(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   5478237,     207850]*)
(*NotebookOutlinePosition[   5478979,     207875]*)
(*  CellTagsIndexPosition[   5478935,     207871]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["PROBING NONHOMOGENEITY WITH INCOMING WAVEFRONT", \
"Text",
  FontSize->14,
  Background->None]], "Title",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["The wavefront  is  incident from the left.\n\nThe nonhomogeneity  \
",
    FontSize->12],
  StyleBox["is located on the positive ",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["x",
    FontSize->12,
    FontSlant->"Italic",
    CharacterEncoding->"WindowsANSI"],
  StyleBox["-axis.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["  \n\nThe wavefront enters the nonhomogeneity at time t=0. \n\n\
The potential   v[x], which is ",
    FontSize->12],
  StyleBox["the nonhomogeneity, is strictly positive.  \n\nThe transmission \
coefficient, left reflection coefficient, and right reflection coefficient, \
respectively, are denoted by  T[k],  L[k],  R[k].\n\nThe tail of the wave is \
denoted by  g[x,t]; there is no tail until the wavefront interacts with the \
nonhomogeneity. ",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  FontSize->18,
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The potential and the scattering coefficients are given next:\
\>", \
"Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(Clear[v, T, L, R, x0, g, e]; 
    v[x_] = \ UnitStep[
          x]\ 80\ \((Sqrt[5] + 1)\) \((Sqrt[5] + 
            2)\)\ E^\((2\ Sqrt[
                  5]\ x)\)/\((\((1 + Sqrt[5])\) \((2 + 
                      Sqrt[5])\)\ E^\((2\ Sqrt[5]\ x)\) - 2)\)^2;\), "\n", 
    \(\(T[k_] = 
        k \((k + I\ Sqrt[5])\)/\((\((k + I)\) \((k + 2\ I)\))\);\)\), "\n", 
    \(\(L[k_] = 2/\((\((k + I)\) \((k + 2\ I)\))\);\)\), "\n", 
    \(\(R[
          k_] = \(-2\)\ \((k + 
                I\ Sqrt[5])\)/\((\((k + I)\) \((k + 2\ I)\) \((k - 
                    I\ Sqrt[5])\))\);\)\)}], "Input",
  CellOpen->False],

Cell[BoxData[
    \(\(\(x0 = 0;\)\(\ \)\)\)], "Input",
  CellOpen->False],

Cell["The tail  g[x,t]  of the  wave is evaluated  next:", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(e[x_] = 
        4\ Sqrt[5]/\((\((1 + Sqrt[5])\) \((2 + 
                      Sqrt[5])\)\ E^\((2\ Sqrt[5]\ x)\) - 
                2)\);\)\n\t\t\), "\n", 
    \(\(q25[x_, t_] = \ 
        2 \((Sqrt[5] - 2 + 
                e[x])\)\ E^\((2 \((\ x - x0 - t)\))\)\  - \((Sqrt[5] - 1 + 
                e[x])\)\ E^\((x - x0 - t)\);\)\n\t\), "\n", 
    \(\t\(q26[x_, t_] = 
        2 \((E^\((\(-2\) \((\ x + x0 + t)\))\)\  - 
              E^\((\(-\((\ x + x0 + t)\)\))\))\)\ ;\)\n\n\), "\n", 
    \(\(g[x_, t_] = \ 
        UnitStep[x]\ \ \ UnitStep[\(-x\) + x0 + t]\ q25[x, t] + 
          UnitStep[\(-x\)]\ \ \ UnitStep[x + x0 + t]\ q26[x, 
              t];\)\)}], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input",
  CellOpen->False],

Cell[TextData[{
  "The wave is animated  next. The wavefront (",
  StyleBox["magenta",
    FontColor->RGBColor[1, 0, 1]],
  ") and the tail (",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  ") are incident from the left onto the nonhomogeneity (",
  StyleBox["green",
    FontColor->RGBColor[0, 1, 0]],
  "):"
}], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-1\), \ 
              2}, \ PlotRange -> {\(-1\), 4}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-1\), \ 2}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(-1\), 
                1}], \[IndentingNewLine]\ \ \ \ \ \ \ Plot[{g[x, 
                t]}, {x, \ \(-1\), \ 2}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(-1\), 
                1}]}, \[IndentingNewLine]\ {t, \ \(-0.9\), \ 1.9,  .02}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.0503 .12361 L
.05288 .12361 L
.05405 .12361 L
.05528 .12361 L
s
.05528 .12361 m
.05554 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`05oooo00?o
09Woooooool07Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool001koool00ol0VOooooooo`16
oooo00<0000co`0co`00Ac?o00D0001Zoooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol0
048co`050000Koooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000m<ol01@0007Coool0
01koool00ol0VOooooooo`16oooo00<0000co`0co`00>C?o00@0001ioooo000Noooo00?o09Wooooo
ool0A_ooo`80000h<ol00P0007goool001koool00ol0VOooooooo`16oooo00<0000co`0co`00=C?o
0080001ooooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol003<co`020000POooo`007_oo
o`03o`2Ioooooooo04Koool00`0003?o03?o000a<ol00P0008?oool001koool00ol0VOooooooo`16
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool001koool00ol0VOooooooo`16oooo00<0
000co`0co`00;S?o00800026oooo000Noooo00?o09Woooooool0A_ooo`80000]<ol00P0008Soool0
01koool00ol0VOooooooo`16oooo00<0000co`0co`00:c?o00030000oooooooo08Soool001koool0
0ol0VOooooooo`16oooo00<0000co`0co`00:S?o00030000oooooooo08Woool001koool00ol0VOoo
ooooo`16oooo00<0000co`0co`00:C?o00030000oooooooo08[oool001koool00ol0VOooooooo`16
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool001koool00ol0VOooooooo`16oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool001koool00ol0VOooooooo`16oooo0P0002Pco`00
0`000?ooooooo`2<oooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000N
oooo00?o09Woooooool0A_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000Noooo00?o
09Woooooool0A_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000Noooo00?o09Wooooo
ool0A_ooo`80000S<ol000<0003oooooool0TOooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`007_ooo`03o`2Ioooooooo03koool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000Noooo00?o09Woooooool0@?ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`007_ooo`03o`2Ioooooooo043oool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000Noooo00?o09Woooooool0@?ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`007_ooo`03o`2Ioooooooo043oool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool001koool00ol0VOooooooo`0o
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`007_ooo`03o`2Ioooooooo
04Koool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`007_ooo`03o`2Ioooooooo04Koool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`007_ooo`03o`2Ioooooooo04Koool2000073?o
00030000oooooooo09Soool001koool00ol0VOooooooo`16oooo00<0000co`0co`006S?o00030000
oooooooo09Woool001koool00ol0VOooooooo`16oooo00<0000co`0co`006S?o00030000oooooooo
09Woool001koool00ol0VOooooooo`16oooo00<0000co`0co`006C?o00030000oooooooo09[oool0
01koool00ol0VOooooooo`16oooo00<0000co`0co`006C?o00030000oooooooo09[oool001koool0
0ol0VOooooooo`16oooo00<0000co`0co`0063?o00030000oooooooo09_oool001koool00ol0VOoo
ooooo`16oooo0P0001Tco`000`000?ooooooo`2Koooo000Noooo00?o09Woooooool0A_ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000N
oooo00?o09Woooooool0A_ooo`80000F<ol000<0003oooooool0W_ooo`007_ooo`03o`2Ioooooooo
04Koool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`007_ooo`03o`2Ioooooooo04Koool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`007_ooo`03o`2Ioooooooo04Koool200005C?o00030000oooooooo09ooool0
01koool00ol0VOooooooo`16oooo00<0000co`0co`004c?o00030000oooooooo0:3oool001koool0
0ol0VOooooooo`16oooo00<0000co`0co`004c?o00030000oooooooo0:3oool001koool00ol0VOoo
ooooo`16oooo00<0000co`0co`004c?o00030000oooooooo0:3oool001koool00ol0VOooooooo`0n
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`007_ooo`03o`2Ioooooooo
03koool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool001koool0
0ol0VOooooooo`0ooooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`007_oo
o`03o`2Ioooooooo043oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool001koool00ol0VOooooooo`0noooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool001koool00ol0VOooooooo`0ooooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`007_ooo`03o`2Ioooooooo04Koool200004C?o00030000oooooooo0:?oool001koool0
0ol0VOooooooo`16oooo00<0000co`0co`0043?o00030000oooooooo0:?oool001koool00ol0VOoo
ooooo`16oooo00<0000co`0co`0043?o00030000oooooooo0:?oool001koool00ol0VOooooooo`16
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool001koool00ol0VOooooooo`16oooo00<0
000co`0co`003c?o00030000oooooooo0:Coool001koool00ol0VOooooooo`16oooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool001koool00ol0VOooooooo`16oooo00<0000co`0co`003c?o
00030000oooooooo0:Coool001koool00ol0VOooooooo`16oooo0P00010co`000`000?ooooooo`2T
oooo000Noooo00?o09Woooooool0A_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000N
oooo00?o09Woooooool0A_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Noooo00?o
09Woooooool0A_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Noooo00?o09Wooooo
ool0A_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Noooo00?o09Woooooool0A_oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000Noooo00?o09Woooooool0A_ooo`80000>
<ol000<0003oooooool0Y_ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`007_oo
o`03o`2Ioooooooo04Koool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`007_ooo`03o`2I
oooooooo04Koool200003C?o00030000oooooooo0:Ooool001koool00ol0VOooooooo`16oooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool001koool00ol0VOooooooo`16oooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool001koool00ol0VOooooooo`16oooo00<0000co`0co`002c?o
00030000oooooooo0:Soool001koool00ol0VOooooooo`0ooooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`007_ooo`03o`2Ioooooooo03koool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`007_ooo`03o`2Ioooooooo043oool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000Noooo00?o09Woooooool0@Oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`007_ooo`03o`2Ioooooooo
03koool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`007_oo
o`03o`2Ioooooooo03ooool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000N
oooo00?o09Woooooool0A_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Noooo00?o
09Woooooool0A_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Noooo00?o09Wooooo
ool0A_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Noooo00?o09Woooooool0A_oo
o`80000;<ol000<0003oooooool0ZOooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`007_oo
o`03o`2Ioooooooo04Koool200002S?o00030000oooooooo0:[oool001koool00ol0VOooooooo`16
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool001koool00ol0VOooooooo`16oooo00<0
000co`0co`002C?o00030000oooooooo0:[oool001koool00ol0VOooooooo`16oooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool001koool00ol0VOooooooo`16oooo00<0000co`0co`0023?o
00030000oooooooo0:_oool001koool00ol0VOooooooo`16oooo00<0000co`0co`0023?o00030000
oooooooo0:_oool001koool00ol0VOooooooo`16oooo0P0000Tco`000`000?ooooooo`2[oooo000N
oooo00?o09Woooooool0A_ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000Noooo00?o
09Woooooool0A_ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000Noooo00?o09Wooooo
ool0A_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Noooo00?o09Woooooool0A_oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Noooo00?o09Woooooool0A_ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000Noooo00?o09Woooooool0A_ooo`800008<ol000<0
003oooooool0[?ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`007_ooo`03o`2Ioooooooo04Koool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`007_oo
o`03o`2Ioooooooo04Koool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`007_ooo`03o`2I
oooooooo043oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Noooo00?o
09Woooooool0@Oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`007_ooo`03o`2Ioooooooo03koool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Ooo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo0`0000Coool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002_ooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000oooooooo00002Oooo`<00004oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0
003oooooool01@0001;oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003ooooo
ool05oooo`80000:oooo0`0000;oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8
<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{79.5625, 308.938}, {204.5, 63.1875}} -> {-0.349561, \
0.447144, 0.00349883, 0.00566123}, {{79.875, 308.563}, {204.5, 63.1875}} -> \
{-2.52168, 1.38097, 0.0124465, 0.0319664}, {{79.875, 308.563}, {204.5, \
63.1875}} -> {-2.52168, 1.38097, 0.0124465, 0.0319664}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.05546 .12361 L
.05789 .12361 L
.06007 .12361 L
.06131 .12361 L
s
.06131 .12361 m
.06176 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooool0V@05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`07oooo00?o
09Woooooool06oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool0023oool00ol0VOooooooo`14
oooo00<0000co`0co`00Ac?o00D0001Zoooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol0
048co`050000Koooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000m<ol01@0007Coool0
023oool00ol0VOooooooo`14oooo00<0000co`0co`00>C?o00@0001ioooo000Poooo00?o09Wooooo
ool0A?ooo`80000h<ol00P0007goool0023oool00ol0VOooooooo`14oooo00<0000co`0co`00=C?o
0080001ooooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol003<co`020000POooo`008?oo
o`03o`2Ioooooooo04Coool00`0003?o03?o000a<ol00P0008?oool0023oool00ol0VOooooooo`14
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool0023oool00ol0VOooooooo`14oooo00<0
000co`0co`00;S?o00800026oooo000Poooo00?o09Woooooool0A?ooo`80000]<ol00P0008Soool0
023oool00ol0VOooooooo`14oooo00<0000co`0co`00:c?o00030000oooooooo08Soool0023oool0
0ol0VOooooooo`14oooo00<0000co`0co`00:S?o00030000oooooooo08Woool0023oool00ol0VOoo
ooooo`14oooo00<0000co`0co`00:C?o00030000oooooooo08[oool0023oool00ol0VOooooooo`14
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool0023oool00ol0VOooooooo`14oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool0023oool00ol0VOooooooo`14oooo0P0002Pco`00
0`000?ooooooo`2<oooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000P
oooo00?o09Woooooool0A?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000Poooo00?o
09Woooooool0A?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000Poooo00?o09Wooooo
ool0A?ooo`80000S<ol000<0003oooooool0TOooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`008?ooo`03o`2Ioooooooo03coool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000Poooo00?o09Woooooool0?_ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`008?ooo`03o`2Ioooooooo03koool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000Poooo00?o09Woooooool0?_ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`008?ooo`03o`2Ioooooooo03koool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool0023oool00ol0VOooooooo`0m
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`008?ooo`03o`2Ioooooooo
04Coool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`008?ooo`03o`2Ioooooooo04Coool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`008?ooo`03o`2Ioooooooo04Coool2000073?o
00030000oooooooo09Soool0023oool00ol0VOooooooo`14oooo00<0000co`0co`006S?o00030000
oooooooo09Woool0023oool00ol0VOooooooo`14oooo00<0000co`0co`006S?o00030000oooooooo
09Woool0023oool00ol0VOooooooo`14oooo00<0000co`0co`006C?o00030000oooooooo09[oool0
023oool00ol0VOooooooo`14oooo00<0000co`0co`006C?o00030000oooooooo09[oool0023oool0
0ol0VOooooooo`14oooo00<0000co`0co`0063?o00030000oooooooo09_oool0023oool00ol0VOoo
ooooo`14oooo0P0001Tco`000`000?ooooooo`2Koooo000Poooo00?o09Woooooool0A?ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000P
oooo00?o09Woooooool0A?ooo`80000F<ol000<0003oooooool0W_ooo`008?ooo`03o`2Ioooooooo
04Coool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`008?ooo`03o`2Ioooooooo04Coool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`008?ooo`03o`2Ioooooooo04Coool200005C?o00030000oooooooo09ooool0
023oool00ol0VOooooooo`14oooo00<0000co`0co`004c?o00030000oooooooo0:3oool0023oool0
0ol0VOooooooo`14oooo00<0000co`0co`004c?o00030000oooooooo0:3oool0023oool00ol0VOoo
ooooo`14oooo00<0000co`0co`004c?o00030000oooooooo0:3oool0023oool00ol0VOooooooo`0l
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`008?ooo`03o`2Ioooooooo
03coool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool0023oool0
0ol0VOooooooo`0moooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`008?oo
o`03o`2Ioooooooo03koool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool0023oool00ol0VOooooooo`0loooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool0023oool00ol0VOooooooo`0moooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`008?ooo`03o`2Ioooooooo04Coool200004C?o00030000oooooooo0:?oool0023oool0
0ol0VOooooooo`14oooo00<0000co`0co`0043?o00030000oooooooo0:?oool0023oool00ol0VOoo
ooooo`14oooo00<0000co`0co`0043?o00030000oooooooo0:?oool0023oool00ol0VOooooooo`14
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool0023oool00ol0VOooooooo`14oooo00<0
000co`0co`003c?o00030000oooooooo0:Coool0023oool00ol0VOooooooo`14oooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool0023oool00ol0VOooooooo`14oooo00<0000co`0co`003c?o
00030000oooooooo0:Coool0023oool00ol0VOooooooo`14oooo0P00010co`000`000?ooooooo`2T
oooo000Poooo00?o09Woooooool0A?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000P
oooo00?o09Woooooool0A?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Poooo00?o
09Woooooool0A?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Poooo00?o09Wooooo
ool0A?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Poooo00?o09Woooooool0A?oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000Poooo00?o09Woooooool0A?ooo`80000>
<ol000<0003oooooool0Y_ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`008?oo
o`03o`2Ioooooooo04Coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`008?ooo`03o`2I
oooooooo04Coool200003C?o00030000oooooooo0:Ooool0023oool00ol0VOooooooo`14oooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool0023oool00ol0VOooooooo`14oooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool0023oool00ol0VOooooooo`14oooo00<0000co`0co`002c?o
00030000oooooooo0:Soool0023oool00ol0VOooooooo`0moooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`008?ooo`03o`2Ioooooooo03coool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`008?ooo`03o`2Ioooooooo03koool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000Poooo00?o09Woooooool0?oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`008?ooo`03o`2Ioooooooo
03coool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`008?oo
o`03o`2Ioooooooo03goool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000P
oooo00?o09Woooooool0A?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Poooo00?o
09Woooooool0A?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Poooo00?o09Wooooo
ool0A?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Poooo00?o09Woooooool0A?oo
o`80000;<ol000<0003oooooool0ZOooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`008?oo
o`03o`2Ioooooooo04Coool200002S?o00030000oooooooo0:[oool0023oool00ol0VOooooooo`14
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool0023oool00ol0VOooooooo`14oooo00<0
000co`0co`002C?o00030000oooooooo0:[oool0023oool00ol0VOooooooo`14oooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool0023oool00ol0VOooooooo`14oooo00<0000co`0co`0023?o
00030000oooooooo0:_oool0023oool00ol0VOooooooo`14oooo00<0000co`0co`0023?o00030000
oooooooo0:_oool0023oool00ol0VOooooooo`14oooo0P0000Tco`000`000?ooooooo`2[oooo000P
oooo00?o09Woooooool0A?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000Poooo00?o
09Woooooool0A?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000Poooo00?o09Wooooo
ool0A?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Poooo00?o09Woooooool0A?oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Poooo00?o09Woooooool0A?ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000Poooo00?o09Woooooool0A?ooo`800008<ol000<0
003oooooool0[?ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`008?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`008?oo
o`03o`2Ioooooooo04Coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`008?ooo`03o`2I
oooooooo03koool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Poooo00?o
09Woooooool0?oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`008?ooo`03o`2Ioooooooo03coool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00Ioooo`Tco`04oooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`00
00;oool010000?ooooooo`0000Coool00`000?ooooooo`1doooo001Woooo2C?o00Goool00`000?oo
ooooo`0500004_ooo`040000oooooooo00002Oooo`800004oooo0P0000Coool00`000?ooooooo`1e
oooo001Woooo2C?o00Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00Ioooo`Tco`06
oooo00<0003oooooool05oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Koool0
06Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.04262 .12361 L
.0522 .12361 L
.06244 .12361 L
.06525 .12361 L
.06662 .12361 L
.0679 .12361 L
s
.0679 .12361 m
.06836 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool010000?ooooooool0
V@Coool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo00Soool0
0ol0VOooooooo`0Joooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`008Oooo`03o`2Ioooooooo
04?oool00`0003?o03?o0017<ol01@0006[oool0027oool00ol0VOooooooo`13oooo00<0000co`0c
o`00@S?o00D0001_oooo000Qoooo00?o09Woooooool0@oooo`030000<ol0<ol003dco`050000M?oo
o`008Oooo`03o`2Ioooooooo04?oool00`0003?o03?o000i<ol0100007Woool0027oool00ol0VOoo
ooooo`13oooo0P0003Pco`020000OOooo`008Oooo`03o`2Ioooooooo04?oool00`0003?o03?o000e
<ol00P0007ooool0027oool00ol0VOooooooo`13oooo00<0000co`0co`00<c?o00800021oooo000Q
oooo00?o09Woooooool0@oooo`030000<ol0<ol0034co`020000Poooo`008Oooo`03o`2Ioooooooo
04?oool00`0003?o03?o000`<ol000<0003oooooool0Poooo`008Oooo`03o`2Ioooooooo04?oool0
0`0003?o03?o000^<ol00P0008Koool0027oool00ol0VOooooooo`13oooo0P0002dco`020000R?oo
o`008Oooo`03o`2Ioooooooo04?oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`008Ooo
o`03o`2Ioooooooo04?oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`008Oooo`03o`2I
oooooooo04?oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`008Oooo`03o`2Ioooooooo
04?oool00`0003?o03?o000X<ol000<0003oooooool0Roooo`008Oooo`03o`2Ioooooooo04?oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`008Oooo`03o`2Ioooooooo04?oool20000:3?o
00030000oooooooo08coool0027oool00ol0VOooooooo`13oooo00<0000co`0co`009S?o00030000
oooooooo08goool0027oool00ol0VOooooooo`13oooo00<0000co`0co`009C?o00030000oooooooo
08koool0027oool00ol0VOooooooo`13oooo00<0000co`0co`0093?o00030000oooooooo08ooool0
027oool00ol0VOooooooo`13oooo00<0000co`0co`008c?o00030000oooooooo093oool0027oool0
0ol0VOooooooo`13oooo00<0000co`0co`008c?o00030000oooooooo093oool0027oool00ol0VOoo
ooooo`13oooo0P0002<co`000`000?ooooooo`2Aoooo000Qoooo00?o09Woooooool0@oooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo000Qoooo00?o09Woooooool0@oooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo000Qoooo00?o09Woooooool0@oooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo000Qoooo00?o09Woooooool0@oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000Qoooo00?o09Woooooool0>oooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo09Coool0027oool00ol0VOooooooo`0moooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Eoooo000Qoooo00?o09Woooooool0?Oooo`030000oooooooo00?oool2
00007c?o00030000oooooooo09Goool0027oool00ol0VOooooooo`0moooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`2Foooo000Qoooo00?o09Woooooool0?Oooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`008Oooo`03o`2Ioooooooo
03coool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000Qoooo00?o09Wooooo
ool0@oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000Qoooo00?o09Woooooool0@ooo
o`030000<ol0<ol001/co`000`000?ooooooo`2Hoooo000Qoooo00?o09Woooooool0@oooo`80000L
<ol000<0003oooooool0V?ooo`008Oooo`03o`2Ioooooooo04?oool00`0003?o03?o000J<ol000<0
003oooooool0VOooo`008Oooo`03o`2Ioooooooo04?oool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`008Oooo`03o`2Ioooooooo04?oool00`0003?o03?o000I<ol000<0003oooooool0V_oo
o`008Oooo`03o`2Ioooooooo04?oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`008Ooo
o`03o`2Ioooooooo04?oool00`0003?o03?o000H<ol000<0003oooooool0Voooo`008Oooo`03o`2I
oooooooo04?oool200006C?o00030000oooooooo09_oool0027oool00ol0VOooooooo`13oooo00<0
000co`0co`005c?o00030000oooooooo09coool0027oool00ol0VOooooooo`13oooo00<0000co`0c
o`005c?o00030000oooooooo09coool0027oool00ol0VOooooooo`13oooo00<0000co`0co`005S?o
00030000oooooooo09goool0027oool00ol0VOooooooo`13oooo00<0000co`0co`005S?o00030000
oooooooo09goool0027oool00ol0VOooooooo`13oooo00<0000co`0co`005S?o00030000oooooooo
09goool0027oool00ol0VOooooooo`13oooo00<0000co`0co`005C?o00030000oooooooo09koool0
027oool00ol0VOooooooo`13oooo0P0001Hco`000`000?ooooooo`2Noooo000Qoooo00?o09Wooooo
ool0@oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000Qoooo00?o09Woooooool0@ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000Qoooo00?o09Woooooool0@oooo`030000
<ol0<ol001@co`000`000?ooooooo`2Ooooo000Qoooo00?o09Woooooool0@oooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo000Qoooo00?o09Woooooool0@oooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo000Qoooo00?o09Woooooool0@oooo`80000E<ol000<0003oooooool0Wooo
o`008Oooo`03o`2Ioooooooo04?oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`008Ooo
o`03o`2Ioooooooo04?oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`008Oooo`03o`2I
oooooooo04?oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`008Oooo`03o`2Ioooooooo
03_oool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo000Qoooo00?o09Wooooo
ool0>oooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`008Ooo
o`03o`2Ioooooooo03coool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo000R
oooo00?o09Woooooool0??ooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0XOooo`008_ooo`03o`2Ioooooooo03[oool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`008_ooo`03o`2Ioooooooo03_oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo000Roooo00?o09Woooooool0@_ooo`80000A<ol000<0003oooooool0Xoooo`008_oo
o`03o`2Ioooooooo04;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`008_ooo`03o`2I
oooooooo04;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`008_ooo`03o`2Ioooooooo
04;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`008_ooo`03o`2Ioooooooo04;oool0
0`0003?o03?o000?<ol000<0003oooooool0Y?ooo`008_ooo`03o`2Ioooooooo04;oool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`008_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`008_ooo`03o`2Ioooooooo04;oool2000043?o00030000oooooooo
0:Coool002;oool00ol0VOooooooo`12oooo00<0000co`0co`003S?o00030000oooooooo0:Goool0
02;oool00ol0VOooooooo`12oooo00<0000co`0co`003S?o00030000oooooooo0:Goool002;oool0
0ol0VOooooooo`12oooo00<0000co`0co`003S?o00030000oooooooo0:Goool002;oool00ol0VOoo
ooooo`12oooo00<0000co`0co`003S?o00030000oooooooo0:Goool002;oool00ol0VOooooooo`12
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool002;oool00ol0VOooooooo`12oooo0P00
00hco`000`000?ooooooo`2Voooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000dco`00
0`000?ooooooo`2Voooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000`co`000`000?ooooooo`2W
oooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000R
oooo00?o09Woooooool0@_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000Roooo00?o
09Woooooool0@_ooo`80000=<ol000<0003oooooool0Yoooo`008_ooo`03o`2Ioooooooo04;oool0
0`0003?o03?o000<<ol000<0003oooooool0Yoooo`008_ooo`03o`2Ioooooooo04;oool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`008_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`008_ooo`03o`2Ioooooooo03_oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo000Roooo00?o09Woooooool0>_ooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000Roooo00?o09Woooooool0??ooo`030000
oooooooo00?oool2000033?o00030000oooooooo0:Soool002;oool00ol0VOooooooo`0moooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000Roooo00?o09Wooooo
ool0>_ooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000R
oooo00?o09Woooooool0>oooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
02;oool00ol0VOooooooo`12oooo00<0000co`0co`002S?o00030000oooooooo0:Woool002;oool0
0ol0VOooooooo`12oooo00<0000co`0co`002S?o00030000oooooooo0:Woool002;oool00ol0VOoo
ooooo`12oooo00<0000co`0co`002S?o00030000oooooooo0:Woool002;oool00ol0VOooooooo`12
oooo0P0000/co`000`000?ooooooo`2Yoooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000R
oooo00?o09Woooooool0@_ooo`80000:<ol000<0003oooooool0Z_ooo`008_ooo`03o`2Ioooooooo
04;oool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`008_ooo`03o`2Ioooooooo04;oool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`008_ooo`03o`2Ioooooooo04;oool00`0003?o
03?o0008<ol000<0003oooooool0Zoooo`008_ooo`03o`2Ioooooooo04;oool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`008_ooo`03o`2Ioooooooo04;oool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`008_ooo`03o`2Ioooooooo04;oool200002C?o00030000oooooooo0:_oool0
02;oool00ol0VOooooooo`12oooo00<0000co`0co`0023?o00030000oooooooo0:_oool002;oool0
0ol0VOooooooo`12oooo00<0000co`0co`0023?o00030000oooooooo0:_oool002;oool00ol0VOoo
ooooo`12oooo00<0000co`0co`001c?o00030000oooooooo0:coool002;oool00ol0VOooooooo`12
oooo00<0000co`0co`001c?o00030000oooooooo0:coool002;oool00ol0VOooooooo`12oooo00<0
000co`0co`001c?o00030000oooooooo0:coool002;oool00ol0VOooooooo`12oooo0P0000Pco`00
0`000?ooooooo`2/oooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`2/oooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000Roooo00?o09Woooooool0@_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000R
oooo00?o09Woooooool0@_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Roooo00?o
09Woooooool0??ooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool002;oool0
0ol0VOooooooo`0moooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000Roooo00?o09Woooooool0>_ooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200000oooo`<00004
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001Woooo2C?o00Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo
00000_ooo`040000oooooooo00001?ooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000
oooooooo00D0000Boooo00@0003oooooool00009oooo0P0000?oool300001?ooo`030000oooooooo
07Goool006Ooool9<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0MOooo`00Ioooo`Tco`06
oooo00<0003oooooool05oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Koool0
06Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.06747 .12361 L
.07024 .12361 L
.0716 .12361 L
.07286 .12361 L
.07404 .12361 L
s
.07404 .12361 m
.07454 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`02
oooo00Co09Woooooool00007oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo00[oool0
0ol0VOooooooo`0Hoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`008oooo`03o`2Ioooooooo
047oool00`0003?o03?o0017<ol01@0006[oool002?oool00ol0VOooooooo`11oooo00<0000co`0c
o`00@S?o00D0001_oooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol003dco`050000M?oo
o`008oooo`03o`2Ioooooooo047oool00`0003?o03?o000i<ol0100007Woool002?oool00ol0VOoo
ooooo`11oooo0P0003Pco`020000OOooo`008oooo`03o`2Ioooooooo047oool00`0003?o03?o000e
<ol00P0007ooool002?oool00ol0VOooooooo`11oooo00<0000co`0co`00<c?o00800021oooo000S
oooo00?o09Woooooool0@Oooo`030000<ol0<ol0034co`020000Poooo`008oooo`03o`2Ioooooooo
047oool00`0003?o03?o000`<ol000<0003oooooool0Poooo`008oooo`03o`2Ioooooooo047oool0
0`0003?o03?o000^<ol00P0008Koool002?oool00ol0VOooooooo`11oooo0P0002dco`020000R?oo
o`008oooo`03o`2Ioooooooo047oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`008ooo
o`03o`2Ioooooooo047oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`008oooo`03o`2I
oooooooo047oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`008oooo`03o`2Ioooooooo
047oool00`0003?o03?o000X<ol000<0003oooooool0Roooo`008oooo`03o`2Ioooooooo047oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`008oooo`03o`2Ioooooooo047oool20000:3?o
00030000oooooooo08coool002?oool00ol0VOooooooo`11oooo00<0000co`0co`009S?o00030000
oooooooo08goool002?oool00ol0VOooooooo`11oooo00<0000co`0co`009C?o00030000oooooooo
08koool002?oool00ol0VOooooooo`11oooo00<0000co`0co`0093?o00030000oooooooo08ooool0
02?oool00ol0VOooooooo`11oooo00<0000co`0co`008c?o00030000oooooooo093oool002?oool0
0ol0VOooooooo`11oooo00<0000co`0co`008c?o00030000oooooooo093oool002?oool00ol0VOoo
ooooo`11oooo0P0002<co`000`000?ooooooo`2Aoooo000Soooo00?o09Woooooool0@Oooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000Soooo00?o09Woooooool0>Oooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo09Coool002?oool00ol0VOooooooo`0koooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Eoooo000Soooo00?o09Woooooool0>oooo`030000oooooooo00?oool2
00007c?o00030000oooooooo09Goool002?oool00ol0VOooooooo`0koooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`2Foooo000Soooo00?o09Woooooool0>oooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`008oooo`03o`2Ioooooooo
03[oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000Soooo00?o09Wooooo
ool0@Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000Soooo00?o09Woooooool0@Ooo
o`030000<ol0<ol001/co`000`000?ooooooo`2Hoooo000Soooo00?o09Woooooool0@Oooo`80000L
<ol000<0003oooooool0V?ooo`008oooo`03o`2Ioooooooo047oool00`0003?o03?o000J<ol000<0
003oooooool0VOooo`008oooo`03o`2Ioooooooo047oool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`008oooo`03o`2Ioooooooo047oool00`0003?o03?o000I<ol000<0003oooooool0V_oo
o`008oooo`03o`2Ioooooooo047oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`008ooo
o`03o`2Ioooooooo047oool00`0003?o03?o000H<ol000<0003oooooool0Voooo`008oooo`03o`2I
oooooooo047oool200006C?o00030000oooooooo09_oool002?oool00ol0VOooooooo`11oooo00<0
000co`0co`005c?o00030000oooooooo09coool002?oool00ol0VOooooooo`11oooo00<0000co`0c
o`005c?o00030000oooooooo09coool002?oool00ol0VOooooooo`11oooo00<0000co`0co`005S?o
00030000oooooooo09goool002?oool00ol0VOooooooo`11oooo00<0000co`0co`005S?o00030000
oooooooo09goool002?oool00ol0VOooooooo`11oooo00<0000co`0co`005S?o00030000oooooooo
09goool002?oool00ol0VOooooooo`11oooo00<0000co`0co`005C?o00030000oooooooo09koool0
02?oool00ol0VOooooooo`11oooo0P0001Hco`000`000?ooooooo`2Noooo000Soooo00?o09Wooooo
ool0@Oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000Soooo00?o09Woooooool0@Ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000Soooo00?o09Woooooool0@Oooo`030000
<ol0<ol001@co`000`000?ooooooo`2Ooooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo000Soooo00?o09Woooooool0@Oooo`80000E<ol000<0003oooooool0Wooo
o`008oooo`03o`2Ioooooooo047oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`008ooo
o`03o`2Ioooooooo047oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`008oooo`03o`2I
oooooooo047oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`008oooo`03o`2Ioooooooo
03Woool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo000Soooo00?o09Wooooo
ool0>Oooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`008ooo
o`03o`2Ioooooooo03[oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo000S
oooo00?o09Woooooool0>oooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0XOooo`008oooo`03o`2Ioooooooo03Woool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`008oooo`03o`2Ioooooooo03[oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo000Soooo00?o09Woooooool0@Oooo`80000A<ol000<0003oooooool0Xoooo`008ooo
o`03o`2Ioooooooo047oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`008oooo`03o`2I
oooooooo047oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`008oooo`03o`2Ioooooooo
047oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`008oooo`03o`2Ioooooooo047oool0
0`0003?o03?o000?<ol000<0003oooooool0Y?ooo`008oooo`03o`2Ioooooooo047oool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`008oooo`03o`2Ioooooooo047oool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`008oooo`03o`2Ioooooooo047oool2000043?o00030000oooooooo
0:Coool002?oool00ol0VOooooooo`11oooo00<0000co`0co`003S?o00030000oooooooo0:Goool0
02?oool00ol0VOooooooo`11oooo00<0000co`0co`003S?o00030000oooooooo0:Goool002?oool0
0ol0VOooooooo`11oooo00<0000co`0co`003S?o00030000oooooooo0:Goool002?oool00ol0VOoo
ooooo`11oooo00<0000co`0co`003S?o00030000oooooooo0:Goool002?oool00ol0VOooooooo`11
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool002?oool00ol0VOooooooo`11oooo0P00
00hco`000`000?ooooooo`2Voooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000dco`00
0`000?ooooooo`2Voooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000`co`000`000?ooooooo`2W
oooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000S
oooo00?o09Woooooool0@Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000Soooo00?o
09Woooooool0@Oooo`80000=<ol000<0003oooooool0Yoooo`008oooo`03o`2Ioooooooo047oool0
0`0003?o03?o000<<ol000<0003oooooool0Yoooo`008oooo`03o`2Ioooooooo047oool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`008oooo`03o`2Ioooooooo047oool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`008oooo`03o`2Ioooooooo03[oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo000Soooo00?o09Woooooool0>Oooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000Soooo00?o09Woooooool0>oooo`030000
oooooooo00?oool2000033?o00030000oooooooo0:Soool002?oool00ol0VOooooooo`0loooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000Soooo00?o09Wooooo
ool0>Oooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000S
oooo00?o09Woooooool0>_ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
02?oool00ol0VOooooooo`11oooo00<0000co`0co`002S?o00030000oooooooo0:Woool002?oool0
0ol0VOooooooo`11oooo00<0000co`0co`002S?o00030000oooooooo0:Woool002?oool00ol0VOoo
ooooo`11oooo00<0000co`0co`002S?o00030000oooooooo0:Woool002?oool00ol0VOooooooo`11
oooo0P0000/co`000`000?ooooooo`2Yoooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000S
oooo00?o09Woooooool0@Oooo`80000:<ol000<0003oooooool0Z_ooo`008oooo`03o`2Ioooooooo
047oool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`008oooo`03o`2Ioooooooo047oool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`008oooo`03o`2Ioooooooo047oool00`0003?o
03?o0008<ol000<0003oooooool0Zoooo`008oooo`03o`2Ioooooooo047oool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`008oooo`03o`2Ioooooooo047oool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`008oooo`03o`2Ioooooooo047oool200002C?o00030000oooooooo0:_oool0
02?oool00ol0VOooooooo`11oooo00<0000co`0co`0023?o00030000oooooooo0:_oool002?oool0
0ol0VOooooooo`11oooo00<0000co`0co`0023?o00030000oooooooo0:_oool002?oool00ol0VOoo
ooooo`11oooo00<0000co`0co`001c?o00030000oooooooo0:coool002?oool00ol0VOooooooo`11
oooo00<0000co`0co`001c?o00030000oooooooo0:coool002?oool00ol0VOooooooo`11oooo00<0
000co`0co`001c?o00030000oooooooo0:coool002?oool00ol0VOooooooo`11oooo0P0000Pco`00
0`000?ooooooo`2/oooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`2/oooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000Soooo00?o09Woooooool0@Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000S
oooo00?o09Woooooool0@Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Soooo00?o
09Woooooool0>oooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool002?oool0
0ol0VOooooooo`0loooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000Soooo00?o09Woooooool0>Oooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200001Oooo`<00002
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool01@000?ooooooooooo`00001goooo001Woooo2C?o00Coool00`000?ooooooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`D00003
oooo00<0003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000Woool200000oooo`040000oooooooo00000oooo`030000oooooooo07Goool006Ooool9
<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooo`000003oooo00<0003oooooool0MOooo`00Ioooo`Tco`06oooo00<0003ooooo
ool05oooo`80000:oooo0P0000Goool200000_ooo`030000oooooooo07Koool006Ooool9<ol0/?oo
o`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.06747 .12361 L
.07286 .12361 L
.07547 .12361 L
.07793 .12361 L
.07901 .12361 L
.08015 .12361 L
s
.08015 .12361 m
.08065 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`04
oooo00?o09T0003oool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0<oooo00?o
09Woooooool05_ooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool002Goool00ol0VOooooooo`0o
oooo00<0000co`0co`00Ac?o00D0001Zoooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol0
048co`050000Koooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000m<ol01@0007Coool0
02Goool00ol0VOooooooo`0ooooo00<0000co`0co`00>C?o00@0001ioooo000Uoooo00?o09Wooooo
ool0?oooo`80000h<ol00P0007goool002Goool00ol0VOooooooo`0ooooo00<0000co`0co`00=C?o
0080001ooooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol003<co`020000POooo`009Ooo
o`03o`2Ioooooooo03ooool00`0003?o03?o000a<ol00P0008?oool002Goool00ol0VOooooooo`0o
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool002Goool00ol0VOooooooo`0ooooo00<0
000co`0co`00;S?o00800026oooo000Uoooo00?o09Woooooool0?oooo`80000]<ol00P0008Soool0
02Goool00ol0VOooooooo`0ooooo00<0000co`0co`00:c?o00030000oooooooo08Soool002Goool0
0ol0VOooooooo`0ooooo00<0000co`0co`00:S?o00030000oooooooo08Woool002Goool00ol0VOoo
ooooo`0ooooo00<0000co`0co`00:C?o00030000oooooooo08[oool002Goool00ol0VOooooooo`0o
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool002Goool00ol0VOooooooo`0ooooo00<0
000co`0co`00:3?o00030000oooooooo08_oool002Goool00ol0VOooooooo`0ooooo0P0002Pco`00
0`000?ooooooo`2<oooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000U
oooo00?o09Woooooool0?oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000Uoooo00?o
09Woooooool0?oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000Uoooo00?o09Wooooo
ool0?oooo`80000S<ol000<0003oooooool0TOooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`009Oooo`03o`2Ioooooooo03Ooool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000Uoooo00?o09Woooooool0>Oooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`009Oooo`03o`2Ioooooooo03Woool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000Uoooo00?o09Woooooool0>Oooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`009Oooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool002Goool00ol0VOooooooo`0h
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`009Oooo`03o`2Ioooooooo
03ooool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`009Oooo`03o`2Ioooooooo03ooool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`009Oooo`03o`2Ioooooooo03ooool2000073?o
00030000oooooooo09Soool002Goool00ol0VOooooooo`0ooooo00<0000co`0co`006S?o00030000
oooooooo09Woool002Goool00ol0VOooooooo`0ooooo00<0000co`0co`006S?o00030000oooooooo
09Woool002Goool00ol0VOooooooo`0ooooo00<0000co`0co`006C?o00030000oooooooo09[oool0
02Goool00ol0VOooooooo`0ooooo00<0000co`0co`006C?o00030000oooooooo09[oool002Goool0
0ol0VOooooooo`0ooooo00<0000co`0co`0063?o00030000oooooooo09_oool002Goool00ol0VOoo
ooooo`0ooooo0P0001Tco`000`000?ooooooo`2Koooo000Uoooo00?o09Woooooool0?oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000U
oooo00?o09Woooooool0?oooo`80000F<ol000<0003oooooool0W_ooo`009Oooo`03o`2Ioooooooo
03ooool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`009Oooo`03o`2Ioooooooo03ooool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`009Oooo`03o`2Ioooooooo03ooool200005C?o00030000oooooooo09ooool0
02Goool00ol0VOooooooo`0ooooo00<0000co`0co`004c?o00030000oooooooo0:3oool002Goool0
0ol0VOooooooo`0ooooo00<0000co`0co`004c?o00030000oooooooo0:3oool002Goool00ol0VOoo
ooooo`0ooooo00<0000co`0co`004c?o00030000oooooooo0:3oool002Goool00ol0VOooooooo`0g
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`009Oooo`03o`2Ioooooooo
03Ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool002Goool0
0ol0VOooooooo`0hoooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`009Ooo
o`03o`2Ioooooooo03Woool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool002Goool00ol0VOooooooo`0goooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool002Goool00ol0VOooooooo`0hoooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`009Oooo`03o`2Ioooooooo03ooool200004C?o00030000oooooooo0:?oool002Goool0
0ol0VOooooooo`0ooooo00<0000co`0co`0043?o00030000oooooooo0:?oool002Goool00ol0VOoo
ooooo`0ooooo00<0000co`0co`0043?o00030000oooooooo0:?oool002Goool00ol0VOooooooo`0o
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool002Goool00ol0VOooooooo`0ooooo00<0
000co`0co`003c?o00030000oooooooo0:Coool002Goool00ol0VOooooooo`0ooooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool002Goool00ol0VOooooooo`0ooooo00<0000co`0co`003c?o
00030000oooooooo0:Coool002Goool00ol0VOooooooo`0ooooo0P00010co`000`000?ooooooo`2T
oooo000Uoooo00?o09Woooooool0?oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000U
oooo00?o09Woooooool0?oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Uoooo00?o
09Woooooool0?oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Uoooo00?o09Wooooo
ool0?oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Uoooo00?o09Woooooool0?ooo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000Uoooo00?o09Woooooool0?oooo`80000>
<ol000<0003oooooool0Y_ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`009Ooo
o`03o`2Ioooooooo03ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`009Oooo`03o`2I
oooooooo03ooool200003C?o00030000oooooooo0:Ooool002Goool00ol0VOooooooo`0ooooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool002Goool00ol0VOooooooo`0ooooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool002Goool00ol0VOooooooo`0ooooo00<0000co`0co`002c?o
00030000oooooooo0:Soool002Goool00ol0VOooooooo`0hoooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`009Oooo`03o`2Ioooooooo03Ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`009Oooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000Uoooo00?o09Woooooool0>_ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`009Oooo`03o`2Ioooooooo
03Ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`009Ooo
o`03o`2Ioooooooo03Soool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000U
oooo00?o09Woooooool0?oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Uoooo00?o
09Woooooool0?oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Uoooo00?o09Wooooo
ool0?oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Uoooo00?o09Woooooool0?ooo
o`80000;<ol000<0003oooooool0ZOooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`009Ooo
o`03o`2Ioooooooo03ooool200002S?o00030000oooooooo0:[oool002Goool00ol0VOooooooo`0o
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool002Goool00ol0VOooooooo`0ooooo00<0
000co`0co`002C?o00030000oooooooo0:[oool002Goool00ol0VOooooooo`0ooooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool002Goool00ol0VOooooooo`0ooooo00<0000co`0co`0023?o
00030000oooooooo0:_oool002Goool00ol0VOooooooo`0ooooo00<0000co`0co`0023?o00030000
oooooooo0:_oool002Goool00ol0VOooooooo`0ooooo0P0000Tco`000`000?ooooooo`2[oooo000U
oooo00?o09Woooooool0?oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000Uoooo00?o
09Woooooool0?oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000Uoooo00?o09Wooooo
ool0?oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Uoooo00?o09Woooooool0?ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Uoooo00?o09Woooooool0?oooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000Uoooo00?o09Woooooool0?oooo`800008<ol000<0
003oooooool0[?ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`009Oooo`03o`2Ioooooooo03ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`009Ooo
o`03o`2Ioooooooo03ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`009Oooo`03o`2I
oooooooo03Woool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Uoooo00?o
09Woooooool0>_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`009Oooo`03o`2Ioooooooo03Ooool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000?oool400000ooo
o`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00<0003oooooool01?ooo`030000oooooooo07Goool006Ooool9<ol01?ooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool01?ooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000oooooooo
00D0000Boooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`02oooo00<0003ooooo
ool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool006Ooool9
<ol01_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1f
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.07216 .12361 L
.0775 .12361 L
.08255 .12361 L
.08542 .12361 L
.0862 .12361 L
.08703 .12361 L
s
.08703 .12361 m
.08732 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0=oooo00?o
09Woooooool05Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool002Koool00ol0VOooooooo`0n
oooo00<0000co`0co`00Ac?o00D0001Zoooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol0
048co`050000Koooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000m<ol01@0007Coool0
02Koool00ol0VOooooooo`0noooo00<0000co`0co`00>C?o00@0001ioooo000Voooo00?o09Wooooo
ool0?_ooo`80000h<ol00P0007goool002Koool00ol0VOooooooo`0noooo00<0000co`0co`00=C?o
0080001ooooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol003<co`020000POooo`009_oo
o`03o`2Ioooooooo03koool00`0003?o03?o000a<ol00P0008?oool002Koool00ol0VOooooooo`0n
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool002Koool00ol0VOooooooo`0noooo00<0
000co`0co`00;S?o00800026oooo000Voooo00?o09Woooooool0?_ooo`80000]<ol00P0008Soool0
02Koool00ol0VOooooooo`0noooo00<0000co`0co`00:c?o00030000oooooooo08Soool002Koool0
0ol0VOooooooo`0noooo00<0000co`0co`00:S?o00030000oooooooo08Woool002Koool00ol0VOoo
ooooo`0noooo00<0000co`0co`00:C?o00030000oooooooo08[oool002Koool00ol0VOooooooo`0n
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool002Koool00ol0VOooooooo`0noooo00<0
000co`0co`00:3?o00030000oooooooo08_oool002Koool00ol0VOooooooo`0noooo0P0002Pco`00
0`000?ooooooo`2<oooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000V
oooo00?o09Woooooool0?_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000Voooo00?o
09Woooooool0?_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000Voooo00?o09Wooooo
ool0?_ooo`80000S<ol000<0003oooooool0TOooo`009_ooo`03o`2Ioooooooo03koool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`009_ooo`03o`2Ioooooooo03Koool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000Voooo00?o09Woooooool0>?ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`009_ooo`03o`2Ioooooooo03Soool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000Voooo00?o09Woooooool0>?ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`009_ooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool002Koool00ol0VOooooooo`0g
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`009_ooo`03o`2Ioooooooo
03koool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`009_ooo`03o`2Ioooooooo03koool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`009_ooo`03o`2Ioooooooo03koool2000073?o
00030000oooooooo09Soool002Koool00ol0VOooooooo`0noooo00<0000co`0co`006S?o00030000
oooooooo09Woool002Koool00ol0VOooooooo`0noooo00<0000co`0co`006S?o00030000oooooooo
09Woool002Koool00ol0VOooooooo`0noooo00<0000co`0co`006C?o00030000oooooooo09[oool0
02Koool00ol0VOooooooo`0noooo00<0000co`0co`006C?o00030000oooooooo09[oool002Koool0
0ol0VOooooooo`0noooo00<0000co`0co`0063?o00030000oooooooo09_oool002Koool00ol0VOoo
ooooo`0noooo0P0001Tco`000`000?ooooooo`2Koooo000Voooo00?o09Woooooool0?_ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000V
oooo00?o09Woooooool0?_ooo`80000F<ol000<0003oooooool0W_ooo`009_ooo`03o`2Ioooooooo
03koool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`009_ooo`03o`2Ioooooooo03koool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`009_ooo`03o`2Ioooooooo03koool200005C?o00030000oooooooo09ooool0
02Koool00ol0VOooooooo`0noooo00<0000co`0co`004c?o00030000oooooooo0:3oool002Koool0
0ol0VOooooooo`0noooo00<0000co`0co`004c?o00030000oooooooo0:3oool002Koool00ol0VOoo
ooooo`0noooo00<0000co`0co`004c?o00030000oooooooo0:3oool002Koool00ol0VOooooooo`0f
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`009_ooo`03o`2Ioooooooo
03Koool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool002Koool0
0ol0VOooooooo`0goooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`009_oo
o`03o`2Ioooooooo03Soool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool002Koool00ol0VOooooooo`0foooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool002Koool00ol0VOooooooo`0goooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`009_ooo`03o`2Ioooooooo03koool200004C?o00030000oooooooo0:?oool002Koool0
0ol0VOooooooo`0noooo00<0000co`0co`0043?o00030000oooooooo0:?oool002Koool00ol0VOoo
ooooo`0noooo00<0000co`0co`0043?o00030000oooooooo0:?oool002Koool00ol0VOooooooo`0n
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool002Koool00ol0VOooooooo`0noooo00<0
000co`0co`003c?o00030000oooooooo0:Coool002Koool00ol0VOooooooo`0noooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool002Koool00ol0VOooooooo`0noooo00<0000co`0co`003c?o
00030000oooooooo0:Coool002Koool00ol0VOooooooo`0noooo0P00010co`000`000?ooooooo`2T
oooo000Voooo00?o09Woooooool0?_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000V
oooo00?o09Woooooool0?_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Voooo00?o
09Woooooool0?_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Voooo00?o09Wooooo
ool0?_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Voooo00?o09Woooooool0?_oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000Voooo00?o09Woooooool0?_ooo`80000>
<ol000<0003oooooool0Y_ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`009_oo
o`03o`2Ioooooooo03koool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`009_ooo`03o`2I
oooooooo03koool200003C?o00030000oooooooo0:Ooool002Koool00ol0VOooooooo`0noooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool002Koool00ol0VOooooooo`0noooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool002Koool00ol0VOooooooo`0noooo00<0000co`0co`002c?o
00030000oooooooo0:Soool002Koool00ol0VOooooooo`0goooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`009_ooo`03o`2Ioooooooo03Koool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`009_ooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000Voooo00?o09Woooooool0>Oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`009_ooo`03o`2Ioooooooo
03Koool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`009_oo
o`03o`2Ioooooooo03Ooool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000V
oooo00?o09Woooooool0?_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Voooo00?o
09Woooooool0?_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Voooo00?o09Wooooo
ool0?_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Voooo00?o09Woooooool0?_oo
o`80000;<ol000<0003oooooool0ZOooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`009_oo
o`03o`2Ioooooooo03koool200002S?o00030000oooooooo0:[oool002Koool00ol0VOooooooo`0n
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool002Koool00ol0VOooooooo`0noooo00<0
000co`0co`002C?o00030000oooooooo0:[oool002Koool00ol0VOooooooo`0noooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool002Koool00ol0VOooooooo`0noooo00<0000co`0co`0023?o
00030000oooooooo0:_oool002Koool00ol0VOooooooo`0noooo00<0000co`0co`0023?o00030000
oooooooo0:_oool002Koool00ol0VOooooooo`0noooo0P0000Tco`000`000?ooooooo`2[oooo000V
oooo00?o09Woooooool0?_ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000Voooo00?o
09Woooooool0?_ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000Voooo00?o09Wooooo
ool0?_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Voooo00?o09Woooooool0?_oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Voooo00?o09Woooooool0?_ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000Voooo00?o09Woooooool0?_ooo`800008<ol000<0
003oooooool0[?ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`009_ooo`03o`2Ioooooooo03koool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`009_oo
o`03o`2Ioooooooo03koool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`009_ooo`03o`2I
oooooooo03Soool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Voooo00?o
09Woooooool0>Oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`009_ooo`03o`2Ioooooooo03Koool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Ooo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000Coool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00Iooo
o`Tco`08oooo00<0003oooooool01@0001;oool010000?ooooooo`0000Woool200001?ooo`030000
oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?oo
ooooo`0Goooo0P0000[oool200000oooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Iooo
o`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.07216 .12361 L
.08255 .12361 L
.08562 .12361 L
.08852 .12361 L
.09113 .12361 L
.09184 .12361 L
.0926 .12361 L
.09325 .12361 L
s
.09325 .12361 m
.09353 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003ooooo09T01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0?oooo00?o
09Woooooool04oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool002Soool00ol0VOooooooo`0l
oooo00<0000co`0co`00Ac?o00D0001Zoooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol0
048co`050000Koooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000m<ol01@0007Coool0
02Soool00ol0VOooooooo`0loooo00<0000co`0co`00>C?o00@0001ioooo000Xoooo00?o09Wooooo
ool0??ooo`80000h<ol00P0007goool002Soool00ol0VOooooooo`0loooo00<0000co`0co`00=C?o
0080001ooooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol003<co`020000POooo`00:?oo
o`03o`2Ioooooooo03coool00`0003?o03?o000a<ol00P0008?oool002Soool00ol0VOooooooo`0l
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool002Soool00ol0VOooooooo`0loooo00<0
000co`0co`00;S?o00800026oooo000Xoooo00?o09Woooooool0??ooo`80000]<ol00P0008Soool0
02Soool00ol0VOooooooo`0loooo00<0000co`0co`00:c?o00030000oooooooo08Soool002Soool0
0ol0VOooooooo`0loooo00<0000co`0co`00:S?o00030000oooooooo08Woool002Soool00ol0VOoo
ooooo`0loooo00<0000co`0co`00:C?o00030000oooooooo08[oool002Soool00ol0VOooooooo`0l
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool002Soool00ol0VOooooooo`0loooo00<0
000co`0co`00:3?o00030000oooooooo08_oool002Soool00ol0VOooooooo`0loooo0P0002Pco`00
0`000?ooooooo`2<oooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000X
oooo00?o09Woooooool0??ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000Xoooo00?o
09Woooooool0??ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000Xoooo00?o09Wooooo
ool0??ooo`80000S<ol000<0003oooooool0TOooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00:?ooo`03o`2Ioooooooo03Coool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000Xoooo00?o09Woooooool0=_ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00:?ooo`03o`2Ioooooooo03Koool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000Xoooo00?o09Woooooool0=_ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00:?ooo`03o`2Ioooooooo03Koool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool002Soool00ol0VOooooooo`0e
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00:?ooo`03o`2Ioooooooo
03coool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00:?ooo`03o`2Ioooooooo03coool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00:?ooo`03o`2Ioooooooo03coool2000073?o
00030000oooooooo09Soool002Soool00ol0VOooooooo`0loooo00<0000co`0co`006S?o00030000
oooooooo09Woool002Soool00ol0VOooooooo`0loooo00<0000co`0co`006S?o00030000oooooooo
09Woool002Soool00ol0VOooooooo`0loooo00<0000co`0co`006C?o00030000oooooooo09[oool0
02Soool00ol0VOooooooo`0loooo00<0000co`0co`006C?o00030000oooooooo09[oool002Soool0
0ol0VOooooooo`0loooo00<0000co`0co`0063?o00030000oooooooo09_oool002Soool00ol0VOoo
ooooo`0loooo0P0001Tco`000`000?ooooooo`2Koooo000Xoooo00?o09Woooooool0??ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000X
oooo00?o09Woooooool0??ooo`80000F<ol000<0003oooooool0W_ooo`00:?ooo`03o`2Ioooooooo
03coool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00:?ooo`03o`2Ioooooooo03coool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00:?ooo`03o`2Ioooooooo03coool200005C?o00030000oooooooo09ooool0
02Soool00ol0VOooooooo`0loooo00<0000co`0co`004c?o00030000oooooooo0:3oool002Soool0
0ol0VOooooooo`0loooo00<0000co`0co`004c?o00030000oooooooo0:3oool002Soool00ol0VOoo
ooooo`0loooo00<0000co`0co`004c?o00030000oooooooo0:3oool002Soool00ol0VOooooooo`0d
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00:?ooo`03o`2Ioooooooo
03Coool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool002Soool0
0ol0VOooooooo`0eoooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00:?oo
o`03o`2Ioooooooo03Koool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool002Soool00ol0VOooooooo`0doooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool002Soool00ol0VOooooooo`0eoooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00:?ooo`03o`2Ioooooooo03coool200004C?o00030000oooooooo0:?oool002Soool0
0ol0VOooooooo`0loooo00<0000co`0co`0043?o00030000oooooooo0:?oool002Soool00ol0VOoo
ooooo`0loooo00<0000co`0co`0043?o00030000oooooooo0:?oool002Soool00ol0VOooooooo`0l
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool002Soool00ol0VOooooooo`0loooo00<0
000co`0co`003c?o00030000oooooooo0:Coool002Soool00ol0VOooooooo`0loooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool002Soool00ol0VOooooooo`0loooo00<0000co`0co`003c?o
00030000oooooooo0:Coool002Soool00ol0VOooooooo`0loooo0P00010co`000`000?ooooooo`2T
oooo000Xoooo00?o09Woooooool0??ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000X
oooo00?o09Woooooool0??ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Xoooo00?o
09Woooooool0??ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Xoooo00?o09Wooooo
ool0??ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000Xoooo00?o09Woooooool0??oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000Xoooo00?o09Woooooool0??ooo`80000>
<ol000<0003oooooool0Y_ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00:?oo
o`03o`2Ioooooooo03coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00:?ooo`03o`2I
oooooooo03coool200003C?o00030000oooooooo0:Ooool002Soool00ol0VOooooooo`0loooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool002Soool00ol0VOooooooo`0loooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool002Soool00ol0VOooooooo`0loooo00<0000co`0co`002c?o
00030000oooooooo0:Soool002Soool00ol0VOooooooo`0eoooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00:?ooo`03o`2Ioooooooo03Coool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00:?ooo`03o`2Ioooooooo03Koool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000Xoooo00?o09Woooooool0=oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00:?ooo`03o`2Ioooooooo
03Coool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00:?oo
o`03o`2Ioooooooo03Goool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000X
oooo00?o09Woooooool0??ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Xoooo00?o
09Woooooool0??ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Xoooo00?o09Wooooo
ool0??ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000Xoooo00?o09Woooooool0??oo
o`80000;<ol000<0003oooooool0ZOooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00:?oo
o`03o`2Ioooooooo03coool200002S?o00030000oooooooo0:[oool002Soool00ol0VOooooooo`0l
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool002Soool00ol0VOooooooo`0loooo00<0
000co`0co`002C?o00030000oooooooo0:[oool002Soool00ol0VOooooooo`0loooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool002Soool00ol0VOooooooo`0loooo00<0000co`0co`0023?o
00030000oooooooo0:_oool002Soool00ol0VOooooooo`0loooo00<0000co`0co`0023?o00030000
oooooooo0:_oool002Soool00ol0VOooooooo`0loooo0P0000Tco`000`000?ooooooo`2[oooo000X
oooo00?o09Woooooool0??ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000Xoooo00?o
09Woooooool0??ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000Xoooo00?o09Wooooo
ool0??ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Xoooo00?o09Woooooool0??oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Xoooo00?o09Woooooool0??ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000Xoooo00?o09Woooooool0??ooo`800008<ol000<0
003oooooool0[?ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00:?ooo`03o`2Ioooooooo03coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00:?oo
o`03o`2Ioooooooo03coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00:?ooo`03o`2I
oooooooo03Koool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Xoooo00?o
09Woooooool0=oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00:?ooo`03o`2Ioooooooo03Coool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005oooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00Ioooo`Tco`04oooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000
oooooooo00D0000Boooo00@0003oooooool0000;oooo00@0003oooooooooool200001?ooo`030000
oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001W
oooo2C?o00Koool00`000?ooooooo`0Goooo0P0000Woool400000oooo`800003oooo00<0003ooooo
ool0M_ooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.08255 .12361 L
.08806 .12361 L
.09396 .12361 L
.09682 .12361 L
.09822 .12361 L
.09952 .12361 L
s
.09952 .12361 m
.09999 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00@0003ooooooooo09T4oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo013oool0
0ol0VOooooooo`0Boooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00:Oooo`03o`2Ioooooooo
03_oool00`0003?o03?o0017<ol01@0006[oool002Woool00ol0VOooooooo`0koooo00<0000co`0c
o`00@S?o00D0001_oooo000Yoooo00?o09Woooooool0>oooo`030000<ol0<ol003dco`050000M?oo
o`00:Oooo`03o`2Ioooooooo03_oool00`0003?o03?o000i<ol0100007Woool002Woool00ol0VOoo
ooooo`0koooo0P0003Pco`020000OOooo`00:Oooo`03o`2Ioooooooo03_oool00`0003?o03?o000e
<ol00P0007ooool002Woool00ol0VOooooooo`0koooo00<0000co`0co`00<c?o00800021oooo000Y
oooo00?o09Woooooool0>oooo`030000<ol0<ol0034co`020000Poooo`00:Oooo`03o`2Ioooooooo
03_oool00`0003?o03?o000`<ol000<0003oooooool0Poooo`00:Oooo`03o`2Ioooooooo03_oool0
0`0003?o03?o000^<ol00P0008Koool002Woool00ol0VOooooooo`0koooo0P0002dco`020000R?oo
o`00:Oooo`03o`2Ioooooooo03_oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00:Ooo
o`03o`2Ioooooooo03_oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`00:Oooo`03o`2I
oooooooo03_oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`00:Oooo`03o`2Ioooooooo
03_oool00`0003?o03?o000X<ol000<0003oooooool0Roooo`00:Oooo`03o`2Ioooooooo03_oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`00:Oooo`03o`2Ioooooooo03_oool20000:3?o
00030000oooooooo08coool002Woool00ol0VOooooooo`0koooo00<0000co`0co`009S?o00030000
oooooooo08goool002Woool00ol0VOooooooo`0koooo00<0000co`0co`009C?o00030000oooooooo
08koool002Woool00ol0VOooooooo`0koooo00<0000co`0co`0093?o00030000oooooooo08ooool0
02Woool00ol0VOooooooo`0koooo00<0000co`0co`008c?o00030000oooooooo093oool002Woool0
0ol0VOooooooo`0koooo00<0000co`0co`008c?o00030000oooooooo093oool002Woool00ol0VOoo
ooooo`0koooo0P0002<co`000`000?ooooooo`2Aoooo000Yoooo00?o09Woooooool0>oooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo000Yoooo00?o09Woooooool0>oooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo000Yoooo00?o09Woooooool0>oooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo000Yoooo00?o09Woooooool0>oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000Yoooo00?o09Woooooool0<oooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo09Coool002Woool00ol0VOooooooo`0eoooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Eoooo000Yoooo00?o09Woooooool0=Oooo`030000oooooooo00?oool2
00007c?o00030000oooooooo09Goool002Woool00ol0VOooooooo`0eoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`2Foooo000Yoooo00?o09Woooooool0=Oooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00:Oooo`03o`2Ioooooooo
03Coool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000Yoooo00?o09Wooooo
ool0>oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000Yoooo00?o09Woooooool0>ooo
o`030000<ol0<ol001/co`000`000?ooooooo`2Hoooo000Yoooo00?o09Woooooool0>oooo`80000L
<ol000<0003oooooool0V?ooo`00:Oooo`03o`2Ioooooooo03_oool00`0003?o03?o000J<ol000<0
003oooooool0VOooo`00:Oooo`03o`2Ioooooooo03_oool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`00:Oooo`03o`2Ioooooooo03_oool00`0003?o03?o000I<ol000<0003oooooool0V_oo
o`00:Oooo`03o`2Ioooooooo03_oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00:Ooo
o`03o`2Ioooooooo03_oool00`0003?o03?o000H<ol000<0003oooooool0Voooo`00:Oooo`03o`2I
oooooooo03_oool200006C?o00030000oooooooo09_oool002Woool00ol0VOooooooo`0koooo00<0
000co`0co`005c?o00030000oooooooo09coool002Woool00ol0VOooooooo`0koooo00<0000co`0c
o`005c?o00030000oooooooo09coool002Woool00ol0VOooooooo`0koooo00<0000co`0co`005S?o
00030000oooooooo09goool002Woool00ol0VOooooooo`0koooo00<0000co`0co`005S?o00030000
oooooooo09goool002Woool00ol0VOooooooo`0koooo00<0000co`0co`005S?o00030000oooooooo
09goool002Woool00ol0VOooooooo`0koooo00<0000co`0co`005C?o00030000oooooooo09koool0
02Woool00ol0VOooooooo`0koooo0P0001Hco`000`000?ooooooo`2Noooo000Yoooo00?o09Wooooo
ool0>oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000Yoooo00?o09Woooooool0>ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000Yoooo00?o09Woooooool0>oooo`030000
<ol0<ol001@co`000`000?ooooooo`2Ooooo000Yoooo00?o09Woooooool0>oooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo000Yoooo00?o09Woooooool0>oooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo000Yoooo00?o09Woooooool0>oooo`80000E<ol000<0003oooooool0Wooo
o`00:Oooo`03o`2Ioooooooo03_oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00:Ooo
o`03o`2Ioooooooo03_oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00:Oooo`03o`2I
oooooooo03_oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00:Oooo`03o`2Ioooooooo
03?oool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo000Yoooo00?o09Wooooo
ool0<oooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00:Ooo
o`03o`2Ioooooooo03Coool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo000Z
oooo00?o09Woooooool0=?ooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0XOooo`00:_ooo`03o`2Ioooooooo03;oool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00:_ooo`03o`2Ioooooooo03?oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo000Zoooo00?o09Woooooool0>_ooo`80000A<ol000<0003oooooool0Xoooo`00:_oo
o`03o`2Ioooooooo03[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00:_ooo`03o`2I
oooooooo03[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00:_ooo`03o`2Ioooooooo
03[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00:_ooo`03o`2Ioooooooo03[oool0
0`0003?o03?o000?<ol000<0003oooooool0Y?ooo`00:_ooo`03o`2Ioooooooo03[oool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`00:_ooo`03o`2Ioooooooo03[oool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`00:_ooo`03o`2Ioooooooo03[oool2000043?o00030000oooooooo
0:Coool002[oool00ol0VOooooooo`0joooo00<0000co`0co`003S?o00030000oooooooo0:Goool0
02[oool00ol0VOooooooo`0joooo00<0000co`0co`003S?o00030000oooooooo0:Goool002[oool0
0ol0VOooooooo`0joooo00<0000co`0co`003S?o00030000oooooooo0:Goool002[oool00ol0VOoo
ooooo`0joooo00<0000co`0co`003S?o00030000oooooooo0:Goool002[oool00ol0VOooooooo`0j
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool002[oool00ol0VOooooooo`0joooo0P00
00hco`000`000?ooooooo`2Voooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000dco`00
0`000?ooooooo`2Voooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000`co`000`000?ooooooo`2W
oooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000Z
oooo00?o09Woooooool0>_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000Zoooo00?o
09Woooooool0>_ooo`80000=<ol000<0003oooooool0Yoooo`00:_ooo`03o`2Ioooooooo03[oool0
0`0003?o03?o000<<ol000<0003oooooool0Yoooo`00:_ooo`03o`2Ioooooooo03[oool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`00:_ooo`03o`2Ioooooooo03[oool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00:_ooo`03o`2Ioooooooo03?oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo000Zoooo00?o09Woooooool0<_ooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000Zoooo00?o09Woooooool0=?ooo`030000
oooooooo00?oool2000033?o00030000oooooooo0:Soool002[oool00ol0VOooooooo`0eoooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000Zoooo00?o09Wooooo
ool0<_ooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000Z
oooo00?o09Woooooool0<oooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
02[oool00ol0VOooooooo`0joooo00<0000co`0co`002S?o00030000oooooooo0:Woool002[oool0
0ol0VOooooooo`0joooo00<0000co`0co`002S?o00030000oooooooo0:Woool002[oool00ol0VOoo
ooooo`0joooo00<0000co`0co`002S?o00030000oooooooo0:Woool002[oool00ol0VOooooooo`0j
oooo0P0000/co`000`000?ooooooo`2Yoooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000Z
oooo00?o09Woooooool0>_ooo`80000:<ol000<0003oooooool0Z_ooo`00:_ooo`03o`2Ioooooooo
03[oool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00:_ooo`03o`2Ioooooooo03[oool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00:_ooo`03o`2Ioooooooo03[oool00`0003?o
03?o0008<ol000<0003oooooool0Zoooo`00:_ooo`03o`2Ioooooooo03[oool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`00:_ooo`03o`2Ioooooooo03[oool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`00:_ooo`03o`2Ioooooooo03[oool200002C?o00030000oooooooo0:_oool0
02[oool00ol0VOooooooo`0joooo00<0000co`0co`0023?o00030000oooooooo0:_oool002[oool0
0ol0VOooooooo`0joooo00<0000co`0co`0023?o00030000oooooooo0:_oool002[oool00ol0VOoo
ooooo`0joooo00<0000co`0co`001c?o00030000oooooooo0:coool002[oool00ol0VOooooooo`0j
oooo00<0000co`0co`001c?o00030000oooooooo0:coool002[oool00ol0VOooooooo`0joooo00<0
000co`0co`001c?o00030000oooooooo0:coool002[oool00ol0VOooooooo`0joooo0P0000Pco`00
0`000?ooooooo`2/oooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`2/oooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000Zoooo00?o09Woooooool0>_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Z
oooo00?o09Woooooool0>_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000Zoooo00?o
09Woooooool0=?ooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool002[oool0
0ol0VOooooooo`0eoooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000Zoooo00?o09Woooooool0<_ooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Goool010000?oooooooooo
o`<00004oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00Ioooo`Tco`04oooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000
oooooooo00D0000Boooo00@0003oooooool0000;oooo00<0003oooooool00`0000Coool00`000?oo
ooooo`1eoooo001Woooo2C?o00Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Goool006Ooool9
<ol01_ooo`030000oooooooo01Ooool200002Oooo`@00003oooo0`0000;oool00`000?ooooooo`1f
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.09905 .12361 L
.10192 .12361 L
.10319 .12361 L
.10458 .12361 L
.10587 .12361 L
s
.10587 .12361 m
.10635 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool00_ooo`04o`2Ioooooooo00001oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo01;oool0
0ol0VOooooooo`0@oooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00:oooo`03o`2Ioooooooo
03Woool00`0003?o03?o0017<ol01@0006[oool002_oool00ol0VOooooooo`0ioooo00<0000co`0c
o`00@S?o00D0001_oooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol003dco`050000M?oo
o`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o000i<ol0100007Woool002_oool00ol0VOoo
ooooo`0ioooo0P0003Pco`020000OOooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o000e
<ol00P0007ooool002_oool00ol0VOooooooo`0ioooo00<0000co`0co`00<c?o00800021oooo000[
oooo00?o09Woooooool0>Oooo`030000<ol0<ol0034co`020000Poooo`00:oooo`03o`2Ioooooooo
03Woool00`0003?o03?o000`<ol000<0003oooooool0Poooo`00:oooo`03o`2Ioooooooo03Woool0
0`0003?o03?o000^<ol00P0008Koool002_oool00ol0VOooooooo`0ioooo0P0002dco`020000R?oo
o`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00:ooo
o`03o`2Ioooooooo03Woool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`00:oooo`03o`2I
oooooooo03Woool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`00:oooo`03o`2Ioooooooo
03Woool00`0003?o03?o000X<ol000<0003oooooool0Roooo`00:oooo`03o`2Ioooooooo03Woool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`00:oooo`03o`2Ioooooooo03Woool20000:3?o
00030000oooooooo08coool002_oool00ol0VOooooooo`0ioooo00<0000co`0co`009S?o00030000
oooooooo08goool002_oool00ol0VOooooooo`0ioooo00<0000co`0co`009C?o00030000oooooooo
08koool002_oool00ol0VOooooooo`0ioooo00<0000co`0co`0093?o00030000oooooooo08ooool0
02_oool00ol0VOooooooo`0ioooo00<0000co`0co`008c?o00030000oooooooo093oool002_oool0
0ol0VOooooooo`0ioooo00<0000co`0co`008c?o00030000oooooooo093oool002_oool00ol0VOoo
ooooo`0ioooo0P0002<co`000`000?ooooooo`2Aoooo000[oooo00?o09Woooooool0>Oooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000[oooo00?o09Woooooool0<Oooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo09Coool002_oool00ol0VOooooooo`0coooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Eoooo000[oooo00?o09Woooooool0<oooo`030000oooooooo00?oool2
00007c?o00030000oooooooo09Goool002_oool00ol0VOooooooo`0coooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`2Foooo000[oooo00?o09Woooooool0<oooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00:oooo`03o`2Ioooooooo
03;oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000[oooo00?o09Wooooo
ool0>Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000[oooo00?o09Woooooool0>Ooo
o`030000<ol0<ol001/co`000`000?ooooooo`2Hoooo000[oooo00?o09Woooooool0>Oooo`80000L
<ol000<0003oooooool0V?ooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o000J<ol000<0
003oooooool0VOooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o000I<ol000<0003oooooool0V_oo
o`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00:ooo
o`03o`2Ioooooooo03Woool00`0003?o03?o000H<ol000<0003oooooool0Voooo`00:oooo`03o`2I
oooooooo03Woool200006C?o00030000oooooooo09_oool002_oool00ol0VOooooooo`0ioooo00<0
000co`0co`005c?o00030000oooooooo09coool002_oool00ol0VOooooooo`0ioooo00<0000co`0c
o`005c?o00030000oooooooo09coool002_oool00ol0VOooooooo`0ioooo00<0000co`0co`005S?o
00030000oooooooo09goool002_oool00ol0VOooooooo`0ioooo00<0000co`0co`005S?o00030000
oooooooo09goool002_oool00ol0VOooooooo`0ioooo00<0000co`0co`005S?o00030000oooooooo
09goool002_oool00ol0VOooooooo`0ioooo00<0000co`0co`005C?o00030000oooooooo09koool0
02_oool00ol0VOooooooo`0ioooo0P0001Hco`000`000?ooooooo`2Noooo000[oooo00?o09Wooooo
ool0>Oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000[oooo00?o09Woooooool0>Ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000[oooo00?o09Woooooool0>Oooo`030000
<ol0<ol001@co`000`000?ooooooo`2Ooooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo000[oooo00?o09Woooooool0>Oooo`80000E<ol000<0003oooooool0Wooo
o`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00:ooo
o`03o`2Ioooooooo03Woool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00:oooo`03o`2I
oooooooo03Woool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00:oooo`03o`2Ioooooooo
037oool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo000[oooo00?o09Wooooo
ool0<Oooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00:ooo
o`03o`2Ioooooooo03;oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo000[
oooo00?o09Woooooool0<oooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0XOooo`00:oooo`03o`2Ioooooooo037oool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00:oooo`03o`2Ioooooooo03;oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo000[oooo00?o09Woooooool0>Oooo`80000A<ol000<0003oooooool0Xoooo`00:ooo
o`03o`2Ioooooooo03Woool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00:oooo`03o`2I
oooooooo03Woool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00:oooo`03o`2Ioooooooo
03Woool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00:oooo`03o`2Ioooooooo03Woool0
0`0003?o03?o000?<ol000<0003oooooool0Y?ooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`00:oooo`03o`2Ioooooooo03Woool2000043?o00030000oooooooo
0:Coool002_oool00ol0VOooooooo`0ioooo00<0000co`0co`003S?o00030000oooooooo0:Goool0
02_oool00ol0VOooooooo`0ioooo00<0000co`0co`003S?o00030000oooooooo0:Goool002_oool0
0ol0VOooooooo`0ioooo00<0000co`0co`003S?o00030000oooooooo0:Goool002_oool00ol0VOoo
ooooo`0ioooo00<0000co`0co`003S?o00030000oooooooo0:Goool002_oool00ol0VOooooooo`0i
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool002_oool00ol0VOooooooo`0ioooo0P00
00hco`000`000?ooooooo`2Voooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000dco`00
0`000?ooooooo`2Voooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000`co`000`000?ooooooo`2W
oooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000[
oooo00?o09Woooooool0>Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000[oooo00?o
09Woooooool0>Oooo`80000=<ol000<0003oooooool0Yoooo`00:oooo`03o`2Ioooooooo03Woool0
0`0003?o03?o000<<ol000<0003oooooool0Yoooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00:oooo`03o`2Ioooooooo03;oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo000[oooo00?o09Woooooool0<Oooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000[oooo00?o09Woooooool0<oooo`030000
oooooooo00?oool2000033?o00030000oooooooo0:Soool002_oool00ol0VOooooooo`0doooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000[oooo00?o09Wooooo
ool0<Oooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000[
oooo00?o09Woooooool0<_ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
02_oool00ol0VOooooooo`0ioooo00<0000co`0co`002S?o00030000oooooooo0:Woool002_oool0
0ol0VOooooooo`0ioooo00<0000co`0co`002S?o00030000oooooooo0:Woool002_oool00ol0VOoo
ooooo`0ioooo00<0000co`0co`002S?o00030000oooooooo0:Woool002_oool00ol0VOooooooo`0i
oooo0P0000/co`000`000?ooooooo`2Yoooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000[
oooo00?o09Woooooool0>Oooo`80000:<ol000<0003oooooool0Z_ooo`00:oooo`03o`2Ioooooooo
03Woool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00:oooo`03o`2Ioooooooo03Woool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o
03?o0008<ol000<0003oooooool0Zoooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`00:oooo`03o`2Ioooooooo03Woool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`00:oooo`03o`2Ioooooooo03Woool200002C?o00030000oooooooo0:_oool0
02_oool00ol0VOooooooo`0ioooo00<0000co`0co`0023?o00030000oooooooo0:_oool002_oool0
0ol0VOooooooo`0ioooo00<0000co`0co`0023?o00030000oooooooo0:_oool002_oool00ol0VOoo
ooooo`0ioooo00<0000co`0co`001c?o00030000oooooooo0:coool002_oool00ol0VOooooooo`0i
oooo00<0000co`0co`001c?o00030000oooooooo0:coool002_oool00ol0VOooooooo`0ioooo00<0
000co`0co`001c?o00030000oooooooo0:coool002_oool00ol0VOooooooo`0ioooo0P0000Pco`00
0`000?ooooooo`2/oooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`2/oooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000[oooo00?o09Woooooool0>Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000[
oooo00?o09Woooooool0>Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000[oooo00?o
09Woooooool0<oooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool002_oool0
0ol0VOooooooo`0doooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000[oooo00?o09Woooooool0<Oooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Goool00`000?ooooooo`03
oooo0`0000;oool00`000?ooooooo`1eoooo001Woooo2C?o00Goool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_oo
o`030000oooooooo00Coool01@000?ooooooooooo`00001goooo001Woooo2C?o00Coool00`000?oo
ooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002_ooo`040000oooooooooooo1@00
00?oool00`000?ooooooo`1doooo001Woooo2C?o00Goool00`000?ooooooo`0500004_ooo`040000
oooooooo00002oooo`040000oooooooo00000_ooo`050000oooooooooooo000007Ooool006Ooool9
<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooo`000003oooo00<0003oooooool0MOooo`00Ioooo`Tco`06oooo00<0003ooooo
ool05oooo`800009oooo100000Coool200000_ooo`030000oooooooo07Koool006Ooool9<ol0/?oo
o`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.09905 .12361 L
.10458 .12361 L
.10972 .12361 L
.11113 .12361 L
.1119 .12361 L
.11263 .12361 L
s
.11263 .12361 m
.11314 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01?ooo`03o`2I0000oooo00Koool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Doooo00?o
09Woooooool03_ooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool002goool00ol0VOooooooo`0g
oooo00<0000co`0co`00Ac?o00D0001Zoooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol0
048co`050000Koooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000m<ol01@0007Coool0
02goool00ol0VOooooooo`0goooo00<0000co`0co`00>C?o00@0001ioooo000]oooo00?o09Wooooo
ool0=oooo`80000h<ol00P0007goool002goool00ol0VOooooooo`0goooo00<0000co`0co`00=C?o
0080001ooooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol003<co`020000POooo`00;Ooo
o`03o`2Ioooooooo03Ooool00`0003?o03?o000a<ol00P0008?oool002goool00ol0VOooooooo`0g
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool002goool00ol0VOooooooo`0goooo00<0
000co`0co`00;S?o00800026oooo000]oooo00?o09Woooooool0=oooo`80000]<ol00P0008Soool0
02goool00ol0VOooooooo`0goooo00<0000co`0co`00:c?o00030000oooooooo08Soool002goool0
0ol0VOooooooo`0goooo00<0000co`0co`00:S?o00030000oooooooo08Woool002goool00ol0VOoo
ooooo`0goooo00<0000co`0co`00:C?o00030000oooooooo08[oool002goool00ol0VOooooooo`0g
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool002goool00ol0VOooooooo`0goooo00<0
000co`0co`00:3?o00030000oooooooo08_oool002goool00ol0VOooooooo`0goooo0P0002Pco`00
0`000?ooooooo`2<oooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000]
oooo00?o09Woooooool0=oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000]oooo00?o
09Woooooool0=oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000]oooo00?o09Wooooo
ool0=oooo`80000S<ol000<0003oooooool0TOooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00;Oooo`03o`2Ioooooooo02ooool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000]oooo00?o09Woooooool0<Oooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00;Oooo`03o`2Ioooooooo037oool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000]oooo00?o09Woooooool0<Oooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00;Oooo`03o`2Ioooooooo037oool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool002goool00ol0VOooooooo`0`
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00;Oooo`03o`2Ioooooooo
03Ooool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00;Oooo`03o`2Ioooooooo03Ooool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00;Oooo`03o`2Ioooooooo03Ooool2000073?o
00030000oooooooo09Soool002goool00ol0VOooooooo`0goooo00<0000co`0co`006S?o00030000
oooooooo09Woool002goool00ol0VOooooooo`0goooo00<0000co`0co`006S?o00030000oooooooo
09Woool002goool00ol0VOooooooo`0goooo00<0000co`0co`006C?o00030000oooooooo09[oool0
02goool00ol0VOooooooo`0goooo00<0000co`0co`006C?o00030000oooooooo09[oool002goool0
0ol0VOooooooo`0goooo00<0000co`0co`0063?o00030000oooooooo09_oool002goool00ol0VOoo
ooooo`0goooo0P0001Tco`000`000?ooooooo`2Koooo000]oooo00?o09Woooooool0=oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000]
oooo00?o09Woooooool0=oooo`80000F<ol000<0003oooooool0W_ooo`00;Oooo`03o`2Ioooooooo
03Ooool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00;Oooo`03o`2Ioooooooo03Ooool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00;Oooo`03o`2Ioooooooo03Ooool200005C?o00030000oooooooo09ooool0
02goool00ol0VOooooooo`0goooo00<0000co`0co`004c?o00030000oooooooo0:3oool002goool0
0ol0VOooooooo`0goooo00<0000co`0co`004c?o00030000oooooooo0:3oool002goool00ol0VOoo
ooooo`0goooo00<0000co`0co`004c?o00030000oooooooo0:3oool002goool00ol0VOooooooo`0_
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00;Oooo`03o`2Ioooooooo
02ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool002goool0
0ol0VOooooooo`0`oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00;Ooo
o`03o`2Ioooooooo037oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool002goool00ol0VOooooooo`0_oooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool002goool00ol0VOooooooo`0`oooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00;Oooo`03o`2Ioooooooo03Ooool200004C?o00030000oooooooo0:?oool002goool0
0ol0VOooooooo`0goooo00<0000co`0co`0043?o00030000oooooooo0:?oool002goool00ol0VOoo
ooooo`0goooo00<0000co`0co`0043?o00030000oooooooo0:?oool002goool00ol0VOooooooo`0g
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool002goool00ol0VOooooooo`0goooo00<0
000co`0co`003c?o00030000oooooooo0:Coool002goool00ol0VOooooooo`0goooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool002goool00ol0VOooooooo`0goooo00<0000co`0co`003c?o
00030000oooooooo0:Coool002goool00ol0VOooooooo`0goooo0P00010co`000`000?ooooooo`2T
oooo000]oooo00?o09Woooooool0=oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000]
oooo00?o09Woooooool0=oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000]oooo00?o
09Woooooool0=oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000]oooo00?o09Wooooo
ool0=oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000]oooo00?o09Woooooool0=ooo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000]oooo00?o09Woooooool0=oooo`80000>
<ol000<0003oooooool0Y_ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00;Ooo
o`03o`2Ioooooooo03Ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00;Oooo`03o`2I
oooooooo03Ooool200003C?o00030000oooooooo0:Ooool002goool00ol0VOooooooo`0goooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool002goool00ol0VOooooooo`0goooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool002goool00ol0VOooooooo`0goooo00<0000co`0co`002c?o
00030000oooooooo0:Soool002goool00ol0VOooooooo`0`oooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00;Oooo`03o`2Ioooooooo02ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00;Oooo`03o`2Ioooooooo037oool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000]oooo00?o09Woooooool0<_ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00;Oooo`03o`2Ioooooooo
02ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00;Ooo
o`03o`2Ioooooooo033oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000]
oooo00?o09Woooooool0=oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000]oooo00?o
09Woooooool0=oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000]oooo00?o09Wooooo
ool0=oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000]oooo00?o09Woooooool0=ooo
o`80000;<ol000<0003oooooool0ZOooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00;Ooo
o`03o`2Ioooooooo03Ooool200002S?o00030000oooooooo0:[oool002goool00ol0VOooooooo`0g
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool002goool00ol0VOooooooo`0goooo00<0
000co`0co`002C?o00030000oooooooo0:[oool002goool00ol0VOooooooo`0goooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool002goool00ol0VOooooooo`0goooo00<0000co`0co`0023?o
00030000oooooooo0:_oool002goool00ol0VOooooooo`0goooo00<0000co`0co`0023?o00030000
oooooooo0:_oool002goool00ol0VOooooooo`0goooo0P0000Tco`000`000?ooooooo`2[oooo000]
oooo00?o09Woooooool0=oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000]oooo00?o
09Woooooool0=oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000]oooo00?o09Wooooo
ool0=oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000]oooo00?o09Woooooool0=ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000]oooo00?o09Woooooool0=oooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000]oooo00?o09Woooooool0=oooo`800008<ol000<0
003oooooool0[?ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00;Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00;Ooo
o`03o`2Ioooooooo03Ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00;Oooo`03o`2I
oooooooo037oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000]oooo00?o
09Woooooool0<_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00;Oooo`03o`2Ioooooooo02ooool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005oooo00@0003oooooooooool4
00000oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool0000:oooo00D0
003oooooooooool000001_ooo`030000oooooooo07Goool006Ooool9<ol01?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000
oooooooo00Coool00`000?ooooooo`1doooo001Woooo2C?o00Goool00`000?ooooooo`0500004_oo
o`040000oooooooo00002oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003ooooo
ool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool006Ooool9
<ol01_ooo`030000oooooooo01Ooool200002Oooo`@00003oooo0P0000?oool00`000?ooooooo`1f
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.10458 .12361 L
.11009 .12361 L
.1128 .12361 L
.11531 .12361 L
.11758 .12361 L
.11872 .12361 L
s
.11872 .12361 m
.11923 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Eoooo00?o
09Woooooool03Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool002koool00ol0VOooooooo`0f
oooo00<0000co`0co`00Ac?o00D0001Zoooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol0
048co`050000Koooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000m<ol01@0007Coool0
02koool00ol0VOooooooo`0foooo00<0000co`0co`00>C?o00@0001ioooo000^oooo00?o09Wooooo
ool0=_ooo`80000h<ol00P0007goool002koool00ol0VOooooooo`0foooo00<0000co`0co`00=C?o
0080001ooooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol003<co`020000POooo`00;_oo
o`03o`2Ioooooooo03Koool00`0003?o03?o000a<ol00P0008?oool002koool00ol0VOooooooo`0f
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool002koool00ol0VOooooooo`0foooo00<0
000co`0co`00;S?o00800026oooo000^oooo00?o09Woooooool0=_ooo`80000]<ol00P0008Soool0
02koool00ol0VOooooooo`0foooo00<0000co`0co`00:c?o00030000oooooooo08Soool002koool0
0ol0VOooooooo`0foooo00<0000co`0co`00:S?o00030000oooooooo08Woool002koool00ol0VOoo
ooooo`0foooo00<0000co`0co`00:C?o00030000oooooooo08[oool002koool00ol0VOooooooo`0f
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool002koool00ol0VOooooooo`0foooo00<0
000co`0co`00:3?o00030000oooooooo08_oool002koool00ol0VOooooooo`0foooo0P0002Pco`00
0`000?ooooooo`2<oooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000^
oooo00?o09Woooooool0=_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000^oooo00?o
09Woooooool0=_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000^oooo00?o09Wooooo
ool0=_ooo`80000S<ol000<0003oooooool0TOooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00;_ooo`03o`2Ioooooooo02koool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000^oooo00?o09Woooooool0<?ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00;_ooo`03o`2Ioooooooo033oool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000^oooo00?o09Woooooool0<?ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00;_ooo`03o`2Ioooooooo033oool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool002koool00ol0VOooooooo`0_
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00;_ooo`03o`2Ioooooooo
03Koool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00;_ooo`03o`2Ioooooooo03Koool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00;_ooo`03o`2Ioooooooo03Koool2000073?o
00030000oooooooo09Soool002koool00ol0VOooooooo`0foooo00<0000co`0co`006S?o00030000
oooooooo09Woool002koool00ol0VOooooooo`0foooo00<0000co`0co`006S?o00030000oooooooo
09Woool002koool00ol0VOooooooo`0foooo00<0000co`0co`006C?o00030000oooooooo09[oool0
02koool00ol0VOooooooo`0foooo00<0000co`0co`006C?o00030000oooooooo09[oool002koool0
0ol0VOooooooo`0foooo00<0000co`0co`0063?o00030000oooooooo09_oool002koool00ol0VOoo
ooooo`0foooo0P0001Tco`000`000?ooooooo`2Koooo000^oooo00?o09Woooooool0=_ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000^
oooo00?o09Woooooool0=_ooo`80000F<ol000<0003oooooool0W_ooo`00;_ooo`03o`2Ioooooooo
03Koool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00;_ooo`03o`2Ioooooooo03Koool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00;_ooo`03o`2Ioooooooo03Koool200005C?o00030000oooooooo09ooool0
02koool00ol0VOooooooo`0foooo00<0000co`0co`004c?o00030000oooooooo0:3oool002koool0
0ol0VOooooooo`0foooo00<0000co`0co`004c?o00030000oooooooo0:3oool002koool00ol0VOoo
ooooo`0foooo00<0000co`0co`004c?o00030000oooooooo0:3oool002koool00ol0VOooooooo`0^
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00;_ooo`03o`2Ioooooooo
02koool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool002koool0
0ol0VOooooooo`0_oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00;_oo
o`03o`2Ioooooooo033oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool002koool00ol0VOooooooo`0^oooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool002koool00ol0VOooooooo`0_oooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00;_ooo`03o`2Ioooooooo03Koool200004C?o00030000oooooooo0:?oool002koool0
0ol0VOooooooo`0foooo00<0000co`0co`0043?o00030000oooooooo0:?oool002koool00ol0VOoo
ooooo`0foooo00<0000co`0co`0043?o00030000oooooooo0:?oool002koool00ol0VOooooooo`0f
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool002koool00ol0VOooooooo`0foooo00<0
000co`0co`003c?o00030000oooooooo0:Coool002koool00ol0VOooooooo`0foooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool002koool00ol0VOooooooo`0foooo00<0000co`0co`003c?o
00030000oooooooo0:Coool002koool00ol0VOooooooo`0foooo0P00010co`000`000?ooooooo`2T
oooo000^oooo00?o09Woooooool0=_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000^
oooo00?o09Woooooool0=_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000^oooo00?o
09Woooooool0=_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000^oooo00?o09Wooooo
ool0=_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000^oooo00?o09Woooooool0=_oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000^oooo00?o09Woooooool0=_ooo`80000>
<ol000<0003oooooool0Y_ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00;_oo
o`03o`2Ioooooooo03Koool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00;_ooo`03o`2I
oooooooo03Koool200003C?o00030000oooooooo0:Ooool002koool00ol0VOooooooo`0foooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool002koool00ol0VOooooooo`0foooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool002koool00ol0VOooooooo`0foooo00<0000co`0co`002c?o
00030000oooooooo0:Soool002koool00ol0VOooooooo`0_oooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00;_ooo`03o`2Ioooooooo02koool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00;_ooo`03o`2Ioooooooo033oool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000^oooo00?o09Woooooool0<Oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00;_ooo`03o`2Ioooooooo
02koool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00;_oo
o`03o`2Ioooooooo02ooool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000^
oooo00?o09Woooooool0=_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000^oooo00?o
09Woooooool0=_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000^oooo00?o09Wooooo
ool0=_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000^oooo00?o09Woooooool0=_oo
o`80000;<ol000<0003oooooool0ZOooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00;_oo
o`03o`2Ioooooooo03Koool200002S?o00030000oooooooo0:[oool002koool00ol0VOooooooo`0f
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool002koool00ol0VOooooooo`0foooo00<0
000co`0co`002C?o00030000oooooooo0:[oool002koool00ol0VOooooooo`0foooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool002koool00ol0VOooooooo`0foooo00<0000co`0co`0023?o
00030000oooooooo0:_oool002koool00ol0VOooooooo`0foooo00<0000co`0co`0023?o00030000
oooooooo0:_oool002koool00ol0VOooooooo`0foooo0P0000Tco`000`000?ooooooo`2[oooo000^
oooo00?o09Woooooool0=_ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000^oooo00?o
09Woooooool0=_ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000^oooo00?o09Wooooo
ool0=_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000^oooo00?o09Woooooool0=_oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000^oooo00?o09Woooooool0=_ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000^oooo00?o09Woooooool0=_ooo`800008<ol000<0
003oooooool0[?ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00;_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00;_oo
o`03o`2Ioooooooo03Koool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00;_ooo`03o`2I
oooooooo033oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000^oooo00?o
09Woooooool0<Oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00;_ooo`03o`2Ioooooooo02koool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Ooo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005oooo00<0003oooooool00_oo
o`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool0000:oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?oo
ooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo07Ooool0
06Ooool9<ol02?ooo`030000oooooooo00D0000Boooo00@0003oooooool0000;oooo00D0003ooooo
ooooool00000N_ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000005Oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000
oooooooo01Ooool200002Oooo`@00002oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001W
oooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.10458 .12361 L
.11448 .12361 L
.11992 .12361 L
.1226 .12361 L
.12377 .12361 L
.12507 .12361 L
s
.12507 .12361 m
.12555 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000ooooo`2I00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Goooo00?o
09Woooooool02oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool0033oool00ol0VOooooooo`0d
oooo00<0000co`0co`00Ac?o00D0001Zoooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol0
048co`050000Koooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000m<ol01@0007Coool0
033oool00ol0VOooooooo`0doooo00<0000co`0co`00>C?o00@0001ioooo000`oooo00?o09Wooooo
ool0=?ooo`80000h<ol00P0007goool0033oool00ol0VOooooooo`0doooo00<0000co`0co`00=C?o
0080001ooooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol003<co`020000POooo`00<?oo
o`03o`2Ioooooooo03Coool00`0003?o03?o000a<ol00P0008?oool0033oool00ol0VOooooooo`0d
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool0033oool00ol0VOooooooo`0doooo00<0
000co`0co`00;S?o00800026oooo000`oooo00?o09Woooooool0=?ooo`80000]<ol00P0008Soool0
033oool00ol0VOooooooo`0doooo00<0000co`0co`00:c?o00030000oooooooo08Soool0033oool0
0ol0VOooooooo`0doooo00<0000co`0co`00:S?o00030000oooooooo08Woool0033oool00ol0VOoo
ooooo`0doooo00<0000co`0co`00:C?o00030000oooooooo08[oool0033oool00ol0VOooooooo`0d
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool0033oool00ol0VOooooooo`0doooo00<0
000co`0co`00:3?o00030000oooooooo08_oool0033oool00ol0VOooooooo`0doooo0P0002Pco`00
0`000?ooooooo`2<oooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000`
oooo00?o09Woooooool0=?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000`oooo00?o
09Woooooool0=?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000`oooo00?o09Wooooo
ool0=?ooo`80000S<ol000<0003oooooool0TOooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00<?ooo`03o`2Ioooooooo02coool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000`oooo00?o09Woooooool0;_ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00<?ooo`03o`2Ioooooooo02koool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000`oooo00?o09Woooooool0;_ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00<?ooo`03o`2Ioooooooo02koool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool0033oool00ol0VOooooooo`0]
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00<?ooo`03o`2Ioooooooo
03Coool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00<?ooo`03o`2Ioooooooo03Coool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00<?ooo`03o`2Ioooooooo03Coool2000073?o
00030000oooooooo09Soool0033oool00ol0VOooooooo`0doooo00<0000co`0co`006S?o00030000
oooooooo09Woool0033oool00ol0VOooooooo`0doooo00<0000co`0co`006S?o00030000oooooooo
09Woool0033oool00ol0VOooooooo`0doooo00<0000co`0co`006C?o00030000oooooooo09[oool0
033oool00ol0VOooooooo`0doooo00<0000co`0co`006C?o00030000oooooooo09[oool0033oool0
0ol0VOooooooo`0doooo00<0000co`0co`0063?o00030000oooooooo09_oool0033oool00ol0VOoo
ooooo`0doooo0P0001Tco`000`000?ooooooo`2Koooo000`oooo00?o09Woooooool0=?ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000`
oooo00?o09Woooooool0=?ooo`80000F<ol000<0003oooooool0W_ooo`00<?ooo`03o`2Ioooooooo
03Coool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00<?ooo`03o`2Ioooooooo03Coool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00<?ooo`03o`2Ioooooooo03Coool200005C?o00030000oooooooo09ooool0
033oool00ol0VOooooooo`0doooo00<0000co`0co`004c?o00030000oooooooo0:3oool0033oool0
0ol0VOooooooo`0doooo00<0000co`0co`004c?o00030000oooooooo0:3oool0033oool00ol0VOoo
ooooo`0doooo00<0000co`0co`004c?o00030000oooooooo0:3oool0033oool00ol0VOooooooo`0/
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00<?ooo`03o`2Ioooooooo
02coool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool0033oool0
0ol0VOooooooo`0]oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00<?oo
o`03o`2Ioooooooo02koool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool0033oool00ol0VOooooooo`0/oooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool0033oool00ol0VOooooooo`0]oooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00<?ooo`03o`2Ioooooooo03Coool200004C?o00030000oooooooo0:?oool0033oool0
0ol0VOooooooo`0doooo00<0000co`0co`0043?o00030000oooooooo0:?oool0033oool00ol0VOoo
ooooo`0doooo00<0000co`0co`0043?o00030000oooooooo0:?oool0033oool00ol0VOooooooo`0d
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool0033oool00ol0VOooooooo`0doooo00<0
000co`0co`003c?o00030000oooooooo0:Coool0033oool00ol0VOooooooo`0doooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool0033oool00ol0VOooooooo`0doooo00<0000co`0co`003c?o
00030000oooooooo0:Coool0033oool00ol0VOooooooo`0doooo0P00010co`000`000?ooooooo`2T
oooo000`oooo00?o09Woooooool0=?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000`
oooo00?o09Woooooool0=?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000`oooo00?o
09Woooooool0=?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000`oooo00?o09Wooooo
ool0=?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000`oooo00?o09Woooooool0=?oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000`oooo00?o09Woooooool0=?ooo`80000>
<ol000<0003oooooool0Y_ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00<?oo
o`03o`2Ioooooooo03Coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00<?ooo`03o`2I
oooooooo03Coool200003C?o00030000oooooooo0:Ooool0033oool00ol0VOooooooo`0doooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool0033oool00ol0VOooooooo`0doooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool0033oool00ol0VOooooooo`0doooo00<0000co`0co`002c?o
00030000oooooooo0:Soool0033oool00ol0VOooooooo`0]oooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00<?ooo`03o`2Ioooooooo02coool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00<?ooo`03o`2Ioooooooo02koool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000`oooo00?o09Woooooool0;oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00<?ooo`03o`2Ioooooooo
02coool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00<?oo
o`03o`2Ioooooooo02goool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000`
oooo00?o09Woooooool0=?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000`oooo00?o
09Woooooool0=?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000`oooo00?o09Wooooo
ool0=?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000`oooo00?o09Woooooool0=?oo
o`80000;<ol000<0003oooooool0ZOooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00<?oo
o`03o`2Ioooooooo03Coool200002S?o00030000oooooooo0:[oool0033oool00ol0VOooooooo`0d
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool0033oool00ol0VOooooooo`0doooo00<0
000co`0co`002C?o00030000oooooooo0:[oool0033oool00ol0VOooooooo`0doooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool0033oool00ol0VOooooooo`0doooo00<0000co`0co`0023?o
00030000oooooooo0:_oool0033oool00ol0VOooooooo`0doooo00<0000co`0co`0023?o00030000
oooooooo0:_oool0033oool00ol0VOooooooo`0doooo0P0000Tco`000`000?ooooooo`2[oooo000`
oooo00?o09Woooooool0=?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000`oooo00?o
09Woooooool0=?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000`oooo00?o09Wooooo
ool0=?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000`oooo00?o09Woooooool0=?oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000`oooo00?o09Woooooool0=?ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000`oooo00?o09Woooooool0=?ooo`800008<ol000<0
003oooooool0[?ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00<?ooo`03o`2Ioooooooo03Coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00<?oo
o`03o`2Ioooooooo03Coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00<?ooo`03o`2I
oooooooo02koool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000`oooo00?o
09Woooooool0;oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00<?ooo`03o`2Ioooooooo02coool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo0`0000Coool200001?oo
o`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00Ioooo`Tco`04oooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`00
00;oool010000?ooooooo`0000Coool00`000?ooooooo`1doooo001Woooo2C?o00Goool00`000?oo
ooooo`0500004_ooo`040000oooooooo00002?ooo`<00004oooo0P0000Coool00`000?ooooooo`1e
oooo001Woooo2C?o00Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009oooo00<0
003oooooool00_ooo`040000oooooooo00000oooo`030000oooooooo07Goool006Ooool9<ol01_oo
o`030000oooooooo01Ooool200002_ooo`<00003oooo0P0000?oool00`000?ooooooo`1foooo001W
oooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.10458 .12361 L
.11448 .12361 L
.11992 .12361 L
.12507 .12361 L
.12739 .12361 L
.12986 .12361 L
.13115 .12361 L
s
.13115 .12361 m
.13144 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`040000ooooooooo`2I1?ooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo01Soool0
0ol0VOooooooo`0:oooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00<Oooo`03o`2Ioooooooo
03?oool00`0003?o03?o0017<ol01@0006[oool0037oool00ol0VOooooooo`0coooo00<0000co`0c
o`00@S?o00D0001_oooo000aoooo00?o09Woooooool0<oooo`030000<ol0<ol003dco`050000M?oo
o`00<Oooo`03o`2Ioooooooo03?oool00`0003?o03?o000i<ol0100007Woool0037oool00ol0VOoo
ooooo`0coooo0P0003Pco`020000OOooo`00<Oooo`03o`2Ioooooooo03?oool00`0003?o03?o000e
<ol00P0007ooool0037oool00ol0VOooooooo`0coooo00<0000co`0co`00<c?o00800021oooo000a
oooo00?o09Woooooool0<oooo`030000<ol0<ol0034co`020000Poooo`00<Oooo`03o`2Ioooooooo
03?oool00`0003?o03?o000`<ol000<0003oooooool0Poooo`00<Oooo`03o`2Ioooooooo03?oool0
0`0003?o03?o000^<ol00P0008Koool0037oool00ol0VOooooooo`0coooo0P0002dco`020000R?oo
o`00<Oooo`03o`2Ioooooooo03?oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00<Ooo
o`03o`2Ioooooooo03?oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`00<Oooo`03o`2I
oooooooo03?oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`00<Oooo`03o`2Ioooooooo
03?oool00`0003?o03?o000X<ol000<0003oooooool0Roooo`00<Oooo`03o`2Ioooooooo03?oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`00<Oooo`03o`2Ioooooooo03?oool20000:3?o
00030000oooooooo08coool0037oool00ol0VOooooooo`0coooo00<0000co`0co`009S?o00030000
oooooooo08goool0037oool00ol0VOooooooo`0coooo00<0000co`0co`009C?o00030000oooooooo
08koool0037oool00ol0VOooooooo`0coooo00<0000co`0co`0093?o00030000oooooooo08ooool0
037oool00ol0VOooooooo`0coooo00<0000co`0co`008c?o00030000oooooooo093oool0037oool0
0ol0VOooooooo`0coooo00<0000co`0co`008c?o00030000oooooooo093oool0037oool00ol0VOoo
ooooo`0coooo0P0002<co`000`000?ooooooo`2Aoooo000aoooo00?o09Woooooool0<oooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo000aoooo00?o09Woooooool0<oooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo000aoooo00?o09Woooooool0<oooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo000aoooo00?o09Woooooool0<oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000aoooo00?o09Woooooool0:oooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo09Coool0037oool00ol0VOooooooo`0]oooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Eoooo000aoooo00?o09Woooooool0;Oooo`030000oooooooo00?oool2
00007c?o00030000oooooooo09Goool0037oool00ol0VOooooooo`0]oooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`2Foooo000aoooo00?o09Woooooool0;Oooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00<Oooo`03o`2Ioooooooo
02coool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000aoooo00?o09Wooooo
ool0<oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000aoooo00?o09Woooooool0<ooo
o`030000<ol0<ol001/co`000`000?ooooooo`2Hoooo000aoooo00?o09Woooooool0<oooo`80000L
<ol000<0003oooooool0V?ooo`00<Oooo`03o`2Ioooooooo03?oool00`0003?o03?o000J<ol000<0
003oooooool0VOooo`00<Oooo`03o`2Ioooooooo03?oool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`00<Oooo`03o`2Ioooooooo03?oool00`0003?o03?o000I<ol000<0003oooooool0V_oo
o`00<Oooo`03o`2Ioooooooo03?oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00<Ooo
o`03o`2Ioooooooo03?oool00`0003?o03?o000H<ol000<0003oooooool0Voooo`00<Oooo`03o`2I
oooooooo03?oool200006C?o00030000oooooooo09_oool0037oool00ol0VOooooooo`0coooo00<0
000co`0co`005c?o00030000oooooooo09coool0037oool00ol0VOooooooo`0coooo00<0000co`0c
o`005c?o00030000oooooooo09coool0037oool00ol0VOooooooo`0coooo00<0000co`0co`005S?o
00030000oooooooo09goool0037oool00ol0VOooooooo`0coooo00<0000co`0co`005S?o00030000
oooooooo09goool0037oool00ol0VOooooooo`0coooo00<0000co`0co`005S?o00030000oooooooo
09goool0037oool00ol0VOooooooo`0coooo00<0000co`0co`005C?o00030000oooooooo09koool0
037oool00ol0VOooooooo`0coooo0P0001Hco`000`000?ooooooo`2Noooo000aoooo00?o09Wooooo
ool0<oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000aoooo00?o09Woooooool0<ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000aoooo00?o09Woooooool0<oooo`030000
<ol0<ol001@co`000`000?ooooooo`2Ooooo000aoooo00?o09Woooooool0<oooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo000aoooo00?o09Woooooool0<oooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo000aoooo00?o09Woooooool0<oooo`80000E<ol000<0003oooooool0Wooo
o`00<Oooo`03o`2Ioooooooo03?oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00<Ooo
o`03o`2Ioooooooo03?oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00<Oooo`03o`2I
oooooooo03?oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00<Oooo`03o`2Ioooooooo
02_oool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo000aoooo00?o09Wooooo
ool0:oooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00<Ooo
o`03o`2Ioooooooo02coool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo000b
oooo00?o09Woooooool0;?ooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0XOooo`00<_ooo`03o`2Ioooooooo02[oool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00<_ooo`03o`2Ioooooooo02_oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo000boooo00?o09Woooooool0<_ooo`80000A<ol000<0003oooooool0Xoooo`00<_oo
o`03o`2Ioooooooo03;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00<_ooo`03o`2I
oooooooo03;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00<_ooo`03o`2Ioooooooo
03;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00<_ooo`03o`2Ioooooooo03;oool0
0`0003?o03?o000?<ol000<0003oooooool0Y?ooo`00<_ooo`03o`2Ioooooooo03;oool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`00<_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`00<_ooo`03o`2Ioooooooo03;oool2000043?o00030000oooooooo
0:Coool003;oool00ol0VOooooooo`0boooo00<0000co`0co`003S?o00030000oooooooo0:Goool0
03;oool00ol0VOooooooo`0boooo00<0000co`0co`003S?o00030000oooooooo0:Goool003;oool0
0ol0VOooooooo`0boooo00<0000co`0co`003S?o00030000oooooooo0:Goool003;oool00ol0VOoo
ooooo`0boooo00<0000co`0co`003S?o00030000oooooooo0:Goool003;oool00ol0VOooooooo`0b
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool003;oool00ol0VOooooooo`0boooo0P00
00hco`000`000?ooooooo`2Voooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000dco`00
0`000?ooooooo`2Voooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000`co`000`000?ooooooo`2W
oooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000b
oooo00?o09Woooooool0<_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000boooo00?o
09Woooooool0<_ooo`80000=<ol000<0003oooooool0Yoooo`00<_ooo`03o`2Ioooooooo03;oool0
0`0003?o03?o000<<ol000<0003oooooool0Yoooo`00<_ooo`03o`2Ioooooooo03;oool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`00<_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00<_ooo`03o`2Ioooooooo02_oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo000boooo00?o09Woooooool0:_ooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000boooo00?o09Woooooool0;?ooo`030000
oooooooo00?oool2000033?o00030000oooooooo0:Soool003;oool00ol0VOooooooo`0]oooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000boooo00?o09Wooooo
ool0:_ooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000b
oooo00?o09Woooooool0:oooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
03;oool00ol0VOooooooo`0boooo00<0000co`0co`002S?o00030000oooooooo0:Woool003;oool0
0ol0VOooooooo`0boooo00<0000co`0co`002S?o00030000oooooooo0:Woool003;oool00ol0VOoo
ooooo`0boooo00<0000co`0co`002S?o00030000oooooooo0:Woool003;oool00ol0VOooooooo`0b
oooo0P0000/co`000`000?ooooooo`2Yoooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000b
oooo00?o09Woooooool0<_ooo`80000:<ol000<0003oooooool0Z_ooo`00<_ooo`03o`2Ioooooooo
03;oool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00<_ooo`03o`2Ioooooooo03;oool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00<_ooo`03o`2Ioooooooo03;oool00`0003?o
03?o0008<ol000<0003oooooool0Zoooo`00<_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`00<_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`00<_ooo`03o`2Ioooooooo03;oool200002C?o00030000oooooooo0:_oool0
03;oool00ol0VOooooooo`0boooo00<0000co`0co`0023?o00030000oooooooo0:_oool003;oool0
0ol0VOooooooo`0boooo00<0000co`0co`0023?o00030000oooooooo0:_oool003;oool00ol0VOoo
ooooo`0boooo00<0000co`0co`001c?o00030000oooooooo0:coool003;oool00ol0VOooooooo`0b
oooo00<0000co`0co`001c?o00030000oooooooo0:coool003;oool00ol0VOooooooo`0boooo00<0
000co`0co`001c?o00030000oooooooo0:coool003;oool00ol0VOooooooo`0boooo0P0000Pco`00
0`000?ooooooo`2/oooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`2/oooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000boooo00?o09Woooooool0<_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000b
oooo00?o09Woooooool0<_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000boooo00?o
09Woooooool0;?ooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool003;oool0
0ol0VOooooooo`0]oooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000boooo00?o09Woooooool0:_ooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool300000oooo`<00004
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001Woooo2C?o00Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo
00000_ooo`040000oooooooo00001?ooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000
oooooooo00D0000Boooo00@0003oooooool00008oooo0`0000?oool300001?ooo`030000oooooooo
07Goool006Ooool9<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Goool006Ooool9<ol01_oo
o`030000oooooooo01Ooool200002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1foooo001W
oooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.10458 .12361 L
.11448 .12361 L
.12507 .12361 L
.1302 .12361 L
.13273 .12361 L
.13506 .12361 L
.13615 .12361 L
.13718 .12361 L
s
.13718 .12361 m
.1376 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00;oool01?l0VOooooooo`0000Ooool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo01[oool0
0ol0VOooooooo`08oooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00<oooo`03o`2Ioooooooo
037oool00`0003?o03?o0017<ol01@0006[oool003?oool00ol0VOooooooo`0aoooo00<0000co`0c
o`00@S?o00D0001_oooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol003dco`050000M?oo
o`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o000i<ol0100007Woool003?oool00ol0VOoo
ooooo`0aoooo0P0003Pco`020000OOooo`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o000e
<ol00P0007ooool003?oool00ol0VOooooooo`0aoooo00<0000co`0co`00<c?o00800021oooo000c
oooo00?o09Woooooool0<Oooo`030000<ol0<ol0034co`020000Poooo`00<oooo`03o`2Ioooooooo
037oool00`0003?o03?o000`<ol000<0003oooooool0Poooo`00<oooo`03o`2Ioooooooo037oool0
0`0003?o03?o000^<ol00P0008Koool003?oool00ol0VOooooooo`0aoooo0P0002dco`020000R?oo
o`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00<ooo
o`03o`2Ioooooooo037oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`00<oooo`03o`2I
oooooooo037oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`00<oooo`03o`2Ioooooooo
037oool00`0003?o03?o000X<ol000<0003oooooool0Roooo`00<oooo`03o`2Ioooooooo037oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`00<oooo`03o`2Ioooooooo037oool20000:3?o
00030000oooooooo08coool003?oool00ol0VOooooooo`0aoooo00<0000co`0co`009S?o00030000
oooooooo08goool003?oool00ol0VOooooooo`0aoooo00<0000co`0co`009C?o00030000oooooooo
08koool003?oool00ol0VOooooooo`0aoooo00<0000co`0co`0093?o00030000oooooooo08ooool0
03?oool00ol0VOooooooo`0aoooo00<0000co`0co`008c?o00030000oooooooo093oool003?oool0
0ol0VOooooooo`0aoooo00<0000co`0co`008c?o00030000oooooooo093oool003?oool00ol0VOoo
ooooo`0aoooo0P0002<co`000`000?ooooooo`2Aoooo000coooo00?o09Woooooool0<Oooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000coooo00?o09Woooooool0:Oooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo09Coool003?oool00ol0VOooooooo`0[oooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Eoooo000coooo00?o09Woooooool0:oooo`030000oooooooo00?oool2
00007c?o00030000oooooooo09Goool003?oool00ol0VOooooooo`0[oooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`2Foooo000coooo00?o09Woooooool0:oooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00<oooo`03o`2Ioooooooo
02[oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000coooo00?o09Wooooo
ool0<Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000coooo00?o09Woooooool0<Ooo
o`030000<ol0<ol001/co`000`000?ooooooo`2Hoooo000coooo00?o09Woooooool0<Oooo`80000L
<ol000<0003oooooool0V?ooo`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o000J<ol000<0
003oooooool0VOooo`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o000I<ol000<0003oooooool0V_oo
o`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00<ooo
o`03o`2Ioooooooo037oool00`0003?o03?o000H<ol000<0003oooooool0Voooo`00<oooo`03o`2I
oooooooo037oool200006C?o00030000oooooooo09_oool003?oool00ol0VOooooooo`0aoooo00<0
000co`0co`005c?o00030000oooooooo09coool003?oool00ol0VOooooooo`0aoooo00<0000co`0c
o`005c?o00030000oooooooo09coool003?oool00ol0VOooooooo`0aoooo00<0000co`0co`005S?o
00030000oooooooo09goool003?oool00ol0VOooooooo`0aoooo00<0000co`0co`005S?o00030000
oooooooo09goool003?oool00ol0VOooooooo`0aoooo00<0000co`0co`005S?o00030000oooooooo
09goool003?oool00ol0VOooooooo`0aoooo00<0000co`0co`005C?o00030000oooooooo09koool0
03?oool00ol0VOooooooo`0aoooo0P0001Hco`000`000?ooooooo`2Noooo000coooo00?o09Wooooo
ool0<Oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000coooo00?o09Woooooool0<Ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000coooo00?o09Woooooool0<Oooo`030000
<ol0<ol001@co`000`000?ooooooo`2Ooooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo000coooo00?o09Woooooool0<Oooo`80000E<ol000<0003oooooool0Wooo
o`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00<ooo
o`03o`2Ioooooooo037oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00<oooo`03o`2I
oooooooo037oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00<oooo`03o`2Ioooooooo
02Woool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo000coooo00?o09Wooooo
ool0:Oooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00<ooo
o`03o`2Ioooooooo02[oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo000c
oooo00?o09Woooooool0:oooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0XOooo`00<oooo`03o`2Ioooooooo02Woool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00<oooo`03o`2Ioooooooo02[oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo000coooo00?o09Woooooool0<Oooo`80000A<ol000<0003oooooool0Xoooo`00<ooo
o`03o`2Ioooooooo037oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00<oooo`03o`2I
oooooooo037oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00<oooo`03o`2Ioooooooo
037oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00<oooo`03o`2Ioooooooo037oool0
0`0003?o03?o000?<ol000<0003oooooool0Y?ooo`00<oooo`03o`2Ioooooooo037oool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`00<oooo`03o`2Ioooooooo037oool2000043?o00030000oooooooo
0:Coool003?oool00ol0VOooooooo`0aoooo00<0000co`0co`003S?o00030000oooooooo0:Goool0
03?oool00ol0VOooooooo`0aoooo00<0000co`0co`003S?o00030000oooooooo0:Goool003?oool0
0ol0VOooooooo`0aoooo00<0000co`0co`003S?o00030000oooooooo0:Goool003?oool00ol0VOoo
ooooo`0aoooo00<0000co`0co`003S?o00030000oooooooo0:Goool003?oool00ol0VOooooooo`0a
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool003?oool00ol0VOooooooo`0aoooo0P00
00hco`000`000?ooooooo`2Voooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000dco`00
0`000?ooooooo`2Voooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000`co`000`000?ooooooo`2W
oooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000c
oooo00?o09Woooooool0<Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000coooo00?o
09Woooooool0<Oooo`80000=<ol000<0003oooooool0Yoooo`00<oooo`03o`2Ioooooooo037oool0
0`0003?o03?o000<<ol000<0003oooooool0Yoooo`00<oooo`03o`2Ioooooooo037oool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00<oooo`03o`2Ioooooooo02[oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo000coooo00?o09Woooooool0:Oooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000coooo00?o09Woooooool0:oooo`030000
oooooooo00?oool2000033?o00030000oooooooo0:Soool003?oool00ol0VOooooooo`0/oooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000coooo00?o09Wooooo
ool0:Oooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000c
oooo00?o09Woooooool0:_ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
03?oool00ol0VOooooooo`0aoooo00<0000co`0co`002S?o00030000oooooooo0:Woool003?oool0
0ol0VOooooooo`0aoooo00<0000co`0co`002S?o00030000oooooooo0:Woool003?oool00ol0VOoo
ooooo`0aoooo00<0000co`0co`002S?o00030000oooooooo0:Woool003?oool00ol0VOooooooo`0a
oooo0P0000/co`000`000?ooooooo`2Yoooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000c
oooo00?o09Woooooool0<Oooo`80000:<ol000<0003oooooool0Z_ooo`00<oooo`03o`2Ioooooooo
037oool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00<oooo`03o`2Ioooooooo037oool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00<oooo`03o`2Ioooooooo037oool00`0003?o
03?o0008<ol000<0003oooooool0Zoooo`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`00<oooo`03o`2Ioooooooo037oool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`00<oooo`03o`2Ioooooooo037oool200002C?o00030000oooooooo0:_oool0
03?oool00ol0VOooooooo`0aoooo00<0000co`0co`0023?o00030000oooooooo0:_oool003?oool0
0ol0VOooooooo`0aoooo00<0000co`0co`0023?o00030000oooooooo0:_oool003?oool00ol0VOoo
ooooo`0aoooo00<0000co`0co`001c?o00030000oooooooo0:coool003?oool00ol0VOooooooo`0a
oooo00<0000co`0co`001c?o00030000oooooooo0:coool003?oool00ol0VOooooooo`0aoooo00<0
000co`0co`001c?o00030000oooooooo0:coool003?oool00ol0VOooooooo`0aoooo0P0000Pco`00
0`000?ooooooo`2/oooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`2/oooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000coooo00?o09Woooooool0<Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000c
oooo00?o09Woooooool0<Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000coooo00?o
09Woooooool0:oooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool003?oool0
0ol0VOooooooo`0/oooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000coooo00?o09Woooooool0:Oooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool300001Oooo`<00002
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool01@000?ooooooooooo`00001goooo001Woooo2C?o00Coool00`000?ooooooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`D00003
oooo00<0003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000Soool300000oooo`040000oooooooo00000oooo`030000oooooooo07Goool006Ooool9
<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooooooo`03
oooo00<0003oool000000oooo`030000oooooooo07Goool006Ooool9<ol01_ooo`030000oooooooo
01Ooool200002_ooo`<00004oooo0P0000;oool00`000?ooooooo`1foooo001Woooo2C?o0;3oool0
06Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.13506 .12361 L
.13979 .12361 L
.14186 .12361 L
.14305 .12361 L
.14415 .12361 L
s
.14415 .12361 m
.14458 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Coool00ol0V@000?ooo`06oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Loooo00?o
09Woooooool01_ooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool003Goool00ol0VOooooooo`0_
oooo00<0000co`0co`00Ac?o00D0001Zoooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol0
048co`050000Koooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000m<ol01@0007Coool0
03Goool00ol0VOooooooo`0_oooo00<0000co`0co`00>C?o00@0001ioooo000eoooo00?o09Wooooo
ool0;oooo`80000h<ol00P0007goool003Goool00ol0VOooooooo`0_oooo00<0000co`0co`00=C?o
0080001ooooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol003<co`020000POooo`00=Ooo
o`03o`2Ioooooooo02ooool00`0003?o03?o000a<ol00P0008?oool003Goool00ol0VOooooooo`0_
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool003Goool00ol0VOooooooo`0_oooo00<0
000co`0co`00;S?o00800026oooo000eoooo00?o09Woooooool0;oooo`80000]<ol00P0008Soool0
03Goool00ol0VOooooooo`0_oooo00<0000co`0co`00:c?o00030000oooooooo08Soool003Goool0
0ol0VOooooooo`0_oooo00<0000co`0co`00:S?o00030000oooooooo08Woool003Goool00ol0VOoo
ooooo`0_oooo00<0000co`0co`00:C?o00030000oooooooo08[oool003Goool00ol0VOooooooo`0_
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool003Goool00ol0VOooooooo`0_oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool003Goool00ol0VOooooooo`0_oooo0P0002Pco`00
0`000?ooooooo`2<oooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000e
oooo00?o09Woooooool0;oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000eoooo00?o
09Woooooool0;oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000eoooo00?o09Wooooo
ool0;oooo`80000S<ol000<0003oooooool0TOooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00=Oooo`03o`2Ioooooooo02Ooool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000eoooo00?o09Woooooool0:Oooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00=Oooo`03o`2Ioooooooo02Woool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000eoooo00?o09Woooooool0:Oooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00=Oooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool003Goool00ol0VOooooooo`0X
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00=Oooo`03o`2Ioooooooo
02ooool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00=Oooo`03o`2Ioooooooo02ooool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00=Oooo`03o`2Ioooooooo02ooool2000073?o
00030000oooooooo09Soool003Goool00ol0VOooooooo`0_oooo00<0000co`0co`006S?o00030000
oooooooo09Woool003Goool00ol0VOooooooo`0_oooo00<0000co`0co`006S?o00030000oooooooo
09Woool003Goool00ol0VOooooooo`0_oooo00<0000co`0co`006C?o00030000oooooooo09[oool0
03Goool00ol0VOooooooo`0_oooo00<0000co`0co`006C?o00030000oooooooo09[oool003Goool0
0ol0VOooooooo`0_oooo00<0000co`0co`0063?o00030000oooooooo09_oool003Goool00ol0VOoo
ooooo`0_oooo0P0001Tco`000`000?ooooooo`2Koooo000eoooo00?o09Woooooool0;oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000e
oooo00?o09Woooooool0;oooo`80000F<ol000<0003oooooool0W_ooo`00=Oooo`03o`2Ioooooooo
02ooool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00=Oooo`03o`2Ioooooooo02ooool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00=Oooo`03o`2Ioooooooo02ooool200005C?o00030000oooooooo09ooool0
03Goool00ol0VOooooooo`0_oooo00<0000co`0co`004c?o00030000oooooooo0:3oool003Goool0
0ol0VOooooooo`0_oooo00<0000co`0co`004c?o00030000oooooooo0:3oool003Goool00ol0VOoo
ooooo`0_oooo00<0000co`0co`004c?o00030000oooooooo0:3oool003Goool00ol0VOooooooo`0W
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00=Oooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool003Goool0
0ol0VOooooooo`0Xoooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00=Ooo
o`03o`2Ioooooooo02Woool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool003Goool00ol0VOooooooo`0Woooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool003Goool00ol0VOooooooo`0Xoooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00=Oooo`03o`2Ioooooooo02ooool200004C?o00030000oooooooo0:?oool003Goool0
0ol0VOooooooo`0_oooo00<0000co`0co`0043?o00030000oooooooo0:?oool003Goool00ol0VOoo
ooooo`0_oooo00<0000co`0co`0043?o00030000oooooooo0:?oool003Goool00ol0VOooooooo`0_
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool003Goool00ol0VOooooooo`0_oooo00<0
000co`0co`003c?o00030000oooooooo0:Coool003Goool00ol0VOooooooo`0_oooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool003Goool00ol0VOooooooo`0_oooo00<0000co`0co`003c?o
00030000oooooooo0:Coool003Goool00ol0VOooooooo`0_oooo0P00010co`000`000?ooooooo`2T
oooo000eoooo00?o09Woooooool0;oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000e
oooo00?o09Woooooool0;oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000eoooo00?o
09Woooooool0;oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000eoooo00?o09Wooooo
ool0;oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000eoooo00?o09Woooooool0;ooo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000eoooo00?o09Woooooool0;oooo`80000>
<ol000<0003oooooool0Y_ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00=Ooo
o`03o`2Ioooooooo02ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00=Oooo`03o`2I
oooooooo02ooool200003C?o00030000oooooooo0:Ooool003Goool00ol0VOooooooo`0_oooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool003Goool00ol0VOooooooo`0_oooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool003Goool00ol0VOooooooo`0_oooo00<0000co`0co`002c?o
00030000oooooooo0:Soool003Goool00ol0VOooooooo`0Xoooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00=Oooo`03o`2Ioooooooo02Ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00=Oooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000eoooo00?o09Woooooool0:_ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00=Oooo`03o`2Ioooooooo
02Ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00=Ooo
o`03o`2Ioooooooo02Soool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000e
oooo00?o09Woooooool0;oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000eoooo00?o
09Woooooool0;oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000eoooo00?o09Wooooo
ool0;oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000eoooo00?o09Woooooool0;ooo
o`80000;<ol000<0003oooooool0ZOooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00=Ooo
o`03o`2Ioooooooo02ooool200002S?o00030000oooooooo0:[oool003Goool00ol0VOooooooo`0_
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool003Goool00ol0VOooooooo`0_oooo00<0
000co`0co`002C?o00030000oooooooo0:[oool003Goool00ol0VOooooooo`0_oooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool003Goool00ol0VOooooooo`0_oooo00<0000co`0co`0023?o
00030000oooooooo0:_oool003Goool00ol0VOooooooo`0_oooo00<0000co`0co`0023?o00030000
oooooooo0:_oool003Goool00ol0VOooooooo`0_oooo0P0000Tco`000`000?ooooooo`2[oooo000e
oooo00?o09Woooooool0;oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000eoooo00?o
09Woooooool0;oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000eoooo00?o09Wooooo
ool0;oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000eoooo00?o09Woooooool0;ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000eoooo00?o09Woooooool0;oooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000eoooo00?o09Woooooool0;oooo`800008<ol000<0
003oooooool0[?ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00=Oooo`03o`2Ioooooooo02ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00=Ooo
o`03o`2Ioooooooo02ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00=Oooo`03o`2I
oooooooo02Woool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000eoooo00?o
09Woooooool0:_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00=Oooo`03o`2Ioooooooo02Ooool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo0`0000?oool400000ooo
o`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00<0003oooooool01?ooo`030000oooooooo07Goool006Ooool9<ol01?ooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool01?ooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000oooooooo
00D0000Boooo00@0003oooooool00008oooo0`0000Goool00`000?ooooooo`02oooo00<0003ooooo
ool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000005Oooo`040000oooooooo00002Ooo
o`030000oooooooo00;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001Woooo2C?o
00Koool00`000?ooooooo`0Goooo0P0000[oool300000oooo`800003oooo00<0003oooooool0M_oo
o`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.13506 .12361 L
.14415 .12361 L
.14635 .12361 L
.14868 .12361 L
.1499 .12361 L
.15059 .12361 L
s
.15059 .12361 m
.15085 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Moooo00?o
09Woooooool01Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool003Koool00ol0VOooooooo`0^
oooo00<0000co`0co`00Ac?o00D0001Zoooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol0
048co`050000Koooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000m<ol01@0007Coool0
03Koool00ol0VOooooooo`0^oooo00<0000co`0co`00>C?o00@0001ioooo000foooo00?o09Wooooo
ool0;_ooo`80000h<ol00P0007goool003Koool00ol0VOooooooo`0^oooo00<0000co`0co`00=C?o
0080001ooooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol003<co`020000POooo`00=_oo
o`03o`2Ioooooooo02koool00`0003?o03?o000a<ol00P0008?oool003Koool00ol0VOooooooo`0^
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool003Koool00ol0VOooooooo`0^oooo00<0
000co`0co`00;S?o00800026oooo000foooo00?o09Woooooool0;_ooo`80000]<ol00P0008Soool0
03Koool00ol0VOooooooo`0^oooo00<0000co`0co`00:c?o00030000oooooooo08Soool003Koool0
0ol0VOooooooo`0^oooo00<0000co`0co`00:S?o00030000oooooooo08Woool003Koool00ol0VOoo
ooooo`0^oooo00<0000co`0co`00:C?o00030000oooooooo08[oool003Koool00ol0VOooooooo`0^
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool003Koool00ol0VOooooooo`0^oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool003Koool00ol0VOooooooo`0^oooo0P0002Pco`00
0`000?ooooooo`2<oooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000f
oooo00?o09Woooooool0;_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000foooo00?o
09Woooooool0;_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000foooo00?o09Wooooo
ool0;_ooo`80000S<ol000<0003oooooool0TOooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00=_ooo`03o`2Ioooooooo02Koool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000foooo00?o09Woooooool0:?ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00=_ooo`03o`2Ioooooooo02Soool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000foooo00?o09Woooooool0:?ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00=_ooo`03o`2Ioooooooo02Soool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool003Koool00ol0VOooooooo`0W
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00=_ooo`03o`2Ioooooooo
02koool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00=_ooo`03o`2Ioooooooo02koool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00=_ooo`03o`2Ioooooooo02koool2000073?o
00030000oooooooo09Soool003Koool00ol0VOooooooo`0^oooo00<0000co`0co`006S?o00030000
oooooooo09Woool003Koool00ol0VOooooooo`0^oooo00<0000co`0co`006S?o00030000oooooooo
09Woool003Koool00ol0VOooooooo`0^oooo00<0000co`0co`006C?o00030000oooooooo09[oool0
03Koool00ol0VOooooooo`0^oooo00<0000co`0co`006C?o00030000oooooooo09[oool003Koool0
0ol0VOooooooo`0^oooo00<0000co`0co`0063?o00030000oooooooo09_oool003Koool00ol0VOoo
ooooo`0^oooo0P0001Tco`000`000?ooooooo`2Koooo000foooo00?o09Woooooool0;_ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000f
oooo00?o09Woooooool0;_ooo`80000F<ol000<0003oooooool0W_ooo`00=_ooo`03o`2Ioooooooo
02koool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00=_ooo`03o`2Ioooooooo02koool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00=_ooo`03o`2Ioooooooo02koool200005C?o00030000oooooooo09ooool0
03Koool00ol0VOooooooo`0^oooo00<0000co`0co`004c?o00030000oooooooo0:3oool003Koool0
0ol0VOooooooo`0^oooo00<0000co`0co`004c?o00030000oooooooo0:3oool003Koool00ol0VOoo
ooooo`0^oooo00<0000co`0co`004c?o00030000oooooooo0:3oool003Koool00ol0VOooooooo`0V
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00=_ooo`03o`2Ioooooooo
02Koool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool003Koool0
0ol0VOooooooo`0Woooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00=_oo
o`03o`2Ioooooooo02Soool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool003Koool00ol0VOooooooo`0Voooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool003Koool00ol0VOooooooo`0Woooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00=_ooo`03o`2Ioooooooo02koool200004C?o00030000oooooooo0:?oool003Koool0
0ol0VOooooooo`0^oooo00<0000co`0co`0043?o00030000oooooooo0:?oool003Koool00ol0VOoo
ooooo`0^oooo00<0000co`0co`0043?o00030000oooooooo0:?oool003Koool00ol0VOooooooo`0^
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool003Koool00ol0VOooooooo`0^oooo00<0
000co`0co`003c?o00030000oooooooo0:Coool003Koool00ol0VOooooooo`0^oooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool003Koool00ol0VOooooooo`0^oooo00<0000co`0co`003c?o
00030000oooooooo0:Coool003Koool00ol0VOooooooo`0^oooo0P00010co`000`000?ooooooo`2T
oooo000foooo00?o09Woooooool0;_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000f
oooo00?o09Woooooool0;_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000foooo00?o
09Woooooool0;_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000foooo00?o09Wooooo
ool0;_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000foooo00?o09Woooooool0;_oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000foooo00?o09Woooooool0;_ooo`80000>
<ol000<0003oooooool0Y_ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00=_oo
o`03o`2Ioooooooo02koool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00=_ooo`03o`2I
oooooooo02koool200003C?o00030000oooooooo0:Ooool003Koool00ol0VOooooooo`0^oooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool003Koool00ol0VOooooooo`0^oooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool003Koool00ol0VOooooooo`0^oooo00<0000co`0co`002c?o
00030000oooooooo0:Soool003Koool00ol0VOooooooo`0Woooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00=_ooo`03o`2Ioooooooo02Koool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00=_ooo`03o`2Ioooooooo02Soool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000foooo00?o09Woooooool0:Oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00=_ooo`03o`2Ioooooooo
02Koool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00=_oo
o`03o`2Ioooooooo02Ooool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000f
oooo00?o09Woooooool0;_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000foooo00?o
09Woooooool0;_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000foooo00?o09Wooooo
ool0;_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000foooo00?o09Woooooool0;_oo
o`80000;<ol000<0003oooooool0ZOooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00=_oo
o`03o`2Ioooooooo02koool200002S?o00030000oooooooo0:[oool003Koool00ol0VOooooooo`0^
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool003Koool00ol0VOooooooo`0^oooo00<0
000co`0co`002C?o00030000oooooooo0:[oool003Koool00ol0VOooooooo`0^oooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool003Koool00ol0VOooooooo`0^oooo00<0000co`0co`0023?o
00030000oooooooo0:_oool003Koool00ol0VOooooooo`0^oooo00<0000co`0co`0023?o00030000
oooooooo0:_oool003Koool00ol0VOooooooo`0^oooo0P0000Tco`000`000?ooooooo`2[oooo000f
oooo00?o09Woooooool0;_ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000foooo00?o
09Woooooool0;_ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000foooo00?o09Wooooo
ool0;_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000foooo00?o09Woooooool0;_oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000foooo00?o09Woooooool0;_ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000foooo00?o09Woooooool0;_ooo`800008<ol000<0
003oooooool0[?ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00=_ooo`03o`2Ioooooooo02koool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00=_oo
o`03o`2Ioooooooo02koool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00=_ooo`03o`2I
oooooooo02Soool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000foooo00?o
09Woooooool0:Oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00=_ooo`03o`2Ioooooooo02Koool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Ooo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo0`0000Coool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00Iooo
o`Tco`08oooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool300001?ooo`030000
oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Woool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003ooooo
ool05oooo`80000:oooo0`0000;oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8
<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.13506 .12361 L
.14415 .12361 L
.14868 .12361 L
.15107 .12361 L
.1536 .12361 L
.15581 .12361 L
.15707 .12361 L
s
.15707 .12361 m
.15754 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooool0V@05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Ooooo00?o
09Woooooool00oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool003Soool00ol0VOooooooo`0/
oooo00<0000co`0co`00Ac?o00D0001Zoooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol0
048co`050000Koooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000m<ol01@0007Coool0
03Soool00ol0VOooooooo`0/oooo00<0000co`0co`00>C?o00@0001ioooo000hoooo00?o09Wooooo
ool0;?ooo`80000h<ol00P0007goool003Soool00ol0VOooooooo`0/oooo00<0000co`0co`00=C?o
0080001ooooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol003<co`020000POooo`00>?oo
o`03o`2Ioooooooo02coool00`0003?o03?o000a<ol00P0008?oool003Soool00ol0VOooooooo`0/
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool003Soool00ol0VOooooooo`0/oooo00<0
000co`0co`00;S?o00800026oooo000hoooo00?o09Woooooool0;?ooo`80000]<ol00P0008Soool0
03Soool00ol0VOooooooo`0/oooo00<0000co`0co`00:c?o00030000oooooooo08Soool003Soool0
0ol0VOooooooo`0/oooo00<0000co`0co`00:S?o00030000oooooooo08Woool003Soool00ol0VOoo
ooooo`0/oooo00<0000co`0co`00:C?o00030000oooooooo08[oool003Soool00ol0VOooooooo`0/
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool003Soool00ol0VOooooooo`0/oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool003Soool00ol0VOooooooo`0/oooo0P0002Pco`00
0`000?ooooooo`2<oooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000h
oooo00?o09Woooooool0;?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000hoooo00?o
09Woooooool0;?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000hoooo00?o09Wooooo
ool0;?ooo`80000S<ol000<0003oooooool0TOooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00>?ooo`03o`2Ioooooooo02Coool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000hoooo00?o09Woooooool09_ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00>?ooo`03o`2Ioooooooo02Koool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo000hoooo00?o09Woooooool09_ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00>?ooo`03o`2Ioooooooo02Koool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool003Soool00ol0VOooooooo`0U
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00>?ooo`03o`2Ioooooooo
02coool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00>?ooo`03o`2Ioooooooo02coool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00>?ooo`03o`2Ioooooooo02coool2000073?o
00030000oooooooo09Soool003Soool00ol0VOooooooo`0/oooo00<0000co`0co`006S?o00030000
oooooooo09Woool003Soool00ol0VOooooooo`0/oooo00<0000co`0co`006S?o00030000oooooooo
09Woool003Soool00ol0VOooooooo`0/oooo00<0000co`0co`006C?o00030000oooooooo09[oool0
03Soool00ol0VOooooooo`0/oooo00<0000co`0co`006C?o00030000oooooooo09[oool003Soool0
0ol0VOooooooo`0/oooo00<0000co`0co`0063?o00030000oooooooo09_oool003Soool00ol0VOoo
ooooo`0/oooo0P0001Tco`000`000?ooooooo`2Koooo000hoooo00?o09Woooooool0;?ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000h
oooo00?o09Woooooool0;?ooo`80000F<ol000<0003oooooool0W_ooo`00>?ooo`03o`2Ioooooooo
02coool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00>?ooo`03o`2Ioooooooo02coool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00>?ooo`03o`2Ioooooooo02coool200005C?o00030000oooooooo09ooool0
03Soool00ol0VOooooooo`0/oooo00<0000co`0co`004c?o00030000oooooooo0:3oool003Soool0
0ol0VOooooooo`0/oooo00<0000co`0co`004c?o00030000oooooooo0:3oool003Soool00ol0VOoo
ooooo`0/oooo00<0000co`0co`004c?o00030000oooooooo0:3oool003Soool00ol0VOooooooo`0T
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00>?ooo`03o`2Ioooooooo
02Coool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool003Soool0
0ol0VOooooooo`0Uoooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00>?oo
o`03o`2Ioooooooo02Koool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool003Soool00ol0VOooooooo`0Toooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool003Soool00ol0VOooooooo`0Uoooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00>?ooo`03o`2Ioooooooo02coool200004C?o00030000oooooooo0:?oool003Soool0
0ol0VOooooooo`0/oooo00<0000co`0co`0043?o00030000oooooooo0:?oool003Soool00ol0VOoo
ooooo`0/oooo00<0000co`0co`0043?o00030000oooooooo0:?oool003Soool00ol0VOooooooo`0/
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool003Soool00ol0VOooooooo`0/oooo00<0
000co`0co`003c?o00030000oooooooo0:Coool003Soool00ol0VOooooooo`0/oooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool003Soool00ol0VOooooooo`0/oooo00<0000co`0co`003c?o
00030000oooooooo0:Coool003Soool00ol0VOooooooo`0/oooo0P00010co`000`000?ooooooo`2T
oooo000hoooo00?o09Woooooool0;?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000h
oooo00?o09Woooooool0;?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000hoooo00?o
09Woooooool0;?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000hoooo00?o09Wooooo
ool0;?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000hoooo00?o09Woooooool0;?oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000hoooo00?o09Woooooool0;?ooo`80000>
<ol000<0003oooooool0Y_ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00>?oo
o`03o`2Ioooooooo02coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00>?ooo`03o`2I
oooooooo02coool200003C?o00030000oooooooo0:Ooool003Soool00ol0VOooooooo`0/oooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool003Soool00ol0VOooooooo`0/oooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool003Soool00ol0VOooooooo`0/oooo00<0000co`0co`002c?o
00030000oooooooo0:Soool003Soool00ol0VOooooooo`0Uoooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00>?ooo`03o`2Ioooooooo02Coool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00>?ooo`03o`2Ioooooooo02Koool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo000hoooo00?o09Woooooool09oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00>?ooo`03o`2Ioooooooo
02Coool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00>?oo
o`03o`2Ioooooooo02Goool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000h
oooo00?o09Woooooool0;?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000hoooo00?o
09Woooooool0;?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000hoooo00?o09Wooooo
ool0;?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000hoooo00?o09Woooooool0;?oo
o`80000;<ol000<0003oooooool0ZOooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00>?oo
o`03o`2Ioooooooo02coool200002S?o00030000oooooooo0:[oool003Soool00ol0VOooooooo`0/
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool003Soool00ol0VOooooooo`0/oooo00<0
000co`0co`002C?o00030000oooooooo0:[oool003Soool00ol0VOooooooo`0/oooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool003Soool00ol0VOooooooo`0/oooo00<0000co`0co`0023?o
00030000oooooooo0:_oool003Soool00ol0VOooooooo`0/oooo00<0000co`0co`0023?o00030000
oooooooo0:_oool003Soool00ol0VOooooooo`0/oooo0P0000Tco`000`000?ooooooo`2[oooo000h
oooo00?o09Woooooool0;?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000hoooo00?o
09Woooooool0;?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000hoooo00?o09Wooooo
ool0;?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000hoooo00?o09Woooooool0;?oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000hoooo00?o09Woooooool0;?ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000hoooo00?o09Woooooool0;?ooo`800008<ol000<0
003oooooool0[?ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00>?ooo`03o`2Ioooooooo02coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00>?oo
o`03o`2Ioooooooo02coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00>?ooo`03o`2I
oooooooo02Koool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000hoooo00?o
09Woooooool09oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00>?ooo`03o`2Ioooooooo02Coool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00Ioooo`Tco`04oooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000_oool010000?ooooooo`00
00;oool00`000?ooooooo`02oooo00<0003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003ooooo
ool01@0001;oool010000?ooooooo`0000Woool200001?ooo`800004oooo00<0003oooooool0MOoo
o`00Ioooo`Tco`05oooo00D0003oooooooooool000005Oooo`040000oooooooo00002Oooo`030000
oooooooo00;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001Woooo2C?o00Koool0
0`000?ooooooo`0Goooo0P0000[oool300000oooo`800003oooo00<0003oooooool0M_ooo`00Iooo
o`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.14415 .12361 L
.1536 .12361 L
.15825 .12361 L
.16029 .12361 L
.16137 .12361 L
.16254 .12361 L
s
.16254 .12361 m
.16303 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool010000?ooooooool0V@Coool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo023oool0
0ol0VOooooooo`02oooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00>Oooo`03o`2Ioooooooo
02_oool00`0003?o03?o0017<ol01@0006[oool003Woool00ol0VOooooooo`0[oooo00<0000co`0c
o`00@S?o00D0001_oooo000ioooo00?o09Woooooool0:oooo`030000<ol0<ol003dco`050000M?oo
o`00>Oooo`03o`2Ioooooooo02_oool00`0003?o03?o000i<ol0100007Woool003Woool00ol0VOoo
ooooo`0[oooo0P0003Pco`020000OOooo`00>Oooo`03o`2Ioooooooo02_oool00`0003?o03?o000e
<ol00P0007ooool003Woool00ol0VOooooooo`0[oooo00<0000co`0co`00<c?o00800021oooo000i
oooo00?o09Woooooool0:oooo`030000<ol0<ol0034co`020000Poooo`00>Oooo`03o`2Ioooooooo
02_oool00`0003?o03?o000`<ol000<0003oooooool0Poooo`00>Oooo`03o`2Ioooooooo02_oool0
0`0003?o03?o000^<ol00P0008Koool003Woool00ol0VOooooooo`0[oooo0P0002dco`020000R?oo
o`00>Oooo`03o`2Ioooooooo02_oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00>Ooo
o`03o`2Ioooooooo02_oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`00>Oooo`03o`2I
oooooooo02_oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`00>Oooo`03o`2Ioooooooo
02_oool00`0003?o03?o000X<ol000<0003oooooool0Roooo`00>Oooo`03o`2Ioooooooo02_oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`00>Oooo`03o`2Ioooooooo02_oool20000:3?o
00030000oooooooo08coool003Woool00ol0VOooooooo`0[oooo00<0000co`0co`009S?o00030000
oooooooo08goool003Woool00ol0VOooooooo`0[oooo00<0000co`0co`009C?o00030000oooooooo
08koool003Woool00ol0VOooooooo`0[oooo00<0000co`0co`0093?o00030000oooooooo08ooool0
03Woool00ol0VOooooooo`0[oooo00<0000co`0co`008c?o00030000oooooooo093oool003Woool0
0ol0VOooooooo`0[oooo00<0000co`0co`008c?o00030000oooooooo093oool003Woool00ol0VOoo
ooooo`0[oooo0P0002<co`000`000?ooooooo`2Aoooo000ioooo00?o09Woooooool0:oooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo000ioooo00?o09Woooooool0:oooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo000ioooo00?o09Woooooool0:oooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo000ioooo00?o09Woooooool0:oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo000ioooo00?o09Woooooool08oooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo09Coool003Woool00ol0VOooooooo`0Uoooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Eoooo000ioooo00?o09Woooooool09Oooo`030000oooooooo00?oool2
00007c?o00030000oooooooo09Goool003Woool00ol0VOooooooo`0Uoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`2Foooo000ioooo00?o09Woooooool09Oooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00>Oooo`03o`2Ioooooooo
02Coool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000ioooo00?o09Wooooo
ool0:oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo000ioooo00?o09Woooooool0:ooo
o`030000<ol0<ol001/co`000`000?ooooooo`2Hoooo000ioooo00?o09Woooooool0:oooo`80000L
<ol000<0003oooooool0V?ooo`00>Oooo`03o`2Ioooooooo02_oool00`0003?o03?o000J<ol000<0
003oooooool0VOooo`00>Oooo`03o`2Ioooooooo02_oool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`00>Oooo`03o`2Ioooooooo02_oool00`0003?o03?o000I<ol000<0003oooooool0V_oo
o`00>Oooo`03o`2Ioooooooo02_oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00>Ooo
o`03o`2Ioooooooo02_oool00`0003?o03?o000H<ol000<0003oooooool0Voooo`00>Oooo`03o`2I
oooooooo02_oool200006C?o00030000oooooooo09_oool003Woool00ol0VOooooooo`0[oooo00<0
000co`0co`005c?o00030000oooooooo09coool003Woool00ol0VOooooooo`0[oooo00<0000co`0c
o`005c?o00030000oooooooo09coool003Woool00ol0VOooooooo`0[oooo00<0000co`0co`005S?o
00030000oooooooo09goool003Woool00ol0VOooooooo`0[oooo00<0000co`0co`005S?o00030000
oooooooo09goool003Woool00ol0VOooooooo`0[oooo00<0000co`0co`005S?o00030000oooooooo
09goool003Woool00ol0VOooooooo`0[oooo00<0000co`0co`005C?o00030000oooooooo09koool0
03Woool00ol0VOooooooo`0[oooo0P0001Hco`000`000?ooooooo`2Noooo000ioooo00?o09Wooooo
ool0:oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000ioooo00?o09Woooooool0:ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000ioooo00?o09Woooooool0:oooo`030000
<ol0<ol001@co`000`000?ooooooo`2Ooooo000ioooo00?o09Woooooool0:oooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo000ioooo00?o09Woooooool0:oooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo000ioooo00?o09Woooooool0:oooo`80000E<ol000<0003oooooool0Wooo
o`00>Oooo`03o`2Ioooooooo02_oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00>Ooo
o`03o`2Ioooooooo02_oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00>Oooo`03o`2I
oooooooo02_oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00>Oooo`03o`2Ioooooooo
02?oool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo000ioooo00?o09Wooooo
ool08oooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00>Ooo
o`03o`2Ioooooooo02Coool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo000j
oooo00?o09Woooooool09?ooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0XOooo`00>_ooo`03o`2Ioooooooo02;oool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00>_ooo`03o`2Ioooooooo02?oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo000joooo00?o09Woooooool0:_ooo`80000A<ol000<0003oooooool0Xoooo`00>_oo
o`03o`2Ioooooooo02[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00>_ooo`03o`2I
oooooooo02[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00>_ooo`03o`2Ioooooooo
02[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00>_ooo`03o`2Ioooooooo02[oool0
0`0003?o03?o000?<ol000<0003oooooool0Y?ooo`00>_ooo`03o`2Ioooooooo02[oool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`00>_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`00>_ooo`03o`2Ioooooooo02[oool2000043?o00030000oooooooo
0:Coool003[oool00ol0VOooooooo`0Zoooo00<0000co`0co`003S?o00030000oooooooo0:Goool0
03[oool00ol0VOooooooo`0Zoooo00<0000co`0co`003S?o00030000oooooooo0:Goool003[oool0
0ol0VOooooooo`0Zoooo00<0000co`0co`003S?o00030000oooooooo0:Goool003[oool00ol0VOoo
ooooo`0Zoooo00<0000co`0co`003S?o00030000oooooooo0:Goool003[oool00ol0VOooooooo`0Z
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool003[oool00ol0VOooooooo`0Zoooo0P00
00hco`000`000?ooooooo`2Voooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000dco`00
0`000?ooooooo`2Voooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000`co`000`000?ooooooo`2W
oooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000j
oooo00?o09Woooooool0:_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000joooo00?o
09Woooooool0:_ooo`80000=<ol000<0003oooooool0Yoooo`00>_ooo`03o`2Ioooooooo02[oool0
0`0003?o03?o000<<ol000<0003oooooool0Yoooo`00>_ooo`03o`2Ioooooooo02[oool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`00>_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00>_ooo`03o`2Ioooooooo02?oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo000joooo00?o09Woooooool08_ooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000joooo00?o09Woooooool09?ooo`030000
oooooooo00?oool2000033?o00030000oooooooo0:Soool003[oool00ol0VOooooooo`0Uoooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000joooo00?o09Wooooo
ool08_ooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000j
oooo00?o09Woooooool08oooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
03[oool00ol0VOooooooo`0Zoooo00<0000co`0co`002S?o00030000oooooooo0:Woool003[oool0
0ol0VOooooooo`0Zoooo00<0000co`0co`002S?o00030000oooooooo0:Woool003[oool00ol0VOoo
ooooo`0Zoooo00<0000co`0co`002S?o00030000oooooooo0:Woool003[oool00ol0VOooooooo`0Z
oooo0P0000/co`000`000?ooooooo`2Yoooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000j
oooo00?o09Woooooool0:_ooo`80000:<ol000<0003oooooool0Z_ooo`00>_ooo`03o`2Ioooooooo
02[oool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00>_ooo`03o`2Ioooooooo02[oool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00>_ooo`03o`2Ioooooooo02[oool00`0003?o
03?o0008<ol000<0003oooooool0Zoooo`00>_ooo`03o`2Ioooooooo02[oool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`00>_ooo`03o`2Ioooooooo02[oool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`00>_ooo`03o`2Ioooooooo02[oool200002C?o00030000oooooooo0:_oool0
03[oool00ol0VOooooooo`0Zoooo00<0000co`0co`0023?o00030000oooooooo0:_oool003[oool0
0ol0VOooooooo`0Zoooo00<0000co`0co`0023?o00030000oooooooo0:_oool003[oool00ol0VOoo
ooooo`0Zoooo00<0000co`0co`001c?o00030000oooooooo0:coool003[oool00ol0VOooooooo`0Z
oooo00<0000co`0co`001c?o00030000oooooooo0:coool003[oool00ol0VOooooooo`0Zoooo00<0
000co`0co`001c?o00030000oooooooo0:coool003[oool00ol0VOooooooo`0Zoooo0P0000Pco`00
0`000?ooooooo`2/oooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`2/oooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000joooo00?o09Woooooool0:_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000j
oooo00?o09Woooooool0:_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000joooo00?o
09Woooooool09?ooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool003[oool0
0ol0VOooooooo`0Uoooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo000joooo00?o09Woooooool08_ooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200000oooo`<00004
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001Woooo2C?o00Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002oooo`040000oooooooo
00000_ooo`030000oooooooo00;oool00`000?ooooooo`1doooo001Woooo2C?o00Goool00`000?oo
ooooo`0500004_ooo`040000oooooooo00002Oooo`800003oooo0`0000Coool00`000?ooooooo`1e
oooo001Woooo2C?o00Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009oooo00<0
003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`1eoooo001Woooo2C?o00Koool0
0`000?ooooooo`0Goooo0P0000[oool300000oooo`<00002oooo00<0003oooooool0M_ooo`00Iooo
o`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.14415 .12361 L
.1536 .12361 L
.16254 .12361 L
.16494 .12361 L
.16748 .12361 L
.1688 .12361 L
.16956 .12361 L
s
.16956 .12361 m
.16984 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo00Co09Wooooo
ool00008oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02;oool0
1?l0VOooooooo`0002Soool00`0003?o03?o000U<ol000<0000co`0co`0093?o0100000Ioooo00<0
003oooooool09_ooo`030000oooooooo01Goool003_oool00ol0VOooooooo`0Yoooo00<0000co`0c
o`00Ac?o00D0001Zoooo000koooo00?o09Woooooool0:Oooo`030000<ol0<ol0048co`050000Kooo
o`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000m<ol01@0007Coool003_oool00ol0VOoo
ooooo`0Yoooo00<0000co`0co`00>C?o00@0001ioooo000koooo00?o09Woooooool0:Oooo`80000h
<ol00P0007goool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`00=C?o0080001ooooo000k
oooo00?o09Woooooool0:Oooo`030000<ol0<ol003<co`020000POooo`00>oooo`03o`2Ioooooooo
02Woool00`0003?o03?o000a<ol00P0008?oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0c
o`00<3?o00030000oooooooo08?oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`00;S?o
00800026oooo000koooo00?o09Woooooool0:Oooo`80000]<ol00P0008Soool003_oool00ol0VOoo
ooooo`0Yoooo00<0000co`0co`00:c?o00030000oooooooo08Soool003_oool00ol0VOooooooo`0Y
oooo00<0000co`0co`00:S?o00030000oooooooo08Woool003_oool00ol0VOooooooo`0Yoooo00<0
000co`0co`00:C?o00030000oooooooo08[oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0c
o`00:3?o00030000oooooooo08_oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`00:3?o
00030000oooooooo08_oool003_oool00ol0VOooooooo`0Yoooo0P0002Pco`000`000?ooooooo`2<
oooo000koooo00?o09Woooooool0:Oooo`030000<ol0<ol002Hco`000`000?ooooooo`2=oooo000k
oooo00?o09Woooooool0:Oooo`030000<ol0<ol002Dco`000`000?ooooooo`2>oooo000koooo00?o
09Woooooool0:Oooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo000koooo00?o09Wooooo
ool0:Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000koooo00?o09Woooooool0:Ooo
o`030000<ol0<ol002<co`000`000?ooooooo`2@oooo000koooo00?o09Woooooool0:Oooo`80000S
<ol000<0003oooooool0TOooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000Q<ol000<0
003oooooool0T_ooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000P<ol000<0003ooooo
ool0Toooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000P<ol000<0003oooooool0Tooo
o`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000O<ol000<0003oooooool0U?ooo`00>ooo
o`03o`2Ioooooooo027oool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`2Doooo000k
oooo00?o09Woooooool08oooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003ooooo
ool0UOooo`00>oooo`03o`2Ioooooooo02?oool00`000?ooooooo`03oooo0P0001lco`000`000?oo
ooooo`2Eoooo000koooo00?o09Woooooool08oooo`030000oooooooo00?oool00`0003?o03?o000M
<ol000<0003oooooool0U_ooo`00>oooo`03o`2Ioooooooo02?oool00`000?ooooooo`03oooo00<0
000co`0co`007C?o00030000oooooooo09Koool003_oool00ol0VOooooooo`0Roooo0P0000Goool0
0`0003?o03?o000L<ol000<0003oooooool0Uoooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o
03?o000L<ol000<0003oooooool0Uoooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000K
<ol000<0003oooooool0V?ooo`00>oooo`03o`2Ioooooooo02Woool2000073?o00030000oooooooo
09Soool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`006S?o00030000oooooooo09Woool0
03_oool00ol0VOooooooo`0Yoooo00<0000co`0co`006S?o00030000oooooooo09Woool003_oool0
0ol0VOooooooo`0Yoooo00<0000co`0co`006C?o00030000oooooooo09[oool003_oool00ol0VOoo
ooooo`0Yoooo00<0000co`0co`006C?o00030000oooooooo09[oool003_oool00ol0VOooooooo`0Y
oooo00<0000co`0co`0063?o00030000oooooooo09_oool003_oool00ol0VOooooooo`0Yoooo0P00
01Tco`000`000?ooooooo`2Koooo000koooo00?o09Woooooool0:Oooo`030000<ol0<ol001Lco`00
0`000?ooooooo`2Loooo000koooo00?o09Woooooool0:Oooo`030000<ol0<ol001Lco`000`000?oo
ooooo`2Loooo000koooo00?o09Woooooool0:Oooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo000koooo00?o09Woooooool0:Oooo`030000<ol0<ol001Hco`000`000?ooooooo`2Moooo000k
oooo00?o09Woooooool0:Oooo`030000<ol0<ol001Hco`000`000?ooooooo`2Moooo000koooo00?o
09Woooooool0:Oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo000koooo00?o09Wooooo
ool0:Oooo`80000F<ol000<0003oooooool0W_ooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o
03?o000E<ol000<0003oooooool0W_ooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000E
<ol000<0003oooooool0W_ooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000D<ol000<0003ooooo
ool0Woooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000D<ol000<0003oooooool0Wooo
o`00>oooo`03o`2Ioooooooo02Woool200005C?o00030000oooooooo09ooool003_oool00ol0VOoo
ooooo`0Yoooo00<0000co`0co`004c?o00030000oooooooo0:3oool003_oool00ol0VOooooooo`0Y
oooo00<0000co`0co`004c?o00030000oooooooo0:3oool003_oool00ol0VOooooooo`0Yoooo00<0
000co`0co`004c?o00030000oooooooo0:3oool003_oool00ol0VOooooooo`0Qoooo100000Coool0
0`0003?o03?o000C<ol000<0003oooooool0X?ooo`00>oooo`03o`2Ioooooooo027oool00`000?oo
ooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool003_oool00ol0VOooooooo`0R
oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00>oooo`03o`2Ioooooooo
02?oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo0:7oool003_oool0
0ol0VOooooooo`0Qoooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo
0:;oool003_oool00ol0VOooooooo`0Roooo0P0000Goool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000A<ol000<0003oooooool0X_oo
o`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000A<ol000<0003oooooool0X_ooo`00>ooo
o`03o`2Ioooooooo02Woool200004C?o00030000oooooooo0:?oool003_oool00ol0VOooooooo`0Y
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool003_oool00ol0VOooooooo`0Yoooo00<0
000co`0co`0043?o00030000oooooooo0:?oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0c
o`0043?o00030000oooooooo0:?oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`003c?o
00030000oooooooo0:Coool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`003c?o00030000
oooooooo0:Coool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`003c?o00030000oooooooo
0:Coool003_oool00ol0VOooooooo`0Yoooo0P00010co`000`000?ooooooo`2Toooo000koooo00?o
09Woooooool0:Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000koooo00?o09Wooooo
ool0:Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000koooo00?o09Woooooool0:Ooo
o`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo000koooo00?o09Woooooool0:Oooo`030000
<ol0<ol000hco`000`000?ooooooo`2Uoooo000koooo00?o09Woooooool0:Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`2Voooo000koooo00?o09Woooooool0:Oooo`80000><ol000<0003ooooo
ool0Y_ooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000=<ol000<0003oooooool0Y_oo
o`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000=<ol000<0003oooooool0Y_ooo`00>ooo
o`03o`2Ioooooooo02Woool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00>oooo`03o`2I
oooooooo02Woool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00>oooo`03o`2Ioooooooo
02Woool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00>oooo`03o`2Ioooooooo02Woool2
00003C?o00030000oooooooo0:Ooool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`0033?o
00030000oooooooo0:Ooool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`0033?o00030000
oooooooo0:Ooool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`002c?o00030000oooooooo
0:Soool003_oool00ol0VOooooooo`0Roooo0P0000Goool00`0003?o03?o000;<ol000<0003ooooo
ool0Z?ooo`00>oooo`03o`2Ioooooooo027oool010000?ooooooo`0000Coool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00>oooo`03o`2Ioooooooo02?oool00`000?ooooooo`03oooo0P00
00`co`000`000?ooooooo`2Xoooo000koooo00?o09Woooooool09?ooo`030000oooooooo00;oool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00>oooo`03o`2Ioooooooo027oool010000?oo
ooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00>oooo`03o`2Ioooooooo
02;oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000koooo00?o09Wooooo
ool0:Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000koooo00?o09Woooooool0:Ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo000koooo00?o09Woooooool0:Oooo`030000
<ol0<ol000Xco`000`000?ooooooo`2Yoooo000koooo00?o09Woooooool0:Oooo`80000;<ol000<0
003oooooool0ZOooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o000:<ol000<0003ooooo
ool0ZOooo`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00>ooo
o`03o`2Ioooooooo02Woool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00>oooo`03o`2I
oooooooo02Woool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00>oooo`03o`2Ioooooooo
02Woool200002S?o00030000oooooooo0:[oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0c
o`002C?o00030000oooooooo0:[oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`002C?o
00030000oooooooo0:[oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`0023?o00030000
oooooooo0:_oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`0023?o00030000oooooooo
0:_oool003_oool00ol0VOooooooo`0Yoooo00<0000co`0co`0023?o00030000oooooooo0:_oool0
03_oool00ol0VOooooooo`0Yoooo0P0000Tco`000`000?ooooooo`2[oooo000koooo00?o09Wooooo
ool0:Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000koooo00?o09Woooooool0:Ooo
o`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo000koooo00?o09Woooooool0:Oooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo000koooo00?o09Woooooool0:Oooo`030000<ol0<ol0
00Lco`000`000?ooooooo`2/oooo000koooo00?o09Woooooool0:Oooo`030000<ol0<ol000Lco`00
0`000?ooooooo`2/oooo000koooo00?o09Woooooool0:Oooo`800008<ol000<0003oooooool0[?oo
o`00>oooo`03o`2Ioooooooo02Woool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00>ooo
o`03o`2Ioooooooo02Woool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00>oooo`03o`2I
oooooooo02Woool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00>oooo`03o`2Ioooooooo
02Woool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00>oooo`03o`2Ioooooooo02?oool3
00000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000koooo00?o09Woooooool09?oo
o`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00>oooo`03o`2I
oooooooo027oool500000oooo`800008<ol000<0003oooooool0[?ooo`00Goooo`040000oooooooo
00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:
<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_ooo`030000oooooooo
02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08oooo00<0003ooooo
ool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00goool200001?ooo`800004oooo0P0000Goool300000_ooo`030000oooooooo
07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00D0
003oooooooooool00000Moooo`00Ioooo`Tco`04oooo00<0003oooooool00_ooo`030000oooooooo
01?oool010000?ooooooo`0000_oool00`000?ooooooo`0500000oooo`030000oooooooo07Coool0
06Ooool9<ol01Oooo`030000oooooooo00D0000Boooo00@0003oooooool00009oooo0P0000?oool0
10000?ooooooo`0000?oool00`000?ooooooo`1eoooo001Woooo2C?o00Goool01@000?oooooooooo
o`00000Eoooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooo000000?oool0
0`000?ooooooo`1eoooo001Woooo2C?o00Koool00`000?ooooooo`0Goooo0P0000[oool300001?oo
o`800002oooo00<0003oooooool0M_ooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.14415 .12361 L
.16254 .12361 L
.16783 .12361 L
.17044 .12361 L
.17284 .12361 L
.17502 .12361 L
.17612 .12361 L
s
.17612 .12361 m
.1766 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`04oooo00?o09T0003o
ool01oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Toooo00?o
09T0003oool09oooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol0400001Woool00`000?oo
ooooo`0Voooo00<0003oooooool05Oooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o0017
<ol01@0006[oool003goool00ol0VOooooooo`0Woooo00<0000co`0co`00@S?o00D0001_oooo000m
oooo00?o09Woooooool09oooo`030000<ol0<ol003dco`050000M?ooo`00?Oooo`03o`2Ioooooooo
02Ooool00`0003?o03?o000i<ol0100007Woool003goool00ol0VOooooooo`0Woooo0P0003Pco`02
0000OOooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000e<ol00P0007ooool003goool0
0ol0VOooooooo`0Woooo00<0000co`0co`00<c?o00800021oooo000moooo00?o09Woooooool09ooo
o`030000<ol0<ol0034co`020000Poooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000`
<ol000<0003oooooool0Poooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000^<ol00P00
08Koool003goool00ol0VOooooooo`0Woooo0P0002dco`020000R?ooo`00?Oooo`03o`2Ioooooooo
02Ooool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00?Oooo`03o`2Ioooooooo02Ooool0
0`0003?o03?o000Z<ol000<0003oooooool0ROooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o
03?o000Y<ol000<0003oooooool0R_ooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000X
<ol000<0003oooooool0Roooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000X<ol000<0
003oooooool0Roooo`00?Oooo`03o`2Ioooooooo02Ooool20000:3?o00030000oooooooo08coool0
03goool00ol0VOooooooo`0Woooo00<0000co`0co`009S?o00030000oooooooo08goool003goool0
0ol0VOooooooo`0Woooo00<0000co`0co`009C?o00030000oooooooo08koool003goool00ol0VOoo
ooooo`0Woooo00<0000co`0co`0093?o00030000oooooooo08ooool003goool00ol0VOooooooo`0W
oooo00<0000co`0co`008c?o00030000oooooooo093oool003goool00ol0VOooooooo`0Woooo00<0
000co`0co`008c?o00030000oooooooo093oool003goool00ol0VOooooooo`0Woooo0P0002<co`00
0`000?ooooooo`2Aoooo000moooo00?o09Woooooool09oooo`030000<ol0<ol0024co`000`000?oo
ooooo`2Boooo000moooo00?o09Woooooool09oooo`030000<ol0<ol0020co`000`000?ooooooo`2C
oooo000moooo00?o09Woooooool09oooo`030000<ol0<ol0020co`000`000?ooooooo`2Coooo000m
oooo00?o09Woooooool09oooo`030000<ol0<ol001lco`000`000?ooooooo`2Doooo000moooo00?o
09Woooooool07oooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo09Coool003goool0
0ol0VOooooooo`0Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`2E
oooo000moooo00?o09Woooooool08Oooo`030000oooooooo00?oool200007c?o00030000oooooooo
09Goool003goool00ol0VOooooooo`0Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`00
0`000?ooooooo`2Foooo000moooo00?o09Woooooool08Oooo`030000oooooooo00?oool00`0003?o
03?o000M<ol000<0003oooooool0U_ooo`00?Oooo`03o`2Ioooooooo023oool200001Oooo`030000
<ol0<ol001`co`000`000?ooooooo`2Goooo000moooo00?o09Woooooool09oooo`030000<ol0<ol0
01`co`000`000?ooooooo`2Goooo000moooo00?o09Woooooool09oooo`030000<ol0<ol001/co`00
0`000?ooooooo`2Hoooo000moooo00?o09Woooooool09oooo`80000L<ol000<0003oooooool0V?oo
o`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000J<ol000<0003oooooool0VOooo`00?Ooo
o`03o`2Ioooooooo02Ooool00`0003?o03?o000J<ol000<0003oooooool0VOooo`00?Oooo`03o`2I
oooooooo02Ooool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00?Oooo`03o`2Ioooooooo
02Ooool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00?Oooo`03o`2Ioooooooo02Ooool0
0`0003?o03?o000H<ol000<0003oooooool0Voooo`00?Oooo`03o`2Ioooooooo02Ooool200006C?o
00030000oooooooo09_oool003goool00ol0VOooooooo`0Woooo00<0000co`0co`005c?o00030000
oooooooo09coool003goool00ol0VOooooooo`0Woooo00<0000co`0co`005c?o00030000oooooooo
09coool003goool00ol0VOooooooo`0Woooo00<0000co`0co`005S?o00030000oooooooo09goool0
03goool00ol0VOooooooo`0Woooo00<0000co`0co`005S?o00030000oooooooo09goool003goool0
0ol0VOooooooo`0Woooo00<0000co`0co`005S?o00030000oooooooo09goool003goool00ol0VOoo
ooooo`0Woooo00<0000co`0co`005C?o00030000oooooooo09koool003goool00ol0VOooooooo`0W
oooo0P0001Hco`000`000?ooooooo`2Noooo000moooo00?o09Woooooool09oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`2Noooo000moooo00?o09Woooooool09oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`2Noooo000moooo00?o09Woooooool09oooo`030000<ol0<ol001@co`000`000?oo
ooooo`2Ooooo000moooo00?o09Woooooool09oooo`030000<ol0<ol001@co`000`000?ooooooo`2O
oooo000moooo00?o09Woooooool09oooo`030000<ol0<ol001@co`000`000?ooooooo`2Ooooo000m
oooo00?o09Woooooool09oooo`80000E<ol000<0003oooooool0Woooo`00?Oooo`03o`2Ioooooooo
02Ooool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00?Oooo`03o`2Ioooooooo02Ooool0
0`0003?o03?o000C<ol000<0003oooooool0X?ooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o
03?o000C<ol000<0003oooooool0X?ooo`00?Oooo`03o`2Ioooooooo01ooool400001?ooo`030000
<ol0<ol001<co`000`000?ooooooo`2Poooo000moooo00?o09Woooooool07oooo`030000oooooooo
00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00?Oooo`03o`2Ioooooooo023oool0
0`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo000moooo00?o09Woooooool08Ooo
o`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00?Oooo`03o`2I
oooooooo01ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool0X_oo
o`00?Oooo`03o`2Ioooooooo023oool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`2R
oooo000moooo00?o09Woooooool09oooo`030000<ol0<ol0014co`000`000?ooooooo`2Roooo000m
oooo00?o09Woooooool09oooo`030000<ol0<ol0014co`000`000?ooooooo`2Roooo000moooo00?o
09Woooooool09oooo`80000A<ol000<0003oooooool0Xoooo`00?Oooo`03o`2Ioooooooo02Ooool0
0`0003?o03?o000@<ol000<0003oooooool0Xoooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o
03?o000@<ol000<0003oooooool0Xoooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000@
<ol000<0003oooooool0Xoooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000?<ol000<0
003oooooool0Y?ooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000?<ol000<0003ooooo
ool0Y?ooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000?<ol000<0003oooooool0Y?oo
o`00?Oooo`03o`2Ioooooooo02Ooool2000043?o00030000oooooooo0:Coool003goool00ol0VOoo
ooooo`0Woooo00<0000co`0co`003S?o00030000oooooooo0:Goool003goool00ol0VOooooooo`0W
oooo00<0000co`0co`003S?o00030000oooooooo0:Goool003goool00ol0VOooooooo`0Woooo00<0
000co`0co`003S?o00030000oooooooo0:Goool003goool00ol0VOooooooo`0Woooo00<0000co`0c
o`003S?o00030000oooooooo0:Goool003goool00ol0VOooooooo`0Woooo00<0000co`0co`003C?o
00030000oooooooo0:Koool003goool00ol0VOooooooo`0Woooo0P0000hco`000`000?ooooooo`2V
oooo000moooo00?o09Woooooool09oooo`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000m
oooo00?o09Woooooool09oooo`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000moooo00?o
09Woooooool09oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000moooo00?o09Wooooo
ool09oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000moooo00?o09Woooooool09ooo
o`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000moooo00?o09Woooooool09oooo`80000=
<ol000<0003oooooool0Yoooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000<<ol000<0
003oooooool0Yoooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000<<ol000<0003ooooo
ool0Yoooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o000;<ol000<0003oooooool0Z?oo
o`00?Oooo`03o`2Ioooooooo023oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`2X
oooo000moooo00?o09Woooooool07oooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`2Xoooo000moooo00?o09Woooooool08Oooo`030000oooooooo00?oool2000033?o
00030000oooooooo0:Soool003goool00ol0VOooooooo`0Roooo00<0003oooooool00_ooo`030000
<ol0<ol000/co`000`000?ooooooo`2Xoooo000moooo00?o09Woooooool07oooo`040000oooooooo
00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000moooo00?o09Woooooool08?oo
o`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool003goool00ol0VOooooooo`0W
oooo00<0000co`0co`002S?o00030000oooooooo0:Woool003goool00ol0VOooooooo`0Woooo00<0
000co`0co`002S?o00030000oooooooo0:Woool003goool00ol0VOooooooo`0Woooo00<0000co`0c
o`002S?o00030000oooooooo0:Woool003goool00ol0VOooooooo`0Woooo0P0000/co`000`000?oo
ooooo`2Yoooo000moooo00?o09Woooooool09oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Y
oooo000moooo00?o09Woooooool09oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000m
oooo00?o09Woooooool09oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000moooo00?o
09Woooooool09oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000moooo00?o09Wooooo
ool09oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000moooo00?o09Woooooool09ooo
o`80000:<ol000<0003oooooool0Z_ooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o0009
<ol000<0003oooooool0Z_ooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o0008<ol000<0003ooooo
ool0Zoooo`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o0008<ol000<0003oooooool0Zooo
o`00?Oooo`03o`2Ioooooooo02Ooool00`0003?o03?o0008<ol000<0003oooooool0Zoooo`00?Ooo
o`03o`2Ioooooooo02Ooool200002C?o00030000oooooooo0:_oool003goool00ol0VOooooooo`0W
oooo00<0000co`0co`0023?o00030000oooooooo0:_oool003goool00ol0VOooooooo`0Woooo00<0
000co`0co`0023?o00030000oooooooo0:_oool003goool00ol0VOooooooo`0Woooo00<0000co`0c
o`001c?o00030000oooooooo0:coool003goool00ol0VOooooooo`0Woooo00<0000co`0co`001c?o
00030000oooooooo0:coool003goool00ol0VOooooooo`0Woooo00<0000co`0co`001c?o00030000
oooooooo0:coool003goool00ol0VOooooooo`0Woooo0P0000Pco`000`000?ooooooo`2/oooo000m
oooo00?o09Woooooool09oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000moooo00?o
09Woooooool09oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000moooo00?o09Wooooo
ool09oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000moooo00?o09Woooooool09ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000moooo00?o09Woooooool08Oooo`<00003
oooo00<0000co`0co`001c?o00030000oooooooo0:coool003goool00ol0VOooooooo`0Roooo00<0
003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000moooo00?o09Wooooo
ool07oooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001Ooooo00@0003oooooool00004
oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_
oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06oooo00<0003oooooool0;_oo
o`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo00Soool00`000?ooooooo`0U
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000Coool200000oooo`@00003oooo00<0003oooooool0MOoo
o`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool00`000?oo
ooooo`04oooo00<0003oooooool0MOooo`00Ioooo`Tco`04oooo00<0003oooooool00_ooo`030000
oooooooo01?oool010000?ooooooo`0000_oool01@000?ooooooooooo`000006oooo00<0003ooooo
ool0M?ooo`00Ioooo`Tco`05oooo00<0003oooooool01@0001;oool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo00;oool00`000?ooooooo`1eoooo001Woooo2C?o00Goool01@000?oo
ooooooooo`00000Eoooo00@0003oooooool00009oooo00<0003oooooool00_ooo`040000oooooooo
00000oooo`030000oooooooo07Goool006Ooool9<ol01_ooo`030000oooooooo01Ooool200002_oo
o`<00003oooo0P0000?oool00`000?ooooooo`1foooo001Woooo2C?o0;3oool006Ooool8<ol0/Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.17277 .12361 L
.17735 .12361 L
.17986 .12361 L
.18109 .12361 L
.18221 .12361 L
s
.18221 .12361 m
.18269 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol0400001Woool00`000?oo
ooooo`0Voooo00<0003oooooool05Oooo`00?_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0017
<ol01@0006[oool003koool00ol0VOooooooo`0Voooo00<0000co`0co`00@S?o00D0001_oooo000n
oooo00?o09Woooooool09_ooo`030000<ol0<ol003dco`050000M?ooo`00?_ooo`03o`2Ioooooooo
02Koool00`0003?o03?o000i<ol0100007Woool003koool00ol0VOooooooo`0Voooo0P0003Pco`02
0000OOooo`00?_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000e<ol00P0007ooool003koool0
0ol0VOooooooo`0Voooo00<0000co`0co`00<c?o00800021oooo000noooo00?o09Woooooool09_oo
o`030000<ol0<ol0034co`020000Poooo`00?_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000`
<ol000<0003oooooool0Poooo`00?_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000^<ol00P00
08Koool003koool00ol0VOooooooo`0Voooo0P0002dco`020000R?ooo`00?_ooo`03o`2Ioooooooo
02Koool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00?_ooo`03o`2Ioooooooo02Koool0
0`0003?o03?o000Z<ol000<0003oooooool0ROooo`00?_ooo`03o`2Ioooooooo02Koool00`0003?o
03?o000Y<ol000<0003oooooool0R_ooo`00?_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000X
<ol000<0003oooooool0Roooo`00?_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000X<ol000<0
003oooooool0Roooo`00?_ooo`03o`2Ioooooooo02Koool20000:3?o00030000oooooooo08coool0
03koool00ol0VOooooooo`0Voooo00<0000co`0co`009S?o00030000oooooooo08goool003koool0
0ol0VOooooooo`0Voooo00<0000co`0co`009C?o00030000oooooooo08koool003koool00ol0VOoo
ooooo`0Voooo00<0000co`0co`0093?o00030000oooooooo08ooool003koool00ol0VOooooooo`0V
oooo00<0000co`0co`008c?o00030000oooooooo093oool003koool00ol0VOooooooo`0Voooo00<0
000co`0co`008c?o00030000oooooooo093oool003koool00ol0VOooooooo`0Voooo0P0002<co`00
0`000?ooooooo`2Aoooo000noooo00?o09Woooooool09_ooo`030000<ol0<ol0024co`000`000?oo
ooooo`2Boooo000noooo00?o09Woooooool09_ooo`030000<ol0<ol0020co`000`000?ooooooo`2C
oooo000noooo00?o09Woooooool09_ooo`030000<ol0<ol0020co`000`000?ooooooo`2Coooo000n
oooo00?o09Woooooool09_ooo`030000<ol0<ol001lco`000`000?ooooooo`2Doooo000noooo00?o
09Woooooool07_ooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo09Coool003koool0
0ol0VOooooooo`0Poooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`2E
oooo000noooo00?o09Woooooool08?ooo`030000oooooooo00?oool200007c?o00030000oooooooo
09Goool003koool00ol0VOooooooo`0Poooo00<0003oooooool00oooo`030000<ol0<ol001dco`00
0`000?ooooooo`2Foooo000noooo00?o09Woooooool08?ooo`030000oooooooo00?oool00`0003?o
03?o000M<ol000<0003oooooool0U_ooo`00?_ooo`03o`2Ioooooooo01ooool200001Oooo`030000
<ol0<ol001`co`000`000?ooooooo`2Goooo000noooo00?o09Woooooool09_ooo`030000<ol0<ol0
01`co`000`000?ooooooo`2Goooo000noooo00?o09Woooooool09_ooo`030000<ol0<ol001/co`00
0`000?ooooooo`2Hoooo000noooo00?o09Woooooool09_ooo`80000L<ol000<0003oooooool0V?oo
o`00?_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000J<ol000<0003oooooool0VOooo`00?_oo
o`03o`2Ioooooooo02Koool00`0003?o03?o000J<ol000<0003oooooool0VOooo`00?_ooo`03o`2I
oooooooo02Koool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00?_ooo`03o`2Ioooooooo
02Koool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00?_ooo`03o`2Ioooooooo02Koool0
0`0003?o03?o000H<ol000<0003oooooool0Voooo`00?_ooo`03o`2Ioooooooo02Koool200006C?o
00030000oooooooo09_oool003koool00ol0VOooooooo`0Voooo00<0000co`0co`005c?o00030000
oooooooo09coool003koool00ol0VOooooooo`0Voooo00<0000co`0co`005c?o00030000oooooooo
09coool003koool00ol0VOooooooo`0Voooo00<0000co`0co`005S?o00030000oooooooo09goool0
03koool00ol0VOooooooo`0Voooo00<0000co`0co`005S?o00030000oooooooo09goool003koool0
0ol0VOooooooo`0Voooo00<0000co`0co`005S?o00030000oooooooo09goool003koool00ol0VOoo
ooooo`0Voooo00<0000co`0co`005C?o00030000oooooooo09koool003koool00ol0VOooooooo`0V
oooo0P0001Hco`000`000?ooooooo`2Noooo000noooo00?o09Woooooool09_ooo`030000<ol0<ol0
01Dco`000`000?ooooooo`2Noooo000noooo00?o09Woooooool09_ooo`030000<ol0<ol001Dco`00
0`000?ooooooo`2Noooo000noooo00?o09Woooooool09_ooo`030000<ol0<ol001@co`000`000?oo
ooooo`2Ooooo000noooo00?o09Woooooool09_ooo`030000<ol0<ol001@co`000`000?ooooooo`2O
oooo000noooo00?o09Woooooool09_ooo`030000<ol0<ol001@co`000`000?ooooooo`2Ooooo000n
oooo00?o09Woooooool09_ooo`80000E<ol000<0003oooooool0Woooo`00?_ooo`03o`2Ioooooooo
02Koool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00?_ooo`03o`2Ioooooooo02Koool0
0`0003?o03?o000C<ol000<0003oooooool0X?ooo`00?_ooo`03o`2Ioooooooo02Koool00`0003?o
03?o000C<ol000<0003oooooool0X?ooo`00?_ooo`03o`2Ioooooooo01koool400001?ooo`030000
<ol0<ol001<co`000`000?ooooooo`2Poooo000noooo00?o09Woooooool07_ooo`030000oooooooo
00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00?_ooo`03o`2Ioooooooo01ooool0
0`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo000ooooo00?o09Woooooool07ooo
o`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00?oooo`03o`2I
oooooooo01goool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool0X_oo
o`00?oooo`03o`2Ioooooooo01koool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`2R
oooo000ooooo00?o09Woooooool09Oooo`030000<ol0<ol0014co`000`000?ooooooo`2Roooo000o
oooo00?o09Woooooool09Oooo`030000<ol0<ol0014co`000`000?ooooooo`2Roooo000ooooo00?o
09Woooooool09Oooo`80000A<ol000<0003oooooool0Xoooo`00?oooo`03o`2Ioooooooo02Goool0
0`0003?o03?o000@<ol000<0003oooooool0Xoooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o
03?o000@<ol000<0003oooooool0Xoooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o000@
<ol000<0003oooooool0Xoooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o000?<ol000<0
003oooooool0Y?ooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o000?<ol000<0003ooooo
ool0Y?ooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o000?<ol000<0003oooooool0Y?oo
o`00?oooo`03o`2Ioooooooo02Goool2000043?o00030000oooooooo0:Coool003ooool00ol0VOoo
ooooo`0Uoooo00<0000co`0co`003S?o00030000oooooooo0:Goool003ooool00ol0VOooooooo`0U
oooo00<0000co`0co`003S?o00030000oooooooo0:Goool003ooool00ol0VOooooooo`0Uoooo00<0
000co`0co`003S?o00030000oooooooo0:Goool003ooool00ol0VOooooooo`0Uoooo00<0000co`0c
o`003S?o00030000oooooooo0:Goool003ooool00ol0VOooooooo`0Uoooo00<0000co`0co`003C?o
00030000oooooooo0:Koool003ooool00ol0VOooooooo`0Uoooo0P0000hco`000`000?ooooooo`2V
oooo000ooooo00?o09Woooooool09Oooo`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000o
oooo00?o09Woooooool09Oooo`030000<ol0<ol000dco`000`000?ooooooo`2Voooo000ooooo00?o
09Woooooool09Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000ooooo00?o09Wooooo
ool09Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000ooooo00?o09Woooooool09Ooo
o`030000<ol0<ol000`co`000`000?ooooooo`2Woooo000ooooo00?o09Woooooool09Oooo`80000=
<ol000<0003oooooool0Yoooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o000<<ol000<0
003oooooool0Yoooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o000<<ol000<0003ooooo
ool0Yoooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o000;<ol000<0003oooooool0Z?oo
o`00?oooo`03o`2Ioooooooo01koool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`2X
oooo000ooooo00?o09Woooooool07Oooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`2Xoooo000ooooo00?o09Woooooool07oooo`030000oooooooo00?oool2000033?o
00030000oooooooo0:Soool003ooool00ol0VOooooooo`0Poooo00<0003oooooool00_ooo`030000
<ol0<ol000/co`000`000?ooooooo`2Xoooo000ooooo00?o09Woooooool07Oooo`040000oooooooo
00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo000ooooo00?o09Woooooool07_oo
o`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool003ooool00ol0VOooooooo`0U
oooo00<0000co`0co`002S?o00030000oooooooo0:Woool003ooool00ol0VOooooooo`0Uoooo00<0
000co`0co`002S?o00030000oooooooo0:Woool003ooool00ol0VOooooooo`0Uoooo00<0000co`0c
o`002S?o00030000oooooooo0:Woool003ooool00ol0VOooooooo`0Uoooo0P0000/co`000`000?oo
ooooo`2Yoooo000ooooo00?o09Woooooool09Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Y
oooo000ooooo00?o09Woooooool09Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000o
oooo00?o09Woooooool09Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000ooooo00?o
09Woooooool09Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000ooooo00?o09Wooooo
ool09Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo000ooooo00?o09Woooooool09Ooo
o`80000:<ol000<0003oooooool0Z_ooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o0009
<ol000<0003oooooool0Z_ooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o0008<ol000<0003ooooo
ool0Zoooo`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o0008<ol000<0003oooooool0Zooo
o`00?oooo`03o`2Ioooooooo02Goool00`0003?o03?o0008<ol000<0003oooooool0Zoooo`00?ooo
o`03o`2Ioooooooo02Goool200002C?o00030000oooooooo0:_oool003ooool00ol0VOooooooo`0U
oooo00<0000co`0co`0023?o00030000oooooooo0:_oool003ooool00ol0VOooooooo`0Uoooo00<0
000co`0co`0023?o00030000oooooooo0:_oool003ooool00ol0VOooooooo`0Uoooo00<0000co`0c
o`001c?o00030000oooooooo0:coool003ooool00ol0VOooooooo`0Uoooo00<0000co`0co`001c?o
00030000oooooooo0:coool003ooool00ol0VOooooooo`0Uoooo00<0000co`0co`001c?o00030000
oooooooo0:coool003ooool00ol0VOooooooo`0Uoooo0P0000Pco`000`000?ooooooo`2/oooo000o
oooo00?o09Woooooool09Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000ooooo00?o
09Woooooool09Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000ooooo00?o09Wooooo
ool09Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000ooooo00?o09Woooooool09Ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000ooooo00?o09Woooooool07oooo`<00003
oooo00<0000co`0co`001c?o00030000oooooooo0:coool003ooool00ol0VOooooooo`0Poooo00<0
003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo000ooooo00?o09Wooooo
ool07Oooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001Ooooo00@0003oooooool00004
oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_
oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?oo
o`030000oooooooo07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool006Ooool9
<ol02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003ooooo
ool01@0001;oool010000?ooooooo`0000Woool200001?ooo`030000oooooooo07Soool006Ooool9
<ol02?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooooooo`03
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool05oooo`80000:oooo0`00
00;oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.17277 .12361 L
.18221 .12361 L
.18475 .12361 L
.18614 .12361 L
.18744 .12361 L
.18855 .12361 L
s
.18855 .12361 m
.18902 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
09T01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003ooooo09T09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol0400001Woool00`000?oo
ooooo`0Voooo00<0003oooooool05Oooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o0017
<ol01@0006[oool0043oool00ol0VOooooooo`0Toooo00<0000co`0co`00@S?o00D0001_oooo0010
oooo00?o09Woooooool09?ooo`030000<ol0<ol003dco`050000M?ooo`00@?ooo`03o`2Ioooooooo
02Coool00`0003?o03?o000i<ol0100007Woool0043oool00ol0VOooooooo`0Toooo0P0003Pco`02
0000OOooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000e<ol00P0007ooool0043oool0
0ol0VOooooooo`0Toooo00<0000co`0co`00<c?o00800021oooo0010oooo00?o09Woooooool09?oo
o`030000<ol0<ol0034co`020000Poooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000`
<ol000<0003oooooool0Poooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000^<ol00P00
08Koool0043oool00ol0VOooooooo`0Toooo0P0002dco`020000R?ooo`00@?ooo`03o`2Ioooooooo
02Coool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00@?ooo`03o`2Ioooooooo02Coool0
0`0003?o03?o000Z<ol000<0003oooooool0ROooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o
03?o000Y<ol000<0003oooooool0R_ooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000X
<ol000<0003oooooool0Roooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000X<ol000<0
003oooooool0Roooo`00@?ooo`03o`2Ioooooooo02Coool20000:3?o00030000oooooooo08coool0
043oool00ol0VOooooooo`0Toooo00<0000co`0co`009S?o00030000oooooooo08goool0043oool0
0ol0VOooooooo`0Toooo00<0000co`0co`009C?o00030000oooooooo08koool0043oool00ol0VOoo
ooooo`0Toooo00<0000co`0co`0093?o00030000oooooooo08ooool0043oool00ol0VOooooooo`0T
oooo00<0000co`0co`008c?o00030000oooooooo093oool0043oool00ol0VOooooooo`0Toooo00<0
000co`0co`008c?o00030000oooooooo093oool0043oool00ol0VOooooooo`0Toooo0P0002<co`00
0`000?ooooooo`2Aoooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol0024co`000`000?oo
ooooo`2Boooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol0020co`000`000?ooooooo`2C
oooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol0020co`000`000?ooooooo`2Coooo0010
oooo00?o09Woooooool09?ooo`030000<ol0<ol001lco`000`000?ooooooo`2Doooo0010oooo00?o
09Woooooool07?ooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo09Coool0043oool0
0ol0VOooooooo`0Noooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`2E
oooo0010oooo00?o09Woooooool07_ooo`030000oooooooo00?oool200007c?o00030000oooooooo
09Goool0043oool00ol0VOooooooo`0Noooo00<0003oooooool00oooo`030000<ol0<ol001dco`00
0`000?ooooooo`2Foooo0010oooo00?o09Woooooool07_ooo`030000oooooooo00?oool00`0003?o
03?o000M<ol000<0003oooooool0U_ooo`00@?ooo`03o`2Ioooooooo01goool200001Oooo`030000
<ol0<ol001`co`000`000?ooooooo`2Goooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol0
01`co`000`000?ooooooo`2Goooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol001/co`00
0`000?ooooooo`2Hoooo0010oooo00?o09Woooooool09?ooo`80000L<ol000<0003oooooool0V?oo
o`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000J<ol000<0003oooooool0VOooo`00@?oo
o`03o`2Ioooooooo02Coool00`0003?o03?o000J<ol000<0003oooooool0VOooo`00@?ooo`03o`2I
oooooooo02Coool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00@?ooo`03o`2Ioooooooo
02Coool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00@?ooo`03o`2Ioooooooo02Coool0
0`0003?o03?o000H<ol000<0003oooooool0Voooo`00@?ooo`03o`2Ioooooooo02Coool200006C?o
00030000oooooooo09_oool0043oool00ol0VOooooooo`0Toooo00<0000co`0co`005c?o00030000
oooooooo09coool0043oool00ol0VOooooooo`0Toooo00<0000co`0co`005c?o00030000oooooooo
09coool0043oool00ol0VOooooooo`0Toooo00<0000co`0co`005S?o00030000oooooooo09goool0
043oool00ol0VOooooooo`0Toooo00<0000co`0co`005S?o00030000oooooooo09goool0043oool0
0ol0VOooooooo`0Toooo00<0000co`0co`005S?o00030000oooooooo09goool0043oool00ol0VOoo
ooooo`0Toooo00<0000co`0co`005C?o00030000oooooooo09koool0043oool00ol0VOooooooo`0T
oooo0P0001Hco`000`000?ooooooo`2Noooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol0
01Dco`000`000?ooooooo`2Noooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol001Dco`00
0`000?ooooooo`2Noooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol001@co`000`000?oo
ooooo`2Ooooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol001@co`000`000?ooooooo`2O
oooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol001@co`000`000?ooooooo`2Ooooo0010
oooo00?o09Woooooool09?ooo`80000E<ol000<0003oooooool0Woooo`00@?ooo`03o`2Ioooooooo
02Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00@?ooo`03o`2Ioooooooo02Coool0
0`0003?o03?o000C<ol000<0003oooooool0X?ooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o
03?o000C<ol000<0003oooooool0X?ooo`00@?ooo`03o`2Ioooooooo01coool400001?ooo`030000
<ol0<ol001<co`000`000?ooooooo`2Poooo0010oooo00?o09Woooooool07?ooo`030000oooooooo
00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00@?ooo`03o`2Ioooooooo01goool0
0`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo0010oooo00?o09Woooooool07_oo
o`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00@?ooo`03o`2I
oooooooo01coool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool0X_oo
o`00@?ooo`03o`2Ioooooooo01goool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`2R
oooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol0014co`000`000?ooooooo`2Roooo0010
oooo00?o09Woooooool09?ooo`030000<ol0<ol0014co`000`000?ooooooo`2Roooo0010oooo00?o
09Woooooool09?ooo`80000A<ol000<0003oooooool0Xoooo`00@?ooo`03o`2Ioooooooo02Coool0
0`0003?o03?o000@<ol000<0003oooooool0Xoooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o
03?o000@<ol000<0003oooooool0Xoooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000@
<ol000<0003oooooool0Xoooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000?<ol000<0
003oooooool0Y?ooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000?<ol000<0003ooooo
ool0Y?ooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000?<ol000<0003oooooool0Y?oo
o`00@?ooo`03o`2Ioooooooo02Coool2000043?o00030000oooooooo0:Coool0043oool00ol0VOoo
ooooo`0Toooo00<0000co`0co`003S?o00030000oooooooo0:Goool0043oool00ol0VOooooooo`0T
oooo00<0000co`0co`003S?o00030000oooooooo0:Goool0043oool00ol0VOooooooo`0Toooo00<0
000co`0co`003S?o00030000oooooooo0:Goool0043oool00ol0VOooooooo`0Toooo00<0000co`0c
o`003S?o00030000oooooooo0:Goool0043oool00ol0VOooooooo`0Toooo00<0000co`0co`003C?o
00030000oooooooo0:Koool0043oool00ol0VOooooooo`0Toooo0P0000hco`000`000?ooooooo`2V
oooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol000dco`000`000?ooooooo`2Voooo0010
oooo00?o09Woooooool09?ooo`030000<ol0<ol000dco`000`000?ooooooo`2Voooo0010oooo00?o
09Woooooool09?ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo0010oooo00?o09Wooooo
ool09?ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo0010oooo00?o09Woooooool09?oo
o`030000<ol0<ol000`co`000`000?ooooooo`2Woooo0010oooo00?o09Woooooool09?ooo`80000=
<ol000<0003oooooool0Yoooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000<<ol000<0
003oooooool0Yoooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000<<ol000<0003ooooo
ool0Yoooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000;<ol000<0003oooooool0Z?oo
o`00@?ooo`03o`2Ioooooooo01goool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`2X
oooo0010oooo00?o09Woooooool07?ooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`2Xoooo0010oooo00?o09Woooooool07_ooo`030000oooooooo00?oool2000033?o
00030000oooooooo0:Soool0043oool00ol0VOooooooo`0Ooooo00<0003oooooool00_ooo`030000
<ol0<ol000/co`000`000?ooooooo`2Xoooo0010oooo00?o09Woooooool07?ooo`040000oooooooo
00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo0010oooo00?o09Woooooool07Ooo
o`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0043oool00ol0VOooooooo`0T
oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0043oool00ol0VOooooooo`0Toooo00<0
000co`0co`002S?o00030000oooooooo0:Woool0043oool00ol0VOooooooo`0Toooo00<0000co`0c
o`002S?o00030000oooooooo0:Woool0043oool00ol0VOooooooo`0Toooo0P0000/co`000`000?oo
ooooo`2Yoooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Y
oooo0010oooo00?o09Woooooool09?ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo0010
oooo00?o09Woooooool09?ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo0010oooo00?o
09Woooooool09?ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo0010oooo00?o09Wooooo
ool09?ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo0010oooo00?o09Woooooool09?oo
o`80000:<ol000<0003oooooool0Z_ooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o0009
<ol000<0003oooooool0Z_ooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o0008<ol000<0003ooooo
ool0Zoooo`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o0008<ol000<0003oooooool0Zooo
o`00@?ooo`03o`2Ioooooooo02Coool00`0003?o03?o0008<ol000<0003oooooool0Zoooo`00@?oo
o`03o`2Ioooooooo02Coool200002C?o00030000oooooooo0:_oool0043oool00ol0VOooooooo`0T
oooo00<0000co`0co`0023?o00030000oooooooo0:_oool0043oool00ol0VOooooooo`0Toooo00<0
000co`0co`0023?o00030000oooooooo0:_oool0043oool00ol0VOooooooo`0Toooo00<0000co`0c
o`001c?o00030000oooooooo0:coool0043oool00ol0VOooooooo`0Toooo00<0000co`0co`001c?o
00030000oooooooo0:coool0043oool00ol0VOooooooo`0Toooo00<0000co`0co`001c?o00030000
oooooooo0:coool0043oool00ol0VOooooooo`0Toooo0P0000Pco`000`000?ooooooo`2/oooo0010
oooo00?o09Woooooool09?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0010oooo00?o
09Woooooool09?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0010oooo00?o09Wooooo
ool09?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0010oooo00?o09Woooooool09?oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0010oooo00?o09Woooooool07_ooo`<00003
oooo00<0000co`0co`001c?o00030000oooooooo0:coool0043oool00ol0VOooooooo`0Ooooo00<0
003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0010oooo00?o09Wooooo
ool07?ooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001Ooooo00@0003oooooool00004
oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_
oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06oooo00<0003oooooool0;_oo
o`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo00Soool00`000?ooooooo`0U
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000Goool300000_ooo`800004oooo00<0003oooooool0MOoo
o`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`04oooo100000?oool010000?ooooooo`0000_oool010000?ooooooo`0000;oool01@000?oo
ooooooooo`00001goooo001Woooo2C?o00Coool00`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000oooooooo00002?ooo`D000001Oooo`000?ooooooo`000004oooo00<0003oooooool0M?oo
o`00Ioooo`Tco`05oooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool200001?ooo`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooo
oooo000001Goool010000?ooooooo`0000Woool00`000?ooo`000002oooo00@0003oooooool00003
oooo00<0003oooooool0MOooo`00Ioooo`Tco`06oooo00<0003oooooool05oooo`80000;oooo0P00
00?oool200000oooo`030000oooooooo07Koool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.18221 .12361 L
.18703 .12361 L
.18957 .12361 L
.19227 .12361 L
.1934 .12361 L
.19462 .12361 L
s
.19462 .12361 m
.1949 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00D0003ooooo
oooooooo09T01?ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0U
oooo00D0003ooooooooooooo09T09?ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol04000
01Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00@_ooo`03o`2Ioooooooo02;oool0
0`0003?o03?o0017<ol01@0006[oool004;oool00ol0VOooooooo`0Roooo00<0000co`0co`00@S?o
00D0001_oooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol003dco`050000M?ooo`00@_oo
o`03o`2Ioooooooo02;oool00`0003?o03?o000i<ol0100007Woool004;oool00ol0VOooooooo`0R
oooo0P0003Pco`020000OOooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o000e<ol00P00
07ooool004;oool00ol0VOooooooo`0Roooo00<0000co`0co`00<c?o00800021oooo0012oooo00?o
09Woooooool08_ooo`030000<ol0<ol0034co`020000Poooo`00@_ooo`03o`2Ioooooooo02;oool0
0`0003?o03?o000`<ol000<0003oooooool0Poooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o
03?o000^<ol00P0008Koool004;oool00ol0VOooooooo`0Roooo0P0002dco`020000R?ooo`00@_oo
o`03o`2Ioooooooo02;oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00@_ooo`03o`2I
oooooooo02;oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`00@_ooo`03o`2Ioooooooo
02;oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`00@_ooo`03o`2Ioooooooo02;oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o
03?o000X<ol000<0003oooooool0Roooo`00@_ooo`03o`2Ioooooooo02;oool20000:3?o00030000
oooooooo08coool004;oool00ol0VOooooooo`0Roooo00<0000co`0co`009S?o00030000oooooooo
08goool004;oool00ol0VOooooooo`0Roooo00<0000co`0co`009C?o00030000oooooooo08koool0
04;oool00ol0VOooooooo`0Roooo00<0000co`0co`0093?o00030000oooooooo08ooool004;oool0
0ol0VOooooooo`0Roooo00<0000co`0co`008c?o00030000oooooooo093oool004;oool00ol0VOoo
ooooo`0Roooo00<0000co`0co`008c?o00030000oooooooo093oool004;oool00ol0VOooooooo`0R
oooo0P0002<co`000`000?ooooooo`2Aoooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol0
024co`000`000?ooooooo`2Boooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol0020co`000`000?oo
ooooo`2Coooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol001lco`000`000?ooooooo`2D
oooo0012oooo00?o09Woooooool06_ooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo
09Coool004;oool00ol0VOooooooo`0Loooo00<0003oooooool00oooo`030000<ol0<ol001hco`00
0`000?ooooooo`2Eoooo0012oooo00?o09Woooooool07?ooo`030000oooooooo00?oool200007c?o
00030000oooooooo09Goool004;oool00ol0VOooooooo`0Loooo00<0003oooooool00oooo`030000
<ol0<ol001dco`000`000?ooooooo`2Foooo0012oooo00?o09Woooooool07?ooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00@_ooo`03o`2Ioooooooo01_oool2
00001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo0012oooo00?o09Woooooool08_oo
o`030000<ol0<ol001`co`000`000?ooooooo`2Goooo0012oooo00?o09Woooooool08_ooo`030000
<ol0<ol001/co`000`000?ooooooo`2Hoooo0012oooo00?o09Woooooool08_ooo`80000L<ol000<0
003oooooool0V?ooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o000J<ol000<0003oooooool0VOoo
o`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00@_oo
o`03o`2Ioooooooo02;oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00@_ooo`03o`2I
oooooooo02;oool00`0003?o03?o000H<ol000<0003oooooool0Voooo`00@_ooo`03o`2Ioooooooo
02;oool200006C?o00030000oooooooo09_oool004;oool00ol0VOooooooo`0Roooo00<0000co`0c
o`005c?o00030000oooooooo09coool004;oool00ol0VOooooooo`0Roooo00<0000co`0co`005c?o
00030000oooooooo09coool004;oool00ol0VOooooooo`0Roooo00<0000co`0co`005S?o00030000
oooooooo09goool004;oool00ol0VOooooooo`0Roooo00<0000co`0co`005S?o00030000oooooooo
09goool004;oool00ol0VOooooooo`0Roooo00<0000co`0co`005S?o00030000oooooooo09goool0
04;oool00ol0VOooooooo`0Roooo00<0000co`0co`005C?o00030000oooooooo09koool004;oool0
0ol0VOooooooo`0Roooo0P0001Hco`000`000?ooooooo`2Noooo0012oooo00?o09Woooooool08_oo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo0012oooo00?o09Woooooool08_ooo`030000
<ol0<ol001Dco`000`000?ooooooo`2Noooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol001@co`000`000?oo
ooooo`2Ooooo0012oooo00?o09Woooooool08_ooo`80000E<ol000<0003oooooool0Woooo`00@_oo
o`03o`2Ioooooooo02;oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00@_ooo`03o`2I
oooooooo02;oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00@_ooo`03o`2Ioooooooo
02;oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00@_ooo`03o`2Ioooooooo01[oool4
00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo0012oooo00?o09Woooooool06_oo
o`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00@_ooo`03o`2I
oooooooo01_oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo0012oooo00?o
09Woooooool07?ooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0XOoo
o`00@_ooo`03o`2Ioooooooo01[oool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00@_ooo`03o`2Ioooooooo01_oool200001Oooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol0014co`000`000?ooooooo`2R
oooo0012oooo00?o09Woooooool08_ooo`80000A<ol000<0003oooooool0Xoooo`00@_ooo`03o`2I
oooooooo02;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00@_ooo`03o`2Ioooooooo
02;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00@_ooo`03o`2Ioooooooo02;oool0
0`0003?o03?o000@<ol000<0003oooooool0Xoooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o000?<ol000<0
003oooooool0Y?ooo`00@_ooo`03o`2Ioooooooo02;oool2000043?o00030000oooooooo0:Coool0
04;oool00ol0VOooooooo`0Roooo00<0000co`0co`003S?o00030000oooooooo0:Goool004;oool0
0ol0VOooooooo`0Roooo00<0000co`0co`003S?o00030000oooooooo0:Goool004;oool00ol0VOoo
ooooo`0Roooo00<0000co`0co`003S?o00030000oooooooo0:Goool004;oool00ol0VOooooooo`0R
oooo00<0000co`0co`003S?o00030000oooooooo0:Goool004;oool00ol0VOooooooo`0Roooo00<0
000co`0co`003C?o00030000oooooooo0:Koool004;oool00ol0VOooooooo`0Roooo0P0000hco`00
0`000?ooooooo`2Voooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol000dco`000`000?ooooooo`2V
oooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo0012
oooo00?o09Woooooool08_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo0012oooo00?o
09Woooooool08_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo0012oooo00?o09Wooooo
ool08_ooo`80000=<ol000<0003oooooool0Yoooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o000<
<ol000<0003oooooool0Yoooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o000;<ol000<0
003oooooool0Z?ooo`00@_ooo`03o`2Ioooooooo01_oool200001Oooo`030000<ol0<ol000/co`00
0`000?ooooooo`2Xoooo0012oooo00?o09Woooooool06_ooo`040000oooooooo00001?ooo`030000
<ol0<ol000/co`000`000?ooooooo`2Xoooo0012oooo00?o09Woooooool07?ooo`030000oooooooo
00?oool2000033?o00030000oooooooo0:Soool004;oool00ol0VOooooooo`0Moooo00<0003ooooo
ool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo0012oooo00?o09Woooooool06_oo
o`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo0012oooo00?o
09Woooooool06oooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool004;oool0
0ol0VOooooooo`0Roooo00<0000co`0co`002S?o00030000oooooooo0:Woool004;oool00ol0VOoo
ooooo`0Roooo00<0000co`0co`002S?o00030000oooooooo0:Woool004;oool00ol0VOooooooo`0R
oooo00<0000co`0co`002S?o00030000oooooooo0:Woool004;oool00ol0VOooooooo`0Roooo0P00
00/co`000`000?ooooooo`2Yoooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol000Xco`00
0`000?ooooooo`2Yoooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo0012
oooo00?o09Woooooool08_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo0012oooo00?o
09Woooooool08_ooo`80000:<ol000<0003oooooool0Z_ooo`00@_ooo`03o`2Ioooooooo02;oool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o
03?o0009<ol000<0003oooooool0Z_ooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`00@_ooo`03o`2Ioooooooo02;oool00`0003?o03?o0008<ol000<0003ooooo
ool0Zoooo`00@_ooo`03o`2Ioooooooo02;oool200002C?o00030000oooooooo0:_oool004;oool0
0ol0VOooooooo`0Roooo00<0000co`0co`0023?o00030000oooooooo0:_oool004;oool00ol0VOoo
ooooo`0Roooo00<0000co`0co`0023?o00030000oooooooo0:_oool004;oool00ol0VOooooooo`0R
oooo00<0000co`0co`001c?o00030000oooooooo0:coool004;oool00ol0VOooooooo`0Roooo00<0
000co`0co`001c?o00030000oooooooo0:coool004;oool00ol0VOooooooo`0Roooo00<0000co`0c
o`001c?o00030000oooooooo0:coool004;oool00ol0VOooooooo`0Roooo0P0000Pco`000`000?oo
ooooo`2/oooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo0012oooo00?o09Woooooool08_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0012
oooo00?o09Woooooool08_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0012oooo00?o
09Woooooool08_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0012oooo00?o09Wooooo
ool07?ooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool004;oool00ol0VOoo
ooooo`0Moooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0012
oooo00?o09Woooooool06_ooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001Ooooo00@0
003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool2
00001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06oooo00<0
003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo00Soool0
0`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Goool3000000Coool0000000000004
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000_oool010000?oo
ooooo`0000;oool01@000?ooooooooooo`00001goooo001Woooo2C?o00Coool00`000?ooooooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`D000001Oooo`000?ooooooo`000004
oooo00<0003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000Soool010000?ooooooo`0000;oool300001?ooo`030000oooooooo07Goool006Ooool9
<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooo`000003
oooo00<0003oooooool00oooo`030000oooooooo07Goool006Ooool9<ol01_ooo`030000oooooooo
01Ooool200002oooo`800003oooo0`0000;oool00`000?ooooooo`1foooo001Woooo2C?o0;3oool0
06Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.18221 .12361 L
.18703 .12361 L
.19227 .12361 L
.19467 .12361 L
.19721 .12361 L
.19939 .12361 L
.20062 .12361 L
s
.20062 .12361 m
.20109 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`05o`2Ioooooooooooo000000Ooool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0U
oooo00<0003oooooool00_ooo`03o`2Ioooooooo027oool00`0003?o03?o000U<ol000<0000co`0c
o`0093?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool004?oool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`00Ac?o00D0001Zoooo0013oooo00?o09Woooooool08Oooo`030000
<ol0<ol0048co`050000Koooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000m<ol01@00
07Coool004?oool00ol0VOooooooo`0Qoooo00<0000co`0co`00>C?o00@0001ioooo0013oooo00?o
09Woooooool08Oooo`80000h<ol00P0007goool004?oool00ol0VOooooooo`0Qoooo00<0000co`0c
o`00=C?o0080001ooooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol003<co`020000POoo
o`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000a<ol00P0008?oool004?oool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`00<3?o00030000oooooooo08?oool004?oool00ol0VOooooooo`0Q
oooo00<0000co`0co`00;S?o00800026oooo0013oooo00?o09Woooooool08Oooo`80000]<ol00P00
08Soool004?oool00ol0VOooooooo`0Qoooo00<0000co`0co`00:c?o00030000oooooooo08Soool0
04?oool00ol0VOooooooo`0Qoooo00<0000co`0co`00:S?o00030000oooooooo08Woool004?oool0
0ol0VOooooooo`0Qoooo00<0000co`0co`00:C?o00030000oooooooo08[oool004?oool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`00:3?o00030000oooooooo08_oool004?oool00ol0VOooooooo`0Q
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool004?oool00ol0VOooooooo`0Qoooo0P00
02Pco`000`000?ooooooo`2<oooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol002Hco`00
0`000?ooooooo`2=oooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol002Dco`000`000?oo
ooooo`2>oooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol002@co`000`000?ooooooo`2?
oooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo0013
oooo00?o09Woooooool08Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo0013oooo00?o
09Woooooool08Oooo`80000S<ol000<0003oooooool0TOooo`00@oooo`03o`2Ioooooooo027oool0
0`0003?o03?o000Q<ol000<0003oooooool0T_ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o
03?o000P<ol000<0003oooooool0Toooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000O<ol000<0
003oooooool0U?ooo`00@oooo`03o`2Ioooooooo01Woool500000oooo`030000<ol0<ol001lco`00
0`000?ooooooo`2Doooo0013oooo00?o09Woooooool06oooo`030000oooooooo00?oool00`0003?o
03?o000N<ol000<0003oooooool0UOooo`00@oooo`03o`2Ioooooooo01_oool00`000?ooooooo`03
oooo0P0001lco`000`000?ooooooo`2Eoooo0013oooo00?o09Woooooool06oooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00@oooo`03o`2Ioooooooo01_oool0
0`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool004?oool00ol0VOoo
ooooo`0Joooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00@oooo`03o`2I
oooooooo027oool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00@oooo`03o`2Ioooooooo
027oool00`0003?o03?o000K<ol000<0003oooooool0V?ooo`00@oooo`03o`2Ioooooooo027oool2
000073?o00030000oooooooo09Soool004?oool00ol0VOooooooo`0Qoooo00<0000co`0co`006S?o
00030000oooooooo09Woool004?oool00ol0VOooooooo`0Qoooo00<0000co`0co`006S?o00030000
oooooooo09Woool004?oool00ol0VOooooooo`0Qoooo00<0000co`0co`006C?o00030000oooooooo
09[oool004?oool00ol0VOooooooo`0Qoooo00<0000co`0co`006C?o00030000oooooooo09[oool0
04?oool00ol0VOooooooo`0Qoooo00<0000co`0co`0063?o00030000oooooooo09_oool004?oool0
0ol0VOooooooo`0Qoooo0P0001Tco`000`000?ooooooo`2Koooo0013oooo00?o09Woooooool08Ooo
o`030000<ol0<ol001Lco`000`000?ooooooo`2Loooo0013oooo00?o09Woooooool08Oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`2Moooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol001Dco`000`000?ooooooo`2N
oooo0013oooo00?o09Woooooool08Oooo`80000F<ol000<0003oooooool0W_ooo`00@oooo`03o`2I
oooooooo027oool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00@oooo`03o`2Ioooooooo
027oool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00@oooo`03o`2Ioooooooo027oool0
0`0003?o03?o000D<ol000<0003oooooool0Woooo`00@oooo`03o`2Ioooooooo027oool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00@oooo`03o`2Ioooooooo027oool200005C?o00030000oooooooo
09ooool004?oool00ol0VOooooooo`0Qoooo00<0000co`0co`004c?o00030000oooooooo0:3oool0
04?oool00ol0VOooooooo`0Qoooo00<0000co`0co`004c?o00030000oooooooo0:3oool004?oool0
0ol0VOooooooo`0Qoooo00<0000co`0co`004c?o00030000oooooooo0:3oool004?oool00ol0VOoo
ooooo`0Ioooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00@oooo`03o`2I
oooooooo01Woool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool0
04?oool00ol0VOooooooo`0Joooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOoo
o`00@oooo`03o`2Ioooooooo01_oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000
oooooooo0:7oool004?oool00ol0VOooooooo`0Ioooo00@0003oooooool00004oooo00<0000co`0c
o`004C?o00030000oooooooo0:;oool004?oool00ol0VOooooooo`0Joooo0P0000Goool00`0003?o
03?o000A<ol000<0003oooooool0X_ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00@oooo`03o`2Ioooooooo027oool200004C?o00030000oooooooo0:?oool0
04?oool00ol0VOooooooo`0Qoooo00<0000co`0co`0043?o00030000oooooooo0:?oool004?oool0
0ol0VOooooooo`0Qoooo00<0000co`0co`0043?o00030000oooooooo0:?oool004?oool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`0043?o00030000oooooooo0:?oool004?oool00ol0VOooooooo`0Q
oooo00<0000co`0co`003c?o00030000oooooooo0:Coool004?oool00ol0VOooooooo`0Qoooo00<0
000co`0co`003c?o00030000oooooooo0:Coool004?oool00ol0VOooooooo`0Qoooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool004?oool00ol0VOooooooo`0Qoooo0P00010co`000`000?oo
ooooo`2Toooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol000hco`000`000?ooooooo`2U
oooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0013
oooo00?o09Woooooool08Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0013oooo00?o
09Woooooool08Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0013oooo00?o09Wooooo
ool08Oooo`030000<ol0<ol000dco`000`000?ooooooo`2Voooo0013oooo00?o09Woooooool08Ooo
o`80000><ol000<0003oooooool0Y_ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000=
<ol000<0003oooooool0Y_ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000<<ol000<0003ooooo
ool0Yoooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00@ooo
o`03o`2Ioooooooo027oool200003C?o00030000oooooooo0:Ooool004?oool00ol0VOooooooo`0Q
oooo00<0000co`0co`0033?o00030000oooooooo0:Ooool004?oool00ol0VOooooooo`0Qoooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool004?oool00ol0VOooooooo`0Qoooo00<0000co`0c
o`002c?o00030000oooooooo0:Soool004?oool00ol0VOooooooo`0Joooo0P0000Goool00`0003?o
03?o000;<ol000<0003oooooool0Z?ooo`00@oooo`03o`2Ioooooooo01Woool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00@oooo`03o`2Ioooooooo01_oool0
0`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo0013oooo00?o09Woooooool07?oo
o`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00@oooo`03o`2I
oooooooo01Woool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?oo
o`00@oooo`03o`2Ioooooooo01[oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Y
oooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0013
oooo00?o09Woooooool08Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0013oooo00?o
09Woooooool08Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0013oooo00?o09Wooooo
ool08Oooo`80000;<ol000<0003oooooool0ZOooo`00@oooo`03o`2Ioooooooo027oool00`0003?o
03?o000:<ol000<0003oooooool0ZOooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o0009
<ol000<0003oooooool0Z_ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00@oooo`03o`2Ioooooooo027oool200002S?o00030000oooooooo0:[oool004?oool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`002C?o00030000oooooooo0:[oool004?oool00ol0VOooooooo`0Q
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool004?oool00ol0VOooooooo`0Qoooo00<0
000co`0co`0023?o00030000oooooooo0:_oool004?oool00ol0VOooooooo`0Qoooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool004?oool00ol0VOooooooo`0Qoooo00<0000co`0co`0023?o
00030000oooooooo0:_oool004?oool00ol0VOooooooo`0Qoooo0P0000Tco`000`000?ooooooo`2[
oooo0013oooo00?o09Woooooool08Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo0013
oooo00?o09Woooooool08Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo0013oooo00?o
09Woooooool08Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0013oooo00?o09Wooooo
ool08Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0013oooo00?o09Woooooool08Ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0013oooo00?o09Woooooool08Oooo`800008
<ol000<0003oooooool0[?ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o0007<ol000<0
003oooooool0[?ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00@oooo`03o`2Ioooooooo027oool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00@ooo
o`03o`2Ioooooooo01_oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0013
oooo00?o09Woooooool07?ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00@oooo`03o`2Ioooooooo01Woool500000oooo`800008<ol000<0003oooooool0[?oo
o`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_
oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9
<ol01_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?oo
ooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005oooo0`0000?oool3
00000_ooo`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool0000;oooo00<0
003oooooool00oooo`050000oooooooooooo000007Ooool006Ooool9<ol01?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool00008oooo1@000003oooo0000000000<00003
oooo00<0003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1e
oooo001Woooo2C?o00Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009oooo00<0
003oool000000oooo`030000oooo000000?oool00`000?ooooooo`1eoooo001Woooo2C?o00Koool0
0`000?ooooooo`0Goooo0P0000_oool200001?ooo`800002oooo00<0003oooooool0M_ooo`00Iooo
o`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.19227 .12361 L
.20178 .12361 L
.20433 .12361 L
.20573 .12361 L
.20704 .12361 L
.20772 .12361 L
s
.20772 .12361 m
.20801 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01?ooo`03o`2Ioooo000000Ooool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool01?ooo`03o`2Ioooooooo01ooool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool004Goool00ol0VOooooooo`0O
oooo00<0000co`0co`00Ac?o00D0001Zoooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol0
048co`050000Koooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000m<ol01@0007Coool0
04Goool00ol0VOooooooo`0Ooooo00<0000co`0co`00>C?o00@0001ioooo0015oooo00?o09Wooooo
ool07oooo`80000h<ol00P0007goool004Goool00ol0VOooooooo`0Ooooo00<0000co`0co`00=C?o
0080001ooooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol003<co`020000POooo`00AOoo
o`03o`2Ioooooooo01ooool00`0003?o03?o000a<ol00P0008?oool004Goool00ol0VOooooooo`0O
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool004Goool00ol0VOooooooo`0Ooooo00<0
000co`0co`00;S?o00800026oooo0015oooo00?o09Woooooool07oooo`80000]<ol00P0008Soool0
04Goool00ol0VOooooooo`0Ooooo00<0000co`0co`00:c?o00030000oooooooo08Soool004Goool0
0ol0VOooooooo`0Ooooo00<0000co`0co`00:S?o00030000oooooooo08Woool004Goool00ol0VOoo
ooooo`0Ooooo00<0000co`0co`00:C?o00030000oooooooo08[oool004Goool00ol0VOooooooo`0O
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool004Goool00ol0VOooooooo`0Ooooo00<0
000co`0co`00:3?o00030000oooooooo08_oool004Goool00ol0VOooooooo`0Ooooo0P0002Pco`00
0`000?ooooooo`2<oooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo0015
oooo00?o09Woooooool07oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo0015oooo00?o
09Woooooool07oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo0015oooo00?o09Wooooo
ool07oooo`80000S<ol000<0003oooooool0TOooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00AOooo`03o`2Ioooooooo01Ooool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo0015oooo00?o09Woooooool06Oooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00AOooo`03o`2Ioooooooo01Woool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo0015oooo00?o09Woooooool06Oooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00AOooo`03o`2Ioooooooo01Woool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool004Goool00ol0VOooooooo`0H
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00AOooo`03o`2Ioooooooo
01ooool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00AOooo`03o`2Ioooooooo01ooool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00AOooo`03o`2Ioooooooo01ooool2000073?o
00030000oooooooo09Soool004Goool00ol0VOooooooo`0Ooooo00<0000co`0co`006S?o00030000
oooooooo09Woool004Goool00ol0VOooooooo`0Ooooo00<0000co`0co`006S?o00030000oooooooo
09Woool004Goool00ol0VOooooooo`0Ooooo00<0000co`0co`006C?o00030000oooooooo09[oool0
04Goool00ol0VOooooooo`0Ooooo00<0000co`0co`006C?o00030000oooooooo09[oool004Goool0
0ol0VOooooooo`0Ooooo00<0000co`0co`0063?o00030000oooooooo09_oool004Goool00ol0VOoo
ooooo`0Ooooo0P0001Tco`000`000?ooooooo`2Koooo0015oooo00?o09Woooooool07oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo0015
oooo00?o09Woooooool07oooo`80000F<ol000<0003oooooool0W_ooo`00AOooo`03o`2Ioooooooo
01ooool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00AOooo`03o`2Ioooooooo01ooool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00AOooo`03o`2Ioooooooo01ooool200005C?o00030000oooooooo09ooool0
04Goool00ol0VOooooooo`0Ooooo00<0000co`0co`004c?o00030000oooooooo0:3oool004Goool0
0ol0VOooooooo`0Ooooo00<0000co`0co`004c?o00030000oooooooo0:3oool004Goool00ol0VOoo
ooooo`0Ooooo00<0000co`0co`004c?o00030000oooooooo0:3oool004Goool00ol0VOooooooo`0G
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00AOooo`03o`2Ioooooooo
01Ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool004Goool0
0ol0VOooooooo`0Hoooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00AOoo
o`03o`2Ioooooooo01Woool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool004Goool00ol0VOooooooo`0Goooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool004Goool00ol0VOooooooo`0Hoooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00AOooo`03o`2Ioooooooo01ooool200004C?o00030000oooooooo0:?oool004Goool0
0ol0VOooooooo`0Ooooo00<0000co`0co`0043?o00030000oooooooo0:?oool004Goool00ol0VOoo
ooooo`0Ooooo00<0000co`0co`0043?o00030000oooooooo0:?oool004Goool00ol0VOooooooo`0O
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool004Goool00ol0VOooooooo`0Ooooo00<0
000co`0co`003c?o00030000oooooooo0:Coool004Goool00ol0VOooooooo`0Ooooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool004Goool00ol0VOooooooo`0Ooooo00<0000co`0co`003c?o
00030000oooooooo0:Coool004Goool00ol0VOooooooo`0Ooooo0P00010co`000`000?ooooooo`2T
oooo0015oooo00?o09Woooooool07oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0015
oooo00?o09Woooooool07oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0015oooo00?o
09Woooooool07oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0015oooo00?o09Wooooo
ool07oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0015oooo00?o09Woooooool07ooo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo0015oooo00?o09Woooooool07oooo`80000>
<ol000<0003oooooool0Y_ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00AOoo
o`03o`2Ioooooooo01ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00AOooo`03o`2I
oooooooo01ooool200003C?o00030000oooooooo0:Ooool004Goool00ol0VOooooooo`0Ooooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool004Goool00ol0VOooooooo`0Ooooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool004Goool00ol0VOooooooo`0Ooooo00<0000co`0co`002c?o
00030000oooooooo0:Soool004Goool00ol0VOooooooo`0Hoooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00AOooo`03o`2Ioooooooo01Ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00AOooo`03o`2Ioooooooo01Woool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo0015oooo00?o09Woooooool06_ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00AOooo`03o`2Ioooooooo
01Ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00AOoo
o`03o`2Ioooooooo01Soool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0015
oooo00?o09Woooooool07oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0015oooo00?o
09Woooooool07oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0015oooo00?o09Wooooo
ool07oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0015oooo00?o09Woooooool07ooo
o`80000;<ol000<0003oooooool0ZOooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00AOoo
o`03o`2Ioooooooo01ooool200002S?o00030000oooooooo0:[oool004Goool00ol0VOooooooo`0O
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool004Goool00ol0VOooooooo`0Ooooo00<0
000co`0co`002C?o00030000oooooooo0:[oool004Goool00ol0VOooooooo`0Ooooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool004Goool00ol0VOooooooo`0Ooooo00<0000co`0co`0023?o
00030000oooooooo0:_oool004Goool00ol0VOooooooo`0Ooooo00<0000co`0co`0023?o00030000
oooooooo0:_oool004Goool00ol0VOooooooo`0Ooooo0P0000Tco`000`000?ooooooo`2[oooo0015
oooo00?o09Woooooool07oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo0015oooo00?o
09Woooooool07oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo0015oooo00?o09Wooooo
ool07oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0015oooo00?o09Woooooool07ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0015oooo00?o09Woooooool07oooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo0015oooo00?o09Woooooool07oooo`800008<ol000<0
003oooooool0[?ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00AOooo`03o`2Ioooooooo01ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00AOoo
o`03o`2Ioooooooo01ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00AOooo`03o`2I
oooooooo01Woool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0015oooo00?o
09Woooooool06_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00AOooo`03o`2Ioooooooo01Ooool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005oooo0`000003oooo00000000
00800003oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000_oool0
10000?ooooooo`0000Koool00`000?ooooooo`1eoooo001Woooo2C?o00Coool00`000?ooooooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`D00002oooo00<0003oooooool01?oo
o`030000oooooooo07Coool006Ooool9<ol01Oooo`030000oooooooo00D0000Boooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo07Goool0
06Ooool9<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?oo
o`000002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00Ioooo`Tco`06oooo00<0
003oooooool05oooo`80000;oooo0P0000?oool200000oooo`030000oooooooo07Koool006Ooool9
<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20178 .12361 L
.20742 .12361 L
.21019 .12361 L
.2114 .12361 L
.21274 .12361 L
.21394 .12361 L
s
.21394 .12361 m
.21439 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`03o`2I0000oooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool01Oooo`03o`2Ioooooooo01koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool004Koool00ol0VOooooooo`0N
oooo00<0000co`0co`00Ac?o00D0001Zoooo0016oooo00?o09Woooooool07_ooo`030000<ol0<ol0
048co`050000Koooo`00A_ooo`03o`2Ioooooooo01koool00`0003?o03?o000m<ol01@0007Coool0
04Koool00ol0VOooooooo`0Noooo00<0000co`0co`00>C?o00@0001ioooo0016oooo00?o09Wooooo
ool07_ooo`80000h<ol00P0007goool004Koool00ol0VOooooooo`0Noooo00<0000co`0co`00=C?o
0080001ooooo0016oooo00?o09Woooooool07_ooo`030000<ol0<ol003<co`020000POooo`00A_oo
o`03o`2Ioooooooo01koool00`0003?o03?o000a<ol00P0008?oool004Koool00ol0VOooooooo`0N
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool004Koool00ol0VOooooooo`0Noooo00<0
000co`0co`00;S?o00800026oooo0016oooo00?o09Woooooool07_ooo`80000]<ol00P0008Soool0
04Koool00ol0VOooooooo`0Noooo00<0000co`0co`00:c?o00030000oooooooo08Soool004Koool0
0ol0VOooooooo`0Noooo00<0000co`0co`00:S?o00030000oooooooo08Woool004Koool00ol0VOoo
ooooo`0Noooo00<0000co`0co`00:C?o00030000oooooooo08[oool004Koool00ol0VOooooooo`0N
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool004Koool00ol0VOooooooo`0Noooo00<0
000co`0co`00:3?o00030000oooooooo08_oool004Koool00ol0VOooooooo`0Noooo0P0002Pco`00
0`000?ooooooo`2<oooo0016oooo00?o09Woooooool07_ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo0016oooo00?o09Woooooool07_ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo0016oooo00?o09Woooooool07_ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo0016
oooo00?o09Woooooool07_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo0016oooo00?o
09Woooooool07_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo0016oooo00?o09Wooooo
ool07_ooo`80000S<ol000<0003oooooool0TOooo`00A_ooo`03o`2Ioooooooo01koool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00A_ooo`03o`2Ioooooooo01koool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00A_ooo`03o`2Ioooooooo01koool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00A_ooo`03o`2Ioooooooo01koool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00A_ooo`03o`2Ioooooooo01Koool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo0016oooo00?o09Woooooool06?ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00A_ooo`03o`2Ioooooooo01Soool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo0016oooo00?o09Woooooool06?ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00A_ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool004Koool00ol0VOooooooo`0G
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00A_ooo`03o`2Ioooooooo
01koool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00A_ooo`03o`2Ioooooooo01koool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00A_ooo`03o`2Ioooooooo01koool2000073?o
00030000oooooooo09Soool004Koool00ol0VOooooooo`0Noooo00<0000co`0co`006S?o00030000
oooooooo09Woool004Koool00ol0VOooooooo`0Noooo00<0000co`0co`006S?o00030000oooooooo
09Woool004Koool00ol0VOooooooo`0Noooo00<0000co`0co`006C?o00030000oooooooo09[oool0
04Koool00ol0VOooooooo`0Noooo00<0000co`0co`006C?o00030000oooooooo09[oool004Koool0
0ol0VOooooooo`0Noooo00<0000co`0co`0063?o00030000oooooooo09_oool004Koool00ol0VOoo
ooooo`0Noooo0P0001Tco`000`000?ooooooo`2Koooo0016oooo00?o09Woooooool07_ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo0016oooo00?o09Woooooool07_ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo0016oooo00?o09Woooooool07_ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo0016oooo00?o09Woooooool07_ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo0016oooo00?o09Woooooool07_ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo0016oooo00?o09Woooooool07_ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo0016
oooo00?o09Woooooool07_ooo`80000F<ol000<0003oooooool0W_ooo`00A_ooo`03o`2Ioooooooo
01koool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00A_ooo`03o`2Ioooooooo01koool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00A_ooo`03o`2Ioooooooo01koool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00A_ooo`03o`2Ioooooooo01koool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00A_ooo`03o`2Ioooooooo01koool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00A_ooo`03o`2Ioooooooo01koool200005C?o00030000oooooooo09ooool0
04Koool00ol0VOooooooo`0Noooo00<0000co`0co`004c?o00030000oooooooo0:3oool004Koool0
0ol0VOooooooo`0Noooo00<0000co`0co`004c?o00030000oooooooo0:3oool004Koool00ol0VOoo
ooooo`0Noooo00<0000co`0co`004c?o00030000oooooooo0:3oool004Koool00ol0VOooooooo`0F
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00A_ooo`03o`2Ioooooooo
01Koool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool004Koool0
0ol0VOooooooo`0Goooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00Aooo
o`03o`2Ioooooooo01Ooool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool004Ooool00ol0VOooooooo`0Eoooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool004Ooool00ol0VOooooooo`0Foooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00Aoooo`03o`2Ioooooooo01goool200004C?o00030000oooooooo0:?oool004Ooool0
0ol0VOooooooo`0Moooo00<0000co`0co`0043?o00030000oooooooo0:?oool004Ooool00ol0VOoo
ooooo`0Moooo00<0000co`0co`0043?o00030000oooooooo0:?oool004Ooool00ol0VOooooooo`0M
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool004Ooool00ol0VOooooooo`0Moooo00<0
000co`0co`003c?o00030000oooooooo0:Coool004Ooool00ol0VOooooooo`0Moooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool004Ooool00ol0VOooooooo`0Moooo00<0000co`0co`003c?o
00030000oooooooo0:Coool004Ooool00ol0VOooooooo`0Moooo0P00010co`000`000?ooooooo`2T
oooo0017oooo00?o09Woooooool07Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0017
oooo00?o09Woooooool07Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0017oooo00?o
09Woooooool07Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0017oooo00?o09Wooooo
ool07Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0017oooo00?o09Woooooool07Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo0017oooo00?o09Woooooool07Oooo`80000>
<ol000<0003oooooool0Y_ooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00Aooo
o`03o`2Ioooooooo01goool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00Aoooo`03o`2I
oooooooo01goool200003C?o00030000oooooooo0:Ooool004Ooool00ol0VOooooooo`0Moooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool004Ooool00ol0VOooooooo`0Moooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool004Ooool00ol0VOooooooo`0Moooo00<0000co`0co`002c?o
00030000oooooooo0:Soool004Ooool00ol0VOooooooo`0Foooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00Aoooo`03o`2Ioooooooo01Goool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Aoooo`03o`2Ioooooooo01Ooool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo0017oooo00?o09Woooooool06?ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Aoooo`03o`2Ioooooooo
01Goool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Aooo
o`03o`2Ioooooooo01Koool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0017
oooo00?o09Woooooool07Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0017oooo00?o
09Woooooool07Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0017oooo00?o09Wooooo
ool07Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0017oooo00?o09Woooooool07Ooo
o`80000;<ol000<0003oooooool0ZOooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00Aooo
o`03o`2Ioooooooo01goool200002S?o00030000oooooooo0:[oool004Ooool00ol0VOooooooo`0M
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool004Ooool00ol0VOooooooo`0Moooo00<0
000co`0co`002C?o00030000oooooooo0:[oool004Ooool00ol0VOooooooo`0Moooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool004Ooool00ol0VOooooooo`0Moooo00<0000co`0co`0023?o
00030000oooooooo0:_oool004Ooool00ol0VOooooooo`0Moooo00<0000co`0co`0023?o00030000
oooooooo0:_oool004Ooool00ol0VOooooooo`0Moooo0P0000Tco`000`000?ooooooo`2[oooo0017
oooo00?o09Woooooool07Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo0017oooo00?o
09Woooooool07Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo0017oooo00?o09Wooooo
ool07Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0017oooo00?o09Woooooool07Ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0017oooo00?o09Woooooool07Oooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo0017oooo00?o09Woooooool07Oooo`800008<ol000<0
003oooooool0[?ooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00Aoooo`03o`2Ioooooooo01goool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Aooo
o`03o`2Ioooooooo01goool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Aoooo`03o`2I
oooooooo01Ooool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0017oooo00?o
09Woooooool06?ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00Aoooo`03o`2Ioooooooo01Goool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Ooo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005oooo0`0000;oool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002oooo`050000oooooooooooo0000
07[oool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003ooooo
ool00008oooo1@0000?oool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`05
00004_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
06Ooool9<ol02?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?oo
o`000003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool05oooo`80000;
oooo0P0000;oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20178 .12361 L
.20742 .12361 L
.21274 .12361 L
.21753 .12361 L
.21884 .12361 L
.21955 .12361 L
.22022 .12361 L
s
.22022 .12361 m
.2207 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000o`2Ioooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool01oooo`03o`2Ioooooooo01coool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool004Soool00ol0VOooooooo`0L
oooo00<0000co`0co`00Ac?o00D0001Zoooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol0
048co`050000Koooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000m<ol01@0007Coool0
04Soool00ol0VOooooooo`0Loooo00<0000co`0co`00>C?o00@0001ioooo0018oooo00?o09Wooooo
ool07?ooo`80000h<ol00P0007goool004Soool00ol0VOooooooo`0Loooo00<0000co`0co`00=C?o
0080001ooooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol003<co`020000POooo`00B?oo
o`03o`2Ioooooooo01coool00`0003?o03?o000a<ol00P0008?oool004Soool00ol0VOooooooo`0L
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool004Soool00ol0VOooooooo`0Loooo00<0
000co`0co`00;S?o00800026oooo0018oooo00?o09Woooooool07?ooo`80000]<ol00P0008Soool0
04Soool00ol0VOooooooo`0Loooo00<0000co`0co`00:c?o00030000oooooooo08Soool004Soool0
0ol0VOooooooo`0Loooo00<0000co`0co`00:S?o00030000oooooooo08Woool004Soool00ol0VOoo
ooooo`0Loooo00<0000co`0co`00:C?o00030000oooooooo08[oool004Soool00ol0VOooooooo`0L
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool004Soool00ol0VOooooooo`0Loooo00<0
000co`0co`00:3?o00030000oooooooo08_oool004Soool00ol0VOooooooo`0Loooo0P0002Pco`00
0`000?ooooooo`2<oooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo0018
oooo00?o09Woooooool07?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo0018oooo00?o
09Woooooool07?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo0018oooo00?o09Wooooo
ool07?ooo`80000S<ol000<0003oooooool0TOooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00B?ooo`03o`2Ioooooooo01Coool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo0018oooo00?o09Woooooool05_ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00B?ooo`03o`2Ioooooooo01Koool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo0018oooo00?o09Woooooool05_ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00B?ooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool004Soool00ol0VOooooooo`0E
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00B?ooo`03o`2Ioooooooo
01coool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00B?ooo`03o`2Ioooooooo01coool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00B?ooo`03o`2Ioooooooo01coool2000073?o
00030000oooooooo09Soool004Soool00ol0VOooooooo`0Loooo00<0000co`0co`006S?o00030000
oooooooo09Woool004Soool00ol0VOooooooo`0Loooo00<0000co`0co`006S?o00030000oooooooo
09Woool004Soool00ol0VOooooooo`0Loooo00<0000co`0co`006C?o00030000oooooooo09[oool0
04Soool00ol0VOooooooo`0Loooo00<0000co`0co`006C?o00030000oooooooo09[oool004Soool0
0ol0VOooooooo`0Loooo00<0000co`0co`0063?o00030000oooooooo09_oool004Soool00ol0VOoo
ooooo`0Loooo0P0001Tco`000`000?ooooooo`2Koooo0018oooo00?o09Woooooool07?ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo0018
oooo00?o09Woooooool07?ooo`80000F<ol000<0003oooooool0W_ooo`00B?ooo`03o`2Ioooooooo
01coool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00B?ooo`03o`2Ioooooooo01coool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00B?ooo`03o`2Ioooooooo01coool200005C?o00030000oooooooo09ooool0
04Soool00ol0VOooooooo`0Loooo00<0000co`0co`004c?o00030000oooooooo0:3oool004Soool0
0ol0VOooooooo`0Loooo00<0000co`0co`004c?o00030000oooooooo0:3oool004Soool00ol0VOoo
ooooo`0Loooo00<0000co`0co`004c?o00030000oooooooo0:3oool004Soool00ol0VOooooooo`0D
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00B?ooo`03o`2Ioooooooo
01Coool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool004Soool0
0ol0VOooooooo`0Eoooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00B?oo
o`03o`2Ioooooooo01Koool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool004Soool00ol0VOooooooo`0Doooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool004Soool00ol0VOooooooo`0Eoooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00B?ooo`03o`2Ioooooooo01coool200004C?o00030000oooooooo0:?oool004Soool0
0ol0VOooooooo`0Loooo00<0000co`0co`0043?o00030000oooooooo0:?oool004Soool00ol0VOoo
ooooo`0Loooo00<0000co`0co`0043?o00030000oooooooo0:?oool004Soool00ol0VOooooooo`0L
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool004Soool00ol0VOooooooo`0Loooo00<0
000co`0co`003c?o00030000oooooooo0:Coool004Soool00ol0VOooooooo`0Loooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool004Soool00ol0VOooooooo`0Loooo00<0000co`0co`003c?o
00030000oooooooo0:Coool004Soool00ol0VOooooooo`0Loooo0P00010co`000`000?ooooooo`2T
oooo0018oooo00?o09Woooooool07?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0018
oooo00?o09Woooooool07?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0018oooo00?o
09Woooooool07?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0018oooo00?o09Wooooo
ool07?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo0018oooo00?o09Woooooool07?oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo0018oooo00?o09Woooooool07?ooo`80000>
<ol000<0003oooooool0Y_ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00B?oo
o`03o`2Ioooooooo01coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00B?ooo`03o`2I
oooooooo01coool200003C?o00030000oooooooo0:Ooool004Soool00ol0VOooooooo`0Loooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool004Soool00ol0VOooooooo`0Loooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool004Soool00ol0VOooooooo`0Loooo00<0000co`0co`002c?o
00030000oooooooo0:Soool004Soool00ol0VOooooooo`0Eoooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00B?ooo`03o`2Ioooooooo01Coool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00B?ooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo0018oooo00?o09Woooooool05oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00B?ooo`03o`2Ioooooooo
01Coool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00B?oo
o`03o`2Ioooooooo01Goool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0018
oooo00?o09Woooooool07?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0018oooo00?o
09Woooooool07?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0018oooo00?o09Wooooo
ool07?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo0018oooo00?o09Woooooool07?oo
o`80000;<ol000<0003oooooool0ZOooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00B?oo
o`03o`2Ioooooooo01coool200002S?o00030000oooooooo0:[oool004Soool00ol0VOooooooo`0L
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool004Soool00ol0VOooooooo`0Loooo00<0
000co`0co`002C?o00030000oooooooo0:[oool004Soool00ol0VOooooooo`0Loooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool004Soool00ol0VOooooooo`0Loooo00<0000co`0co`0023?o
00030000oooooooo0:_oool004Soool00ol0VOooooooo`0Loooo00<0000co`0co`0023?o00030000
oooooooo0:_oool004Soool00ol0VOooooooo`0Loooo0P0000Tco`000`000?ooooooo`2[oooo0018
oooo00?o09Woooooool07?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo0018oooo00?o
09Woooooool07?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo0018oooo00?o09Wooooo
ool07?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0018oooo00?o09Woooooool07?oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0018oooo00?o09Woooooool07?ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo0018oooo00?o09Woooooool07?ooo`800008<ol000<0
003oooooool0[?ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00B?ooo`03o`2Ioooooooo01coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00B?oo
o`03o`2Ioooooooo01coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00B?ooo`03o`2I
oooooooo01Koool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo0018oooo00?o
09Woooooool05oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00B?ooo`03o`2Ioooooooo01Coool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00Ioooo`Tco`04oooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000
oooooooo00D0000Boooo00@0003oooooool0000;oooo00@0003oooooooooool200001?ooo`030000
oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001W
oooo2C?o00Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`800003oooo00<0003ooooo
ool0M_ooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.21345 .12361 L
.21786 .12361 L
.22037 .12361 L
.22272 .12361 L
.22496 .12361 L
.22623 .12361 L
s
.22623 .12361 m
.22669 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`040000ooooooooo`2I1?ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool0
0`000?ooooooo`09oooo00?o09Woooooool06_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00B_ooo`03o`2Ioooooooo
01[oool00`0003?o03?o0017<ol01@0006[oool004[oool00ol0VOooooooo`0Joooo00<0000co`0c
o`00@S?o00D0001_oooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol003dco`050000M?oo
o`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000i<ol0100007Woool004[oool00ol0VOoo
ooooo`0Joooo0P0003Pco`020000OOooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000e
<ol00P0007ooool004[oool00ol0VOooooooo`0Joooo00<0000co`0co`00<c?o00800021oooo001:
oooo00?o09Woooooool06_ooo`030000<ol0<ol0034co`020000Poooo`00B_ooo`03o`2Ioooooooo
01[oool00`0003?o03?o000`<ol000<0003oooooool0Poooo`00B_ooo`03o`2Ioooooooo01[oool0
0`0003?o03?o000^<ol00P0008Koool004[oool00ol0VOooooooo`0Joooo0P0002dco`020000R?oo
o`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00B_oo
o`03o`2Ioooooooo01[oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`00B_ooo`03o`2I
oooooooo01[oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`00B_ooo`03o`2Ioooooooo
01[oool00`0003?o03?o000X<ol000<0003oooooool0Roooo`00B_ooo`03o`2Ioooooooo01[oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`00B_ooo`03o`2Ioooooooo01[oool20000:3?o
00030000oooooooo08coool004[oool00ol0VOooooooo`0Joooo00<0000co`0co`009S?o00030000
oooooooo08goool004[oool00ol0VOooooooo`0Joooo00<0000co`0co`009C?o00030000oooooooo
08koool004[oool00ol0VOooooooo`0Joooo00<0000co`0co`0093?o00030000oooooooo08ooool0
04[oool00ol0VOooooooo`0Joooo00<0000co`0co`008c?o00030000oooooooo093oool004[oool0
0ol0VOooooooo`0Joooo00<0000co`0co`008c?o00030000oooooooo093oool004[oool00ol0VOoo
ooooo`0Joooo0P0002<co`000`000?ooooooo`2Aoooo001:oooo00?o09Woooooool06_ooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo001:oooo00?o09Woooooool04_ooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo09Coool004[oool00ol0VOooooooo`0Doooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Eoooo001:oooo00?o09Woooooool05?ooo`030000oooooooo00?oool2
00007c?o00030000oooooooo09Goool004[oool00ol0VOooooooo`0Doooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`2Foooo001:oooo00?o09Woooooool05?ooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00B_ooo`03o`2Ioooooooo
01?oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo001:oooo00?o09Wooooo
ool06_ooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo001:oooo00?o09Woooooool06_oo
o`030000<ol0<ol001/co`000`000?ooooooo`2Hoooo001:oooo00?o09Woooooool06_ooo`80000L
<ol000<0003oooooool0V?ooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000J<ol000<0
003oooooool0VOooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000I<ol000<0003oooooool0V_oo
o`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00B_oo
o`03o`2Ioooooooo01[oool00`0003?o03?o000H<ol000<0003oooooool0Voooo`00B_ooo`03o`2I
oooooooo01[oool200006C?o00030000oooooooo09_oool004[oool00ol0VOooooooo`0Joooo00<0
000co`0co`005c?o00030000oooooooo09coool004[oool00ol0VOooooooo`0Joooo00<0000co`0c
o`005c?o00030000oooooooo09coool004[oool00ol0VOooooooo`0Joooo00<0000co`0co`005S?o
00030000oooooooo09goool004[oool00ol0VOooooooo`0Joooo00<0000co`0co`005S?o00030000
oooooooo09goool004[oool00ol0VOooooooo`0Joooo00<0000co`0co`005S?o00030000oooooooo
09goool004[oool00ol0VOooooooo`0Joooo00<0000co`0co`005C?o00030000oooooooo09koool0
04[oool00ol0VOooooooo`0Joooo0P0001Hco`000`000?ooooooo`2Noooo001:oooo00?o09Wooooo
ool06_ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001:oooo00?o09Woooooool06_oo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001:oooo00?o09Woooooool06_ooo`030000
<ol0<ol001@co`000`000?ooooooo`2Ooooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo001:oooo00?o09Woooooool06_ooo`80000E<ol000<0003oooooool0Wooo
o`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00B_oo
o`03o`2Ioooooooo01[oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00B_ooo`03o`2I
oooooooo01[oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00B_ooo`03o`2Ioooooooo
01;oool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo001:oooo00?o09Wooooo
ool04_ooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00B_oo
o`03o`2Ioooooooo01?oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo001:
oooo00?o09Woooooool05?ooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0XOooo`00B_ooo`03o`2Ioooooooo01;oool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00B_ooo`03o`2Ioooooooo01?oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo001:oooo00?o09Woooooool06_ooo`80000A<ol000<0003oooooool0Xoooo`00B_oo
o`03o`2Ioooooooo01[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00B_ooo`03o`2I
oooooooo01[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00B_ooo`03o`2Ioooooooo
01[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00B_ooo`03o`2Ioooooooo01[oool0
0`0003?o03?o000?<ol000<0003oooooool0Y?ooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`00B_ooo`03o`2Ioooooooo01[oool2000043?o00030000oooooooo
0:Coool004[oool00ol0VOooooooo`0Joooo00<0000co`0co`003S?o00030000oooooooo0:Goool0
04[oool00ol0VOooooooo`0Joooo00<0000co`0co`003S?o00030000oooooooo0:Goool004[oool0
0ol0VOooooooo`0Joooo00<0000co`0co`003S?o00030000oooooooo0:Goool004[oool00ol0VOoo
ooooo`0Joooo00<0000co`0co`003S?o00030000oooooooo0:Goool004[oool00ol0VOooooooo`0J
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool004[oool00ol0VOooooooo`0Joooo0P00
00hco`000`000?ooooooo`2Voooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000dco`00
0`000?ooooooo`2Voooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000`co`000`000?ooooooo`2W
oooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001:
oooo00?o09Woooooool06_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001:oooo00?o
09Woooooool06_ooo`80000=<ol000<0003oooooool0Yoooo`00B_ooo`03o`2Ioooooooo01[oool0
0`0003?o03?o000<<ol000<0003oooooool0Yoooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00B_ooo`03o`2Ioooooooo01?oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo001:oooo00?o09Woooooool04_ooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001:oooo00?o09Woooooool05?ooo`030000
oooooooo00?oool2000033?o00030000oooooooo0:Soool004[oool00ol0VOooooooo`0Eoooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001:oooo00?o09Wooooo
ool04_ooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001:
oooo00?o09Woooooool04oooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
04[oool00ol0VOooooooo`0Joooo00<0000co`0co`002S?o00030000oooooooo0:Woool004[oool0
0ol0VOooooooo`0Joooo00<0000co`0co`002S?o00030000oooooooo0:Woool004[oool00ol0VOoo
ooooo`0Joooo00<0000co`0co`002S?o00030000oooooooo0:Woool004[oool00ol0VOooooooo`0J
oooo0P0000/co`000`000?ooooooo`2Yoooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo001:
oooo00?o09Woooooool06_ooo`80000:<ol000<0003oooooool0Z_ooo`00B_ooo`03o`2Ioooooooo
01[oool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00B_ooo`03o`2Ioooooooo01[oool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o
03?o0008<ol000<0003oooooool0Zoooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`00B_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`00B_ooo`03o`2Ioooooooo01[oool200002C?o00030000oooooooo0:_oool0
04[oool00ol0VOooooooo`0Joooo00<0000co`0co`0023?o00030000oooooooo0:_oool004[oool0
0ol0VOooooooo`0Joooo00<0000co`0co`0023?o00030000oooooooo0:_oool004[oool00ol0VOoo
ooooo`0Joooo00<0000co`0co`001c?o00030000oooooooo0:coool004[oool00ol0VOooooooo`0J
oooo00<0000co`0co`001c?o00030000oooooooo0:coool004[oool00ol0VOooooooo`0Joooo00<0
000co`0co`001c?o00030000oooooooo0:coool004[oool00ol0VOooooooo`0Joooo0P0000Pco`00
0`000?ooooooo`2/oooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`2/oooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo001:oooo00?o09Woooooool06_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001:
oooo00?o09Woooooool06_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001:oooo00?o
09Woooooool05?ooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool004[oool0
0ol0VOooooooo`0Eoooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo001:oooo00?o09Woooooool04_ooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200000oooo`<00004
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001Woooo2C?o00Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002_ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0
003oooooool01@0001;oool010000?ooooooo`0000_oool00`000?ooooooo`0300001?ooo`030000
oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0MOooo`00Iooo
o`Tco`06oooo00<0003oooooool05oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo
07Koool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.22738 .12361 L
.22994 .12361 L
.23119 .12361 L
.23233 .12361 L
s
.23233 .12361 m
.23283 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`050000ooooooooooooo`2I00?oool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0U
oooo00<0003oooooool02_ooo`03o`2Ioooooooo01Woool00`0003?o03?o000U<ol000<0000co`0c
o`0093?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool004_oool00ol0VOoo
ooooo`0Ioooo00<0000co`0co`00Ac?o00D0001Zoooo001;oooo00?o09Woooooool06Oooo`030000
<ol0<ol0048co`050000Koooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000m<ol01@00
07Coool004_oool00ol0VOooooooo`0Ioooo00<0000co`0co`00>C?o00@0001ioooo001;oooo00?o
09Woooooool06Oooo`80000h<ol00P0007goool004_oool00ol0VOooooooo`0Ioooo00<0000co`0c
o`00=C?o0080001ooooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol003<co`020000POoo
o`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000a<ol00P0008?oool004_oool00ol0VOoo
ooooo`0Ioooo00<0000co`0co`00<3?o00030000oooooooo08?oool004_oool00ol0VOooooooo`0I
oooo00<0000co`0co`00;S?o00800026oooo001;oooo00?o09Woooooool06Oooo`80000]<ol00P00
08Soool004_oool00ol0VOooooooo`0Ioooo00<0000co`0co`00:c?o00030000oooooooo08Soool0
04_oool00ol0VOooooooo`0Ioooo00<0000co`0co`00:S?o00030000oooooooo08Woool004_oool0
0ol0VOooooooo`0Ioooo00<0000co`0co`00:C?o00030000oooooooo08[oool004_oool00ol0VOoo
ooooo`0Ioooo00<0000co`0co`00:3?o00030000oooooooo08_oool004_oool00ol0VOooooooo`0I
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool004_oool00ol0VOooooooo`0Ioooo0P00
02Pco`000`000?ooooooo`2<oooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol002Hco`00
0`000?ooooooo`2=oooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol002Dco`000`000?oo
ooooo`2>oooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol002@co`000`000?ooooooo`2?
oooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001;
oooo00?o09Woooooool06Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001;oooo00?o
09Woooooool06Oooo`80000S<ol000<0003oooooool0TOooo`00Boooo`03o`2Ioooooooo01Woool0
0`0003?o03?o000Q<ol000<0003oooooool0T_ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o
03?o000P<ol000<0003oooooool0Toooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000O<ol000<0
003oooooool0U?ooo`00Boooo`03o`2Ioooooooo017oool500000oooo`030000<ol0<ol001lco`00
0`000?ooooooo`2Doooo001;oooo00?o09Woooooool04oooo`030000oooooooo00?oool00`0003?o
03?o000N<ol000<0003oooooool0UOooo`00Boooo`03o`2Ioooooooo01?oool00`000?ooooooo`03
oooo0P0001lco`000`000?ooooooo`2Eoooo001;oooo00?o09Woooooool04oooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00Boooo`03o`2Ioooooooo01?oool0
0`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool004_oool00ol0VOoo
ooooo`0Boooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00Boooo`03o`2I
oooooooo01Woool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00Boooo`03o`2Ioooooooo
01Woool00`0003?o03?o000K<ol000<0003oooooool0V?ooo`00Boooo`03o`2Ioooooooo01Woool2
000073?o00030000oooooooo09Soool004_oool00ol0VOooooooo`0Ioooo00<0000co`0co`006S?o
00030000oooooooo09Woool004_oool00ol0VOooooooo`0Ioooo00<0000co`0co`006S?o00030000
oooooooo09Woool004_oool00ol0VOooooooo`0Ioooo00<0000co`0co`006C?o00030000oooooooo
09[oool004_oool00ol0VOooooooo`0Ioooo00<0000co`0co`006C?o00030000oooooooo09[oool0
04_oool00ol0VOooooooo`0Ioooo00<0000co`0co`0063?o00030000oooooooo09_oool004_oool0
0ol0VOooooooo`0Ioooo0P0001Tco`000`000?ooooooo`2Koooo001;oooo00?o09Woooooool06Ooo
o`030000<ol0<ol001Lco`000`000?ooooooo`2Loooo001;oooo00?o09Woooooool06Oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`2Moooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol001Dco`000`000?ooooooo`2N
oooo001;oooo00?o09Woooooool06Oooo`80000F<ol000<0003oooooool0W_ooo`00Boooo`03o`2I
oooooooo01Woool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00Boooo`03o`2Ioooooooo
01Woool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00Boooo`03o`2Ioooooooo01Woool0
0`0003?o03?o000D<ol000<0003oooooool0Woooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00Boooo`03o`2Ioooooooo01Woool200005C?o00030000oooooooo
09ooool004_oool00ol0VOooooooo`0Ioooo00<0000co`0co`004c?o00030000oooooooo0:3oool0
04_oool00ol0VOooooooo`0Ioooo00<0000co`0co`004c?o00030000oooooooo0:3oool004_oool0
0ol0VOooooooo`0Ioooo00<0000co`0co`004c?o00030000oooooooo0:3oool004_oool00ol0VOoo
ooooo`0Aoooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00Boooo`03o`2I
oooooooo017oool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool0
04_oool00ol0VOooooooo`0Boooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOoo
o`00Boooo`03o`2Ioooooooo01?oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000
oooooooo0:7oool004_oool00ol0VOooooooo`0Aoooo00@0003oooooool00004oooo00<0000co`0c
o`004C?o00030000oooooooo0:;oool004_oool00ol0VOooooooo`0Boooo0P0000Goool00`0003?o
03?o000A<ol000<0003oooooool0X_ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00Boooo`03o`2Ioooooooo01Woool200004C?o00030000oooooooo0:?oool0
04_oool00ol0VOooooooo`0Ioooo00<0000co`0co`0043?o00030000oooooooo0:?oool004_oool0
0ol0VOooooooo`0Ioooo00<0000co`0co`0043?o00030000oooooooo0:?oool004_oool00ol0VOoo
ooooo`0Ioooo00<0000co`0co`0043?o00030000oooooooo0:?oool004_oool00ol0VOooooooo`0I
oooo00<0000co`0co`003c?o00030000oooooooo0:Coool004_oool00ol0VOooooooo`0Ioooo00<0
000co`0co`003c?o00030000oooooooo0:Coool004_oool00ol0VOooooooo`0Ioooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool004_oool00ol0VOooooooo`0Ioooo0P00010co`000`000?oo
ooooo`2Toooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol000hco`000`000?ooooooo`2U
oooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001;
oooo00?o09Woooooool06Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001;oooo00?o
09Woooooool06Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001;oooo00?o09Wooooo
ool06Oooo`030000<ol0<ol000dco`000`000?ooooooo`2Voooo001;oooo00?o09Woooooool06Ooo
o`80000><ol000<0003oooooool0Y_ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000=
<ol000<0003oooooool0Y_ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000<<ol000<0003ooooo
ool0Yoooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00Booo
o`03o`2Ioooooooo01Woool200003C?o00030000oooooooo0:Ooool004_oool00ol0VOooooooo`0I
oooo00<0000co`0co`0033?o00030000oooooooo0:Ooool004_oool00ol0VOooooooo`0Ioooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool004_oool00ol0VOooooooo`0Ioooo00<0000co`0c
o`002c?o00030000oooooooo0:Soool004_oool00ol0VOooooooo`0Boooo0P0000Goool00`0003?o
03?o000;<ol000<0003oooooool0Z?ooo`00Boooo`03o`2Ioooooooo017oool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Boooo`03o`2Ioooooooo01?oool0
0`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001;oooo00?o09Woooooool05?oo
o`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Boooo`03o`2I
oooooooo017oool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?oo
o`00Boooo`03o`2Ioooooooo01;oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Y
oooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001;
oooo00?o09Woooooool06Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001;oooo00?o
09Woooooool06Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001;oooo00?o09Wooooo
ool06Oooo`80000;<ol000<0003oooooool0ZOooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o
03?o000:<ol000<0003oooooool0ZOooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o0009
<ol000<0003oooooool0Z_ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00Boooo`03o`2Ioooooooo01Woool200002S?o00030000oooooooo0:[oool004_oool00ol0VOoo
ooooo`0Ioooo00<0000co`0co`002C?o00030000oooooooo0:[oool004_oool00ol0VOooooooo`0I
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool004_oool00ol0VOooooooo`0Ioooo00<0
000co`0co`0023?o00030000oooooooo0:_oool004_oool00ol0VOooooooo`0Ioooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool004_oool00ol0VOooooooo`0Ioooo00<0000co`0co`0023?o
00030000oooooooo0:_oool004_oool00ol0VOooooooo`0Ioooo0P0000Tco`000`000?ooooooo`2[
oooo001;oooo00?o09Woooooool06Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001;
oooo00?o09Woooooool06Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001;oooo00?o
09Woooooool06Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001;oooo00?o09Wooooo
ool06Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001;oooo00?o09Woooooool06Ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001;oooo00?o09Woooooool06Oooo`800008
<ol000<0003oooooool0[?ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o0007<ol000<0
003oooooool0[?ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00Boooo`03o`2Ioooooooo01Woool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Booo
o`03o`2Ioooooooo01?oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001;
oooo00?o09Woooooool05?ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00Boooo`03o`2Ioooooooo017oool500000oooo`800008<ol000<0003oooooool0[?oo
o`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_
oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9
<ol01_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?oo
ooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000Goool3
00000_ooo`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0
003oooooool00005oooo00D0003oooooooooool00000Moooo`00Ioooo`Tco`04oooo00<0003ooooo
ool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool010000?ooooooooooo`D00003
oooo00<0003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000_oool010000?ooooooo`0000;oool01@000?ooooooooooo`00001goooo001Woooo2C?o
00Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oool000000oooo`030000oooooooo07Goool006Ooool9<ol01_ooo`030000oooooooo
01Ooool200002_ooo`800005oooo0P0000;oool00`000?ooooooo`1foooo001Woooo2C?o0;3oool0
06Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23496 .12361 L
.2364 .12361 L
.23775 .12361 L
.2389 .12361 L
s
.2389 .12361 m
.2394 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00?oool00ol0VOooo`000007oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool03?ooo`03o`2Ioooooooo01Ooool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool004goool00ol0VOooooooo`0G
oooo00<0000co`0co`00Ac?o00D0001Zoooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol0
048co`050000Koooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000m<ol01@0007Coool0
04goool00ol0VOooooooo`0Goooo00<0000co`0co`00>C?o00@0001ioooo001=oooo00?o09Wooooo
ool05oooo`80000h<ol00P0007goool004goool00ol0VOooooooo`0Goooo00<0000co`0co`00=C?o
0080001ooooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol003<co`020000POooo`00COoo
o`03o`2Ioooooooo01Ooool00`0003?o03?o000a<ol00P0008?oool004goool00ol0VOooooooo`0G
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool004goool00ol0VOooooooo`0Goooo00<0
000co`0co`00;S?o00800026oooo001=oooo00?o09Woooooool05oooo`80000]<ol00P0008Soool0
04goool00ol0VOooooooo`0Goooo00<0000co`0co`00:c?o00030000oooooooo08Soool004goool0
0ol0VOooooooo`0Goooo00<0000co`0co`00:S?o00030000oooooooo08Woool004goool00ol0VOoo
ooooo`0Goooo00<0000co`0co`00:C?o00030000oooooooo08[oool004goool00ol0VOooooooo`0G
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool004goool00ol0VOooooooo`0Goooo00<0
000co`0co`00:3?o00030000oooooooo08_oool004goool00ol0VOooooooo`0Goooo0P0002Pco`00
0`000?ooooooo`2<oooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo001=
oooo00?o09Woooooool05oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001=oooo00?o
09Woooooool05oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001=oooo00?o09Wooooo
ool05oooo`80000S<ol000<0003oooooool0TOooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00COooo`03o`2Ioooooooo00ooool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo001=oooo00?o09Woooooool04Oooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00COooo`03o`2Ioooooooo017oool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo001=oooo00?o09Woooooool04Oooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00COooo`03o`2Ioooooooo017oool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool004goool00ol0VOooooooo`0@
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00COooo`03o`2Ioooooooo
01Ooool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00COooo`03o`2Ioooooooo01Ooool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00COooo`03o`2Ioooooooo01Ooool2000073?o
00030000oooooooo09Soool004goool00ol0VOooooooo`0Goooo00<0000co`0co`006S?o00030000
oooooooo09Woool004goool00ol0VOooooooo`0Goooo00<0000co`0co`006S?o00030000oooooooo
09Woool004goool00ol0VOooooooo`0Goooo00<0000co`0co`006C?o00030000oooooooo09[oool0
04goool00ol0VOooooooo`0Goooo00<0000co`0co`006C?o00030000oooooooo09[oool004goool0
0ol0VOooooooo`0Goooo00<0000co`0co`0063?o00030000oooooooo09_oool004goool00ol0VOoo
ooooo`0Goooo0P0001Tco`000`000?ooooooo`2Koooo001=oooo00?o09Woooooool05oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001=
oooo00?o09Woooooool05oooo`80000F<ol000<0003oooooool0W_ooo`00COooo`03o`2Ioooooooo
01Ooool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00COooo`03o`2Ioooooooo01Ooool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00COooo`03o`2Ioooooooo01Ooool200005C?o00030000oooooooo09ooool0
04goool00ol0VOooooooo`0Goooo00<0000co`0co`004c?o00030000oooooooo0:3oool004goool0
0ol0VOooooooo`0Goooo00<0000co`0co`004c?o00030000oooooooo0:3oool004goool00ol0VOoo
ooooo`0Goooo00<0000co`0co`004c?o00030000oooooooo0:3oool004goool00ol0VOooooooo`0?
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00COooo`03o`2Ioooooooo
00ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool004goool0
0ol0VOooooooo`0@oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00COoo
o`03o`2Ioooooooo017oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool004goool00ol0VOooooooo`0?oooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool004goool00ol0VOooooooo`0@oooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00COooo`03o`2Ioooooooo01Ooool200004C?o00030000oooooooo0:?oool004goool0
0ol0VOooooooo`0Goooo00<0000co`0co`0043?o00030000oooooooo0:?oool004goool00ol0VOoo
ooooo`0Goooo00<0000co`0co`0043?o00030000oooooooo0:?oool004goool00ol0VOooooooo`0G
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool004goool00ol0VOooooooo`0Goooo00<0
000co`0co`003c?o00030000oooooooo0:Coool004goool00ol0VOooooooo`0Goooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool004goool00ol0VOooooooo`0Goooo00<0000co`0co`003c?o
00030000oooooooo0:Coool004goool00ol0VOooooooo`0Goooo0P00010co`000`000?ooooooo`2T
oooo001=oooo00?o09Woooooool05oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001=
oooo00?o09Woooooool05oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001=oooo00?o
09Woooooool05oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001=oooo00?o09Wooooo
ool05oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001=oooo00?o09Woooooool05ooo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo001=oooo00?o09Woooooool05oooo`80000>
<ol000<0003oooooool0Y_ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00COoo
o`03o`2Ioooooooo01Ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00COooo`03o`2I
oooooooo01Ooool200003C?o00030000oooooooo0:Ooool004goool00ol0VOooooooo`0Goooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool004goool00ol0VOooooooo`0Goooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool004goool00ol0VOooooooo`0Goooo00<0000co`0co`002c?o
00030000oooooooo0:Soool004goool00ol0VOooooooo`0@oooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00COooo`03o`2Ioooooooo00ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00COooo`03o`2Ioooooooo017oool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001=oooo00?o09Woooooool04_ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00COooo`03o`2Ioooooooo
00ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00COoo
o`03o`2Ioooooooo013oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001=
oooo00?o09Woooooool05oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001=oooo00?o
09Woooooool05oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001=oooo00?o09Wooooo
ool05oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001=oooo00?o09Woooooool05ooo
o`80000;<ol000<0003oooooool0ZOooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00COoo
o`03o`2Ioooooooo01Ooool200002S?o00030000oooooooo0:[oool004goool00ol0VOooooooo`0G
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool004goool00ol0VOooooooo`0Goooo00<0
000co`0co`002C?o00030000oooooooo0:[oool004goool00ol0VOooooooo`0Goooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool004goool00ol0VOooooooo`0Goooo00<0000co`0co`0023?o
00030000oooooooo0:_oool004goool00ol0VOooooooo`0Goooo00<0000co`0co`0023?o00030000
oooooooo0:_oool004goool00ol0VOooooooo`0Goooo0P0000Tco`000`000?ooooooo`2[oooo001=
oooo00?o09Woooooool05oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001=oooo00?o
09Woooooool05oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001=oooo00?o09Wooooo
ool05oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001=oooo00?o09Woooooool05ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001=oooo00?o09Woooooool05oooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo001=oooo00?o09Woooooool05oooo`800008<ol000<0
003oooooool0[?ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00COooo`03o`2Ioooooooo01Ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00COoo
o`03o`2Ioooooooo01Ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00COooo`03o`2I
oooooooo017oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001=oooo00?o
09Woooooool04_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00COooo`03o`2Ioooooooo00ooool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000?oool400000ooo
o`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00<0003oooooool01?ooo`030000oooooooo07Goool006Ooool9<ol01?ooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`030000oooooooo00Coool00`000?ooooooo`1doooo001Woooo2C?o00Goool00`000?ooooooo`05
00004_ooo`040000oooooooo00002oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0
003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000005Oooo`040000oooooooo
00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool0
06Ooool9<ol01_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0P0000?oool00`000?oo
ooooo`1foooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23739 .12361 L
.24016 .12361 L
.24276 .12361 L
.24392 .12361 L
.24502 .12361 L
s
.24502 .12361 m
.24553 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Coool00ol0V@000?ooo`06oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool03Oooo`03o`2Ioooooooo01Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool004koool00ol0VOooooooo`0F
oooo00<0000co`0co`00Ac?o00D0001Zoooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol0
048co`050000Koooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000m<ol01@0007Coool0
04koool00ol0VOooooooo`0Foooo00<0000co`0co`00>C?o00@0001ioooo001>oooo00?o09Wooooo
ool05_ooo`80000h<ol00P0007goool004koool00ol0VOooooooo`0Foooo00<0000co`0co`00=C?o
0080001ooooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol003<co`020000POooo`00C_oo
o`03o`2Ioooooooo01Koool00`0003?o03?o000a<ol00P0008?oool004koool00ol0VOooooooo`0F
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool004koool00ol0VOooooooo`0Foooo00<0
000co`0co`00;S?o00800026oooo001>oooo00?o09Woooooool05_ooo`80000]<ol00P0008Soool0
04koool00ol0VOooooooo`0Foooo00<0000co`0co`00:c?o00030000oooooooo08Soool004koool0
0ol0VOooooooo`0Foooo00<0000co`0co`00:S?o00030000oooooooo08Woool004koool00ol0VOoo
ooooo`0Foooo00<0000co`0co`00:C?o00030000oooooooo08[oool004koool00ol0VOooooooo`0F
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool004koool00ol0VOooooooo`0Foooo00<0
000co`0co`00:3?o00030000oooooooo08_oool004koool00ol0VOooooooo`0Foooo0P0002Pco`00
0`000?ooooooo`2<oooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo001>
oooo00?o09Woooooool05_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001>oooo00?o
09Woooooool05_ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001>oooo00?o09Wooooo
ool05_ooo`80000S<ol000<0003oooooool0TOooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00C_ooo`03o`2Ioooooooo00koool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo001>oooo00?o09Woooooool04?ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00C_ooo`03o`2Ioooooooo013oool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo001>oooo00?o09Woooooool04?ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00C_ooo`03o`2Ioooooooo013oool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool004koool00ol0VOooooooo`0?
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00C_ooo`03o`2Ioooooooo
01Koool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00C_ooo`03o`2Ioooooooo01Koool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00C_ooo`03o`2Ioooooooo01Koool2000073?o
00030000oooooooo09Soool004koool00ol0VOooooooo`0Foooo00<0000co`0co`006S?o00030000
oooooooo09Woool004koool00ol0VOooooooo`0Foooo00<0000co`0co`006S?o00030000oooooooo
09Woool004koool00ol0VOooooooo`0Foooo00<0000co`0co`006C?o00030000oooooooo09[oool0
04koool00ol0VOooooooo`0Foooo00<0000co`0co`006C?o00030000oooooooo09[oool004koool0
0ol0VOooooooo`0Foooo00<0000co`0co`0063?o00030000oooooooo09_oool004koool00ol0VOoo
ooooo`0Foooo0P0001Tco`000`000?ooooooo`2Koooo001>oooo00?o09Woooooool05_ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001>
oooo00?o09Woooooool05_ooo`80000F<ol000<0003oooooool0W_ooo`00C_ooo`03o`2Ioooooooo
01Koool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00C_ooo`03o`2Ioooooooo01Koool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00C_ooo`03o`2Ioooooooo01Koool200005C?o00030000oooooooo09ooool0
04koool00ol0VOooooooo`0Foooo00<0000co`0co`004c?o00030000oooooooo0:3oool004koool0
0ol0VOooooooo`0Foooo00<0000co`0co`004c?o00030000oooooooo0:3oool004koool00ol0VOoo
ooooo`0Foooo00<0000co`0co`004c?o00030000oooooooo0:3oool004koool00ol0VOooooooo`0>
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00C_ooo`03o`2Ioooooooo
00koool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool004koool0
0ol0VOooooooo`0?oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00C_oo
o`03o`2Ioooooooo013oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool004koool00ol0VOooooooo`0>oooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool004koool00ol0VOooooooo`0?oooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00C_ooo`03o`2Ioooooooo01Koool200004C?o00030000oooooooo0:?oool004koool0
0ol0VOooooooo`0Foooo00<0000co`0co`0043?o00030000oooooooo0:?oool004koool00ol0VOoo
ooooo`0Foooo00<0000co`0co`0043?o00030000oooooooo0:?oool004koool00ol0VOooooooo`0F
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool004koool00ol0VOooooooo`0Foooo00<0
000co`0co`003c?o00030000oooooooo0:Coool004koool00ol0VOooooooo`0Foooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool004koool00ol0VOooooooo`0Foooo00<0000co`0co`003c?o
00030000oooooooo0:Coool004koool00ol0VOooooooo`0Foooo0P00010co`000`000?ooooooo`2T
oooo001>oooo00?o09Woooooool05_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001>
oooo00?o09Woooooool05_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001>oooo00?o
09Woooooool05_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001>oooo00?o09Wooooo
ool05_ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001>oooo00?o09Woooooool05_oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo001>oooo00?o09Woooooool05_ooo`80000>
<ol000<0003oooooool0Y_ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00C_oo
o`03o`2Ioooooooo01Koool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00C_ooo`03o`2I
oooooooo01Koool200003C?o00030000oooooooo0:Ooool004koool00ol0VOooooooo`0Foooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool004koool00ol0VOooooooo`0Foooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool004koool00ol0VOooooooo`0Foooo00<0000co`0co`002c?o
00030000oooooooo0:Soool004koool00ol0VOooooooo`0?oooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00C_ooo`03o`2Ioooooooo00koool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00C_ooo`03o`2Ioooooooo013oool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001>oooo00?o09Woooooool04Oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00C_ooo`03o`2Ioooooooo
00koool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00C_oo
o`03o`2Ioooooooo00ooool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001>
oooo00?o09Woooooool05_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001>oooo00?o
09Woooooool05_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001>oooo00?o09Wooooo
ool05_ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001>oooo00?o09Woooooool05_oo
o`80000;<ol000<0003oooooool0ZOooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00C_oo
o`03o`2Ioooooooo01Koool200002S?o00030000oooooooo0:[oool004koool00ol0VOooooooo`0F
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool004koool00ol0VOooooooo`0Foooo00<0
000co`0co`002C?o00030000oooooooo0:[oool004koool00ol0VOooooooo`0Foooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool004koool00ol0VOooooooo`0Foooo00<0000co`0co`0023?o
00030000oooooooo0:_oool004koool00ol0VOooooooo`0Foooo00<0000co`0co`0023?o00030000
oooooooo0:_oool004koool00ol0VOooooooo`0Foooo0P0000Tco`000`000?ooooooo`2[oooo001>
oooo00?o09Woooooool05_ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001>oooo00?o
09Woooooool05_ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001>oooo00?o09Wooooo
ool05_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001>oooo00?o09Woooooool05_oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001>oooo00?o09Woooooool05_ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo001>oooo00?o09Woooooool05_ooo`800008<ol000<0
003oooooool0[?ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00C_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00C_oo
o`03o`2Ioooooooo01Koool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00C_ooo`03o`2I
oooooooo013oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001>oooo00?o
09Woooooool04Oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00C_ooo`03o`2Ioooooooo00koool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Ooo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000Coool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo07Ooool006Ooool9
<ol02?ooo`030000oooooooo00D0000Boooo00@0003oooooool0000;oooo00D0003oooooooooool0
0000N_ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo
01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o
0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23739 .12361 L
.24276 .12361 L
.24745 .12361 L
.24873 .12361 L
.25012 .12361 L
.25142 .12361 L
s
.25142 .12361 m
.2519 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?l0VOooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool03oooo`03o`2Ioooooooo01Coool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool0053oool00ol0VOooooooo`0D
oooo00<0000co`0co`00Ac?o00D0001Zoooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol0
048co`050000Koooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000m<ol01@0007Coool0
053oool00ol0VOooooooo`0Doooo00<0000co`0co`00>C?o00@0001ioooo001@oooo00?o09Wooooo
ool05?ooo`80000h<ol00P0007goool0053oool00ol0VOooooooo`0Doooo00<0000co`0co`00=C?o
0080001ooooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol003<co`020000POooo`00D?oo
o`03o`2Ioooooooo01Coool00`0003?o03?o000a<ol00P0008?oool0053oool00ol0VOooooooo`0D
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool0053oool00ol0VOooooooo`0Doooo00<0
000co`0co`00;S?o00800026oooo001@oooo00?o09Woooooool05?ooo`80000]<ol00P0008Soool0
053oool00ol0VOooooooo`0Doooo00<0000co`0co`00:c?o00030000oooooooo08Soool0053oool0
0ol0VOooooooo`0Doooo00<0000co`0co`00:S?o00030000oooooooo08Woool0053oool00ol0VOoo
ooooo`0Doooo00<0000co`0co`00:C?o00030000oooooooo08[oool0053oool00ol0VOooooooo`0D
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool0053oool00ol0VOooooooo`0Doooo00<0
000co`0co`00:3?o00030000oooooooo08_oool0053oool00ol0VOooooooo`0Doooo0P0002Pco`00
0`000?ooooooo`2<oooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo001@
oooo00?o09Woooooool05?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001@oooo00?o
09Woooooool05?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001@oooo00?o09Wooooo
ool05?ooo`80000S<ol000<0003oooooool0TOooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00D?ooo`03o`2Ioooooooo00coool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo001@oooo00?o09Woooooool03_ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00D?ooo`03o`2Ioooooooo00koool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo001@oooo00?o09Woooooool03_ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00D?ooo`03o`2Ioooooooo00koool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool0053oool00ol0VOooooooo`0=
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00D?ooo`03o`2Ioooooooo
01Coool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00D?ooo`03o`2Ioooooooo01Coool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00D?ooo`03o`2Ioooooooo01Coool2000073?o
00030000oooooooo09Soool0053oool00ol0VOooooooo`0Doooo00<0000co`0co`006S?o00030000
oooooooo09Woool0053oool00ol0VOooooooo`0Doooo00<0000co`0co`006S?o00030000oooooooo
09Woool0053oool00ol0VOooooooo`0Doooo00<0000co`0co`006C?o00030000oooooooo09[oool0
053oool00ol0VOooooooo`0Doooo00<0000co`0co`006C?o00030000oooooooo09[oool0053oool0
0ol0VOooooooo`0Doooo00<0000co`0co`0063?o00030000oooooooo09_oool0053oool00ol0VOoo
ooooo`0Doooo0P0001Tco`000`000?ooooooo`2Koooo001@oooo00?o09Woooooool05?ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001@
oooo00?o09Woooooool05?ooo`80000F<ol000<0003oooooool0W_ooo`00D?ooo`03o`2Ioooooooo
01Coool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00D?ooo`03o`2Ioooooooo01Coool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00D?ooo`03o`2Ioooooooo01Coool200005C?o00030000oooooooo09ooool0
053oool00ol0VOooooooo`0Doooo00<0000co`0co`004c?o00030000oooooooo0:3oool0053oool0
0ol0VOooooooo`0Doooo00<0000co`0co`004c?o00030000oooooooo0:3oool0053oool00ol0VOoo
ooooo`0Doooo00<0000co`0co`004c?o00030000oooooooo0:3oool0053oool00ol0VOooooooo`0<
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00D?ooo`03o`2Ioooooooo
00coool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool0053oool0
0ol0VOooooooo`0=oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00D?oo
o`03o`2Ioooooooo00koool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool0053oool00ol0VOooooooo`0<oooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool0053oool00ol0VOooooooo`0=oooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00D?ooo`03o`2Ioooooooo01Coool200004C?o00030000oooooooo0:?oool0053oool0
0ol0VOooooooo`0Doooo00<0000co`0co`0043?o00030000oooooooo0:?oool0053oool00ol0VOoo
ooooo`0Doooo00<0000co`0co`0043?o00030000oooooooo0:?oool0053oool00ol0VOooooooo`0D
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool0053oool00ol0VOooooooo`0Doooo00<0
000co`0co`003c?o00030000oooooooo0:Coool0053oool00ol0VOooooooo`0Doooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool0053oool00ol0VOooooooo`0Doooo00<0000co`0co`003c?o
00030000oooooooo0:Coool0053oool00ol0VOooooooo`0Doooo0P00010co`000`000?ooooooo`2T
oooo001@oooo00?o09Woooooool05?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001@
oooo00?o09Woooooool05?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001@oooo00?o
09Woooooool05?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001@oooo00?o09Wooooo
ool05?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001@oooo00?o09Woooooool05?oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo001@oooo00?o09Woooooool05?ooo`80000>
<ol000<0003oooooool0Y_ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00D?oo
o`03o`2Ioooooooo01Coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00D?ooo`03o`2I
oooooooo01Coool200003C?o00030000oooooooo0:Ooool0053oool00ol0VOooooooo`0Doooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool0053oool00ol0VOooooooo`0Doooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool0053oool00ol0VOooooooo`0Doooo00<0000co`0co`002c?o
00030000oooooooo0:Soool0053oool00ol0VOooooooo`0=oooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00D?ooo`03o`2Ioooooooo00coool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00D?ooo`03o`2Ioooooooo00koool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001@oooo00?o09Woooooool03oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00D?ooo`03o`2Ioooooooo
00coool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00D?oo
o`03o`2Ioooooooo00goool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001@
oooo00?o09Woooooool05?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001@oooo00?o
09Woooooool05?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001@oooo00?o09Wooooo
ool05?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001@oooo00?o09Woooooool05?oo
o`80000;<ol000<0003oooooool0ZOooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00D?oo
o`03o`2Ioooooooo01Coool200002S?o00030000oooooooo0:[oool0053oool00ol0VOooooooo`0D
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool0053oool00ol0VOooooooo`0Doooo00<0
000co`0co`002C?o00030000oooooooo0:[oool0053oool00ol0VOooooooo`0Doooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool0053oool00ol0VOooooooo`0Doooo00<0000co`0co`0023?o
00030000oooooooo0:_oool0053oool00ol0VOooooooo`0Doooo00<0000co`0co`0023?o00030000
oooooooo0:_oool0053oool00ol0VOooooooo`0Doooo0P0000Tco`000`000?ooooooo`2[oooo001@
oooo00?o09Woooooool05?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001@oooo00?o
09Woooooool05?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001@oooo00?o09Wooooo
ool05?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001@oooo00?o09Woooooool05?oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001@oooo00?o09Woooooool05?ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo001@oooo00?o09Woooooool05?ooo`800008<ol000<0
003oooooool0[?ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00D?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00D?oo
o`03o`2Ioooooooo01Coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00D?ooo`03o`2I
oooooooo00koool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001@oooo00?o
09Woooooool03oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00D?ooo`03o`2Ioooooooo00coool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo100000?oool200001?oo
o`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00<0003ooooo
ool00oooo`040000oooooooo00000oooo`030000oooooooo07Goool006Ooool9<ol01?ooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00009oooo00<0003oooooool00_oo
o`040000oooooooo00001?ooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000oooooooo
00D0000Boooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool006Ooool9
<ol01_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1f
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.24276 .12361 L
.24754 .12361 L
.25261 .12361 L
.2547 .12361 L
.25694 .12361 L
.25823 .12361 L
s
.25823 .12361 m
.2587 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool010000?ooooooool0V@Coool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Aoooo00?o09Woooooool04_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00D_ooo`03o`2Ioooooooo
01;oool00`0003?o03?o0017<ol01@0006[oool005;oool00ol0VOooooooo`0Boooo00<0000co`0c
o`00@S?o00D0001_oooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol003dco`050000M?oo
o`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000i<ol0100007Woool005;oool00ol0VOoo
ooooo`0Boooo0P0003Pco`020000OOooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000e
<ol00P0007ooool005;oool00ol0VOooooooo`0Boooo00<0000co`0co`00<c?o00800021oooo001B
oooo00?o09Woooooool04_ooo`030000<ol0<ol0034co`020000Poooo`00D_ooo`03o`2Ioooooooo
01;oool00`0003?o03?o000`<ol000<0003oooooool0Poooo`00D_ooo`03o`2Ioooooooo01;oool0
0`0003?o03?o000^<ol00P0008Koool005;oool00ol0VOooooooo`0Boooo0P0002dco`020000R?oo
o`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00D_oo
o`03o`2Ioooooooo01;oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`00D_ooo`03o`2I
oooooooo01;oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`00D_ooo`03o`2Ioooooooo
01;oool00`0003?o03?o000X<ol000<0003oooooool0Roooo`00D_ooo`03o`2Ioooooooo01;oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`00D_ooo`03o`2Ioooooooo01;oool20000:3?o
00030000oooooooo08coool005;oool00ol0VOooooooo`0Boooo00<0000co`0co`009S?o00030000
oooooooo08goool005;oool00ol0VOooooooo`0Boooo00<0000co`0co`009C?o00030000oooooooo
08koool005;oool00ol0VOooooooo`0Boooo00<0000co`0co`0093?o00030000oooooooo08ooool0
05;oool00ol0VOooooooo`0Boooo00<0000co`0co`008c?o00030000oooooooo093oool005;oool0
0ol0VOooooooo`0Boooo00<0000co`0co`008c?o00030000oooooooo093oool005;oool00ol0VOoo
ooooo`0Boooo0P0002<co`000`000?ooooooo`2Aoooo001Boooo00?o09Woooooool04_ooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo001Boooo00?o09Woooooool02_ooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo09Coool005;oool00ol0VOooooooo`0<oooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Eoooo001Boooo00?o09Woooooool03?ooo`030000oooooooo00?oool2
00007c?o00030000oooooooo09Goool005;oool00ol0VOooooooo`0<oooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`2Foooo001Boooo00?o09Woooooool03?ooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00D_ooo`03o`2Ioooooooo
00_oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo001Boooo00?o09Wooooo
ool04_ooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo001Boooo00?o09Woooooool04_oo
o`030000<ol0<ol001/co`000`000?ooooooo`2Hoooo001Boooo00?o09Woooooool04_ooo`80000L
<ol000<0003oooooool0V?ooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000J<ol000<0
003oooooool0VOooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000I<ol000<0003oooooool0V_oo
o`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00D_oo
o`03o`2Ioooooooo01;oool00`0003?o03?o000H<ol000<0003oooooool0Voooo`00D_ooo`03o`2I
oooooooo01;oool200006C?o00030000oooooooo09_oool005;oool00ol0VOooooooo`0Boooo00<0
000co`0co`005c?o00030000oooooooo09coool005;oool00ol0VOooooooo`0Boooo00<0000co`0c
o`005c?o00030000oooooooo09coool005;oool00ol0VOooooooo`0Boooo00<0000co`0co`005S?o
00030000oooooooo09goool005;oool00ol0VOooooooo`0Boooo00<0000co`0co`005S?o00030000
oooooooo09goool005;oool00ol0VOooooooo`0Boooo00<0000co`0co`005S?o00030000oooooooo
09goool005;oool00ol0VOooooooo`0Boooo00<0000co`0co`005C?o00030000oooooooo09koool0
05;oool00ol0VOooooooo`0Boooo0P0001Hco`000`000?ooooooo`2Noooo001Boooo00?o09Wooooo
ool04_ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001Boooo00?o09Woooooool04_oo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001Boooo00?o09Woooooool04_ooo`030000
<ol0<ol001@co`000`000?ooooooo`2Ooooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo001Boooo00?o09Woooooool04_ooo`80000E<ol000<0003oooooool0Wooo
o`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00D_oo
o`03o`2Ioooooooo01;oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00D_ooo`03o`2I
oooooooo01;oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00D_ooo`03o`2Ioooooooo
00[oool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo001Boooo00?o09Wooooo
ool02_ooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00D_oo
o`03o`2Ioooooooo00_oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo001B
oooo00?o09Woooooool03?ooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0XOooo`00D_ooo`03o`2Ioooooooo00[oool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00D_ooo`03o`2Ioooooooo00_oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo001Boooo00?o09Woooooool04_ooo`80000A<ol000<0003oooooool0Xoooo`00D_oo
o`03o`2Ioooooooo01;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00D_ooo`03o`2I
oooooooo01;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00D_ooo`03o`2Ioooooooo
01;oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00D_ooo`03o`2Ioooooooo01;oool0
0`0003?o03?o000?<ol000<0003oooooool0Y?ooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`00D_ooo`03o`2Ioooooooo01;oool2000043?o00030000oooooooo
0:Coool005;oool00ol0VOooooooo`0Boooo00<0000co`0co`003S?o00030000oooooooo0:Goool0
05;oool00ol0VOooooooo`0Boooo00<0000co`0co`003S?o00030000oooooooo0:Goool005;oool0
0ol0VOooooooo`0Boooo00<0000co`0co`003S?o00030000oooooooo0:Goool005;oool00ol0VOoo
ooooo`0Boooo00<0000co`0co`003S?o00030000oooooooo0:Goool005;oool00ol0VOooooooo`0B
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool005;oool00ol0VOooooooo`0Boooo0P00
00hco`000`000?ooooooo`2Voooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000dco`00
0`000?ooooooo`2Voooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000`co`000`000?ooooooo`2W
oooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001B
oooo00?o09Woooooool04_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001Boooo00?o
09Woooooool04_ooo`80000=<ol000<0003oooooool0Yoooo`00D_ooo`03o`2Ioooooooo01;oool0
0`0003?o03?o000<<ol000<0003oooooool0Yoooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00D_ooo`03o`2Ioooooooo00_oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo001Boooo00?o09Woooooool02_ooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001Boooo00?o09Woooooool03?ooo`030000
oooooooo00?oool2000033?o00030000oooooooo0:Soool005;oool00ol0VOooooooo`0=oooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001Boooo00?o09Wooooo
ool02_ooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001B
oooo00?o09Woooooool02oooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
05;oool00ol0VOooooooo`0Boooo00<0000co`0co`002S?o00030000oooooooo0:Woool005;oool0
0ol0VOooooooo`0Boooo00<0000co`0co`002S?o00030000oooooooo0:Woool005;oool00ol0VOoo
ooooo`0Boooo00<0000co`0co`002S?o00030000oooooooo0:Woool005;oool00ol0VOooooooo`0B
oooo0P0000/co`000`000?ooooooo`2Yoooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo001B
oooo00?o09Woooooool04_ooo`80000:<ol000<0003oooooool0Z_ooo`00D_ooo`03o`2Ioooooooo
01;oool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00D_ooo`03o`2Ioooooooo01;oool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o
03?o0008<ol000<0003oooooool0Zoooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`00D_ooo`03o`2Ioooooooo01;oool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`00D_ooo`03o`2Ioooooooo01;oool200002C?o00030000oooooooo0:_oool0
05;oool00ol0VOooooooo`0Boooo00<0000co`0co`0023?o00030000oooooooo0:_oool005;oool0
0ol0VOooooooo`0Boooo00<0000co`0co`0023?o00030000oooooooo0:_oool005;oool00ol0VOoo
ooooo`0Boooo00<0000co`0co`001c?o00030000oooooooo0:coool005;oool00ol0VOooooooo`0B
oooo00<0000co`0co`001c?o00030000oooooooo0:coool005;oool00ol0VOooooooo`0Boooo00<0
000co`0co`001c?o00030000oooooooo0:coool005;oool00ol0VOooooooo`0Boooo0P0000Pco`00
0`000?ooooooo`2/oooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`2/oooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo001Boooo00?o09Woooooool04_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001B
oooo00?o09Woooooool04_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Boooo00?o
09Woooooool03?ooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool005;oool0
0ol0VOooooooo`0=oooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo001Boooo00?o09Woooooool02_ooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool400000_ooo`<00004
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool00`000?oo
ooooo`03oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00Ioooo`Tco`04oooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Woool00`000?ooooooo`02
oooo00@0003oooooool00004oooo00<0003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003ooooo
ool01@0001;oool010000?ooooooo`0000[oool010000?ooooooooooo`<00004oooo00<0003ooooo
ool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1eoooo001Woooo2C?o
00Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`<00002oooo00<0003oooooool0M_oo
o`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.25666 .12361 L
.26171 .12361 L
.26301 .12361 L
.26425 .12361 L
.26493 .12361 L
s
.26493 .12361 m
.26523 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool01@000?ooooooooooool0V@03oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0U
oooo00<0003oooooool04_ooo`03o`2Ioooooooo017oool00`0003?o03?o000U<ol000<0000co`0c
o`0093?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool005?oool00ol0VOoo
ooooo`0Aoooo00<0000co`0co`00Ac?o00D0001Zoooo001Coooo00?o09Woooooool04Oooo`030000
<ol0<ol0048co`050000Koooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000m<ol01@00
07Coool005?oool00ol0VOooooooo`0Aoooo00<0000co`0co`00>C?o00@0001ioooo001Coooo00?o
09Woooooool04Oooo`80000h<ol00P0007goool005?oool00ol0VOooooooo`0Aoooo00<0000co`0c
o`00=C?o0080001ooooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol003<co`020000POoo
o`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000a<ol00P0008?oool005?oool00ol0VOoo
ooooo`0Aoooo00<0000co`0co`00<3?o00030000oooooooo08?oool005?oool00ol0VOooooooo`0A
oooo00<0000co`0co`00;S?o00800026oooo001Coooo00?o09Woooooool04Oooo`80000]<ol00P00
08Soool005?oool00ol0VOooooooo`0Aoooo00<0000co`0co`00:c?o00030000oooooooo08Soool0
05?oool00ol0VOooooooo`0Aoooo00<0000co`0co`00:S?o00030000oooooooo08Woool005?oool0
0ol0VOooooooo`0Aoooo00<0000co`0co`00:C?o00030000oooooooo08[oool005?oool00ol0VOoo
ooooo`0Aoooo00<0000co`0co`00:3?o00030000oooooooo08_oool005?oool00ol0VOooooooo`0A
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool005?oool00ol0VOooooooo`0Aoooo0P00
02Pco`000`000?ooooooo`2<oooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol002Hco`00
0`000?ooooooo`2=oooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol002Dco`000`000?oo
ooooo`2>oooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol002@co`000`000?ooooooo`2?
oooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001C
oooo00?o09Woooooool04Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Coooo00?o
09Woooooool04Oooo`80000S<ol000<0003oooooool0TOooo`00Doooo`03o`2Ioooooooo017oool0
0`0003?o03?o000Q<ol000<0003oooooool0T_ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o
03?o000P<ol000<0003oooooool0Toooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000O<ol000<0
003oooooool0U?ooo`00Doooo`03o`2Ioooooooo00Woool500000oooo`030000<ol0<ol001lco`00
0`000?ooooooo`2Doooo001Coooo00?o09Woooooool02oooo`030000oooooooo00?oool00`0003?o
03?o000N<ol000<0003oooooool0UOooo`00Doooo`03o`2Ioooooooo00_oool00`000?ooooooo`03
oooo0P0001lco`000`000?ooooooo`2Eoooo001Coooo00?o09Woooooool02oooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00Doooo`03o`2Ioooooooo00_oool0
0`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool005?oool00ol0VOoo
ooooo`0:oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00Doooo`03o`2I
oooooooo017oool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00Doooo`03o`2Ioooooooo
017oool00`0003?o03?o000K<ol000<0003oooooool0V?ooo`00Doooo`03o`2Ioooooooo017oool2
000073?o00030000oooooooo09Soool005?oool00ol0VOooooooo`0Aoooo00<0000co`0co`006S?o
00030000oooooooo09Woool005?oool00ol0VOooooooo`0Aoooo00<0000co`0co`006S?o00030000
oooooooo09Woool005?oool00ol0VOooooooo`0Aoooo00<0000co`0co`006C?o00030000oooooooo
09[oool005?oool00ol0VOooooooo`0Aoooo00<0000co`0co`006C?o00030000oooooooo09[oool0
05?oool00ol0VOooooooo`0Aoooo00<0000co`0co`0063?o00030000oooooooo09_oool005?oool0
0ol0VOooooooo`0Aoooo0P0001Tco`000`000?ooooooo`2Koooo001Coooo00?o09Woooooool04Ooo
o`030000<ol0<ol001Lco`000`000?ooooooo`2Loooo001Coooo00?o09Woooooool04Oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`2Moooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol001Dco`000`000?ooooooo`2N
oooo001Coooo00?o09Woooooool04Oooo`80000F<ol000<0003oooooool0W_ooo`00Doooo`03o`2I
oooooooo017oool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00Doooo`03o`2Ioooooooo
017oool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00Doooo`03o`2Ioooooooo017oool0
0`0003?o03?o000D<ol000<0003oooooool0Woooo`00Doooo`03o`2Ioooooooo017oool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00Doooo`03o`2Ioooooooo017oool200005C?o00030000oooooooo
09ooool005?oool00ol0VOooooooo`0Aoooo00<0000co`0co`004c?o00030000oooooooo0:3oool0
05?oool00ol0VOooooooo`0Aoooo00<0000co`0co`004c?o00030000oooooooo0:3oool005?oool0
0ol0VOooooooo`0Aoooo00<0000co`0co`004c?o00030000oooooooo0:3oool005?oool00ol0VOoo
ooooo`09oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00Doooo`03o`2I
oooooooo00Woool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool0
05?oool00ol0VOooooooo`0:oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOoo
o`00Doooo`03o`2Ioooooooo00_oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000
oooooooo0:7oool005?oool00ol0VOooooooo`09oooo00@0003oooooool00004oooo00<0000co`0c
o`004C?o00030000oooooooo0:;oool005?oool00ol0VOooooooo`0:oooo0P0000Goool00`0003?o
03?o000A<ol000<0003oooooool0X_ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00Doooo`03o`2Ioooooooo017oool200004C?o00030000oooooooo0:?oool0
05?oool00ol0VOooooooo`0Aoooo00<0000co`0co`0043?o00030000oooooooo0:?oool005?oool0
0ol0VOooooooo`0Aoooo00<0000co`0co`0043?o00030000oooooooo0:?oool005?oool00ol0VOoo
ooooo`0Aoooo00<0000co`0co`0043?o00030000oooooooo0:?oool005?oool00ol0VOooooooo`0A
oooo00<0000co`0co`003c?o00030000oooooooo0:Coool005?oool00ol0VOooooooo`0Aoooo00<0
000co`0co`003c?o00030000oooooooo0:Coool005?oool00ol0VOooooooo`0Aoooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool005?oool00ol0VOooooooo`0Aoooo0P00010co`000`000?oo
ooooo`2Toooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol000hco`000`000?ooooooo`2U
oooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001C
oooo00?o09Woooooool04Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Coooo00?o
09Woooooool04Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Coooo00?o09Wooooo
ool04Oooo`030000<ol0<ol000dco`000`000?ooooooo`2Voooo001Coooo00?o09Woooooool04Ooo
o`80000><ol000<0003oooooool0Y_ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000=
<ol000<0003oooooool0Y_ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000<<ol000<0003ooooo
ool0Yoooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00Dooo
o`03o`2Ioooooooo017oool200003C?o00030000oooooooo0:Ooool005?oool00ol0VOooooooo`0A
oooo00<0000co`0co`0033?o00030000oooooooo0:Ooool005?oool00ol0VOooooooo`0Aoooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool005?oool00ol0VOooooooo`0Aoooo00<0000co`0c
o`002c?o00030000oooooooo0:Soool005?oool00ol0VOooooooo`0:oooo0P0000Goool00`0003?o
03?o000;<ol000<0003oooooool0Z?ooo`00Doooo`03o`2Ioooooooo00Woool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Doooo`03o`2Ioooooooo00_oool0
0`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001Coooo00?o09Woooooool03?oo
o`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Doooo`03o`2I
oooooooo00Woool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?oo
o`00Doooo`03o`2Ioooooooo00[oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Y
oooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001C
oooo00?o09Woooooool04Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Coooo00?o
09Woooooool04Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Coooo00?o09Wooooo
ool04Oooo`80000;<ol000<0003oooooool0ZOooo`00Doooo`03o`2Ioooooooo017oool00`0003?o
03?o000:<ol000<0003oooooool0ZOooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o0009
<ol000<0003oooooool0Z_ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00Doooo`03o`2Ioooooooo017oool200002S?o00030000oooooooo0:[oool005?oool00ol0VOoo
ooooo`0Aoooo00<0000co`0co`002C?o00030000oooooooo0:[oool005?oool00ol0VOooooooo`0A
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool005?oool00ol0VOooooooo`0Aoooo00<0
000co`0co`0023?o00030000oooooooo0:_oool005?oool00ol0VOooooooo`0Aoooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool005?oool00ol0VOooooooo`0Aoooo00<0000co`0co`0023?o
00030000oooooooo0:_oool005?oool00ol0VOooooooo`0Aoooo0P0000Tco`000`000?ooooooo`2[
oooo001Coooo00?o09Woooooool04Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001C
oooo00?o09Woooooool04Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001Coooo00?o
09Woooooool04Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Coooo00?o09Wooooo
ool04Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Coooo00?o09Woooooool04Ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Coooo00?o09Woooooool04Oooo`800008
<ol000<0003oooooool0[?ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o0007<ol000<0
003oooooool0[?ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00Doooo`03o`2Ioooooooo017oool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Dooo
o`03o`2Ioooooooo00_oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001C
oooo00?o09Woooooool03?ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00Doooo`03o`2Ioooooooo00Woool500000oooo`800008<ol000<0003oooooool0[?oo
o`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_
oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9
<ol01_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?oo
ooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo100000Coool3
00000_ooo`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00<0
003oooooool01_ooo`050000oooooooooooo000007Ooool006Ooool9<ol01?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool00009oooo00<0003oooooool00_ooo`D00003
oooo00<0003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00Iooo
o`Tco`05oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooo000000?oool00`000?ooooooo`1eoooo001Woooo2C?o00Koool00`000?oo
ooooo`0Goooo0P0000[oool200001Oooo`800002oooo00<0003oooooool0M_ooo`00Ioooo`Tco`2`
oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.26171 .12361 L
.26698 .12361 L
.26843 .12361 L
.26922 .12361 L
.26998 .12361 L
.27068 .12361 L
s
.27068 .12361 m
.27099 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`03oooo00?o09Woool000001oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool05?ooo`03o`2Ioooooooo00ooool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool005Goool00ol0VOooooooo`0?
oooo00<0000co`0co`00Ac?o00D0001Zoooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol0
048co`050000Koooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000m<ol01@0007Coool0
05Goool00ol0VOooooooo`0?oooo00<0000co`0co`00>C?o00@0001ioooo001Eoooo00?o09Wooooo
ool03oooo`80000h<ol00P0007goool005Goool00ol0VOooooooo`0?oooo00<0000co`0co`00=C?o
0080001ooooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol003<co`020000POooo`00EOoo
o`03o`2Ioooooooo00ooool00`0003?o03?o000a<ol00P0008?oool005Goool00ol0VOooooooo`0?
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool005Goool00ol0VOooooooo`0?oooo00<0
000co`0co`00;S?o00800026oooo001Eoooo00?o09Woooooool03oooo`80000]<ol00P0008Soool0
05Goool00ol0VOooooooo`0?oooo00<0000co`0co`00:c?o00030000oooooooo08Soool005Goool0
0ol0VOooooooo`0?oooo00<0000co`0co`00:S?o00030000oooooooo08Woool005Goool00ol0VOoo
ooooo`0?oooo00<0000co`0co`00:C?o00030000oooooooo08[oool005Goool00ol0VOooooooo`0?
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool005Goool00ol0VOooooooo`0?oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool005Goool00ol0VOooooooo`0?oooo0P0002Pco`00
0`000?ooooooo`2<oooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo001E
oooo00?o09Woooooool03oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Eoooo00?o
09Woooooool03oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Eoooo00?o09Wooooo
ool03oooo`80000S<ol000<0003oooooool0TOooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00EOooo`03o`2Ioooooooo00Ooool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo001Eoooo00?o09Woooooool02Oooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00EOooo`03o`2Ioooooooo00Woool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo001Eoooo00?o09Woooooool02Oooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00EOooo`03o`2Ioooooooo00Woool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool005Goool00ol0VOooooooo`08
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00EOooo`03o`2Ioooooooo
00ooool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00EOooo`03o`2Ioooooooo00ooool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00EOooo`03o`2Ioooooooo00ooool2000073?o
00030000oooooooo09Soool005Goool00ol0VOooooooo`0?oooo00<0000co`0co`006S?o00030000
oooooooo09Woool005Goool00ol0VOooooooo`0?oooo00<0000co`0co`006S?o00030000oooooooo
09Woool005Goool00ol0VOooooooo`0?oooo00<0000co`0co`006C?o00030000oooooooo09[oool0
05Goool00ol0VOooooooo`0?oooo00<0000co`0co`006C?o00030000oooooooo09[oool005Goool0
0ol0VOooooooo`0?oooo00<0000co`0co`0063?o00030000oooooooo09_oool005Goool00ol0VOoo
ooooo`0?oooo0P0001Tco`000`000?ooooooo`2Koooo001Eoooo00?o09Woooooool03oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001E
oooo00?o09Woooooool03oooo`80000F<ol000<0003oooooool0W_ooo`00EOooo`03o`2Ioooooooo
00ooool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00EOooo`03o`2Ioooooooo00ooool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00EOooo`03o`2Ioooooooo00ooool200005C?o00030000oooooooo09ooool0
05Goool00ol0VOooooooo`0?oooo00<0000co`0co`004c?o00030000oooooooo0:3oool005Goool0
0ol0VOooooooo`0?oooo00<0000co`0co`004c?o00030000oooooooo0:3oool005Goool00ol0VOoo
ooooo`0?oooo00<0000co`0co`004c?o00030000oooooooo0:3oool005Goool00ol0VOooooooo`07
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00EOooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool005Goool0
0ol0VOooooooo`08oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00EOoo
o`03o`2Ioooooooo00Woool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool005Goool00ol0VOooooooo`07oooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool005Goool00ol0VOooooooo`08oooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00EOooo`03o`2Ioooooooo00ooool200004C?o00030000oooooooo0:?oool005Goool0
0ol0VOooooooo`0?oooo00<0000co`0co`0043?o00030000oooooooo0:?oool005Goool00ol0VOoo
ooooo`0?oooo00<0000co`0co`0043?o00030000oooooooo0:?oool005Goool00ol0VOooooooo`0?
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool005Goool00ol0VOooooooo`0?oooo00<0
000co`0co`003c?o00030000oooooooo0:Coool005Goool00ol0VOooooooo`0?oooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool005Goool00ol0VOooooooo`0?oooo00<0000co`0co`003c?o
00030000oooooooo0:Coool005Goool00ol0VOooooooo`0?oooo0P00010co`000`000?ooooooo`2T
oooo001Eoooo00?o09Woooooool03oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001E
oooo00?o09Woooooool03oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Eoooo00?o
09Woooooool03oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Eoooo00?o09Wooooo
ool03oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Eoooo00?o09Woooooool03ooo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo001Eoooo00?o09Woooooool03oooo`80000>
<ol000<0003oooooool0Y_ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00EOoo
o`03o`2Ioooooooo00ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00EOooo`03o`2I
oooooooo00ooool200003C?o00030000oooooooo0:Ooool005Goool00ol0VOooooooo`0?oooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool005Goool00ol0VOooooooo`0?oooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool005Goool00ol0VOooooooo`0?oooo00<0000co`0co`002c?o
00030000oooooooo0:Soool005Goool00ol0VOooooooo`08oooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00EOooo`03o`2Ioooooooo00Ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00EOooo`03o`2Ioooooooo00Woool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001Eoooo00?o09Woooooool02_ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00EOooo`03o`2Ioooooooo
00Ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00EOoo
o`03o`2Ioooooooo00Soool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001E
oooo00?o09Woooooool03oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Eoooo00?o
09Woooooool03oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Eoooo00?o09Wooooo
ool03oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Eoooo00?o09Woooooool03ooo
o`80000;<ol000<0003oooooool0ZOooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00EOoo
o`03o`2Ioooooooo00ooool200002S?o00030000oooooooo0:[oool005Goool00ol0VOooooooo`0?
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool005Goool00ol0VOooooooo`0?oooo00<0
000co`0co`002C?o00030000oooooooo0:[oool005Goool00ol0VOooooooo`0?oooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool005Goool00ol0VOooooooo`0?oooo00<0000co`0co`0023?o
00030000oooooooo0:_oool005Goool00ol0VOooooooo`0?oooo00<0000co`0co`0023?o00030000
oooooooo0:_oool005Goool00ol0VOooooooo`0?oooo0P0000Tco`000`000?ooooooo`2[oooo001E
oooo00?o09Woooooool03oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001Eoooo00?o
09Woooooool03oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001Eoooo00?o09Wooooo
ool03oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Eoooo00?o09Woooooool03ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Eoooo00?o09Woooooool03oooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo001Eoooo00?o09Woooooool03oooo`800008<ol000<0
003oooooool0[?ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00EOooo`03o`2Ioooooooo00ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00EOoo
o`03o`2Ioooooooo00ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00EOooo`03o`2I
oooooooo00Woool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Eoooo00?o
09Woooooool02_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00EOooo`03o`2Ioooooooo00Ooool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo100000;oool400000ooo
o`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`1eoooo001Woooo2C?o00Coool00`000?oo
ooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002Oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003oooooool01@00
01;oool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000
oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001W
oooo2C?o00Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`800003oooo00<0003ooooo
ool0M_ooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.26171 .12361 L
.26709 .12361 L
.27279 .12361 L
.27513 .12361 L
.27643 .12361 L
.27765 .12361 L
s
.27765 .12361 m
.27793 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool05_ooo`03o`2Ioooooooo00goool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool005Ooool00ol0VOooooooo`0=
oooo00<0000co`0co`00Ac?o00D0001Zoooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol0
048co`050000Koooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000m<ol01@0007Coool0
05Ooool00ol0VOooooooo`0=oooo00<0000co`0co`00>C?o00@0001ioooo001Goooo00?o09Wooooo
ool03Oooo`80000h<ol00P0007goool005Ooool00ol0VOooooooo`0=oooo00<0000co`0co`00=C?o
0080001ooooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol003<co`020000POooo`00Eooo
o`03o`2Ioooooooo00goool00`0003?o03?o000a<ol00P0008?oool005Ooool00ol0VOooooooo`0=
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool005Ooool00ol0VOooooooo`0=oooo00<0
000co`0co`00;S?o00800026oooo001Goooo00?o09Woooooool03Oooo`80000]<ol00P0008Soool0
05Ooool00ol0VOooooooo`0=oooo00<0000co`0co`00:c?o00030000oooooooo08Soool005Ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`00:S?o00030000oooooooo08Woool005Ooool00ol0VOoo
ooooo`0=oooo00<0000co`0co`00:C?o00030000oooooooo08[oool005Ooool00ol0VOooooooo`0=
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool005Ooool00ol0VOooooooo`0=oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool005Ooool00ol0VOooooooo`0=oooo0P0002Pco`00
0`000?ooooooo`2<oooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo001G
oooo00?o09Woooooool03Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Goooo00?o
09Woooooool03Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Goooo00?o09Wooooo
ool03Oooo`80000S<ol000<0003oooooool0TOooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00Eoooo`03o`2Ioooooooo00Goool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo001Goooo00?o09Woooooool01oooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00Eoooo`03o`2Ioooooooo00Ooool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo001Goooo00?o09Woooooool01oooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00Eoooo`03o`2Ioooooooo00Ooool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool005Ooool00ol0VOooooooo`06
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00Eoooo`03o`2Ioooooooo
00goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00Eoooo`03o`2Ioooooooo00goool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00Eoooo`03o`2Ioooooooo00goool2000073?o
00030000oooooooo09Soool005Ooool00ol0VOooooooo`0=oooo00<0000co`0co`006S?o00030000
oooooooo09Woool005Ooool00ol0VOooooooo`0=oooo00<0000co`0co`006S?o00030000oooooooo
09Woool005Ooool00ol0VOooooooo`0=oooo00<0000co`0co`006C?o00030000oooooooo09[oool0
05Ooool00ol0VOooooooo`0=oooo00<0000co`0co`006C?o00030000oooooooo09[oool005Ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`0063?o00030000oooooooo09_oool005Ooool00ol0VOoo
ooooo`0=oooo0P0001Tco`000`000?ooooooo`2Koooo001Goooo00?o09Woooooool03Oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001G
oooo00?o09Woooooool03Oooo`80000F<ol000<0003oooooool0W_ooo`00Eoooo`03o`2Ioooooooo
00goool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00Eoooo`03o`2Ioooooooo00goool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00Eoooo`03o`2Ioooooooo00goool200005C?o00030000oooooooo09ooool0
05Ooool00ol0VOooooooo`0=oooo00<0000co`0co`004c?o00030000oooooooo0:3oool005Ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`004c?o00030000oooooooo0:3oool005Ooool00ol0VOoo
ooooo`0=oooo00<0000co`0co`004c?o00030000oooooooo0:3oool005Ooool00ol0VOooooooo`05
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00Eoooo`03o`2Ioooooooo
00Goool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool005Ooool0
0ol0VOooooooo`06oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00Eooo
o`03o`2Ioooooooo00Ooool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool005Ooool00ol0VOooooooo`05oooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool005Ooool00ol0VOooooooo`06oooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00Eoooo`03o`2Ioooooooo00goool200004C?o00030000oooooooo0:?oool005Ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`0043?o00030000oooooooo0:?oool005Ooool00ol0VOoo
ooooo`0=oooo00<0000co`0co`0043?o00030000oooooooo0:?oool005Ooool00ol0VOooooooo`0=
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool005Ooool00ol0VOooooooo`0=oooo00<0
000co`0co`003c?o00030000oooooooo0:Coool005Ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool005Ooool00ol0VOooooooo`0=oooo00<0000co`0co`003c?o
00030000oooooooo0:Coool005Ooool00ol0VOooooooo`0=oooo0P00010co`000`000?ooooooo`2T
oooo001Goooo00?o09Woooooool03Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001G
oooo00?o09Woooooool03Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Goooo00?o
09Woooooool03Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Goooo00?o09Wooooo
ool03Oooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Goooo00?o09Woooooool03Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo001Goooo00?o09Woooooool03Oooo`80000>
<ol000<0003oooooool0Y_ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00Eooo
o`03o`2Ioooooooo00goool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00Eoooo`03o`2I
oooooooo00goool200003C?o00030000oooooooo0:Ooool005Ooool00ol0VOooooooo`0=oooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool005Ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool005Ooool00ol0VOooooooo`0=oooo00<0000co`0co`002c?o
00030000oooooooo0:Soool005Ooool00ol0VOooooooo`06oooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00Eoooo`03o`2Ioooooooo00Goool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Eoooo`03o`2Ioooooooo00Ooool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001Goooo00?o09Woooooool02?ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Eoooo`03o`2Ioooooooo
00Goool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Eooo
o`03o`2Ioooooooo00Koool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001G
oooo00?o09Woooooool03Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Goooo00?o
09Woooooool03Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Goooo00?o09Wooooo
ool03Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Goooo00?o09Woooooool03Ooo
o`80000;<ol000<0003oooooool0ZOooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00Eooo
o`03o`2Ioooooooo00goool200002S?o00030000oooooooo0:[oool005Ooool00ol0VOooooooo`0=
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool005Ooool00ol0VOooooooo`0=oooo00<0
000co`0co`002C?o00030000oooooooo0:[oool005Ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool005Ooool00ol0VOooooooo`0=oooo00<0000co`0co`0023?o
00030000oooooooo0:_oool005Ooool00ol0VOooooooo`0=oooo00<0000co`0co`0023?o00030000
oooooooo0:_oool005Ooool00ol0VOooooooo`0=oooo0P0000Tco`000`000?ooooooo`2[oooo001G
oooo00?o09Woooooool03Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001Goooo00?o
09Woooooool03Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001Goooo00?o09Wooooo
ool03Oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Goooo00?o09Woooooool03Ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Goooo00?o09Woooooool03Oooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo001Goooo00?o09Woooooool03Oooo`800008<ol000<0
003oooooool0[?ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00Eoooo`03o`2Ioooooooo00goool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Eooo
o`03o`2Ioooooooo00goool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Eoooo`03o`2I
oooooooo00Ooool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Goooo00?o
09Woooooool02?ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00Eoooo`03o`2Ioooooooo00Goool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Ooo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo100000?oool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`030000oooooooo00Coool0
0`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1goooo001Woooo2C?o
00Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0
003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool0
06Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28025 .12361 L
.2817 .12361 L
.28302 .12361 L
s
.28302 .12361 m
.28351 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003o09Woool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool05oooo`03o`2Ioooooooo00coool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool005Soool00ol0VOooooooo`0<
oooo00<0000co`0co`00Ac?o00D0001Zoooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol0
048co`050000Koooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000m<ol01@0007Coool0
05Soool00ol0VOooooooo`0<oooo00<0000co`0co`00>C?o00@0001ioooo001Hoooo00?o09Wooooo
ool03?ooo`80000h<ol00P0007goool005Soool00ol0VOooooooo`0<oooo00<0000co`0co`00=C?o
0080001ooooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol003<co`020000POooo`00F?oo
o`03o`2Ioooooooo00coool00`0003?o03?o000a<ol00P0008?oool005Soool00ol0VOooooooo`0<
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool005Soool00ol0VOooooooo`0<oooo00<0
000co`0co`00;S?o00800026oooo001Hoooo00?o09Woooooool03?ooo`80000]<ol00P0008Soool0
05Soool00ol0VOooooooo`0<oooo00<0000co`0co`00:c?o00030000oooooooo08Soool005Soool0
0ol0VOooooooo`0<oooo00<0000co`0co`00:S?o00030000oooooooo08Woool005Soool00ol0VOoo
ooooo`0<oooo00<0000co`0co`00:C?o00030000oooooooo08[oool005Soool00ol0VOooooooo`0<
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool005Soool00ol0VOooooooo`0<oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool005Soool00ol0VOooooooo`0<oooo0P0002Pco`00
0`000?ooooooo`2<oooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo001H
oooo00?o09Woooooool03?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Hoooo00?o
09Woooooool03?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Hoooo00?o09Wooooo
ool03?ooo`80000S<ol000<0003oooooool0TOooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00F?ooo`03o`2Ioooooooo00Coool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo001Hoooo00?o09Woooooool01_ooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00F?ooo`03o`2Ioooooooo00Koool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`2Eoooo001Hoooo00?o09Woooooool01_ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0U_ooo`00F?ooo`03o`2Ioooooooo00Koool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool005Soool00ol0VOooooooo`05
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00F?ooo`03o`2Ioooooooo
00coool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00F?ooo`03o`2Ioooooooo00coool0
0`0003?o03?o000K<ol000<0003oooooool0V?ooo`00F?ooo`03o`2Ioooooooo00coool2000073?o
00030000oooooooo09Soool005Soool00ol0VOooooooo`0<oooo00<0000co`0co`006S?o00030000
oooooooo09Woool005Soool00ol0VOooooooo`0<oooo00<0000co`0co`006S?o00030000oooooooo
09Woool005Soool00ol0VOooooooo`0<oooo00<0000co`0co`006C?o00030000oooooooo09[oool0
05Soool00ol0VOooooooo`0<oooo00<0000co`0co`006C?o00030000oooooooo09[oool005Soool0
0ol0VOooooooo`0<oooo00<0000co`0co`0063?o00030000oooooooo09_oool005Soool00ol0VOoo
ooooo`0<oooo0P0001Tco`000`000?ooooooo`2Koooo001Hoooo00?o09Woooooool03?ooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Loooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol001Hco`000`000?oo
ooooo`2Moooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol001Hco`000`000?ooooooo`2M
oooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001H
oooo00?o09Woooooool03?ooo`80000F<ol000<0003oooooool0W_ooo`00F?ooo`03o`2Ioooooooo
00coool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00F?ooo`03o`2Ioooooooo00coool0
0`0003?o03?o000E<ol000<0003oooooool0W_ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000D
<ol000<0003oooooool0Woooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000D<ol000<0
003oooooool0Woooo`00F?ooo`03o`2Ioooooooo00coool200005C?o00030000oooooooo09ooool0
05Soool00ol0VOooooooo`0<oooo00<0000co`0co`004c?o00030000oooooooo0:3oool005Soool0
0ol0VOooooooo`0<oooo00<0000co`0co`004c?o00030000oooooooo0:3oool005Soool00ol0VOoo
ooooo`0<oooo00<0000co`0co`004c?o00030000oooooooo0:3oool005Soool00ol0VOooooooo`04
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00F?ooo`03o`2Ioooooooo
00Coool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool005Soool0
0ol0VOooooooo`05oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0XOooo`00F?oo
o`03o`2Ioooooooo00Koool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
0:7oool005Soool00ol0VOooooooo`04oooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool005Soool00ol0VOooooooo`05oooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00F?ooo`03o`2Ioooooooo00coool200004C?o00030000oooooooo0:?oool005Soool0
0ol0VOooooooo`0<oooo00<0000co`0co`0043?o00030000oooooooo0:?oool005Soool00ol0VOoo
ooooo`0<oooo00<0000co`0co`0043?o00030000oooooooo0:?oool005Soool00ol0VOooooooo`0<
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool005Soool00ol0VOooooooo`0<oooo00<0
000co`0co`003c?o00030000oooooooo0:Coool005Soool00ol0VOooooooo`0<oooo00<0000co`0c
o`003c?o00030000oooooooo0:Coool005Soool00ol0VOooooooo`0<oooo00<0000co`0co`003c?o
00030000oooooooo0:Coool005Soool00ol0VOooooooo`0<oooo0P00010co`000`000?ooooooo`2T
oooo001Hoooo00?o09Woooooool03?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001H
oooo00?o09Woooooool03?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Hoooo00?o
09Woooooool03?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Hoooo00?o09Wooooo
ool03?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Hoooo00?o09Woooooool03?oo
o`030000<ol0<ol000dco`000`000?ooooooo`2Voooo001Hoooo00?o09Woooooool03?ooo`80000>
<ol000<0003oooooool0Y_ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000=<ol000<0003ooooo
ool0Y_ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00F?oo
o`03o`2Ioooooooo00coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00F?ooo`03o`2I
oooooooo00coool200003C?o00030000oooooooo0:Ooool005Soool00ol0VOooooooo`0<oooo00<0
000co`0co`0033?o00030000oooooooo0:Ooool005Soool00ol0VOooooooo`0<oooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool005Soool00ol0VOooooooo`0<oooo00<0000co`0co`002c?o
00030000oooooooo0:Soool005Soool00ol0VOooooooo`05oooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00F?ooo`03o`2Ioooooooo00Coool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00F?ooo`03o`2Ioooooooo00Koool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001Hoooo00?o09Woooooool01oooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00F?ooo`03o`2Ioooooooo
00Coool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00F?oo
o`03o`2Ioooooooo00Goool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001H
oooo00?o09Woooooool03?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Hoooo00?o
09Woooooool03?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Hoooo00?o09Wooooo
ool03?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Hoooo00?o09Woooooool03?oo
o`80000;<ol000<0003oooooool0ZOooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00F?oo
o`03o`2Ioooooooo00coool200002S?o00030000oooooooo0:[oool005Soool00ol0VOooooooo`0<
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool005Soool00ol0VOooooooo`0<oooo00<0
000co`0co`002C?o00030000oooooooo0:[oool005Soool00ol0VOooooooo`0<oooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool005Soool00ol0VOooooooo`0<oooo00<0000co`0co`0023?o
00030000oooooooo0:_oool005Soool00ol0VOooooooo`0<oooo00<0000co`0co`0023?o00030000
oooooooo0:_oool005Soool00ol0VOooooooo`0<oooo0P0000Tco`000`000?ooooooo`2[oooo001H
oooo00?o09Woooooool03?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001Hoooo00?o
09Woooooool03?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001Hoooo00?o09Wooooo
ool03?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Hoooo00?o09Woooooool03?oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Hoooo00?o09Woooooool03?ooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo001Hoooo00?o09Woooooool03?ooo`800008<ol000<0
003oooooool0[?ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00F?ooo`03o`2Ioooooooo00coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00F?oo
o`03o`2Ioooooooo00coool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00F?ooo`03o`2I
oooooooo00Koool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Hoooo00?o
09Woooooool01oooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00F?ooo`03o`2Ioooooooo00Coool500000oooo`800008<ol000<0003oooooool0[?ooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08
oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo1@0000;oool200001?oo
o`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool0000:oooo00D0003ooooo
ooooool000000_ooo`050000oooooooooooo000007Ooool006Ooool9<ol01?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`1doooo001Woooo2C?o00Goool00`000?ooooooo`05
00004_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
07Goool006Ooool9<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`0000[oool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00Ioooo`Tco`06oooo00<0
003oooooool05oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Koool006Ooool9
<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28302 .12361 L
.28542 .12361 L
.288 .12361 L
.28876 .12361 L
.28948 .12361 L
.29013 .12361 L
s
.29013 .12361 m
.29041 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00@0003ooooooooo09T4oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Ioooo00?o09Woooooool02_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00F_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o0017<ol01@0006[oool005[oool00ol0VOooooooo`0:oooo00<0000co`0c
o`00@S?o00D0001_oooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol003dco`050000M?oo
o`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000i<ol0100007Woool005[oool00ol0VOoo
ooooo`0:oooo0P0003Pco`020000OOooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000e
<ol00P0007ooool005[oool00ol0VOooooooo`0:oooo00<0000co`0co`00<c?o00800021oooo001J
oooo00?o09Woooooool02_ooo`030000<ol0<ol0034co`020000Poooo`00F_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o000`<ol000<0003oooooool0Poooo`00F_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o000^<ol00P0008Koool005[oool00ol0VOooooooo`0:oooo0P0002dco`020000R?oo
o`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00F_oo
o`03o`2Ioooooooo00[oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`00F_ooo`03o`2I
oooooooo00[oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`00F_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o000X<ol000<0003oooooool0Roooo`00F_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`00F_ooo`03o`2Ioooooooo00[oool20000:3?o
00030000oooooooo08coool005[oool00ol0VOooooooo`0:oooo00<0000co`0co`009S?o00030000
oooooooo08goool005[oool00ol0VOooooooo`0:oooo00<0000co`0co`009C?o00030000oooooooo
08koool005[oool00ol0VOooooooo`0:oooo00<0000co`0co`0093?o00030000oooooooo08ooool0
05[oool00ol0VOooooooo`0:oooo00<0000co`0co`008c?o00030000oooooooo093oool005[oool0
0ol0VOooooooo`0:oooo00<0000co`0co`008c?o00030000oooooooo093oool005[oool00ol0VOoo
ooooo`0:oooo0P0002<co`000`000?ooooooo`2Aoooo001Joooo00?o09Woooooool02_ooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo001Joooo00?o09Woooooool00_ooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo09Coool005[oool00ol0VOooooooo`04oooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Eoooo001Joooo00?o09Woooooool01?ooo`030000oooooooo00?oool2
00007c?o00030000oooooooo09Goool005[oool00ol0VOooooooo`04oooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`2Foooo001Joooo00?o09Woooooool01?ooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0U_ooo`00F_ooo`03o`2Ioooooooo
00?oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo001Joooo00?o09Wooooo
ool02_ooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo001Joooo00?o09Woooooool02_oo
o`030000<ol0<ol001/co`000`000?ooooooo`2Hoooo001Joooo00?o09Woooooool02_ooo`80000L
<ol000<0003oooooool0V?ooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000J<ol000<0
003oooooool0VOooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000J<ol000<0003ooooo
ool0VOooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000I<ol000<0003oooooool0V_oo
o`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00F_oo
o`03o`2Ioooooooo00[oool00`0003?o03?o000H<ol000<0003oooooool0Voooo`00F_ooo`03o`2I
oooooooo00[oool200006C?o00030000oooooooo09_oool005[oool00ol0VOooooooo`0:oooo00<0
000co`0co`005c?o00030000oooooooo09coool005[oool00ol0VOooooooo`0:oooo00<0000co`0c
o`005c?o00030000oooooooo09coool005[oool00ol0VOooooooo`0:oooo00<0000co`0co`005S?o
00030000oooooooo09goool005[oool00ol0VOooooooo`0:oooo00<0000co`0co`005S?o00030000
oooooooo09goool005[oool00ol0VOooooooo`0:oooo00<0000co`0co`005S?o00030000oooooooo
09goool005[oool00ol0VOooooooo`0:oooo00<0000co`0co`005C?o00030000oooooooo09koool0
05[oool00ol0VOooooooo`0:oooo0P0001Hco`000`000?ooooooo`2Noooo001Joooo00?o09Wooooo
ool02_ooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001Joooo00?o09Woooooool02_oo
o`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001Joooo00?o09Woooooool02_ooo`030000
<ol0<ol001@co`000`000?ooooooo`2Ooooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol0
01@co`000`000?ooooooo`2Ooooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol001@co`00
0`000?ooooooo`2Ooooo001Joooo00?o09Woooooool02_ooo`80000E<ol000<0003oooooool0Wooo
o`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00F_oo
o`03o`2Ioooooooo00[oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00F_ooo`03o`2I
oooooooo00[oool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00F_ooo`03o`2Ioooooooo
00;oool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo001Joooo00?o09Wooooo
ool00_ooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00F_oo
o`03o`2Ioooooooo00?oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`2Qoooo001J
oooo00?o09Woooooool01?ooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0XOooo`00F_ooo`03o`2Ioooooooo00;oool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0X_ooo`00F_ooo`03o`2Ioooooooo00?oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo001Joooo00?o09Woooooool02_ooo`80000A<ol000<0003oooooool0Xoooo`00F_oo
o`03o`2Ioooooooo00[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00F_ooo`03o`2I
oooooooo00[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00F_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00F_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o000?<ol000<0003oooooool0Y?ooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`00F_ooo`03o`2Ioooooooo00[oool2000043?o00030000oooooooo
0:Coool005[oool00ol0VOooooooo`0:oooo00<0000co`0co`003S?o00030000oooooooo0:Goool0
05[oool00ol0VOooooooo`0:oooo00<0000co`0co`003S?o00030000oooooooo0:Goool005[oool0
0ol0VOooooooo`0:oooo00<0000co`0co`003S?o00030000oooooooo0:Goool005[oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`003S?o00030000oooooooo0:Goool005[oool00ol0VOooooooo`0:
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool005[oool00ol0VOooooooo`0:oooo0P00
00hco`000`000?ooooooo`2Voooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000dco`00
0`000?ooooooo`2Voooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000`co`000`000?ooooooo`2W
oooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001J
oooo00?o09Woooooool02_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001Joooo00?o
09Woooooool02_ooo`80000=<ol000<0003oooooool0Yoooo`00F_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o000<<ol000<0003oooooool0Yoooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00F_ooo`03o`2Ioooooooo00?oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo001Joooo00?o09Woooooool00_ooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001Joooo00?o09Woooooool01?ooo`030000
oooooooo00?oool2000033?o00030000oooooooo0:Soool005[oool00ol0VOooooooo`05oooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001Joooo00?o09Wooooo
ool00_ooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001J
oooo00?o09Woooooool00oooo`800005oooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
05[oool00ol0VOooooooo`0:oooo00<0000co`0co`002S?o00030000oooooooo0:Woool005[oool0
0ol0VOooooooo`0:oooo00<0000co`0co`002S?o00030000oooooooo0:Woool005[oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`002S?o00030000oooooooo0:Woool005[oool00ol0VOooooooo`0:
oooo0P0000/co`000`000?ooooooo`2Yoooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2Zoooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo001J
oooo00?o09Woooooool02_ooo`80000:<ol000<0003oooooool0Z_ooo`00F_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00F_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o
03?o0008<ol000<0003oooooool0Zoooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`00F_ooo`03o`2Ioooooooo00[oool00`0003?o03?o0008<ol000<0
003oooooool0Zoooo`00F_ooo`03o`2Ioooooooo00[oool200002C?o00030000oooooooo0:_oool0
05[oool00ol0VOooooooo`0:oooo00<0000co`0co`0023?o00030000oooooooo0:_oool005[oool0
0ol0VOooooooo`0:oooo00<0000co`0co`0023?o00030000oooooooo0:_oool005[oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`001c?o00030000oooooooo0:coool005[oool00ol0VOooooooo`0:
oooo00<0000co`0co`001c?o00030000oooooooo0:coool005[oool00ol0VOooooooo`0:oooo00<0
000co`0co`001c?o00030000oooooooo0:coool005[oool00ol0VOooooooo`0:oooo0P0000Pco`00
0`000?ooooooo`2/oooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`2/oooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo001Joooo00?o09Woooooool02_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001J
oooo00?o09Woooooool02_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Joooo00?o
09Woooooool01?ooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo0:coool005[oool0
0ol0VOooooooo`05oooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo001Joooo00?o09Woooooool00_ooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool5000000Coool00000
00000004oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00Ioooo`Tco`04oooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000
oooooooo00D0000Boooo00@0003oooooool0000:oooo00@0003oooooooooool300001?ooo`030000
oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000001Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo07Goool006Ooool9
<ol01_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1f
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.28302 .12361 L
.2881 .12361 L
.29088 .12361 L
.29349 .12361 L
.29462 .12361 L
.2957 .12361 L
s
.2957 .12361 m
.2962 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00D0003ooooooooooooo09T00ooo
o`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0U
oooo00<0003oooooool06_ooo`03o`2Ioooooooo00Woool00`0003?o03?o000U<ol000<0000co`0c
o`0093?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool005_oool00ol0VOoo
ooooo`09oooo00<0000co`0co`00Ac?o00D0001Zoooo001Koooo00?o09Woooooool02Oooo`030000
<ol0<ol0048co`050000Koooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000m<ol01@00
07Coool005_oool00ol0VOooooooo`09oooo00<0000co`0co`00>C?o00@0001ioooo001Koooo00?o
09Woooooool02Oooo`80000h<ol00P0007goool005_oool00ol0VOooooooo`09oooo00<0000co`0c
o`00=C?o0080001ooooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol003<co`020000POoo
o`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000a<ol00P0008?oool005_oool00ol0VOoo
ooooo`09oooo00<0000co`0co`00<3?o00030000oooooooo08?oool005_oool00ol0VOooooooo`09
oooo00<0000co`0co`00;S?o00800026oooo001Koooo00?o09Woooooool02Oooo`80000]<ol00P00
08Soool005_oool00ol0VOooooooo`09oooo00<0000co`0co`00:c?o00030000oooooooo08Soool0
05_oool00ol0VOooooooo`09oooo00<0000co`0co`00:S?o00030000oooooooo08Woool005_oool0
0ol0VOooooooo`09oooo00<0000co`0co`00:C?o00030000oooooooo08[oool005_oool00ol0VOoo
ooooo`09oooo00<0000co`0co`00:3?o00030000oooooooo08_oool005_oool00ol0VOooooooo`09
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool005_oool00ol0VOooooooo`09oooo0P00
02Pco`000`000?ooooooo`2<oooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol002Hco`00
0`000?ooooooo`2=oooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol002Dco`000`000?oo
ooooo`2>oooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol002@co`000`000?ooooooo`2?
oooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001K
oooo00?o09Woooooool02Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Koooo00?o
09Woooooool02Oooo`80000S<ol000<0003oooooool0TOooo`00Foooo`03o`2Ioooooooo00Woool0
0`0003?o03?o000Q<ol000<0003oooooool0T_ooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o
03?o000P<ol000<0003oooooool0Toooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000O<ol000<0
003oooooool0U?ooo`00Foooo`04o`2Ioooooooooooo1@0000?oool00`0003?o03?o000O<ol000<0
003oooooool0U?ooo`00Foooo`03o`2Ioooooooo00?oool00`000?ooooooo`03oooo00<0000co`0c
o`007S?o00030000oooooooo09Goool005_oool00ol0VOooooooo`03oooo00<0003oooooool00ooo
o`80000O<ol000<0003oooooool0UOooo`00Foooo`03o`2Ioooooooo00?oool00`000?ooooooo`03
oooo00<0000co`0co`007C?o00030000oooooooo09Koool005_oool00ol0VOooooooo`03oooo00<0
003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`2Foooo001Koooo00?o09Wooooo
ool00_ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo09Ooool005_oool00ol0VOoo
ooooo`09oooo00<0000co`0co`0073?o00030000oooooooo09Ooool005_oool00ol0VOooooooo`09
oooo00<0000co`0co`006c?o00030000oooooooo09Soool005_oool00ol0VOooooooo`09oooo0P00
01`co`000`000?ooooooo`2Hoooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol001Xco`00
0`000?ooooooo`2Ioooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol001Xco`000`000?oo
ooooo`2Ioooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol001Tco`000`000?ooooooo`2J
oooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol001Tco`000`000?ooooooo`2Joooo001K
oooo00?o09Woooooool02Oooo`030000<ol0<ol001Pco`000`000?ooooooo`2Koooo001Koooo00?o
09Woooooool02Oooo`80000I<ol000<0003oooooool0Voooo`00Foooo`03o`2Ioooooooo00Woool0
0`0003?o03?o000G<ol000<0003oooooool0W?ooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o
03?o000G<ol000<0003oooooool0W?ooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000F
<ol000<0003oooooool0WOooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000F<ol000<0
003oooooool0WOooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000F<ol000<0003ooooo
ool0WOooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000E<ol000<0003oooooool0W_oo
o`00Foooo`03o`2Ioooooooo00Woool200005S?o00030000oooooooo09koool005_oool00ol0VOoo
ooooo`09oooo00<0000co`0co`005C?o00030000oooooooo09koool005_oool00ol0VOooooooo`09
oooo00<0000co`0co`005C?o00030000oooooooo09koool005_oool00ol0VOooooooo`09oooo00<0
000co`0co`0053?o00030000oooooooo09ooool005_oool00ol0VOooooooo`09oooo00<0000co`0c
o`0053?o00030000oooooooo09ooool005_oool00ol0VOooooooo`09oooo00<0000co`0co`0053?o
00030000oooooooo09ooool005_oool00ol0VOooooooo`09oooo0P0001Dco`000`000?ooooooo`2O
oooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo001K
oooo00?o09Woooooool02Oooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo001Koooo00?o
09Woooooool02Oooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo001Koooo00Co09Wooooo
ooooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo001Koooo00Go09Wooooo
ooooool000001oooo`030000<ol0<ol0018co`000`000?ooooooo`2Qoooo001Koooo00?o09Wooooo
ool00_ooo`030000oooooooo00Coool200004c?o00030000oooooooo0:7oool005_oool00ol0VOoo
ooooo`03oooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`2Qoooo001K
oooo00Go09Woooooooooool000000_ooo`030000oooooooo00;oool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00Foooo`03o`2Ioooooooo00;oool200001Oooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Roooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol0014co`000`000?ooooooo`2R
oooo001Koooo00?o09Woooooool02Oooo`80000A<ol000<0003oooooool0Xoooo`00Foooo`03o`2I
oooooooo00Woool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00Foooo`03o`2Ioooooooo
00Woool00`0003?o03?o000@<ol000<0003oooooool0Xoooo`00Foooo`03o`2Ioooooooo00Woool0
0`0003?o03?o000@<ol000<0003oooooool0Xoooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o
03?o000?<ol000<0003oooooool0Y?ooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000?
<ol000<0003oooooool0Y?ooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000?<ol000<0
003oooooool0Y?ooo`00Foooo`03o`2Ioooooooo00Woool2000043?o00030000oooooooo0:Coool0
05_oool00ol0VOooooooo`09oooo00<0000co`0co`003S?o00030000oooooooo0:Goool005_oool0
0ol0VOooooooo`09oooo00<0000co`0co`003S?o00030000oooooooo0:Goool005_oool00ol0VOoo
ooooo`09oooo00<0000co`0co`003S?o00030000oooooooo0:Goool005_oool00ol0VOooooooo`09
oooo00<0000co`0co`003S?o00030000oooooooo0:Goool005_oool00ol0VOooooooo`09oooo00<0
000co`0co`003C?o00030000oooooooo0:Koool005_oool00ol0VOooooooo`09oooo0P0000hco`00
0`000?ooooooo`2Voooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`2Voooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol000dco`000`000?ooooooo`2V
oooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001K
oooo00?o09Woooooool02Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001Koooo00?o
09Woooooool02Oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001Koooo00?o09Wooooo
ool02Oooo`80000=<ol000<0003oooooool0Yoooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o
03?o000<<ol000<0003oooooool0Yoooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000<
<ol000<0003oooooool0Yoooo`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000;<ol000<0
003oooooool0Z?ooo`00Foooo`03o`2Ioooooooo00;oool200001Oooo`030000<ol0<ol000/co`00
0`000?ooooooo`2Xoooo001Koooo00Go09Woooooooooool000000_ooo`030000oooooooo00;oool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Foooo`03o`2Ioooooooo00?oool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001Koooo00?o09Woooooool01?ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Foooo`05o`2Ioooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo0:Soool0
05_oool00ol0VOooooooo`02oooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0ZOoo
o`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o000:<ol000<0003oooooool0ZOooo`00Fooo
o`03o`2Ioooooooo00Woool00`0003?o03?o000:<ol000<0003oooooool0ZOooo`00Foooo`03o`2I
oooooooo00Woool00`0003?o03?o000:<ol000<0003oooooool0ZOooo`00Foooo`03o`2Ioooooooo
00Woool200002c?o00030000oooooooo0:Woool005_oool00ol0VOooooooo`09oooo00<0000co`0c
o`002S?o00030000oooooooo0:Woool005_oool00ol0VOooooooo`09oooo00<0000co`0co`002C?o
00030000oooooooo0:[oool005_oool00ol0VOooooooo`09oooo00<0000co`0co`002C?o00030000
oooooooo0:[oool005_oool00ol0VOooooooo`09oooo00<0000co`0co`002C?o00030000oooooooo
0:[oool005_oool00ol0VOooooooo`09oooo00<0000co`0co`002C?o00030000oooooooo0:[oool0
05_oool00ol0VOooooooo`09oooo0P0000Xco`000`000?ooooooo`2Zoooo001Koooo00?o09Wooooo
ool02Oooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo001Koooo00?o09Woooooool02Ooo
o`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo001Koooo00?o09Woooooool02Oooo`030000
<ol0<ol000Pco`000`000?ooooooo`2[oooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol0
00Pco`000`000?ooooooo`2[oooo001Koooo00?o09Woooooool02Oooo`030000<ol0<ol000Pco`00
0`000?ooooooo`2[oooo001Koooo00?o09Woooooool02Oooo`800009<ol000<0003oooooool0Zooo
o`00Foooo`03o`2Ioooooooo00Woool00`0003?o03?o0008<ol000<0003oooooool0Zoooo`00Fooo
o`03o`2Ioooooooo00Woool00`0003?o03?o0008<ol000<0003oooooool0Zoooo`00Foooo`03o`2I
oooooooo00Woool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Foooo`03o`2Ioooooooo
00Woool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Foooo`03o`2Ioooooooo00Woool0
0`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Foooo`03o`2Ioooooooo00Woool2000023?o
00030000oooooooo0:coool005_oool00ol0VOooooooo`09oooo00<0000co`0co`001c?o00030000
oooooooo0:coool005_oool00ol0VOooooooo`09oooo00<0000co`0co`001c?o00030000oooooooo
0:coool005_oool00ol0VOooooooo`09oooo00<0000co`0co`001c?o00030000oooooooo0:coool0
05_oool00ol0VOooooooo`09oooo00<0000co`0co`001c?o00030000oooooooo0:coool005_oool0
0ol0VOooooooo`03oooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Fooo
o`03o`2Ioooooooo00Coool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo
0:coool005_oool01?l0VOooooooooooo`D00003oooo0P0000Pco`000`000?ooooooo`2/oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`06
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool006Ooool9<ol01Oooo`030000oooooooo
00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool500000oooo`<00002
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00D0003oooooooooool00000Moooo`00Ioooo`Tco`04oooo00<0003oooooool00_oo
o`030000oooooooo01?oool010000?ooooooo`0000[oool010000?ooooooooooo`D00003oooo00<0
003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003oooooool01@0001;oool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00Ioooo`Tco`05
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool0
0`000?ooo`000003oooo00<0003oooooool0MOooo`00Ioooo`Tco`06oooo00<0003oooooool05ooo
o`80000:oooo0P0000Goool200000_ooo`030000oooooooo07Koool006Ooool9<ol0/?ooo`00Iooo
o`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30059 .12361 L
.30182 .12361 L
.30246 .12361 L
.30316 .12361 L
s
.30316 .12361 m
.30366 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool00oooo`03o`2I
oooo000000Ooool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool07?ooo`03o`2Ioooooooo00Ooool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool005goool00ol0VOooooooo`07
oooo00<0000co`0co`00Ac?o00D0001Zoooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol0
048co`050000Koooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000m<ol01@0007Coool0
05goool00ol0VOooooooo`07oooo00<0000co`0co`00>C?o00@0001ioooo001Moooo00?o09Wooooo
ool01oooo`80000h<ol00P0007goool005goool00ol0VOooooooo`07oooo00<0000co`0co`00=C?o
0080001ooooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol003<co`020000POooo`00GOoo
o`03o`2Ioooooooo00Ooool00`0003?o03?o000a<ol00P0008?oool005goool00ol0VOooooooo`07
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool005goool00ol0VOooooooo`07oooo00<0
000co`0co`00;S?o00800026oooo001Moooo00?o09Woooooool01oooo`80000]<ol00P0008Soool0
05goool00ol0VOooooooo`07oooo00<0000co`0co`00:c?o00030000oooooooo08Soool005goool0
0ol0VOooooooo`07oooo00<0000co`0co`00:S?o00030000oooooooo08Woool005goool00ol0VOoo
ooooo`07oooo00<0000co`0co`00:C?o00030000oooooooo08[oool005goool00ol0VOooooooo`07
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool005goool00ol0VOooooooo`07oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool005goool00ol0VOooooooo`07oooo0P0002Pco`00
0`000?ooooooo`2<oooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo001M
oooo00?o09Woooooool01oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Moooo00?o
09Woooooool01oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Moooo00?o09Wooooo
ool01oooo`80000S<ol000<0003oooooool0TOooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00GOooo`03o`2Ioooo000000@00003oooo00<0000co`0co`007c?o00030000oooooooo
09Coool005goool01Ol0VOooooooooooo`000005oooo00<0000co`0co`007S?o00030000oooooooo
09Goool005goool01Ol0VOooooooooooo`000005oooo0P0001lco`000`000?ooooooo`2Eoooo001M
oooo00Go09Woooooooooool000001Oooo`030000<ol0<ol001dco`000`000?ooooooo`2Foooo001M
oooo00Go09Woooooooooool000001Oooo`030000<ol0<ol001dco`000`000?ooooooo`2Foooo001M
oooo00?o09Woooooool00P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00GOoo
o`03o`2Ioooooooo00Ooool00`0003?o03?o000L<ol000<0003oooooool0Uoooo`00GOooo`03o`2I
oooooooo00Ooool00`0003?o03?o000K<ol000<0003oooooool0V?ooo`00GOooo`03o`2Ioooooooo
00Ooool2000073?o00030000oooooooo09Soool005goool00ol0VOooooooo`07oooo00<0000co`0c
o`006S?o00030000oooooooo09Woool005goool00ol0VOooooooo`07oooo00<0000co`0co`006S?o
00030000oooooooo09Woool005goool00ol0VOooooooo`07oooo00<0000co`0co`006C?o00030000
oooooooo09[oool005goool00ol0VOooooooo`07oooo00<0000co`0co`006C?o00030000oooooooo
09[oool005goool00ol0VOooooooo`07oooo00<0000co`0co`0063?o00030000oooooooo09_oool0
05goool00ol0VOooooooo`07oooo0P0001Tco`000`000?ooooooo`2Koooo001Moooo00?o09Wooooo
ool01oooo`030000<ol0<ol001Lco`000`000?ooooooo`2Loooo001Moooo00?o09Woooooool01ooo
o`030000<ol0<ol001Lco`000`000?ooooooo`2Loooo001Moooo00?o09Woooooool01oooo`030000
<ol0<ol001Hco`000`000?ooooooo`2Moooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`2Moooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`2Noooo001Moooo00?o09Woooooool01oooo`80000F<ol000<0003oooooool0W_ooo`00GOoo
o`03o`2Ioooooooo00Ooool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00GOooo`03o`2I
oooooooo00Ooool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00GOooo`03o`2Ioooooooo
00Ooool00`0003?o03?o000D<ol000<0003oooooool0Woooo`00GOooo`03o`2Ioooooooo00Ooool0
0`0003?o03?o000D<ol000<0003oooooool0Woooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o
03?o000D<ol000<0003oooooool0Woooo`00GOooo`03o`2Ioooooooo00Ooool200005C?o00030000
oooooooo09ooool005goool00ol0VOooooooo`07oooo00<0000co`0co`004c?o00030000oooooooo
0:3oool005goool00ol0VOooooooo`07oooo00<0000co`0co`004c?o00030000oooooooo0:3oool0
05goool00ol0VOooooooo`07oooo00<0000co`0co`004c?o00030000oooooooo0:3oool005goool0
0ol0VOooo`00000300001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo001Moooo00?o
09Woool000001oooo`030000<ol0<ol0018co`000`000?ooooooo`2Qoooo001Moooo00Co09Wooooo
ool00006oooo0P0001<co`000`000?ooooooo`2Qoooo001Moooo00Go09Woooooooooool000001Ooo
o`030000<ol0<ol0018co`000`000?ooooooo`2Qoooo001Moooo00?o09Woool000000_ooo`030000
oooooooo00;oool00`0003?o03?o000A<ol000<0003oooooool0X_ooo`00GOooo`03o`2Ioooooooo
00800005oooo00<0000co`0co`004C?o00030000oooooooo0:;oool005goool00ol0VOooooooo`07
oooo00<0000co`0co`004C?o00030000oooooooo0:;oool005goool00ol0VOooooooo`07oooo00<0
000co`0co`004C?o00030000oooooooo0:;oool005goool00ol0VOooooooo`07oooo0P00014co`00
0`000?ooooooo`2Soooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol0010co`000`000?oo
ooooo`2Soooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol0010co`000`000?ooooooo`2S
oooo001Moooo00?o09Woooooool01oooo`030000<ol0<ol0010co`000`000?ooooooo`2Soooo001M
oooo00?o09Woooooool01oooo`030000<ol0<ol000lco`000`000?ooooooo`2Toooo001Moooo00?o
09Woooooool01oooo`030000<ol0<ol000lco`000`000?ooooooo`2Toooo001Moooo00?o09Wooooo
ool01oooo`030000<ol0<ol000lco`000`000?ooooooo`2Toooo001Moooo00?o09Woooooool01ooo
o`80000@<ol000<0003oooooool0Y?ooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000>
<ol000<0003oooooool0YOooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000><ol000<0
003oooooool0YOooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000><ol000<0003ooooo
ool0YOooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000><ol000<0003oooooool0YOoo
o`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000=<ol000<0003oooooool0Y_ooo`00GOoo
o`03o`2Ioooooooo00Ooool200003S?o00030000oooooooo0:Koool005goool00ol0VOooooooo`07
oooo00<0000co`0co`003C?o00030000oooooooo0:Koool005goool00ol0VOooooooo`07oooo00<0
000co`0co`003C?o00030000oooooooo0:Koool005goool00ol0VOooooooo`07oooo00<0000co`0c
o`0033?o00030000oooooooo0:Ooool005goool00ol0VOooooooo`07oooo00<0000co`0co`0033?o
00030000oooooooo0:Ooool005goool00ol0VOooooooo`07oooo00<0000co`0co`0033?o00030000
oooooooo0:Ooool005goool00ol0VOooooooo`07oooo0P0000dco`000`000?ooooooo`2Woooo001M
oooo00?o09Woooooool01oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001Moooo00?o
09Woooooool01oooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001Moooo00?o09Wooooo
ool01oooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001Moooo00?o09Woooooool00P00
00Goool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00GOooo`03o`2Ioooo000000;oool0
0`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo0:Soool005goool01Ol0VOoo
ooooooooo`000005oooo0P0000`co`000`000?ooooooo`2Xoooo001Moooo00?o09Woooooool00_oo
o`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00GOooo`03o`2I
oooo000000;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo0:Soool0
05goool00ol0VOooooooo`0200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001M
oooo00?o09Woooooool01oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Moooo00?o
09Woooooool01oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Moooo00?o09Wooooo
ool01oooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Moooo00?o09Woooooool01ooo
o`80000;<ol000<0003oooooool0ZOooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000:
<ol000<0003oooooool0ZOooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00GOoo
o`03o`2Ioooooooo00Ooool200002S?o00030000oooooooo0:[oool005goool00ol0VOooooooo`07
oooo00<0000co`0co`002C?o00030000oooooooo0:[oool005goool00ol0VOooooooo`07oooo00<0
000co`0co`002C?o00030000oooooooo0:[oool005goool00ol0VOooooooo`07oooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool005goool00ol0VOooooooo`07oooo00<0000co`0co`0023?o
00030000oooooooo0:_oool005goool00ol0VOooooooo`07oooo00<0000co`0co`0023?o00030000
oooooooo0:_oool005goool00ol0VOooooooo`07oooo0P0000Tco`000`000?ooooooo`2[oooo001M
oooo00?o09Woooooool01oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001Moooo00?o
09Woooooool01oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001Moooo00?o09Wooooo
ool01oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Moooo00?o09Woooooool01ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Moooo00?o09Woooooool01oooo`030000
<ol0<ol000Lco`000`000?ooooooo`2/oooo001Moooo00?o09Woooooool01oooo`800008<ol000<0
003oooooool0[?ooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00GOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00GOoo
o`03o`2Ioooooooo00Ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00GOooo`04o`2I
oooooooooooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00GOooo`03o`2I
oooooooo00;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo0:coool0
05goool00ol0VOooo`00000400000oooo`800008<ol000<0003oooooool0[?ooo`00Goooo`040000
oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P00
00Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol01_ooo`030000
oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?ooooooo`08oooo00<0
003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00goool200001?ooo`800003oooo1@000003oooo0000000000800003
oooo00<0003oooooool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool01@000?oo
ooooooooo`000006oooo00<0003oooooool0MOooo`00Ioooo`Tco`04oooo00<0003oooooool00_oo
o`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000oooooooo00D0000Boooo00@0
003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`1e
oooo001Woooo2C?o00Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool0000:oooo00D0
003oooooooooool000000_ooo`050000oooooooooooo000007Ooool006Ooool9<ol01_ooo`030000
oooooooo01Ooool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1foooo001Woooo2C?o
0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30316 .12361 L
.3056 .12361 L
.30791 .12361 L
.30919 .12361 L
s
.30919 .12361 m
.30948 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool07_ooo`03o`2Ioooooooo00Goool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool005ooool00ol0VOooooooo`05
oooo00<0000co`0co`00Ac?o00D0001Zoooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol0
048co`050000Koooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o000m<ol01@0007Coool0
05ooool00ol0VOooooooo`05oooo00<0000co`0co`00>C?o00@0001ioooo001Ooooo00?o09Wooooo
ool01Oooo`80000h<ol00P0007goool005ooool00ol0VOooooooo`05oooo00<0000co`0co`00=C?o
0080001ooooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol003<co`020000POooo`00Gooo
o`03o`2Ioooooooo00Goool00`0003?o03?o000a<ol00P0008?oool005ooool00ol0VOooooooo`05
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool005ooool00ol0VOooooooo`05oooo00<0
000co`0co`00;S?o00800026oooo001Ooooo00?o09Woooooool01Oooo`80000]<ol00P0008Soool0
05ooool00ol0VOooooooo`05oooo00<0000co`0co`00:c?o00030000oooooooo08Soool005ooool0
0ol0VOooooooo`05oooo00<0000co`0co`00:S?o00030000oooooooo08Woool005ooool00ol0VOoo
ooooo`05oooo00<0000co`0co`00:C?o00030000oooooooo08[oool005ooool00ol0VOooooooo`05
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool005ooool00ol0VOooooooo`05oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool005ooool00ol0VOooooooo`05oooo0P0002Pco`00
0`000?ooooooo`2<oooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo001O
oooo00?o09Woooooool01Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Ooooo00?o
09Woooooool01Oooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Ooooo00?o09Wooooo
ool01Oooo`80000S<ol000<0003oooooool0TOooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo09Coool005ooool0
0ol0VOooo`000005oooo00<0000co`0co`007S?o00030000oooooooo09Goool005ooool00ol0VOoo
o`000005oooo0P0001lco`000`000?ooooooo`2Eoooo001Ooooo00?o09Woool000001Oooo`030000
<ol0<ol001dco`000`000?ooooooo`2Foooo001Ooooo00?o09Woool000001Oooo`030000<ol0<ol0
01dco`000`000?ooooooo`2Foooo001Ooooo00?o09T0000000001Oooo`030000<ol0<ol001`co`00
0`000?ooooooo`2Goooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol001`co`000`000?oo
ooooo`2Goooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol001/co`000`000?ooooooo`2H
oooo001Ooooo00?o09Woooooool01Oooo`80000L<ol000<0003oooooool0V?ooo`00Goooo`03o`2I
oooooooo00Goool00`0003?o03?o000J<ol000<0003oooooool0VOooo`00Goooo`03o`2Ioooooooo
00Goool00`0003?o03?o000J<ol000<0003oooooool0VOooo`00Goooo`03o`2Ioooooooo00Goool0
0`0003?o03?o000I<ol000<0003oooooool0V_ooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o
03?o000I<ol000<0003oooooool0V_ooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o000H
<ol000<0003oooooool0Voooo`00Goooo`03o`2Ioooooooo00Goool200006C?o00030000oooooooo
09_oool005ooool00ol0VOooooooo`05oooo00<0000co`0co`005c?o00030000oooooooo09coool0
05ooool00ol0VOooooooo`05oooo00<0000co`0co`005c?o00030000oooooooo09coool005ooool0
0ol0VOooooooo`05oooo00<0000co`0co`005S?o00030000oooooooo09goool005ooool00ol0VOoo
ooooo`05oooo00<0000co`0co`005S?o00030000oooooooo09goool005ooool00ol0VOooooooo`05
oooo00<0000co`0co`005S?o00030000oooooooo09goool005ooool00ol0VOooooooo`05oooo00<0
000co`0co`005C?o00030000oooooooo09koool005ooool00ol0VOooooooo`05oooo0P0001Hco`00
0`000?ooooooo`2Noooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`2Noooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol001Dco`000`000?ooooooo`2N
oooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol001@co`000`000?ooooooo`2Ooooo001O
oooo00?o09Woooooool01Oooo`030000<ol0<ol001@co`000`000?ooooooo`2Ooooo001Ooooo00?o
09Woooooool01Oooo`030000<ol0<ol001@co`000`000?ooooooo`2Ooooo001Ooooo00?o09Wooooo
ool01Oooo`80000E<ol000<0003oooooool0Woooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o
03?o000C<ol000<0003oooooool0X?ooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o000C
<ol000<0003oooooool0X?ooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o000C<ol000<0
003oooooool0X?ooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo0:3oool0
05ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo0:7oool005ooool0
0ol0V@000?ooo`05oooo0P0001<co`000`000?ooooooo`2Qoooo001Ooooo00?o09Woool000001Ooo
o`030000<ol0<ol0018co`000`000?ooooooo`2Qoooo001Ooooo00@0003oooooool00004oooo00<0
000co`0co`004C?o00030000oooooooo0:;oool005ooool00ol0V@0000000005oooo00<0000co`0c
o`004C?o00030000oooooooo0:;oool005ooool00ol0VOooooooo`05oooo00<0000co`0co`004C?o
00030000oooooooo0:;oool005ooool00ol0VOooooooo`05oooo00<0000co`0co`004C?o00030000
oooooooo0:;oool005ooool00ol0VOooooooo`05oooo0P00014co`000`000?ooooooo`2Soooo001O
oooo00?o09Woooooool01Oooo`030000<ol0<ol0010co`000`000?ooooooo`2Soooo001Ooooo00?o
09Woooooool01Oooo`030000<ol0<ol0010co`000`000?ooooooo`2Soooo001Ooooo00?o09Wooooo
ool01Oooo`030000<ol0<ol0010co`000`000?ooooooo`2Soooo001Ooooo00?o09Woooooool01Ooo
o`030000<ol0<ol000lco`000`000?ooooooo`2Toooo001Ooooo00?o09Woooooool01Oooo`030000
<ol0<ol000lco`000`000?ooooooo`2Toooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`2Toooo001Ooooo00?o09Woooooool01Oooo`80000@<ol000<0003ooooo
ool0Y?ooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o000><ol000<0003oooooool0YOoo
o`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o000><ol000<0003oooooool0YOooo`00Gooo
o`03o`2Ioooooooo00Goool00`0003?o03?o000><ol000<0003oooooool0YOooo`00Goooo`03o`2I
oooooooo00Goool00`0003?o03?o000><ol000<0003oooooool0YOooo`00Goooo`03o`2Ioooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0Y_ooo`00Goooo`03o`2Ioooooooo00Goool2
00003S?o00030000oooooooo0:Koool005ooool00ol0VOooooooo`05oooo00<0000co`0co`003C?o
00030000oooooooo0:Koool005ooool00ol0VOooooooo`05oooo00<0000co`0co`003C?o00030000
oooooooo0:Koool005ooool00ol0VOooooooo`05oooo00<0000co`0co`0033?o00030000oooooooo
0:Ooool005ooool00ol0VOooooooo`05oooo00<0000co`0co`0033?o00030000oooooooo0:Ooool0
05ooool00ol0VOooooooo`05oooo00<0000co`0co`0033?o00030000oooooooo0:Ooool005ooool0
0ol0VOooooooo`05oooo0P0000dco`000`000?ooooooo`2Woooo001Ooooo00?o09Woooooool01Ooo
o`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001Ooooo00?o09Woooooool01Oooo`030000
<ol0<ol000`co`000`000?ooooooo`2Woooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo001Ooooo00?o09T0000000001Oooo`030000<ol0<ol000/co`00
0`000?ooooooo`2Xoooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000
oooooooo0:Soool005ooool00ol0VOooo`000005oooo0P0000`co`000`000?ooooooo`2Xoooo001O
oooo00Co09Woooooool00004oooo00<0000co`0co`002c?o00030000oooooooo0:Soool005ooool0
10000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Goooo`03o`2I
0000000000Goool00`0003?o03?o000:<ol000<0003oooooool0ZOooo`00Goooo`03o`2Ioooooooo
00Goool00`0003?o03?o000:<ol000<0003oooooool0ZOooo`00Goooo`03o`2Ioooooooo00Goool0
0`0003?o03?o000:<ol000<0003oooooool0ZOooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o
03?o000:<ol000<0003oooooool0ZOooo`00Goooo`03o`2Ioooooooo00Goool200002c?o00030000
oooooooo0:Woool005ooool00ol0VOooooooo`05oooo00<0000co`0co`002S?o00030000oooooooo
0:Woool005ooool00ol0VOooooooo`05oooo00<0000co`0co`002C?o00030000oooooooo0:[oool0
05ooool00ol0VOooooooo`05oooo00<0000co`0co`002C?o00030000oooooooo0:[oool005ooool0
0ol0VOooooooo`05oooo00<0000co`0co`002C?o00030000oooooooo0:[oool005ooool00ol0VOoo
ooooo`05oooo00<0000co`0co`002C?o00030000oooooooo0:[oool005ooool00ol0VOooooooo`05
oooo0P0000Xco`000`000?ooooooo`2Zoooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol0
00Tco`000`000?ooooooo`2Zoooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol000Tco`00
0`000?ooooooo`2Zoooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol000Pco`000`000?oo
ooooo`2[oooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[
oooo001Ooooo00?o09Woooooool01Oooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001O
oooo00?o09Woooooool01Oooo`800009<ol000<0003oooooool0Zoooo`00Goooo`03o`2Ioooooooo
00Goool00`0003?o03?o0008<ol000<0003oooooool0Zoooo`00Goooo`03o`2Ioooooooo00Goool0
0`0003?o03?o0008<ol000<0003oooooool0Zoooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o
03?o0007<ol000<0003oooooool0[?ooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o0007
<ol000<0003oooooool0[?ooo`00Goooo`03o`2Ioooooooo00Goool00`0003?o03?o0007<ol000<0
003oooooool0[?ooo`00Goooo`03o`2Ioooooooo00Goool2000023?o00030000oooooooo0:coool0
05ooool00ol0VOooooooo`05oooo00<0000co`0co`001c?o00030000oooooooo0:coool005ooool0
0ol0VOooooooo`05oooo00<0000co`0co`001c?o00030000oooooooo0:coool005ooool00ol0VOoo
ooooo`05oooo00<0000co`0co`001c?o00030000oooooooo0:coool005ooool00ol0VOooooooo`05
oooo00<0000co`0co`001c?o00030000oooooooo0:coool005ooool00ol0VOooo`00000200000ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Ooooo00Co09Woooooool00004oooo00<0
000co`0co`001c?o00030000oooooooo0:coool005ooool500000oooo`800008<ol000<0003ooooo
ool0[?ooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?oo
o`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool0
06Ooool9<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo1@00
00;oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_ooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0
003oooooool04oooo`040000oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`1g
oooo001Woooo2C?o00Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000E
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool006Ooool9
<ol02Oooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00Iooo
o`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.30791 .12361 L
.31054 .12361 L
.31304 .12361 L
.31444 .12361 L
.31523 .12361 L
s
.31523 .12361 m
.31553 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
o`2Ioooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool07oooo`03o`2Ioooooooo00Coool00`0003?o03?o000U<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool0063oool00ol0VOooooooo`04
oooo00<0000co`0co`00Ac?o00D0001Zoooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol0
048co`050000Koooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000m<ol01@0007Coool0
063oool00ol0VOooooooo`04oooo00<0000co`0co`00>C?o00@0001ioooo001Poooo00?o09Wooooo
ool01?ooo`80000h<ol00P0007goool0063oool00ol0VOooooooo`04oooo00<0000co`0co`00=C?o
0080001ooooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol003<co`020000POooo`00H?oo
o`03o`2Ioooooooo00Coool00`0003?o03?o000a<ol00P0008?oool0063oool00ol0VOooooooo`04
oooo00<0000co`0co`00<3?o00030000oooooooo08?oool0063oool00ol0VOooooooo`04oooo00<0
000co`0co`00;S?o00800026oooo001Poooo00?o09Woooooool01?ooo`80000]<ol00P0008Soool0
063oool00ol0VOooooooo`04oooo00<0000co`0co`00:c?o00030000oooooooo08Soool0063oool0
0ol0VOooooooo`04oooo00<0000co`0co`00:S?o00030000oooooooo08Woool0063oool00ol0VOoo
ooooo`04oooo00<0000co`0co`00:C?o00030000oooooooo08[oool0063oool00ol0VOooooooo`04
oooo00<0000co`0co`00:3?o00030000oooooooo08_oool0063oool00ol0VOooooooo`04oooo00<0
000co`0co`00:3?o00030000oooooooo08_oool0063oool00ol0VOooooooo`04oooo0P0002Pco`00
0`000?ooooooo`2<oooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol002Hco`000`000?oo
ooooo`2=oooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol002Dco`000`000?ooooooo`2>
oooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol002@co`000`000?ooooooo`2?oooo001P
oooo00?o09Woooooool01?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Poooo00?o
09Woooooool01?ooo`030000<ol0<ol002<co`000`000?ooooooo`2@oooo001Poooo00?o09Wooooo
ool01?ooo`80000S<ol000<0003oooooool0TOooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o
03?o000Q<ol000<0003oooooool0T_ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000P
<ol000<0003oooooool0Toooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000P<ol000<0
003oooooool0Toooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000O<ol000<0003ooooo
ool0U?ooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo09Coool0063oool0
0ol0V@000?ooo`04oooo00<0000co`0co`007S?o00030000oooooooo09Goool0063oool00ol0V@00
0?ooo`04oooo0P0001lco`000`000?ooooooo`2Eoooo001Poooo00?o09T0003oool01?ooo`030000
<ol0<ol001dco`000`000?ooooooo`2Foooo001Poooo00?o09T0003oool01?ooo`030000<ol0<ol0
01dco`000`000?ooooooo`2Foooo001Poooo0P0000Goool00`0003?o03?o000L<ol000<0003ooooo
ool0Uoooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000L<ol000<0003oooooool0Uooo
o`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000K<ol000<0003oooooool0V?ooo`00H?oo
o`03o`2Ioooooooo00Coool2000073?o00030000oooooooo09Soool0063oool00ol0VOooooooo`04
oooo00<0000co`0co`006S?o00030000oooooooo09Woool0063oool00ol0VOooooooo`04oooo00<0
000co`0co`006S?o00030000oooooooo09Woool0063oool00ol0VOooooooo`04oooo00<0000co`0c
o`006C?o00030000oooooooo09[oool0063oool00ol0VOooooooo`04oooo00<0000co`0co`006C?o
00030000oooooooo09[oool0063oool00ol0VOooooooo`04oooo00<0000co`0co`0063?o00030000
oooooooo09_oool0063oool00ol0VOooooooo`04oooo0P0001Tco`000`000?ooooooo`2Koooo001P
oooo00?o09Woooooool01?ooo`030000<ol0<ol001Lco`000`000?ooooooo`2Loooo001Poooo00?o
09Woooooool01?ooo`030000<ol0<ol001Lco`000`000?ooooooo`2Loooo001Poooo00?o09Wooooo
ool01?ooo`030000<ol0<ol001Hco`000`000?ooooooo`2Moooo001Poooo00?o09Woooooool01?oo
o`030000<ol0<ol001Hco`000`000?ooooooo`2Moooo001Poooo00?o09Woooooool01?ooo`030000
<ol0<ol001Hco`000`000?ooooooo`2Moooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol0
01Dco`000`000?ooooooo`2Noooo001Poooo00?o09Woooooool01?ooo`80000F<ol000<0003ooooo
ool0W_ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000E<ol000<0003oooooool0W_oo
o`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000E<ol000<0003oooooool0W_ooo`00H?oo
o`03o`2Ioooooooo00Coool00`0003?o03?o000D<ol000<0003oooooool0Woooo`00H?ooo`03o`2I
oooooooo00Coool00`0003?o03?o000D<ol000<0003oooooool0Woooo`00H?ooo`03o`2Ioooooooo
00Coool00`0003?o03?o000D<ol000<0003oooooool0Woooo`00H?ooo`03o`2Ioooooooo00Coool2
00005C?o00030000oooooooo09ooool0063oool00ol0VOooooooo`04oooo00<0000co`0co`004c?o
00030000oooooooo0:3oool0063oool00ol0VOooooooo`04oooo00<0000co`0co`004c?o00030000
oooooooo0:3oool0063oool00ol0VOooooooo`04oooo00<0000co`0co`004c?o00030000oooooooo
0:3oool005ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo001Ooooo00<0
003o09Woool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`2Qoooo001Poooo00<0003ooooo
ool01?ooo`80000C<ol000<0003oooooool0XOooo`00H?ooo`03o`2I0000oooo00Coool00`0003?o
03?o000B<ol000<0003oooooool0XOooo`00Goooo`040000o`2Ioooo00001?ooo`030000<ol0<ol0
014co`000`000?ooooooo`2Roooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003ooooo
ool0X_ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000A<ol000<0003oooooool0X_oo
o`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000A<ol000<0003oooooool0X_ooo`00H?oo
o`03o`2Ioooooooo00Coool200004C?o00030000oooooooo0:?oool0063oool00ol0VOooooooo`04
oooo00<0000co`0co`0043?o00030000oooooooo0:?oool0063oool00ol0VOooooooo`04oooo00<0
000co`0co`0043?o00030000oooooooo0:?oool0063oool00ol0VOooooooo`04oooo00<0000co`0c
o`0043?o00030000oooooooo0:?oool0063oool00ol0VOooooooo`04oooo00<0000co`0co`003c?o
00030000oooooooo0:Coool0063oool00ol0VOooooooo`04oooo00<0000co`0co`003c?o00030000
oooooooo0:Coool0063oool00ol0VOooooooo`04oooo00<0000co`0co`003c?o00030000oooooooo
0:Coool0063oool00ol0VOooooooo`04oooo0P00010co`000`000?ooooooo`2Toooo001Poooo00?o
09Woooooool01?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Poooo00?o09Wooooo
ool01?ooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Poooo00?o09Woooooool01?oo
o`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001Poooo00?o09Woooooool01?ooo`030000
<ol0<ol000hco`000`000?ooooooo`2Uoooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol0
00dco`000`000?ooooooo`2Voooo001Poooo00?o09Woooooool01?ooo`80000><ol000<0003ooooo
ool0Y_ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000=<ol000<0003oooooool0Y_oo
o`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000=<ol000<0003oooooool0Y_ooo`00H?oo
o`03o`2Ioooooooo00Coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00H?ooo`03o`2I
oooooooo00Coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00H?ooo`03o`2Ioooooooo
00Coool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00H?ooo`03o`2Ioooooooo00Coool2
00003C?o00030000oooooooo0:Ooool0063oool00ol0VOooooooo`04oooo00<0000co`0co`0033?o
00030000oooooooo0:Ooool0063oool00ol0VOooooooo`04oooo00<0000co`0co`0033?o00030000
oooooooo0:Ooool0063oool00ol0VOooooooo`04oooo00<0000co`0co`002c?o00030000oooooooo
0:Soool0063oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001Ooooo00@0
003o09Woool00004oooo00<0000co`0co`002c?o00030000oooooooo0:Soool0063oool00ol0V@00
0?ooo`04oooo0P0000`co`000`000?ooooooo`2Xoooo001Poooo00?o09Woool000001?ooo`030000
<ol0<ol000/co`000`000?ooooooo`2Xoooo001Ooooo00@0003o09Woool00004oooo00<0000co`0c
o`002c?o00030000oooooooo0:Soool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?oo
ooooo`2Yoooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Y
oooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001P
oooo00?o09Woooooool01?ooo`030000<ol0<ol000Xco`000`000?ooooooo`2Yoooo001Poooo00?o
09Woooooool01?ooo`80000;<ol000<0003oooooool0ZOooo`00H?ooo`03o`2Ioooooooo00Coool0
0`0003?o03?o000:<ol000<0003oooooool0ZOooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o
03?o0009<ol000<0003oooooool0Z_ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0009
<ol000<0003oooooool0Z_ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0009<ol000<0
003oooooool0Z_ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0009<ol000<0003ooooo
ool0Z_ooo`00H?ooo`03o`2Ioooooooo00Coool200002S?o00030000oooooooo0:[oool0063oool0
0ol0VOooooooo`04oooo00<0000co`0co`002C?o00030000oooooooo0:[oool0063oool00ol0VOoo
ooooo`04oooo00<0000co`0co`002C?o00030000oooooooo0:[oool0063oool00ol0VOooooooo`04
oooo00<0000co`0co`0023?o00030000oooooooo0:_oool0063oool00ol0VOooooooo`04oooo00<0
000co`0co`0023?o00030000oooooooo0:_oool0063oool00ol0VOooooooo`04oooo00<0000co`0c
o`0023?o00030000oooooooo0:_oool0063oool00ol0VOooooooo`04oooo0P0000Tco`000`000?oo
ooooo`2[oooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[
oooo001Poooo00?o09Woooooool01?ooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001P
oooo00?o09Woooooool01?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Poooo00?o
09Woooooool01?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Poooo00?o09Wooooo
ool01?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Poooo00?o09Woooooool01?oo
o`800008<ol000<0003oooooool0[?ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0007
<ol000<0003oooooool0[?ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0007<ol000<0
003oooooool0[?ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0007<ol000<0003ooooo
ool0[?ooo`00H?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00H?ooo`04o`2I0000000000000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001P
oooo00?o09Woool000001?ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Ooooo1@00
00?oool2000023?o00030000oooooooo0:coool005ooool010000?ooooooo`0000Coool:<ol0[ooo
o`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9
<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Koool00`000?ooooooo`0^oooo00<0003ooooo
ool0M_ooo`00Ioooo`Tco`05oooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?oo
ooooo`1eoooo001Woooo2C?o00Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=
oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1eoooo001Woooo2C?o
00Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00000oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Goool006Ooool9<ol01?ooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00004oooo00<0
003oooooool0M?ooo`00Ioooo`Tco`05oooo00<0003oooooool01@0001;oool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool200001?ooo`030000oooooooo07Goool006Ooool9<ol01Ooo
o`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool0
10000?ooooooo`0000?oool00`000?ooooooo`1eoooo001Woooo2C?o00Koool00`000?ooooooo`0G
oooo0P0000[oool200001?ooo`800003oooo00<0003oooooool0M_ooo`00Ioooo`Tco`2`oooo001W
oooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.31304 .12361 L
.31574 .12361 L
.31865 .12361 L
.32006 .12361 L
.32076 .12361 L
.3214 .12361 L
s
.3214 .12361 m
.32188 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`040000
ooooooooo`2I1?ooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Qoooo00?o09Woooooool00_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00H_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o0017<ol01@0006[oool006;oool00ol0VOooooooo`02oooo00<0000co`0c
o`00@S?o00D0001_oooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol003dco`050000M?oo
o`00H_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000i<ol0100007Woool006;oool00ol0VOoo
ooooo`02oooo0P0003Pco`020000OOooo`00H_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000e
<ol00P0007ooool006;oool00ol0VOooooooo`02oooo00<0000co`0co`00<c?o00800021oooo001R
oooo00?o09Woooooool00_ooo`030000<ol0<ol0034co`020000Poooo`00H_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o000`<ol000<0003oooooool0Poooo`00H_ooo`03o`2Ioooooooo00;oool0
0`0003?o03?o000^<ol00P0008Koool006;oool00ol0VOooooooo`02oooo0P0002dco`020000R?oo
o`00H_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000[<ol000<0003oooooool0R?ooo`00H_oo
o`03o`2Ioooooooo00;oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`00H_ooo`03o`2I
oooooooo00;oool00`0003?o03?o000Y<ol000<0003oooooool0R_ooo`00H_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o000X<ol000<0003oooooool0Roooo`00H_ooo`03o`2Ioooooooo00;oool0
0`0003?o03?o000X<ol000<0003oooooool0Roooo`00H_ooo`03o`2Ioooooooo00;oool20000:3?o
00030000oooooooo08coool006;oool00ol0VOooooooo`02oooo00<0000co`0co`009S?o00030000
oooooooo08goool006;oool00ol0VOooooooo`02oooo00<0000co`0co`009C?o00030000oooooooo
08koool006;oool00ol0VOooooooo`02oooo00<0000co`0co`0093?o00030000oooooooo08ooool0
06;oool00ol0VOooooooo`02oooo00<0000co`0co`008c?o00030000oooooooo093oool006;oool0
0ol0VOooooooo`02oooo00<0000co`0co`008c?o00030000oooooooo093oool006;oool00ol0VOoo
ooooo`02oooo0P0002<co`000`000?ooooooo`2Aoooo001Roooo00?o09Woooooool00_ooo`030000
<ol0<ol0024co`000`000?ooooooo`2Boooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol0
020co`000`000?ooooooo`2Coooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol0020co`00
0`000?ooooooo`2Coooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Doooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003oooooool0U?ooo`00HOoo
o`030000o`2Ioooo00?oool00`0003?o03?o000N<ol000<0003oooooool0UOooo`00HOooo`030000
o`2Ioooo00?oool200007c?o00030000oooooooo09Goool0067oool00`000?l0VOooo`03oooo00<0
000co`0co`007C?o00030000oooooooo09Koool0067oool00`000?l0VOooo`03oooo00<0000co`0c
o`007C?o00030000oooooooo09Koool0063oool2000000?o09Woooooool00_ooo`030000<ol0<ol0
01`co`000`000?ooooooo`2Goooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol001`co`00
0`000?ooooooo`2Goooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol001/co`000`000?oo
ooooo`2Hoooo001Roooo00?o09Woooooool00_ooo`80000L<ol000<0003oooooool0V?ooo`00H_oo
o`03o`2Ioooooooo00;oool00`0003?o03?o000J<ol000<0003oooooool0VOooo`00H_ooo`03o`2I
oooooooo00;oool00`0003?o03?o000J<ol000<0003oooooool0VOooo`00H_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o000I<ol000<0003oooooool0V_ooo`00H_ooo`03o`2Ioooooooo00;oool0
0`0003?o03?o000I<ol000<0003oooooool0V_ooo`00H_ooo`03o`2Ioooooooo00;oool00`0003?o
03?o000H<ol000<0003oooooool0Voooo`00H_ooo`03o`2Ioooooooo00;oool200006C?o00030000
oooooooo09_oool006;oool00ol0VOooooooo`02oooo00<0000co`0co`005c?o00030000oooooooo
09coool006;oool00ol0VOooooooo`02oooo00<0000co`0co`005c?o00030000oooooooo09coool0
06;oool00ol0VOooooooo`02oooo00<0000co`0co`005S?o00030000oooooooo09goool006;oool0
0ol0VOooooooo`02oooo00<0000co`0co`005S?o00030000oooooooo09goool006;oool00ol0VOoo
ooooo`02oooo00<0000co`0co`005S?o00030000oooooooo09goool006;oool00ol0VOooooooo`02
oooo00<0000co`0co`005C?o00030000oooooooo09koool006;oool00ol0VOooooooo`02oooo0P00
01Hco`000`000?ooooooo`2Noooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol001Dco`00
0`000?ooooooo`2Noooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol001Dco`000`000?oo
ooooo`2Noooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol001@co`000`000?ooooooo`2O
oooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol001@co`000`000?ooooooo`2Ooooo001R
oooo00?o09Woooooool00_ooo`030000<ol0<ol001@co`000`000?ooooooo`2Ooooo001Roooo00?o
09Woooooool00_ooo`80000E<ol000<0003oooooool0Woooo`00H_ooo`03o`2Ioooooooo00;oool0
0`0003?o03?o000C<ol000<0003oooooool0X?ooo`00H_ooo`03o`2Ioooooooo00;oool00`0003?o
03?o000C<ol000<0003oooooool0X?ooo`00H_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000C
<ol000<0003oooooool0X?ooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo
0:3oool005ooool010000?ooooooool0V@Coool00`0003?o03?o000B<ol000<0003oooooool0XOoo
o`00H?ooo`030000ooooo`2I00Coool200004c?o00030000oooooooo0:7oool0067oool00`000?l0
VOooo`03oooo00<0000co`0co`004S?o00030000oooooooo0:7oool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000A<ol000<0003oooooool0X_ooo`00H?ooo`8000000ol0VOooooooo`02
oooo00<0000co`0co`004C?o00030000oooooooo0:;oool006;oool00ol0VOooooooo`02oooo00<0
000co`0co`004C?o00030000oooooooo0:;oool006;oool00ol0VOooooooo`02oooo00<0000co`0c
o`004C?o00030000oooooooo0:;oool006;oool00ol0VOooooooo`02oooo0P00014co`000`000?oo
ooooo`2Soooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol0010co`000`000?ooooooo`2S
oooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol0010co`000`000?ooooooo`2Soooo001R
oooo00?o09Woooooool00_ooo`030000<ol0<ol0010co`000`000?ooooooo`2Soooo001Roooo00?o
09Woooooool00_ooo`030000<ol0<ol000lco`000`000?ooooooo`2Toooo001Roooo00?o09Wooooo
ool00_ooo`030000<ol0<ol000lco`000`000?ooooooo`2Toooo001Roooo00?o09Woooooool00_oo
o`030000<ol0<ol000lco`000`000?ooooooo`2Toooo001Roooo00?o09Woooooool00_ooo`80000@
<ol000<0003oooooool0Y?ooo`00H_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000><ol000<0
003oooooool0YOooo`00H_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000><ol000<0003ooooo
ool0YOooo`00H_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000><ol000<0003oooooool0YOoo
o`00H_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000><ol000<0003oooooool0YOooo`00H_oo
o`03o`2Ioooooooo00;oool00`0003?o03?o000=<ol000<0003oooooool0Y_ooo`00H_ooo`03o`2I
oooooooo00;oool200003S?o00030000oooooooo0:Koool006;oool00ol0VOooooooo`02oooo00<0
000co`0co`003C?o00030000oooooooo0:Koool006;oool00ol0VOooooooo`02oooo00<0000co`0c
o`003C?o00030000oooooooo0:Koool006;oool00ol0VOooooooo`02oooo00<0000co`0co`0033?o
00030000oooooooo0:Ooool006;oool00ol0VOooooooo`02oooo00<0000co`0co`0033?o00030000
oooooooo0:Ooool006;oool00ol0VOooooooo`02oooo00<0000co`0co`0033?o00030000oooooooo
0:Ooool006;oool00ol0VOooooooo`02oooo0P0000dco`000`000?ooooooo`2Woooo001Roooo00?o
09Woooooool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001Roooo00?o09Wooooo
ool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001Roooo00?o09Woooooool00_oo
o`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001Poooo0P000003o`2Ioooooooo00;oool0
0`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol000/co`000`000?ooooooo`2Xoooo001Qoooo00<0003o09Woool00oooo`80000<<ol000<0
003oooooool0Z?ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003ooooo
ool0Z?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`2X
oooo001Poooo0P000003o`2Ioooooooo00;oool00`0003?o03?o000:<ol000<0003oooooool0ZOoo
o`00H_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000:<ol000<0003oooooool0ZOooo`00H_oo
o`03o`2Ioooooooo00;oool00`0003?o03?o000:<ol000<0003oooooool0ZOooo`00H_ooo`03o`2I
oooooooo00;oool00`0003?o03?o000:<ol000<0003oooooool0ZOooo`00H_ooo`03o`2Ioooooooo
00;oool200002c?o00030000oooooooo0:Woool006;oool00ol0VOooooooo`02oooo00<0000co`0c
o`002S?o00030000oooooooo0:Woool006;oool00ol0VOooooooo`02oooo00<0000co`0co`002C?o
00030000oooooooo0:[oool006;oool00ol0VOooooooo`02oooo00<0000co`0co`002C?o00030000
oooooooo0:[oool006;oool00ol0VOooooooo`02oooo00<0000co`0co`002C?o00030000oooooooo
0:[oool006;oool00ol0VOooooooo`02oooo00<0000co`0co`002C?o00030000oooooooo0:[oool0
06;oool00ol0VOooooooo`02oooo0P0000Xco`000`000?ooooooo`2Zoooo001Roooo00?o09Wooooo
ool00_ooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo001Roooo00?o09Woooooool00_oo
o`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo001Roooo00?o09Woooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`2[oooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`2[oooo001Roooo00?o09Woooooool00_ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`2[oooo001Roooo00?o09Woooooool00_ooo`800009<ol000<0003oooooool0Zooo
o`00H_ooo`03o`2Ioooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Zoooo`00H_oo
o`03o`2Ioooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Zoooo`00H_ooo`03o`2I
oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00H_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00H_ooo`03o`2Ioooooooo00;oool0
0`0003?o03?o0007<ol000<0003oooooool0[?ooo`00H_ooo`03o`2Ioooooooo00;oool2000023?o
00030000oooooooo0:coool006;oool00ol0VOooooooo`02oooo00<0000co`0co`001c?o00030000
oooooooo0:coool006;oool00ol0VOooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo
0:coool006;oool00ol0VOooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo0:coool0
06;oool00ol0VOooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo0:coool0067oool3
00000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Roooo00<0003oooooool00_oo
o`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Ooooo1@0000?oool2000023?o00030000
oooooooo0:coool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo0000
00Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`
oooo001Woooo2C?o00Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00Ioooo`Tco`05
oooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001Woooo2C?o
00Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?oo
o`800003oooo0`0000Coool00`000?ooooooo`1eoooo001Woooo2C?o00Goool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool0
06Ooool9<ol01?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008
oooo00@0003oooooool00002oooo00@0003oooooool00004oooo00<0003oooooool0M?ooo`00Iooo
o`Tco`05oooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool010000?ooooooo`00
00;oool300001?ooo`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo0000
01Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0
003oooooool0MOooo`00Ioooo`Tco`06oooo00<0003oooooool05oooo`80000:oooo0P0000Coool3
00000_ooo`030000oooooooo07Koool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.31875 .12361 L
.32392 .12361 L
.32617 .12361 L
.32728 .12361 L
.32831 .12361 L
s
.32831 .12361 m
.32878 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`050000
ooooooooooooo`2I00?oool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0U
oooo00<0003oooooool08_ooo`05o`2Ioooooooooooo000002Lco`000`0003?o03?o000T<ol04000
01Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Hoooo`05o`2Ioooooooooooo0000
04Tco`050000J_ooo`00Hoooo`05o`2Ioooooooooooo000004@co`050000Koooo`00Hoooo`05o`2I
oooooooooooo000003lco`050000M?ooo`00Hoooo`05o`2Ioooooooooooo000003/co`040000NOoo
o`00Hoooo`04o`2Ioooooooooooo0P0003Pco`020000OOooo`00Hoooo`05o`2Ioooooooooooo0000
03Lco`020000Ooooo`00Hoooo`05o`2Ioooooooooooo000003Dco`020000POooo`00Hoooo`05o`2I
oooooooooooo000003<co`020000Poooo`00Hoooo`05o`2Ioooooooooooo0000038co`000`000?oo
ooooo`23oooo001Soooo00Go09Woooooooooool00000<3?o00800026oooo001Soooo00Co09Wooooo
ooooool20000;C?o00800028oooo001Soooo00Go09Woooooooooool00000;C?o00030000oooooooo
08Soool006?oool01Ol0VOooooooooooo`00000/<ol000<0003oooooool0ROooo`00Hoooo`05o`2I
oooooooooooo000002/co`000`000?ooooooo`2:oooo001Soooo00Go09Woooooooooool00000:S?o
00030000oooooooo08_oool006?oool01Ol0VOooooooooooo`00000Z<ol000<0003oooooool0Rooo
o`00Hoooo`04o`2Ioooooooooooo0P0002Pco`000`000?ooooooo`2<oooo001Soooo00Go09Wooooo
ooooool00000:3?o00030000oooooooo08goool006?oool01Ol0VOooooooooooo`00000W<ol000<0
003oooooool0S_ooo`00Hoooo`05o`2Ioooooooooooo000002Hco`000`000?ooooooo`2?oooo001S
oooo00Go09Woooooooooool000009C?o00030000oooooooo093oool006?oool01Ol0VOoooooooooo
o`00000U<ol000<0003oooooool0T?ooo`00Hoooo`04o`2Ioooooooooooo0P0002<co`000`000?oo
ooooo`2Aoooo001Soooo00Go09Woooooooooool000008c?o00030000oooooooo09;oool006?oool0
1Ol0VOooooooooooo`00000R<ol000<0003oooooool0Toooo`00Hoooo`05o`2Ioooooooooooo0000
028co`000`000?ooooooo`2Coooo001Soooo00Go09Woooooooooool000008C?o00030000oooooooo
09Coool005ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`2Doooo001Qoooo00<0
003ooooo09T00oooo`030000<ol0<ol001hco`000`000?ooooooo`2Eoooo001Qoooo00<0003ooooo
09T00oooo`80000O<ol000<0003oooooool0UOooo`00HOooo`030000ooooo`2I00?oool00`0003?o
03?o000M<ol000<0003oooooool0U_ooo`00HOooo`030000ooooo`2I00?oool00`0003?o03?o000M
<ol000<0003oooooool0U_ooo`00H?ooo`8000000oooool0VOooo`02oooo00<0000co`0co`0073?o
00030000oooooooo09Ooool006?oool01Ol0VOooooooooooo`00000N<ol000<0003oooooool0Uooo
o`00Hoooo`05o`2Ioooooooooooo000001dco`000`000?ooooooo`2Hoooo001Soooo00Co09Wooooo
ooooool2000073?o00030000oooooooo09Soool006?oool01Ol0VOooooooooooo`00000L<ol000<0
003oooooool0VOooo`00Hoooo`05o`2Ioooooooooooo000001`co`000`000?ooooooo`2Ioooo001S
oooo00Go09Woooooooooool000006c?o00030000oooooooo09[oool006?oool01Ol0VOoooooooooo
o`00000K<ol000<0003oooooool0V_ooo`00Hoooo`05o`2Ioooooooooooo000001Xco`000`000?oo
ooooo`2Koooo001Soooo00Co09Woooooooooool200006C?o00030000oooooooo09_oool006?oool0
1Ol0VOooooooooooo`00000I<ol000<0003oooooool0W?ooo`00Hoooo`05o`2Ioooooooooooo0000
01Tco`000`000?ooooooo`2Loooo001Soooo00Go09Woooooooooool0000063?o00030000oooooooo
09goool006?oool01Ol0VOooooooooooo`00000H<ol000<0003oooooool0WOooo`00Hoooo`05o`2I
oooooooooooo000001Pco`000`000?ooooooo`2Moooo001Soooo00Go09Woooooooooool000005c?o
00030000oooooooo09koool006?oool01?l0VOooooooooooo`80000F<ol000<0003oooooool0W_oo
o`00Hoooo`05o`2Ioooooooooooo000001Lco`000`000?ooooooo`2Noooo001Soooo00Go09Wooooo
ooooool000005c?o00030000oooooooo09koool006?oool01Ol0VOooooooooooo`00000F<ol000<0
003oooooool0Woooo`00Hoooo`05o`2Ioooooooooooo000001Hco`000`000?ooooooo`2Ooooo001S
oooo00Go09Woooooooooool000005S?o00030000oooooooo09ooool006?oool01?l0VOoooooooooo
o`80000E<ol000<0003oooooool0Woooo`00Hoooo`05o`2Ioooooooooooo000001Dco`000`000?oo
ooooo`2Poooo001Soooo00Go09Woooooooooool000005C?o00030000oooooooo0:3oool006?oool0
1Ol0VOooooooooooo`00000E<ol000<0003oooooool0X?ooo`00Goooo`@000001Ol0VOoooooooooo
o`00000E<ol000<0003oooooool0X?ooo`00Goooo`050000ooooooooooooo`2I00?oool00`0003?o
03?o000B<ol000<0003oooooool0XOooo`00H?ooo`040000ooooooooo`2I0oooo`80000C<ol000<0
003oooooool0XOooo`00HOooo`040000ooooooooo`2I0_ooo`030000<ol0<ol0018co`000`000?oo
ooooo`2Qoooo001Ooooo00H0003oooooool0003ooooo09T2oooo00<0000co`0co`004C?o00030000
oooooooo0:;oool0063oool200000_ooo`04o`2Ioooooooo00004c?o00030000oooooooo0:;oool0
06Coool01?l0VOooooooo`0001<co`000`000?ooooooo`2Roooo001Toooo00Co09Woooooool0000C
<ol000<0003oooooool0X_ooo`00I?ooo`03o`2Ioooooooo0080000A<ol000<0003oooooool0Xooo
o`00I?ooo`04o`2Ioooooooo00004S?o00030000oooooooo0:?oool006Coool01?l0VOooooooo`00
018co`000`000?ooooooo`2Soooo001Toooo00Co09Woooooool0000B<ol000<0003oooooool0Xooo
o`00I?ooo`04o`2Ioooooooo00004C?o00030000oooooooo0:Coool006Coool01?l0VOooooooo`00
014co`000`000?ooooooo`2Toooo001Toooo00Co09Woooooool0000A<ol000<0003oooooool0Y?oo
o`00I?ooo`03o`2Ioooooooo0080000@<ol000<0003oooooool0Y?ooo`00I?ooo`04o`2Ioooooooo
000043?o00030000oooooooo0:Goool006Coool01?l0VOooooooo`00010co`000`000?ooooooo`2U
oooo001Toooo00Co09Woooooool0000@<ol000<0003oooooool0YOooo`00I?ooo`04o`2Ioooooooo
000043?o00030000oooooooo0:Goool006Coool01?l0VOooooooo`0000lco`000`000?ooooooo`2V
oooo001Toooo00?o09Woooooool00P0000hco`000`000?ooooooo`2Voooo001Toooo00Co09Wooooo
ool0000?<ol000<0003oooooool0Y_ooo`00I?ooo`04o`2Ioooooooo00003c?o00030000oooooooo
0:Koool006Coool01?l0VOooooooo`0000hco`000`000?ooooooo`2Woooo001Toooo00Co09Wooooo
ool0000><ol000<0003oooooool0Yoooo`00I?ooo`04o`2Ioooooooo00003S?o00030000oooooooo
0:Ooool006Coool00ol0VOooooooo`0200003C?o00030000oooooooo0:Ooool006Coool01?l0VOoo
ooooo`0000hco`000`000?ooooooo`2Woooo001Toooo00Co09Woooooool0000><ol000<0003ooooo
ool0Yoooo`00I?ooo`04o`2Ioooooooo00003C?o00030000oooooooo0:Soool0063oool200000_oo
o`04o`2Ioooooooo00003C?o00030000oooooooo0:Soool005ooool01P000?ooooooo`000?ooool0
V@;oool00`0003?o03?o000;<ol000<0003oooooool0Z?ooo`00HOooo`040000ooooooooo`2I0_oo
o`80000<<ol000<0003oooooool0Z?ooo`00H_ooo`030000ooooo`2I00;oool00`0003?o03?o000;
<ol000<0003oooooool0Z?ooo`00Goooo`060000oooooooo0000ooooo`2I0_ooo`030000<ol0<ol0
00/co`000`000?ooooooo`2Xoooo001Poooo0P0000;oool01?l0VOooooooo`0000`co`000`000?oo
ooooo`2Yoooo001Toooo00Co09Woooooool0000<<ol000<0003oooooool0ZOooo`00I?ooo`04o`2I
oooooooo000033?o00030000oooooooo0:Woool006Coool01?l0VOooooooo`0000`co`000`000?oo
ooooo`2Yoooo001Toooo00?o09Woooooool00P0000/co`000`000?ooooooo`2Yoooo001Toooo00Co
09Woooooool0000<<ol000<0003oooooool0ZOooo`00I?ooo`04o`2Ioooooooo00002c?o00030000
oooooooo0:[oool006Coool01?l0VOooooooo`0000/co`000`000?ooooooo`2Zoooo001Toooo00Co
09Woooooool0000;<ol000<0003oooooool0Z_ooo`00I?ooo`04o`2Ioooooooo00002c?o00030000
oooooooo0:[oool006Coool00ol0VOooooooo`0200002S?o00030000oooooooo0:[oool006Coool0
1?l0VOooooooo`0000/co`000`000?ooooooo`2Zoooo001Toooo00Co09Woooooool0000;<ol000<0
003oooooool0Z_ooo`00I?ooo`04o`2Ioooooooo00002S?o00030000oooooooo0:_oool006Coool0
1?l0VOooooooo`0000Xco`000`000?ooooooo`2[oooo001Toooo00Co09Woooooool0000:<ol000<0
003oooooool0Zoooo`00I?ooo`03o`2Ioooooooo00800009<ol000<0003oooooool0Zoooo`00I?oo
o`04o`2Ioooooooo00002S?o00030000oooooooo0:_oool006Coool01?l0VOooooooo`0000Xco`00
0`000?ooooooo`2[oooo001Toooo00Co09Woooooool00009<ol000<0003oooooool0[?ooo`00I?oo
o`04o`2Ioooooooo00002C?o00030000oooooooo0:coool006Coool01?l0VOooooooo`0000Tco`00
0`000?ooooooo`2/oooo001Toooo00?o09Woooooool00P0000Pco`000`000?ooooooo`2/oooo001T
oooo00Co09Woooooool00009<ol000<0003oooooool0[?ooo`00I?ooo`04o`2Ioooooooo00002C?o
00030000oooooooo0:coool006Coool01?l0VOooooooo`0000Tco`000`000?ooooooo`2/oooo001T
oooo00Co09Woooooool00009<ol000<0003oooooool0[?ooo`00HOooo`<000001?l0VOooooooo`00
00Tco`000`000?ooooooo`2/oooo001Roooo00<0003ooooo09T00_ooo`030000<ol0<ol000Lco`00
0`000?ooooooo`2/oooo001Ooooo1@000003o`2Ioooooooo00800008<ol000<0003oooooool0[?oo
o`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_
oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9
<ol01_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001Woooo2C?o00Goool00`000?oo
ooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool006Ooool9<ol01Oooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P0000Goool3
00000_ooo`030000oooooooo07Goool006Ooool9<ol01Oooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0
003oooooool00005oooo00D0003oooooooooool00000Moooo`00Ioooo`Tco`04oooo00<0003ooooo
ool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool5
00000oooo`030000oooooooo07Coool006Ooool9<ol01Oooo`030000oooooooo00D0000Boooo00@0
003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0MOooo`00Ioooo`Tco`05oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1eoooo001Woooo2C?o
00Koool00`000?ooooooo`0Goooo0P0000[oool200001Oooo`800002oooo00<0003oooooool0M_oo
o`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.32831 .12361 L
.33073 .12361 L
.33304 .12361 L
.33433 .12361 L
s
.33433 .12361 m
.33463 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00?oool00ol0VOooo`000007<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool09?ooo`03o`2Ioooo000002Lco`000`0003?o03?o000T<ol0400001Woool00`000?oo
ooooo`0Voooo00<0003oooooool05Oooo`00IOooo`03o`2Ioooo000004Tco`050000J_ooo`00IOoo
o`03o`2Ioooo000004@co`050000Koooo`00IOooo`03o`2Ioooo000003lco`050000M?ooo`00IOoo
o`03o`2Ioooo000003/co`040000NOooo`00IOooo`04o`2Ioooo00000000>3?o0080001moooo001U
oooo00?o09Woool00000=c?o0080001ooooo001Uoooo00?o09Woool00000=C?o00800021oooo001U
oooo00?o09Woool00000<c?o00800023oooo001Uoooo00?o09Woool00000<S?o00030000oooooooo
08?oool006Goool00ol0VOooo`00000`<ol00P0008Koool006Goool01?l0VOooo`00000002dco`02
0000R?ooo`00IOooo`03o`2Ioooo000002dco`000`000?ooooooo`28oooo001Uoooo00?o09Woool0
0000;3?o00030000oooooooo08Woool006Goool00ol0VOooo`00000[<ol000<0003oooooool0R_oo
o`00IOooo`03o`2Ioooo000002Xco`000`000?ooooooo`2;oooo001Uoooo00?o09Woool00000:S?o
00030000oooooooo08_oool006Goool01?l0VOooo`00000002Pco`000`000?ooooooo`2<oooo001U
oooo00?o09Woool00000:3?o00030000oooooooo08goool006Goool00ol0VOooo`00000W<ol000<0
003oooooool0S_ooo`00IOooo`03o`2Ioooo000002Hco`000`000?ooooooo`2?oooo001Uoooo00?o
09Woool000009C?o00030000oooooooo093oool006Goool00ol0VOooo`00000U<ol000<0003ooooo
ool0T?ooo`00IOooo`04o`2Ioooo000000008c?o00030000oooooooo097oool006Goool00ol0VOoo
o`00000S<ol000<0003oooooool0T_ooo`00IOooo`03o`2Ioooo0000028co`000`000?ooooooo`2C
oooo001Uoooo00?o09Woool000008S?o00030000oooooooo09?oool006Goool00ol0VOooo`00000Q
<ol000<0003oooooool0U?ooo`00Goooo`D000001?ooool0VOooo`00024co`000`000?ooooooo`2D
oooo001Qoooo00L0003ooooooooooooo09Woool0000083?o00030000oooooooo09Goool0067oool0
1P000?ooooooooooool0VOooo`80000O<ol000<0003oooooool0UOooo`00HOooo`070000oooooooo
ooooo`2Ioooo000001lco`000`000?ooooooo`2Foooo001Qoooo00L0003ooooooooooooo09Woool0
00007c?o00030000oooooooo09Koool0063oool200000oooo`03o`2Ioooo000001hco`000`000?oo
ooooo`2Goooo001Uoooo00?o09Woool000007S?o00030000oooooooo09Ooool006Goool00ol0VOoo
o`00000M<ol000<0003oooooool0V?ooo`00IOooo`04o`2Ioooo0000000073?o00030000oooooooo
09Soool006Goool00ol0VOooo`00000L<ol000<0003oooooool0VOooo`00IOooo`03o`2Ioooo0000
01`co`000`000?ooooooo`2Ioooo001Uoooo00?o09Woool000006c?o00030000oooooooo09[oool0
06Goool00ol0VOooo`00000K<ol000<0003oooooool0V_ooo`00IOooo`03o`2Ioooo000001Xco`00
0`000?ooooooo`2Koooo001Uoooo00Co09Woool00000000I<ol000<0003oooooool0Voooo`00IOoo
o`03o`2Ioooo000001Tco`000`000?ooooooo`2Loooo001Uoooo00?o09Woool000006C?o00030000
oooooooo09coool006Goool00ol0VOooo`00000H<ol000<0003oooooool0WOooo`00IOooo`03o`2I
oooo000001Pco`000`000?ooooooo`2Moooo001Uoooo00?o09Woool0000063?o00030000oooooooo
09goool006Goool00ol0VOooo`00000G<ol000<0003oooooool0W_ooo`00IOooo`04o`2Ioooo0000
00005S?o00030000oooooooo09koool006Goool00ol0VOooo`00000G<ol000<0003oooooool0W_oo
o`00IOooo`03o`2Ioooo000001Lco`000`000?ooooooo`2Noooo001Uoooo00?o09Woool000005S?o
00030000oooooooo09ooool006Goool00ol0VOooo`00000F<ol000<0003oooooool0Woooo`00IOoo
o`03o`2Ioooo000001Hco`000`000?ooooooo`2Ooooo001Uoooo00Co09Woool00000000E<ol000<0
003oooooool0Woooo`00IOooo`03o`2Ioooo000001Dco`000`000?ooooooo`2Poooo001Uoooo00?o
09Woool000005C?o00030000oooooooo0:3oool006Goool00ol0VOooo`00000E<ol000<0003ooooo
ool0X?ooo`00Goooo`@00002oooo00?o09Woool000005C?o00030000oooooooo0:3oool005ooool0
0`000?ooooooo`03oooo00?o09Woool0000053?o00030000oooooooo0:7oool0063oool00`000?oo
ooooo`02oooo00Co09Woool00000000C<ol000<0003oooooool0XOooo`00HOooo`070000oooooooo
ooooo`2Ioooo000001@co`000`000?ooooooo`2Qoooo001Ooooo00@0003oooooool00002oooo00?o
09Woool000004c?o00030000oooooooo0:;oool0063oool200000oooo`03o`2Ioooo000001<co`00
0`000?ooooooo`2Roooo001Uoooo00?o09Woool000004c?o00030000oooooooo0:;oool006Goool0
0ol0VOooo`00000C<ol000<0003oooooool0X_ooo`00IOooo`04o`2Ioooo000000004C?o00030000
oooooooo0:?oool006Goool00ol0VOooo`00000B<ol000<0003oooooool0Xoooo`00IOooo`03o`2I
oooo0000018co`000`000?ooooooo`2Soooo001Uoooo00?o09Woool000004S?o00030000oooooooo
0:?oool006Goool00ol0VOooo`00000A<ol000<0003oooooool0Y?ooo`00IOooo`03o`2Ioooo0000
014co`000`000?ooooooo`2Toooo001Uoooo00?o09Woool000004C?o00030000oooooooo0:Coool0
06Goool01?l0VOooo`000000010co`000`000?ooooooo`2Toooo001Uoooo00?o09Woool0000043?o
00030000oooooooo0:Goool006Goool00ol0VOooo`00000@<ol000<0003oooooool0YOooo`00IOoo
o`03o`2Ioooo0000010co`000`000?ooooooo`2Uoooo001Uoooo00?o09Woool0000043?o00030000
oooooooo0:Goool006Goool00ol0VOooo`00000?<ol000<0003oooooool0Y_ooo`00IOooo`04o`2I
oooo000000003S?o00030000oooooooo0:Koool006Goool00ol0VOooo`00000?<ol000<0003ooooo
ool0Y_ooo`00IOooo`03o`2Ioooo000000lco`000`000?ooooooo`2Voooo001Uoooo00?o09Woool0
00003S?o00030000oooooooo0:Ooool006Goool00ol0VOooo`00000><ol000<0003oooooool0Yooo
o`00IOooo`03o`2Ioooo000000hco`000`000?ooooooo`2Woooo001Uoooo00Co09Woool00000000=
<ol000<0003oooooool0Yoooo`00IOooo`03o`2Ioooo000000hco`000`000?ooooooo`2Woooo001U
oooo00?o09Woool000003S?o00030000oooooooo0:Ooool006Goool00ol0VOooo`00000=<ol000<0
003oooooool0Z?ooo`00H?ooo`800003oooo00?o09Woool000003C?o00030000oooooooo0:Soool0
05ooool010000?ooooooo`0000;oool00ol0VOooo`00000=<ol000<0003oooooool0Z?ooo`00HOoo
o`060000ooooooooooooo`2Ioooo0P0000`co`000`000?ooooooo`2Xoooo001Roooo00H0003ooooo
oooo09Woool0000=<ol000<0003oooooool0Z?ooo`00Goooo`040000oooooooo00000_ooo`03o`2I
oooo000000dco`000`000?ooooooo`2Xoooo001Poooo0P0000?oool00ol0VOooo`00000<<ol000<0
003oooooool0ZOooo`00IOooo`03o`2Ioooo000000`co`000`000?ooooooo`2Yoooo001Uoooo00?o
09Woool0000033?o00030000oooooooo0:Woool006Goool00ol0VOooo`00000<<ol000<0003ooooo
ool0ZOooo`00IOooo`04o`2Ioooo000000002c?o00030000oooooooo0:Woool006Goool00ol0VOoo
o`00000<<ol000<0003oooooool0ZOooo`00IOooo`03o`2Ioooo000000/co`000`000?ooooooo`2Z
oooo001Uoooo00?o09Woool000002c?o00030000oooooooo0:[oool006Goool00ol0VOooo`00000;
<ol000<0003oooooool0Z_ooo`00IOooo`03o`2Ioooo000000/co`000`000?ooooooo`2Zoooo001U
oooo00Co09Woool00000000:<ol000<0003oooooool0Z_ooo`00IOooo`03o`2Ioooo000000/co`00
0`000?ooooooo`2Zoooo001Uoooo00?o09Woool000002c?o00030000oooooooo0:[oool006Goool0
0ol0VOooo`00000:<ol000<0003oooooool0Zoooo`00IOooo`03o`2Ioooo000000Xco`000`000?oo
ooooo`2[oooo001Uoooo00?o09Woool000002S?o00030000oooooooo0:_oool006Goool01?l0VOoo
o`00000000Tco`000`000?ooooooo`2[oooo001Uoooo00?o09Woool000002S?o00030000oooooooo
0:_oool006Goool00ol0VOooo`00000:<ol000<0003oooooool0Zoooo`00IOooo`03o`2Ioooo0000
00Tco`000`000?ooooooo`2/oooo001Uoooo00?o09Woool000002C?o00030000oooooooo0:coool0
06Goool00ol0VOooo`000009<ol000<0003oooooool0[?ooo`00IOooo`04o`2Ioooo0000000023?o
00030000oooooooo0:coool006Goool00ol0VOooo`000009<ol000<0003oooooool0[?ooo`00IOoo
o`03o`2Ioooo000000Tco`000`000?ooooooo`2/oooo001Uoooo00?o09Woool000002C?o00030000
oooooooo0:coool006Goool00ol0VOooo`000009<ol000<0003oooooool0[?ooo`00HOooo`<00000
1?ooool0VOooo`0000Tco`000`000?ooooooo`2/oooo001Roooo00H0003ooooooooo09Woool00009
<ol000<0003oooooool0[?ooo`00Goooo`D000000oooool0VOooo`02000023?o00030000oooooooo
0:coool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:
<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001W
oooo2C?o00Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00Ioooo`Tco`05oooo00<0
003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001Woooo2C?o00Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800003
oooo100000?oool00`000?ooooooo`1eoooo001Woooo2C?o00Goool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`030000oooooooo00Coool00`000?ooooooo`1eoooo001Woooo2C?o
00Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`1doooo001Woooo2C?o00Goool0
0`000?ooooooo`0500004_ooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo00;oool00`000?ooooooo`1eoooo001Woooo2C?o00Goool01@000?ooooooooooo`00000E
oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0MOooo`00Ioooo`Tco`06oooo00<0003oooooool05oooo`80000:oooo0P0000Coool2
00000oooo`030000oooooooo07Koool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34121 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000
oooooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol0400001Woool00`000?oo
ooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol004Lco`050000J_ooo`00Iooo
o`030000<ol0<ol0048co`050000Koooo`00Ioooo`030000<ol0<ol003dco`050000M?ooo`00Iooo
o`030000<ol0<ol003Tco`040000NOooo`00Ioooo`80000h<ol00P0007goool006Ooool00`0003?o
03?o000e<ol00P0007ooool006Ooool00`0003?o03?o000c<ol00P00087oool006Ooool00`0003?o
03?o000a<ol00P0008?oool006Ooool00`0003?o03?o000`<ol000<0003oooooool0Poooo`00Iooo
o`030000<ol0<ol002hco`020000Q_ooo`00Ioooo`80000]<ol00P0008Soool006Ooool00`0003?o
03?o000[<ol000<0003oooooool0R?ooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`29
oooo001Woooo00<0000co`0co`00:C?o00030000oooooooo08[oool006Ooool00`0003?o03?o000X
<ol000<0003oooooool0Roooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`2;oooo001W
oooo0P0002Pco`000`000?ooooooo`2<oooo001Woooo00<0000co`0co`009S?o00030000oooooooo
08goool006Ooool00`0003?o03?o000U<ol000<0003oooooool0S_ooo`00Ioooo`030000<ol0<ol0
02@co`000`000?ooooooo`2?oooo001Woooo00<0000co`0co`008c?o00030000oooooooo093oool0
06Ooool00`0003?o03?o000S<ol000<0003oooooool0T?ooo`00Ioooo`80000S<ol000<0003ooooo
ool0TOooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`2Boooo001Woooo00<0000co`0c
o`0083?o00030000oooooooo09?oool006Ooool00`0003?o03?o000P<ol000<0003oooooool0Tooo
o`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`2Doooo001Ooooo1@0000?oool00`0003?o
03?o000O<ol000<0003oooooool0U?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0UOooo`00HOooo`030000oooooooo00?oool200007c?o00030000oooooooo
09Goool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool0
067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo09Koool0063oool2
00001Oooo`030000<ol0<ol001`co`000`000?ooooooo`2Goooo001Woooo00<0000co`0co`0073?o
00030000oooooooo09Ooool006Ooool00`0003?o03?o000K<ol000<0003oooooool0V?ooo`00Iooo
o`80000L<ol000<0003oooooool0V?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`2I
oooo001Woooo00<0000co`0co`006S?o00030000oooooooo09Woool006Ooool00`0003?o03?o000I
<ol000<0003oooooool0V_ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`2Joooo001W
oooo00<0000co`0co`0063?o00030000oooooooo09_oool006Ooool200006C?o00030000oooooooo
09_oool006Ooool00`0003?o03?o000G<ol000<0003oooooool0W?ooo`00Ioooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Loooo001Woooo00<0000co`0co`005S?o00030000oooooooo09goool0
06Ooool00`0003?o03?o000F<ol000<0003oooooool0WOooo`00Ioooo`030000<ol0<ol001Hco`00
0`000?ooooooo`2Moooo001Woooo00<0000co`0co`005C?o00030000oooooooo09koool006Ooool2
00005S?o00030000oooooooo09koool006Ooool00`0003?o03?o000E<ol000<0003oooooool0W_oo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`2Noooo001Woooo00<0000co`0co`0053?o
00030000oooooooo09ooool006Ooool00`0003?o03?o000D<ol000<0003oooooool0Woooo`00Iooo
o`030000<ol0<ol001@co`000`000?ooooooo`2Ooooo001Woooo0P0001Dco`000`000?ooooooo`2O
oooo001Woooo00<0000co`0co`004c?o00030000oooooooo0:3oool006Ooool00`0003?o03?o000C
<ol000<0003oooooool0X?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`2Poooo001O
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0X?ooo`00Goooo`030000oooooooo
00Goool00`0003?o03?o000B<ol000<0003oooooool0XOooo`00H?ooo`030000oooooooo00Coool2
00004c?o00030000oooooooo0:7oool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o
00030000oooooooo0:7oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0
003oooooool0X_ooo`00H?ooo`800005oooo00<0000co`0co`004C?o00030000oooooooo0:;oool0
06Ooool00`0003?o03?o000A<ol000<0003oooooool0X_ooo`00Ioooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Roooo001Woooo0P00014co`000`000?ooooooo`2Soooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo0:?oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0Xooo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`2Soooo001Woooo00<0000co`0co`003c?o
00030000oooooooo0:Coool006Ooool00`0003?o03?o000?<ol000<0003oooooool0Y?ooo`00Iooo
o`030000<ol0<ol000lco`000`000?ooooooo`2Toooo001Woooo0P00010co`000`000?ooooooo`2T
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo0:Goool006Ooool00`0003?o03?o000>
<ol000<0003oooooool0YOooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`2Uoooo001W
oooo00<0000co`0co`003S?o00030000oooooooo0:Goool006Ooool00`0003?o03?o000=<ol000<0
003oooooool0Y_ooo`00Ioooo`80000><ol000<0003oooooool0Y_ooo`00Ioooo`030000<ol0<ol0
00dco`000`000?ooooooo`2Voooo001Woooo00<0000co`0co`003C?o00030000oooooooo0:Koool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0Yoooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`2Woooo001Woooo00<0000co`0co`0033?o00030000oooooooo0:Ooool006Ooool2
00003C?o00030000oooooooo0:Ooool006Ooool00`0003?o03?o000<<ol000<0003oooooool0Yooo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`2Woooo001Woooo00<0000co`0co`002c?o
00030000oooooooo0:Soool0063oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`2X
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo0:Soool0
067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001Roooo00<0003ooooo
ool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`2Xoooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`002c?o00030000oooooooo0:Soool0063oool200001Oooo`030000<ol0<ol0
00Xco`000`000?ooooooo`2Yoooo001Woooo00<0000co`0co`002S?o00030000oooooooo0:Woool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool0ZOooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`2Yoooo001Woooo0P0000/co`000`000?ooooooo`2Yoooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo0:Woool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Z_oo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`2Zoooo001Woooo00<0000co`0co`002C?o
00030000oooooooo0:[oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Z_ooo`00Iooo
o`80000:<ol000<0003oooooool0Z_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`2Z
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo0:[oool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0Zoooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`2[oooo001W
oooo00<0000co`0co`0023?o00030000oooooooo0:_oool006Ooool200002C?o00030000oooooooo
0:_oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Zoooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`2[oooo001Woooo00<0000co`0co`001c?o00030000oooooooo0:coool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0[?ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`2/oooo001Woooo0P0000Pco`000`000?ooooooo`2/oooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo0:coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0[?oo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001Woooo00<0000co`0co`001c?o
00030000oooooooo0:coool0067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2/
oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2/oooo001O
oooo1@0000?oool2000023?o00030000oooooooo0:coool005ooool010000?ooooooo`0000Coool:
<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool0
06Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00ooool00`000?ooooooo`0Loooo00<0
003oooooool0Ooooo`00Ioooo`Tco`0>oooo00<0003oooooool02?ooo`030000oooooooo01?oool0
0`000?ooooooo`1noooo001Woooo2C?o00koool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200001?ooo`030000oooooooo07koool006Ooool9<ol03_ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002Oooo`030000oooooooo07koool006Ooool9<ol03Oooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool0000:oooo00<0003oooooool0OOooo`00Ioooo`Tco`0>oooo00<0
003oooooool01@0000coool010000?ooooooo`0000Woool00`000?ooooooo`1noooo001Woooo2C?o
00koool01@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oooooool0O_oo
o`00Ioooo`Tco`0?oooo00<0003oooooool04Oooo`800009oooo00<0003oooooool0Ooooo`00Iooo
o`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.33788 .12361 L
.34055 .12361 L
.34309 .12361 L
.34549 .12361 L
.34615 .12361 L
.34685 .12361 L
s
.34685 .12361 m
.34735 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.32831 .12361 L
.33073 .12361 L
.33304 .12361 L
.33433 .12361 L
.33507 .12349 L
.33575 .12297 L
.33823 .12107 L
.34309 .11749 L
.34437 .11657 L
.34573 .1156 L
.34689 .11479 L
.34816 .12361 L
.34888 .12361 L
.34953 .12361 L
.351 .12361 L
.35365 .12361 L
.36361 .12361 L
.38221 .12361 L
.42206 .12361 L
.46039 .12361 L
.50117 .12361 L
.54044 .12361 L
.57819 .12361 L
.61839 .12361 L
.65708 .12361 L
.69822 .12361 L
.73784 .12361 L
.77595 .12361 L
.81651 .12361 L
.85556 .12361 L
.89706 .12361 L
.93704 .12361 L
.9755 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo
0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<00000I_ooool0]_ooo`00Ioooo`030000
06Kooooo0;Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?l0VC?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool09_ooo`030000o`2I<ol002Dco`000`0003?o03?o000T<ol0400001Woool00`000?oo
ooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000o`2I<ol004Lco`050000J_ooo`00Iooo
o`030000o`2I<ol0048co`050000Koooo`00Ioooo`030000o`2I<ol003dco`050000M?ooo`00Iooo
o`030000o`2I<ol003Tco`040000NOooo`00Ioooo`80000h<ol00P0007goool006Ooool00`000?l0
VC?o000e<ol00P0007ooool006Ooool00`000?l0VC?o000c<ol00P00087oool006Ooool00`000?l0
VC?o000a<ol00P0008?oool006Ooool00`000?l0VC?o000`<ol000<0003oooooool0Poooo`00Iooo
o`030000o`2I<ol002hco`020000Q_ooo`00Ioooo`80000]<ol00P0008Soool006Ooool00`000?l0
VC?o000[<ol000<0003oooooool0R?ooo`00Ioooo`030000o`2I<ol002Xco`000`000?ooooooo`29
oooo001Woooo00<0003o09Tco`00:C?o00030000oooooooo08[oool006Ooool00`000?l0VC?o000X
<ol000<0003oooooool0Roooo`00Ioooo`030000o`2I<ol002Pco`000`000?ooooooo`2;oooo001W
oooo0P0002Pco`000`000?ooooooo`2<oooo001Woooo00<0003o09Tco`009S?o00030000oooooooo
08goool006Ooool00`000?l0VC?o000U<ol000<0003oooooool0S_ooo`00Ioooo`030000o`2I<ol0
02@co`000`000?ooooooo`2?oooo001Woooo00<0003o09Tco`008c?o00030000oooooooo093oool0
06Ooool00`000?l0VC?o000S<ol000<0003oooooool0T?ooo`00Ioooo`80000S<ol000<0003ooooo
ool0TOooo`00Ioooo`030000o`2I<ol0024co`000`000?ooooooo`2Boooo001Woooo00<0003o09Tc
o`0083?o00030000oooooooo09?oool006Ooool00`000?l0VC?o000P<ol000<0003oooooool0Tooo
o`00Ioooo`030000o`2I<ol001lco`000`000?ooooooo`2Doooo001Ooooo1@0000?oool00`000?l0
VC?o000O<ol000<0003oooooool0U?ooo`00HOooo`030000oooooooo00?oool00`000?l0VC?o000N
<ol000<0003oooooool0UOooo`00HOooo`030000oooooooo00?oool200007c?o00030000oooooooo
09Goool0067oool00`000?ooooooo`03oooo00<0003o09Tco`007C?o00030000oooooooo09Koool0
067oool00`000?ooooooo`03oooo00<0003o09Tco`007C?o00030000oooooooo09Koool0063oool2
00001Oooo`030000o`2I<ol001`co`000`000?ooooooo`2Goooo001Woooo00<0003o09Tco`0073?o
00030000oooooooo09Ooool006Ooool00`000?l0VC?o000K<ol000<0003oooooool0V?ooo`00Iooo
o`80000L<ol000<0003oooooool0V?ooo`00Ioooo`030000o`2I<ol001Xco`000`000?ooooooo`2I
oooo001Woooo00<0003o09Tco`006S?o00030000oooooooo09Woool006Ooool00`000?l0VC?o000I
<ol000<0003oooooool0V_ooo`00Ioooo`030000o`2I<ol001Tco`000`000?ooooooo`2Joooo001W
oooo00<0003o09Tco`0063?o00030000oooooooo09_oool006Ooool200006C?o00030000oooooooo
09_oool006Ooool00`000?l0VC?o000G<ol000<0003oooooool0W?ooo`00Ioooo`030000o`2I<ol0
01Lco`000`000?ooooooo`2Loooo001Woooo00<0003o09Tco`005S?o00030000oooooooo09goool0
06Ooool00`000?l0VC?o000F<ol000<0003oooooool0WOooo`00Ioooo`030000o`2I<ol001Hco`00
0`000?ooooooo`2Moooo001Woooo00<0003o09Tco`005C?o00030000oooooooo09koool006Ooool2
00005S?o00030000oooooooo09koool006Ooool00`000?l0VC?o000E<ol000<0003oooooool0W_oo
o`00Ioooo`030000o`2I<ol001Dco`000`000?ooooooo`2Noooo001Woooo00<0003o09Tco`0053?o
00030000oooooooo09ooool006Ooool00`000?l0VC?o000D<ol000<0003oooooool0Woooo`00Iooo
o`030000o`2I<ol001@co`000`000?ooooooo`2Ooooo001Woooo0P0001Dco`000`000?ooooooo`2O
oooo001Woooo00<0003o09Tco`004c?o00030000oooooooo0:3oool006Ooool00`000?l0VC?o000C
<ol000<0003oooooool0X?ooo`00Ioooo`030000o`2I<ol001<co`000`000?ooooooo`2Poooo001O
oooo100000Coool00`000?l0VC?o000C<ol000<0003oooooool0X?ooo`00Goooo`030000oooooooo
00Goool00`000?l0VC?o000B<ol000<0003oooooool0XOooo`00H?ooo`030000oooooooo00Coool2
00004c?o00030000oooooooo0:7oool0067oool00`000?ooooooo`03oooo00<0003o09Tco`004S?o
00030000oooooooo0:7oool005ooool010000?ooooooo`0000Coool00`000?l0VC?o000A<ol000<0
003oooooool0X_ooo`00H?ooo`800005oooo00<0003o09Tco`004C?o00030000oooooooo0:;oool0
06Ooool00`000?l0VC?o000A<ol000<0003oooooool0X_ooo`00Ioooo`030000o`2I<ol0014co`00
0`000?ooooooo`2Roooo001Woooo0P00014co`000`000?ooooooo`2Soooo001Woooo00<0003o09Tc
o`0043?o00030000oooooooo0:?oool006Ooool00`000?l0VC?o000@<ol000<0003oooooool0Xooo
o`00Ioooo`030000o`2I<ol0010co`000`000?ooooooo`2Soooo001Woooo00<0003o09Tco`003c?o
00030000oooooooo0:Coool006Ooool00`000?l0VC?o000?<ol000<0003oooooool0Y?ooo`00Iooo
o`030000o`2I<ol000lco`000`000?ooooooo`2Toooo001Woooo0P00010co`000`000?ooooooo`2T
oooo001Woooo00<0003o09Tco`003S?o00030000oooooooo0:Goool006Ooool00`000?l0VC?o000>
<ol000<0003oooooool0YOooo`00Ioooo`030000o`2I<ol000hco`000`000?ooooooo`2Uoooo001W
oooo00<0003o09Tco`003S?o00030000oooooooo0:Goool006Ooool00`000?l0VC?o000=<ol000<0
003oooooool0Y_ooo`00Ioooo`80000><ol000<0003oooooool0Y_ooo`00Ioooo`030000o`2I<ol0
00dco`000`000?ooooooo`2Voooo001Woooo00<0003o09Tco`003C?o00030000oooooooo0:Koool0
06Ooool00`000?l0VC?o000<<ol000<0003oooooool0Yoooo`00Ioooo`030000o`2I<ol000`co`00
0`000?ooooooo`2Woooo001Woooo00<0003o09Tco`0033?o00030000oooooooo0:Ooool006Ooool2
00003C?o00030000oooooooo0:Ooool006Ooool00`000?l0VC?o000<<ol000<0003oooooool0Yooo
o`00Ioooo`030000o`2I<ol000`co`000`000?ooooooo`2Woooo001Woooo00<0003o09Tco`002c?o
00030000oooooooo0:Soool0063oool200001Oooo`030000o`2I<ol000/co`000`000?ooooooo`2X
oooo001Ooooo00@0003oooooool00004oooo00<0003o09Tco`002c?o00030000oooooooo0:Soool0
067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`2Xoooo001Roooo00<0003ooooo
ool00_ooo`030000o`2I<ol000/co`000`000?ooooooo`2Xoooo001Ooooo00@0003oooooool00004
oooo00<0003o09Tco`002c?o00030000oooooooo0:Soool0063oool200001Oooo`030000o`2I<ol0
00Xco`000`000?ooooooo`2Yoooo001Woooo00<0003o09Tco`002S?o00030000oooooooo0:Woool0
06Ooool00`000?l0VC?o000:<ol000<0003oooooool0ZOooo`00Ioooo`030000o`2I<ol000Xco`00
0`000?ooooooo`2Yoooo001Woooo0P0000/co`000`000?ooooooo`2Yoooo001Woooo00<0003o09Tc
o`002S?o00030000oooooooo0:Woool006Ooool00`000?l0VC?o0009<ol000<0003oooooool0Z_oo
o`00Ioooo`030000o`2I<ol000Tco`000`000?ooooooo`2Zoooo001Woooo00<0003o09Tco`002C?o
00030000oooooooo0:[oool006Ooool00`000?l0VC?o0009<ol000<0003oooooool0Z_ooo`00Iooo
o`80000:<ol000<0003oooooool0Z_ooo`00Ioooo`030000o`2I<ol000Tco`000`000?ooooooo`2Z
oooo001Woooo00<0003o09Tco`002C?o00030000oooooooo0:[oool006Ooool00`000?l0VC?o0008
<ol000<0003oooooool0Zoooo`00Ioooo`030000o`2I<ol000Pco`000`000?ooooooo`2[oooo001W
oooo00<0003o09Tco`0023?o00030000oooooooo0:_oool006Ooool200002C?o00030000oooooooo
0:_oool006Ooool00`000?l0VC?o0008<ol000<0003oooooool0Zoooo`00Ioooo`030000o`2I<ol0
00Pco`000`000?ooooooo`2[oooo001Woooo00<0003o09Tco`001c?o00030000oooooooo0:coool0
06Ooool00`000?l0VC?o0007<ol000<0003oooooool0[?ooo`00Ioooo`030000o`2I<ol000Lco`00
0`000?ooooooo`2/oooo001Woooo0P0000Pco`000`000?ooooooo`2/oooo001Woooo00<0003o09Tc
o`001c?o00030000oooooooo0:coool006Ooool00`000?l0VC?o0007<ol000<0003oooooool0[?oo
o`00Ioooo`030000o`2I<ol000Lco`000`000?ooooooo`2/oooo001Woooo00<0003o09Tco`001c?o
00030000oooooooo0:coool0067oool300000oooo`030000o`2I<ol000Lco`000`000?ooooooo`2/
oooo001Roooo00<0003oooooool00_ooo`030000o`2I<ol000Lco`000`000?ooooooo`2/oooo001O
oooo1@0000?oool2000023?o00030000oooooooo0:coool005ooool010000?ooooooo`0000Coool:
<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool0
06Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200001?ooo`800003oooo100000?oool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool00`000?ooooooo`04oooo00<0
003oooooool0N?ooo`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo00goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003ooooo
ool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000coool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo
017oool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool0
06Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.34309 .12361 L
.34772 .12361 L
.35028 .12361 L
.35154 .12361 L
.35271 .12361 L
.3538 .12361 L
s
.3538 .12361 m
.35427 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.31875 .12361 L
.32392 .12361 L
.32617 .12361 L
.32728 .12361 L
.32831 .12361 L
.32949 .12289 L
.33078 .1219 L
.33304 .1202 L
.34309 .11305 L
.34816 .10968 L
.35083 .10796 L
.35229 .10704 L
.353 .10659 L
.35365 .10619 L
.35485 .12361 L
.35612 .12361 L
.35884 .12361 L
.36361 .12361 L
.38221 .12361 L
.42206 .12361 L
.46039 .12361 L
.50117 .12361 L
.54044 .12361 L
.57819 .12361 L
.61839 .12361 L
.65708 .12361 L
.69822 .12361 L
.73784 .12361 L
.77595 .12361 L
.81651 .12361 L
.85556 .12361 L
.89706 .12361 L
.93704 .12361 L
.9755 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0]_ooo`00Ioooo`040000oooo06Ko
06Ko]Oooo`00Ioooo`04000006Kooooo06Ko]Oooo`00Ioooo`040000oooooooo06Ko]Oooo`00I_oo
o`0506Ko0000oooooooo06Ko0;Goool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool0100003?o03?o0?l0V@@co`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000
oooooooo02Goool00`000?ooooooo`0Voooo00@0000co`0co`3o09TT<ol000<0000co`0co`0093?o
0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool006Ooool0100003?o03?o0?l0
VDHco`050000J_ooo`00Ioooo`040000<ol0<ol0o`2I@C?o00D0001_oooo001Woooo00@0000co`0c
o`3o09Tl<ol01@0007Coool006Ooool0100003?o03?o0?l0VCPco`040000NOooo`00Ioooo`800000
0c?o0?l0VC?o000e<ol00P0007goool006Ooool0100003?o03?o0?l0VC@co`020000Ooooo`00Iooo
o`040000<ol0<ol0o`2I<S?o00800021oooo001Woooo00@0000co`0co`3o09T`<ol00P0008?oool0
06Ooool0100003?o03?o0?l0VBlco`000`000?ooooooo`23oooo001Woooo00@0000co`0co`3o09T]
<ol00P0008Koool006Ooool2000000<co`3o09Tco`00:S?o00800028oooo001Woooo00@0000co`0c
o`3o09TZ<ol000<0003oooooool0R?ooo`00Ioooo`040000<ol0<ol0o`2I:C?o00030000oooooooo
08Woool006Ooool0100003?o03?o0?l0VBPco`000`000?ooooooo`2:oooo001Woooo00@0000co`0c
o`3o09TW<ol000<0003oooooool0Roooo`00Ioooo`040000<ol0<ol0o`2I9c?o00030000oooooooo
08_oool006Ooool2000000<co`3o09Tco`009C?o00030000oooooooo08coool006Ooool0100003?o
03?o0?l0VBDco`000`000?ooooooo`2=oooo001Woooo00@0000co`0co`3o09TT<ol000<0003ooooo
ool0S_ooo`00Ioooo`040000<ol0<ol0o`2I8c?o00030000oooooooo08ooool006Ooool0100003?o
03?o0?l0VB8co`000`000?ooooooo`2@oooo001Woooo00@0000co`0co`3o09TR<ol000<0003ooooo
ool0T?ooo`00Ioooo`8000000c?o0?l0VC?o000P<ol000<0003oooooool0TOooo`00Ioooo`040000
<ol0<ol0o`2I83?o00030000oooooooo09;oool006Ooool0100003?o03?o0?l0VAlco`000`000?oo
ooooo`2Coooo001Woooo00@0000co`0co`3o09TO<ol000<0003oooooool0Toooo`00Ioooo`040000
<ol0<ol0o`2I7S?o00030000oooooooo09Coool005ooool500000oooo`040000<ol0<ol0o`2I7S?o
00030000oooooooo09Coool0067oool00`000?ooooooo`03oooo00@0000co`0co`3o09TM<ol000<0
003oooooool0UOooo`00HOooo`030000oooooooo00?oool2000000<co`3o09Tco`0073?o00030000
oooooooo09Goool0067oool00`000?ooooooo`03oooo00@0000co`0co`3o09TL<ol000<0003ooooo
ool0U_ooo`00HOooo`030000oooooooo00?oool0100003?o03?o0?l0VA`co`000`000?ooooooo`2F
oooo001Poooo0P0000Goool0100003?o03?o0?l0VA/co`000`000?ooooooo`2Goooo001Woooo00@0
000co`0co`3o09TK<ol000<0003oooooool0Uoooo`00Ioooo`040000<ol0<ol0o`2I6S?o00030000
oooooooo09Soool006Ooool2000000<co`3o09Tco`006C?o00030000oooooooo09Soool006Ooool0
100003?o03?o0?l0VATco`000`000?ooooooo`2Ioooo001Woooo00@0000co`0co`3o09TI<ol000<0
003oooooool0VOooo`00Ioooo`040000<ol0<ol0o`2I63?o00030000oooooooo09[oool006Ooool0
100003?o03?o0?l0VAPco`000`000?ooooooo`2Joooo001Woooo00@0000co`0co`3o09TG<ol000<0
003oooooool0Voooo`00Ioooo`8000000c?o0?l0VC?o000F<ol000<0003oooooool0Voooo`00Iooo
o`040000<ol0<ol0o`2I5S?o00030000oooooooo09coool006Ooool0100003?o03?o0?l0VAHco`00
0`000?ooooooo`2Loooo001Woooo00@0000co`0co`3o09TE<ol000<0003oooooool0WOooo`00Iooo
o`040000<ol0<ol0o`2I5C?o00030000oooooooo09goool006Ooool0100003?o03?o0?l0VADco`00
0`000?ooooooo`2Moooo001Woooo00@0000co`0co`3o09TD<ol000<0003oooooool0W_ooo`00Iooo
o`8000000c?o0?l0VC?o000C<ol000<0003oooooool0W_ooo`00Ioooo`040000<ol0<ol0o`2I53?o
00030000oooooooo09koool006Ooool0100003?o03?o0?l0VA@co`000`000?ooooooo`2Noooo001W
oooo00@0000co`0co`3o09TC<ol000<0003oooooool0Woooo`00Ioooo`040000<ol0<ol0o`2I4c?o
00030000oooooooo09ooool006Ooool0100003?o03?o0?l0VA<co`000`000?ooooooo`2Ooooo001W
oooo0P000003<ol0o`2I<ol0018co`000`000?ooooooo`2Ooooo001Woooo00@0000co`0co`3o09TB
<ol000<0003oooooool0X?ooo`00Ioooo`040000<ol0<ol0o`2I4S?o00030000oooooooo0:3oool0
06Ooool0100003?o03?o0?l0VA8co`000`000?ooooooo`2Poooo001Ooooo100000Coool0100003?o
03?o0?l0VA8co`000`000?ooooooo`2Poooo001Ooooo00<0003oooooool01Oooo`040000<ol0<ol0
o`2I4C?o00030000oooooooo0:7oool0063oool00`000?ooooooo`04oooo0P000003<ol0o`2I<ol0
010co`000`000?ooooooo`2Qoooo001Qoooo00<0003oooooool00oooo`040000<ol0<ol0o`2I4C?o
00030000oooooooo0:7oool005ooool010000?ooooooo`0000Coool0100003?o03?o0?l0VA0co`00
0`000?ooooooo`2Roooo001Poooo0P0000Goool0100003?o03?o0?l0VA0co`000`000?ooooooo`2R
oooo001Woooo00@0000co`0co`3o09T@<ol000<0003oooooool0X_ooo`00Ioooo`040000<ol0<ol0
o`2I43?o00030000oooooooo0:;oool006Ooool2000000<co`3o09Tco`003S?o00030000oooooooo
0:?oool006Ooool0100003?o03?o0?l0V@lco`000`000?ooooooo`2Soooo001Woooo00@0000co`0c
o`3o09T?<ol000<0003oooooool0Xoooo`00Ioooo`040000<ol0<ol0o`2I3c?o00030000oooooooo
0:?oool006Ooool0100003?o03?o0?l0V@hco`000`000?ooooooo`2Toooo001Woooo00@0000co`0c
o`3o09T><ol000<0003oooooool0Y?ooo`00Ioooo`040000<ol0<ol0o`2I3S?o00030000oooooooo
0:Coool006Ooool2000000<co`3o09Tco`003C?o00030000oooooooo0:Coool006Ooool0100003?o
03?o0?l0V@dco`000`000?ooooooo`2Uoooo001Woooo00@0000co`0co`3o09T=<ol000<0003ooooo
ool0YOooo`00Ioooo`040000<ol0<ol0o`2I3C?o00030000oooooooo0:Goool006Ooool0100003?o
03?o0?l0V@dco`000`000?ooooooo`2Uoooo001Woooo00@0000co`0co`3o09T<<ol000<0003ooooo
ool0Y_ooo`00Ioooo`8000000c?o0?l0VC?o000;<ol000<0003oooooool0Y_ooo`00Ioooo`040000
<ol0<ol0o`2I33?o00030000oooooooo0:Koool006Ooool0100003?o03?o0?l0V@`co`000`000?oo
ooooo`2Voooo001Woooo00@0000co`0co`3o09T;<ol000<0003oooooool0Yoooo`00Ioooo`040000
<ol0<ol0o`2I2c?o00030000oooooooo0:Ooool006Ooool0100003?o03?o0?l0V@/co`000`000?oo
ooooo`2Woooo001Woooo0P000003<ol0o`2I<ol000Xco`000`000?ooooooo`2Woooo001Woooo00@0
000co`0co`3o09T;<ol000<0003oooooool0Yoooo`00Ioooo`040000<ol0<ol0o`2I2c?o00030000
oooooooo0:Ooool006Ooool0100003?o03?o0?l0V@Xco`000`000?ooooooo`2Xoooo001Poooo0P00
00Goool0100003?o03?o0?l0V@Xco`000`000?ooooooo`2Xoooo001Ooooo00@0003oooooool00004
oooo00@0000co`0co`3o09T:<ol000<0003oooooool0Z?ooo`00HOooo`030000oooooooo00?oool2
000000<co`3o09Tco`002C?o00030000oooooooo0:Soool006;oool00`000?ooooooo`02oooo00@0
000co`0co`3o09T:<ol000<0003oooooool0Z?ooo`00Goooo`040000oooooooo00001?ooo`040000
<ol0<ol0o`2I2S?o00030000oooooooo0:Soool0063oool200001Oooo`040000<ol0<ol0o`2I2C?o
00030000oooooooo0:Woool006Ooool0100003?o03?o0?l0V@Tco`000`000?ooooooo`2Yoooo001W
oooo00@0000co`0co`3o09T9<ol000<0003oooooool0ZOooo`00Ioooo`040000<ol0<ol0o`2I2C?o
00030000oooooooo0:Woool006Ooool2000000<co`3o09Tco`0023?o00030000oooooooo0:Woool0
06Ooool0100003?o03?o0?l0V@Tco`000`000?ooooooo`2Yoooo001Woooo00@0000co`0co`3o09T8
<ol000<0003oooooool0Z_ooo`00Ioooo`040000<ol0<ol0o`2I23?o00030000oooooooo0:[oool0
06Ooool0100003?o03?o0?l0V@Pco`000`000?ooooooo`2Zoooo001Woooo00@0000co`0co`3o09T8
<ol000<0003oooooool0Z_ooo`00Ioooo`8000000c?o0?l0VC?o0007<ol000<0003oooooool0Z_oo
o`00Ioooo`040000<ol0<ol0o`2I23?o00030000oooooooo0:[oool006Ooool0100003?o03?o0?l0
V@Pco`000`000?ooooooo`2Zoooo001Woooo00@0000co`0co`3o09T7<ol000<0003oooooool0Zooo
o`00Ioooo`040000<ol0<ol0o`2I1c?o00030000oooooooo0:_oool006Ooool0100003?o03?o0?l0
V@Lco`000`000?ooooooo`2[oooo001Woooo0P000003<ol0o`2I<ol000Hco`000`000?ooooooo`2[
oooo001Woooo00@0000co`0co`3o09T7<ol000<0003oooooool0Zoooo`00Ioooo`040000<ol0<ol0
o`2I1c?o00030000oooooooo0:_oool006Ooool0100003?o03?o0?l0V@Hco`000`000?ooooooo`2/
oooo001Woooo00@0000co`0co`3o09T6<ol000<0003oooooool0[?ooo`00Ioooo`040000<ol0<ol0
o`2I1S?o00030000oooooooo0:coool006Ooool2000000<co`3o09Tco`001C?o00030000oooooooo
0:coool006Ooool0100003?o03?o0?l0V@Hco`000`000?ooooooo`2/oooo001Woooo00@0000co`0c
o`3o09T6<ol000<0003oooooool0[?ooo`00Ioooo`040000<ol0<ol0o`2I1S?o00030000oooooooo
0:coool006Ooool0100003?o03?o0?l0V@Hco`000`000?ooooooo`2/oooo001Qoooo0`0000?oool0
100003?o03?o0?l0V@Hco`000`000?ooooooo`2/oooo001Roooo00<0003oooooool00_ooo`040000
<ol0<ol0o`2I1S?o00030000oooooooo0:coool005ooool500000oooo`8000000c?o0?l0VC?o0005
<ol000<0003oooooool0[?ooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0
003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001W
oooo2C?o0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001W
oooo2C?o00Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
06Ooool9<ol02?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?oo
o`800004oooo0P0000Goool300000_ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002?ooo`040000oooooooo00001Oooo`050000oooooooooooo000007[oool006Ooool9<ol01ooo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo1@0000?oool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`05
00003?ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooo`000003oooo00<0003oooooool0N?oo
o`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:oooo0P0000Goool200000_ooo`030000
oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.34309 .12361 L
.34772 .12361 L
.35271 .12361 L
.35513 .12361 L
.35742 .12361 L
.35842 .12361 L
.35948 .12361 L
s
.35948 .12361 m
.35995 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.31304 .12361 L
.31574 .12361 L
.31865 .12361 L
.32006 .12361 L
.32076 .12361 L
.3214 .12361 L
.3226 .12331 L
.32392 .1223 L
.34309 .10888 L
.34816 .10571 L
.35365 .10241 L
.35617 .10094 L
.35755 .10015 L
.35884 .09942 L
.35993 .09881 L
.36111 .12361 L
.36242 .12361 L
.36361 .12361 L
.38221 .12361 L
.42206 .12361 L
.46039 .12361 L
.50117 .12361 L
.54044 .12361 L
.57819 .12361 L
.61839 .12361 L
.65708 .12361 L
.69822 .12361 L
.73784 .12361 L
.77595 .12361 L
.81651 .12361 L
.85556 .12361 L
.89706 .12361 L
.93704 .12361 L
.9755 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300007_ooo`800002oooo00<0I_ooooooool06_ooo`80000:oooo0`00
01ooool200008?ooo`80000:oooo0`00023oool200005oooo`00Ioooo`030000oooooooo0080I_nd
oooo001Woooo00D00000I_l0I_ooool0I_l0]?ooo`00Ioooo`050000oooooooooooo06Ko0;Coool0
06Goool206Ko00<0003oooooool00_ooo`0306Kooooooooo0;7oool006?oool206Ko0_ooo`030000
oooooooo00;oool00`1Vooooooooo`2aoooo000@ooooo`00017oool001Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00D0000co`0co`0co`3o09T00c?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool09Oooo`030000oooooooo02Koool01@0003?o03?o03?o0?l0V@0S<ol000<0
000co`0co`0093?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool006Ooool0
1@0003?o03?o03?o0?l0V@15<ol01@0006[oool006Ooool01@0003?o03?o03?o0?l0V@10<ol01@00
06ooool006Ooool01@0003?o03?o03?o0?l0V@0k<ol01@0007Coool006Ooool01@0003?o03?o03?o
0?l0V@0g<ol0100007Woool006Ooool200000S?o0003o`2I<ol0<ol003<co`020000OOooo`00Iooo
o`050000<ol0<ol0<ol0o`2I03<co`020000Ooooo`00Ioooo`050000<ol0<ol0<ol0o`2I034co`02
0000POooo`00Ioooo`050000<ol0<ol0<ol0o`2I02lco`020000Poooo`00Ioooo`050000<ol0<ol0
<ol0o`2I02hco`000`000?ooooooo`23oooo001Woooo00D0000co`0co`0co`3o09T0;3?o00800026
oooo001Woooo0P00008co`000ol0VC?o03?o000X<ol00P0008Soool006Ooool01@0003?o03?o03?o
0?l0V@0Y<ol000<0003oooooool0R?ooo`00Ioooo`050000<ol0<ol0<ol0o`2I02Pco`000`000?oo
ooooo`29oooo001Woooo00D0000co`0co`0co`3o09T09c?o00030000oooooooo08[oool006Ooool0
1@0003?o03?o03?o0?l0V@0V<ol000<0003oooooool0Roooo`00Ioooo`050000<ol0<ol0<ol0o`2I
02Hco`000`000?ooooooo`2;oooo001Woooo0P00008co`000ol0VC?o03?o000S<ol000<0003ooooo
ool0S?ooo`00Ioooo`050000<ol0<ol0<ol0o`2I02@co`000`000?ooooooo`2=oooo001Woooo00D0
000co`0co`0co`3o09T08c?o00030000oooooooo08koool006Ooool01@0003?o03?o03?o0?l0V@0R
<ol000<0003oooooool0Soooo`00Ioooo`050000<ol0<ol0<ol0o`2I024co`000`000?ooooooo`2@
oooo001Woooo00D0000co`0co`0co`3o09T08C?o00030000oooooooo093oool006Ooool200000S?o
0003o`2I<ol0<ol001hco`000`000?ooooooo`2Aoooo001Woooo00D0000co`0co`0co`3o09T07c?o
00030000oooooooo09;oool006Ooool01@0003?o03?o03?o0?l0V@0N<ol000<0003oooooool0Tooo
o`00Ioooo`050000<ol0<ol0<ol0o`2I01hco`000`000?ooooooo`2Coooo001Woooo00D0000co`0c
o`0co`3o09T07C?o00030000oooooooo09Coool005ooool500000oooo`050000<ol0<ol0<ol0o`2I
01dco`000`000?ooooooo`2Doooo001Qoooo00<0003oooooool00oooo`050000<ol0<ol0<ol0o`2I
01`co`000`000?ooooooo`2Eoooo001Qoooo00<0003oooooool00oooo`800002<ol000?o09Tco`0c
o`006S?o00030000oooooooo09Goool0067oool00`000?ooooooo`03oooo00D0000co`0co`0co`3o
09T06c?o00030000oooooooo09Koool0067oool00`000?ooooooo`03oooo00D0000co`0co`0co`3o
09T06c?o00030000oooooooo09Koool0063oool200001Oooo`050000<ol0<ol0<ol0o`2I01Xco`00
0`000?ooooooo`2Goooo001Woooo00D0000co`0co`0co`3o09T06S?o00030000oooooooo09Ooool0
06Ooool01@0003?o03?o03?o0?l0V@0I<ol000<0003oooooool0V?ooo`00Ioooo`800002<ol000?o
09Tco`0co`005c?o00030000oooooooo09Soool006Ooool01@0003?o03?o03?o0?l0V@0H<ol000<0
003oooooool0VOooo`00Ioooo`050000<ol0<ol0<ol0o`2I01Pco`000`000?ooooooo`2Ioooo001W
oooo00D0000co`0co`0co`3o09T05c?o00030000oooooooo09[oool006Ooool01@0003?o03?o03?o
0?l0V@0G<ol000<0003oooooool0V_ooo`00Ioooo`050000<ol0<ol0<ol0o`2I01Hco`000`000?oo
ooooo`2Koooo001Woooo0P00008co`000ol0VC?o03?o000D<ol000<0003oooooool0Voooo`00Iooo
o`050000<ol0<ol0<ol0o`2I01Dco`000`000?ooooooo`2Loooo001Woooo00D0000co`0co`0co`3o
09T05C?o00030000oooooooo09coool006Ooool01@0003?o03?o03?o0?l0V@0D<ol000<0003ooooo
ool0WOooo`00Ioooo`050000<ol0<ol0<ol0o`2I01@co`000`000?ooooooo`2Moooo001Woooo00D0
000co`0co`0co`3o09T053?o00030000oooooooo09goool006Ooool01@0003?o03?o03?o0?l0V@0C
<ol000<0003oooooool0W_ooo`00Ioooo`800002<ol000?o09Tco`0co`004C?o00030000oooooooo
09koool006Ooool01@0003?o03?o03?o0?l0V@0C<ol000<0003oooooool0W_ooo`00Ioooo`050000
<ol0<ol0<ol0o`2I01<co`000`000?ooooooo`2Noooo001Woooo00D0000co`0co`0co`3o09T04S?o
00030000oooooooo09ooool006Ooool01@0003?o03?o03?o0?l0V@0B<ol000<0003oooooool0Wooo
o`00Ioooo`050000<ol0<ol0<ol0o`2I018co`000`000?ooooooo`2Ooooo001Woooo0P00008co`00
0ol0VC?o03?o000@<ol000<0003oooooool0Woooo`00Ioooo`050000<ol0<ol0<ol0o`2I014co`00
0`000?ooooooo`2Poooo001Woooo00D0000co`0co`0co`3o09T04C?o00030000oooooooo0:3oool0
06Ooool01@0003?o03?o03?o0?l0V@0A<ol000<0003oooooool0X?ooo`00Goooo`@00004oooo00D0
000co`0co`0co`3o09T04C?o00030000oooooooo0:3oool005ooool00`000?ooooooo`05oooo00D0
000co`0co`0co`3o09T043?o00030000oooooooo0:7oool0063oool00`000?ooooooo`04oooo0P00
008co`000ol0VC?o03?o000><ol000<0003oooooool0XOooo`00HOooo`030000oooooooo00?oool0
1@0003?o03?o03?o0?l0V@0@<ol000<0003oooooool0XOooo`00Goooo`040000oooooooo00001?oo
o`050000<ol0<ol0<ol0o`2I00lco`000`000?ooooooo`2Roooo001Poooo0P0000Goool01@0003?o
03?o03?o0?l0V@0?<ol000<0003oooooool0X_ooo`00Ioooo`050000<ol0<ol0<ol0o`2I00lco`00
0`000?ooooooo`2Roooo001Woooo00D0000co`0co`0co`3o09T03c?o00030000oooooooo0:;oool0
06Ooool200000S?o0003o`2I<ol0<ol000`co`000`000?ooooooo`2Soooo001Woooo00D0000co`0c
o`0co`3o09T03S?o00030000oooooooo0:?oool006Ooool01@0003?o03?o03?o0?l0V@0><ol000<0
003oooooool0Xoooo`00Ioooo`050000<ol0<ol0<ol0o`2I00hco`000`000?ooooooo`2Soooo001W
oooo00D0000co`0co`0co`3o09T03C?o00030000oooooooo0:Coool006Ooool01@0003?o03?o03?o
0?l0V@0=<ol000<0003oooooool0Y?ooo`00Ioooo`050000<ol0<ol0<ol0o`2I00dco`000`000?oo
ooooo`2Toooo001Woooo0P00008co`000ol0VC?o03?o000;<ol000<0003oooooool0Y?ooo`00Iooo
o`050000<ol0<ol0<ol0o`2I00`co`000`000?ooooooo`2Uoooo001Woooo00D0000co`0co`0co`3o
09T033?o00030000oooooooo0:Goool006Ooool01@0003?o03?o03?o0?l0V@0<<ol000<0003ooooo
ool0YOooo`00Ioooo`050000<ol0<ol0<ol0o`2I00`co`000`000?ooooooo`2Uoooo001Woooo00D0
000co`0co`0co`3o09T02c?o00030000oooooooo0:Koool006Ooool200000S?o0003o`2I<ol0<ol0
00Tco`000`000?ooooooo`2Voooo001Woooo00D0000co`0co`0co`3o09T02c?o00030000oooooooo
0:Koool006Ooool01@0003?o03?o03?o0?l0V@0;<ol000<0003oooooool0Y_ooo`00Ioooo`050000
<ol0<ol0<ol0o`2I00Xco`000`000?ooooooo`2Woooo001Woooo00D0000co`0co`0co`3o09T02S?o
00030000oooooooo0:Ooool006Ooool01@0003?o03?o03?o0?l0V@0:<ol000<0003oooooool0Yooo
o`00Ioooo`800002<ol000?o09Tco`0co`0023?o00030000oooooooo0:Ooool006Ooool01@0003?o
03?o03?o0?l0V@0:<ol000<0003oooooool0Yoooo`00Ioooo`050000<ol0<ol0<ol0o`2I00Xco`00
0`000?ooooooo`2Woooo001Woooo00D0000co`0co`0co`3o09T02C?o00030000oooooooo0:Soool0
063oool200001Oooo`050000<ol0<ol0<ol0o`2I00Tco`000`000?ooooooo`2Xoooo001Ooooo00@0
003oooooool00004oooo00D0000co`0co`0co`3o09T02C?o00030000oooooooo0:Soool0067oool0
0`000?ooooooo`03oooo0P00008co`000ol0VC?o03?o0007<ol000<0003oooooool0Z?ooo`00H_oo
o`030000oooooooo00;oool01@0003?o03?o03?o0?l0V@09<ol000<0003oooooool0Z?ooo`00Gooo
o`040000oooooooo00001?ooo`050000<ol0<ol0<ol0o`2I00Tco`000`000?ooooooo`2Xoooo001P
oooo0P0000Goool01@0003?o03?o03?o0?l0V@08<ol000<0003oooooool0ZOooo`00Ioooo`050000
<ol0<ol0<ol0o`2I00Pco`000`000?ooooooo`2Yoooo001Woooo00D0000co`0co`0co`3o09T023?o
00030000oooooooo0:Woool006Ooool01@0003?o03?o03?o0?l0V@08<ol000<0003oooooool0ZOoo
o`00Ioooo`800002<ol000?o09Tco`0co`001S?o00030000oooooooo0:Woool006Ooool01@0003?o
03?o03?o0?l0V@08<ol000<0003oooooool0ZOooo`00Ioooo`050000<ol0<ol0<ol0o`2I00Lco`00
0`000?ooooooo`2Zoooo001Woooo00D0000co`0co`0co`3o09T01c?o00030000oooooooo0:[oool0
06Ooool01@0003?o03?o03?o0?l0V@07<ol000<0003oooooool0Z_ooo`00Ioooo`050000<ol0<ol0
<ol0o`2I00Lco`000`000?ooooooo`2Zoooo001Woooo0P00008co`000ol0VC?o03?o0005<ol000<0
003oooooool0Z_ooo`00Ioooo`050000<ol0<ol0<ol0o`2I00Lco`000`000?ooooooo`2Zoooo001W
oooo00D0000co`0co`0co`3o09T01c?o00030000oooooooo0:[oool006Ooool01@0003?o03?o03?o
0?l0V@06<ol000<0003oooooool0Zoooo`00Ioooo`050000<ol0<ol0<ol0o`2I00Hco`000`000?oo
ooooo`2[oooo001Woooo00D0000co`0co`0co`3o09T01S?o00030000oooooooo0:_oool006Ooool2
00000S?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2[oooo001Woooo00D0000co`0co`0co`3o
09T01S?o00030000oooooooo0:_oool006Ooool01@0003?o03?o03?o0?l0V@06<ol000<0003ooooo
ool0Zoooo`00Ioooo`050000<ol0<ol0<ol0o`2I00Dco`000`000?ooooooo`2/oooo001Woooo00D0
000co`0co`0co`3o09T01C?o00030000oooooooo0:coool006Ooool01@0003?o03?o03?o0?l0V@05
<ol000<0003oooooool0[?ooo`00Ioooo`800002<ol000?o09Tco`0co`000c?o00030000oooooooo
0:coool006Ooool01@0003?o03?o03?o0?l0V@05<ol000<0003oooooool0[?ooo`00Ioooo`050000
<ol0<ol0<ol0o`2I00Dco`000`000?ooooooo`2/oooo001Woooo00D0000co`0co`0co`3o09T01C?o
00030000oooooooo0:coool006Ooool01@0003?o03?o03?o0?l0V@05<ol000<0003oooooool0[?oo
o`00HOooo`<00003oooo00D0000co`0co`0co`3o09T01C?o00030000oooooooo0:coool006;oool0
0`000?ooooooo`02oooo00D0000co`0co`0co`3o09T01C?o00030000oooooooo0:coool005ooool5
00000oooo`800002<ol000?o09Tco`0co`000c?o00030000oooooooo0:coool005ooool010000?oo
ooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004
oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800003oooo0`0000Coool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo
00001?ooo`030000oooooooo07Ooool006Ooool9<ol02?ooo`030000oooooooo00D0000<oooo00@0
003oooooool00008oooo00@0003oooooool00002oooo0`0000Coool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000
oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo001Woooo2C?o
0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.35271 .12361 L
.36173 .12361 L
.36405 .12361 L
.3652 .12361 L
.36626 .12361 L
s
.36626 .12361 m
.36675 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.30791 .12361 L
.31054 .12361 L
.31304 .12361 L
.31444 .12361 L
.31523 .12361 L
.31597 .12353 L
.31727 .12253 L
.31865 .12147 L
.32392 .11758 L
.34309 .10496 L
.35337 .09903 L
.35878 .09608 L
.36174 .09452 L
.36318 .09376 L
.3645 .09308 L
.36574 .09245 L
.36691 .12361 L
.36815 .12361 L
.3695 .12361 L
.375 .12361 L
.38467 .12361 L
.42545 .12361 L
.46472 .12361 L
.50247 .12361 L
.54267 .12361 L
.58136 .12361 L
.6225 .12361 L
.66212 .12361 L
.70023 .12361 L
.74079 .12361 L
.77984 .12361 L
.82133 .12361 L
.86132 .12361 L
.89978 .12361 L
.9407 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
10000?ooooooooooo`<0I_lIoooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000
oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_oo
o`006?ooo`80000Poooo0P0000[oool300007_ooo`8000001Oooo`1Vooooooooo`1Vo`0Joooo0P00
00[oool300007oooo`80000Poooo0P0000[oool300008?ooo`80000Goooo001Woooo00<00000I_l0
I_l00oooo`0306Kooooooooo0;3oool006Ooool00`000?ooooooo`03oooo00<0I_ooooooool0/?oo
o`00IOooo`80I_l00`000?ooooooo`03oooo00<0I_ooooooool0/?ooo`00Hoooo`80I_l2oooo00<0
003oooooool00oooo`0306Kooooooooo0;3oool006;oool00`1Vooooooooo`02oooo00<0003ooooo
ool00oooo`0306Kooooooooo0;3oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`0003?o03?o0003<ol000?o09Tco`0000001c?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol000<co`000ol0VC?o03?o000O<ol000<0
000co`0co`0093?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool006Ooool0
0`0003?o03?o0003<ol000?o09Tco`0co`00@C?o00D0001Zoooo001Woooo00<0000co`0co`000c?o
0003o`2I<ol0<ol003`co`050000Koooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o000g
<ol01@0007Coool006Ooool00`0003?o03?o0003<ol000?o09Tco`0co`00<c?o00@0001ioooo001W
oooo0P0000@co`000ol0VC?o03?o000a<ol00P0007goool006Ooool00`0003?o03?o0003<ol000?o
09Tco`0co`00;c?o0080001ooooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol002dco`02
0000POooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o000[<ol00P0008?oool006Ooool0
0`0003?o03?o0003<ol000?o09Tco`0co`00:S?o00030000oooooooo08?oool006Ooool00`0003?o
03?o0003<ol000?o09Tco`0co`00:3?o00800026oooo001Woooo0P0000@co`000ol0VC?o03?o000V
<ol00P0008Soool006Ooool00`0003?o03?o0003<ol000?o09Tco`0co`009C?o00030000oooooooo
08Soool006Ooool00`0003?o03?o0003<ol000?o09Tco`0co`0093?o00030000oooooooo08Woool0
06Ooool00`0003?o03?o0003<ol000?o09Tco`0co`008c?o00030000oooooooo08[oool006Ooool0
0`0003?o03?o0003<ol000?o09Tco`0co`008S?o00030000oooooooo08_oool006Ooool00`0003?o
03?o0003<ol000?o09Tco`0co`008S?o00030000oooooooo08_oool006Ooool2000013?o0003o`2I
<ol0<ol0024co`000`000?ooooooo`2<oooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol0
020co`000`000?ooooooo`2=oooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol001lco`00
0`000?ooooooo`2>oooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol001hco`000`000?oo
ooooo`2?oooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol001dco`000`000?ooooooo`2@
oooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol001dco`000`000?ooooooo`2@oooo001W
oooo0P0000@co`000ol0VC?o03?o000L<ol000<0003oooooool0TOooo`00Ioooo`030000<ol0<ol0
00<co`000ol0VC?o03?o000K<ol000<0003oooooool0T_ooo`00Ioooo`030000<ol0<ol000<co`00
0ol0VC?o03?o000J<ol000<0003oooooool0Toooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o
03?o000J<ol000<0003oooooool0Toooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o000I
<ol000<0003oooooool0U?ooo`00Goooo`D00003oooo00<0000co`0co`000c?o0003o`2I<ol0<ol0
01Tco`000`000?ooooooo`2Doooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol000<co`00
0ol0VC?o03?o000H<ol000<0003oooooool0UOooo`00HOooo`030000oooooooo00?oool2000013?o
0003o`2I<ol0<ol001Pco`000`000?ooooooo`2Eoooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol000<co`000ol0VC?o03?o000G<ol000<0003oooooool0U_ooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o0003<ol000?o09Tco`0co`005c?o00030000oooooooo09Koool0063oool2
00001Oooo`030000<ol0<ol000<co`000ol0VC?o03?o000F<ol000<0003oooooool0Uoooo`00Iooo
o`030000<ol0<ol000<co`000ol0VC?o03?o000F<ol000<0003oooooool0Uoooo`00Ioooo`030000
<ol0<ol000<co`000ol0VC?o03?o000E<ol000<0003oooooool0V?ooo`00Ioooo`800004<ol000?o
09Tco`0co`005C?o00030000oooooooo09Soool006Ooool00`0003?o03?o0003<ol000?o09Tco`0c
o`0053?o00030000oooooooo09Woool006Ooool00`0003?o03?o0003<ol000?o09Tco`0co`0053?o
00030000oooooooo09Woool006Ooool00`0003?o03?o0003<ol000?o09Tco`0co`004c?o00030000
oooooooo09[oool006Ooool00`0003?o03?o0003<ol000?o09Tco`0co`004c?o00030000oooooooo
09[oool006Ooool00`0003?o03?o0003<ol000?o09Tco`0co`004S?o00030000oooooooo09_oool0
06Ooool2000013?o0003o`2I<ol0<ol0018co`000`000?ooooooo`2Koooo001Woooo00<0000co`0c
o`000c?o0003o`2I<ol0<ol0014co`000`000?ooooooo`2Loooo001Woooo00<0000co`0co`000c?o
0003o`2I<ol0<ol0014co`000`000?ooooooo`2Loooo001Woooo00<0000co`0co`000c?o0003o`2I
<ol0<ol0010co`000`000?ooooooo`2Moooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol0
010co`000`000?ooooooo`2Moooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol0010co`00
0`000?ooooooo`2Moooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol000lco`000`000?oo
ooooo`2Noooo001Woooo0P0000@co`000ol0VC?o03?o000?<ol000<0003oooooool0W_ooo`00Iooo
o`030000<ol0<ol000<co`000ol0VC?o03?o000?<ol000<0003oooooool0W_ooo`00Ioooo`030000
<ol0<ol000<co`000ol0VC?o03?o000?<ol000<0003oooooool0W_ooo`00Ioooo`030000<ol0<ol0
00<co`000ol0VC?o03?o000><ol000<0003oooooool0Woooo`00Ioooo`030000<ol0<ol000<co`00
0ol0VC?o03?o000><ol000<0003oooooool0Woooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o
03?o000><ol000<0003oooooool0Woooo`00Ioooo`800004<ol000?o09Tco`0co`003S?o00030000
oooooooo09ooool006Ooool00`0003?o03?o0003<ol000?o09Tco`0co`003C?o00030000oooooooo
0:3oool006Ooool00`0003?o03?o0003<ol000?o09Tco`0co`003C?o00030000oooooooo0:3oool0
06Ooool00`0003?o03?o0003<ol000?o09Tco`0co`003C?o00030000oooooooo0:3oool005ooool4
00001?ooo`030000<ol0<ol000<co`000ol0VC?o03?o000=<ol000<0003oooooool0X?ooo`00Gooo
o`030000oooooooo00Goool00`0003?o03?o0003<ol000?o09Tco`0co`0033?o00030000oooooooo
0:7oool0063oool00`000?ooooooo`04oooo0P0000@co`000ol0VC?o03?o000<<ol000<0003ooooo
ool0XOooo`00HOooo`030000oooooooo00?oool00`0003?o03?o0003<ol000?o09Tco`0co`0033?o
00030000oooooooo0:7oool005ooool010000?ooooooo`0000Coool00`0003?o03?o0003<ol000?o
09Tco`0co`002c?o00030000oooooooo0:;oool0063oool200001Oooo`030000<ol0<ol000<co`00
0ol0VC?o03?o000;<ol000<0003oooooool0X_ooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o
03?o000;<ol000<0003oooooool0X_ooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o000;
<ol000<0003oooooool0X_ooo`00Ioooo`800004<ol000?o09Tco`0co`002S?o00030000oooooooo
0:?oool006Ooool00`0003?o03?o0003<ol000?o09Tco`0co`002S?o00030000oooooooo0:?oool0
06Ooool00`0003?o03?o0003<ol000?o09Tco`0co`002S?o00030000oooooooo0:?oool006Ooool0
0`0003?o03?o0003<ol000?o09Tco`0co`002S?o00030000oooooooo0:?oool006Ooool00`0003?o
03?o0003<ol000?o09Tco`0co`002C?o00030000oooooooo0:Coool006Ooool00`0003?o03?o0003
<ol000?o09Tco`0co`002C?o00030000oooooooo0:Coool006Ooool00`0003?o03?o0003<ol000?o
09Tco`0co`002C?o00030000oooooooo0:Coool006Ooool2000013?o0003o`2I<ol0<ol000Tco`00
0`000?ooooooo`2Toooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Pco`000`000?oo
ooooo`2Uoooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`2U
oooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`2Uoooo001W
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`2Uoooo001Woooo00<0
000co`0co`000c?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Voooo001Woooo0P0000@co`00
0ol0VC?o03?o0007<ol000<0003oooooool0Y_ooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o
03?o0007<ol000<0003oooooool0Y_ooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o0007
<ol000<0003oooooool0Y_ooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o0006<ol000<0
003oooooool0Yoooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o0006<ol000<0003ooooo
ool0Yoooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o0006<ol000<0003oooooool0Yooo
o`00Ioooo`800004<ol000?o09Tco`0co`001S?o00030000oooooooo0:Ooool006Ooool00`0003?o
03?o0003<ol000?o09Tco`0co`001S?o00030000oooooooo0:Ooool006Ooool00`0003?o03?o0003
<ol000?o09Tco`0co`001S?o00030000oooooooo0:Ooool006Ooool00`0003?o03?o0003<ol000?o
09Tco`0co`001C?o00030000oooooooo0:Soool0063oool200001Oooo`030000<ol0<ol000<co`00
0ol0VC?o03?o0005<ol000<0003oooooool0Z?ooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol000<co`000ol0VC?o03?o0005<ol000<0003oooooool0Z?ooo`00HOooo`030000oooooooo
00?oool2000013?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Xoooo001Roooo00<0003ooooo
ool00_ooo`030000<ol0<ol000<co`000ol0VC?o03?o0005<ol000<0003oooooool0Z?ooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000<co`000ol0VC?o03?o0005<ol000<0003ooooo
ool0Z?ooo`00H?ooo`800005oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000@co`000`000?oo
ooooo`2Yoooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Y
oooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Yoooo001W
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Yoooo001Woooo0P00
00@co`000ol0VC?o03?o0004<ol000<0003oooooool0ZOooo`00Ioooo`030000<ol0<ol000<co`00
0ol0VC?o03?o0004<ol000<0003oooooool0ZOooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o
03?o0003<ol000<0003oooooool0Z_ooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o0003
<ol000<0003oooooool0Z_ooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o0003<ol000<0
003oooooool0Z_ooo`00Ioooo`030000<ol0<ol000<co`000ol0VC?o03?o0003<ol000<0003ooooo
ool0Z_ooo`00Ioooo`800004<ol000?o09Tco`0co`000c?o00030000oooooooo0:[oool006Ooool0
0`0003?o03?o0003<ol000?o09Tco`0co`000c?o00030000oooooooo0:[oool006Ooool00`0003?o
03?o0003<ol000?o09Tco`0co`000c?o00030000oooooooo0:[oool006Ooool00`0003?o03?o0003
<ol000?o09Tco`0co`000S?o00030000oooooooo0:_oool006Ooool00`0003?o03?o0003<ol000?o
09Tco`0co`000S?o00030000oooooooo0:_oool006Ooool00`0003?o03?o0003<ol000?o09Tco`0c
o`000S?o00030000oooooooo0:_oool006Ooool2000013?o0003o`2I<ol0<ol0008co`000`000?oo
ooooo`2[oooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2[
oooo001Woooo00<0000co`0co`000c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2[oooo001W
oooo00<0000co`0co`000c?o0005o`2I<ol0<ol0<ol000000:koool006Ooool00`0003?o03?o0003
<ol000Go09Tco`0co`0co`000000[_ooo`00Ioooo`030000<ol0<ol000<co`001Ol0VC?o03?o03?o
0000002^oooo001Woooo0P0000@co`001Ol0VC?o03?o03?o0000002^oooo001Woooo00<0000co`0c
o`000c?o0005o`2I<ol0<ol0<ol000000:koool006Ooool00`0003?o03?o0003<ol000Go09Tco`0c
o`0co`000000[_ooo`00Ioooo`030000<ol0<ol000<co`001Ol0VC?o03?o03?o0000002^oooo001W
oooo00<0000co`0co`000c?o0005o`2I<ol0<ol0<ol000000:koool0067oool300000oooo`030000
<ol0<ol000<co`001Ol0VC?o03?o03?o0000002^oooo001Roooo00<0003oooooool00_ooo`030000
<ol0<ol000<co`001Ol0VC?o03?o03?o0000002^oooo001Ooooo1@0000?oool2000013?o0005o`2I
<ol0<ol0<ol000000:koool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000
oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Iooo
o`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Iooo
o`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool2
00001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001W
oooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool006Ooool9
<ol02?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo0P0000Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool2
00000oooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.36626 .12361 L
.36876 .12361 L
.37114 .12361 L
.37178 .12361 L
.37247 .12361 L
s
.37247 .12361 m
.37278 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30316 .12361 L
.3056 .12361 L
.30791 .12361 L
.30919 .12361 L
.30992 .1233 L
.31059 .12278 L
.31304 .12092 L
.32392 .11313 L
.34309 .10129 L
.35365 .09556 L
.36361 .09052 L
.36795 .08842 L
.37033 .0873 L
.37149 .08676 L
.37255 .08627 L
.3737 .12361 L
.37495 .12361 L
.37758 .12361 L
.38221 .12361 L
.42206 .12361 L
.46039 .12361 L
.50117 .12361 L
.54044 .12361 L
.57819 .12361 L
.61839 .12361 L
.65708 .12361 L
.69822 .12361 L
.73784 .12361 L
.77595 .12361 L
.81651 .12361 L
.85556 .12361 L
.89706 .12361 L
.93704 .12361 L
.9755 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool00oooo`<0I_lGoooo00@0003ooooo
ool0000;oooo00<0003oooooool07_ooo`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0
003oooooool07_ooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo01Ooool4
00000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool00_ooo`0406Kooooooooo
06Ko5oooo`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool07oooo`030000oooooooo
00Soool200008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0003ooooo
ool00009oooo00<0003oooooool07_ooo`030000oooooooo0080I_l3oooo00<0I_ooooooool05Ooo
o`040000oooooooo00002Oooo`030000oooooooo023oool00`000?ooooooo`0Ooooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200008?ooo`80000:
oooo0`0001koool2000000<0I_ooooooool00oooo`0306Kooooooooo01Koool200002_ooo`<0000O
oooo0P00023oool200002_ooo`<0000Poooo0P0001Ooool006Ooool00`000?ooooooo`05oooo00<0
I_ooooooool0[_ooo`00IOooo`80I_l00`000?ooooooo`05oooo00<0I_ooooooool0[_ooo`00Hooo
o`80I_l2oooo00<0003oooooool01Oooo`0306Kooooooooo0:koool006;oool00`1Vooooooooo`02
oooo00<0003oooooool01Oooo`0306Kooooooooo0:koool0067oool00`1Vooooooooo`03oooo00<0
003oooooool01Oooo`0306Kooooooooo0:koool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol000Dco`000ol0VC?o03?o000M
<ol000<0000co`0co`0093?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool0
06Ooool00`0003?o03?o0005<ol000?o09Tco`0co`00?c?o00D0001Zoooo001Woooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol003Xco`050000Koooo`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o
03?o000e<ol01@0007Coool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`00<C?o00@0001i
oooo001Woooo0P0000Hco`000ol0VC?o03?o000_<ol00P0007goool006Ooool00`0003?o03?o0005
<ol000?o09Tco`0co`00;C?o0080001ooooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
02/co`020000POooo`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o03?o000Y<ol00P0008?oool0
06Ooool00`0003?o03?o0005<ol000?o09Tco`0co`00:3?o00030000oooooooo08?oool006Ooool0
0`0003?o03?o0005<ol000?o09Tco`0co`009S?o00800026oooo001Woooo0P0000Hco`000ol0VC?o
03?o000T<ol00P0008Soool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`008c?o00030000
oooooooo08Soool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`008S?o00030000oooooooo
08Woool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`008C?o00030000oooooooo08[oool0
06Ooool00`0003?o03?o0005<ol000?o09Tco`0co`0083?o00030000oooooooo08_oool006Ooool0
0`0003?o03?o0005<ol000?o09Tco`0co`0083?o00030000oooooooo08_oool006Ooool200001S?o
0003o`2I<ol0<ol001lco`000`000?ooooooo`2<oooo001Woooo00<0000co`0co`001C?o0003o`2I
<ol0<ol001hco`000`000?ooooooo`2=oooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
01dco`000`000?ooooooo`2>oooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol001`co`00
0`000?ooooooo`2?oooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol001/co`000`000?oo
ooooo`2@oooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol001/co`000`000?ooooooo`2@
oooo001Woooo0P0000Hco`000ol0VC?o03?o000J<ol000<0003oooooool0TOooo`00Ioooo`030000
<ol0<ol000Dco`000ol0VC?o03?o000I<ol000<0003oooooool0T_ooo`00Ioooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o000H<ol000<0003oooooool0Toooo`00Ioooo`030000<ol0<ol000Dco`00
0ol0VC?o03?o000H<ol000<0003oooooool0Toooo`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o
03?o000G<ol000<0003oooooool0U?ooo`00Goooo`D00003oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol001Lco`000`000?ooooooo`2Doooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o000F<ol000<0003oooooool0UOooo`00HOooo`030000oooooooo00?oool2
00001S?o0003o`2I<ol0<ol001Hco`000`000?ooooooo`2Eoooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o000E<ol000<0003oooooool0U_ooo`00HOooo`030000
oooooooo00?oool00`0003?o03?o0005<ol000?o09Tco`0co`005C?o00030000oooooooo09Koool0
063oool200001Oooo`030000<ol0<ol000Dco`000ol0VC?o03?o000D<ol000<0003oooooool0Uooo
o`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o03?o000D<ol000<0003oooooool0Uoooo`00Iooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o000C<ol000<0003oooooool0V?ooo`00Ioooo`800006
<ol000?o09Tco`0co`004c?o00030000oooooooo09Soool006Ooool00`0003?o03?o0005<ol000?o
09Tco`0co`004S?o00030000oooooooo09Woool006Ooool00`0003?o03?o0005<ol000?o09Tco`0c
o`004S?o00030000oooooooo09Woool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`004C?o
00030000oooooooo09[oool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`004C?o00030000
oooooooo09[oool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`0043?o00030000oooooooo
09_oool006Ooool200001S?o0003o`2I<ol0<ol0010co`000`000?ooooooo`2Koooo001Woooo00<0
000co`0co`001C?o0003o`2I<ol0<ol000lco`000`000?ooooooo`2Loooo001Woooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol000lco`000`000?ooooooo`2Loooo001Woooo00<0000co`0co`001C?o
0003o`2I<ol0<ol000hco`000`000?ooooooo`2Moooo001Woooo00<0000co`0co`001C?o0003o`2I
<ol0<ol000hco`000`000?ooooooo`2Moooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
00hco`000`000?ooooooo`2Moooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol000dco`00
0`000?ooooooo`2Noooo001Woooo0P0000Hco`000ol0VC?o03?o000=<ol000<0003oooooool0W_oo
o`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o03?o000=<ol000<0003oooooool0W_ooo`00Iooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o000=<ol000<0003oooooool0W_ooo`00Ioooo`030000
<ol0<ol000Dco`000ol0VC?o03?o000<<ol000<0003oooooool0Woooo`00Ioooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o000<<ol000<0003oooooool0Woooo`00Ioooo`030000<ol0<ol000Dco`00
0ol0VC?o03?o000<<ol000<0003oooooool0Woooo`00Ioooo`800006<ol000?o09Tco`0co`0033?o
00030000oooooooo09ooool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`002c?o00030000
oooooooo0:3oool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`002c?o00030000oooooooo
0:3oool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`002c?o00030000oooooooo0:3oool0
05ooool400001?ooo`030000<ol0<ol000Dco`000ol0VC?o03?o000;<ol000<0003oooooool0X?oo
o`00Goooo`030000oooooooo00Goool00`0003?o03?o0005<ol000?o09Tco`0co`002S?o00030000
oooooooo0:7oool0063oool00`000?ooooooo`04oooo0P0000Hco`000ol0VC?o03?o000:<ol000<0
003oooooool0XOooo`00HOooo`030000oooooooo00?oool00`0003?o03?o0005<ol000?o09Tco`0c
o`002S?o00030000oooooooo0:7oool005ooool010000?ooooooo`0000Coool00`0003?o03?o0005
<ol000?o09Tco`0co`002C?o00030000oooooooo0:;oool0063oool200001Oooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o0009<ol000<0003oooooool0X_ooo`00Ioooo`030000<ol0<ol000Dco`00
0ol0VC?o03?o0009<ol000<0003oooooool0X_ooo`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o
03?o0009<ol000<0003oooooool0X_ooo`00Ioooo`800006<ol000?o09Tco`0co`0023?o00030000
oooooooo0:?oool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`0023?o00030000oooooooo
0:?oool006Ooool00`0003?o03?o0005<ol000?o09Tco`0co`0023?o00030000oooooooo0:?oool0
06Ooool00`0003?o03?o0005<ol000?o09Tco`0co`0023?o00030000oooooooo0:?oool006Ooool0
0`0003?o03?o0005<ol000?o09Tco`0co`001c?o00030000oooooooo0:Coool006Ooool00`0003?o
03?o0005<ol000?o09Tco`0co`001c?o00030000oooooooo0:Coool006Ooool00`0003?o03?o0005
<ol000?o09Tco`0co`001c?o00030000oooooooo0:Coool006Ooool200001S?o0003o`2I<ol0<ol0
00Lco`000`000?ooooooo`2Toooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol000Hco`00
0`000?ooooooo`2Uoooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol000Hco`000`000?oo
ooooo`2Uoooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`2U
oooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`2Uoooo001W
oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Voooo001Woooo0P00
00Hco`000ol0VC?o03?o0005<ol000<0003oooooool0Y_ooo`00Ioooo`030000<ol0<ol000Dco`00
0ol0VC?o03?o0005<ol000<0003oooooool0Y_ooo`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o
03?o0005<ol000<0003oooooool0Y_ooo`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o03?o0004
<ol000<0003oooooool0Yoooo`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o03?o0004<ol000<0
003oooooool0Yoooo`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o03?o0004<ol000<0003ooooo
ool0Yoooo`00Ioooo`800006<ol000?o09Tco`0co`0013?o00030000oooooooo0:Ooool006Ooool0
0`0003?o03?o0005<ol000?o09Tco`0co`0013?o00030000oooooooo0:Ooool006Ooool00`0003?o
03?o0005<ol000?o09Tco`0co`0013?o00030000oooooooo0:Ooool006Ooool00`0003?o03?o0005
<ol000?o09Tco`0co`000c?o00030000oooooooo0:Soool0063oool200001Oooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o0003<ol000<0003oooooool0Z?ooo`00Goooo`040000oooooooo00001?oo
o`030000<ol0<ol000Dco`000ol0VC?o03?o0003<ol000<0003oooooool0Z?ooo`00HOooo`030000
oooooooo00?oool200001S?o0003o`2I<ol0<ol000<co`000`000?ooooooo`2Xoooo001Roooo00<0
003oooooool00_ooo`030000<ol0<ol000Dco`000ol0VC?o03?o0003<ol000<0003oooooool0Z?oo
o`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000Dco`000ol0VC?o03?o0003<ol000<0
003oooooool0Z?ooo`00H?ooo`800005oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0008co`00
0`000?ooooooo`2Yoooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol0008co`000`000?oo
ooooo`2Yoooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Y
oooo001Woooo00<0000co`0co`001C?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Yoooo001W
oooo0P0000Hco`000ol0VC?o03?o0002<ol000<0003oooooool0ZOooo`00Ioooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o0002<ol000<0003oooooool0ZOooo`00Ioooo`030000<ol0<ol000Dco`00
1Ol0VC?o03?o03?o0000002/oooo001Woooo00<0000co`0co`001C?o0005o`2I<ol0<ol0<ol00000
0:coool006Ooool00`0003?o03?o0005<ol000Go09Tco`0co`0co`000000[?ooo`00Ioooo`030000
<ol0<ol000Dco`001Ol0VC?o03?o03?o0000002/oooo001Woooo0P0000Hco`001Ol0VC?o03?o03?o
0000002/oooo001Woooo00<0000co`0co`001C?o0005o`2I<ol0<ol0<ol000000:coool006Ooool0
0`0003?o03?o0005<ol000Go09Tco`0co`0co`000000[?ooo`00Ioooo`030000<ol0<ol000Dco`00
1?l0VC?o03?o00000:goool006Ooool00`0003?o03?o0005<ol000Co09Tco`0co`00002]oooo001W
oooo00<0000co`0co`001C?o0004o`2I<ol0<ol00000[Oooo`00Ioooo`800006<ol000Co09Tco`0c
o`00002]oooo001Woooo00<0000co`0co`001C?o0004o`2I<ol0<ol00000[Oooo`00Ioooo`030000
<ol0<ol000Dco`001?l0VC?o03?o00000:goool006Ooool00`0003?o03?o0005<ol000?o09Tco`00
0000[_ooo`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o0000002^oooo001Woooo00<0000co`0c
o`001C?o0003o`2I<ol000000:koool006Ooool200001S?o0003o`2I<ol000000:koool006Ooool0
0`0003?o03?o0005<ol000?o09Tco`000000[_ooo`00Ioooo`030000<ol0<ol000Dco`000ol0VC?o
0000002^oooo001Woooo00<0000co`0co`001C?o0003o`2I<ol000000:koool006Ooool00`0003?o
03?o0005<ol000?o09Tco`000000[_ooo`00HOooo`<00003oooo00<0000co`0co`001C?o0003o`2I
<ol000000:koool006;oool00`000?ooooooo`02oooo00<0000co`0co`001C?o0003o`2I<ol00000
0:koool005ooool500000oooo`800006<ol000?o09Tco`000000[_ooo`00Goooo`040000oooooooo
00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:
<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol03?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001Woooo2C?o00_oool00`000?ooooooo`08oooo00<0003ooooo
ool06Oooo`030000oooooooo07_oool006Ooool9<ol02oooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Ooool200001?ooo`800003oooo1@0000;oool00`000?ooooooo`1koooo001W
oooo2C?o00_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Iooo
o`Tco`0:oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000[oool0
0`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Ioooo`Tco`0;oooo00<0003oooooool01@00
00coool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Iooo
o`Tco`0;oooo00D0003oooooooooool000003oooo`040000oooooooo00002_ooo`030000oooooooo
00;oool00`000?ooooooo`1koooo001Woooo2C?o00coool00`000?ooooooo`0Aoooo0P0000[oool2
00000oooo`030000oooooooo07coool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.37114 .12361 L
.37372 .12361 L
.37649 .12361 L
.37783 .12361 L
.3791 .12361 L
s
.3791 .12361 m
.37956 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30059 .12361 L
.30182 .12361 L
.30246 .12361 L
.30316 .12361 L
.30442 .12264 L
.3056 .12174 L
.30791 .12 L
.31304 .11628 L
.32392 .10896 L
.34309 .09785 L
.35337 .0926 L
.3645 .08728 L
.3696 .08496 L
.3724 .08373 L
.375 .08259 L
.37723 .08164 L
.37847 .08111 L
.37961 .12361 L
.38085 .12361 L
.38221 .12361 L
.38467 .12361 L
.42545 .12361 L
.46472 .12361 L
.50247 .12361 L
.54267 .12361 L
.58136 .12361 L
.6225 .12361 L
.66212 .12361 L
.70023 .12361 L
.74079 .12361 L
.77984 .12361 L
.82133 .12361 L
.86132 .12361 L
.89978 .12361 L
.9407 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool20000]oooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007oooo`D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool01Oooo`80I_lFoooo00@0
003oooooool00008oooo00@0003oooooool0000Poooo00<0003oooooool07oooo`030000oooooooo
00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00002oooo`030000oooooooo01coool00`000?ooooooo`03oooo0P1Vo`03oooo
06Kooooo01Goool010000?ooooooo`0000_oool00`000?ooooooo`0Noooo00<0003oooooool07ooo
o`030000oooooooo00[oool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004
oooo00<0003oooooool05oooo`@00002oooo00@0003oooooool00009oooo0P0001ooool010000?oo
ooooooooo`80I_l3oooo00<0I_ooooooool05?ooo`040000oooooooo00002Oooo`80000Qoooo00<0
003oooooool07oooo`030000oooooooo00Soool200008_ooo`030000oooooooo01Goool001Woool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool07_ooo`040000oooo06Ko
06Ko1Oooo`0306Kooooooooo01Coool010000?ooooooo`0000Woool00`000?ooooooo`0Poooo00<0
003oooooool07oooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000F
oooo000Hoooo0P00023oool200002_ooo`<0000Noooo0P0000Ooool00`1Vooooooooo`0Eoooo0P00
00[oool300007oooo`80000Poooo0P0000[oool300008?ooo`80000Goooo001Uoooo0P1Vo`030000
oooooooo00Koool00`1Vooooooooo`2]oooo001Soooo0P1Vo`;oool00`000?ooooooo`06oooo00<0
I_ooooooool0[Oooo`00H_ooo`0306Kooooooooo00;oool00`000?ooooooo`06oooo00<0I_oooooo
ool0[Oooo`00HOooo`0306Kooooooooo00?oool00`000?ooooooo`06oooo00<0I_ooooooool0[Ooo
o`00G_ooo`<0I_l6oooo00<0003oooooool01_ooo`0306Kooooooooo0:goool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005
<ol000<0003o09Tco`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X
00000_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol0
00Hco`000ol0VC?o03?o000L<ol000<0000co`0co`0093?o0100000Ioooo00<0003oooooool09_oo
o`030000oooooooo01Goool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`00?S?o00D0001Z
oooo001Woooo00<0000co`0co`001S?o0003o`2I<ol0<ol003Tco`050000Koooo`00Ioooo`030000
<ol0<ol000Hco`000ol0VC?o03?o000d<ol01@0007Coool006Ooool00`0003?o03?o0006<ol000?o
09Tco`0co`00<3?o00@0001ioooo001Woooo0P0000Lco`000ol0VC?o03?o000^<ol00P0007goool0
06Ooool00`0003?o03?o0006<ol000?o09Tco`0co`00;3?o0080001ooooo001Woooo00<0000co`0c
o`001S?o0003o`2I<ol0<ol002Xco`020000POooo`00Ioooo`030000<ol0<ol000Hco`000ol0VC?o
03?o000X<ol00P0008?oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`009c?o00030000
oooooooo08?oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`009C?o00800026oooo001W
oooo0P0000Lco`000ol0VC?o03?o000S<ol00P0008Soool006Ooool00`0003?o03?o0006<ol000?o
09Tco`0co`008S?o00030000oooooooo08Soool006Ooool00`0003?o03?o0006<ol000?o09Tco`0c
o`008C?o00030000oooooooo08Woool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`0083?o
00030000oooooooo08[oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`007c?o00030000
oooooooo08_oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`007c?o00030000oooooooo
08_oool006Ooool200001c?o0003o`2I<ol0<ol001hco`000`000?ooooooo`2<oooo001Woooo00<0
000co`0co`001S?o0003o`2I<ol0<ol001dco`000`000?ooooooo`2=oooo001Woooo00<0000co`0c
o`001S?o0003o`2I<ol0<ol001`co`000`000?ooooooo`2>oooo001Woooo00<0000co`0co`001S?o
0003o`2I<ol0<ol001/co`000`000?ooooooo`2?oooo001Woooo00<0000co`0co`001S?o0003o`2I
<ol0<ol001Xco`000`000?ooooooo`2@oooo001Woooo00<0000co`0co`001S?o0003o`2I<ol0<ol0
01Xco`000`000?ooooooo`2@oooo001Woooo0P0000Lco`000ol0VC?o03?o000I<ol000<0003ooooo
ool0TOooo`00Ioooo`030000<ol0<ol000Hco`000ol0VC?o03?o000H<ol000<0003oooooool0T_oo
o`00Ioooo`030000<ol0<ol000Hco`000ol0VC?o03?o000G<ol000<0003oooooool0Toooo`00Iooo
o`030000<ol0<ol000Hco`000ol0VC?o03?o000G<ol000<0003oooooool0Toooo`00Ioooo`030000
<ol0<ol000Hco`000ol0VC?o03?o000F<ol000<0003oooooool0U?ooo`00Goooo`D00003oooo00<0
000co`0co`001S?o0003o`2I<ol0<ol001Hco`000`000?ooooooo`2Doooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol000Hco`000ol0VC?o03?o000E<ol000<0003oooooool0UOooo`00HOoo
o`030000oooooooo00?oool200001c?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`2Eoooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol000Hco`000ol0VC?o03?o000D<ol000<0003ooooo
ool0U_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o0006<ol000?o09Tco`0co`0053?o
00030000oooooooo09Koool0063oool200001Oooo`030000<ol0<ol000Hco`000ol0VC?o03?o000C
<ol000<0003oooooool0Uoooo`00Ioooo`030000<ol0<ol000Hco`000ol0VC?o03?o000C<ol000<0
003oooooool0Uoooo`00Ioooo`030000<ol0<ol000Hco`000ol0VC?o03?o000B<ol000<0003ooooo
ool0V?ooo`00Ioooo`800007<ol000?o09Tco`0co`004S?o00030000oooooooo09Soool006Ooool0
0`0003?o03?o0006<ol000?o09Tco`0co`004C?o00030000oooooooo09Woool006Ooool00`0003?o
03?o0006<ol000?o09Tco`0co`004C?o00030000oooooooo09Woool006Ooool00`0003?o03?o0006
<ol000?o09Tco`0co`0043?o00030000oooooooo09[oool006Ooool00`0003?o03?o0006<ol000?o
09Tco`0co`0043?o00030000oooooooo09[oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0c
o`003c?o00030000oooooooo09_oool006Ooool200001c?o0003o`2I<ol0<ol000lco`000`000?oo
ooooo`2Koooo001Woooo00<0000co`0co`001S?o0003o`2I<ol0<ol000hco`000`000?ooooooo`2L
oooo001Woooo00<0000co`0co`001S?o0003o`2I<ol0<ol000hco`000`000?ooooooo`2Loooo001W
oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000dco`000`000?ooooooo`2Moooo001Woooo00<0
000co`0co`001S?o0003o`2I<ol0<ol000dco`000`000?ooooooo`2Moooo001Woooo00<0000co`0c
o`001S?o0003o`2I<ol0<ol000dco`000`000?ooooooo`2Moooo001Woooo00<0000co`0co`001S?o
0003o`2I<ol0<ol000`co`000`000?ooooooo`2Noooo001Woooo0P0000Lco`000ol0VC?o03?o000<
<ol000<0003oooooool0W_ooo`00Ioooo`030000<ol0<ol000Hco`000ol0VC?o03?o000<<ol000<0
003oooooool0W_ooo`00Ioooo`030000<ol0<ol000Hco`000ol0VC?o03?o000<<ol000<0003ooooo
ool0W_ooo`00Ioooo`030000<ol0<ol000Hco`000ol0VC?o03?o000;<ol000<0003oooooool0Wooo
o`00Ioooo`030000<ol0<ol000Hco`000ol0VC?o03?o000;<ol000<0003oooooool0Woooo`00Iooo
o`030000<ol0<ol000Hco`000ol0VC?o03?o000;<ol000<0003oooooool0Woooo`00Ioooo`800007
<ol000?o09Tco`0co`002c?o00030000oooooooo09ooool006Ooool00`0003?o03?o0006<ol000?o
09Tco`0co`002S?o00030000oooooooo0:3oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0c
o`002S?o00030000oooooooo0:3oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`002S?o
00030000oooooooo0:3oool005ooool400001?ooo`030000<ol0<ol000Hco`000ol0VC?o03?o000:
<ol000<0003oooooool0X?ooo`00Goooo`030000oooooooo00Goool00`0003?o03?o0006<ol000?o
09Tco`0co`002C?o00030000oooooooo0:7oool0063oool00`000?ooooooo`04oooo0P0000Lco`00
0ol0VC?o03?o0009<ol000<0003oooooool0XOooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o0006<ol000?o09Tco`0co`002C?o00030000oooooooo0:7oool005ooool010000?ooooooo`00
00Coool00`0003?o03?o0006<ol000?o09Tco`0co`0023?o00030000oooooooo0:;oool0063oool2
00001Oooo`030000<ol0<ol000Hco`000ol0VC?o03?o0008<ol000<0003oooooool0X_ooo`00Iooo
o`030000<ol0<ol000Hco`000ol0VC?o03?o0008<ol000<0003oooooool0X_ooo`00Ioooo`030000
<ol0<ol000Hco`000ol0VC?o03?o0008<ol000<0003oooooool0X_ooo`00Ioooo`800007<ol000?o
09Tco`0co`001c?o00030000oooooooo0:?oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0c
o`001c?o00030000oooooooo0:?oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`001c?o
00030000oooooooo0:?oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`001c?o00030000
oooooooo0:?oool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`001S?o00030000oooooooo
0:Coool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`001S?o00030000oooooooo0:Coool0
06Ooool00`0003?o03?o0006<ol000?o09Tco`0co`001S?o00030000oooooooo0:Coool006Ooool2
00001c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`2Toooo001Woooo00<0000co`0co`001S?o
0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Uoooo001Woooo00<0000co`0co`001S?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`2Uoooo001Woooo00<0000co`0co`001S?o0003o`2I<ol0<ol0
00Dco`000`000?ooooooo`2Uoooo001Woooo00<0000co`0co`001S?o0003o`2I<ol0<ol000Dco`00
0`000?ooooooo`2Uoooo001Woooo00<0000co`0co`001S?o0003o`2I<ol0<ol000@co`000`000?oo
ooooo`2Voooo001Woooo0P0000Lco`000ol0VC?o03?o0004<ol000<0003oooooool0Y_ooo`00Iooo
o`030000<ol0<ol000Hco`000ol0VC?o03?o0004<ol000<0003oooooool0Y_ooo`00Ioooo`030000
<ol0<ol000Hco`000ol0VC?o03?o0004<ol000<0003oooooool0Y_ooo`00Ioooo`030000<ol0<ol0
00Hco`000ol0VC?o03?o0003<ol000<0003oooooool0Yoooo`00Ioooo`030000<ol0<ol000Hco`00
0ol0VC?o03?o0003<ol000<0003oooooool0Yoooo`00Ioooo`030000<ol0<ol000Hco`000ol0VC?o
03?o0003<ol000<0003oooooool0Yoooo`00Ioooo`800007<ol000?o09Tco`0co`000c?o00030000
oooooooo0:Ooool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`000c?o00030000oooooooo
0:Ooool006Ooool00`0003?o03?o0006<ol000?o09Tco`0co`000c?o00030000oooooooo0:Ooool0
06Ooool00`0003?o03?o0006<ol000?o09Tco`0co`000S?o00030000oooooooo0:Soool0063oool2
00001Oooo`030000<ol0<ol000Hco`000ol0VC?o03?o0002<ol000<0003oooooool0Z?ooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000Hco`000ol0VC?o03?o0002<ol000<0003ooooo
ool0Z?ooo`00HOooo`030000oooooooo00?oool200001c?o0003o`2I<ol0<ol0008co`000`000?oo
ooooo`2Xoooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Hco`000ol0VC?o03?o0002
<ol000<0003oooooool0Z?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000Hco`00
0ol0VC?o03?o0002<ol000<0003oooooool0Z?ooo`00H?ooo`800005oooo00<0000co`0co`001S?o
0005o`2I<ol0<ol0<ol000000:_oool006Ooool00`0003?o03?o0006<ol000Go09Tco`0co`0co`00
0000Zoooo`00Ioooo`030000<ol0<ol000Hco`001Ol0VC?o03?o03?o0000002[oooo001Woooo00<0
000co`0co`001S?o0005o`2I<ol0<ol0<ol000000:_oool006Ooool200001c?o0005o`2I<ol0<ol0
<ol000000:_oool006Ooool00`0003?o03?o0006<ol000Go09Tco`0co`0co`000000Zoooo`00Iooo
o`030000<ol0<ol000Hco`001?l0VC?o03?o00000:coool006Ooool00`0003?o03?o0006<ol000Co
09Tco`0co`00002/oooo001Woooo00<0000co`0co`001S?o0004o`2I<ol0<ol00000[?ooo`00Iooo
o`030000<ol0<ol000Hco`001?l0VC?o03?o00000:coool006Ooool200001c?o0004o`2I<ol0<ol0
0000[?ooo`00Ioooo`030000<ol0<ol000Hco`001?l0VC?o03?o00000:coool006Ooool00`0003?o
03?o0006<ol000Co09Tco`0co`00002/oooo001Woooo00<0000co`0co`001S?o0003o`2I<ol00000
0:goool006Ooool00`0003?o03?o0006<ol000?o09Tco`000000[Oooo`00Ioooo`030000<ol0<ol0
00Hco`000ol0VC?o0000002]oooo001Woooo0P0000Lco`000ol0VC?o0000002]oooo001Woooo00<0
000co`0co`001S?o0003o`2I<ol000000:goool006Ooool00`0003?o03?o0006<ol000?o09Tco`00
0000[Oooo`00Ioooo`030000<ol0<ol000Hco`000ol0V@000?ooo`2]oooo001Woooo00<0000co`0c
o`001S?o0003o`2I0000oooo0:goool006Ooool00`0003?o03?o0006<ol000?o09T0003oool0[Ooo
o`00Ioooo`800007<ol000?o09T0003oool0[Oooo`00Ioooo`030000<ol0<ol000Hco`000ol0V@00
0?ooo`2]oooo001Woooo00<0000co`0co`001S?o0003o`2I0000oooo0:goool006Ooool00`0003?o
03?o0006<ol000?o09T0003oool0[Oooo`00Ioooo`030000<ol0<ol000Hco`000ol0V@000?ooo`2]
oooo001Qoooo0`0000?oool00`0003?o03?o0006<ol000?o09T0003oool0[Oooo`00H_ooo`030000
oooooooo00;oool00`0003?o03?o0006<ol000?o09T0003oool0[Oooo`00Goooo`D00003oooo0P00
00Lco`000ol0V@000?ooo`2]oooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool0
0`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool0
06Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
06Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004
oooo0P0000?oool5000000?oool0000000000P0000?oool00`000?ooooooo`1hoooo001Woooo2C?o
00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000[oool01@000?ooooooooooo`000006oooo00<0003oooooool0N?ooo`00Iooo
o`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`030000oooooooo07Ooool006Ooool9<ol02?oo
o`030000oooooooo00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`050000oooooooooooo0000
07[oool006Ooool9<ol02Oooo`030000oooooooo017oool200002_ooo`800004oooo0P0000?oool0
0`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.37685 .12361 L
.3815 .12361 L
.38384 .12361 L
.38448 .12361 L
.38517 .12361 L
s
.38517 .12361 m
.38566 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.28302 .12361 L
.2881 .12361 L
.29088 .12361 L
.29349 .12361 L
.29462 .12361 L
.2957 .12361 L
.29695 .12351 L
.29809 .12263 L
.30316 .11882 L
.34135 .09549 L
.36267 .08548 L
.37273 .08116 L
.37715 .07934 L
.37965 .07833 L
.38199 .0774 L
.38427 .07651 L
.38554 .07602 L
.3867 .12361 L
.38792 .12361 L
.38925 .12361 L
.39167 .12361 L
.40214 .12361 L
.42112 .12361 L
.46191 .12361 L
.50117 .12361 L
.53892 .12361 L
.57913 .12361 L
.61781 .12361 L
.65895 .12361 L
.69858 .12361 L
.73669 .12361 L
.77725 .12361 L
.81629 .12361 L
.85779 .12361 L
.89777 .12361 L
.93624 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo0;Koool006Ooool200002Oooo`0306Kooooooooo0:_oool001Ooool5
00007_ooo`800004oooo0P0000Coool200007oooo`030000oooooooo00Koool306Ko5Oooo`800004
oooo0P0000Coool200007oooo`D0000Moooo1@0000;oool200001?ooo`80000Poooo100001Koool0
01Woool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000Noooo00<0
003oooooool01?ooo`80I_l2oooo00<0I_ooooooool04_ooo`040000oooooooo00002?ooo`040000
oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0003oooooool0000O
oooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000_oool0
0`000?ooooooo`0Loooo00@0003oooooooooool306Ko1?ooo`0306Kooooooooo01;oool010000?oo
ooooo`0000_oool00`000?ooooooo`0Noooo00<0003oooooool07oooo`030000oooooooo00[oool0
0`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool05ooo
o`@00002oooo00@0003oooooool00009oooo0P0001ooool010000?ooo`1Vo`1Vo`Ooool00`1Voooo
ooooo`0Boooo00@0003oooooool00009oooo0P00027oool00`000?ooooooo`0Ooooo00<0003ooooo
ool02?ooo`80000Roooo00<0003oooooool05Oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000Woool00`000?ooooooo`0Noooo00<00000I_ooool02?ooo`0306Kooooooooo01;oool0
10000?ooooooo`0000Woool00`000?ooooooo`0Poooo00<0003oooooool07oooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00023oool200002_oo
o`<0000Loooo0P1Vo`800009oooo00<0I_ooooooool04oooo`80000:oooo0`0001ooool200008?oo
o`80000:oooo0`00023oool200005oooo`00Hoooo`80I_l2oooo00<0003oooooool02?ooo`0306Ko
oooooooo0:_oool006;oool00`1Vooooooooo`02oooo00<0003oooooool02?ooo`0306Kooooooooo
0:_oool0063oool206Ko1Oooo`030000oooooooo00Soool00`1Vooooooooo`2[oooo001Noooo0P1V
o`Ooool00`000?ooooooo`08oooo00<0I_ooooooool0Zoooo`00GOooo`0306Kooooooooo00Ooool0
0`000?ooooooo`08oooo00<0I_ooooooool0Zoooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`00100003?o03?o0?l0
V@@co`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o0008<ol000?o09Tco`0c
o`006S?o00030000<ol0<ol002@co`0@00006Oooo`030000oooooooo02Koool00`000?ooooooo`0E
oooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol003`co`050000J_ooo`00Ioooo`030000
<ol0<ol000Pco`000ol0VC?o03?o000g<ol01@0006ooool006Ooool00`0003?o03?o0008<ol000?o
09Tco`0co`00<S?o00D0001doooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol002hco`04
0000NOooo`00Ioooo`800009<ol000?o09Tco`0co`00;3?o0080001moooo001Woooo00<0000co`0c
o`0023?o0003o`2I<ol0<ol002Xco`020000Ooooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o
03?o000X<ol00P00087oool006Ooool00`0003?o03?o0008<ol000?o09Tco`0co`009S?o00800023
oooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol002Dco`000`000?ooooooo`23oooo001W
oooo00<0000co`0co`0023?o0003o`2I<ol0<ol002<co`020000Q_ooo`00Ioooo`800009<ol000?o
09Tco`0co`008C?o00800028oooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol0020co`00
0`000?ooooooo`28oooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol001lco`000`000?oo
ooooo`29oooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol001hco`000`000?ooooooo`2:
oooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol001dco`000`000?ooooooo`2;oooo001W
oooo00<0000co`0co`0023?o0003o`2I<ol0<ol001dco`000`000?ooooooo`2;oooo001Woooo0P00
00Tco`000ol0VC?o03?o000L<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol000Pco`00
0ol0VC?o03?o000K<ol000<0003oooooool0SOooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o
03?o000J<ol000<0003oooooool0S_ooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o03?o000I
<ol000<0003oooooool0Soooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o03?o000H<ol000<0
003oooooool0T?ooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o03?o000H<ol000<0003ooooo
ool0T?ooo`00Ioooo`800009<ol000?o09Tco`0co`005c?o00030000oooooooo097oool006Ooool0
0`0003?o03?o0008<ol000?o09Tco`0co`005S?o00030000oooooooo09;oool006Ooool00`0003?o
03?o0008<ol000?o09Tco`0co`005C?o00030000oooooooo09?oool006Ooool00`0003?o03?o0008
<ol000?o09Tco`0co`005C?o00030000oooooooo09?oool006Ooool00`0003?o03?o0008<ol000?o
09Tco`0co`0053?o00030000oooooooo09Coool005ooool500000oooo`030000<ol0<ol000Pco`00
0ol0VC?o03?o000D<ol000<0003oooooool0U?ooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o0008<ol000?o09Tco`0co`004c?o00030000oooooooo09Goool0067oool00`000?ooooooo`03
oooo0P0000Tco`000ol0VC?o03?o000C<ol000<0003oooooool0UOooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o0008<ol000?o09Tco`0co`004S?o00030000oooooooo09Koool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`0023?o0003o`2I<ol0<ol0018co`000`000?ooooooo`2F
oooo001Poooo0P0000Goool00`0003?o03?o0008<ol000?o09Tco`0co`004C?o00030000oooooooo
09Ooool006Ooool00`0003?o03?o0008<ol000?o09Tco`0co`004C?o00030000oooooooo09Ooool0
06Ooool00`0003?o03?o0008<ol000?o09Tco`0co`0043?o00030000oooooooo09Soool006Ooool2
00002C?o0003o`2I<ol0<ol0010co`000`000?ooooooo`2Hoooo001Woooo00<0000co`0co`0023?o
0003o`2I<ol0<ol000lco`000`000?ooooooo`2Ioooo001Woooo00<0000co`0co`0023?o0003o`2I
<ol0<ol000lco`000`000?ooooooo`2Ioooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol0
00hco`000`000?ooooooo`2Joooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol000hco`00
0`000?ooooooo`2Joooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol000dco`000`000?oo
ooooo`2Koooo001Woooo0P0000Tco`000ol0VC?o03?o000=<ol000<0003oooooool0Voooo`00Iooo
o`030000<ol0<ol000Pco`000ol0VC?o03?o000<<ol000<0003oooooool0W?ooo`00Ioooo`030000
<ol0<ol000Pco`000ol0VC?o03?o000<<ol000<0003oooooool0W?ooo`00Ioooo`030000<ol0<ol0
00Pco`000ol0VC?o03?o000;<ol000<0003oooooool0WOooo`00Ioooo`030000<ol0<ol000Pco`00
0ol0VC?o03?o000;<ol000<0003oooooool0WOooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o
03?o000;<ol000<0003oooooool0WOooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o03?o000:
<ol000<0003oooooool0W_ooo`00Ioooo`800009<ol000?o09Tco`0co`002S?o00030000oooooooo
09koool006Ooool00`0003?o03?o0008<ol000?o09Tco`0co`002S?o00030000oooooooo09koool0
06Ooool00`0003?o03?o0008<ol000?o09Tco`0co`002S?o00030000oooooooo09koool006Ooool0
0`0003?o03?o0008<ol000?o09Tco`0co`002C?o00030000oooooooo09ooool006Ooool00`0003?o
03?o0008<ol000?o09Tco`0co`002C?o00030000oooooooo09ooool006Ooool00`0003?o03?o0008
<ol000?o09Tco`0co`002C?o00030000oooooooo09ooool006Ooool200002C?o0003o`2I<ol0<ol0
00Tco`000`000?ooooooo`2Ooooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Pco`00
0`000?ooooooo`2Poooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Pco`000`000?oo
ooooo`2Poooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`2P
oooo001Ooooo100000Coool00`0003?o03?o0008<ol000?o09Tco`0co`0023?o00030000oooooooo
0:3oool005ooool00`000?ooooooo`05oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Lco`00
0`000?ooooooo`2Qoooo001Poooo00<0003oooooool01?ooo`800009<ol000?o09Tco`0co`001c?o
00030000oooooooo0:7oool0067oool00`000?ooooooo`03oooo00<0000co`0co`0023?o0003o`2I
<ol0<ol000Lco`000`000?ooooooo`2Qoooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`0023?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`2Roooo001Poooo0P0000Goool00`0003?o
03?o0008<ol000?o09Tco`0co`001S?o00030000oooooooo0:;oool006Ooool00`0003?o03?o0008
<ol000?o09Tco`0co`001S?o00030000oooooooo0:;oool006Ooool00`0003?o03?o0008<ol000?o
09Tco`0co`001S?o00030000oooooooo0:;oool006Ooool200002C?o0003o`2I<ol0<ol000Dco`00
0`000?ooooooo`2Soooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Dco`000`000?oo
ooooo`2Soooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2S
oooo001Woooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Soooo001W
oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Toooo001Woooo00<0
000co`0co`0023?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Toooo001Woooo00<0000co`0c
o`0023?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Toooo001Woooo0P0000Tco`000ol0VC?o
03?o0004<ol000<0003oooooool0Y?ooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o03?o0003
<ol000<0003oooooool0YOooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o03?o0003<ol000<0
003oooooool0YOooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o03?o0003<ol000<0003ooooo
ool0YOooo`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o03?o0003<ol000<0003oooooool0YOoo
o`00Ioooo`030000<ol0<ol000Pco`000ol0VC?o03?o0002<ol000<0003oooooool0Y_ooo`00Iooo
o`800009<ol000?o09Tco`0co`000S?o00030000oooooooo0:Koool006Ooool00`0003?o03?o0008
<ol000?o09Tco`0co`000S?o00030000oooooooo0:Koool006Ooool00`0003?o03?o0008<ol000?o
09Tco`0co`000S?o00030000oooooooo0:Koool006Ooool00`0003?o03?o0008<ol000Go09Tco`0c
o`0co`000000ZOooo`00Ioooo`030000<ol0<ol000Pco`001Ol0VC?o03?o03?o0000002Yoooo001W
oooo00<0000co`0co`0023?o0005o`2I<ol0<ol0<ol000000:Woool006Ooool200002C?o0005o`2I
<ol0<ol0<ol000000:Woool006Ooool00`0003?o03?o0008<ol000Go09Tco`0co`0co`000000ZOoo
o`00Ioooo`030000<ol0<ol000Pco`001Ol0VC?o03?o03?o0000002Yoooo001Woooo00<0000co`0c
o`0023?o0004o`2I<ol0<ol00000Z_ooo`00H?ooo`800005oooo00<0000co`0co`0023?o0004o`2I
<ol0<ol00000Z_ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`001?l0VC?o
03?o00000:[oool0067oool00`000?ooooooo`03oooo0P0000Tco`001?l0VC?o03?o00000:[oool0
06;oool00`000?ooooooo`02oooo00<0000co`0co`0023?o0004o`2I<ol0<ol00000Z_ooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000Pco`001?l0VC?o03?o00000:[oool0063oool2
00001Oooo`030000<ol0<ol000Pco`000ol0VC?o0000002[oooo001Woooo00<0000co`0co`0023?o
0003o`2I<ol000000:_oool006Ooool00`0003?o03?o0008<ol000?o09Tco`000000Zoooo`00Iooo
o`030000<ol0<ol000Pco`000ol0VC?o0000002[oooo001Woooo0P0000Tco`000ol0VC?o0000002[
oooo001Woooo00<0000co`0co`0023?o0003o`2I<ol000000:_oool006Ooool00`0003?o03?o0008
<ol000?o09T0003oool0Zoooo`00Ioooo`030000<ol0<ol000Pco`000ol0V@000?ooo`2[oooo001W
oooo00<0000co`0co`0023?o0003o`2I0000oooo0:_oool006Ooool00`0003?o03?o0008<ol000?o
09T0003oool0Zoooo`00Ioooo`800009<ol000?o09T0003oool0Zoooo`00Ioooo`030000<ol0<ol0
00Pco`000ol0V@000?ooo`2[oooo001Woooo00<0000co`0co`0023?o0003o`2I0000oooo0:_oool0
06Ooool00`0003?o03?o0008<ol000?o09Woooooool0Zoooo`00Ioooo`030000<ol0<ol000Pco`00
0ol0VOooooooo`2[oooo001Woooo00<0000co`0co`0023?o0003o`2Ioooooooo0:_oool006Ooool2
00002C?o0003o`2Ioooooooo0:_oool006Ooool00`0003?o03?o0008<ol000?o09Woooooool0Zooo
o`00Ioooo`030000<ol0<ol000Pco`000ol0VOooooooo`2[oooo001Woooo00<0000co`0co`001c?o
00030000o`2Ioooo0:coool006Ooool00`0003?o03?o0007<ol000<0003o09Woool0[?ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?l0VOooo`2/oooo001Woooo0P0000Pco`000`000?l0VOooo`2/
oooo001Woooo00<0000co`0co`001c?o00030000o`2Ioooo0:coool006Ooool00`0003?o03?o0007
<ol000<0003o09Woool0[?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?l0VOooo`2/oooo001W
oooo00<0000co`0co`001c?o00030000o`2Ioooo0:coool0067oool300000oooo`030000<ol0<ol0
00Lco`000`000?l0VOooo`2/oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`00
0`000?l0VOooo`2/oooo001Ooooo1@0000?oool2000023?o00030000o`2Ioooo0:coool005ooool0
10000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOoo
o`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`D00003oooo0`0000;oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00D0
003oooooooooool00000N_ooo`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000[oool010000?ooooooooooo`D00003oooo00<0003oooooool0Mooo
o`00Ioooo`Tco`08oooo00<0003oooooool01@0000coool010000?ooooooo`0000[oool01@000?oo
ooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00Ioooo`Tco`08oooo00D0003ooooo
ooooool000003oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooo`000003
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:oooo0P00
00Goool200000_ooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.3815 .12361 L
.3864 .12361 L
.38881 .12361 L
.38999 .12361 L
.39106 .12361 L
s
.39106 .12361 m
.39155 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28302 .12361 L
.28542 .12361 L
.288 .12361 L
.28876 .12361 L
.28948 .12361 L
.29013 .12361 L
.29083 .12333 L
.2915 .12281 L
.29221 .12227 L
.29349 .1213 L
.30316 .11431 L
.34474 .09085 L
.3656 .08179 L
.37476 .07812 L
.37961 .07624 L
.3848 .07428 L
.38741 .07332 L
.38869 .07286 L
.38988 .07243 L
.39095 .07204 L
.39209 .12361 L
.39323 .12361 L
.3945 .12361 L
.40355 .12361 L
.42335 .12361 L
.46356 .12361 L
.50225 .12361 L
.54339 .12361 L
.58301 .12361 L
.62112 .12361 L
.66168 .12361 L
.70072 .12361 L
.74222 .12361 L
.7822 .12361 L
.82067 .12361 L
.86159 .12361 L
.90099 .12361 L
.93888 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool0]_oo
o`00Ioooo`030000oooooooo00Woool00`1Vooooooooo`2Zoooo001Woooo0P0000Ooool406Ko[?oo
o`005oooo`D0000Noooo0P0000Coool200001?ooo`80000Ooooo00<0003oooooool01Oooo`0506Ko
oooooooooooo06Ko01Coool200001?ooo`800004oooo0P0001ooool500007Oooo`D00002oooo0P00
00Coool200008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002?oo
o`040000oooooooo00007_ooo`030000oooooooo00;oool306Ko1?ooo`0306Kooooooooo017oool0
10000?ooooooo`0000Soool010000?ooooooo`00023oool00`000?ooooooo`0Ooooo00<0003ooooo
ool01oooo`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0M
oooo00@0003oooooool0000;oooo00<0003oooooool07?ooo`030000oooooooo0080I_l7oooo00<0
I_ooooooool04Oooo`040000oooooooo00002oooo`030000oooooooo01koool00`000?ooooooo`0O
oooo00<0003oooooool02_ooo`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo1000
00Coool00`000?ooooooo`0Goooo100000;oool010000?ooooooo`0000Woool200007oooo`030000
06Ko06Ko00Woool00`1Vooooooooo`0Aoooo00@0003oooooool00009oooo0P00027oool00`000?oo
ooooo`0Ooooo00<0003oooooool02?ooo`80000Roooo00<0003oooooool05Oooo`006Oooo`030000
oooooooo01goool010000?ooooooo`0000Woool00`000?ooooooo`0Moooo00<0I_l0003oool02_oo
o`0306Kooooooooo017oool010000?ooooooo`0000Woool00`000?ooooooo`0Poooo00<0003ooooo
ool07oooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000H
oooo0P00023oool200002_ooo`<0000Koooo0P1Vo`03oooo0000000000_oool00`1Vooooooooo`0A
oooo0P0000[oool300007oooo`80000Poooo0P0000[oool300008?ooo`80000Goooo001Roooo0P1V
o`?oool00`000?ooooooo`0:oooo00<0I_ooooooool0ZOooo`00H?ooo`80I_l5oooo00<0003ooooo
ool02_ooo`0306Kooooooooo0:Woool005koool206Ko1oooo`030000oooooooo00[oool00`1Voooo
ooooo`2Yoooo001Moooo00<0I_ooooooool01oooo`030000oooooooo00[oool00`1Vooooooooo`2Y
oooo001Loooo00<0I_ooooooool02?ooo`030000oooooooo00[oool00`1Vooooooooo`2Yoooo000@
ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
000co`0co`001C?o00050000<ol0<ol0<ol0o`2I00<co`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo
02Koool00`0003?o03?o0009<ol000?o09Tco`0co`006C?o00030000<ol0<ol002@co`0@00006Ooo
o`030000oooooooo02Koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`002C?o0003o`2I
<ol0<ol003/co`050000J_ooo`00Ioooo`030000<ol0<ol000Tco`000ol0VC?o03?o000f<ol01@00
06ooool006Ooool00`0003?o03?o0009<ol000?o09Tco`0co`00<C?o00D0001doooo001Woooo00<0
000co`0co`002C?o0003o`2I<ol0<ol002dco`040000NOooo`00Ioooo`80000:<ol000?o09Tco`0c
o`00:c?o0080001moooo001Woooo00<0000co`0co`002C?o0003o`2I<ol0<ol002Tco`020000Oooo
o`00Ioooo`030000<ol0<ol000Tco`000ol0VC?o03?o000W<ol00P00087oool006Ooool00`0003?o
03?o0009<ol000?o09Tco`0co`009C?o00800023oooo001Woooo00<0000co`0co`002C?o0003o`2I
<ol0<ol002@co`000`000?ooooooo`23oooo001Woooo00<0000co`0co`002C?o0003o`2I<ol0<ol0
028co`020000Q_ooo`00Ioooo`80000:<ol000?o09Tco`0co`0083?o00800028oooo001Woooo00<0
000co`0co`002C?o0003o`2I<ol0<ol001lco`000`000?ooooooo`28oooo001Woooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol001hco`000`000?ooooooo`29oooo001Woooo00<0000co`0co`002C?o
0003o`2I<ol0<ol001dco`000`000?ooooooo`2:oooo001Woooo00<0000co`0co`002C?o0003o`2I
<ol0<ol001`co`000`000?ooooooo`2;oooo001Woooo00<0000co`0co`002C?o0003o`2I<ol0<ol0
01`co`000`000?ooooooo`2;oooo001Woooo0P0000Xco`000ol0VC?o03?o000K<ol000<0003ooooo
ool0S?ooo`00Ioooo`030000<ol0<ol000Tco`000ol0VC?o03?o000J<ol000<0003oooooool0SOoo
o`00Ioooo`030000<ol0<ol000Tco`000ol0VC?o03?o000I<ol000<0003oooooool0S_ooo`00Iooo
o`030000<ol0<ol000Tco`000ol0VC?o03?o000H<ol000<0003oooooool0Soooo`00Ioooo`030000
<ol0<ol000Tco`000ol0VC?o03?o000G<ol000<0003oooooool0T?ooo`00Ioooo`030000<ol0<ol0
00Tco`000ol0VC?o03?o000G<ol000<0003oooooool0T?ooo`00Ioooo`80000:<ol000?o09Tco`0c
o`005S?o00030000oooooooo097oool006Ooool00`0003?o03?o0009<ol000?o09Tco`0co`005C?o
00030000oooooooo09;oool006Ooool00`0003?o03?o0009<ol000?o09Tco`0co`0053?o00030000
oooooooo09?oool006Ooool00`0003?o03?o0009<ol000?o09Tco`0co`0053?o00030000oooooooo
09?oool006Ooool00`0003?o03?o0009<ol000?o09Tco`0co`004c?o00030000oooooooo09Coool0
05ooool500000oooo`030000<ol0<ol000Tco`000ol0VC?o03?o000C<ol000<0003oooooool0U?oo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o0009<ol000?o09Tco`0co`004S?o00030000
oooooooo09Goool0067oool00`000?ooooooo`03oooo0P0000Xco`000ol0VC?o03?o000B<ol000<0
003oooooool0UOooo`00HOooo`030000oooooooo00?oool00`0003?o03?o0009<ol000?o09Tco`0c
o`004C?o00030000oooooooo09Koool0067oool00`000?ooooooo`03oooo00<0000co`0co`002C?o
0003o`2I<ol0<ol0014co`000`000?ooooooo`2Foooo001Poooo0P0000Goool00`0003?o03?o0009
<ol000?o09Tco`0co`0043?o00030000oooooooo09Ooool006Ooool00`0003?o03?o0009<ol000?o
09Tco`0co`0043?o00030000oooooooo09Ooool006Ooool00`0003?o03?o0009<ol000?o09Tco`0c
o`003c?o00030000oooooooo09Soool006Ooool200002S?o0003o`2I<ol0<ol000lco`000`000?oo
ooooo`2Hoooo001Woooo00<0000co`0co`002C?o0003o`2I<ol0<ol000hco`000`000?ooooooo`2I
oooo001Woooo00<0000co`0co`002C?o0003o`2I<ol0<ol000hco`000`000?ooooooo`2Ioooo001W
oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000dco`000`000?ooooooo`2Joooo001Woooo00<0
000co`0co`002C?o0003o`2I<ol0<ol000dco`000`000?ooooooo`2Joooo001Woooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol000`co`000`000?ooooooo`2Koooo001Woooo0P0000Xco`000ol0VC?o
03?o000<<ol000<0003oooooool0Voooo`00Ioooo`030000<ol0<ol000Tco`000ol0VC?o03?o000;
<ol000<0003oooooool0W?ooo`00Ioooo`030000<ol0<ol000Tco`000ol0VC?o03?o000;<ol000<0
003oooooool0W?ooo`00Ioooo`030000<ol0<ol000Tco`000ol0VC?o03?o000:<ol000<0003ooooo
ool0WOooo`00Ioooo`030000<ol0<ol000Tco`000ol0VC?o03?o000:<ol000<0003oooooool0WOoo
o`00Ioooo`030000<ol0<ol000Tco`000ol0VC?o03?o000:<ol000<0003oooooool0WOooo`00Iooo
o`030000<ol0<ol000Tco`000ol0VC?o03?o0009<ol000<0003oooooool0W_ooo`00Ioooo`80000:
<ol000?o09Tco`0co`002C?o00030000oooooooo09koool006Ooool00`0003?o03?o0009<ol000?o
09Tco`0co`002C?o00030000oooooooo09koool006Ooool00`0003?o03?o0009<ol000?o09Tco`0c
o`002C?o00030000oooooooo09koool006Ooool00`0003?o03?o0009<ol000?o09Tco`0co`0023?o
00030000oooooooo09ooool006Ooool00`0003?o03?o0009<ol000?o09Tco`0co`0023?o00030000
oooooooo09ooool006Ooool00`0003?o03?o0009<ol000?o09Tco`0co`0023?o00030000oooooooo
09ooool006Ooool200002S?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`2Ooooo001Woooo00<0
000co`0co`002C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Poooo001Woooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Poooo001Woooo00<0000co`0co`002C?o
0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Poooo001Ooooo100000Coool00`0003?o03?o0009
<ol000?o09Tco`0co`001c?o00030000oooooooo0:3oool005ooool00`000?ooooooo`05oooo00<0
000co`0co`002C?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`2Qoooo001Poooo00<0003ooooo
ool01?ooo`80000:<ol000?o09Tco`0co`001S?o00030000oooooooo0:7oool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`2Qoooo001O
oooo00@0003oooooool00004oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000Dco`000`000?oo
ooooo`2Roooo001Poooo0P0000Goool00`0003?o03?o0009<ol000?o09Tco`0co`001C?o00030000
oooooooo0:;oool006Ooool00`0003?o03?o0009<ol000?o09Tco`0co`001C?o00030000oooooooo
0:;oool006Ooool00`0003?o03?o0009<ol000?o09Tco`0co`001C?o00030000oooooooo0:;oool0
06Ooool200002S?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Soooo001Woooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Soooo001Woooo00<0000co`0co`002C?o
0003o`2I<ol0<ol000@co`000`000?ooooooo`2Soooo001Woooo00<0000co`0co`002C?o0003o`2I
<ol0<ol000@co`000`000?ooooooo`2Soooo001Woooo00<0000co`0co`002C?o0003o`2I<ol0<ol0
00<co`000`000?ooooooo`2Toooo001Woooo00<0000co`0co`002C?o0003o`2I<ol0<ol000<co`00
0`000?ooooooo`2Toooo001Woooo00<0000co`0co`002C?o0003o`2I<ol0<ol000<co`000`000?oo
ooooo`2Toooo001Woooo0P0000Xco`000ol0VC?o03?o0003<ol000<0003oooooool0Y?ooo`00Iooo
o`030000<ol0<ol000Tco`000ol0VC?o03?o0002<ol000<0003oooooool0YOooo`00Ioooo`030000
<ol0<ol000Tco`000ol0VC?o03?o0002<ol000<0003oooooool0YOooo`00Ioooo`030000<ol0<ol0
00Tco`000ol0VC?o03?o0002<ol000<0003oooooool0YOooo`00Ioooo`030000<ol0<ol000Tco`00
0ol0VC?o03?o0002<ol000<0003oooooool0YOooo`00Ioooo`030000<ol0<ol000Tco`001Ol0VC?o
03?o03?o0000002Xoooo001Woooo0P0000Xco`001Ol0VC?o03?o03?o0000002Xoooo001Woooo00<0
000co`0co`002C?o0005o`2I<ol0<ol0<ol000000:Soool006Ooool00`0003?o03?o0009<ol000Go
09Tco`0co`0co`000000Z?ooo`00Ioooo`030000<ol0<ol000Tco`001?l0VC?o03?o00000:Woool0
06Ooool00`0003?o03?o0009<ol000Co09Tco`0co`00002Yoooo001Woooo00<0000co`0co`002C?o
0004o`2I<ol0<ol00000ZOooo`00Ioooo`80000:<ol000Co09Tco`0co`00002Yoooo001Woooo00<0
000co`0co`002C?o0004o`2I<ol0<ol00000ZOooo`00Ioooo`030000<ol0<ol000Tco`001?l0VC?o
03?o00000:Woool006Ooool00`0003?o03?o0009<ol000?o09Tco`000000Z_ooo`00H?ooo`800005
oooo00<0000co`0co`002C?o0003o`2I<ol000000:[oool005ooool010000?ooooooo`0000Coool0
0`0003?o03?o0009<ol000?o09Tco`000000Z_ooo`00HOooo`030000oooooooo00?oool200002S?o
0003o`2I<ol000000:[oool006;oool00`000?ooooooo`02oooo00<0000co`0co`002C?o0003o`2I
<ol000000:[oool005ooool010000?ooooooo`0000Coool00`0003?o03?o0009<ol000?o09Tco`00
0000Z_ooo`00H?ooo`800005oooo00<0000co`0co`002C?o0003o`2I0000oooo0:[oool006Ooool0
0`0003?o03?o0009<ol000?o09T0003oool0Z_ooo`00Ioooo`030000<ol0<ol000Tco`000ol0V@00
0?ooo`2Zoooo001Woooo00<0000co`0co`002C?o0003o`2I0000oooo0:[oool006Ooool200002S?o
0003o`2I0000oooo0:[oool006Ooool00`0003?o03?o0009<ol000?o09T0003oool0Z_ooo`00Iooo
o`030000<ol0<ol000Tco`000ol0VOooooooo`2Zoooo001Woooo00<0000co`0co`002C?o0003o`2I
oooooooo0:[oool006Ooool00`0003?o03?o0009<ol000?o09Woooooool0Z_ooo`00Ioooo`030000
<ol0<ol000Tco`000ol0VOooooooo`2Zoooo001Woooo0P0000Xco`000ol0VOooooooo`2Zoooo001W
oooo00<0000co`0co`002C?o0003o`2Ioooooooo0:[oool006Ooool00`0003?o03?o0009<ol000?o
09Woooooool0Z_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?l0VOooo`2[oooo001Woooo00<0
000co`0co`0023?o00030000o`2Ioooo0:_oool006Ooool00`0003?o03?o0008<ol000<0003o09Wo
ool0Zoooo`00Ioooo`800009<ol000<0003o09Woool0Zoooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?l0VOooo`2[oooo001Woooo00<0000co`0co`0023?o00030000o`2Ioooo0:_oool006Ooool0
0`0003?o03?o0007<ol000<0003ooooo09T0[?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ool0V@2/oooo001Woooo00<0000co`0co`001c?o00030000ooooo`2I0:coool006Ooool2000023?o
00030000ooooo`2I0:coool006Ooool00`0003?o03?o0007<ol000<0003ooooo09T0[?ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooool0V@2/oooo001Woooo00<0000co`0co`001c?o00030000
ooooo`2I0:coool006Ooool00`0003?o03?o0007<ol000<0003ooooo09T0[?ooo`00HOooo`<00003
oooo00<0000co`0co`001c?o00030000ooooo`2I0:coool006;oool00`000?ooooooo`02oooo00<0
000co`0co`001c?o00030000ooooo`2I0:coool005ooool500000oooo`800008<ol000<0003ooooo
09T0[?ooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?oo
o`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool0
06Ooool9<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo1@00
0004oooo0000000000001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002_oo
o`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001Woooo2C?o00Ooool0
0`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002_ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0
003oooooool01@0000coool010000?ooooooo`0000[oool010000?ooooooooooo`<00004oooo00<0
003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000003oooo`040000oooooooo
00002_ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00Iooo
o`Tco`09oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo
07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.3815 .12361 L
.39106 .12361 L
.39381 .12361 L
.39516 .12361 L
.39642 .12361 L
.39756 .12361 L
s
.39756 .12361 m
.39805 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28025 .12361 L
.2817 .12361 L
.28302 .12361 L
.28425 .12351 L
.28542 .12261 L
.288 .12065 L
.29349 .11663 L
.30316 .11006 L
.34135 .08956 L
.36267 .08071 L
.38199 .07342 L
.39167 .07002 L
.39432 .06912 L
.39577 .06863 L
.39713 .06818 L
.39828 .0678 L
.39952 .12361 L
.40022 .12361 L
.40089 .12361 L
.40214 .12361 L
.42112 .12361 L
.45945 .12361 L
.50023 .12361 L
.5395 .12361 L
.57725 .12361 L
.61746 .12361 L
.65614 .12361 L
.69728 .12361 L
.73691 .12361 L
.77502 .12361 L
.81558 .12361 L
.85462 .12361 L
.89612 .12361 L
.9361 .12361 L
.97457 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0003oooooool02ooo
o`0306Kooooooooo0:Soool006Ooool00`000?ooooooo`09oooo0`1Voj[oool006Ooool200001ooo
o`<0I_l2oooo00<0I_ooooooool0Z?ooo`005oooo`D0000Noooo0P0000Coool200001?ooo`80000O
oooo00<0003oooooool01?ooo`80I_l5oooo00<0I_ooooooool04?ooo`800004oooo0P0000Coool2
00007oooo`D0000Moooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?oo
ooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000Noooo00@0003oooooooooool3
06Ko1oooo`0306Kooooooooo00ooool010000?ooooooo`0000Soool010000?ooooooo`00023oool0
0`000?ooooooo`0Ooooo00<0003oooooool01oooo`040000oooooooo00007oooo`030000oooooooo
01Ooool001Woool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool07?oo
o`040000oooo06Ko06Ko2_ooo`0306Kooooooooo00ooool010000?ooooooo`0000_oool00`000?oo
ooooo`0Noooo00<0003oooooool07oooo`030000oooooooo00[oool00`000?ooooooo`0Noooo00<0
003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool05oooo`@00002oooo00@0003ooooo
ool00009oooo0P0001ooool00`00001Vooooo`0;oooo00<0I_ooooooool03oooo`040000oooooooo
00002Oooo`80000Qoooo00<0003oooooool07oooo`030000oooooooo00Soool200008_ooo`030000
oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003ooooo
ool07?ooo`80I_l00`000?ooooooo`0;oooo00<0I_ooooooool03oooo`040000oooooooo00002Ooo
o`030000oooooooo023oool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`030000oooooooo
01ooool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`0001[oool206Ko0_oo
o`80000<oooo00<0I_ooooooool04?ooo`80000:oooo0`0001ooool200008?ooo`80000:oooo0`00
023oool200005oooo`00HOooo`80I_l4oooo00<0003oooooool02oooo`0306Kooooooooo0:Soool0
05ooool206Ko1_ooo`030000oooooooo00_oool00`1Vooooooooo`2Xoooo001Moooo0P1Vo`Soool0
0`000?ooooooo`0;oooo00<0I_ooooooool0Z?ooo`00G?ooo`0306Kooooooooo00Soool00`000?oo
ooooo`0;oooo00<0I_ooooooool0Z?ooo`00Foooo`0306Kooooooooo00Woool00`000?ooooooo`0;
oooo00<0I_ooooooool0Z?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0003<ol000?o09Tco`00
00001c?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0000co`0co`002c?o0003o`2I<ol0<ol001Lco`000`0003?o
03?o000T<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000
<ol0<ol000/co`000ol0VC?o03?o000i<ol01@0006[oool006Ooool00`0003?o03?o000;<ol000?o
09Tco`0co`00=3?o00D0001_oooo001Woooo00<0000co`0co`002c?o0003o`2I<ol0<ol002lco`05
0000M?ooo`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o000[<ol0100007Woool006Ooool2
000033?o0003o`2I<ol0<ol002Tco`020000OOooo`00Ioooo`030000<ol0<ol000/co`000ol0VC?o
03?o000W<ol00P0007ooool006Ooool00`0003?o03?o000;<ol000?o09Tco`0co`009C?o00800021
oooo001Woooo00<0000co`0co`002c?o0003o`2I<ol0<ol002<co`020000Poooo`00Ioooo`030000
<ol0<ol000/co`000ol0VC?o03?o000R<ol000<0003oooooool0Poooo`00Ioooo`030000<ol0<ol0
00/co`000ol0VC?o03?o000P<ol00P0008Koool006Ooool2000033?o0003o`2I<ol0<ol001hco`02
0000R?ooo`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o000M<ol000<0003oooooool0R?oo
o`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o000L<ol000<0003oooooool0ROooo`00Iooo
o`030000<ol0<ol000/co`000ol0VC?o03?o000K<ol000<0003oooooool0R_ooo`00Ioooo`030000
<ol0<ol000/co`000ol0VC?o03?o000J<ol000<0003oooooool0Roooo`00Ioooo`030000<ol0<ol0
00/co`000ol0VC?o03?o000J<ol000<0003oooooool0Roooo`00Ioooo`80000<<ol000?o09Tco`0c
o`006C?o00030000oooooooo08coool006Ooool00`0003?o03?o000;<ol000?o09Tco`0co`0063?o
00030000oooooooo08goool006Ooool00`0003?o03?o000;<ol000?o09Tco`0co`005c?o00030000
oooooooo08koool006Ooool00`0003?o03?o000;<ol000?o09Tco`0co`005S?o00030000oooooooo
08ooool006Ooool00`0003?o03?o000;<ol000?o09Tco`0co`005C?o00030000oooooooo093oool0
06Ooool00`0003?o03?o000;<ol000?o09Tco`0co`005C?o00030000oooooooo093oool006Ooool2
000033?o0003o`2I<ol0<ol001@co`000`000?ooooooo`2Aoooo001Woooo00<0000co`0co`002c?o
0003o`2I<ol0<ol001<co`000`000?ooooooo`2Boooo001Woooo00<0000co`0co`002c?o0003o`2I
<ol0<ol0018co`000`000?ooooooo`2Coooo001Woooo00<0000co`0co`002c?o0003o`2I<ol0<ol0
018co`000`000?ooooooo`2Coooo001Woooo00<0000co`0co`002c?o0003o`2I<ol0<ol0014co`00
0`000?ooooooo`2Doooo001Ooooo1@0000?oool00`0003?o03?o000;<ol000?o09Tco`0co`004C?o
00030000oooooooo09Coool0067oool00`000?ooooooo`03oooo00<0000co`0co`002c?o0003o`2I
<ol0<ol0010co`000`000?ooooooo`2Eoooo001Qoooo00<0003oooooool00oooo`80000<<ol000?o
09Tco`0co`0043?o00030000oooooooo09Goool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol000lco`000`000?ooooooo`2Foooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol000/co`000ol0VC?o03?o000?<ol000<0003oooooool0U_ooo`00H?ooo`800005
oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000hco`000`000?ooooooo`2Goooo001Woooo00<0
000co`0co`002c?o0003o`2I<ol0<ol000hco`000`000?ooooooo`2Goooo001Woooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol000dco`000`000?ooooooo`2Hoooo001Woooo0P0000`co`000ol0VC?o
03?o000=<ol000<0003oooooool0V?ooo`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o000<
<ol000<0003oooooool0VOooo`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o000<<ol000<0
003oooooool0VOooo`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o000;<ol000<0003ooooo
ool0V_ooo`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o000;<ol000<0003oooooool0V_oo
o`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o000:<ol000<0003oooooool0Voooo`00Iooo
o`80000<<ol000?o09Tco`0co`002S?o00030000oooooooo09_oool006Ooool00`0003?o03?o000;
<ol000?o09Tco`0co`002C?o00030000oooooooo09coool006Ooool00`0003?o03?o000;<ol000?o
09Tco`0co`002C?o00030000oooooooo09coool006Ooool00`0003?o03?o000;<ol000?o09Tco`0c
o`0023?o00030000oooooooo09goool006Ooool00`0003?o03?o000;<ol000?o09Tco`0co`0023?o
00030000oooooooo09goool006Ooool00`0003?o03?o000;<ol000?o09Tco`0co`0023?o00030000
oooooooo09goool006Ooool00`0003?o03?o000;<ol000?o09Tco`0co`001c?o00030000oooooooo
09koool006Ooool2000033?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Noooo001Woooo00<0
000co`0co`002c?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Noooo001Woooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Noooo001Woooo00<0000co`0co`002c?o
0003o`2I<ol0<ol000Hco`000`000?ooooooo`2Ooooo001Woooo00<0000co`0co`002c?o0003o`2I
<ol0<ol000Hco`000`000?ooooooo`2Ooooo001Woooo00<0000co`0co`002c?o0003o`2I<ol0<ol0
00Hco`000`000?ooooooo`2Ooooo001Woooo0P0000`co`000ol0VC?o03?o0006<ol000<0003ooooo
ool0Woooo`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o0005<ol000<0003oooooool0X?oo
o`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o0005<ol000<0003oooooool0X?ooo`00Iooo
o`030000<ol0<ol000/co`000ol0VC?o03?o0005<ol000<0003oooooool0X?ooo`00Goooo`@00004
oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Poooo001Ooooo00<0
003oooooool01Oooo`030000<ol0<ol000/co`000ol0VC?o03?o0004<ol000<0003oooooool0XOoo
o`00H?ooo`030000oooooooo00Coool2000033?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Q
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol000/co`000ol0VC?o03?o0004<ol000<0
003oooooool0XOooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000ol0VC?o
03?o0003<ol000<0003oooooool0X_ooo`00H?ooo`800005oooo00<0000co`0co`002c?o0003o`2I
<ol0<ol000<co`000`000?ooooooo`2Roooo001Woooo00<0000co`0co`002c?o0003o`2I<ol0<ol0
00<co`000`000?ooooooo`2Roooo001Woooo00<0000co`0co`002c?o0003o`2I<ol0<ol000<co`00
0`000?ooooooo`2Roooo001Woooo0P0000`co`000ol0VC?o03?o0002<ol000<0003oooooool0Xooo
o`00Ioooo`030000<ol0<ol000/co`000ol0VC?o03?o0002<ol000<0003oooooool0Xoooo`00Iooo
o`030000<ol0<ol000/co`000ol0VC?o03?o0002<ol000<0003oooooool0Xoooo`00Ioooo`030000
<ol0<ol000/co`000ol0VC?o03?o0002<ol000<0003oooooool0Xoooo`00Ioooo`030000<ol0<ol0
00/co`001Ol0VC?o03?o03?o0000002Voooo001Woooo00<0000co`0co`002c?o0005o`2I<ol0<ol0
<ol000000:Koool006Ooool00`0003?o03?o000;<ol000Go09Tco`0co`0co`000000Y_ooo`00Iooo
o`80000<<ol000Go09Tco`0co`0co`000000Y_ooo`00Ioooo`030000<ol0<ol000/co`001?l0VC?o
03?o00000:Ooool006Ooool00`0003?o03?o000;<ol000Co09Tco`0co`00002Woooo001Woooo00<0
000co`0co`002c?o0004o`2I<ol0<ol00000Yoooo`00Ioooo`030000<ol0<ol000/co`001?l0VC?o
03?o00000:Ooool006Ooool00`0003?o03?o000;<ol000?o09Tco`000000Z?ooo`00Ioooo`80000<
<ol000?o09Tco`000000Z?ooo`00Ioooo`030000<ol0<ol000/co`000ol0VC?o0000002Xoooo001W
oooo00<0000co`0co`002c?o0003o`2I<ol000000:Soool006Ooool00`0003?o03?o000;<ol000?o
09T0003oool0Z?ooo`00Ioooo`030000<ol0<ol000/co`000ol0V@000?ooo`2Xoooo001Woooo00<0
000co`0co`002c?o0003o`2I0000oooo0:Soool006Ooool2000033?o0003o`2I0000oooo0:Soool0
06Ooool00`0003?o03?o000;<ol000?o09T0003oool0Z?ooo`00Ioooo`030000<ol0<ol000/co`00
0ol0V@000?ooo`2Xoooo001Woooo00<0000co`0co`002c?o0003o`2Ioooooooo0:Soool0063oool2
00001Oooo`030000<ol0<ol000/co`000ol0VOooooooo`2Xoooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`002c?o0003o`2Ioooooooo0:Soool0067oool00`000?ooooooo`03oooo0P00
00`co`000ol0VOooooooo`2Xoooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`00
0ol0VOooooooo`2Xoooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o0003o`2I
oooooooo0:Soool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?l0VOooo`2Yoooo001W
oooo00<0000co`0co`002S?o00030000o`2Ioooo0:Woool006Ooool00`0003?o03?o000:<ol000<0
003o09Woool0ZOooo`00Ioooo`030000<ol0<ol000Xco`000`000?l0VOooo`2Yoooo001Woooo0P00
00/co`000`000?l0VOooo`2Yoooo001Woooo00<0000co`0co`002S?o00030000o`2Ioooo0:Woool0
06Ooool00`0003?o03?o0009<ol000<0003ooooo09T0Z_ooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooool0V@2Zoooo001Woooo00<0000co`0co`002C?o00030000ooooo`2I0:[oool006Ooool0
0`0003?o03?o0009<ol000<0003ooooo09T0Z_ooo`00Ioooo`80000:<ol000<0003ooooo09T0Z_oo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooool0V@2Zoooo001Woooo00<0000co`0co`002C?o
00030000ooooo`2I0:[oool006Ooool00`0003?o03?o0008<ol000@0003ooooooooo09VZoooo001W
oooo00<0000co`0co`0023?o00040000ooooooooo`2IZ_ooo`00Ioooo`030000<ol0<ol000Pco`00
10000?ooooooool0VJ[oool006Ooool200002C?o00040000ooooooooo`2IZ_ooo`00Ioooo`030000
<ol0<ol000Pco`0010000?ooooooool0VJ[oool006Ooool00`0003?o03?o0008<ol000@0003ooooo
oooo09VZoooo001Woooo00<0000co`0co`001c?o00050000ooooooooooooo`2I0:[oool006Ooool0
0`0003?o03?o0007<ol000D0003ooooooooooooo09T0Z_ooo`00Ioooo`030000<ol0<ol000Lco`00
1@000?ooooooooooool0V@2Zoooo001Woooo0P0000Pco`001@000?ooooooooooool0V@2Zoooo001W
oooo00<0000co`0co`001c?o00050000ooooooooooooo`2I0:[oool006Ooool00`0003?o03?o0007
<ol000D0003ooooooooooooo09T0Z_ooo`00Ioooo`030000<ol0<ol000Lco`001@000?oooooooooo
ool0V@2Zoooo001Woooo00<0000co`0co`001c?o00050000ooooooooooooo`2I0:[oool0067oool3
00000oooo`030000<ol0<ol000Lco`001@000?ooooooooooool0V@2Zoooo001Roooo00<0003ooooo
ool00_ooo`030000<ol0<ol000Lco`001@000?ooooooooooool0V@2Zoooo001Ooooo1@0000?oool2
000023?o00050000ooooooooooooo`2I0:[oool005ooool010000?ooooooo`0000Coool:<ol0[ooo
o`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9
<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000Coool200000oooo`D00002oooo0P0000Coool00`000?ooooooo`1hoooo001Woooo2C?o
00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000N_oo
o`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
06Ooool9<ol02?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000:oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool0
00003oooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool01@000?oooooooooo
o`00001joooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`800003
oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.39174 .12361 L
.39675 .12361 L
.40134 .12361 L
.40252 .12361 L
.40381 .12361 L
s
.40381 .12361 m
.4043 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.26171 .12361 L
.26709 .12361 L
.27279 .12361 L
.27513 .12361 L
.27643 .12361 L
.27765 .12361 L
.27835 .12317 L
.2791 .12258 L
.28042 .12157 L
.28302 .11963 L
.30316 .10607 L
.3438 .08589 L
.38293 .07134 L
.39322 .0679 L
.39863 .06616 L
.40158 .06523 L
.40303 .06478 L
.40434 .06437 L
.40558 .12361 L
.40676 .12361 L
.40935 .12361 L
.41485 .12361 L
.42451 .12361 L
.46284 .12361 L
.50362 .12361 L
.54289 .12361 L
.58064 .12361 L
.62084 .12361 L
.65953 .12361 L
.70067 .12361 L
.7403 .12361 L
.7784 .12361 L
.81897 .12361 L
.85801 .12361 L
.89951 .12361 L
.93949 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`0<oooo0P1VojSoool006Ooool00`000?oo
ooooo`09oooo1@1VojSoool006Ooool00`000?ooooooo`06oooo0`1Vo`Coool00`1Vooooooooo`2V
oooo001Woooo0P0000Goool206Ko1oooo`0306Kooooooooo0:Koool001Ooool500007_ooo`800004
oooo0P0000Coool200007oooo`040000oooooooooooo0`1Vo`Woool00`1Vooooooooo`0>oooo0P00
00Coool200001?ooo`80000Ooooo1@0001goool500000_ooo`800004oooo0P00023oool400005_oo
o`006Oooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`0001koool0
10000?ooo`1Vo`1Vo`coool00`1Vooooooooo`0=oooo00@0003oooooool00008oooo00@0003ooooo
ool0000Poooo00<0003oooooool07oooo`030000oooooooo00Ooool010000?ooooooo`0001ooool0
0`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000
oooooooo01coool00`00001Vooooo`0=oooo00<0I_ooooooool03Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200007Oooo`80I_l00`000?ooooooo`0=oooo00<0I_ooooooool03Ooo
o`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool07oooo`030000oooooooo00Soool2
00008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0003oooooool00009
oooo00<0003oooooool06_ooo`80I_l2oooo00<0003oooooool03Oooo`0306Kooooooooo00goool0
10000?ooooooo`0000Woool00`000?ooooooo`0Poooo00<0003oooooool07oooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00023oool200002_oo
o`<0000Hoooo0P1Vo`Coool200003_ooo`0306Kooooooooo00koool200002_ooo`<0000Ooooo0P00
023oool200002_ooo`<0000Poooo0P0001Ooool005ooool206Ko1_ooo`030000oooooooo00goool0
0`1Vooooooooo`2Voooo001Moooo0P1Vo`Soool00`000?ooooooo`0=oooo00<0I_ooooooool0Y_oo
o`00Foooo`80I_l:oooo00<0003oooooool03Oooo`0306Kooooooooo0:Koool005Woool206Ko3?oo
o`030000oooooooo00goool00`1Vooooooooo`2Voooo001Hoooo00<0I_ooooooool03?ooo`030000
oooooooo00goool00`1Vooooooooo`2Voooo000@ooooo`00017oool001Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000=<ol000?o09Tco`0co`005C?o
00030000<ol0<ol002@co`0@00006Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo001W
oooo00<0000co`0co`003C?o0003o`2I<ol0<ol003Lco`050000J_ooo`00Ioooo`030000<ol0<ol0
00dco`000ol0VC?o03?o000b<ol01@0006ooool006Ooool00`0003?o03?o000=<ol000?o09Tco`0c
o`00;C?o00D0001doooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol002Tco`040000NOoo
o`00Ioooo`80000><ol000?o09Tco`0co`009c?o0080001moooo001Woooo00<0000co`0co`003C?o
0003o`2I<ol0<ol002Dco`020000Ooooo`00Ioooo`030000<ol0<ol000dco`000ol0VC?o03?o000S
<ol00P00087oool006Ooool00`0003?o03?o000=<ol000?o09Tco`0co`008C?o00800023oooo001W
oooo00<0000co`0co`003C?o0003o`2I<ol0<ol0020co`000`000?ooooooo`23oooo001Woooo00<0
000co`0co`003C?o0003o`2I<ol0<ol001hco`020000Q_ooo`00Ioooo`80000><ol000?o09Tco`0c
o`0073?o00800028oooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol001/co`000`000?oo
ooooo`28oooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol001Xco`000`000?ooooooo`29
oooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol001Tco`000`000?ooooooo`2:oooo001W
oooo00<0000co`0co`003C?o0003o`2I<ol0<ol001Pco`000`000?ooooooo`2;oooo001Woooo00<0
000co`0co`003C?o0003o`2I<ol0<ol001Pco`000`000?ooooooo`2;oooo001Woooo0P0000hco`00
0ol0VC?o03?o000G<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol000dco`000ol0VC?o
03?o000F<ol000<0003oooooool0SOooo`00Ioooo`030000<ol0<ol000dco`000ol0VC?o03?o000E
<ol000<0003oooooool0S_ooo`00Ioooo`030000<ol0<ol000dco`000ol0VC?o03?o000D<ol000<0
003oooooool0Soooo`00Ioooo`030000<ol0<ol000dco`000ol0VC?o03?o000C<ol000<0003ooooo
ool0T?ooo`00Ioooo`030000<ol0<ol000dco`000ol0VC?o03?o000C<ol000<0003oooooool0T?oo
o`00Ioooo`80000><ol000?o09Tco`0co`004S?o00030000oooooooo097oool006Ooool00`0003?o
03?o000=<ol000?o09Tco`0co`004C?o00030000oooooooo09;oool006Ooool00`0003?o03?o000=
<ol000?o09Tco`0co`0043?o00030000oooooooo09?oool006Ooool00`0003?o03?o000=<ol000?o
09Tco`0co`0043?o00030000oooooooo09?oool006Ooool00`0003?o03?o000=<ol000?o09Tco`0c
o`003c?o00030000oooooooo09Coool005ooool500000oooo`030000<ol0<ol000dco`000ol0VC?o
03?o000?<ol000<0003oooooool0U?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000=
<ol000?o09Tco`0co`003S?o00030000oooooooo09Goool0067oool00`000?ooooooo`03oooo0P00
00hco`000ol0VC?o03?o000><ol000<0003oooooool0UOooo`00HOooo`030000oooooooo00?oool0
0`0003?o03?o000=<ol000?o09Tco`0co`003C?o00030000oooooooo09Koool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`003C?o0003o`2I<ol0<ol000dco`000`000?ooooooo`2Foooo001P
oooo0P0000Goool00`0003?o03?o000=<ol000?o09Tco`0co`0033?o00030000oooooooo09Ooool0
06Ooool00`0003?o03?o000=<ol000?o09Tco`0co`0033?o00030000oooooooo09Ooool006Ooool0
0`0003?o03?o000=<ol000?o09Tco`0co`002c?o00030000oooooooo09Soool006Ooool200003S?o
0003o`2I<ol0<ol000/co`000`000?ooooooo`2Hoooo001Woooo00<0000co`0co`003C?o0003o`2I
<ol0<ol000Xco`000`000?ooooooo`2Ioooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol0
00Xco`000`000?ooooooo`2Ioooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol000Tco`00
0`000?ooooooo`2Joooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol000Tco`000`000?oo
ooooo`2Joooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`2K
oooo001Woooo0P0000hco`000ol0VC?o03?o0008<ol000<0003oooooool0Voooo`00Ioooo`030000
<ol0<ol000dco`000ol0VC?o03?o0007<ol000<0003oooooool0W?ooo`00Ioooo`030000<ol0<ol0
00dco`000ol0VC?o03?o0007<ol000<0003oooooool0W?ooo`00Ioooo`030000<ol0<ol000dco`00
0ol0VC?o03?o0006<ol000<0003oooooool0WOooo`00Ioooo`030000<ol0<ol000dco`000ol0VC?o
03?o0006<ol000<0003oooooool0WOooo`00Ioooo`030000<ol0<ol000dco`000ol0VC?o03?o0006
<ol000<0003oooooool0WOooo`00Ioooo`030000<ol0<ol000dco`000ol0VC?o03?o0005<ol000<0
003oooooool0W_ooo`00Ioooo`80000><ol000?o09Tco`0co`001C?o00030000oooooooo09koool0
06Ooool00`0003?o03?o000=<ol000?o09Tco`0co`001C?o00030000oooooooo09koool006Ooool0
0`0003?o03?o000=<ol000?o09Tco`0co`001C?o00030000oooooooo09koool006Ooool00`0003?o
03?o000=<ol000?o09Tco`0co`0013?o00030000oooooooo09ooool006Ooool00`0003?o03?o000=
<ol000?o09Tco`0co`0013?o00030000oooooooo09ooool006Ooool00`0003?o03?o000=<ol000?o
09Tco`0co`0013?o00030000oooooooo09ooool006Ooool200003S?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`2Ooooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol000<co`000`000?oo
ooooo`2Poooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol000<co`000`000?ooooooo`2P
oooo001Woooo00<0000co`0co`003C?o0003o`2I<ol0<ol000<co`000`000?ooooooo`2Poooo001O
oooo100000Coool00`0003?o03?o000=<ol000?o09Tco`0co`000c?o00030000oooooooo0:3oool0
05ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o0003o`2I<ol0<ol0008co`000`000?oo
ooooo`2Qoooo001Poooo00<0003oooooool01?ooo`80000><ol000?o09Tco`0co`000S?o00030000
oooooooo0:7oool0067oool00`000?ooooooo`03oooo00<0000co`0co`003C?o0003o`2I<ol0<ol0
008co`000`000?ooooooo`2Qoooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`003C?o
0005o`2I<ol0<ol0<ol000000:Coool0063oool200001Oooo`030000<ol0<ol000dco`001Ol0VC?o
03?o03?o0000002Toooo001Woooo00<0000co`0co`003C?o0005o`2I<ol0<ol0<ol000000:Coool0
06Ooool00`0003?o03?o000=<ol000Go09Tco`0co`0co`000000Y?ooo`00Ioooo`80000><ol000Co
09Tco`0co`00002Uoooo001Woooo00<0000co`0co`003C?o0004o`2I<ol0<ol00000YOooo`00Iooo
o`030000<ol0<ol000dco`001?l0VC?o03?o00000:Goool006Ooool00`0003?o03?o000=<ol000Co
09Tco`0co`00002Uoooo001Woooo00<0000co`0co`003C?o0003o`2I<ol000000:Koool006Ooool0
0`0003?o03?o000=<ol000?o09Tco`000000Y_ooo`00Ioooo`030000<ol0<ol000dco`000ol0VC?o
0000002Voooo001Woooo0P0000hco`000ol0VC?o0000002Voooo001Woooo00<0000co`0co`003C?o
0003o`2I0000oooo0:Koool006Ooool00`0003?o03?o000=<ol000?o09T0003oool0Y_ooo`00Iooo
o`030000<ol0<ol000dco`000ol0V@000?ooo`2Voooo001Woooo00<0000co`0co`003C?o0003o`2I
0000oooo0:Koool006Ooool00`0003?o03?o000=<ol000?o09Woooooool0Y_ooo`00Ioooo`80000>
<ol000?o09Woooooool0Y_ooo`00Ioooo`030000<ol0<ol000dco`000ol0VOooooooo`2Voooo001W
oooo00<0000co`0co`003C?o0003o`2Ioooooooo0:Koool006Ooool00`0003?o03?o000<<ol000<0
003o09Woool0Yoooo`00Ioooo`030000<ol0<ol000`co`000`000?l0VOooo`2Woooo001Woooo00<0
000co`0co`0033?o00030000o`2Ioooo0:Ooool006Ooool200003C?o00030000o`2Ioooo0:Ooool0
06Ooool00`0003?o03?o000<<ol000<0003o09Woool0Yoooo`00Ioooo`030000<ol0<ol000`co`00
0`000?l0VOooo`2Woooo001Woooo00<0000co`0co`002c?o00030000ooooo`2I0:Soool0063oool2
00001Oooo`030000<ol0<ol000/co`000`000?ooool0V@2Xoooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`002c?o00030000ooooo`2I0:Soool0067oool00`000?ooooooo`03oooo0P00
00`co`000`000?ooool0V@2Xoooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`00
0`000?ooool0V@2Xoooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000
ooooo`2I0:Soool0063oool200001Oooo`030000<ol0<ol000Xco`0010000?ooooooool0VJSoool0
06Ooool00`0003?o03?o000:<ol000@0003ooooooooo09VXoooo001Woooo00<0000co`0co`002S?o
00040000ooooooooo`2IZ?ooo`00Ioooo`030000<ol0<ol000Xco`0010000?ooooooool0VJSoool0
06Ooool200002c?o00040000ooooooooo`2IZ?ooo`00Ioooo`030000<ol0<ol000Xco`0010000?oo
ooooool0VJSoool006Ooool00`0003?o03?o0009<ol000D0003ooooooooooooo09T0Z?ooo`00Iooo
o`030000<ol0<ol000Tco`001@000?ooooooooooool0V@2Xoooo001Woooo00<0000co`0co`002C?o
00050000ooooooooooooo`2I0:Soool006Ooool00`0003?o03?o0009<ol000D0003ooooooooooooo
09T0Z?ooo`00Ioooo`80000:<ol000D0003ooooooooooooo09T0Z?ooo`00Ioooo`030000<ol0<ol0
00Tco`001@000?ooooooooooool0V@2Xoooo001Woooo00<0000co`0co`002C?o00050000oooooooo
ooooo`2I0:Soool006Ooool00`0003?o03?o0008<ol000<0003oooooool00_ooo`03o`2Ioooooooo
0:Koool006Ooool00`0003?o03?o0008<ol000<0003oooooool00_ooo`03o`2Ioooooooo0:Koool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool00_ooo`03o`2Ioooooooo0:Koool006Ooool2
00002C?o00030000oooooooo00;oool00ol0VOooooooo`2Voooo001Woooo00<0000co`0co`0023?o
00030000oooooooo00;oool00ol0VOooooooo`2Voooo001Woooo00<0000co`0co`0023?o00030000
oooooooo00;oool00ol0VOooooooo`2Voooo001Woooo00<0000co`0co`001c?o00030000oooooooo
00?oool00ol0VOooooooo`2Voooo001Woooo00<0000co`0co`001c?o00030000oooooooo00?oool0
0ol0VOooooooo`2Voooo001Woooo00<0000co`0co`001c?o00030000oooooooo00?oool00ol0VOoo
ooooo`2Voooo001Woooo0P0000Pco`000`000?ooooooo`03oooo00?o09Woooooool0Y_ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`03oooo00?o09Woooooool0Y_ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`03oooo00?o09Woooooool0Y_ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`03oooo00?o09Woooooool0Y_ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`03oooo00?o09Woooooool0Y_ooo`00HOooo`<00003oooo00<0000co`0co`001c?o
00030000oooooooo00?oool00ol0VOooooooo`2Voooo001Roooo00<0003oooooool00_ooo`030000
<ol0<ol000Lco`000`000?ooooooo`03oooo00?o09Woooooool0Y_ooo`00Goooo`D00003oooo0P00
00Pco`000`000?ooooooo`03oooo00?o09Woooooool0Y_ooo`00Goooo`040000oooooooo00001?oo
o`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[ooo
o`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol03?ooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001Woooo2C?o00_oool00`000?ooooooo`08oooo00<0003oooooool06Ooo
o`030000oooooooo07_oool006Ooool9<ol02oooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800003oooo100000?oool00`000?ooooooo`1koooo001Woooo2C?o
00_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Soool00`000?ooooooo`04oooo00<0003oooooool0Noooo`00Ioooo`Tco`0:
oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0N_ooo`00Ioooo`Tco`0;oooo00<0003oooooool01@0000coool0
10000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Ioooo`Tco`0;
oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07_oool006Ooool9<ol03?ooo`030000oooooooo017oool200002_ooo`800003
oooo00<0003oooooool0O?ooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.39174 .12361 L
.40134 .12361 L
.40616 .12361 L
.40755 .12361 L
.40887 .12361 L
.41005 .12361 L
s
.41005 .12361 m
.41057 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.26171 .12361 L
.26698 .12361 L
.26843 .12361 L
.26922 .12361 L
.26998 .12361 L
.27068 .12361 L
.27145 .12359 L
.27214 .12305 L
.27279 .12256 L
.28302 .11506 L
.30316 .10233 L
.34228 .08404 L
.36226 .07676 L
.38387 .06943 L
.39401 .0662 L
.39956 .06449 L
.40473 .06293 L
.407 .06226 L
.40915 .06164 L
.41034 .06129 L
.41163 .12361 L
.4128 .12361 L
.41389 .12361 L
.42393 .12361 L
.4632 .12361 L
.50095 .12361 L
.54115 .12361 L
.57984 .12361 L
.62098 .12361 L
.66061 .12361 L
.69871 .12361 L
.73927 .12361 L
.77832 .12361 L
.81982 .12361 L
.8598 .12361 L
.89827 .12361 L
.93918 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo0;Koool006Ooool00`000?ooooooo`0<oooo0`1VojOoool006Ooool00`000?oo
ooooo`0:oooo0P1Vo`;oool00`1Vooooooooo`2Uoooo001Woooo00<0003oooooool01oooo`<0I_l4
oooo00<0I_ooooooool0YOooo`00Ioooo`800005oooo0`1Vo`Ooool00`1Vooooooooo`2Uoooo000G
oooo1@0001koool200001?ooo`800004oooo0P0001ooool00`000?ooooooo`0406Ko2_ooo`0306Ko
oooooooo00goool200001?ooo`800004oooo0P0001ooool500007Oooo`D00002oooo0P0000Coool2
00008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000
oooooooo00007_ooo`03000006Ko06Ko00koool00`1Vooooooooo`0<oooo00@0003oooooool00008
oooo00@0003oooooool0000Poooo00<0003oooooool07oooo`030000oooooooo00Ooool010000?oo
ooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002oooo`030000oooooooo01[oool206Ko00<0003oooooool03_ooo`0306Kooooooooo00coool0
10000?ooooooo`0000_oool00`000?ooooooo`0Noooo00<0003oooooool07oooo`030000oooooooo
00[oool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003ooooo
ool05oooo`@00002oooo00@0003oooooool00009oooo0P0001_oool206Ko0_ooo`030000oooooooo
00koool00`1Vooooooooo`0<oooo00@0003oooooool00009oooo0P00027oool00`000?ooooooo`0O
oooo00<0003oooooool02?ooo`80000Roooo00<0003oooooool05Oooo`006Oooo`030000oooooooo
01goool010000?ooooooo`0000Woool00`000?ooooooo`0Hoooo0P1Vo`Coool00`000?ooooooo`0?
oooo00<0I_ooooooool02oooo`040000oooooooo00002Oooo`030000oooooooo023oool00`000?oo
ooooo`0Ooooo00<0003oooooool02?ooo`030000oooooooo01ooool010000?ooooooo`0001Koool0
01Soool200008?ooo`80000:oooo0`0001Koool206Ko1_ooo`80000@oooo00<0I_ooooooool03?oo
o`80000:oooo0`0001ooool200008?ooo`80000:oooo0`00023oool200005oooo`00GOooo`80I_l8
oooo00<0003oooooool03oooo`0306Kooooooooo0:Coool005_oool206Ko2_ooo`030000oooooooo
00ooool00`1Vooooooooo`2Toooo001Ioooo0P1Vo`coool00`000?ooooooo`0?oooo00<0I_oooooo
ool0Y?ooo`00F?ooo`0306Kooooooooo00coool00`000?ooooooo`0?oooo00<0I_ooooooool0Y?oo
o`00E_ooo`80I_l?oooo00<0003oooooool03oooo`0306Kooooooooo0:Coool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000o`2I<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X
00000_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol0
00hco`000ol0VC?o03?o000D<ol000<0000co`0co`0093?o0100000Ioooo00<0003oooooool09_oo
o`030000oooooooo01Goool006Ooool00`0003?o03?o000><ol000?o09Tco`0co`00=S?o00D0001Z
oooo001Woooo00<0000co`0co`003S?o0003o`2I<ol0<ol0034co`050000Koooo`00Ioooo`030000
<ol0<ol000hco`000ol0VC?o03?o000/<ol01@0007Coool006Ooool00`0003?o03?o000><ol000?o
09Tco`0co`00:3?o00@0001ioooo001Woooo0P0000lco`000ol0VC?o03?o000V<ol00P0007goool0
06Ooool00`0003?o03?o000><ol000?o09Tco`0co`0093?o0080001ooooo001Woooo00<0000co`0c
o`003S?o0003o`2I<ol0<ol0028co`020000POooo`00Ioooo`030000<ol0<ol000hco`000ol0VC?o
03?o000P<ol00P0008?oool006Ooool00`0003?o03?o000><ol000?o09Tco`0co`007c?o00030000
oooooooo08?oool006Ooool00`0003?o03?o000><ol000?o09Tco`0co`007C?o00800026oooo001W
oooo0P0000lco`000ol0VC?o03?o000K<ol00P0008Soool006Ooool00`0003?o03?o000><ol000?o
09Tco`0co`006S?o00030000oooooooo08Soool006Ooool00`0003?o03?o000><ol000?o09Tco`0c
o`006C?o00030000oooooooo08Woool006Ooool00`0003?o03?o000><ol000?o09Tco`0co`0063?o
00030000oooooooo08[oool006Ooool00`0003?o03?o000><ol000?o09Tco`0co`005c?o00030000
oooooooo08_oool006Ooool00`0003?o03?o000><ol000?o09Tco`0co`005c?o00030000oooooooo
08_oool006Ooool200003c?o0003o`2I<ol0<ol001Hco`000`000?ooooooo`2<oooo001Woooo00<0
000co`0co`003S?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`2=oooo001Woooo00<0000co`0c
o`003S?o0003o`2I<ol0<ol001@co`000`000?ooooooo`2>oooo001Woooo00<0000co`0co`003S?o
0003o`2I<ol0<ol001<co`000`000?ooooooo`2?oooo001Woooo00<0000co`0co`003S?o0003o`2I
<ol0<ol0018co`000`000?ooooooo`2@oooo001Woooo00<0000co`0co`003S?o0003o`2I<ol0<ol0
018co`000`000?ooooooo`2@oooo001Woooo0P0000lco`000ol0VC?o03?o000A<ol000<0003ooooo
ool0TOooo`00Ioooo`030000<ol0<ol000hco`000ol0VC?o03?o000@<ol000<0003oooooool0T_oo
o`00Ioooo`030000<ol0<ol000hco`000ol0VC?o03?o000?<ol000<0003oooooool0Toooo`00Iooo
o`030000<ol0<ol000hco`000ol0VC?o03?o000?<ol000<0003oooooool0Toooo`00Ioooo`030000
<ol0<ol000hco`000ol0VC?o03?o000><ol000<0003oooooool0U?ooo`00Goooo`D00003oooo00<0
000co`0co`003S?o0003o`2I<ol0<ol000hco`000`000?ooooooo`2Doooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol000hco`000ol0VC?o03?o000=<ol000<0003oooooool0UOooo`00HOoo
o`030000oooooooo00?oool200003c?o0003o`2I<ol0<ol000dco`000`000?ooooooo`2Eoooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol000hco`000ol0VC?o03?o000<<ol000<0003ooooo
ool0U_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000><ol000?o09Tco`0co`0033?o
00030000oooooooo09Koool0063oool200001Oooo`030000<ol0<ol000hco`000ol0VC?o03?o000;
<ol000<0003oooooool0Uoooo`00Ioooo`030000<ol0<ol000hco`000ol0VC?o03?o000;<ol000<0
003oooooool0Uoooo`00Ioooo`030000<ol0<ol000hco`000ol0VC?o03?o000:<ol000<0003ooooo
ool0V?ooo`00Ioooo`80000?<ol000?o09Tco`0co`002S?o00030000oooooooo09Soool006Ooool0
0`0003?o03?o000><ol000?o09Tco`0co`002C?o00030000oooooooo09Woool006Ooool00`0003?o
03?o000><ol000?o09Tco`0co`002C?o00030000oooooooo09Woool006Ooool00`0003?o03?o000>
<ol000?o09Tco`0co`0023?o00030000oooooooo09[oool006Ooool00`0003?o03?o000><ol000?o
09Tco`0co`0023?o00030000oooooooo09[oool006Ooool00`0003?o03?o000><ol000?o09Tco`0c
o`001c?o00030000oooooooo09_oool006Ooool200003c?o0003o`2I<ol0<ol000Lco`000`000?oo
ooooo`2Koooo001Woooo00<0000co`0co`003S?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`2L
oooo001Woooo00<0000co`0co`003S?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`2Loooo001W
oooo00<0000co`0co`003S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Moooo001Woooo00<0
000co`0co`003S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Moooo001Woooo00<0000co`0c
o`003S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Moooo001Woooo00<0000co`0co`003S?o
0003o`2I<ol0<ol000@co`000`000?ooooooo`2Noooo001Woooo0P0000lco`000ol0VC?o03?o0004
<ol000<0003oooooool0W_ooo`00Ioooo`030000<ol0<ol000hco`000ol0VC?o03?o0004<ol000<0
003oooooool0W_ooo`00Ioooo`030000<ol0<ol000hco`000ol0VC?o03?o0004<ol000<0003ooooo
ool0W_ooo`00Ioooo`030000<ol0<ol000hco`000ol0VC?o03?o0003<ol000<0003oooooool0Wooo
o`00Ioooo`030000<ol0<ol000hco`000ol0VC?o03?o0003<ol000<0003oooooool0Woooo`00Iooo
o`030000<ol0<ol000hco`000ol0VC?o03?o0003<ol000<0003oooooool0Woooo`00Ioooo`80000?
<ol000?o09Tco`0co`000c?o00030000oooooooo09ooool006Ooool00`0003?o03?o000><ol000?o
09Tco`0co`000S?o00030000oooooooo0:3oool006Ooool00`0003?o03?o000><ol000?o09Tco`0c
o`000S?o00030000oooooooo0:3oool006Ooool00`0003?o03?o000><ol000?o09Tco`0co`000S?o
00030000oooooooo0:3oool005ooool400001?ooo`030000<ol0<ol000hco`000ol0VC?o03?o0002
<ol000<0003oooooool0X?ooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000><ol000Go
09Tco`0co`0co`000000Xoooo`00H?ooo`030000oooooooo00Coool200003c?o0005o`2I<ol0<ol0
<ol000000:?oool0067oool00`000?ooooooo`03oooo00<0000co`0co`003S?o0005o`2I<ol0<ol0
<ol000000:?oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000><ol000Co09Tco`0c
o`00002Toooo001Poooo0P0000Goool00`0003?o03?o000><ol000Co09Tco`0co`00002Toooo001W
oooo00<0000co`0co`003S?o0004o`2I<ol0<ol00000Y?ooo`00Ioooo`030000<ol0<ol000hco`00
1?l0VC?o03?o00000:Coool006Ooool200003c?o0003o`2I<ol000000:Goool006Ooool00`0003?o
03?o000><ol000?o09Tco`000000YOooo`00Ioooo`030000<ol0<ol000hco`000ol0VC?o0000002U
oooo001Woooo00<0000co`0co`003S?o0003o`2I<ol000000:Goool006Ooool00`0003?o03?o000>
<ol000?o09T0003oool0YOooo`00Ioooo`030000<ol0<ol000hco`000ol0V@000?ooo`2Uoooo001W
oooo00<0000co`0co`003S?o0003o`2I0000oooo0:Goool006Ooool200003c?o0003o`2I0000oooo
0:Goool006Ooool00`0003?o03?o000><ol000?o09Woooooool0YOooo`00Ioooo`030000<ol0<ol0
00hco`000ol0VOooooooo`2Uoooo001Woooo00<0000co`0co`003S?o0003o`2Ioooooooo0:Goool0
06Ooool00`0003?o03?o000><ol000?o09Woooooool0YOooo`00Ioooo`030000<ol0<ol000dco`00
0`000?l0VOooo`2Voooo001Woooo0P0000hco`000`000?l0VOooo`2Voooo001Woooo00<0000co`0c
o`003C?o00030000o`2Ioooo0:Koool006Ooool00`0003?o03?o000=<ol000<0003o09Woool0Y_oo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooool0V@2Woooo001Woooo00<0000co`0co`0033?o
00030000ooooo`2I0:Ooool006Ooool00`0003?o03?o000<<ol000<0003ooooo09T0Yoooo`00Iooo
o`80000=<ol000<0003ooooo09T0Yoooo`00Ioooo`030000<ol0<ol000`co`000`000?ooool0V@2W
oooo001Woooo00<0000co`0co`0033?o00030000ooooo`2I0:Ooool006Ooool00`0003?o03?o000;
<ol000@0003ooooooooo09VWoooo001Poooo0P0000Goool00`0003?o03?o000;<ol000@0003ooooo
oooo09VWoooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00040000oooooooo
o`2IYoooo`00HOooo`030000oooooooo00?oool2000033?o00040000ooooooooo`2IYoooo`00H_oo
o`030000oooooooo00;oool00`0003?o03?o000;<ol000@0003ooooooooo09VWoooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`002c?o00040000ooooooooo`2IYoooo`00H?ooo`800005
oooo00<0000co`0co`002S?o00050000ooooooooooooo`2I0:Ooool006Ooool00`0003?o03?o000:
<ol000D0003ooooooooooooo09T0Yoooo`00Ioooo`030000<ol0<ol000Xco`001@000?oooooooooo
ool0V@2Woooo001Woooo00<0000co`0co`002S?o00050000ooooooooooooo`2I0:Ooool006Ooool2
00002c?o00050000ooooooooooooo`2I0:Ooool006Ooool00`0003?o03?o000:<ol000D0003ooooo
oooooooo09T0Yoooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`02oooo00?o09Wooooo
ool0YOooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`02oooo00?o09Woooooool0YOoo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`02oooo00?o09Woooooool0YOooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`02oooo00?o09Woooooool0YOooo`00Ioooo`80000:
<ol000<0003oooooool00_ooo`03o`2Ioooooooo0:Goool006Ooool00`0003?o03?o0009<ol000<0
003oooooool00_ooo`03o`2Ioooooooo0:Goool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool00_ooo`03o`2Ioooooooo0:Goool006Ooool00`0003?o03?o0008<ol000<0003oooooool00ooo
o`03o`2Ioooooooo0:Goool006Ooool00`0003?o03?o0008<ol000<0003oooooool00oooo`03o`2I
oooooooo0:Goool006Ooool00`0003?o03?o0008<ol000<0003oooooool00oooo`03o`2Ioooooooo
0:Goool006Ooool200002C?o00030000oooooooo00?oool00ol0VOooooooo`2Uoooo001Woooo00<0
000co`0co`0023?o00030000oooooooo00?oool00ol0VOooooooo`2Uoooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo00?oool00ol0VOooooooo`2Uoooo001Woooo00<0000co`0co`001c?o
00030000oooooooo00Coool00ol0VOooooooo`2Uoooo001Woooo00<0000co`0co`001c?o00030000
oooooooo00Coool00ol0VOooooooo`2Uoooo001Woooo00<0000co`0co`001c?o00030000oooooooo
00Coool00ol0VOooooooo`2Uoooo001Woooo0P0000Pco`000`000?ooooooo`04oooo00?o09Wooooo
ool0YOooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`04oooo00?o09Woooooool0YOoo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`04oooo00?o09Woooooool0YOooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`04oooo00?o09Woooooool0YOooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`04oooo00?o09Woooooool0YOooo`00HOooo`<00003oooo00<0
000co`0co`001c?o00030000oooooooo00Coool00ol0VOooooooo`2Uoooo001Roooo00<0003ooooo
ool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`04oooo00?o09Woooooool0YOooo`00Gooo
o`D00003oooo0P0000Pco`000`000?ooooooo`04oooo00?o09Woooooool0YOooo`00Goooo`040000
oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P00
00Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Oooo`030000
oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo100000;oool400000oooo`030000
oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool0N?ooo`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000
oooooooo00goool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo07Ooool006Ooool9<ol02?ooo`030000oooooooo00D0000<oooo00@0003ooooo
ool0000:oooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0
003oooooool04Oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Woool006Ooool9
<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40134 .12361 L
.41134 .12361 L
.41408 .12361 L
.4156 .12361 L
.41634 .12361 L
.41703 .12361 L
s
.41703 .12361 m
.41729 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.25666 .12361 L
.26171 .12361 L
.26301 .12361 L
.26425 .12361 L
.26493 .12361 L
.26568 .12314 L
.26698 .12214 L
.27279 .11782 L
.28302 .11077 L
.30316 .09882 L
.3438 .08123 L
.38293 .06827 L
.39322 .06512 L
.40434 .06185 L
.40945 .0604 L
.41224 .05963 L
.41485 .05891 L
.41599 .0586 L
.41707 .0583 L
.41832 .12361 L
.41945 .12361 L
.42451 .12361 L
.46284 .12361 L
.50362 .12361 L
.54289 .12361 L
.58064 .12361 L
.62084 .12361 L
.65953 .12361 L
.70067 .12361 L
.7403 .12361 L
.7784 .12361 L
.81897 .12361 L
.85801 .12361 L
.89951 .12361 L
.93949 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool0]_ooo`00Iooo
o`030000oooooooo00koool306KoYOooo`00Ioooo`030000oooooooo00coool206Ko0_ooo`0306Ko
oooooooo0:?oool006Ooool00`000?ooooooo`06oooo1P1Vo`Coool00`1Vooooooooo`2Soooo001W
oooo00<0003oooooool01?ooo`80I_l:oooo00<0I_ooooooool0Xoooo`00Ioooo`800002oooo0`1V
o`coool00`1Vooooooooo`2Soooo000Goooo1@0001koool200001?ooo`800004oooo0P0001ooool0
10000?ooo`1Vo`1Vo`ooool00`1Vooooooooo`0;oooo0P0000Coool200001?ooo`80000Ooooo1@00
01goool500000_ooo`800004oooo0P00023oool400005_ooo`006Oooo`030000oooooooo01goool0
10000?ooooooo`0000Soool010000?ooooooo`0001goool00`1Vo`00001Vo`0Aoooo00<0I_oooooo
ool02_ooo`040000oooooooo00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool0
0`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000
oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0Ioooo0P1Vo`03oooo0000oooo
017oool00`1Vooooooooo`0:oooo00@0003oooooool0000;oooo00<0003oooooool07_ooo`030000
oooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Oooo`80000I
oooo0`1Vo`?oool00`000?ooooooo`0@oooo00<0I_ooooooool02_ooo`040000oooooooo00002Ooo
o`80000Qoooo00<0003oooooool07oooo`030000oooooooo00Soool200008_ooo`030000oooooooo
01Goool001Woool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool05_oo
o`80I_l6oooo00<0003oooooool04?ooo`0306Kooooooooo00[oool010000?ooooooo`0000Woool0
0`000?ooooooo`0Poooo00<0003oooooool07oooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00@0003oooooool0000Foooo000Hoooo0P00023oool200002_ooo`<0000Doooo0P1Vo`Soool2
00004Oooo`0306Kooooooooo00_oool200002_ooo`<0000Ooooo0P00023oool200002_ooo`<0000P
oooo0P0001Ooool005_oool206Ko2_ooo`030000oooooooo013oool00`1Vooooooooo`2Soooo001I
oooo0P1Vo`coool00`000?ooooooo`0@oooo00<0I_ooooooool0Xoooo`00F?ooo`0306Kooooooooo
00coool00`000?ooooooo`0@oooo00<0I_ooooooool0Xoooo`00E_ooo`80I_l?oooo00<0003ooooo
ool04?ooo`0306Kooooooooo0:?oool005Goool00`1Vooooooooo`0?oooo00<0003oooooool04?oo
o`0306Kooooooooo0:?oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00040000<ol0<ol0
o`2I13?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0000co`0co`0043?o0003o`2I<ol0<ol0018co`000`0003?o
03?o000T<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000
<ol0<ol0010co`000ol0VC?o03?o000d<ol01@0006[oool006Ooool00`0003?o03?o000@<ol000?o
09Tco`0co`00;c?o00D0001_oooo001Woooo00<0000co`0co`0043?o0003o`2I<ol0<ol002Xco`05
0000M?ooo`00Ioooo`030000<ol0<ol0010co`000ol0VC?o03?o000V<ol0100007Woool006Ooool2
00004C?o0003o`2I<ol0<ol002@co`020000OOooo`00Ioooo`030000<ol0<ol0010co`000ol0VC?o
03?o000R<ol00P0007ooool006Ooool00`0003?o03?o000@<ol000?o09Tco`0co`0083?o00800021
oooo001Woooo00<0000co`0co`0043?o0003o`2I<ol0<ol001hco`020000Poooo`00Ioooo`030000
<ol0<ol0010co`000ol0VC?o03?o000M<ol000<0003oooooool0Poooo`00Ioooo`030000<ol0<ol0
010co`000ol0VC?o03?o000K<ol00P0008Koool006Ooool200004C?o0003o`2I<ol0<ol001Tco`02
0000R?ooo`00Ioooo`030000<ol0<ol0010co`000ol0VC?o03?o000H<ol000<0003oooooool0R?oo
o`00Ioooo`030000<ol0<ol0010co`000ol0VC?o03?o000G<ol000<0003oooooool0ROooo`00Iooo
o`030000<ol0<ol0010co`000ol0VC?o03?o000F<ol000<0003oooooool0R_ooo`00Ioooo`030000
<ol0<ol0010co`000ol0VC?o03?o000E<ol000<0003oooooool0Roooo`00Ioooo`030000<ol0<ol0
010co`000ol0VC?o03?o000E<ol000<0003oooooool0Roooo`00Ioooo`80000A<ol000?o09Tco`0c
o`0053?o00030000oooooooo08coool006Ooool00`0003?o03?o000@<ol000?o09Tco`0co`004c?o
00030000oooooooo08goool006Ooool00`0003?o03?o000@<ol000?o09Tco`0co`004S?o00030000
oooooooo08koool006Ooool00`0003?o03?o000@<ol000?o09Tco`0co`004C?o00030000oooooooo
08ooool006Ooool00`0003?o03?o000@<ol000?o09Tco`0co`0043?o00030000oooooooo093oool0
06Ooool00`0003?o03?o000@<ol000?o09Tco`0co`0043?o00030000oooooooo093oool006Ooool2
00004C?o0003o`2I<ol0<ol000lco`000`000?ooooooo`2Aoooo001Woooo00<0000co`0co`0043?o
0003o`2I<ol0<ol000hco`000`000?ooooooo`2Boooo001Woooo00<0000co`0co`0043?o0003o`2I
<ol0<ol000dco`000`000?ooooooo`2Coooo001Woooo00<0000co`0co`0043?o0003o`2I<ol0<ol0
00dco`000`000?ooooooo`2Coooo001Woooo00<0000co`0co`0043?o0003o`2I<ol0<ol000`co`00
0`000?ooooooo`2Doooo001Ooooo1@0000?oool00`0003?o03?o000@<ol000?o09Tco`0co`0033?o
00030000oooooooo09Coool0067oool00`000?ooooooo`03oooo00<0000co`0co`0043?o0003o`2I
<ol0<ol000/co`000`000?ooooooo`2Eoooo001Qoooo00<0003oooooool00oooo`80000A<ol000?o
09Tco`0co`002c?o00030000oooooooo09Goool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`0043?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`2Foooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol0010co`000ol0VC?o03?o000:<ol000<0003oooooool0U_ooo`00H?ooo`800005
oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`2Goooo001Woooo00<0
000co`0co`0043?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`2Goooo001Woooo00<0000co`0c
o`0043?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`2Hoooo001Woooo0P00014co`000ol0VC?o
03?o0008<ol000<0003oooooool0V?ooo`00Ioooo`030000<ol0<ol0010co`000ol0VC?o03?o0007
<ol000<0003oooooool0VOooo`00Ioooo`030000<ol0<ol0010co`000ol0VC?o03?o0007<ol000<0
003oooooool0VOooo`00Ioooo`030000<ol0<ol0010co`000ol0VC?o03?o0006<ol000<0003ooooo
ool0V_ooo`00Ioooo`030000<ol0<ol0010co`000ol0VC?o03?o0006<ol000<0003oooooool0V_oo
o`00Ioooo`030000<ol0<ol0010co`000ol0VC?o03?o0005<ol000<0003oooooool0Voooo`00Iooo
o`80000A<ol000?o09Tco`0co`001C?o00030000oooooooo09_oool006Ooool00`0003?o03?o000@
<ol000?o09Tco`0co`0013?o00030000oooooooo09coool006Ooool00`0003?o03?o000@<ol000?o
09Tco`0co`0013?o00030000oooooooo09coool006Ooool00`0003?o03?o000@<ol000?o09Tco`0c
o`000c?o00030000oooooooo09goool006Ooool00`0003?o03?o000@<ol000?o09Tco`0co`000c?o
00030000oooooooo09goool006Ooool00`0003?o03?o000@<ol000?o09Tco`0co`000c?o00030000
oooooooo09goool006Ooool00`0003?o03?o000@<ol000?o09Tco`0co`000S?o00030000oooooooo
09koool006Ooool200004C?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Noooo001Woooo00<0
000co`0co`0043?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Noooo001Woooo00<0000co`0c
o`0043?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Noooo001Woooo00<0000co`0co`0043?o
0005o`2I<ol0<ol0<ol000000:7oool006Ooool00`0003?o03?o000@<ol000Go09Tco`0co`0co`00
0000XOooo`00Ioooo`030000<ol0<ol0010co`001Ol0VC?o03?o03?o0000002Qoooo001Woooo0P00
014co`001Ol0VC?o03?o03?o0000002Qoooo001Woooo00<0000co`0co`0043?o0004o`2I<ol0<ol0
0000X_ooo`00Ioooo`030000<ol0<ol0010co`001?l0VC?o03?o00000:;oool006Ooool00`0003?o
03?o000@<ol000Co09Tco`0co`00002Roooo001Ooooo100000Coool00`0003?o03?o000@<ol000Co
09Tco`0co`00002Roooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0010co`000ol0VC?o
0000002Soooo001Poooo00<0003oooooool01?ooo`80000A<ol000?o09Tco`000000Xoooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000@<ol000?o09Tco`000000Xoooo`00Goooo`040000
oooooooo00001?ooo`030000<ol0<ol0010co`000ol0V@000?ooo`2Soooo001Poooo0P0000Goool0
0`0003?o03?o000@<ol000?o09T0003oool0Xoooo`00Ioooo`030000<ol0<ol0010co`000ol0V@00
0?ooo`2Soooo001Woooo00<0000co`0co`0043?o0003o`2I0000oooo0:?oool006Ooool200004C?o
0003o`2Ioooooooo0:?oool006Ooool00`0003?o03?o000@<ol000?o09Woooooool0Xoooo`00Iooo
o`030000<ol0<ol0010co`000ol0VOooooooo`2Soooo001Woooo00<0000co`0co`0043?o0003o`2I
oooooooo0:?oool006Ooool00`0003?o03?o000?<ol000<0003o09Woool0Y?ooo`00Ioooo`030000
<ol0<ol000lco`000`000?l0VOooo`2Toooo001Woooo00<0000co`0co`003c?o00030000o`2Ioooo
0:Coool006Ooool2000043?o00030000o`2Ioooo0:Coool006Ooool00`0003?o03?o000><ol000<0
003ooooo09T0YOooo`00Ioooo`030000<ol0<ol000hco`000`000?ooool0V@2Uoooo001Woooo00<0
000co`0co`003S?o00030000ooooo`2I0:Goool006Ooool00`0003?o03?o000><ol000<0003ooooo
09T0YOooo`00Ioooo`030000<ol0<ol000dco`0010000?ooooooool0VJGoool006Ooool200003S?o
00040000ooooooooo`2IYOooo`00Ioooo`030000<ol0<ol000dco`0010000?ooooooool0VJGoool0
06Ooool00`0003?o03?o000=<ol000@0003ooooooooo09VUoooo001Woooo00<0000co`0co`0033?o
00050000ooooooooooooo`2I0:Goool006Ooool00`0003?o03?o000<<ol000D0003ooooooooooooo
09T0YOooo`00Ioooo`030000<ol0<ol000`co`001@000?ooooooooooool0V@2Uoooo001Woooo0P00
00dco`001@000?ooooooooooool0V@2Uoooo001Woooo00<0000co`0co`0033?o00050000oooooooo
ooooo`2I0:Goool006Ooool00`0003?o03?o000<<ol000D0003ooooooooooooo09T0YOooo`00Iooo
o`030000<ol0<ol000/co`000`000?ooooooo`02oooo00?o09Woooooool0Xoooo`00H?ooo`800005
oooo00<0000co`0co`002c?o00030000oooooooo00;oool00ol0VOooooooo`2Soooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo00;oool00ol0VOooooooo`2S
oooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0003oooooool00_ooo`03o`2Ioooooooo
0:?oool006;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo00;oool0
0ol0VOooooooo`2Soooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000
oooooooo00;oool00ol0VOooooooo`2Soooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0
003oooooool00oooo`03o`2Ioooooooo0:?oool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool00oooo`03o`2Ioooooooo0:?oool006Ooool00`0003?o03?o000:<ol000<0003oooooool00ooo
o`03o`2Ioooooooo0:?oool006Ooool00`0003?o03?o000:<ol000<0003oooooool00oooo`03o`2I
oooooooo0:?oool006Ooool200002c?o00030000oooooooo00?oool00ol0VOooooooo`2Soooo001W
oooo00<0000co`0co`002S?o00030000oooooooo00?oool00ol0VOooooooo`2Soooo001Woooo00<0
000co`0co`002C?o00030000oooooooo00Coool00ol0VOooooooo`2Soooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo00Coool00ol0VOooooooo`2Soooo001Woooo00<0000co`0co`002C?o
00030000oooooooo00Coool00ol0VOooooooo`2Soooo001Woooo00<0000co`0co`002C?o00030000
oooooooo00Coool00ol0VOooooooo`2Soooo001Woooo0P0000Xco`000`000?ooooooo`04oooo00?o
09Woooooool0Xoooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`04oooo00?o09Wooooo
ool0Xoooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`04oooo00?o09Woooooool0Xooo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`05oooo00?o09Woooooool0Xoooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`05oooo00?o09Woooooool0Xoooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`05oooo00?o09Woooooool0Xoooo`00Ioooo`800009<ol000<0
003oooooool01Oooo`03o`2Ioooooooo0:?oool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool01Oooo`03o`2Ioooooooo0:?oool006Ooool00`0003?o03?o0008<ol000<0003oooooool01Ooo
o`03o`2Ioooooooo0:?oool006Ooool00`0003?o03?o0007<ol000<0003oooooool01_ooo`03o`2I
oooooooo0:?oool006Ooool00`0003?o03?o0007<ol000<0003oooooool01_ooo`03o`2Ioooooooo
0:?oool006Ooool00`0003?o03?o0007<ol000<0003oooooool01_ooo`03o`2Ioooooooo0:?oool0
06Ooool2000023?o00030000oooooooo00Koool00ol0VOooooooo`2Soooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo00Koool00ol0VOooooooo`2Soooo001Woooo00<0000co`0co`001c?o
00030000oooooooo00Koool00ol0VOooooooo`2Soooo001Woooo00<0000co`0co`001c?o00030000
oooooooo00Koool00ol0VOooooooo`2Soooo001Woooo00<0000co`0co`001c?o00030000oooooooo
00Koool00ol0VOooooooo`2Soooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo0:?oool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o
00030000oooooooo00Koool00ol0VOooooooo`2Soooo001Ooooo1@0000?oool2000023?o00030000
oooooooo00Koool00ol0VOooooooo`2Soooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0
063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o
0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo
07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000?oool400001?ooo`<00002oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00<0003oooooool01_ooo`050000oooooooooooo000007[oool006Ooool9
<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00009oooo00<0
003oooooool00_ooo`D00003oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00D0003ooooo
ooooool00000N_ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000003oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001W
oooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000[oool200001Oooo`800002oooo00<0003ooooo
ool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.41696 .12361 L
.41976 .12361 L
.42113 .12361 L
.42237 .12361 L
.42363 .12361 L
s
.42363 .12361 m
.42411 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.24276 .12361 L
.24754 .12361 L
.25261 .12361 L
.2547 .12361 L
.25694 .12361 L
.25823 .12361 L
.2594 .12308 L
.26059 .12217 L
.26171 .12132 L
.2999 .09719 L
.31958 .08801 L
.34055 .0802 L
.38213 .06717 L
.403 .06114 L
.41215 .05864 L
.417 .05736 L
.41967 .05666 L
.42098 .05632 L
.4222 .05601 L
.42337 .05571 L
.42463 .12361 L
.42588 .12361 L
.42727 .12361 L
.43189 .12361 L
.44094 .12361 L
.46075 .12361 L
.50095 .12361 L
.53964 .12361 L
.58078 .12361 L
.6204 .12361 L
.65851 .12361 L
.69907 .12361 L
.73812 .12361 L
.77961 .12361 L
.8196 .12361 L
.85806 .12361 L
.89898 .12361 L
.93838 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool04Oooo`80I_nS
oooo001Woooo00<0003oooooool03_ooo`<0I_l00oooo`1Vooooo`2Roooo001Woooo00<0003ooooo
ool02_ooo`@0I_l4oooo00<0I_ooooooool0XOooo`00Ioooo`030000oooooooo00Koool406Ko2?oo
o`0306Kooooooooo0:7oool006Ooool00`000?ooooooo`03oooo0`1Vo`coool00`1Vooooooooo`2Q
oooo001Woooo0P0000@0I_l?oooo00<0I_ooooooool0XOooo`005oooo`D0000Noooo0P0000Coool2
00001?ooo`80000Noooo00<0I_l00000I_l04oooo`0306Kooooooooo00Woool200001?ooo`800004
oooo0P0001ooool500007Oooo`D00002oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00006_ooo`<0I_l00oooo`00
0?ooo`0Coooo00<0I_ooooooool02?ooo`040000oooooooo00002?ooo`040000oooooooo00008?oo
o`030000oooooooo01ooool00`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003ooooo
ool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0F
oooo0P1Vo`Coool00`000?ooooooo`0Boooo00<0I_ooooooool02?ooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200005oooo`80I_l6oooo00<0003oooooool04_ooo`0306Kooooooooo
00Soool010000?ooooooo`0000Woool200008Oooo`030000oooooooo01ooool00`000?ooooooo`08
oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`030000oooooooo01Coool206Ko2?ooo`030000oooooooo01;oool00`1Vooooooooo`08
oooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo01ooool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P00
00[oool300004oooo`0306Kooooooooo00Soool200004oooo`0306Kooooooooo00Woool200002_oo
o`<0000Ooooo0P00023oool200002_ooo`<0000Poooo0P0001Ooool005[oool206Ko2oooo`030000
oooooooo01;oool00`1Vooooooooo`2Qoooo001Ioooo00<0I_ooooooool02oooo`030000oooooooo
01;oool00`1Vooooooooo`2Qoooo001Goooo0P1Vo`koool00`000?ooooooo`0Boooo00<0I_oooooo
ool0XOooo`00E_ooo`0306Kooooooooo00koool00`000?ooooooo`0Boooo00<0I_ooooooool0XOoo
o`00E?ooo`80I_lAoooo00<0003oooooool04_ooo`0306Kooooooooo0:7oool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol0008co`001?l0VC?o03?o000000Lco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o
02P00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0c
o`004S?o0003o`2I<ol0<ol0010co`000`0003?o03?o000T<ol0400001Woool00`000?ooooooo`0V
oooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol0018co`000ol0VC?o03?o000b<ol01@00
06[oool006Ooool00`0003?o03?o000B<ol000?o09Tco`0co`00;C?o00D0001_oooo001Woooo00<0
000co`0co`004S?o0003o`2I<ol0<ol002Pco`050000M?ooo`00Ioooo`030000<ol0<ol0018co`00
0ol0VC?o03?o000T<ol0100007Woool006Ooool200004c?o0003o`2I<ol0<ol0028co`020000OOoo
o`00Ioooo`030000<ol0<ol0018co`000ol0VC?o03?o000P<ol00P0007ooool006Ooool00`0003?o
03?o000B<ol000?o09Tco`0co`007S?o00800021oooo001Woooo00<0000co`0co`004S?o0003o`2I
<ol0<ol001`co`020000Poooo`00Ioooo`030000<ol0<ol0018co`000ol0VC?o03?o000K<ol000<0
003oooooool0Poooo`00Ioooo`030000<ol0<ol0018co`000ol0VC?o03?o000I<ol00P0008Koool0
06Ooool200004c?o0003o`2I<ol0<ol001Lco`020000R?ooo`00Ioooo`030000<ol0<ol0018co`00
0ol0VC?o03?o000F<ol000<0003oooooool0R?ooo`00Ioooo`030000<ol0<ol0018co`000ol0VC?o
03?o000E<ol000<0003oooooool0ROooo`00Ioooo`030000<ol0<ol0018co`000ol0VC?o03?o000D
<ol000<0003oooooool0R_ooo`00Ioooo`030000<ol0<ol0018co`000ol0VC?o03?o000C<ol000<0
003oooooool0Roooo`00Ioooo`030000<ol0<ol0018co`000ol0VC?o03?o000C<ol000<0003ooooo
ool0Roooo`00Ioooo`80000C<ol000?o09Tco`0co`004S?o00030000oooooooo08coool006Ooool0
0`0003?o03?o000B<ol000?o09Tco`0co`004C?o00030000oooooooo08goool006Ooool00`0003?o
03?o000B<ol000?o09Tco`0co`0043?o00030000oooooooo08koool006Ooool00`0003?o03?o000B
<ol000?o09Tco`0co`003c?o00030000oooooooo08ooool006Ooool00`0003?o03?o000B<ol000?o
09Tco`0co`003S?o00030000oooooooo093oool006Ooool00`0003?o03?o000B<ol000?o09Tco`0c
o`003S?o00030000oooooooo093oool006Ooool200004c?o0003o`2I<ol0<ol000dco`000`000?oo
ooooo`2Aoooo001Woooo00<0000co`0co`004S?o0003o`2I<ol0<ol000`co`000`000?ooooooo`2B
oooo001Woooo00<0000co`0co`004S?o0003o`2I<ol0<ol000/co`000`000?ooooooo`2Coooo001W
oooo00<0000co`0co`004S?o0003o`2I<ol0<ol000/co`000`000?ooooooo`2Coooo001Woooo00<0
000co`0co`004S?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`2Doooo001Ooooo1@0000?oool0
0`0003?o03?o000B<ol000?o09Tco`0co`002S?o00030000oooooooo09Coool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`004S?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`2Eoooo001Q
oooo00<0003oooooool00oooo`80000C<ol000?o09Tco`0co`002C?o00030000oooooooo09Goool0
067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o0003o`2I<ol0<ol000Pco`000`000?oo
ooooo`2Foooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000ol0VC?o03?o0008
<ol000<0003oooooool0U_ooo`00H?ooo`800005oooo00<0000co`0co`004S?o0003o`2I<ol0<ol0
00Lco`000`000?ooooooo`2Goooo001Woooo00<0000co`0co`004S?o0003o`2I<ol0<ol000Lco`00
0`000?ooooooo`2Goooo001Woooo00<0000co`0co`004S?o0003o`2I<ol0<ol000Hco`000`000?oo
ooooo`2Hoooo001Woooo0P0001<co`000ol0VC?o03?o0006<ol000<0003oooooool0V?ooo`00Iooo
o`030000<ol0<ol0018co`000ol0VC?o03?o0005<ol000<0003oooooool0VOooo`00Ioooo`030000
<ol0<ol0018co`000ol0VC?o03?o0005<ol000<0003oooooool0VOooo`00Ioooo`030000<ol0<ol0
018co`000ol0VC?o03?o0004<ol000<0003oooooool0V_ooo`00Ioooo`030000<ol0<ol0018co`00
0ol0VC?o03?o0004<ol000<0003oooooool0V_ooo`00Ioooo`030000<ol0<ol0018co`000ol0VC?o
03?o0003<ol000<0003oooooool0Voooo`00Ioooo`80000C<ol000?o09Tco`0co`000c?o00030000
oooooooo09_oool006Ooool00`0003?o03?o000B<ol000?o09Tco`0co`000S?o00030000oooooooo
09coool006Ooool00`0003?o03?o000B<ol000?o09Tco`0co`000S?o00030000oooooooo09coool0
06Ooool00`0003?o03?o000B<ol000Go09Tco`0co`0co`000000Woooo`00Ioooo`030000<ol0<ol0
018co`001Ol0VC?o03?o03?o0000002Ooooo001Woooo00<0000co`0co`004S?o0005o`2I<ol0<ol0
<ol0000009ooool006Ooool00`0003?o03?o000B<ol000Co09Tco`0co`00002Poooo001Woooo0P00
01<co`001?l0VC?o03?o00000:3oool006Ooool00`0003?o03?o000B<ol000Co09Tco`0co`00002P
oooo001Woooo00<0000co`0co`004S?o0004o`2I<ol0<ol00000X?ooo`00Ioooo`030000<ol0<ol0
018co`000ol0VC?o0000002Qoooo001Woooo00<0000co`0co`004S?o0003o`2I<ol000000:7oool0
06Ooool00`0003?o03?o000B<ol000?o09Tco`000000XOooo`00Ioooo`80000C<ol000?o09Tco`00
0000XOooo`00Ioooo`030000<ol0<ol0018co`000ol0V@000?ooo`2Qoooo001Woooo00<0000co`0c
o`004S?o0003o`2I0000oooo0:7oool006Ooool00`0003?o03?o000B<ol000?o09T0003oool0XOoo
o`00Goooo`@00004oooo00<0000co`0co`004S?o0003o`2I0000oooo0:7oool005ooool00`000?oo
ooooo`05oooo00<0000co`0co`004S?o0003o`2Ioooooooo0:7oool0063oool00`000?ooooooo`04
oooo0P0001<co`000ol0VOooooooo`2Qoooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
018co`000ol0VOooooooo`2Qoooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000o`2Ioooo0:;oool0063oool200001Oooo`030000<ol0<ol0014co`000`000?l0VOooo`2R
oooo001Woooo00<0000co`0co`004C?o00030000o`2Ioooo0:;oool006Ooool00`0003?o03?o000A
<ol000<0003o09Woool0X_ooo`00Ioooo`80000A<ol000<0003ooooo09T0Xoooo`00Ioooo`030000
<ol0<ol0010co`000`000?ooool0V@2Soooo001Woooo00<0000co`0co`0043?o00030000ooooo`2I
0:?oool006Ooool00`0003?o03?o000@<ol000<0003ooooo09T0Xoooo`00Ioooo`030000<ol0<ol0
00lco`0010000?ooooooool0VJ?oool006Ooool00`0003?o03?o000?<ol000@0003ooooooooo09VS
oooo001Woooo00<0000co`0co`003c?o00040000ooooooooo`2IXoooo`00Ioooo`80000@<ol000@0
003ooooooooo09VSoooo001Woooo00<0000co`0co`003S?o00050000ooooooooooooo`2I0:?oool0
06Ooool00`0003?o03?o000><ol000D0003ooooooooooooo09T0Xoooo`00Ioooo`030000<ol0<ol0
00hco`001@000?ooooooooooool0V@2Soooo001Woooo00<0000co`0co`003S?o00050000oooooooo
ooooo`2I0:?oool006Ooool00`0003?o03?o000=<ol000<0003oooooool00_ooo`03o`2Ioooooooo
0:7oool006Ooool200003S?o00030000oooooooo00;oool00ol0VOooooooo`2Qoooo001Woooo00<0
000co`0co`003C?o00030000oooooooo00;oool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0c
o`003C?o00030000oooooooo00;oool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0co`0033?o
00030000oooooooo00?oool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0co`0033?o00030000
oooooooo00?oool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0co`0033?o00030000oooooooo
00?oool00ol0VOooooooo`2Qoooo001Woooo0P0000dco`000`000?ooooooo`03oooo00?o09Wooooo
ool0XOooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`03oooo00?o09Woooooool0XOoo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`03oooo00?o09Woooooool0XOooo`00Iooo
o`030000<ol0<ol000/co`000`000?ooooooo`04oooo00?o09Woooooool0XOooo`00H?ooo`800005
oooo00<0000co`0co`002c?o00030000oooooooo00Coool00ol0VOooooooo`2Qoooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo00Coool00ol0VOooooooo`2Q
oooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0003oooooool01?ooo`03o`2Ioooooooo
0:7oool006;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo00Coool0
0ol0VOooooooo`2Qoooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000
oooooooo00Coool00ol0VOooooooo`2Qoooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0
003oooooool01Oooo`03o`2Ioooooooo0:7oool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool01Oooo`03o`2Ioooooooo0:7oool006Ooool00`0003?o03?o000:<ol000<0003oooooool01Ooo
o`03o`2Ioooooooo0:7oool006Ooool00`0003?o03?o000:<ol000<0003oooooool01Oooo`03o`2I
oooooooo0:7oool006Ooool200002c?o00030000oooooooo00Goool00ol0VOooooooo`2Qoooo001W
oooo00<0000co`0co`002S?o00030000oooooooo00Goool00ol0VOooooooo`2Qoooo001Woooo00<0
000co`0co`002C?o00030000oooooooo00Koool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo00Koool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0co`002C?o
00030000oooooooo00Koool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0co`002C?o00030000
oooooooo00Koool00ol0VOooooooo`2Qoooo001Woooo0P0000Xco`000`000?ooooooo`06oooo00?o
09Woooooool0XOooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`06oooo00?o09Wooooo
ool0XOooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`06oooo00?o09Woooooool0XOoo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`07oooo00?o09Woooooool0XOooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`07oooo00?o09Woooooool0XOooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`07oooo00?o09Woooooool0XOooo`00Ioooo`800009<ol000<0
003oooooool01oooo`03o`2Ioooooooo0:7oool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo0:7oool006Ooool00`0003?o03?o0008<ol000<0003oooooool01ooo
o`03o`2Ioooooooo0:7oool006Ooool00`0003?o03?o0007<ol000<0003oooooool02?ooo`03o`2I
oooooooo0:7oool006Ooool00`0003?o03?o0007<ol000<0003oooooool02?ooo`03o`2Ioooooooo
0:7oool006Ooool00`0003?o03?o0007<ol000<0003oooooool02?ooo`03o`2Ioooooooo0:7oool0
06Ooool2000023?o00030000oooooooo00Soool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo00Soool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0co`001c?o
00030000oooooooo00Soool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0co`001c?o00030000
oooooooo00Soool00ol0VOooooooo`2Qoooo001Woooo00<0000co`0co`001c?o00030000oooooooo
00Soool00ol0VOooooooo`2Qoooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003ooooo
ool02?ooo`03o`2Ioooooooo0:7oool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o
00030000oooooooo00Soool00ol0VOooooooo`2Qoooo001Ooooo1@0000?oool2000023?o00030000
oooooooo00Soool00ol0VOooooooo`2Qoooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0
063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o
0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo
07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000?oool400000_ooo`<00004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00000oooo`030000oooooooo
07Soool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003ooooo
ool00009oooo00<0003oooooool00_ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool0
06Ooool9<ol02?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000:oooo00@0003ooooo
ooooool300001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool3
00000_ooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.41696 .12361 L
.42237 .12361 L
.42482 .12361 L
.42744 .12361 L
.42821 .12361 L
.42894 .12361 L
.4296 .12361 L
s
.4296 .12361 m
.42988 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23739 .12361 L
.24276 .12361 L
.24745 .12361 L
.24873 .12361 L
.25012 .12361 L
.25142 .12361 L
.25261 .12343 L
.25377 .12253 L
.25484 .12171 L
.25728 .11988 L
.26171 .11666 L
.30084 .09356 L
.32225 .08442 L
.34242 .07763 L
.38097 .06627 L
.40052 .06083 L
.41087 .05808 L
.41658 .0566 L
.42198 .05524 L
.42709 .05398 L
.42849 .05364 L
.42926 .05345 L
.42998 .05328 L
.43125 .12361 L
.43193 .12361 L
.43266 .12361 L
.4424 .12361 L
.46146 .12361 L
.5026 .12361 L
.54223 .12361 L
.58034 .12361 L
.6209 .12361 L
.65994 .12361 L
.70144 .12361 L
.74142 .12361 L
.77989 .12361 L
.82081 .12361 L
.86021 .12361 L
.8981 .12361 L
.93844 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80002goooo001Woooo00<0003oooooool04?ooo`@0I_nR
oooo001Woooo00<0003oooooool02oooo`D0I_l3oooo00<0I_ooooooool0X?ooo`00Ioooo`030000
oooooooo00Woool206Ko2?ooo`0306Kooooooooo0:3oool006Ooool00`000?ooooooo`06oooo0`1V
o`[oool00`1Vooooooooo`2Poooo001Woooo00<0003oooooool00oooo`<0I_l=oooo00<0I_oooooo
ool0X?ooo`00Ioooo`80000406Ko4?ooo`0306Kooooooooo0:3oool001Ooool500007_ooo`800004
oooo0P0000Coool200007Oooo`80I_l00`00001Vooooo`0Coooo00<0I_ooooooool02?ooo`800004
oooo0P0000Coool200007oooo`D0000Moooo1@0000;oool200001?ooo`80000Poooo100001Koool0
01Woool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000Ioooo0`1V
o`;oool00`000?ooooooo`0Coooo00<0I_ooooooool01oooo`040000oooooooo00002?ooo`040000
oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0003oooooool0000O
oooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000_oool0
0`000?ooooooo`0Eoooo0P1Vo`Goool00`000?ooooooo`0Coooo00<0I_ooooooool01oooo`040000
oooooooo00002oooo`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_oo
o`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0G
oooo100000;oool010000?ooooooo`0000Woool200005_ooo`80I_l7oooo00<0003oooooool05?oo
o`0306Kooooooooo00Koool010000?ooooooo`0000Woool200008Oooo`030000oooooooo01ooool0
0`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`030000oooooooo01?oool206Ko2Oooo`030000oooooooo01Coool0
0`1Vooooooooo`06oooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300004Oooo`80I_l;oooo0P0001Goool00`1Vooooooooo`07oooo0P00
00[oool300007oooo`80000Poooo0P0000[oool300008?ooo`80000Goooo001Ioooo00<0I_oooooo
ool02oooo`030000oooooooo01Coool00`1Vooooooooo`2Ooooo001Goooo0P1Vo`koool00`000?oo
ooooo`0Doooo00<0I_ooooooool0Woooo`00E_ooo`0306Kooooooooo00koool00`000?ooooooo`0D
oooo00<0I_ooooooool0Woooo`00E?ooo`80I_lAoooo00<0003oooooool05?ooo`0306Kooooooooo
09ooool0057oool306Ko4oooo`030000oooooooo01Coool00`1Vooooooooo`2Ooooo000@ooooo`00
017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0003<ol000?o09Tco`0000001c?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004
<ol0:00000;oool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`0003?o
03?o000C<ol000?o09Tco`0co`003c?o00030000<ol0<ol002@co`0@00006Oooo`030000oooooooo
02Koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`004c?o0003o`2I<ol0<ol0034co`05
0000J_ooo`00Ioooo`030000<ol0<ol001<co`000ol0VC?o03?o000/<ol01@0006ooool006Ooool0
0`0003?o03?o000C<ol000?o09Tco`0co`009c?o00D0001doooo001Woooo00<0000co`0co`004c?o
0003o`2I<ol0<ol002<co`040000NOooo`00Ioooo`80000D<ol000?o09Tco`0co`008C?o0080001m
oooo001Woooo00<0000co`0co`004c?o0003o`2I<ol0<ol001lco`020000Ooooo`00Ioooo`030000
<ol0<ol001<co`000ol0VC?o03?o000M<ol00P00087oool006Ooool00`0003?o03?o000C<ol000?o
09Tco`0co`006c?o00800023oooo001Woooo00<0000co`0co`004c?o0003o`2I<ol0<ol001Xco`00
0`000?ooooooo`23oooo001Woooo00<0000co`0co`004c?o0003o`2I<ol0<ol001Pco`020000Q_oo
o`00Ioooo`80000D<ol000?o09Tco`0co`005S?o00800028oooo001Woooo00<0000co`0co`004c?o
0003o`2I<ol0<ol001Dco`000`000?ooooooo`28oooo001Woooo00<0000co`0co`004c?o0003o`2I
<ol0<ol001@co`000`000?ooooooo`29oooo001Woooo00<0000co`0co`004c?o0003o`2I<ol0<ol0
01<co`000`000?ooooooo`2:oooo001Woooo00<0000co`0co`004c?o0003o`2I<ol0<ol0018co`00
0`000?ooooooo`2;oooo001Woooo00<0000co`0co`004c?o0003o`2I<ol0<ol0018co`000`000?oo
ooooo`2;oooo001Woooo0P0001@co`000ol0VC?o03?o000A<ol000<0003oooooool0S?ooo`00Iooo
o`030000<ol0<ol001<co`000ol0VC?o03?o000@<ol000<0003oooooool0SOooo`00Ioooo`030000
<ol0<ol001<co`000ol0VC?o03?o000?<ol000<0003oooooool0S_ooo`00Ioooo`030000<ol0<ol0
01<co`000ol0VC?o03?o000><ol000<0003oooooool0Soooo`00Ioooo`030000<ol0<ol001<co`00
0ol0VC?o03?o000=<ol000<0003oooooool0T?ooo`00Ioooo`030000<ol0<ol001<co`000ol0VC?o
03?o000=<ol000<0003oooooool0T?ooo`00Ioooo`80000D<ol000?o09Tco`0co`0033?o00030000
oooooooo097oool006Ooool00`0003?o03?o000C<ol000?o09Tco`0co`002c?o00030000oooooooo
09;oool006Ooool00`0003?o03?o000C<ol000?o09Tco`0co`002S?o00030000oooooooo09?oool0
06Ooool00`0003?o03?o000C<ol000?o09Tco`0co`002S?o00030000oooooooo09?oool006Ooool0
0`0003?o03?o000C<ol000?o09Tco`0co`002C?o00030000oooooooo09Coool005ooool500000ooo
o`030000<ol0<ol001<co`000ol0VC?o03?o0009<ol000<0003oooooool0U?ooo`00HOooo`030000
oooooooo00?oool00`0003?o03?o000C<ol000?o09Tco`0co`0023?o00030000oooooooo09Goool0
067oool00`000?ooooooo`03oooo0P0001@co`000ol0VC?o03?o0008<ol000<0003oooooool0UOoo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000C<ol000?o09Tco`0co`001c?o00030000
oooooooo09Koool0067oool00`000?ooooooo`03oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0
00Lco`000`000?ooooooo`2Foooo001Poooo0P0000Goool00`0003?o03?o000C<ol000?o09Tco`0c
o`001S?o00030000oooooooo09Ooool006Ooool00`0003?o03?o000C<ol000?o09Tco`0co`001S?o
00030000oooooooo09Ooool006Ooool00`0003?o03?o000C<ol000?o09Tco`0co`001C?o00030000
oooooooo09Soool006Ooool2000053?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Hoooo001W
oooo00<0000co`0co`004c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Ioooo001Woooo00<0
000co`0co`004c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`2Ioooo001Woooo00<0000co`0c
o`004c?o0003o`2I<ol0<ol000<co`000`000?ooooooo`2Joooo001Woooo00<0000co`0co`004c?o
0003o`2I<ol0<ol000<co`000`000?ooooooo`2Joooo001Woooo00<0000co`0co`004c?o0003o`2I
<ol0<ol0008co`000`000?ooooooo`2Koooo001Woooo0P0001@co`000ol0VC?o03?o0002<ol000<0
003oooooool0Voooo`00Ioooo`030000<ol0<ol001<co`001Ol0VC?o03?o03?o0000002Noooo001W
oooo00<0000co`0co`004c?o0005o`2I<ol0<ol0<ol0000009koool006Ooool00`0003?o03?o000C
<ol000Co09Tco`0co`00002Ooooo001Woooo00<0000co`0co`004c?o0004o`2I<ol0<ol00000Wooo
o`00Ioooo`030000<ol0<ol001<co`001?l0VC?o03?o000009ooool006Ooool00`0003?o03?o000C
<ol000?o09Tco`000000X?ooo`00Ioooo`80000D<ol000?o09Tco`000000X?ooo`00Ioooo`030000
<ol0<ol001<co`000ol0VC?o0000002Poooo001Woooo00<0000co`0co`004c?o0003o`2I<ol00000
0:3oool006Ooool00`0003?o03?o000C<ol000?o09T0003oool0X?ooo`00Ioooo`030000<ol0<ol0
01<co`000ol0V@000?ooo`2Poooo001Woooo00<0000co`0co`004c?o0003o`2I0000oooo0:3oool0
06Ooool2000053?o0003o`2I0000oooo0:3oool006Ooool00`0003?o03?o000C<ol000?o09Wooooo
ool0X?ooo`00Ioooo`030000<ol0<ol001<co`000ol0VOooooooo`2Poooo001Woooo00<0000co`0c
o`004c?o0003o`2Ioooooooo0:3oool005ooool400001?ooo`030000<ol0<ol001<co`000ol0VOoo
ooooo`2Poooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?l0VOooo`2Q
oooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0003o09Woool0XOooo`00HOooo`030000
oooooooo00?oool00`0003?o03?o000B<ol000<0003o09Woool0XOooo`00Goooo`040000oooooooo
00001?ooo`030000<ol0<ol0014co`000`000?ooool0V@2Roooo001Poooo0P0000Goool00`0003?o
03?o000A<ol000<0003ooooo09T0X_ooo`00Ioooo`030000<ol0<ol0014co`000`000?ooool0V@2R
oooo001Woooo00<0000co`0co`004C?o00030000ooooo`2I0:;oool006Ooool200004C?o00040000
ooooooooo`2IX_ooo`00Ioooo`030000<ol0<ol0010co`0010000?ooooooool0VJ;oool006Ooool0
0`0003?o03?o000@<ol000@0003ooooooooo09VRoooo001Woooo00<0000co`0co`0043?o00040000
ooooooooo`2IX_ooo`00Ioooo`030000<ol0<ol000lco`001@000?ooooooooooool0V@2Roooo001W
oooo00<0000co`0co`003c?o00050000ooooooooooooo`2I0:;oool006Ooool00`0003?o03?o000?
<ol000D0003ooooooooooooo09T0X_ooo`00Ioooo`80000@<ol000D0003ooooooooooooo09T0X_oo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`02oooo00?o09Woooooool0X?ooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`02oooo00?o09Woooooool0X?ooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`02oooo00?o09Woooooool0X?ooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`02oooo00?o09Woooooool0X?ooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`03oooo00?o09Woooooool0X?ooo`00Ioooo`80000><ol000<0003oooooool00ooo
o`03o`2Ioooooooo0:3oool006Ooool00`0003?o03?o000=<ol000<0003oooooool00oooo`03o`2I
oooooooo0:3oool006Ooool00`0003?o03?o000=<ol000<0003oooooool00oooo`03o`2Ioooooooo
0:3oool006Ooool00`0003?o03?o000<<ol000<0003oooooool01?ooo`03o`2Ioooooooo0:3oool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool01?ooo`03o`2Ioooooooo0:3oool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool01?ooo`03o`2Ioooooooo0:3oool006Ooool200003C?o
00030000oooooooo00Coool00ol0VOooooooo`2Poooo001Woooo00<0000co`0co`0033?o00030000
oooooooo00Coool00ol0VOooooooo`2Poooo001Woooo00<0000co`0co`0033?o00030000oooooooo
00Coool00ol0VOooooooo`2Poooo001Woooo00<0000co`0co`002c?o00030000oooooooo00Goool0
0ol0VOooooooo`2Poooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool01Ooo
o`03o`2Ioooooooo0:3oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0
003oooooool01Oooo`03o`2Ioooooooo0:3oool0067oool00`000?ooooooo`03oooo0P0000`co`00
0`000?ooooooo`05oooo00?o09Woooooool0X?ooo`00H_ooo`030000oooooooo00;oool00`0003?o
03?o000;<ol000<0003oooooool01Oooo`03o`2Ioooooooo0:3oool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool01Oooo`03o`2Ioooooooo0:3oool0063oool2
00001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`06oooo00?o09Woooooool0X?ooo`00Iooo
o`030000<ol0<ol000Xco`000`000?ooooooo`06oooo00?o09Woooooool0X?ooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`06oooo00?o09Woooooool0X?ooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`06oooo00?o09Woooooool0X?ooo`00Ioooo`80000;<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo0:3oool006Ooool00`0003?o03?o000:<ol000<0003oooooool01_oo
o`03o`2Ioooooooo0:3oool006Ooool00`0003?o03?o0009<ol000<0003oooooool01oooo`03o`2I
oooooooo0:3oool006Ooool00`0003?o03?o0009<ol000<0003oooooool01oooo`03o`2Ioooooooo
0:3oool006Ooool00`0003?o03?o0009<ol000<0003oooooool01oooo`03o`2Ioooooooo0:3oool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool01oooo`03o`2Ioooooooo0:3oool006Ooool2
00002S?o00030000oooooooo00Ooool00ol0VOooooooo`2Poooo001Woooo00<0000co`0co`002C?o
00030000oooooooo00Ooool00ol0VOooooooo`2Poooo001Woooo00<0000co`0co`002C?o00030000
oooooooo00Ooool00ol0VOooooooo`2Poooo001Woooo00<0000co`0co`0023?o00030000oooooooo
00Soool00ol0VOooooooo`2Poooo001Woooo00<0000co`0co`0023?o00030000oooooooo00Soool0
0ol0VOooooooo`2Poooo001Woooo00<0000co`0co`0023?o00030000oooooooo00Soool00ol0VOoo
ooooo`2Poooo001Woooo0P0000Tco`000`000?ooooooo`08oooo00?o09Woooooool0X?ooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`08oooo00?o09Woooooool0X?ooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`08oooo00?o09Woooooool0X?ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`09oooo00?o09Woooooool0X?ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`09oooo00?o09Woooooool0X?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`09oooo00?o09Woooooool0X?ooo`00Ioooo`800008<ol000<0003oooooool02Oooo`03o`2I
oooooooo0:3oool006Ooool00`0003?o03?o0007<ol000<0003oooooool02Oooo`03o`2Ioooooooo
0:3oool006Ooool00`0003?o03?o0007<ol000<0003oooooool02Oooo`03o`2Ioooooooo0:3oool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool02Oooo`03o`2Ioooooooo0:3oool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool02Oooo`03o`2Ioooooooo0:3oool0067oool300000ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`09oooo00?o09Woooooool0X?ooo`00H_ooo`030000
oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool02Oooo`03o`2Ioooooooo0:3oool0
05ooool500000oooo`800008<ol000<0003oooooool02Oooo`03o`2Ioooooooo0:3oool005ooool0
10000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOoo
o`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`@00003oooo0P0000Coool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`07oooo00<0003oooooool00_oo
o`030000oooooooo00goool010000?ooooooo`0000Woool00`000?ooooooo`02oooo00@0003ooooo
ool00004oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000coool0
10000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0
003oooooool04Oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Woool006Ooool9
<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.42237 .12361 L
.42781 .12361 L
.43049 .12361 L
.43298 .12361 L
.43522 .12361 L
.43648 .12361 L
s
.43648 .12361 m
.43693 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23739 .12361 L
.24016 .12361 L
.24276 .12361 L
.24392 .12361 L
.24502 .12361 L
.24629 .12341 L
.24745 .12251 L
.25261 .11864 L
.26171 .11227 L
.2999 .09104 L
.31958 .08306 L
.34055 .07634 L
.38213 .06483 L
.403 .05929 L
.41215 .05695 L
.4222 .05447 L
.42688 .05334 L
.42945 .05273 L
.43189 .05216 L
.43416 .05164 L
.43544 .05134 L
.43663 .12361 L
.43762 .12361 L
.43872 .12361 L
.44094 .12361 L
.46075 .12361 L
.50095 .12361 L
.53964 .12361 L
.58078 .12361 L
.6204 .12361 L
.65851 .12361 L
.69907 .12361 L
.73812 .12361 L
.77961 .12361 L
.8196 .12361 L
.85806 .12361 L
.89898 .12361 L
.93838 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80000Doooo0`1Voj3oool006Ooool00`000?ooooooo`0A
oooo0P1Vo`;oool00`1Vooooooooo`2Noooo001Woooo00<0003oooooool02_ooo`L0I_l4oooo00<0
I_ooooooool0W_ooo`00Ioooo`030000oooooooo00Koool406Ko2oooo`0306Kooooooooo09koool0
06Ooool00`000?ooooooo`03oooo0`1Vo`ooool00`1Vooooooooo`2Noooo001Woooo00<0003oool0
I_l00`1Voa;oool00`1Vooooooooo`2Noooo001Voooo00<0I_l0000000005_ooo`0306Kooooooooo
09koool001Ooool500007_ooo`800004oooo0P0000Coool200006oooo`<0I_l00oooo`000?ooo`0F
oooo00<0I_ooooooool01_ooo`800004oooo0P0000Coool200007oooo`D0000Moooo1@0000;oool2
00001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool0000Goooo0`1Vo`Coool00`000?ooooooo`0Eoooo00<0I_ooooooool01Ooo
o`040000oooooooo00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?oo
ooooo`07oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo
01goool010000?ooooooo`0000_oool00`000?ooooooo`0Coooo0P1Vo`Ooool00`000?ooooooo`0E
oooo00<0I_ooooooool01Oooo`040000oooooooo00002oooo`030000oooooooo01koool00`000?oo
ooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo01koool00`000?ooooooo`0Foooo000A
oooo100000Coool00`000?ooooooo`0Goooo100000;oool010000?ooooooo`0000Woool200005?oo
o`80I_l9oooo00<0003oooooool05Oooo`0306Kooooooooo00Goool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo017oool2
06Ko2oooo`030000oooooooo01Goool00`1Vooooooooo`05oooo00@0003oooooool00009oooo00<0
003oooooool08?ooo`030000oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool300004?ooo`0306Kooooooooo
00_oool200005_ooo`0306Kooooooooo00Koool200002_ooo`<0000Ooooo0P00023oool200002_oo
o`<0000Poooo0P0001Ooool005Ooool206Ko3_ooo`030000oooooooo01Goool00`1Vooooooooo`2N
oooo001Foooo00<0I_ooooooool03_ooo`030000oooooooo01Goool00`1Vooooooooo`2Noooo001D
oooo0P1Voa7oool00`000?ooooooo`0Eoooo00<0I_ooooooool0W_ooo`00D_ooo`80I_lCoooo00<0
003oooooool05Oooo`0306Kooooooooo09koool0053oool206Ko5Oooo`030000oooooooo01Goool0
0`1Vooooooooo`2Noooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`0003?o03?o000E<ol000?o09Tco`0co`003C?o00030000<ol0<ol0
02@co`0@00006Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0c
o`005C?o0003o`2I<ol0<ol002lco`050000J_ooo`00Ioooo`030000<ol0<ol001Dco`000ol0VC?o
03?o000Z<ol01@0006ooool006Ooool00`0003?o03?o000E<ol000?o09Tco`0co`009C?o00D0001d
oooo001Woooo00<0000co`0co`005C?o0003o`2I<ol0<ol0024co`040000NOooo`00Ioooo`80000F
<ol000?o09Tco`0co`007c?o0080001moooo001Woooo00<0000co`0co`005C?o0003o`2I<ol0<ol0
01dco`020000Ooooo`00Ioooo`030000<ol0<ol001Dco`000ol0VC?o03?o000K<ol00P00087oool0
06Ooool00`0003?o03?o000E<ol000?o09Tco`0co`006C?o00800023oooo001Woooo00<0000co`0c
o`005C?o0003o`2I<ol0<ol001Pco`000`000?ooooooo`23oooo001Woooo00<0000co`0co`005C?o
0003o`2I<ol0<ol001Hco`020000Q_ooo`00Ioooo`80000F<ol000?o09Tco`0co`0053?o00800028
oooo001Woooo00<0000co`0co`005C?o0003o`2I<ol0<ol001<co`000`000?ooooooo`28oooo001W
oooo00<0000co`0co`005C?o0003o`2I<ol0<ol0018co`000`000?ooooooo`29oooo001Woooo00<0
000co`0co`005C?o0003o`2I<ol0<ol0014co`000`000?ooooooo`2:oooo001Woooo00<0000co`0c
o`005C?o0003o`2I<ol0<ol0010co`000`000?ooooooo`2;oooo001Woooo00<0000co`0co`005C?o
0003o`2I<ol0<ol0010co`000`000?ooooooo`2;oooo001Woooo0P0001Hco`000ol0VC?o03?o000?
<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol001Dco`000ol0VC?o03?o000><ol000<0
003oooooool0SOooo`00Ioooo`030000<ol0<ol001Dco`000ol0VC?o03?o000=<ol000<0003ooooo
ool0S_ooo`00Ioooo`030000<ol0<ol001Dco`000ol0VC?o03?o000<<ol000<0003oooooool0Sooo
o`00Ioooo`030000<ol0<ol001Dco`000ol0VC?o03?o000;<ol000<0003oooooool0T?ooo`00Iooo
o`030000<ol0<ol001Dco`000ol0VC?o03?o000;<ol000<0003oooooool0T?ooo`00Ioooo`80000F
<ol000?o09Tco`0co`002S?o00030000oooooooo097oool006Ooool00`0003?o03?o000E<ol000?o
09Tco`0co`002C?o00030000oooooooo09;oool006Ooool00`0003?o03?o000E<ol000?o09Tco`0c
o`0023?o00030000oooooooo09?oool006Ooool00`0003?o03?o000E<ol000?o09Tco`0co`0023?o
00030000oooooooo09?oool006Ooool00`0003?o03?o000E<ol000?o09Tco`0co`001c?o00030000
oooooooo09Coool005ooool500000oooo`030000<ol0<ol001Dco`000ol0VC?o03?o0007<ol000<0
003oooooool0U?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000E<ol000?o09Tco`0c
o`001S?o00030000oooooooo09Goool0067oool00`000?ooooooo`03oooo0P0001Hco`000ol0VC?o
03?o0006<ol000<0003oooooool0UOooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000?o09Tco`0co`001C?o00030000oooooooo09Koool0067oool00`000?ooooooo`03oooo00<0
000co`0co`005C?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Foooo001Poooo0P0000Goool0
0`0003?o03?o000E<ol000?o09Tco`0co`0013?o00030000oooooooo09Ooool006Ooool00`0003?o
03?o000E<ol000?o09Tco`0co`0013?o00030000oooooooo09Ooool006Ooool00`0003?o03?o000E
<ol000?o09Tco`0co`000c?o00030000oooooooo09Soool006Ooool200005S?o0003o`2I<ol0<ol0
00<co`000`000?ooooooo`2Hoooo001Woooo00<0000co`0co`005C?o0003o`2I<ol0<ol0008co`00
0`000?ooooooo`2Ioooo001Woooo00<0000co`0co`005C?o0003o`2I<ol0<ol0008co`000`000?oo
ooooo`2Ioooo001Woooo00<0000co`0co`005C?o0005o`2I<ol0<ol0<ol0000009coool006Ooool0
0`0003?o03?o000E<ol000Go09Tco`0co`0co`000000W?ooo`00Ioooo`030000<ol0<ol001Dco`00
1?l0VC?o03?o000009goool006Ooool200005S?o0004o`2I<ol0<ol00000WOooo`00Ioooo`030000
<ol0<ol001Dco`000ol0VC?o0000002Noooo001Woooo00<0000co`0co`005C?o0003o`2I<ol00000
09koool006Ooool00`0003?o03?o000E<ol000?o09T0003oool0W_ooo`00Ioooo`030000<ol0<ol0
01Dco`000ol0V@000?ooo`2Noooo001Woooo00<0000co`0co`005C?o0003o`2I0000oooo09koool0
06Ooool00`0003?o03?o000E<ol000?o09Woooooool0W_ooo`00Ioooo`80000F<ol000?o09Wooooo
ool0W_ooo`00Ioooo`030000<ol0<ol001Dco`000ol0VOooooooo`2Noooo001Woooo00<0000co`0c
o`005C?o0003o`2Ioooooooo09koool006Ooool00`0003?o03?o000D<ol000<0003o09Woool0Wooo
o`00Ioooo`030000<ol0<ol001@co`000`000?l0VOooo`2Ooooo001Woooo00<0000co`0co`0053?o
00030000o`2Ioooo09ooool006Ooool200005C?o00030000o`2Ioooo09ooool006Ooool00`0003?o
03?o000C<ol000<0003ooooo09T0X?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooool0V@2P
oooo001Woooo00<0000co`0co`004c?o00030000ooooo`2I0:3oool005ooool400001?ooo`030000
<ol0<ol001<co`000`000?ooool0V@2Poooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0
018co`0010000?ooooooool0VJ3oool0063oool00`000?ooooooo`04oooo0P0001<co`0010000?oo
ooooool0VJ3oool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00040000oooooooo
o`2IX?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`001@000?oooooooooo
ool0V@2Poooo001Poooo0P0000Goool00`0003?o03?o000A<ol000D0003ooooooooooooo09T0X?oo
o`00Ioooo`030000<ol0<ol0014co`001@000?ooooooooooool0V@2Poooo001Woooo00<0000co`0c
o`004C?o00050000ooooooooooooo`2I0:3oool006Ooool200004C?o00030000oooooooo00;oool0
0ol0VOooooooo`2Noooo001Woooo00<0000co`0co`0043?o00030000oooooooo00;oool00ol0VOoo
ooooo`2Noooo001Woooo00<0000co`0co`0043?o00030000oooooooo00;oool00ol0VOooooooo`2N
oooo001Woooo00<0000co`0co`0043?o00030000oooooooo00;oool00ol0VOooooooo`2Noooo001W
oooo00<0000co`0co`003c?o00030000oooooooo00?oool00ol0VOooooooo`2Noooo001Woooo00<0
000co`0co`003c?o00030000oooooooo00?oool00ol0VOooooooo`2Noooo001Woooo00<0000co`0c
o`003c?o00030000oooooooo00?oool00ol0VOooooooo`2Noooo001Woooo0P00010co`000`000?oo
ooooo`03oooo00?o09Woooooool0W_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`04
oooo00?o09Woooooool0W_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`04oooo00?o
09Woooooool0W_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`04oooo00?o09Wooooo
ool0W_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`04oooo00?o09Woooooool0W_oo
o`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`05oooo00?o09Woooooool0W_ooo`00Iooo
o`80000><ol000<0003oooooool01Oooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o000=
<ol000<0003oooooool01Oooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o000=<ol000<0
003oooooool01Oooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o000<<ol000<0003oooooool01_oo
o`03o`2Ioooooooo09koool006Ooool00`0003?o03?o000<<ol000<0003oooooool01_ooo`03o`2I
oooooooo09koool006Ooool200003C?o00030000oooooooo00Koool00ol0VOooooooo`2Noooo001W
oooo00<0000co`0co`0033?o00030000oooooooo00Koool00ol0VOooooooo`2Noooo001Woooo00<0
000co`0co`0033?o00030000oooooooo00Koool00ol0VOooooooo`2Noooo001Woooo00<0000co`0c
o`002c?o00030000oooooooo00Ooool00ol0VOooooooo`2Noooo001Poooo0P0000Goool00`0003?o
03?o000;<ol000<0003oooooool01oooo`03o`2Ioooooooo09koool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool01oooo`03o`2Ioooooooo09koool0067oool0
0`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`07oooo00?o09Woooooool0W_ooo`00H_oo
o`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool01oooo`03o`2Ioooooooo
09koool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool01ooo
o`03o`2Ioooooooo09koool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`08
oooo00?o09Woooooool0W_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`08oooo00?o
09Woooooool0W_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`08oooo00?o09Wooooo
ool0W_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`08oooo00?o09Woooooool0W_oo
o`00Ioooo`80000;<ol000<0003oooooool02?ooo`03o`2Ioooooooo09koool006Ooool00`0003?o
03?o000:<ol000<0003oooooool02?ooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o0009
<ol000<0003oooooool02Oooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o0009<ol000<0
003oooooool02Oooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool02Oooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o0009<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo09koool006Ooool200002S?o00030000oooooooo00Woool00ol0VOooooooo`2N
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo00Woool00ol0VOooooooo`2Noooo001W
oooo00<0000co`0co`002C?o00030000oooooooo00Woool00ol0VOooooooo`2Noooo001Woooo00<0
000co`0co`0023?o00030000oooooooo00[oool00ol0VOooooooo`2Noooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo00[oool00ol0VOooooooo`2Noooo001Woooo00<0000co`0co`0023?o
00030000oooooooo00[oool00ol0VOooooooo`2Noooo001Woooo0P0000Tco`000`000?ooooooo`0:
oooo00?o09Woooooool0W_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0:oooo00?o
09Woooooool0W_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0:oooo00?o09Wooooo
ool0W_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0;oooo00?o09Woooooool0W_oo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0;oooo00?o09Woooooool0W_ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0;oooo00?o09Woooooool0W_ooo`00Ioooo`800008
<ol000<0003oooooool02oooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o0007<ol000<0
003oooooool02oooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo09koool006Ooool00`0003?o03?o0007<ol000<0003oooooool02ooo
o`03o`2Ioooooooo09koool006Ooool00`0003?o03?o0007<ol000<0003oooooool02oooo`03o`2I
oooooooo09koool0067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`0;oooo00?o
09Woooooool0W_ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo09koool005ooool500000oooo`800008<ol000<0003oooooool02ooo
o`03o`2Ioooooooo09koool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000
oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Iooo
o`Tco`2`oooo001Woooo2C?o00coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Iooo
o`Tco`0;oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001W
oooo2C?o00_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool2
00001?ooo`800004oooo00<0003oooooool0Noooo`00Ioooo`Tco`0;oooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00Ioooo`Tco`0:oooo00<0003oooooool00_oo
o`030000oooooooo00goool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003ooooo
ool0N_ooo`00Ioooo`Tco`0;oooo00<0003oooooool01@0000coool010000?ooooooo`0000_oool0
1@000?ooooooooooo`00001moooo001Woooo2C?o00_oool01@000?ooooooooooo`00000?oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Ioooo`Tco`0<
oooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo001Woooo2C?o
0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44021 .12361 L
.44151 .12361 L
.44268 .12361 L
s
.44268 .12361 m
.44316 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23496 .12361 L
.2364 .12361 L
.23775 .12361 L
.2389 .12361 L
.24014 .12325 L
.24084 .12271 L
.24151 .1222 L
.24276 .12124 L
.26171 .10815 L
.2999 .08827 L
.31958 .08084 L
.34055 .07463 L
.38213 .06383 L
.403 .05851 L
.4222 .05384 L
.43189 .05159 L
.43663 .05052 L
.43869 .05007 L
.44094 .04957 L
.44216 .04931 L
.44328 .12361 L
.44436 .12361 L
.4455 .12361 L
.45038 .12361 L
.46075 .12361 L
.4985 .12361 L
.5387 .12361 L
.57739 .12361 L
.61853 .12361 L
.65815 .12361 L
.69626 .12361 L
.73682 .12361 L
.77587 .12361 L
.81737 .12361 L
.85735 .12361 L
.89581 .12361 L
.93673 .12361 L
.97614 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool0]_ooo`00Ioooo`80000Doooo101Voiooool006Ooool00`000?ooooooo`0?
oooo101Vo`?oool00`1Vooooooooo`2Moooo001Woooo00<0003oooooool02_ooo`D0I_l7oooo00<0
I_ooooooool0WOooo`00Ioooo`030000oooooooo00Koool406Ko3?ooo`0306Kooooooooo09goool0
06Ooool00`000?ooooooo`03oooo0`1Voa3oool00`1Vooooooooo`2Moooo001Woooo00<0003oool0
I_l00`1Voa?oool00`1Vooooooooo`2Moooo001Voooo00<0I_l0000000005oooo`0306Kooooooooo
09goool001Ooool500007_ooo`800004oooo0P0000Coool200006oooo`<0I_l00oooo`000?ooo`0G
oooo00<0I_ooooooool01Oooo`800004oooo0P0000Coool200007oooo`D0000Moooo1@0000;oool2
00001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool0000Foooo101Vo`Coool00`000?ooooooo`0Foooo00<0I_ooooooool01?oo
o`040000oooooooo00002?ooo`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?oo
ooooo`07oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo
01goool010000?ooooooo`0000_oool00`000?ooooooo`0Aoooo0`1Vo`Soool00`000?ooooooo`0F
oooo00<0I_ooooooool01?ooo`040000oooooooo00002oooo`030000oooooooo01koool00`000?oo
ooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo01koool00`000?ooooooo`0Foooo000A
oooo100000Coool00`000?ooooooo`0Goooo100000;oool010000?ooooooo`0000Woool200004_oo
o`80I_l;oooo00<0003oooooool05oooo`0306Kooooooooo00?oool010000?ooooooo`0000Woool2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo00ooool2
06Ko3Oooo`030000oooooooo01Ooool00`1Vooooooooo`03oooo00@0003oooooool00009oooo00<0
003oooooool08?ooo`030000oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool300003Oooo`80I_l?oooo0P00
01Soool00`1Vooooooooo`04oooo0P0000[oool300007oooo`80000Poooo0P0000[oool300008?oo
o`80000Goooo001Doooo0P1Voa7oool00`000?ooooooo`0Goooo00<0I_ooooooool0W?ooo`00Dooo
o`0306Kooooooooo017oool00`000?ooooooo`0Goooo00<0I_ooooooool0W?ooo`00D_ooo`0306Ko
oooooooo01;oool00`000?ooooooo`0Goooo00<0I_ooooooool0W?ooo`00D?ooo`80I_lEoooo00<0
003oooooool05oooo`0306Kooooooooo09coool004ooool00`1Vooooooooo`0Eoooo00<0003ooooo
ool05oooo`0306Kooooooooo09coool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`000?l0VC?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol001Hco`000ol0VC?o03?o000<<ol000<0
000co`0co`0093?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool006Ooool0
0`0003?o03?o000F<ol000?o09Tco`0co`00;S?o00D0001Zoooo001Woooo00<0000co`0co`005S?o
0003o`2I<ol0<ol002Tco`050000Koooo`00Ioooo`030000<ol0<ol001Hco`000ol0VC?o03?o000T
<ol01@0007Coool006Ooool00`0003?o03?o000F<ol000?o09Tco`0co`0083?o00@0001ioooo001W
oooo0P0001Lco`000ol0VC?o03?o000N<ol00P0007goool006Ooool00`0003?o03?o000F<ol000?o
09Tco`0co`0073?o0080001ooooo001Woooo00<0000co`0co`005S?o0003o`2I<ol0<ol001Xco`02
0000POooo`00Ioooo`030000<ol0<ol001Hco`000ol0VC?o03?o000H<ol00P0008?oool006Ooool0
0`0003?o03?o000F<ol000?o09Tco`0co`005c?o00030000oooooooo08?oool006Ooool00`0003?o
03?o000F<ol000?o09Tco`0co`005C?o00800026oooo001Woooo0P0001Lco`000ol0VC?o03?o000C
<ol00P0008Soool006Ooool00`0003?o03?o000F<ol000?o09Tco`0co`004S?o00030000oooooooo
08Soool006Ooool00`0003?o03?o000F<ol000?o09Tco`0co`004C?o00030000oooooooo08Woool0
06Ooool00`0003?o03?o000F<ol000?o09Tco`0co`0043?o00030000oooooooo08[oool006Ooool0
0`0003?o03?o000F<ol000?o09Tco`0co`003c?o00030000oooooooo08_oool006Ooool00`0003?o
03?o000F<ol000?o09Tco`0co`003c?o00030000oooooooo08_oool006Ooool200005c?o0003o`2I
<ol0<ol000hco`000`000?ooooooo`2<oooo001Woooo00<0000co`0co`005S?o0003o`2I<ol0<ol0
00dco`000`000?ooooooo`2=oooo001Woooo00<0000co`0co`005S?o0003o`2I<ol0<ol000`co`00
0`000?ooooooo`2>oooo001Woooo00<0000co`0co`005S?o0003o`2I<ol0<ol000/co`000`000?oo
ooooo`2?oooo001Woooo00<0000co`0co`005S?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`2@
oooo001Woooo00<0000co`0co`005S?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`2@oooo001W
oooo0P0001Lco`000ol0VC?o03?o0009<ol000<0003oooooool0TOooo`00Ioooo`030000<ol0<ol0
01Hco`000ol0VC?o03?o0008<ol000<0003oooooool0T_ooo`00Ioooo`030000<ol0<ol001Hco`00
0ol0VC?o03?o0007<ol000<0003oooooool0Toooo`00Ioooo`030000<ol0<ol001Hco`000ol0VC?o
03?o0007<ol000<0003oooooool0Toooo`00Ioooo`030000<ol0<ol001Hco`000ol0VC?o03?o0006
<ol000<0003oooooool0U?ooo`00Goooo`D00003oooo00<0000co`0co`005S?o0003o`2I<ol0<ol0
00Hco`000`000?ooooooo`2Doooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001Hco`00
0ol0VC?o03?o0005<ol000<0003oooooool0UOooo`00HOooo`030000oooooooo00?oool200005c?o
0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Eoooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001Hco`000ol0VC?o03?o0004<ol000<0003oooooool0U_ooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000F<ol000?o09Tco`0co`0013?o00030000oooooooo09Koool0063oool2
00001Oooo`030000<ol0<ol001Hco`000ol0VC?o03?o0003<ol000<0003oooooool0Uoooo`00Iooo
o`030000<ol0<ol001Hco`000ol0VC?o03?o0003<ol000<0003oooooool0Uoooo`00Ioooo`030000
<ol0<ol001Hco`000ol0VC?o03?o0002<ol000<0003oooooool0V?ooo`00Ioooo`80000G<ol000?o
09Tco`0co`000S?o00030000oooooooo09Soool006Ooool00`0003?o03?o000F<ol000Go09Tco`0c
o`0co`000000Voooo`00Ioooo`030000<ol0<ol001Hco`001Ol0VC?o03?o03?o0000002Koooo001W
oooo00<0000co`0co`005S?o0004o`2I<ol0<ol00000W?ooo`00Ioooo`030000<ol0<ol001Hco`00
1?l0VC?o03?o000009coool006Ooool00`0003?o03?o000F<ol000?o09Tco`000000WOooo`00Iooo
o`80000G<ol000?o09Tco`000000WOooo`00Ioooo`030000<ol0<ol001Hco`000ol0V@000?ooo`2M
oooo001Woooo00<0000co`0co`005S?o0003o`2I0000oooo09goool006Ooool00`0003?o03?o000F
<ol000?o09Woooooool0WOooo`00Ioooo`030000<ol0<ol001Hco`000ol0VOooooooo`2Moooo001W
oooo00<0000co`0co`005S?o0003o`2Ioooooooo09goool006Ooool00`0003?o03?o000E<ol000<0
003o09Woool0W_ooo`00Ioooo`80000F<ol000<0003o09Woool0W_ooo`00Ioooo`030000<ol0<ol0
01Dco`000`000?l0VOooo`2Noooo001Woooo00<0000co`0co`005C?o00030000o`2Ioooo09koool0
06Ooool00`0003?o03?o000D<ol000<0003ooooo09T0Woooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooool0V@2Ooooo001Woooo00<0000co`0co`0053?o00030000ooooo`2I09ooool006Ooool2
00005C?o00030000ooooo`2I09ooool006Ooool00`0003?o03?o000C<ol000@0003ooooooooo09VO
oooo001Woooo00<0000co`0co`004c?o00040000ooooooooo`2IWoooo`00Ioooo`030000<ol0<ol0
01<co`0010000?ooooooool0VIooool005ooool400001?ooo`030000<ol0<ol001<co`0010000?oo
ooooool0VIooool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00050000oooooooo
ooooo`2I09ooool0063oool00`000?ooooooo`04oooo0P0001<co`001@000?ooooooooooool0V@2O
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`02oooo00?o
09Woooooool0W?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`000`000?oo
ooooo`03oooo00?o09Woooooool0W?ooo`00H?ooo`800005oooo00<0000co`0co`004C?o00030000
oooooooo00?oool00ol0VOooooooo`2Loooo001Woooo00<0000co`0co`004C?o00030000oooooooo
00?oool00ol0VOooooooo`2Loooo001Woooo00<0000co`0co`004C?o00030000oooooooo00?oool0
0ol0VOooooooo`2Loooo001Woooo0P00014co`000`000?ooooooo`04oooo00?o09Woooooool0W?oo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`04oooo00?o09Woooooool0W?ooo`00Iooo
o`030000<ol0<ol0010co`000`000?ooooooo`04oooo00?o09Woooooool0W?ooo`00Ioooo`030000
<ol0<ol0010co`000`000?ooooooo`04oooo00?o09Woooooool0W?ooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`05oooo00?o09Woooooool0W?ooo`00Ioooo`030000<ol0<ol000lco`00
0`000?ooooooo`05oooo00?o09Woooooool0W?ooo`00Ioooo`030000<ol0<ol000lco`000`000?oo
ooooo`05oooo00?o09Woooooool0W?ooo`00Ioooo`80000@<ol000<0003oooooool01Oooo`03o`2I
oooooooo09coool006Ooool00`0003?o03?o000><ol000<0003oooooool01_ooo`03o`2Ioooooooo
09coool006Ooool00`0003?o03?o000><ol000<0003oooooool01_ooo`03o`2Ioooooooo09coool0
06Ooool00`0003?o03?o000><ol000<0003oooooool01_ooo`03o`2Ioooooooo09coool006Ooool0
0`0003?o03?o000><ol000<0003oooooool01_ooo`03o`2Ioooooooo09coool006Ooool00`0003?o
03?o000=<ol000<0003oooooool01oooo`03o`2Ioooooooo09coool006Ooool200003S?o00030000
oooooooo00Ooool00ol0VOooooooo`2Loooo001Woooo00<0000co`0co`003C?o00030000oooooooo
00Ooool00ol0VOooooooo`2Loooo001Woooo00<0000co`0co`003C?o00030000oooooooo00Ooool0
0ol0VOooooooo`2Loooo001Woooo00<0000co`0co`0033?o00030000oooooooo00Soool00ol0VOoo
ooooo`2Loooo001Woooo00<0000co`0co`0033?o00030000oooooooo00Soool00ol0VOooooooo`2L
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo00Soool00ol0VOooooooo`2Loooo001W
oooo0P0000dco`000`000?ooooooo`08oooo00?o09Woooooool0W?ooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`08oooo00?o09Woooooool0W?ooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`08oooo00?o09Woooooool0W?ooo`00Ioooo`030000<ol0<ol000/co`000`000?oo
ooooo`09oooo00?o09Woooooool0W?ooo`00H?ooo`800005oooo00<0000co`0co`002c?o00030000
oooooooo00Woool00ol0VOooooooo`2Loooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`002c?o00030000oooooooo00Woool00ol0VOooooooo`2Loooo001Qoooo00<0003oooooool00ooo
o`80000<<ol000<0003oooooool02Oooo`03o`2Ioooooooo09coool006;oool00`000?ooooooo`02
oooo00<0000co`0co`002c?o00030000oooooooo00Woool00ol0VOooooooo`2Loooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo00Woool00ol0VOooooooo`2L
oooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool02_ooo`03o`2Ioooooooo
09coool006Ooool00`0003?o03?o000:<ol000<0003oooooool02_ooo`03o`2Ioooooooo09coool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool02_ooo`03o`2Ioooooooo09coool006Ooool0
0`0003?o03?o000:<ol000<0003oooooool02_ooo`03o`2Ioooooooo09coool006Ooool200002c?o
00030000oooooooo00[oool00ol0VOooooooo`2Loooo001Woooo00<0000co`0co`002S?o00030000
oooooooo00[oool00ol0VOooooooo`2Loooo001Woooo00<0000co`0co`002C?o00030000oooooooo
00_oool00ol0VOooooooo`2Loooo001Woooo00<0000co`0co`002C?o00030000oooooooo00_oool0
0ol0VOooooooo`2Loooo001Woooo00<0000co`0co`002C?o00030000oooooooo00_oool00ol0VOoo
ooooo`2Loooo001Woooo00<0000co`0co`002C?o00030000oooooooo00_oool00ol0VOooooooo`2L
oooo001Woooo0P0000Xco`000`000?ooooooo`0;oooo00?o09Woooooool0W?ooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`0;oooo00?o09Woooooool0W?ooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0;oooo00?o09Woooooool0W?ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0<oooo00?o09Woooooool0W?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0<oooo00?o09Woooooool0W?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0<
oooo00?o09Woooooool0W?ooo`00Ioooo`800009<ol000<0003oooooool03?ooo`03o`2Ioooooooo
09coool006Ooool00`0003?o03?o0008<ol000<0003oooooool03?ooo`03o`2Ioooooooo09coool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool03?ooo`03o`2Ioooooooo09coool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool03Oooo`03o`2Ioooooooo09coool006Ooool00`0003?o
03?o0007<ol000<0003oooooool03Oooo`03o`2Ioooooooo09coool006Ooool00`0003?o03?o0007
<ol000<0003oooooool03Oooo`03o`2Ioooooooo09coool006Ooool2000023?o00030000oooooooo
00goool00ol0VOooooooo`2Loooo001Woooo00<0000co`0co`001c?o00030000oooooooo00goool0
0ol0VOooooooo`2Loooo001Woooo00<0000co`0co`001c?o00030000oooooooo00goool00ol0VOoo
ooooo`2Loooo001Woooo00<0000co`0co`001c?o00030000oooooooo00goool00ol0VOooooooo`2L
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo00goool00ol0VOooooooo`2Loooo001Q
oooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool03Oooo`03o`2Ioooooooo09coool0
06;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo00goool00ol0VOoo
ooooo`2Loooo001Ooooo1@0000?oool2000023?o00030000oooooooo00goool00ol0VOooooooo`2L
oooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o
0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Iooo
o`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Coool200000ooo
o`@00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00<0003oooooool01?ooo`030000oooooooo07Soool006Ooool9<ol01oooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`030000oooooooo00Coool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`05
00003?ooo`040000oooooooo00002oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000003oooo`040000oooooooo
00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
06Ooool9<ol02Oooo`030000oooooooo017oool200002_ooo`800004oooo0P0000?oool00`000?oo
ooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44268 .12361 L
.44498 .12361 L
.44744 .12361 L
.44816 .12361 L
.44885 .12361 L
s
.44885 .12361 m
.44936 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.22738 .12361 L
.22994 .12361 L
.23119 .12361 L
.23233 .12361 L
.23357 .12342 L
.23426 .12289 L
.23491 .12239 L
.23775 .12024 L
.24276 .11658 L
.26171 .10428 L
.2999 .08569 L
.31958 .07879 L
.34055 .07306 L
.38213 .06293 L
.403 .05783 L
.4222 .0533 L
.43189 .05111 L
.44094 .04913 L
.4455 .04816 L
.44681 .04789 L
.44805 .04763 L
.44917 .0474 L
.45038 .12361 L
.45162 .12361 L
.45299 .12361 L
.45577 .12361 L
.46075 .12361 L
.50095 .12361 L
.53964 .12361 L
.58078 .12361 L
.6204 .12361 L
.65851 .12361 L
.69907 .12361 L
.73812 .12361 L
.77961 .12361 L
.8196 .12361 L
.85806 .12361 L
.89898 .12361 L
.93838 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool05oooo`80I_nMoooo001Woooo0P0001Coool406Ko00?oool0I_ooool0W?oo
o`00Ioooo`030000oooooooo00ooool406Ko1Oooo`0306Kooooooooo09_oool006Ooool00`000?oo
ooooo`0:oooo1@1Vo`Woool00`1Vooooooooo`2Koooo001Woooo00<0003oooooool01_ooo`@0I_l>
oooo00<0I_ooooooool0Voooo`00Ioooo`030000oooooooo00?oool306Ko4_ooo`0306Kooooooooo
09_oool006Ooool00`000?ooo`1Vo`0306Ko5Oooo`0306Kooooooooo09_oool006Goool206Ko0P00
01Woool00`1Vooooooooo`2Koooo000Goooo1@0001koool200001?ooo`800004oooo0P0001Soool5
06Ko0_ooo`030000oooooooo01Soool00`1Vooooooooo`03oooo0P0000Coool200001?ooo`80000O
oooo1@0001goool500000_ooo`800004oooo0P00023oool400005_ooo`006Oooo`030000oooooooo
01goool010000?ooooooo`0000Soool010000?ooooooo`0001Goool206Ko1oooo`030000oooooooo
01Soool00`1Vooooooooo`02oooo00@0003oooooool00008oooo00@0003oooooool0000Poooo00<0
003oooooool07oooo`030000oooooooo00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0G
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo017oool2
06Ko2Oooo`030000oooooooo01Soool00`1Vooooooooo`02oooo00@0003oooooool0000;oooo00<0
003oooooool07_ooo`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool07_oo
o`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000
oooooooo00002Oooo`80000Boooo0P1Vo`_oool00`000?ooooooo`0Hoooo00<0I_ooooooool00_oo
o`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool07oooo`030000oooooooo00Soool2
00008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0003oooooool00009
oooo00<0003oooooool03oooo`80I_l=oooo00<0003oooooool06?ooo`0306Kooooooooo00;oool0
10000?ooooooo`0000Woool00`000?ooooooo`0Poooo00<0003oooooool07oooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00023oool200002_oo
o`<0000=oooo0P1Vo`ooool200006Oooo`0306Kooooooooo00?oool200002_ooo`<0000Ooooo0P00
023oool200002_ooo`<0000Poooo0P0001Ooool005Coool206Ko4Oooo`030000oooooooo01Soool0
0`1Vooooooooo`2Koooo001Coooo00<0I_ooooooool04Oooo`030000oooooooo01Soool00`1Voooo
ooooo`2Koooo001Aoooo0P1VoaCoool00`000?ooooooo`0Hoooo00<0I_ooooooool0Voooo`00Cooo
o`80I_lFoooo00<0003oooooool06?ooo`0306Kooooooooo09_oool004koool00`1Vooooooooo`0F
oooo00<0003oooooool06?ooo`0306Kooooooooo09_oool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`00100003?o03?o0?l0V@@co`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0co`0063?o0003o`2I
<ol0<ol000Xco`000`0003?o03?o000T<ol0400001Woool00`000?ooooooo`0Voooo00<0003ooooo
ool05Oooo`00Ioooo`030000<ol0<ol001Pco`000ol0VC?o03?o000/<ol01@0006[oool006Ooool0
0`0003?o03?o000H<ol000?o09Tco`0co`009c?o00D0001_oooo001Woooo00<0000co`0co`0063?o
0003o`2I<ol0<ol0028co`050000M?ooo`00Ioooo`030000<ol0<ol001Pco`000ol0VC?o03?o000N
<ol0100007Woool006Ooool200006C?o0003o`2I<ol0<ol001`co`020000OOooo`00Ioooo`030000
<ol0<ol001Pco`000ol0VC?o03?o000J<ol00P0007ooool006Ooool00`0003?o03?o000H<ol000?o
09Tco`0co`0063?o00800021oooo001Woooo00<0000co`0co`0063?o0003o`2I<ol0<ol001Hco`02
0000Poooo`00Ioooo`030000<ol0<ol001Pco`000ol0VC?o03?o000E<ol000<0003oooooool0Pooo
o`00Ioooo`030000<ol0<ol001Pco`000ol0VC?o03?o000C<ol00P0008Koool006Ooool200006C?o
0003o`2I<ol0<ol0014co`020000R?ooo`00Ioooo`030000<ol0<ol001Pco`000ol0VC?o03?o000@
<ol000<0003oooooool0R?ooo`00Ioooo`030000<ol0<ol001Pco`000ol0VC?o03?o000?<ol000<0
003oooooool0ROooo`00Ioooo`030000<ol0<ol001Pco`000ol0VC?o03?o000><ol000<0003ooooo
ool0R_ooo`00Ioooo`030000<ol0<ol001Pco`000ol0VC?o03?o000=<ol000<0003oooooool0Rooo
o`00Ioooo`030000<ol0<ol001Pco`000ol0VC?o03?o000=<ol000<0003oooooool0Roooo`00Iooo
o`80000I<ol000?o09Tco`0co`0033?o00030000oooooooo08coool006Ooool00`0003?o03?o000H
<ol000?o09Tco`0co`002c?o00030000oooooooo08goool006Ooool00`0003?o03?o000H<ol000?o
09Tco`0co`002S?o00030000oooooooo08koool006Ooool00`0003?o03?o000H<ol000?o09Tco`0c
o`002C?o00030000oooooooo08ooool006Ooool00`0003?o03?o000H<ol000?o09Tco`0co`0023?o
00030000oooooooo093oool006Ooool00`0003?o03?o000H<ol000?o09Tco`0co`0023?o00030000
oooooooo093oool006Ooool200006C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Aoooo001W
oooo00<0000co`0co`0063?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`2Boooo001Woooo00<0
000co`0co`0063?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Coooo001Woooo00<0000co`0c
o`0063?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`2Coooo001Woooo00<0000co`0co`0063?o
0003o`2I<ol0<ol000@co`000`000?ooooooo`2Doooo001Ooooo1@0000?oool00`0003?o03?o000H
<ol000?o09Tco`0co`0013?o00030000oooooooo09Coool0067oool00`000?ooooooo`03oooo00<0
000co`0co`0063?o0003o`2I<ol0<ol000<co`000`000?ooooooo`2Eoooo001Qoooo00<0003ooooo
ool00oooo`80000I<ol000?o09Tco`0co`000c?o00030000oooooooo09Goool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`0063?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Foooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001Pco`000ol0VC?o03?o0002<ol000<0003ooooo
ool0U_ooo`00H?ooo`800005oooo00<0000co`0co`0063?o0005o`2I<ol0<ol0<ol0000009Woool0
06Ooool00`0003?o03?o000H<ol000Go09Tco`0co`0co`000000VOooo`00Ioooo`030000<ol0<ol0
01Pco`001?l0VC?o03?o000009[oool006Ooool200006C?o0004o`2I<ol0<ol00000V_ooo`00Iooo
o`030000<ol0<ol001Pco`000ol0VC?o0000002Koooo001Woooo00<0000co`0co`0063?o0003o`2I
<ol0000009_oool006Ooool00`0003?o03?o000H<ol000?o09T0003oool0Voooo`00Ioooo`030000
<ol0<ol001Pco`000ol0V@000?ooo`2Koooo001Woooo00<0000co`0co`0063?o0003o`2Ioooooooo
09_oool006Ooool200006C?o0003o`2Ioooooooo09_oool006Ooool00`0003?o03?o000G<ol000<0
003o09Woool0W?ooo`00Ioooo`030000<ol0<ol001Lco`000`000?l0VOooo`2Loooo001Woooo00<0
000co`0co`005S?o00030000ooooo`2I09goool006Ooool00`0003?o03?o000F<ol000<0003ooooo
09T0WOooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooool0V@2Moooo001Woooo00<0000co`0c
o`005C?o00040000ooooooooo`2IWOooo`00Ioooo`80000F<ol000@0003ooooooooo09VMoooo001W
oooo00<0000co`0co`005C?o00040000ooooooooo`2IWOooo`00Ioooo`030000<ol0<ol001Dco`00
10000?ooooooool0VIgoool006Ooool00`0003?o03?o000D<ol000D0003ooooooooooooo09T0WOoo
o`00Ioooo`030000<ol0<ol001@co`001@000?ooooooooooool0V@2Moooo001Woooo00<0000co`0c
o`0053?o00050000ooooooooooooo`2I09goool006Ooool200005C?o00050000ooooooooooooo`2I
09goool006Ooool00`0003?o03?o000C<ol000<0003oooooool00_ooo`03o`2Ioooooooo09_oool0
06Ooool00`0003?o03?o000C<ol000<0003oooooool00_ooo`03o`2Ioooooooo09_oool006Ooool0
0`0003?o03?o000C<ol000<0003oooooool00_ooo`03o`2Ioooooooo09_oool005ooool400001?oo
o`030000<ol0<ol001<co`000`000?ooooooo`02oooo00?o09Woooooool0Voooo`00Goooo`030000
oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool00oooo`03o`2Ioooooooo09_oool0
063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`03oooo00?o09Woooooool0Vooo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool00oooo`03o`2I
oooooooo09_oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003ooooo
ool01?ooo`03o`2Ioooooooo09_oool0063oool200001Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`04oooo00?o09Woooooool0Voooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`04
oooo00?o09Woooooool0Voooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`04oooo00?o
09Woooooool0Voooo`00Ioooo`80000A<ol000<0003oooooool01Oooo`03o`2Ioooooooo09_oool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool01Oooo`03o`2Ioooooooo09_oool006Ooool0
0`0003?o03?o000@<ol000<0003oooooool01Oooo`03o`2Ioooooooo09_oool006Ooool00`0003?o
03?o000@<ol000<0003oooooool01Oooo`03o`2Ioooooooo09_oool006Ooool00`0003?o03?o000?
<ol000<0003oooooool01_ooo`03o`2Ioooooooo09_oool006Ooool00`0003?o03?o000?<ol000<0
003oooooool01_ooo`03o`2Ioooooooo09_oool006Ooool00`0003?o03?o000?<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo09_oool006Ooool2000043?o00030000oooooooo00Koool00ol0VOoo
ooooo`2Koooo001Woooo00<0000co`0co`003S?o00030000oooooooo00Ooool00ol0VOooooooo`2K
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo00Ooool00ol0VOooooooo`2Koooo001W
oooo00<0000co`0co`003S?o00030000oooooooo00Ooool00ol0VOooooooo`2Koooo001Woooo00<0
000co`0co`003S?o00030000oooooooo00Ooool00ol0VOooooooo`2Koooo001Woooo00<0000co`0c
o`003C?o00030000oooooooo00Soool00ol0VOooooooo`2Koooo001Woooo0P0000hco`000`000?oo
ooooo`08oooo00?o09Woooooool0Voooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`08
oooo00?o09Woooooool0Voooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`08oooo00?o
09Woooooool0Voooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`09oooo00?o09Wooooo
ool0Voooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`09oooo00?o09Woooooool0Vooo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`09oooo00?o09Woooooool0Voooo`00Iooo
o`80000=<ol000<0003oooooool02Oooo`03o`2Ioooooooo09_oool006Ooool00`0003?o03?o000<
<ol000<0003oooooool02Oooo`03o`2Ioooooooo09_oool006Ooool00`0003?o03?o000<<ol000<0
003oooooool02Oooo`03o`2Ioooooooo09_oool006Ooool00`0003?o03?o000;<ol000<0003ooooo
ool02_ooo`03o`2Ioooooooo09_oool0063oool200001Oooo`030000<ol0<ol000/co`000`000?oo
ooooo`0:oooo00?o09Woooooool0Voooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0
00/co`000`000?ooooooo`0:oooo00?o09Woooooool0Voooo`00HOooo`030000oooooooo00?oool2
000033?o00030000oooooooo00[oool00ol0VOooooooo`2Koooo001Roooo00<0003oooooool00_oo
o`030000<ol0<ol000/co`000`000?ooooooo`0:oooo00?o09Woooooool0Voooo`00Goooo`040000
oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0:oooo00?o09Woooooool0Vooo
o`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo00_oool00ol0VOooooooo`2K
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo00_oool00ol0VOooooooo`2Koooo001W
oooo00<0000co`0co`002S?o00030000oooooooo00_oool00ol0VOooooooo`2Koooo001Woooo00<0
000co`0co`002S?o00030000oooooooo00_oool00ol0VOooooooo`2Koooo001Woooo0P0000/co`00
0`000?ooooooo`0;oooo00?o09Woooooool0Voooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0;oooo00?o09Woooooool0Voooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0<
oooo00?o09Woooooool0Voooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0<oooo00?o
09Woooooool0Voooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0<oooo00?o09Wooooo
ool0Voooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0<oooo00?o09Woooooool0Vooo
o`00Ioooo`80000:<ol000<0003oooooool03?ooo`03o`2Ioooooooo09_oool006Ooool00`0003?o
03?o0009<ol000<0003oooooool03?ooo`03o`2Ioooooooo09_oool006Ooool00`0003?o03?o0009
<ol000<0003oooooool03?ooo`03o`2Ioooooooo09_oool006Ooool00`0003?o03?o0008<ol000<0
003oooooool03Oooo`03o`2Ioooooooo09_oool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo09_oool006Ooool00`0003?o03?o0008<ol000<0003oooooool03Ooo
o`03o`2Ioooooooo09_oool006Ooool200002C?o00030000oooooooo00goool00ol0VOooooooo`2K
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo00goool00ol0VOooooooo`2Koooo001W
oooo00<0000co`0co`0023?o00030000oooooooo00goool00ol0VOooooooo`2Koooo001Woooo00<0
000co`0co`001c?o00030000oooooooo00koool00ol0VOooooooo`2Koooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo00koool00ol0VOooooooo`2Koooo001Woooo00<0000co`0co`001c?o
00030000oooooooo00koool00ol0VOooooooo`2Koooo001Woooo0P0000Pco`000`000?ooooooo`0>
oooo00?o09Woooooool0Voooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0>oooo00?o
09Woooooool0Voooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0>oooo00?o09Wooooo
ool0Voooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0>oooo00?o09Woooooool0Vooo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0>oooo00?o09Woooooool0Voooo`00HOoo
o`<00003oooo00<0000co`0co`001c?o00030000oooooooo00koool00ol0VOooooooo`2Koooo001R
oooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`0>oooo00?o09Wooooo
ool0Voooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`0>oooo00?o09Woooooool0Vooo
o`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_
oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9
<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo0P0000Goool3
00000_ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo
00001Oooo`050000oooooooooooo000007[oool006Ooool9<ol01oooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0003oooooool0000:oooo00@0003oooooooooool500000oooo`030000
oooooooo07Ooool006Ooool9<ol02?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000;
oooo00@0003oooooool00002oooo00D0003oooooooooool00000N_ooo`00Ioooo`Tco`08oooo00D0
003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooo000000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P00
00[oool200001Oooo`800002oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o
0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.44268 .12361 L
.44778 .12361 L
.45029 .12361 L
.45262 .12361 L
.45371 .12361 L
.45473 .12361 L
s
.45473 .12361 m
.4552 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.21345 .12361 L
.21786 .12361 L
.22037 .12361 L
.22272 .12361 L
.22496 .12361 L
.22623 .12361 L
.22738 .1233 L
.22859 .12236 L
.22992 .12135 L
.23233 .11955 L
.24276 .1122 L
.26171 .10065 L
.28303 .09007 L
.30236 .0824 L
.34148 .07142 L
.38155 .06227 L
.4201 .05333 L
.44004 .04896 L
.44489 .04795 L
.45008 .04688 L
.45161 .04657 L
.45306 .04628 L
.45437 .04602 L
.4551 .04588 L
.45578 .12361 L
.45701 .12361 L
.45836 .12361 L
.46111 .12361 L
.50131 .12361 L
.54 .12361 L
.58114 .12361 L
.62076 .12361 L
.65887 .12361 L
.69943 .12361 L
.73847 .12361 L
.77997 .12361 L
.81995 .12361 L
.85842 .12361 L
.89934 .12361 L
.93874 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001W
oooo00<0003oooooool05Oooo`H0I_nKoooo001Woooo0P0001Coool206Ko1Oooo`0306Kooooooooo
09Woool006Ooool00`000?ooooooo`0?oooo101Vo`Ooool00`1Vooooooooo`2Ioooo001Woooo00<0
003oooooool02_ooo`D0I_l;oooo00<0I_ooooooool0VOooo`00Ioooo`030000oooooooo00Goool5
06Ko4?ooo`0306Kooooooooo09Woool006Ooool00`000?ooooooo`0506Ko5Oooo`0306Kooooooooo
09Woool006Koool0101Vo`00001Vo`1Voa[oool00`1Vooooooooo`2Ioooo001Soooo0`1Vo`03oooo
0000000001_oool00`1Vooooooooo`2Ioooo000Goooo1@0001koool200001?ooo`800004oooo0P00
01Ooool406Ko1?ooo`030000oooooooo01[oool0101Vooooooooooooo`800004oooo0P0000Coool2
00007oooo`D0000Moooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?oo
ooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000Coooo0`1Vo`Soool00`000?oo
ooooo`0Joooo00@0I_ooooooool00002oooo00<0003oooooool01_ooo`040000oooooooo00008?oo
o`030000oooooooo01ooool00`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003ooooo
ool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0?
oooo0P1Vo`_oool00`000?ooooooo`0Joooo00@0I_ooooooool00002oooo00<0003oooooool02Ooo
o`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool0
10000?ooooooo`0000Woool200004?ooo`80I_l=oooo00<0003oooooool06_ooo`0406Kooooooooo
00000_ooo`030000oooooooo00Ooool200008Oooo`030000oooooooo01ooool00`000?ooooooo`08
oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`030000oooooooo00goool206Ko3oooo`030000oooooooo01[oool0101Vooooooooo`00
00;oool00`000?ooooooo`07oooo00<0003oooooool08?ooo`030000oooooooo01ooool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P00
00[oool300002oooo`80I_lAoooo0P0001_oool0101Vooooooooooooo`80000:oooo0`0001ooool2
00008?ooo`80000:oooo0`00023oool200005oooo`00Doooo`0306Kooooooooo017oool00`000?oo
ooooo`0Joooo00<0I_ooooooool0VOooo`00DOooo`80I_lDoooo00<0003oooooool06_ooo`0306Ko
oooooooo09Woool004ooool206Ko5_ooo`030000oooooooo01[oool00`1Vooooooooo`2Ioooo001=
oooo0P1VoaSoool00`000?ooooooo`0Joooo00<0I_ooooooool0VOooo`00Boooo`80I_lJoooo00<0
003oooooool06_ooo`0306Kooooooooo09Woool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`001@0003?o03?o03?o0?l0V@03<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol001Tco`000ol0VC?o
03?o0009<ol000<0000co`0co`0093?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo
01Goool006Ooool00`0003?o03?o000I<ol000?o09Tco`0co`00:c?o00D0001Zoooo001Woooo00<0
000co`0co`006C?o0003o`2I<ol0<ol002Hco`050000Koooo`00Ioooo`030000<ol0<ol001Tco`00
0ol0VC?o03?o000Q<ol01@0007Coool006Ooool00`0003?o03?o000I<ol000?o09Tco`0co`007C?o
00@0001ioooo001Woooo0P0001Xco`000ol0VC?o03?o000K<ol00P0007goool006Ooool00`0003?o
03?o000I<ol000?o09Tco`0co`006C?o0080001ooooo001Woooo00<0000co`0co`006C?o0003o`2I
<ol0<ol001Lco`020000POooo`00Ioooo`030000<ol0<ol001Tco`000ol0VC?o03?o000E<ol00P00
08?oool006Ooool00`0003?o03?o000I<ol000?o09Tco`0co`0053?o00030000oooooooo08?oool0
06Ooool00`0003?o03?o000I<ol000?o09Tco`0co`004S?o00800026oooo001Woooo0P0001Xco`00
0ol0VC?o03?o000@<ol00P0008Soool006Ooool00`0003?o03?o000I<ol000?o09Tco`0co`003c?o
00030000oooooooo08Soool006Ooool00`0003?o03?o000I<ol000?o09Tco`0co`003S?o00030000
oooooooo08Woool006Ooool00`0003?o03?o000I<ol000?o09Tco`0co`003C?o00030000oooooooo
08[oool006Ooool00`0003?o03?o000I<ol000?o09Tco`0co`0033?o00030000oooooooo08_oool0
06Ooool00`0003?o03?o000I<ol000?o09Tco`0co`0033?o00030000oooooooo08_oool006Ooool2
00006S?o0003o`2I<ol0<ol000/co`000`000?ooooooo`2<oooo001Woooo00<0000co`0co`006C?o
0003o`2I<ol0<ol000Xco`000`000?ooooooo`2=oooo001Woooo00<0000co`0co`006C?o0003o`2I
<ol0<ol000Tco`000`000?ooooooo`2>oooo001Woooo00<0000co`0co`006C?o0003o`2I<ol0<ol0
00Pco`000`000?ooooooo`2?oooo001Woooo00<0000co`0co`006C?o0003o`2I<ol0<ol000Lco`00
0`000?ooooooo`2@oooo001Woooo00<0000co`0co`006C?o0003o`2I<ol0<ol000Lco`000`000?oo
ooooo`2@oooo001Woooo0P0001Xco`000ol0VC?o03?o0006<ol000<0003oooooool0TOooo`00Iooo
o`030000<ol0<ol001Tco`000ol0VC?o03?o0005<ol000<0003oooooool0T_ooo`00Ioooo`030000
<ol0<ol001Tco`000ol0VC?o03?o0004<ol000<0003oooooool0Toooo`00Ioooo`030000<ol0<ol0
01Tco`000ol0VC?o03?o0004<ol000<0003oooooool0Toooo`00Ioooo`030000<ol0<ol001Tco`00
0ol0VC?o03?o0003<ol000<0003oooooool0U?ooo`00Goooo`D00003oooo00<0000co`0co`006C?o
0003o`2I<ol0<ol000<co`000`000?ooooooo`2Doooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001Tco`000ol0VC?o03?o0002<ol000<0003oooooool0UOooo`00HOooo`030000oooooooo
00?oool200006S?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Eoooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001Tco`001Ol0VC?o03?o03?o0000002Hoooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001Tco`001Ol0VC?o03?o03?o0000002Hoooo001Poooo0P0000Goool0
0`0003?o03?o000I<ol000Co09Tco`0co`00002Ioooo001Woooo00<0000co`0co`006C?o0004o`2I
<ol0<ol00000VOooo`00Ioooo`030000<ol0<ol001Tco`000ol0VC?o0000002Joooo001Woooo0P00
01Xco`000ol0VC?o0000002Joooo001Woooo00<0000co`0co`006C?o0003o`2I0000oooo09[oool0
06Ooool00`0003?o03?o000I<ol000?o09T0003oool0V_ooo`00Ioooo`030000<ol0<ol001Tco`00
0ol0VOooooooo`2Joooo001Woooo00<0000co`0co`006C?o0003o`2Ioooooooo09[oool006Ooool0
0`0003?o03?o000H<ol000<0003o09Woool0Voooo`00Ioooo`80000I<ol000<0003o09Woool0Vooo
o`00Ioooo`030000<ol0<ol001Lco`000`000?ooool0V@2Loooo001Woooo00<0000co`0co`005c?o
00030000ooooo`2I09coool006Ooool00`0003?o03?o000F<ol000@0003ooooooooo09VLoooo001W
oooo00<0000co`0co`005S?o00040000ooooooooo`2IW?ooo`00Ioooo`030000<ol0<ol001Hco`00
10000?ooooooool0VIcoool006Ooool00`0003?o03?o000E<ol000D0003ooooooooooooo09T0W?oo
o`00Ioooo`80000F<ol000D0003ooooooooooooo09T0W?ooo`00Ioooo`030000<ol0<ol001Dco`00
1@000?ooooooooooool0V@2Loooo001Woooo00<0000co`0co`005C?o00050000ooooooooooooo`2I
09coool006Ooool00`0003?o03?o000D<ol000<0003oooooool00_ooo`03o`2Ioooooooo09[oool0
06Ooool00`0003?o03?o000D<ol000<0003oooooool00_ooo`03o`2Ioooooooo09[oool006Ooool0
0`0003?o03?o000D<ol000<0003oooooool00_ooo`03o`2Ioooooooo09[oool006Ooool200005C?o
00030000oooooooo00;oool00ol0VOooooooo`2Joooo001Woooo00<0000co`0co`004c?o00030000
oooooooo00?oool00ol0VOooooooo`2Joooo001Woooo00<0000co`0co`004c?o00030000oooooooo
00?oool00ol0VOooooooo`2Joooo001Woooo00<0000co`0co`004c?o00030000oooooooo00?oool0
0ol0VOooooooo`2Joooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003oooooool00ooo
o`03o`2Ioooooooo09[oool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000
oooooooo00Coool00ol0VOooooooo`2Joooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0
003oooooool01?ooo`03o`2Ioooooooo09[oool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`004S?o00030000oooooooo00Goool00ol0VOooooooo`2Ioooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`004C?o00030000oooooooo00Koool00ol0VOooooooo`2Ioooo001Poooo0P00
00Goool00`0003?o03?o000A<ol000<0003oooooool01_ooo`03o`2Ioooooooo09Woool006Ooool0
0`0003?o03?o000A<ol000<0003oooooool01_ooo`03o`2Ioooooooo09Woool006Ooool00`0003?o
03?o000A<ol000<0003oooooool01_ooo`03o`2Ioooooooo09Woool006Ooool200004C?o00030000
oooooooo00Ooool00ol0VOooooooo`2Ioooo001Woooo00<0000co`0co`0043?o00030000oooooooo
00Ooool00ol0VOooooooo`2Ioooo001Woooo00<0000co`0co`0043?o00030000oooooooo00Ooool0
0ol0VOooooooo`2Ioooo001Woooo00<0000co`0co`0043?o00030000oooooooo00Ooool00ol0VOoo
ooooo`2Ioooo001Woooo00<0000co`0co`003c?o00030000oooooooo00Soool00ol0VOooooooo`2I
oooo001Woooo00<0000co`0co`003c?o00030000oooooooo00Soool00ol0VOooooooo`2Ioooo001W
oooo00<0000co`0co`003c?o00030000oooooooo00Soool00ol0VOooooooo`2Ioooo001Woooo0P00
010co`000`000?ooooooo`08oooo00?o09Woooooool0VOooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`09oooo00?o09Woooooool0VOooo`00Ioooo`030000<ol0<ol000hco`000`000?oo
ooooo`09oooo00?o09Woooooool0VOooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`09
oooo00?o09Woooooool0VOooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`09oooo00?o
09Woooooool0VOooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0:oooo00?o09Wooooo
ool0VOooo`00Ioooo`80000><ol000<0003oooooool02_ooo`03o`2Ioooooooo09Woool006Ooool0
0`0003?o03?o000=<ol000<0003oooooool02_ooo`03o`2Ioooooooo09Woool006Ooool00`0003?o
03?o000=<ol000<0003oooooool02_ooo`03o`2Ioooooooo09Woool006Ooool00`0003?o03?o000<
<ol000<0003oooooool02oooo`03o`2Ioooooooo09Woool006Ooool00`0003?o03?o000<<ol000<0
003oooooool02oooo`03o`2Ioooooooo09Woool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo09Woool006Ooool200003C?o00030000oooooooo00_oool00ol0VOoo
ooooo`2Ioooo001Woooo00<0000co`0co`0033?o00030000oooooooo00_oool00ol0VOooooooo`2I
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo00_oool00ol0VOooooooo`2Ioooo001W
oooo00<0000co`0co`002c?o00030000oooooooo00coool00ol0VOooooooo`2Ioooo001Poooo0P00
00Goool00`0003?o03?o000;<ol000<0003oooooool03?ooo`03o`2Ioooooooo09Woool005ooool0
10000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool03?ooo`03o`2Ioooooooo
09Woool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`0<oooo00?o09Wooooo
ool0VOooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool03?oo
o`03o`2Ioooooooo09Woool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0
003oooooool03?ooo`03o`2Ioooooooo09Woool0063oool200001Oooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0=oooo00?o09Woooooool0VOooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0=oooo00?o09Woooooool0VOooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0=
oooo00?o09Woooooool0VOooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0=oooo00?o
09Woooooool0VOooo`00Ioooo`80000;<ol000<0003oooooool03Oooo`03o`2Ioooooooo09Woool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool03Oooo`03o`2Ioooooooo09Woool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool03_ooo`03o`2Ioooooooo09Woool006Ooool00`0003?o
03?o0009<ol000<0003oooooool03_ooo`03o`2Ioooooooo09Woool006Ooool00`0003?o03?o0009
<ol000<0003oooooool03_ooo`03o`2Ioooooooo09Woool006Ooool00`0003?o03?o0009<ol000<0
003oooooool03_ooo`03o`2Ioooooooo09Woool006Ooool200002S?o00030000oooooooo00koool0
0ol0VOooooooo`2Ioooo001Woooo00<0000co`0co`002C?o00030000oooooooo00koool00ol0VOoo
ooooo`2Ioooo001Woooo00<0000co`0co`002C?o00030000oooooooo00koool00ol0VOooooooo`2I
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo00ooool00ol0VOooooooo`2Ioooo001W
oooo00<0000co`0co`0023?o00030000oooooooo00ooool00ol0VOooooooo`2Ioooo001Woooo00<0
000co`0co`0023?o00030000oooooooo00ooool00ol0VOooooooo`2Ioooo001Woooo0P0000Tco`00
0`000?ooooooo`0?oooo00?o09Woooooool0VOooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0?oooo00?o09Woooooool0VOooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0?
oooo00?o09Woooooool0VOooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0@oooo00?o
09Woooooool0VOooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0@oooo00?o09Wooooo
ool0VOooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0@oooo00?o09Woooooool0VOoo
o`00Ioooo`800008<ol000<0003oooooool04?ooo`03o`2Ioooooooo09Woool006Ooool00`0003?o
03?o0007<ol000<0003oooooool04?ooo`03o`2Ioooooooo09Woool006Ooool00`0003?o03?o0007
<ol000<0003oooooool04?ooo`03o`2Ioooooooo09Woool006Ooool00`0003?o03?o0007<ol000<0
003oooooool04?ooo`03o`2Ioooooooo09Woool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo09Woool0067oool300000oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0@oooo00?o09Woooooool0VOooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007
<ol000<0003oooooool04?ooo`03o`2Ioooooooo09Woool005ooool500000oooo`800008<ol000<0
003oooooool04?ooo`03o`2Ioooooooo09Woool005ooool010000?ooooooo`0000Coool:<ol0[ooo
o`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9
<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000Coool200001?ooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001Woooo2C?o
00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000coool010000?ooooooo`0000_oool0
0`000?ooooooo`0300001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:oooo0P00
00Coool300000_ooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.45734 .12361 L
.45963 .12361 L
.46063 .12361 L
.46172 .12361 L
s
.46172 .12361 m
.46216 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20178 .12361 L
.20742 .12361 L
.21274 .12361 L
.21753 .12361 L
.21884 .12361 L
.21955 .12361 L
.22022 .12361 L
.22141 .12301 L
.22272 .122 L
.26149 .09736 L
.28262 .08753 L
.30271 .08012 L
.32252 .07437 L
.34091 .07023 L
.38004 .0619 L
.42162 .05261 L
.44249 .04818 L
.45164 .04632 L
.45649 .04537 L
.45916 .04485 L
.46047 .0446 L
.46168 .04437 L
.46286 .12361 L
.46411 .12361 L
.46676 .12361 L
.47138 .12361 L
.48043 .12361 L
.50023 .12361 L
.53799 .12361 L
.57819 .12361 L
.61688 .12361 L
.65802 .12361 L
.69764 .12361 L
.73575 .12361 L
.77631 .12361 L
.81535 .12361 L
.85685 .12361 L
.89683 .12361 L
.9353 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0Koooo00<0
I_ooooooool0V?ooo`00Ioooo`030000oooooooo01Coool806KoV_ooo`00Ioooo`80000Aoooo101V
o`Ooool00`1Vooooooooo`2Hoooo001Woooo00<0003oooooool03Oooo`<0I_l;oooo00<0I_oooooo
ool0V?ooo`00Ioooo`030000oooooooo00Woool406Ko3_ooo`0306Kooooooooo09Soool006Ooool0
0`000?ooooooo`05oooo101Voa;oool00`1Vooooooooo`2Hoooo001Woooo00<0003oooooool01@1V
oaKoool00`1Vooooooooo`2Hoooo001Uoooo0P1Vo`03000006Ko06Ko01_oool00`1Vooooooooo`2H
oooo001Poooo1@1Vo`;oool200007?ooo`0306Kooooooooo09Soool001Ooool500007_ooo`800004
oooo0P0000Coool200005?ooo`@0I_l7oooo00<0003oooooool06oooo`0306Kooooooooo00800004
oooo0P0000Coool200007oooo`D0000Moooo1@0000;oool200001?ooo`80000Poooo100001Koool0
01Woool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000Aoooo0P1V
o`_oool00`000?ooooooo`0Koooo00<0I_ooool000000_ooo`030000oooooooo00Koool010000?oo
ooooo`00023oool00`000?ooooooo`0Ooooo00<0003oooooool01oooo`040000oooooooo00007ooo
o`030000oooooooo01Ooool001Woool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0
003oooooool03Oooo`80I_l=oooo00<0003oooooool07?ooo`0506Ko0000oooooooo000000_oool0
0`000?ooooooo`0Noooo00<0003oooooool07oooo`030000oooooooo00[oool00`000?ooooooo`0N
oooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool05oooo`@00002oooo00@0
003oooooool00009oooo0P0000koool206Ko3oooo`030000oooooooo01coool01@1Vo`000?oooooo
o`000009oooo0P00027oool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`80000Roooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Woool00`000?oo
ooooo`0;oooo0P1Voa7oool00`000?ooooooo`0Loooo00D0I_l0003oooooool000002Oooo`030000
oooooooo023oool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`030000oooooooo01ooool0
10000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`0000Woool206Ko4oooo`80000M
oooo00@0I_ooool00000000:oooo0`0001ooool200008?ooo`80000:oooo0`00023oool200005ooo
o`00D?ooo`80I_lEoooo00<0003oooooool07?ooo`0306Kooooooooo09Ooool004ooool00`1Voooo
ooooo`0Eoooo00<0003oooooool07?ooo`0306Kooooooooo09Ooool004goool206Ko6?ooo`030000
oooooooo01coool00`1Vooooooooo`2Goooo001<oooo00<0I_ooooooool06?ooo`030000oooooooo
01coool00`1Vooooooooo`2Goooo001:oooo0P1Voa_oool00`000?ooooooo`0Loooo00<0I_oooooo
ool0Uoooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000<co`000ol0VC?o00000007<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0000co`0co`006c?o0003o`2I<ol0<ol000Lco`000`0003?o03?o000T<ol04000
01Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol001/co`00
0ol0VC?o03?o000Y<ol01@0006[oool006Ooool00`0003?o03?o000K<ol000?o09Tco`0co`0093?o
00D0001_oooo001Woooo00<0000co`0co`006c?o0003o`2I<ol0<ol001lco`050000M?ooo`00Iooo
o`030000<ol0<ol001/co`000ol0VC?o03?o000K<ol0100007Woool006Ooool2000073?o0003o`2I
<ol0<ol001Tco`020000OOooo`00Ioooo`030000<ol0<ol001/co`000ol0VC?o03?o000G<ol00P00
07ooool006Ooool00`0003?o03?o000K<ol000?o09Tco`0co`005C?o00800021oooo001Woooo00<0
000co`0co`006c?o0003o`2I<ol0<ol001<co`020000Poooo`00Ioooo`030000<ol0<ol001/co`00
0ol0VC?o03?o000B<ol000<0003oooooool0Poooo`00Ioooo`030000<ol0<ol001/co`000ol0VC?o
03?o000@<ol00P0008Koool006Ooool2000073?o0003o`2I<ol0<ol000hco`020000R?ooo`00Iooo
o`030000<ol0<ol001/co`000ol0VC?o03?o000=<ol000<0003oooooool0R?ooo`00Ioooo`030000
<ol0<ol001/co`000ol0VC?o03?o000<<ol000<0003oooooool0ROooo`00Ioooo`030000<ol0<ol0
01/co`000ol0VC?o03?o000;<ol000<0003oooooool0R_ooo`00Ioooo`030000<ol0<ol001/co`00
0ol0VC?o03?o000:<ol000<0003oooooool0Roooo`00Ioooo`030000<ol0<ol001/co`000ol0VC?o
03?o000:<ol000<0003oooooool0Roooo`00Ioooo`80000L<ol000?o09Tco`0co`002C?o00030000
oooooooo08coool006Ooool00`0003?o03?o000K<ol000?o09Tco`0co`0023?o00030000oooooooo
08goool006Ooool00`0003?o03?o000K<ol000?o09Tco`0co`001c?o00030000oooooooo08koool0
06Ooool00`0003?o03?o000K<ol000?o09Tco`0co`001S?o00030000oooooooo08ooool006Ooool0
0`0003?o03?o000K<ol000?o09Tco`0co`001C?o00030000oooooooo093oool006Ooool00`0003?o
03?o000K<ol000?o09Tco`0co`001C?o00030000oooooooo093oool006Ooool2000073?o0003o`2I
<ol0<ol000@co`000`000?ooooooo`2Aoooo001Woooo00<0000co`0co`006c?o0003o`2I<ol0<ol0
00<co`000`000?ooooooo`2Boooo001Woooo00<0000co`0co`006c?o0003o`2I<ol0<ol0008co`00
0`000?ooooooo`2Coooo001Woooo00<0000co`0co`006c?o0003o`2I<ol0<ol0008co`000`000?oo
ooooo`2Coooo001Woooo00<0000co`0co`006c?o0005o`2I<ol0<ol0<ol0000009Koool005ooool5
00000oooo`030000<ol0<ol001/co`001Ol0VC?o03?o03?o0000002Foooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001/co`001?l0VC?o03?o000009Ooool0067oool00`000?ooooooo`03
oooo0P0001`co`001?l0VC?o03?o000009Ooool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`006c?o0003o`2I<ol0000009Soool0067oool00`000?ooooooo`03oooo00<0000co`0co`006c?o
0003o`2I<ol0000009Soool0063oool200001Oooo`030000<ol0<ol001/co`000ol0V@000?ooo`2H
oooo001Woooo00<0000co`0co`006c?o0003o`2I0000oooo09Soool006Ooool00`0003?o03?o000K
<ol000?o09Woooooool0V?ooo`00Ioooo`80000L<ol000?o09Woooooool0V?ooo`00Ioooo`030000
<ol0<ol001Xco`000`000?l0VOooo`2Ioooo001Woooo00<0000co`0co`006S?o00030000o`2Ioooo
09Woool006Ooool00`0003?o03?o000I<ol000<0003ooooo09T0V_ooo`00Ioooo`030000<ol0<ol0
01Tco`000`000?ooool0V@2Joooo001Woooo00<0000co`0co`0063?o00040000ooooooooo`2IV_oo
o`00Ioooo`80000I<ol000@0003ooooooooo09VJoooo001Woooo00<0000co`0co`005c?o00050000
ooooooooooooo`2I09[oool006Ooool00`0003?o03?o000G<ol000D0003ooooooooooooo09T0V_oo
o`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`02oooo00?o09Woooooool0V?ooo`00Iooo
o`030000<ol0<ol001Hco`000`000?ooooooo`02oooo00?o09Woooooool0V?ooo`00Ioooo`030000
<ol0<ol001Hco`000`000?ooooooo`02oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol0
01Dco`000`000?ooooooo`03oooo00?o09Woooooool0V?ooo`00Ioooo`80000F<ol000<0003ooooo
ool00oooo`03o`2Ioooooooo09Soool006Ooool00`0003?o03?o000E<ol000<0003oooooool00ooo
o`03o`2Ioooooooo09Soool006Ooool00`0003?o03?o000E<ol000<0003oooooool00oooo`03o`2I
oooooooo09Soool006Ooool00`0003?o03?o000D<ol000<0003oooooool01?ooo`03o`2Ioooooooo
09Soool006Ooool00`0003?o03?o000D<ol000<0003oooooool01?ooo`03o`2Ioooooooo09Soool0
06Ooool00`0003?o03?o000D<ol000<0003oooooool01?ooo`03o`2Ioooooooo09Soool006Ooool2
00005C?o00030000oooooooo00Coool00ol0VOooooooo`2Hoooo001Woooo00<0000co`0co`004c?o
00030000oooooooo00Goool00ol0VOooooooo`2Hoooo001Woooo00<0000co`0co`004c?o00030000
oooooooo00Goool00ol0VOooooooo`2Hoooo001Woooo00<0000co`0co`004c?o00030000oooooooo
00Goool00ol0VOooooooo`2Hoooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003ooooo
ool01Oooo`03o`2Ioooooooo09Soool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o
00030000oooooooo00Koool00ol0VOooooooo`2Hoooo001Poooo00<0003oooooool01?ooo`80000C
<ol000<0003oooooool01_ooo`03o`2Ioooooooo09Soool0067oool00`000?ooooooo`03oooo00<0
000co`0co`004S?o00030000oooooooo00Koool00ol0VOooooooo`2Hoooo001Ooooo00@0003ooooo
ool00004oooo00<0000co`0co`004C?o00030000oooooooo00Ooool00ol0VOooooooo`2Hoooo001P
oooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool01oooo`03o`2Ioooooooo09Soool0
06Ooool00`0003?o03?o000A<ol000<0003oooooool01oooo`03o`2Ioooooooo09Soool006Ooool0
0`0003?o03?o000A<ol000<0003oooooool01oooo`03o`2Ioooooooo09Soool006Ooool200004C?o
00030000oooooooo00Soool00ol0VOooooooo`2Hoooo001Woooo00<0000co`0co`0043?o00030000
oooooooo00Soool00ol0VOooooooo`2Hoooo001Woooo00<0000co`0co`0043?o00030000oooooooo
00Soool00ol0VOooooooo`2Hoooo001Woooo00<0000co`0co`0043?o00030000oooooooo00Soool0
0ol0VOooooooo`2Hoooo001Woooo00<0000co`0co`003c?o00030000oooooooo00Woool00ol0VOoo
ooooo`2Hoooo001Woooo00<0000co`0co`003c?o00030000oooooooo00Woool00ol0VOooooooo`2H
oooo001Woooo00<0000co`0co`003c?o00030000oooooooo00Woool00ol0VOooooooo`2Hoooo001W
oooo0P00010co`000`000?ooooooo`09oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`0:oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`0:oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000hco`000`000?oo
ooooo`0:oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0:
oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0;oooo00?o
09Woooooool0V?ooo`00Ioooo`80000><ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool0
06Ooool00`0003?o03?o000=<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool006Ooool0
0`0003?o03?o000=<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool006Ooool00`0003?o
03?o000<<ol000<0003oooooool03?ooo`03o`2Ioooooooo09Soool006Ooool00`0003?o03?o000<
<ol000<0003oooooool03?ooo`03o`2Ioooooooo09Soool006Ooool00`0003?o03?o000<<ol000<0
003oooooool03?ooo`03o`2Ioooooooo09Soool006Ooool200003C?o00030000oooooooo00coool0
0ol0VOooooooo`2Hoooo001Woooo00<0000co`0co`0033?o00030000oooooooo00coool00ol0VOoo
ooooo`2Hoooo001Woooo00<0000co`0co`0033?o00030000oooooooo00coool00ol0VOooooooo`2H
oooo001Woooo00<0000co`0co`002c?o00030000oooooooo00goool00ol0VOooooooo`2Hoooo001P
oooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool03Oooo`03o`2Ioooooooo09Soool0
05ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool03Oooo`03o`2I
oooooooo09Soool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`0=oooo00?o
09Woooooool0V?ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo09Soool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;
<ol000<0003oooooool03Oooo`03o`2Ioooooooo09Soool0063oool200001Oooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0>oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0>oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0>oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0>
oooo00?o09Woooooool0V?ooo`00Ioooo`80000;<ol000<0003oooooool03_ooo`03o`2Ioooooooo
09Soool006Ooool00`0003?o03?o000:<ol000<0003oooooool03_ooo`03o`2Ioooooooo09Soool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool03oooo`03o`2Ioooooooo09Soool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool03oooo`03o`2Ioooooooo09Soool006Ooool00`0003?o
03?o0009<ol000<0003oooooool03oooo`03o`2Ioooooooo09Soool006Ooool00`0003?o03?o0009
<ol000<0003oooooool03oooo`03o`2Ioooooooo09Soool006Ooool200002S?o00030000oooooooo
00ooool00ol0VOooooooo`2Hoooo001Woooo00<0000co`0co`002C?o00030000oooooooo00ooool0
0ol0VOooooooo`2Hoooo001Woooo00<0000co`0co`002C?o00030000oooooooo00ooool00ol0VOoo
ooooo`2Hoooo001Woooo00<0000co`0co`0023?o00030000oooooooo013oool00ol0VOooooooo`2H
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo013oool00ol0VOooooooo`2Hoooo001W
oooo00<0000co`0co`0023?o00030000oooooooo013oool00ol0VOooooooo`2Hoooo001Woooo0P00
00Tco`000`000?ooooooo`0@oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0@oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0@oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0A
oooo00?o09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Aoooo00?o
09Woooooool0V?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Aoooo00?o09Wooooo
ool0V?ooo`00Ioooo`800008<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Soool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Soool006Ooool00`0003?o
03?o0007<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Soool006Ooool00`0003?o03?o0007
<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Soool006Ooool00`0003?o03?o0007<ol000<0
003oooooool04Oooo`03o`2Ioooooooo09Soool0067oool300000oooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Aoooo00?o09Woooooool0V?ooo`00H_ooo`030000oooooooo00;oool00`0003?o
03?o0007<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Soool005ooool500000oooo`800008
<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Soool005ooool010000?ooooooo`0000Coool:
<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool0
06Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03Ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000coool010000?ooooooo`00
00_oool010000?ooooooooooo`800004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0
003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000
oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo017oool2
00002_ooo`800004oooo0P0000?oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8
<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46388 .12361 L
.46618 .12361 L
.46687 .12361 L
.46751 .12361 L
s
.46751 .12361 m
.46799 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20178 .12361 L
.20742 .12361 L
.21019 .12361 L
.2114 .12361 L
.21274 .12361 L
.21394 .12361 L
.21506 .123 L
.21753 .12112 L
.22272 .1173 L
.26149 .09417 L
.28262 .085 L
.30271 .07812 L
.32252 .07282 L
.34091 .06904 L
.38004 .06126 L
.42162 .05232 L
.44249 .04798 L
.45164 .04615 L
.45649 .04521 L
.46168 .04422 L
.46429 .04373 L
.46557 .04349 L
.46676 .04327 L
.46783 .04308 L
.46897 .12361 L
.47012 .12361 L
.47138 .12361 L
.48043 .12361 L
.50023 .12361 L
.54044 .12361 L
.57913 .12361 L
.62027 .12361 L
.65989 .12361 L
.698 .12361 L
.73856 .12361 L
.7776 .12361 L
.8191 .12361 L
.85908 .12361 L
.89755 .12361 L
.93847 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0Koooo0`1V
oiSoool006Ooool00`000?ooooooo`0Doooo1`1Vo`;oool00`1Vooooooooo`2Foooo001Woooo0P00
017oool406Ko2Oooo`0306Kooooooooo09Koool006Ooool00`000?ooooooo`0=oooo0`1Vo`goool0
0`1Vooooooooo`2Foooo001Woooo00<0003oooooool02Oooo`@0I_l@oooo00<0I_ooooooool0U_oo
o`00Ioooo`030000oooooooo00Goool406Ko5?ooo`0306Kooooooooo09Koool006Ooool00`000?oo
ooooo`0506Ko6?ooo`0306Kooooooooo09Koool006Goool206Ko00<00000I_l0I_l07Oooo`0306Ko
oooooooo09Koool0063oool506Ko0_ooo`80000Noooo00<0I_ooooooool0U_ooo`005oooo`D0000N
oooo0P0000Coool200001?ooo`80000Doooo101Vo`Ooool00`000?ooooooo`0Moooo00<0I_l00000
00001?ooo`800004oooo0P0001ooool500007Oooo`D00002oooo0P0000Coool200008?ooo`@0000F
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00004Ooo
o`80I_l;oooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00008?oo
o`030000oooooooo01ooool00`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003ooooo
ool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0<
oooo0`1Vo`goool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool07_oo
o`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Ooo
o`80000<oooo0`1Voa3oool00`000?ooooooo`0Moooo00@0003oooooool00009oooo0P00027oool0
0`000?ooooooo`0Ooooo00<0003oooooool02?ooo`80000Roooo00<0003oooooool05Oooo`006Ooo
o`030000oooooooo01goool010000?ooooooo`0000Woool00`000?ooooooo`09oooo0P1Voa?oool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?oo
o`80000Poooo0P0000[oool300001oooo`80I_lEoooo0P0001koool00`1Vo`000000000:oooo0`00
01ooool200008?ooo`80000:oooo0`00023oool200005oooo`00Coooo`0306Kooooooooo01Goool0
0`000?ooooooo`0Moooo00<0I_ooooooool0U_ooo`00COooo`80I_lHoooo00<0003oooooool07Ooo
o`0306Kooooooooo09Koool004coool00`1Vooooooooo`0Hoooo00<0003oooooool07Oooo`0306Ko
oooooooo09Koool004[oool206Ko6oooo`030000oooooooo01goool00`1Vooooooooo`2Foooo0019
oooo00<0I_ooooooool06oooo`030000oooooooo01goool00`1Vooooooooo`2Foooo000@ooooo`00
017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004
<ol0:00000;oool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`0003?o
03?o000M<ol000?o09Tco`0co`001C?o00030000<ol0<ol002@co`0@00006Oooo`030000oooooooo
02Koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`007C?o0003o`2I<ol0<ol002Lco`05
0000J_ooo`00Ioooo`030000<ol0<ol001dco`000ol0VC?o03?o000R<ol01@0006ooool006Ooool0
0`0003?o03?o000M<ol000?o09Tco`0co`007C?o00D0001doooo001Woooo00<0000co`0co`007C?o
0003o`2I<ol0<ol001Tco`040000NOooo`00Ioooo`80000N<ol000?o09Tco`0co`005c?o0080001m
oooo001Woooo00<0000co`0co`007C?o0003o`2I<ol0<ol001Dco`020000Ooooo`00Ioooo`030000
<ol0<ol001dco`000ol0VC?o03?o000C<ol00P00087oool006Ooool00`0003?o03?o000M<ol000?o
09Tco`0co`004C?o00800023oooo001Woooo00<0000co`0co`007C?o0003o`2I<ol0<ol0010co`00
0`000?ooooooo`23oooo001Woooo00<0000co`0co`007C?o0003o`2I<ol0<ol000hco`020000Q_oo
o`00Ioooo`80000N<ol000?o09Tco`0co`0033?o00800028oooo001Woooo00<0000co`0co`007C?o
0003o`2I<ol0<ol000/co`000`000?ooooooo`28oooo001Woooo00<0000co`0co`007C?o0003o`2I
<ol0<ol000Xco`000`000?ooooooo`29oooo001Woooo00<0000co`0co`007C?o0003o`2I<ol0<ol0
00Tco`000`000?ooooooo`2:oooo001Woooo00<0000co`0co`007C?o0003o`2I<ol0<ol000Pco`00
0`000?ooooooo`2;oooo001Woooo00<0000co`0co`007C?o0003o`2I<ol0<ol000Pco`000`000?oo
ooooo`2;oooo001Woooo0P0001hco`000ol0VC?o03?o0007<ol000<0003oooooool0S?ooo`00Iooo
o`030000<ol0<ol001dco`000ol0VC?o03?o0006<ol000<0003oooooool0SOooo`00Ioooo`030000
<ol0<ol001dco`000ol0VC?o03?o0005<ol000<0003oooooool0S_ooo`00Ioooo`030000<ol0<ol0
01dco`000ol0VC?o03?o0004<ol000<0003oooooool0Soooo`00Ioooo`030000<ol0<ol001dco`00
0ol0VC?o03?o0003<ol000<0003oooooool0T?ooo`00Ioooo`030000<ol0<ol001dco`000ol0VC?o
03?o0003<ol000<0003oooooool0T?ooo`00Ioooo`80000N<ol000?o09Tco`0co`000S?o00030000
oooooooo097oool006Ooool00`0003?o03?o000M<ol000Go09Tco`0co`0co`000000U?ooo`00Iooo
o`030000<ol0<ol001dco`001?l0VC?o03?o000009Goool006Ooool00`0003?o03?o000M<ol000Co
09Tco`0co`00002Eoooo001Woooo00<0000co`0co`007C?o0003o`2I<ol0000009Koool005ooool5
00000oooo`030000<ol0<ol001dco`000ol0VC?o0000002Foooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000ol0V@000?ooo`2Foooo001Qoooo00<0003oooooool00oooo`80000N
<ol000?o09T0003oool0U_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000?o
09Woooooool0U_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000?o09Wooooo
ool0U_ooo`00H?ooo`800005oooo00<0000co`0co`0073?o00030000o`2Ioooo09Ooool006Ooool0
0`0003?o03?o000L<ol000<0003o09Woool0Uoooo`00Ioooo`030000<ol0<ol001/co`000`000?oo
ool0V@2Hoooo001Woooo0P0001`co`000`000?ooool0V@2Hoooo001Woooo00<0000co`0co`006S?o
00040000ooooooooo`2IV?ooo`00Ioooo`030000<ol0<ol001Xco`0010000?ooooooool0VISoool0
06Ooool00`0003?o03?o000I<ol000D0003ooooooooooooo09T0V?ooo`00Ioooo`030000<ol0<ol0
01Tco`001@000?ooooooooooool0V@2Hoooo001Woooo00<0000co`0co`0063?o00030000oooooooo
00;oool00ol0VOooooooo`2Foooo001Woooo0P0001Tco`000`000?ooooooo`02oooo00?o09Wooooo
ool0U_ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`03oooo00?o09Woooooool0U_oo
o`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`03oooo00?o09Woooooool0U_ooo`00Iooo
o`030000<ol0<ol001Hco`000`000?ooooooo`04oooo00?o09Woooooool0U_ooo`00Ioooo`030000
<ol0<ol001Hco`000`000?ooooooo`04oooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol0
01Hco`000`000?ooooooo`04oooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol001Dco`00
0`000?ooooooo`05oooo00?o09Woooooool0U_ooo`00Ioooo`80000F<ol000<0003oooooool01Ooo
o`03o`2Ioooooooo09Koool006Ooool00`0003?o03?o000E<ol000<0003oooooool01Oooo`03o`2I
oooooooo09Koool006Ooool00`0003?o03?o000E<ol000<0003oooooool01Oooo`03o`2Ioooooooo
09Koool006Ooool00`0003?o03?o000D<ol000<0003oooooool01_ooo`03o`2Ioooooooo09Koool0
06Ooool00`0003?o03?o000D<ol000<0003oooooool01_ooo`03o`2Ioooooooo09Koool006Ooool0
0`0003?o03?o000D<ol000<0003oooooool01_ooo`03o`2Ioooooooo09Koool006Ooool200005C?o
00030000oooooooo00Koool00ol0VOooooooo`2Foooo001Woooo00<0000co`0co`004c?o00030000
oooooooo00Ooool00ol0VOooooooo`2Foooo001Woooo00<0000co`0co`004c?o00030000oooooooo
00Ooool00ol0VOooooooo`2Foooo001Woooo00<0000co`0co`004c?o00030000oooooooo00Ooool0
0ol0VOooooooo`2Foooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003oooooool01ooo
o`03o`2Ioooooooo09Koool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000
oooooooo00Soool00ol0VOooooooo`2Foooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0
003oooooool02?ooo`03o`2Ioooooooo09Koool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`004S?o00030000oooooooo00Soool00ol0VOooooooo`2Foooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`004C?o00030000oooooooo00Woool00ol0VOooooooo`2Foooo001Poooo0P00
00Goool00`0003?o03?o000A<ol000<0003oooooool02Oooo`03o`2Ioooooooo09Koool006Ooool0
0`0003?o03?o000A<ol000<0003oooooool02Oooo`03o`2Ioooooooo09Koool006Ooool00`0003?o
03?o000A<ol000<0003oooooool02Oooo`03o`2Ioooooooo09Koool006Ooool200004C?o00030000
oooooooo00[oool00ol0VOooooooo`2Foooo001Woooo00<0000co`0co`0043?o00030000oooooooo
00[oool00ol0VOooooooo`2Foooo001Woooo00<0000co`0co`0043?o00030000oooooooo00[oool0
0ol0VOooooooo`2Foooo001Woooo00<0000co`0co`0043?o00030000oooooooo00[oool00ol0VOoo
ooooo`2Foooo001Woooo00<0000co`0co`003c?o00030000oooooooo00_oool00ol0VOooooooo`2F
oooo001Woooo00<0000co`0co`003c?o00030000oooooooo00_oool00ol0VOooooooo`2Foooo001W
oooo00<0000co`0co`003c?o00030000oooooooo00_oool00ol0VOooooooo`2Foooo001Woooo0P00
010co`000`000?ooooooo`0;oooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`0<oooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000hco`000`000?oo
ooooo`0<oooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0<
oooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0<oooo00?o
09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0=oooo00?o09Wooooo
ool0U_ooo`00Ioooo`80000><ol000<0003oooooool03Oooo`03o`2Ioooooooo09Koool006Ooool0
0`0003?o03?o000=<ol000<0003oooooool03Oooo`03o`2Ioooooooo09Koool006Ooool00`0003?o
03?o000=<ol000<0003oooooool03Oooo`03o`2Ioooooooo09Koool006Ooool00`0003?o03?o000<
<ol000<0003oooooool03_ooo`03o`2Ioooooooo09Koool006Ooool00`0003?o03?o000<<ol000<0
003oooooool03_ooo`03o`2Ioooooooo09Koool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool03_ooo`03o`2Ioooooooo09Koool006Ooool200003C?o00030000oooooooo00koool00ol0VOoo
ooooo`2Foooo001Woooo00<0000co`0co`0033?o00030000oooooooo00koool00ol0VOooooooo`2F
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo00koool00ol0VOooooooo`2Foooo001W
oooo00<0000co`0co`002c?o00030000oooooooo00ooool00ol0VOooooooo`2Foooo001Poooo0P00
00Goool00`0003?o03?o000;<ol000<0003oooooool03oooo`03o`2Ioooooooo09Koool005ooool0
10000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool03oooo`03o`2Ioooooooo
09Koool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`0?oooo00?o09Wooooo
ool0U_ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool03ooo
o`03o`2Ioooooooo09Koool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0
003oooooool03oooo`03o`2Ioooooooo09Koool0063oool200001Oooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0@oooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0@oooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0@
oooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0@oooo00?o
09Woooooool0U_ooo`00Ioooo`80000;<ol000<0003oooooool04?ooo`03o`2Ioooooooo09Koool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool04?ooo`03o`2Ioooooooo09Koool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Koool006Ooool00`0003?o
03?o0009<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Koool006Ooool00`0003?o03?o0009
<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Koool006Ooool00`0003?o03?o0009<ol000<0
003oooooool04Oooo`03o`2Ioooooooo09Koool006Ooool200002S?o00030000oooooooo017oool0
0ol0VOooooooo`2Foooo001Woooo00<0000co`0co`002C?o00030000oooooooo017oool00ol0VOoo
ooooo`2Foooo001Woooo00<0000co`0co`002C?o00030000oooooooo017oool00ol0VOooooooo`2F
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo01;oool00ol0VOooooooo`2Foooo001W
oooo00<0000co`0co`0023?o00030000oooooooo01;oool00ol0VOooooooo`2Foooo001Woooo00<0
000co`0co`0023?o00030000oooooooo01;oool00ol0VOooooooo`2Foooo001Woooo0P0000Tco`00
0`000?ooooooo`0Boooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0Boooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0B
oooo00?o09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Coooo00?o
09Woooooool0U_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Coooo00?o09Wooooo
ool0U_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Coooo00?o09Woooooool0U_oo
o`00Ioooo`800008<ol000<0003oooooool04oooo`03o`2Ioooooooo09Koool006Ooool00`0003?o
03?o0007<ol000<0003oooooool04oooo`03o`2Ioooooooo09Koool006Ooool00`0003?o03?o0007
<ol000<0003oooooool04oooo`03o`2Ioooooooo09Koool006Ooool00`0003?o03?o0007<ol000<0
003oooooool04oooo`03o`2Ioooooooo09Koool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo09Koool0067oool300000oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Coooo00?o09Woooooool0U_ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007
<ol000<0003oooooool04oooo`03o`2Ioooooooo09Koool005ooool500000oooo`800008<ol000<0
003oooooool04oooo`03o`2Ioooooooo09Koool005ooool010000?ooooooo`0000Coool:<ol0[ooo
o`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9
<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00coool00`000?ooooooo`0Roooo00<0003ooooo
ool0O?ooo`00Ioooo`Tco`0;oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?oo
ooooo`1koooo001Woooo2C?o00_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000Coool200001Oooo`<00002oooo00<0003oooooool0Noooo`00Ioooo`Tco`0;oooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool0000;oooo00D0003oooooooooool00000OOooo`00Ioooo`Tco`0:oooo00<0003oooooool00_oo
o`030000oooooooo00goool010000?ooooooo`0000Soool500000oooo`030000oooooooo07[oool0
06Ooool9<ol02oooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0Noooo`00Ioooo`Tco`0;oooo00D0003oooooooooool000003ooo
o`040000oooooooo00002Oooo`030000oooo000000?oool00`000?ooooooo`1koooo001Woooo2C?o
00coool00`000?ooooooo`0Aoooo0P0000_oool200000_ooo`030000oooooooo07coool006Ooool9
<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46618 .12361 L
.46854 .12361 L
.47106 .12361 L
.47231 .12361 L
.47348 .12361 L
.47453 .12361 L
s
.47453 .12361 m
.47498 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.19227 .12361 L
.20178 .12361 L
.20433 .12361 L
.20573 .12361 L
.20704 .12361 L
.20772 .12361 L
.20845 .12321 L
.21 .12201 L
.21274 .11995 L
.22272 .11287 L
.24243 .10078 L
.26394 .09009 L
.28477 .08189 L
.30365 .07601 L
.32332 .07123 L
.3443 .06741 L
.38436 .05983 L
.42291 .05183 L
.44246 .04785 L
.45281 .04582 L
.46392 .04372 L
.4694 .04272 L
.4721 .04223 L
.47329 .04202 L
.4746 .04179 L
.47576 .12361 L
.47686 .12361 L
.47926 .12361 L
.48434 .12361 L
.5034 .12361 L
.54209 .12361 L
.58323 .12361 L
.62285 .12361 L
.66096 .12361 L
.70152 .12361 L
.74057 .12361 L
.78207 .12361 L
.82205 .12361 L
.86052 .12361 L
.90143 .12361 L
.94084 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0Koooo1@1V
oiKoool006Ooool00`000?ooooooo`0Doooo1`1Vo`Coool00`1Vooooooooo`2Doooo001Woooo0P00
013oool506Ko2oooo`0306Kooooooooo09Coool006Ooool00`000?ooooooo`0;oooo101Voa3oool0
0`1Vooooooooo`2Doooo001Woooo00<0003oooooool01_ooo`D0I_lDoooo00<0I_ooooooool0U?oo
o`00Ioooo`030000oooooooo00H0I_lIoooo00<0I_ooooooool0U?ooo`00IOooo`80I_l00`00001V
o`1Vo`0Ooooo00<0I_ooooooool0U?ooo`00H?ooo`D0I_l2oooo00<0003oooooool07oooo`0306Ko
oooooooo09Coool005coool406Ko1oooo`80000Poooo00<0I_ooooooool0U?ooo`005oooo`D0000N
oooo0P0000Coool200001?ooo`80000Boooo0P1Vo`_oool00`000?ooooooo`0Noooo0P0000Coool2
00001?ooo`80000Ooooo1@0001goool500000_ooo`800004oooo0P00023oool400005_ooo`006Ooo
o`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`0000koool306Ko3Ooo
o`030000oooooooo01goool010000?ooo`1Vo`0000Soool010000?ooooooo`00023oool00`000?oo
ooooo`0Ooooo00<0003oooooool01oooo`040000oooooooo00007oooo`030000oooooooo01Ooool0
01Woool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool02_ooo`80I_l@
oooo00<0003oooooool07Oooo`040000oooo06Ko00002oooo`030000oooooooo01koool00`000?oo
ooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo01koool00`000?ooooooo`0Foooo000A
oooo100000Coool00`000?ooooooo`0Goooo100000;oool010000?ooooooo`0000Woool200002ooo
o`80I_lBoooo00<0003oooooool07Oooo`040000oooo06Ko00002Oooo`80000Qoooo00<0003ooooo
ool07oooo`030000oooooooo00Soool200008_ooo`030000oooooooo01Goool001Woool00`000?oo
ooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool02?ooo`80I_lDoooo00<0003ooooo
ool07Oooo`040000oooo06Ko00002Oooo`030000oooooooo023oool00`000?ooooooo`0Ooooo00<0
003oooooool02?ooo`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200008?oo
o`80000:oooo0`0000Koool206Ko5_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo001>oooo00<0I_ooooooool05_ooo`030000oooooooo01ooool0
0`1Vooooooooo`2Doooo001<oooo0P1VoaWoool00`000?ooooooo`0Ooooo00<0I_ooooooool0U?oo
o`00B_ooo`80I_lKoooo00<0003oooooool07oooo`0306Kooooooooo09Coool004Soool206Ko7Ooo
o`030000oooooooo01ooool00`1Vooooooooo`2Doooo0016oooo0P1Voaooool00`000?ooooooo`0O
oooo00<0I_ooooooool0U?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o0?l0V@05<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0000co`0co`007c?o0003o`2I<ol0<ol000<co`000`0003?o
03?o000T<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000
<ol0<ol001lco`000ol0VC?o03?o000U<ol01@0006[oool006Ooool00`0003?o03?o000O<ol000?o
09Tco`0co`0083?o00D0001_oooo001Woooo00<0000co`0co`007c?o0003o`2I<ol0<ol001/co`05
0000M?ooo`00Ioooo`030000<ol0<ol001lco`000ol0VC?o03?o000G<ol0100007Woool006Ooool2
000083?o0003o`2I<ol0<ol001Dco`020000OOooo`00Ioooo`030000<ol0<ol001lco`000ol0VC?o
03?o000C<ol00P0007ooool006Ooool00`0003?o03?o000O<ol000?o09Tco`0co`004C?o00800021
oooo001Woooo00<0000co`0co`007c?o0003o`2I<ol0<ol000lco`020000Poooo`00Ioooo`030000
<ol0<ol001lco`000ol0VC?o03?o000><ol000<0003oooooool0Poooo`00Ioooo`030000<ol0<ol0
01lco`000ol0VC?o03?o000<<ol00P0008Koool006Ooool2000083?o0003o`2I<ol0<ol000Xco`02
0000R?ooo`00Ioooo`030000<ol0<ol001lco`000ol0VC?o03?o0009<ol000<0003oooooool0R?oo
o`00Ioooo`030000<ol0<ol001lco`000ol0VC?o03?o0008<ol000<0003oooooool0ROooo`00Iooo
o`030000<ol0<ol001lco`000ol0VC?o03?o0007<ol000<0003oooooool0R_ooo`00Ioooo`030000
<ol0<ol001lco`000ol0VC?o03?o0006<ol000<0003oooooool0Roooo`00Ioooo`030000<ol0<ol0
01lco`000ol0VC?o03?o0006<ol000<0003oooooool0Roooo`00Ioooo`80000P<ol000?o09Tco`0c
o`001C?o00030000oooooooo08coool006Ooool00`0003?o03?o000O<ol000?o09Tco`0co`0013?o
00030000oooooooo08goool006Ooool00`0003?o03?o000O<ol000?o09Tco`0co`000c?o00030000
oooooooo08koool006Ooool00`0003?o03?o000O<ol000?o09Tco`0co`000S?o00030000oooooooo
08ooool006Ooool00`0003?o03?o000O<ol000Go09Tco`0co`0co`000000T_ooo`00Ioooo`030000
<ol0<ol001lco`001Ol0VC?o03?o03?o0000002Boooo001Woooo0P00020co`001?l0VC?o03?o0000
09?oool006Ooool00`0003?o03?o000O<ol000?o09Tco`000000U?ooo`00Ioooo`030000<ol0<ol0
01lco`000ol0V@000?ooo`2Doooo001Woooo00<0000co`0co`007c?o0003o`2I0000oooo09Coool0
06Ooool00`0003?o03?o000O<ol000?o09Woooooool0U?ooo`00Goooo`D00003oooo00<0000co`0c
o`007c?o0003o`2Ioooooooo09Coool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o
00030000o`2Ioooo09Goool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?l0VOooo`2E
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooool0V@2Foooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooool0V@2Foooo001Poooo0P00
00Goool00`0003?o03?o000L<ol000@0003ooooooooo09VFoooo001Woooo00<0000co`0co`0073?o
00040000ooooooooo`2IU_ooo`00Ioooo`030000<ol0<ol001/co`001@000?ooooooooooool0V@2F
oooo001Woooo0P0001`co`001@000?ooooooooooool0V@2Foooo001Woooo00<0000co`0co`006S?o
00030000oooooooo00;oool00ol0VOooooooo`2Doooo001Woooo00<0000co`0co`006S?o00030000
oooooooo00;oool00ol0VOooooooo`2Doooo001Woooo00<0000co`0co`006C?o00030000oooooooo
00?oool00ol0VOooooooo`2Doooo001Woooo00<0000co`0co`006C?o00030000oooooooo00?oool0
0ol0VOooooooo`2Doooo001Woooo00<0000co`0co`0063?o00030000oooooooo00Coool00ol0VOoo
ooooo`2Doooo001Woooo0P0001Tco`000`000?ooooooo`04oooo00?o09Woooooool0U?ooo`00Iooo
o`030000<ol0<ol001Lco`000`000?ooooooo`05oooo00?o09Woooooool0U?ooo`00Ioooo`030000
<ol0<ol001Lco`000`000?ooooooo`05oooo00?o09Woooooool0U?ooo`00Ioooo`030000<ol0<ol0
01Hco`000`000?ooooooo`06oooo00?o09Woooooool0U?ooo`00Ioooo`030000<ol0<ol001Hco`00
0`000?ooooooo`06oooo00?o09Woooooool0U?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?oo
ooooo`06oooo00?o09Woooooool0U?ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`07
oooo00?o09Woooooool0U?ooo`00Ioooo`80000F<ol000<0003oooooool01oooo`03o`2Ioooooooo
09Coool006Ooool00`0003?o03?o000E<ol000<0003oooooool01oooo`03o`2Ioooooooo09Coool0
06Ooool00`0003?o03?o000E<ol000<0003oooooool01oooo`03o`2Ioooooooo09Coool006Ooool0
0`0003?o03?o000D<ol000<0003oooooool02?ooo`03o`2Ioooooooo09Coool006Ooool00`0003?o
03?o000D<ol000<0003oooooool02?ooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o000D
<ol000<0003oooooool02?ooo`03o`2Ioooooooo09Coool006Ooool200005C?o00030000oooooooo
00Soool00ol0VOooooooo`2Doooo001Woooo00<0000co`0co`004c?o00030000oooooooo00Woool0
0ol0VOooooooo`2Doooo001Woooo00<0000co`0co`004c?o00030000oooooooo00Woool00ol0VOoo
ooooo`2Doooo001Woooo00<0000co`0co`004c?o00030000oooooooo00Woool00ol0VOooooooo`2D
oooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003oooooool02Oooo`03o`2Ioooooooo
09Coool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo00[oool0
0ol0VOooooooo`2Doooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool02_oo
o`03o`2Ioooooooo09Coool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000
oooooooo00[oool00ol0VOooooooo`2Doooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`004C?o00030000oooooooo00_oool00ol0VOooooooo`2Doooo001Poooo0P0000Goool00`0003?o
03?o000A<ol000<0003oooooool02oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o000A
<ol000<0003oooooool02oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o000A<ol000<0
003oooooool02oooo`03o`2Ioooooooo09Coool006Ooool200004C?o00030000oooooooo00coool0
0ol0VOooooooo`2Doooo001Woooo00<0000co`0co`0043?o00030000oooooooo00coool00ol0VOoo
ooooo`2Doooo001Woooo00<0000co`0co`0043?o00030000oooooooo00coool00ol0VOooooooo`2D
oooo001Woooo00<0000co`0co`0043?o00030000oooooooo00coool00ol0VOooooooo`2Doooo001W
oooo00<0000co`0co`003c?o00030000oooooooo00goool00ol0VOooooooo`2Doooo001Woooo00<0
000co`0co`003c?o00030000oooooooo00goool00ol0VOooooooo`2Doooo001Woooo00<0000co`0c
o`003c?o00030000oooooooo00goool00ol0VOooooooo`2Doooo001Woooo0P00010co`000`000?oo
ooooo`0=oooo00?o09Woooooool0U?ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0>
oooo00?o09Woooooool0U?ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0>oooo00?o
09Woooooool0U?ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0>oooo00?o09Wooooo
ool0U?ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0>oooo00?o09Woooooool0U?oo
o`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0?oooo00?o09Woooooool0U?ooo`00Iooo
o`80000><ol000<0003oooooool03oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o000=
<ol000<0003oooooool03oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o000=<ol000<0
003oooooool03oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o000<<ol000<0003oooooool04?oo
o`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o000<<ol000<0003oooooool04?ooo`03o`2I
oooooooo09Coool006Ooool200003C?o00030000oooooooo013oool00ol0VOooooooo`2Doooo001W
oooo00<0000co`0co`0033?o00030000oooooooo013oool00ol0VOooooooo`2Doooo001Woooo00<0
000co`0co`0033?o00030000oooooooo013oool00ol0VOooooooo`2Doooo001Woooo00<0000co`0c
o`002c?o00030000oooooooo017oool00ol0VOooooooo`2Doooo001Poooo0P0000Goool00`0003?o
03?o000;<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Coool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool04Oooo`03o`2Ioooooooo09Coool0067oool0
0`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`0Aoooo00?o09Woooooool0U?ooo`00H_oo
o`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool04Oooo`03o`2Ioooooooo
09Coool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo09Coool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`0B
oooo00?o09Woooooool0U?ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Boooo00?o
09Woooooool0U?ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Boooo00?o09Wooooo
ool0U?ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Boooo00?o09Woooooool0U?oo
o`00Ioooo`80000;<ol000<0003oooooool04_ooo`03o`2Ioooooooo09Coool006Ooool00`0003?o
03?o000:<ol000<0003oooooool04_ooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o0009
<ol000<0003oooooool04oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o0009<ol000<0
003oooooool04oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool04ooo
o`03o`2Ioooooooo09Coool006Ooool200002S?o00030000oooooooo01?oool00ol0VOooooooo`2D
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo01?oool00ol0VOooooooo`2Doooo001W
oooo00<0000co`0co`002C?o00030000oooooooo01?oool00ol0VOooooooo`2Doooo001Woooo00<0
000co`0co`0023?o00030000oooooooo01Coool00ol0VOooooooo`2Doooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo01Coool00ol0VOooooooo`2Doooo001Woooo00<0000co`0co`0023?o
00030000oooooooo01Coool00ol0VOooooooo`2Doooo001Woooo0P0000Tco`000`000?ooooooo`0D
oooo00?o09Woooooool0U?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Doooo00?o
09Woooooool0U?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Doooo00?o09Wooooo
ool0U?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Eoooo00?o09Woooooool0U?oo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Eoooo00?o09Woooooool0U?ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Eoooo00?o09Woooooool0U?ooo`00Ioooo`800008
<ol000<0003oooooool05Oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o0007<ol000<0
003oooooool05Oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool05Oooo`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo09Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool05Oooo`03o`2I
oooooooo09Coool0067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`0Eoooo00?o
09Woooooool0U?ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003ooooo
ool05Oooo`03o`2Ioooooooo09Coool005ooool500000oooo`800008<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo09Coool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000
oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Iooo
o`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Iooo
o`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool2
00001Oooo`<000000oooo`000000000200000oooo`030000oooooooo07Soool006Ooool9<ol02?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000
oooooooo00002oooo`040000oooooooo00001_ooo`030000oooooooo07Soool006Ooool9<ol01ooo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo1@0000;oool0
0`000?ooooooo`04oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@00
00coool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000003oooo`040000oooooooo
00002Oooo`030000oooo000000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001W
oooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000_oool200000oooo`800003oooo00<0003ooooo
ool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47567 .12361 L
.47791 .12361 L
.47889 .12361 L
.47994 .12361 L
s
.47994 .12361 m
.48043 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.18221 .12361 L
.18703 .12361 L
.19227 .12361 L
.19467 .12361 L
.19721 .12361 L
.19939 .12361 L
.20062 .12361 L
.20178 .12346 L
.20307 .12246 L
.20448 .12138 L
.20705 .11946 L
.21187 .11598 L
.22272 .10871 L
.24403 .09654 L
.26336 .08762 L
.28374 .08009 L
.30249 .07462 L
.32174 .07026 L
.34256 .06674 L
.38205 .05985 L
.42002 .05226 L
.44116 .04805 L
.46044 .04435 L
.47001 .0426 L
.47506 .04171 L
.47783 .04122 L
.47918 .04099 L
.48042 .04078 L
.48152 .12361 L
.48267 .12361 L
.4851 .12361 L
.49025 .12361 L
.49935 .12361 L
.53746 .12361 L
.57802 .12361 L
.61706 .12361 L
.65856 .12361 L
.69854 .12361 L
.73701 .12361 L
.77793 .12361 L
.81733 .12361 L
.85522 .12361 L
.89556 .12361 L
.93438 .12361 L
.97566 .12361 L
Mistroke
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo023oool00`1Vooooooooo`2Coooo001Woooo00<0
003oooooool06Oooo`P0I_nEoooo001Woooo00<0003oooooool05?ooo`D0I_l7oooo00<0I_oooooo
ool0Toooo`00Ioooo`80000@oooo1@1Vo`coool00`1Vooooooooo`2Coooo001Woooo00<0003ooooo
ool02_ooo`D0I_lAoooo00<0I_ooooooool0Toooo`00Ioooo`030000oooooooo00Goool506Ko5_oo
o`0306Kooooooooo09?oool006Ooool00`000?ooooooo`0506Ko6oooo`0306Kooooooooo09?oool0
06Goool206Ko00<00000I_l0I_l08?ooo`0306Kooooooooo09?oool0063oool506Ko0_ooo`030000
oooooooo023oool00`1Vooooooooo`2Coooo001Koooo1@1Vo`Ooool200008Oooo`0306Kooooooooo
09?oool001Ooool500007_ooo`800004oooo0P0000Coool200003oooo`@0I_l<oooo00<0003ooooo
ool07_ooo`800000101Vooooooooooooo`800004oooo0P0001ooool500007Oooo`D00002oooo0P00
00Coool200008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002?oo
o`040000oooooooo00003?ooo`80I_l@oooo00<0003oooooool07Oooo`040000oooooooo00002?oo
o`040000oooooooo00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0003ooooo
ool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`00
00_oool00`000?ooooooo`08oooo0P1Voa;oool00`000?ooooooo`0Moooo00@0003oooooool0000;
oooo00<0003oooooool07_ooo`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0003ooooo
ool07_ooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_oo
o`040000oooooooo00002Oooo`800009oooo0P1VoaCoool00`000?ooooooo`0Moooo00@0003ooooo
ool00009oooo0P00027oool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`80000Roooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Woool00`000?oo
ooooo`06oooo0P1VoaKoool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003ooooo
ool08?ooo`030000oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000
oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool300001Oooo`0306Kooooooooo01Koool2
00007oooo`8000000`1Vooooooooo`07oooo0`0001ooool200008?ooo`80000:oooo0`00023oool2
00005oooo`00C?ooo`80I_lIoooo00<0003oooooool08?ooo`0306Kooooooooo09?oool004[oool2
06Ko6oooo`030000oooooooo023oool00`1Vooooooooo`2Coooo0018oooo0P1Voagoool00`000?oo
ooooo`0Poooo00<0I_ooooooool0Toooo`00A_ooo`80I_lOoooo00<0003oooooool08?ooo`0306Ko
oooooooo09?oool004Goool00`1Vooooooooo`0Ooooo00<0003oooooool08?ooo`0306Kooooooooo
09?oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000@0000co`0co`3o09T4<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0000co`0co`0083?o0003o`2I<ol0<ol0008co`000`0003?o03?o000T<ol04000
01Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol0020co`00
0ol0VC?o03?o000T<ol01@0006[oool006Ooool00`0003?o03?o000P<ol000?o09Tco`0co`007c?o
00D0001_oooo001Woooo00<0000co`0co`0083?o0003o`2I<ol0<ol001Xco`050000M?ooo`00Iooo
o`030000<ol0<ol0020co`000ol0VC?o03?o000F<ol0100007Woool006Ooool200008C?o0003o`2I
<ol0<ol001@co`020000OOooo`00Ioooo`030000<ol0<ol0020co`000ol0VC?o03?o000B<ol00P00
07ooool006Ooool00`0003?o03?o000P<ol000?o09Tco`0co`0043?o00800021oooo001Woooo00<0
000co`0co`0083?o0003o`2I<ol0<ol000hco`020000Poooo`00Ioooo`030000<ol0<ol0020co`00
0ol0VC?o03?o000=<ol000<0003oooooool0Poooo`00Ioooo`030000<ol0<ol0020co`000ol0VC?o
03?o000;<ol00P0008Koool006Ooool200008C?o0003o`2I<ol0<ol000Tco`020000R?ooo`00Iooo
o`030000<ol0<ol0020co`000ol0VC?o03?o0008<ol000<0003oooooool0R?ooo`00Ioooo`030000
<ol0<ol0020co`000ol0VC?o03?o0007<ol000<0003oooooool0ROooo`00Ioooo`030000<ol0<ol0
020co`000ol0VC?o03?o0006<ol000<0003oooooool0R_ooo`00Ioooo`030000<ol0<ol0020co`00
0ol0VC?o03?o0005<ol000<0003oooooool0Roooo`00Ioooo`030000<ol0<ol0020co`000ol0VC?o
03?o0005<ol000<0003oooooool0Roooo`00Ioooo`80000Q<ol000?o09Tco`0co`0013?o00030000
oooooooo08coool006Ooool00`0003?o03?o000P<ol000?o09Tco`0co`000c?o00030000oooooooo
08goool006Ooool00`0003?o03?o000P<ol000?o09Tco`0co`000S?o00030000oooooooo08koool0
06Ooool00`0003?o03?o000P<ol000Go09Tco`0co`0co`000000TOooo`00Ioooo`030000<ol0<ol0
020co`001?l0VC?o03?o000009;oool006Ooool00`0003?o03?o000P<ol000Co09Tco`0co`00002B
oooo001Woooo0P00024co`000ol0VC?o0000002Coooo001Woooo00<0000co`0co`0083?o0003o`2I
0000oooo09?oool006Ooool00`0003?o03?o000P<ol000?o09Woooooool0Toooo`00Ioooo`030000
<ol0<ol0020co`000ol0VOooooooo`2Coooo001Woooo00<0000co`0co`007c?o00030000o`2Ioooo
09Coool005ooool500000oooo`030000<ol0<ol001lco`000`000?l0VOooo`2Doooo001Qoooo00<0
003oooooool00oooo`030000<ol0<ol001hco`000`000?ooool0V@2Eoooo001Qoooo00<0003ooooo
ool00oooo`80000O<ol000<0003ooooo09T0UOooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o000M<ol000@0003ooooooooo09VEoooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`0010000?ooooooool0VIGoool0063oool200001Oooo`030000<ol0<ol001`co`001@000?oo
ooooooooool0V@2Eoooo001Woooo00<0000co`0co`0073?o00050000ooooooooooooo`2I09Goool0
06Ooool00`0003?o03?o000K<ol000<0003oooooool00_ooo`03o`2Ioooooooo09?oool006Ooool2
000073?o00030000oooooooo00;oool00ol0VOooooooo`2Coooo001Woooo00<0000co`0co`006S?o
00030000oooooooo00?oool00ol0VOooooooo`2Coooo001Woooo00<0000co`0co`006S?o00030000
oooooooo00?oool00ol0VOooooooo`2Coooo001Woooo00<0000co`0co`006C?o00030000oooooooo
00Coool00ol0VOooooooo`2Coooo001Woooo00<0000co`0co`006C?o00030000oooooooo00Coool0
0ol0VOooooooo`2Coooo001Woooo00<0000co`0co`0063?o00030000oooooooo00Goool00ol0VOoo
ooooo`2Coooo001Woooo0P0001Tco`000`000?ooooooo`05oooo00?o09Woooooool0Toooo`00Iooo
o`030000<ol0<ol001Lco`000`000?ooooooo`06oooo00?o09Woooooool0Toooo`00Ioooo`030000
<ol0<ol001Lco`000`000?ooooooo`06oooo00?o09Woooooool0Toooo`00Ioooo`030000<ol0<ol0
01Hco`000`000?ooooooo`07oooo00?o09Woooooool0Toooo`00Ioooo`030000<ol0<ol001Hco`00
0`000?ooooooo`07oooo00?o09Woooooool0Toooo`00Ioooo`030000<ol0<ol001Hco`000`000?oo
ooooo`07oooo00?o09Woooooool0Toooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`08
oooo00?o09Woooooool0Toooo`00Ioooo`80000F<ol000<0003oooooool02?ooo`03o`2Ioooooooo
09?oool006Ooool00`0003?o03?o000E<ol000<0003oooooool02?ooo`03o`2Ioooooooo09?oool0
06Ooool00`0003?o03?o000E<ol000<0003oooooool02?ooo`03o`2Ioooooooo09?oool006Ooool0
0`0003?o03?o000D<ol000<0003oooooool02Oooo`03o`2Ioooooooo09?oool006Ooool00`0003?o
03?o000D<ol000<0003oooooool02Oooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o000D
<ol000<0003oooooool02Oooo`03o`2Ioooooooo09?oool006Ooool200005C?o00030000oooooooo
00Woool00ol0VOooooooo`2Coooo001Woooo00<0000co`0co`004c?o00030000oooooooo00[oool0
0ol0VOooooooo`2Coooo001Woooo00<0000co`0co`004c?o00030000oooooooo00[oool00ol0VOoo
ooooo`2Coooo001Woooo00<0000co`0co`004c?o00030000oooooooo00[oool00ol0VOooooooo`2C
oooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003oooooool02_ooo`03o`2Ioooooooo
09?oool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo00_oool0
0ol0VOooooooo`2Coooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool02ooo
o`03o`2Ioooooooo09?oool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000
oooooooo00_oool00ol0VOooooooo`2Coooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`004C?o00030000oooooooo00coool00ol0VOooooooo`2Coooo001Poooo0P0000Goool00`0003?o
03?o000A<ol000<0003oooooool03?ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o000A
<ol000<0003oooooool03?ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o000A<ol000<0
003oooooool03?ooo`03o`2Ioooooooo09?oool006Ooool200004C?o00030000oooooooo00goool0
0ol0VOooooooo`2Coooo001Woooo00<0000co`0co`0043?o00030000oooooooo00goool00ol0VOoo
ooooo`2Coooo001Woooo00<0000co`0co`0043?o00030000oooooooo00goool00ol0VOooooooo`2C
oooo001Woooo00<0000co`0co`0043?o00030000oooooooo00goool00ol0VOooooooo`2Coooo001W
oooo00<0000co`0co`003c?o00030000oooooooo00koool00ol0VOooooooo`2Coooo001Woooo00<0
000co`0co`003c?o00030000oooooooo00koool00ol0VOooooooo`2Coooo001Woooo00<0000co`0c
o`003c?o00030000oooooooo00koool00ol0VOooooooo`2Coooo001Woooo0P00010co`000`000?oo
ooooo`0>oooo00?o09Woooooool0Toooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0?
oooo00?o09Woooooool0Toooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0?oooo00?o
09Woooooool0Toooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0?oooo00?o09Wooooo
ool0Toooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0?oooo00?o09Woooooool0Tooo
o`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0@oooo00?o09Woooooool0Toooo`00Iooo
o`80000><ol000<0003oooooool04?ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o000=
<ol000<0003oooooool04?ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o000=<ol000<0
003oooooool04?ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool04Oooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o000<<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o000<<ol000<0003oooooool04Oooo`03o`2I
oooooooo09?oool006Ooool200003C?o00030000oooooooo017oool00ol0VOooooooo`2Coooo001W
oooo00<0000co`0co`0033?o00030000oooooooo017oool00ol0VOooooooo`2Coooo001Woooo00<0
000co`0co`0033?o00030000oooooooo017oool00ol0VOooooooo`2Coooo001Woooo00<0000co`0c
o`002c?o00030000oooooooo01;oool00ol0VOooooooo`2Coooo001Poooo0P0000Goool00`0003?o
03?o000;<ol000<0003oooooool04_ooo`03o`2Ioooooooo09?oool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool04_ooo`03o`2Ioooooooo09?oool0067oool0
0`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`0Boooo00?o09Woooooool0Toooo`00H_oo
o`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool04_ooo`03o`2Ioooooooo
09?oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool04_oo
o`03o`2Ioooooooo09?oool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`0C
oooo00?o09Woooooool0Toooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Coooo00?o
09Woooooool0Toooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Coooo00?o09Wooooo
ool0Toooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Coooo00?o09Woooooool0Tooo
o`00Ioooo`80000;<ol000<0003oooooool04oooo`03o`2Ioooooooo09?oool006Ooool00`0003?o
03?o000:<ol000<0003oooooool04oooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o0009
<ol000<0003oooooool05?ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o0009<ol000<0
003oooooool05?ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o0009<ol000<0003oooooool05?oo
o`03o`2Ioooooooo09?oool006Ooool200002S?o00030000oooooooo01Coool00ol0VOooooooo`2C
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo01Coool00ol0VOooooooo`2Coooo001W
oooo00<0000co`0co`002C?o00030000oooooooo01Coool00ol0VOooooooo`2Coooo001Woooo00<0
000co`0co`0023?o00030000oooooooo01Goool00ol0VOooooooo`2Coooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo01Goool00ol0VOooooooo`2Coooo001Woooo00<0000co`0co`0023?o
00030000oooooooo01Goool00ol0VOooooooo`2Coooo001Woooo0P0000Tco`000`000?ooooooo`0E
oooo00?o09Woooooool0Toooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Eoooo00?o
09Woooooool0Toooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Eoooo00?o09Wooooo
ool0Toooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Foooo00?o09Woooooool0Tooo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Foooo00?o09Woooooool0Toooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Foooo00?o09Woooooool0Toooo`00Ioooo`800008
<ol000<0003oooooool05_ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o0007<ol000<0
003oooooool05_ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool05_ooo`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o0007<ol000<0003oooooool05_oo
o`03o`2Ioooooooo09?oool006Ooool00`0003?o03?o0007<ol000<0003oooooool05_ooo`03o`2I
oooooooo09?oool0067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`0Foooo00?o
09Woooooool0Toooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003ooooo
ool05_ooo`03o`2Ioooooooo09?oool005ooool500000oooo`800008<ol000<0003oooooool05_oo
o`03o`2Ioooooooo09?oool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000
oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Iooo
o`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Iooo
o`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool2
00001Oooo`<00003oooo0`0000;oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00_oool00`000?ooooooo`03oooo00D0003oooooooooool00000N_ooo`00Ioooo`Tco`07oooo00<0
003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool5000000?oool00000
00000`0000?oool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003?oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Woool00`000?ooo`000003oooo00<0003oool000000oooo`030000oooooooo07Soool006Ooool9
<ol02Oooo`030000oooooooo017oool200002oooo`800004oooo0P0000;oool00`000?ooooooo`1i
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47994 .12361 L
.48231 .12361 L
.48484 .12361 L
.48559 .12361 L
.48629 .12361 L
s
.48629 .12361 m
.48682 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.18221 .12361 L
.18703 .12361 L
.18957 .12361 L
.19227 .12361 L
.1934 .12361 L
.19462 .12361 L
.19532 .12354 L
.19596 .12305 L
.19721 .12208 L
.20178 .11867 L
.22272 .10481 L
.24331 .09375 L
.26243 .08545 L
.28209 .0786 L
.30062 .0735 L
.32114 .06917 L
.33975 .06626 L
.3783 .06016 L
.4193 .05231 L
.43972 .04832 L
.45879 .0447 L
.4682 .04299 L
.47712 .04141 L
.48204 .04056 L
.48339 .04034 L
.48482 .0401 L
.48604 .03989 L
.48674 .03978 L
.48739 .12361 L
.48854 .12361 L
.48974 .12361 L
.4919 .12361 L
.49676 .12361 L
.53487 .12361 L
.57543 .12361 L
.61448 .12361 L
.65597 .12361 L
.69596 .12361 L
.73442 .12361 L
.77534 .12361 L
.81474 .12361 L
.85263 .12361 L
.89297 .12361 L
.93179 .12361 L
.97307 .12361 L
Mistroke
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo023oool306KoToooo`00Ioooo`030000oooooooo
01Woool706Ko0_ooo`0306Kooooooooo097oool006Ooool00`000?ooooooo`0Doooo1@1Vo`Woool0
0`1Vooooooooo`2Aoooo001Woooo0P00013oool506Ko3_ooo`0306Kooooooooo097oool006Ooool0
0`000?ooooooo`09oooo1P1Voa?oool00`1Vooooooooo`2Aoooo001Woooo00<0003oooooool01?oo
o`D0I_lIoooo00<0I_ooooooool0TOooo`00Ioooo`030000oooo06Ko00@0I_lNoooo00<0I_oooooo
ool0TOooo`00IOooo`80I_l00`00001Vooooo`0Roooo00<0I_ooooooool0TOooo`00H?ooo`D0I_l2
oooo00<0003oooooool08_ooo`0306Kooooooooo097oool005_oool506Ko1oooo`80000Soooo00<0
I_ooooooool0TOooo`005oooo`D0000Noooo0P0000Coool200001?ooo`80000?oooo101Vo`coool0
0`000?ooooooo`0Noooo0P0000;oool0101Vooooo`00000000Coool200007oooo`D0000Moooo1@00
00;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003ooooo
ool00008oooo00@0003oooooool0000<oooo0P1Voa3oool00`000?ooooooo`0Moooo00H0003ooooo
ool0003oool0I_l6oooo00@0003oooooool0000Poooo00<0003oooooool07oooo`030000oooooooo
00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00002oooo`030000oooooooo00Ooool306Ko4_ooo`030000oooooooo01goool0
1P000?ooooooo`000?ooo`1Vo`Woool00`000?ooooooo`0Noooo00<0003oooooool07oooo`030000
oooooooo00[oool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0
003oooooool05oooo`@00002oooo00@0003oooooool00009oooo0P0000Soool206Ko5Oooo`030000
oooooooo01goool01P000?ooooooo`000?ooo`1Vo`Ooool200008Oooo`030000oooooooo01ooool0
0`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`030000oooooooo00Goool206Ko5oooo`030000oooooooo01goool0
1P000?ooooooo`000?ooo`1Vo`Ooool00`000?ooooooo`0Poooo00<0003oooooool07oooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00023oool2
00002_ooo`<00003oooo0P1VoaWoool200007oooo`800002oooo00<0I_ooooooool01Oooo`<0000O
oooo0P00023oool200002_ooo`<0000Poooo0P0001Ooool004[oool206Ko6oooo`030000oooooooo
02;oool00`1Vooooooooo`2Aoooo0019oooo00<0I_ooooooool06oooo`030000oooooooo02;oool0
0`1Vooooooooo`2Aoooo0017oooo0P1Voakoool00`000?ooooooo`0Roooo00<0I_ooooooool0TOoo
o`00AOooo`80I_lPoooo00<0003oooooool08_ooo`0306Kooooooooo097oool004?oool206Ko8_oo
o`030000oooooooo02;oool00`1Vooooooooo`2Aoooo000@ooooo`00017oool001Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00050000<ol0<ol0<ol0o`2I00<co`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000Q<ol000Go
09Tco`0co`0co`0000009S?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool0
06Ooool00`0003?o03?o000Q<ol000?o09Tco`0co`008c?o00D0001Zoooo001Woooo00<0000co`0c
o`008C?o0003o`2I<ol0<ol001hco`050000Koooo`00Ioooo`030000<ol0<ol0024co`000ol0VC?o
03?o000I<ol01@0007Coool006Ooool00`0003?o03?o000Q<ol000?o09Tco`0co`005C?o00@0001i
oooo001Woooo0P00028co`000ol0VC?o03?o000C<ol00P0007goool006Ooool00`0003?o03?o000Q
<ol000?o09Tco`0co`004C?o0080001ooooo001Woooo00<0000co`0co`008C?o0003o`2I<ol0<ol0
00lco`020000POooo`00Ioooo`030000<ol0<ol0024co`000ol0VC?o03?o000=<ol00P0008?oool0
06Ooool00`0003?o03?o000Q<ol000?o09Tco`0co`0033?o00030000oooooooo08?oool006Ooool0
0`0003?o03?o000Q<ol000?o09Tco`0co`002S?o00800026oooo001Woooo0P00028co`000ol0VC?o
03?o0008<ol00P0008Soool006Ooool00`0003?o03?o000Q<ol000?o09Tco`0co`001c?o00030000
oooooooo08Soool006Ooool00`0003?o03?o000Q<ol000?o09Tco`0co`001S?o00030000oooooooo
08Woool006Ooool00`0003?o03?o000Q<ol000?o09Tco`0co`001C?o00030000oooooooo08[oool0
06Ooool00`0003?o03?o000Q<ol000?o09Tco`0co`0013?o00030000oooooooo08_oool006Ooool0
0`0003?o03?o000Q<ol000?o09Tco`0co`0013?o00030000oooooooo08_oool006Ooool200008S?o
0003o`2I<ol0<ol000<co`000`000?ooooooo`2<oooo001Woooo00<0000co`0co`008C?o0003o`2I
<ol0<ol0008co`000`000?ooooooo`2=oooo001Woooo00<0000co`0co`008C?o0005o`2I<ol0<ol0
<ol00000093oool006Ooool00`0003?o03?o000Q<ol000Co09Tco`0co`00002Aoooo001Woooo00<0
000co`0co`008C?o0003o`2I<ol0000009;oool006Ooool00`0003?o03?o000Q<ol000?o09Tco`00
0000T_ooo`00Ioooo`80000R<ol000?o09T0003oool0T_ooo`00Ioooo`030000<ol0<ol0024co`00
0ol0VOooooooo`2Boooo001Woooo00<0000co`0co`0083?o00030000o`2Ioooo09?oool006Ooool0
0`0003?o03?o000P<ol000<0003o09Woool0Toooo`00Ioooo`030000<ol0<ol001lco`000`000?oo
ool0V@2Doooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003ooooo09T0U?ooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000N<ol000@0003ooooooooo09VDoooo001Qoooo00<0
003oooooool00oooo`80000O<ol000@0003ooooooooo09VDoooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`001@000?ooooooooooool0V@2Doooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`001@000?ooooooooooool0V@2Doooo001Poooo0P0000Goool00`0003?o
03?o000L<ol000<0003oooooool00_ooo`03o`2Ioooooooo09;oool006Ooool00`0003?o03?o000L
<ol000<0003oooooool00_ooo`03o`2Ioooooooo09;oool006Ooool00`0003?o03?o000K<ol000<0
003oooooool00oooo`03o`2Ioooooooo09;oool006Ooool2000073?o00030000oooooooo00?oool0
0ol0VOooooooo`2Boooo001Woooo00<0000co`0co`006S?o00030000oooooooo00Coool00ol0VOoo
ooooo`2Boooo001Woooo00<0000co`0co`006S?o00030000oooooooo00Coool00ol0VOooooooo`2B
oooo001Woooo00<0000co`0co`006C?o00030000oooooooo00Goool00ol0VOooooooo`2Boooo001W
oooo00<0000co`0co`006C?o00030000oooooooo00Goool00ol0VOooooooo`2Boooo001Woooo00<0
000co`0co`0063?o00030000oooooooo00Koool00ol0VOooooooo`2Boooo001Woooo0P0001Tco`00
0`000?ooooooo`06oooo00?o09Woooooool0T_ooo`00Ioooo`030000<ol0<ol001Lco`000`000?oo
ooooo`07oooo00?o09Woooooool0T_ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`07
oooo00?o09Woooooool0T_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`08oooo00?o
09Woooooool0T_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`08oooo00?o09Wooooo
ool0T_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`08oooo00?o09Woooooool0T_oo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`09oooo00?o09Woooooool0T_ooo`00Iooo
o`80000F<ol000<0003oooooool02Oooo`03o`2Ioooooooo09;oool006Ooool00`0003?o03?o000E
<ol000<0003oooooool02Oooo`03o`2Ioooooooo09;oool006Ooool00`0003?o03?o000E<ol000<0
003oooooool02Oooo`03o`2Ioooooooo09;oool006Ooool00`0003?o03?o000D<ol000<0003ooooo
ool02_ooo`03o`2Ioooooooo09;oool006Ooool00`0003?o03?o000D<ol000<0003oooooool02_oo
o`03o`2Ioooooooo09;oool006Ooool00`0003?o03?o000D<ol000<0003oooooool02_ooo`03o`2I
oooooooo09;oool006Ooool200005C?o00030000oooooooo00[oool00ol0VOooooooo`2Boooo001W
oooo00<0000co`0co`004c?o00030000oooooooo00_oool00ol0VOooooooo`2Boooo001Woooo00<0
000co`0co`004c?o00030000oooooooo00_oool00ol0VOooooooo`2Boooo001Woooo00<0000co`0c
o`004c?o00030000oooooooo00_oool00ol0VOooooooo`2Boooo001Ooooo100000Coool00`0003?o
03?o000C<ol000<0003oooooool02oooo`03o`2Ioooooooo09;oool005ooool00`000?ooooooo`05
oooo00<0000co`0co`004S?o00030000oooooooo00coool00ol0VOooooooo`2Boooo001Poooo00<0
003oooooool01?ooo`80000C<ol000<0003oooooool03?ooo`03o`2Ioooooooo09;oool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo00goool00ol0VOooooooo`2A
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo00koool0
0ol0VOooooooo`2Aoooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool03_oo
o`03o`2Ioooooooo097oool006Ooool00`0003?o03?o000A<ol000<0003oooooool03_ooo`03o`2I
oooooooo097oool006Ooool00`0003?o03?o000A<ol000<0003oooooool03_ooo`03o`2Ioooooooo
097oool006Ooool200004C?o00030000oooooooo00ooool00ol0VOooooooo`2Aoooo001Woooo00<0
000co`0co`0043?o00030000oooooooo00ooool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo00ooool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`0043?o
00030000oooooooo00ooool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`003c?o00030000
oooooooo013oool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`003c?o00030000oooooooo
013oool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`003c?o00030000oooooooo013oool0
0ol0VOooooooo`2Aoooo001Woooo0P00010co`000`000?ooooooo`0@oooo00?o09Woooooool0TOoo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Aoooo00?o09Woooooool0TOooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`0Aoooo00?o09Woooooool0TOooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`0Aoooo00?o09Woooooool0TOooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`0Aoooo00?o09Woooooool0TOooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`0Boooo00?o09Woooooool0TOooo`00Ioooo`80000><ol000<0003oooooool04_oo
o`03o`2Ioooooooo097oool006Ooool00`0003?o03?o000=<ol000<0003oooooool04_ooo`03o`2I
oooooooo097oool006Ooool00`0003?o03?o000=<ol000<0003oooooool04_ooo`03o`2Ioooooooo
097oool006Ooool00`0003?o03?o000<<ol000<0003oooooool04oooo`03o`2Ioooooooo097oool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool04oooo`03o`2Ioooooooo097oool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool04oooo`03o`2Ioooooooo097oool006Ooool200003C?o
00030000oooooooo01?oool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`0033?o00030000
oooooooo01?oool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`0033?o00030000oooooooo
01?oool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`002c?o00030000oooooooo01Coool0
0ol0VOooooooo`2Aoooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool05?oo
o`03o`2Ioooooooo097oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0
003oooooool05?ooo`03o`2Ioooooooo097oool0067oool00`000?ooooooo`03oooo0P0000`co`00
0`000?ooooooo`0Doooo00?o09Woooooool0TOooo`00H_ooo`030000oooooooo00;oool00`0003?o
03?o000;<ol000<0003oooooool05?ooo`03o`2Ioooooooo097oool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool05?ooo`03o`2Ioooooooo097oool0063oool2
00001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0TOooo`00Iooo
o`030000<ol0<ol000Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0TOooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0TOooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0TOooo`00Ioooo`80000;<ol000<0003ooooo
ool05Oooo`03o`2Ioooooooo097oool006Ooool00`0003?o03?o000:<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo097oool006Ooool00`0003?o03?o0009<ol000<0003oooooool05_ooo`03o`2I
oooooooo097oool006Ooool00`0003?o03?o0009<ol000<0003oooooool05_ooo`03o`2Ioooooooo
097oool006Ooool00`0003?o03?o0009<ol000<0003oooooool05_ooo`03o`2Ioooooooo097oool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool05_ooo`03o`2Ioooooooo097oool006Ooool2
00002S?o00030000oooooooo01Koool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`002C?o
00030000oooooooo01Koool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`002C?o00030000
oooooooo01Koool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`0023?o00030000oooooooo
01Ooool00ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`0023?o00030000oooooooo01Ooool0
0ol0VOooooooo`2Aoooo001Woooo00<0000co`0co`0023?o00030000oooooooo01Ooool00ol0VOoo
ooooo`2Aoooo001Woooo0P0000Tco`000`000?ooooooo`0Goooo00?o09Woooooool0TOooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`0Goooo00?o09Woooooool0TOooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`0Goooo00?o09Woooooool0TOooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Hoooo00?o09Woooooool0TOooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Hoooo00?o09Woooooool0TOooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Hoooo00?o09Woooooool0TOooo`00Ioooo`800008<ol000<0003oooooool06?ooo`03o`2I
oooooooo097oool006Ooool00`0003?o03?o0007<ol000<0003oooooool06?ooo`03o`2Ioooooooo
097oool006Ooool00`0003?o03?o0007<ol000<0003oooooool06?ooo`03o`2Ioooooooo097oool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool06?ooo`03o`2Ioooooooo097oool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool06?ooo`03o`2Ioooooooo097oool0067oool300000ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Hoooo00?o09Woooooool0TOooo`00H_ooo`030000
oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool06?ooo`03o`2Ioooooooo097oool0
05ooool500000oooo`800008<ol000<0003oooooool06?ooo`03o`2Ioooooooo097oool005ooool0
10000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOoo
o`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`<000001?ooo`0000000000
00Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000_oool010000?ooooooo`00
00;oool01@000?ooooooooooo`00001joooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000oooooooo00002?ooo`D000001Oooo`000?ooooooo`000004oooo00<0
003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000coool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool300001?ooo`030000oooooooo07Soool006Ooool9<ol02?oo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0
003oooooool00oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo017oool2
00002oooo`800003oooo0`0000;oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8
<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47994 .12361 L
.48519 .12361 L
.48778 .12361 L
.49018 .12361 L
.49235 .12361 L
.49356 .12361 L
s
.49356 .12361 m
.494 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.17277 .12361 L
.18221 .12361 L
.18475 .12361 L
.18614 .12361 L
.18744 .12361 L
.18855 .12361 L
.18974 .12295 L
.19227 .12102 L
.20178 .11416 L
.22272 .10114 L
.24243 .0912 L
.26394 .08252 L
.28453 .07603 L
.30365 .07136 L
.32417 .06759 L
.34278 .06512 L
.38285 .05903 L
.4214 .05187 L
.44094 .04814 L
.4624 .04415 L
.47226 .04238 L
.48282 .04056 L
.48794 .0397 L
.49046 .03929 L
.49157 .0391 L
.49279 .03891 L
.49388 .12361 L
.49491 .12361 L
.49715 .12361 L
.50189 .12361 L
.54057 .12361 L
.58171 .12361 L
.62134 .12361 L
.65945 .12361 L
.70001 .12361 L
.73905 .12361 L
.78055 .12361 L
.82053 .12361 L
.859 .12361 L
.89992 .12361 L
.93932 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo023oool406KoT_ooo`00Ioooo`030000oooooooo
01Woool706Ko0oooo`0306Kooooooooo093oool006Ooool00`000?ooooooo`0Doooo1@1Vo`[oool0
0`1Vooooooooo`2@oooo001Woooo0P00013oool506Ko3oooo`0306Kooooooooo093oool006Ooool0
0`000?ooooooo`0:oooo1@1VoaCoool00`1Vooooooooo`2@oooo001Woooo00<0003oooooool01Ooo
o`D0I_lIoooo00<0I_ooooooool0T?ooo`00Ioooo`030000oooooooo00D0I_lNoooo00<0I_oooooo
ool0T?ooo`00H?ooo`L0I_l00`00001Vo`1Vo`0Soooo00<0I_ooooooool0T?ooo`00Foooo`D0I_l7
oooo00<0003oooooool08oooo`0306Kooooooooo093oool005Ooool406Ko3?ooo`80000Toooo00<0
I_ooooooool0T?ooo`005oooo`D0000Noooo0P0000Coool200001?ooo`80000=oooo0P1Voa3oool0
0`000?ooooooo`0Noooo0P0000?oool00`1Vo`0000000004oooo0P0001ooool500007Oooo`D00002
oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00002Oooo`<0I_lBoooo00<0003oooooool07Oooo`040000oooooooo
00000_ooo`0306Kooooooooo00?oool010000?ooooooo`00023oool00`000?ooooooo`0Ooooo00<0
003oooooool01oooo`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?oo
ooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool01Oooo`80I_lEoooo00<0003ooooo
ool07Oooo`040000oooooooo00000_ooo`0306Kooooooooo00Koool00`000?ooooooo`0Noooo00<0
003oooooool07oooo`030000oooooooo00[oool00`000?ooooooo`0Noooo00<0003oooooool05_oo
o`004Oooo`@00004oooo00<0003oooooool05oooo`@00002oooo00@0003oooooool00009oooo0P00
00Koool206Ko5oooo`030000oooooooo01goool010000?ooooooo`0000;oool00`1Vooooooooo`04
oooo0P00027oool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`80000Roooo00<0003ooooo
ool05Oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Woool00`000?ooooooo`03
oooo0P1VoaWoool00`000?ooooooo`0Moooo00@0003oooooool00002oooo00<0I_ooooooool01?oo
o`030000oooooooo023oool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`030000oooooooo
01ooool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`000003oooo06Ko06Ko
01_oool200007oooo`800003oooo00<0I_ooooooool01?ooo`<0000Ooooo0P00023oool200002_oo
o`<0000Poooo0P0001Ooool004Woool00`1Vooooooooo`0Koooo00<0003oooooool08oooo`0306Ko
oooooooo093oool004Ooool206Ko7_ooo`030000oooooooo02?oool00`1Vooooooooo`2@oooo0015
oooo0P1Vob3oool00`000?ooooooo`0Soooo00<0I_ooooooool0T?ooo`00@oooo`80I_lRoooo00<0
003oooooool08oooo`0306Kooooooooo093oool004;oool00`1Vooooooooo`0Roooo00<0003ooooo
ool08oooo`0306Kooooooooo093oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`000c?o0003o`2I<ol0000000Lco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002<co`000ol0VC?o0000000V<ol04000
01Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol002<co`00
0ol0VC?o03?o000Q<ol01@0006[oool006Ooool00`0003?o03?o000S<ol000?o09Tco`0co`0073?o
00D0001_oooo001Woooo00<0000co`0co`008c?o0003o`2I<ol0<ol001Lco`050000M?ooo`00Iooo
o`030000<ol0<ol002<co`000ol0VC?o03?o000C<ol0100007Woool006Ooool2000093?o0003o`2I
<ol0<ol0014co`020000OOooo`00Ioooo`030000<ol0<ol002<co`000ol0VC?o03?o000?<ol00P00
07ooool006Ooool00`0003?o03?o000S<ol000?o09Tco`0co`003C?o00800021oooo001Woooo00<0
000co`0co`008c?o0003o`2I<ol0<ol000/co`020000Poooo`00Ioooo`030000<ol0<ol002<co`00
0ol0VC?o03?o000:<ol000<0003oooooool0Poooo`00Ioooo`030000<ol0<ol002<co`000ol0VC?o
03?o0008<ol00P0008Koool006Ooool2000093?o0003o`2I<ol0<ol000Hco`020000R?ooo`00Iooo
o`030000<ol0<ol002<co`000ol0VC?o03?o0005<ol000<0003oooooool0R?ooo`00Ioooo`030000
<ol0<ol002<co`000ol0VC?o03?o0004<ol000<0003oooooool0ROooo`00Ioooo`030000<ol0<ol0
02<co`000ol0VC?o03?o0003<ol000<0003oooooool0R_ooo`00Ioooo`030000<ol0<ol002<co`00
0ol0VC?o03?o0002<ol000<0003oooooool0Roooo`00Ioooo`030000<ol0<ol002<co`000ol0VC?o
03?o0002<ol000<0003oooooool0Roooo`00Ioooo`80000T<ol000Go09Tco`0co`0co`000000S_oo
o`00Ioooo`030000<ol0<ol002<co`001?l0VC?o03?o000008ooool006Ooool00`0003?o03?o000S
<ol000?o09Tco`000000T?ooo`00Ioooo`030000<ol0<ol002<co`000ol0V@000?ooo`2@oooo001W
oooo00<0000co`0co`008c?o0003o`2Ioooooooo093oool006Ooool00`0003?o03?o000S<ol000?o
09Woooooool0T?ooo`00Ioooo`80000S<ol000<0003o09Woool0TOooo`00Ioooo`030000<ol0<ol0
024co`000`000?ooool0V@2Boooo001Woooo00<0000co`0co`0083?o00040000ooooooooo`2IT_oo
o`00Ioooo`030000<ol0<ol0020co`0010000?ooooooool0VI;oool006Ooool00`0003?o03?o000O
<ol000D0003ooooooooooooo09T0T_ooo`00Goooo`D00003oooo00<0000co`0co`007c?o00050000
ooooooooooooo`2I09;oool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o00030000
oooooooo00;oool00ol0VOooooooo`2@oooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0
003oooooool00_ooo`03o`2Ioooooooo093oool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`007C?o00030000oooooooo00?oool00ol0VOooooooo`2@oooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`03oooo00?o09Woooooool0T?ooo`00H?ooo`800005
oooo00<0000co`0co`0073?o00030000oooooooo00Coool00ol0VOooooooo`2@oooo001Woooo00<0
000co`0co`0073?o00030000oooooooo00Coool00ol0VOooooooo`2@oooo001Woooo00<0000co`0c
o`006c?o00030000oooooooo00Goool00ol0VOooooooo`2@oooo001Woooo0P0001`co`000`000?oo
ooooo`05oooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`06
oooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`06oooo00?o
09Woooooool0T?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`07oooo00?o09Wooooo
ool0T?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`07oooo00?o09Woooooool0T?oo
o`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`08oooo00?o09Woooooool0T?ooo`00Iooo
o`80000I<ol000<0003oooooool02?ooo`03o`2Ioooooooo093oool006Ooool00`0003?o03?o000G
<ol000<0003oooooool02Oooo`03o`2Ioooooooo093oool006Ooool00`0003?o03?o000G<ol000<0
003oooooool02Oooo`03o`2Ioooooooo093oool006Ooool00`0003?o03?o000F<ol000<0003ooooo
ool02_ooo`03o`2Ioooooooo093oool006Ooool00`0003?o03?o000F<ol000<0003oooooool02_oo
o`03o`2Ioooooooo093oool006Ooool00`0003?o03?o000F<ol000<0003oooooool02_ooo`03o`2I
oooooooo093oool006Ooool00`0003?o03?o000E<ol000<0003oooooool02oooo`03o`2Ioooooooo
093oool006Ooool200005S?o00030000oooooooo00_oool00ol0VOooooooo`2@oooo001Woooo00<0
000co`0co`005C?o00030000oooooooo00_oool00ol0VOooooooo`2@oooo001Woooo00<0000co`0c
o`005C?o00030000oooooooo00_oool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`0053?o
00030000oooooooo00coool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`0053?o00030000
oooooooo00coool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`0053?o00030000oooooooo
00coool00ol0VOooooooo`2@oooo001Woooo0P0001Dco`000`000?ooooooo`0<oooo00?o09Wooooo
ool0T?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0=oooo00?o09Woooooool0T?oo
o`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0=oooo00?o09Woooooool0T?ooo`00Iooo
o`030000<ol0<ol001<co`000`000?ooooooo`0=oooo00?o09Woooooool0T?ooo`00Goooo`@00004
oooo00<0000co`0co`004c?o00030000oooooooo00goool00ol0VOooooooo`2@oooo001Ooooo00<0
003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`0>oooo00?o09Woooooool0T?oo
o`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo00koool00ol0VOooooooo`2@
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`0>oooo00?o
09Woooooool0T?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`000`000?oo
ooooo`0?oooo00?o09Woooooool0T?ooo`00H?ooo`800005oooo00<0000co`0co`004C?o00030000
oooooooo00ooool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`004C?o00030000oooooooo
00ooool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`004C?o00030000oooooooo00ooool0
0ol0VOooooooo`2@oooo001Woooo0P00014co`000`000?ooooooo`0@oooo00?o09Woooooool0T?oo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0@oooo00?o09Woooooool0T?ooo`00Iooo
o`030000<ol0<ol0010co`000`000?ooooooo`0@oooo00?o09Woooooool0T?ooo`00Ioooo`030000
<ol0<ol0010co`000`000?ooooooo`0@oooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`0Aoooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol000lco`00
0`000?ooooooo`0Aoooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol000lco`000`000?oo
ooooo`0Aoooo00?o09Woooooool0T?ooo`00Ioooo`80000@<ol000<0003oooooool04Oooo`03o`2I
oooooooo093oool006Ooool00`0003?o03?o000><ol000<0003oooooool04_ooo`03o`2Ioooooooo
093oool006Ooool00`0003?o03?o000><ol000<0003oooooool04_ooo`03o`2Ioooooooo093oool0
06Ooool00`0003?o03?o000><ol000<0003oooooool04_ooo`03o`2Ioooooooo093oool006Ooool0
0`0003?o03?o000><ol000<0003oooooool04_ooo`03o`2Ioooooooo093oool006Ooool00`0003?o
03?o000=<ol000<0003oooooool04oooo`03o`2Ioooooooo093oool006Ooool200003S?o00030000
oooooooo01?oool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`003C?o00030000oooooooo
01?oool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`003C?o00030000oooooooo01?oool0
0ol0VOooooooo`2@oooo001Woooo00<0000co`0co`0033?o00030000oooooooo01Coool00ol0VOoo
ooooo`2@oooo001Woooo00<0000co`0co`0033?o00030000oooooooo01Coool00ol0VOooooooo`2@
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo01Coool00ol0VOooooooo`2@oooo001W
oooo0P0000dco`000`000?ooooooo`0Doooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`0Doooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`0Doooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol000/co`000`000?oo
ooooo`0Eoooo00?o09Woooooool0T?ooo`00H?ooo`800005oooo00<0000co`0co`002c?o00030000
oooooooo01Goool00ol0VOooooooo`2@oooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`002c?o00030000oooooooo01Goool00ol0VOooooooo`2@oooo001Qoooo00<0003oooooool00ooo
o`80000<<ol000<0003oooooool05Oooo`03o`2Ioooooooo093oool006;oool00`000?ooooooo`02
oooo00<0000co`0co`002c?o00030000oooooooo01Goool00ol0VOooooooo`2@oooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo01Goool00ol0VOooooooo`2@
oooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool05_ooo`03o`2Ioooooooo
093oool006Ooool00`0003?o03?o000:<ol000<0003oooooool05_ooo`03o`2Ioooooooo093oool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool05_ooo`03o`2Ioooooooo093oool006Ooool0
0`0003?o03?o000:<ol000<0003oooooool05_ooo`03o`2Ioooooooo093oool006Ooool200002c?o
00030000oooooooo01Koool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`002S?o00030000
oooooooo01Koool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`002C?o00030000oooooooo
01Ooool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`002C?o00030000oooooooo01Ooool0
0ol0VOooooooo`2@oooo001Woooo00<0000co`0co`002C?o00030000oooooooo01Ooool00ol0VOoo
ooooo`2@oooo001Woooo00<0000co`0co`002C?o00030000oooooooo01Ooool00ol0VOooooooo`2@
oooo001Woooo0P0000Xco`000`000?ooooooo`0Goooo00?o09Woooooool0T?ooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`0Goooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0Goooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0Hoooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0Hoooo00?o09Woooooool0T?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0H
oooo00?o09Woooooool0T?ooo`00Ioooo`800009<ol000<0003oooooool06?ooo`03o`2Ioooooooo
093oool006Ooool00`0003?o03?o0008<ol000<0003oooooool06?ooo`03o`2Ioooooooo093oool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool06?ooo`03o`2Ioooooooo093oool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool06Oooo`03o`2Ioooooooo093oool006Ooool00`0003?o
03?o0007<ol000<0003oooooool06Oooo`03o`2Ioooooooo093oool006Ooool00`0003?o03?o0007
<ol000<0003oooooool06Oooo`03o`2Ioooooooo093oool006Ooool2000023?o00030000oooooooo
01Woool00ol0VOooooooo`2@oooo001Woooo00<0000co`0co`001c?o00030000oooooooo01Woool0
0ol0VOooooooo`2@oooo001Woooo00<0000co`0co`001c?o00030000oooooooo01Woool00ol0VOoo
ooooo`2@oooo001Woooo00<0000co`0co`001c?o00030000oooooooo01Woool00ol0VOooooooo`2@
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo01Woool00ol0VOooooooo`2@oooo001Q
oooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool06Oooo`03o`2Ioooooooo093oool0
06;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo01Woool00ol0VOoo
ooooo`2@oooo001Ooooo1@0000?oool2000023?o00030000oooooooo01Woool00ol0VOooooooo`2@
oooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o
0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Iooo
o`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Goool300000_oo
o`800004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000;oooo00@0003ooooo
ool00002oooo00D0003oooooooooool00000N_ooo`00Ioooo`Tco`07oooo00<0003oooooool00_oo
o`030000oooooooo00goool010000?ooooooo`0000Soool5000000Goool0003oooooool000001?oo
o`030000oooooooo07Ooool006Ooool9<ol02?ooo`030000oooooooo00D0000<oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1hoooo001Woooo2C?o
00Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oool000000_oo
o`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo
017oool200002oooo`800003oooo0P0000?oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool0
06Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50007 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.17277 .12361 L
.17735 .12361 L
.17986 .12361 L
.18109 .12361 L
.18221 .12361 L
.18341 .12293 L
.1847 .12194 L
.18744 .11988 L
.19227 .11637 L
.20178 .10992 L
.22272 .09771 L
.24331 .08804 L
.26243 .08084 L
.28209 .07497 L
.30062 .07067 L
.32114 .06709 L
.33975 .06476 L
.3783 .05955 L
.4193 .05228 L
.45879 .04496 L
.47865 .04145 L
.48733 .03998 L
.4919 .03923 L
.49676 .03845 L
.49795 .03826 L
.49923 .03806 L
.49997 .03794 L
.50064 .12361 L
.50197 .12361 L
.50678 .12361 L
.51627 .12361 L
.53719 .12361 L
.57681 .12361 L
.61492 .12361 L
.65548 .12361 L
.69452 .12361 L
.73602 .12361 L
.776 .12361 L
.81447 .12361 L
.85539 .12361 L
.89479 .12361 L
.93268 .12361 L
.97302 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo02;oool406KoT?ooo`00Ioooo`030000oooooooo
01Woool906Ko0oooo`0306Kooooooooo08koool006Ooool00`000?ooooooo`0Doooo1@1Vo`coool0
0`1Vooooooooo`2>oooo001Woooo0P00013oool506Ko4Oooo`0306Kooooooooo08koool006Ooool0
0`000?ooooooo`09oooo1P1VoaKoool00`1Vooooooooo`2>oooo001Woooo00<0003oooooool00_oo
o`L0I_lLoooo00<0I_ooooooool0S_ooo`00IOooo`80I_l00`00001Vo`1Vo`0206Ko8oooo`0306Ko
oooooooo08koool0063oool506Ko0_ooo`030000oooooooo02Goool00`1Vooooooooo`2>oooo001K
oooo1@1Vo`Ooool00`000?ooooooo`0Uoooo00<0I_ooooooool0S_ooo`00Eoooo`@0I_l<oooo0P00
02Koool00`1Vooooooooo`2>oooo000Goooo1@0001koool200001?ooo`800004oooo0P0000goool2
06Ko4?ooo`030000oooooooo01koool200001?ooo`800004oooo0P0001ooool500007Oooo`D00002
oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00002?ooo`@0I_lBoooo00<0003oooooool07Oooo`040000oooooooo
00001?ooo`0506Kooooooooooooo000000;oool00`000?ooooooo`0Noooo00<0003oooooool07ooo
o`030000oooooooo00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo00?oool306Ko5_ooo`030000
oooooooo01goool010000?ooooooo`0000Coool00`1Vooooooooo`04oooo00<0003oooooool07_oo
o`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Ooo
o`800004oooo0P1VoaWoool00`000?ooooooo`0Moooo00@0003oooooool00004oooo00<0I_oooooo
ool00_ooo`80000Qoooo00<0003oooooool07oooo`030000oooooooo00Soool200008_ooo`030000
oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00@0003ooooo
ooooool206Ko6oooo`030000oooooooo01goool010000?ooooooo`0000Coool00`1Vooooooooo`02
oooo00<0003oooooool08?ooo`030000oooooooo01ooool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool3000000<0I_oooooo
ool06oooo`80000Ooooo0P0000Goool00`1Vooooooooo`02oooo0`0001ooool200008?ooo`80000:
oooo0`00023oool200005oooo`00Aoooo`80I_lNoooo00<0003oooooool09Oooo`0306Kooooooooo
08koool004Goool206Ko8?ooo`030000oooooooo02Goool00`1Vooooooooo`2>oooo0013oooo0P1V
ob;oool00`000?ooooooo`0Uoooo00<0I_ooooooool0S_ooo`00@_ooo`0306Kooooooooo02;oool0
0`000?ooooooo`0Uoooo00<0I_ooooooool0S_ooo`00@?ooo`80I_lUoooo00<0003oooooool09Ooo
o`0306Kooooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0U
oooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol0400001Woool0
0`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol002Dco`000ol0VC?o
03?o000O<ol01@0006[oool006Ooool00`0003?o03?o000U<ol000?o09Tco`0co`006S?o00D0001_
oooo001Woooo00<0000co`0co`009C?o0003o`2I<ol0<ol001Dco`050000M?ooo`00Ioooo`030000
<ol0<ol002Dco`000ol0VC?o03?o000A<ol0100007Woool006Ooool200009S?o0003o`2I<ol0<ol0
00lco`020000OOooo`00Ioooo`030000<ol0<ol002Dco`000ol0VC?o03?o000=<ol00P0007ooool0
06Ooool00`0003?o03?o000U<ol000?o09Tco`0co`002c?o00800021oooo001Woooo00<0000co`0c
o`009C?o0003o`2I<ol0<ol000Tco`020000Poooo`00Ioooo`030000<ol0<ol002Dco`000ol0VC?o
03?o0008<ol000<0003oooooool0Poooo`00Ioooo`030000<ol0<ol002Dco`000ol0VC?o03?o0006
<ol00P0008Koool006Ooool200009S?o0003o`2I<ol0<ol000@co`020000R?ooo`00Ioooo`030000
<ol0<ol002Dco`000ol0VC?o03?o0003<ol000<0003oooooool0R?ooo`00Ioooo`030000<ol0<ol0
02Dco`000ol0VC?o03?o0002<ol000<0003oooooool0ROooo`00Ioooo`030000<ol0<ol002Dco`00
1Ol0VC?o03?o03?o0000002<oooo001Woooo00<0000co`0co`009C?o0004o`2I<ol0<ol00000SOoo
o`00Ioooo`030000<ol0<ol002Dco`001?l0VC?o03?o000008goool006Ooool200009S?o0003o`2I
<ol0000008koool006Ooool00`0003?o03?o000U<ol000?o09T0003oool0S_ooo`00Ioooo`030000
<ol0<ol002Dco`000ol0VOooooooo`2>oooo001Woooo00<0000co`0co`0093?o00030000o`2Ioooo
08ooool006Ooool00`0003?o03?o000S<ol000<0003ooooo09T0T?ooo`00Ioooo`030000<ol0<ol0
02<co`000`000?ooool0V@2@oooo001Woooo0P0002<co`0010000?ooooooool0VI3oool006Ooool0
0`0003?o03?o000Q<ol000D0003ooooooooooooo09T0T?ooo`00Ioooo`030000<ol0<ol0020co`00
0`000?ooooooo`02oooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol0020co`000`000?oo
ooooo`02oooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`03
oooo00?o09Woooooool0S_ooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo
00?oool00ol0VOooooooo`2>oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`00
0`000?ooooooo`04oooo00?o09Woooooool0S_ooo`00HOooo`030000oooooooo00?oool200007c?o
00030000oooooooo00Coool00ol0VOooooooo`2>oooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001dco`000`000?ooooooo`05oooo00?o09Woooooool0S_ooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003oooooool01Oooo`03o`2Ioooooooo08koool0063oool2
00001Oooo`030000<ol0<ol001`co`000`000?ooooooo`06oooo00?o09Woooooool0S_ooo`00Iooo
o`030000<ol0<ol001`co`000`000?ooooooo`06oooo00?o09Woooooool0S_ooo`00Ioooo`030000
<ol0<ol001/co`000`000?ooooooo`07oooo00?o09Woooooool0S_ooo`00Ioooo`80000L<ol000<0
003oooooool01oooo`03o`2Ioooooooo08koool006Ooool00`0003?o03?o000J<ol000<0003ooooo
ool02?ooo`03o`2Ioooooooo08koool006Ooool00`0003?o03?o000J<ol000<0003oooooool02?oo
o`03o`2Ioooooooo08koool006Ooool00`0003?o03?o000I<ol000<0003oooooool02Oooo`03o`2I
oooooooo08koool006Ooool00`0003?o03?o000I<ol000<0003oooooool02Oooo`03o`2Ioooooooo
08koool006Ooool00`0003?o03?o000H<ol000<0003oooooool02_ooo`03o`2Ioooooooo08koool0
06Ooool200006C?o00030000oooooooo00[oool00ol0VOooooooo`2>oooo001Woooo00<0000co`0c
o`005c?o00030000oooooooo00_oool00ol0VOooooooo`2>oooo001Woooo00<0000co`0co`005c?o
00030000oooooooo00_oool00ol0VOooooooo`2>oooo001Woooo00<0000co`0co`005S?o00030000
oooooooo00coool00ol0VOooooooo`2>oooo001Woooo00<0000co`0co`005S?o00030000oooooooo
00coool00ol0VOooooooo`2>oooo001Woooo00<0000co`0co`005S?o00030000oooooooo00coool0
0ol0VOooooooo`2>oooo001Woooo00<0000co`0co`005C?o00030000oooooooo00goool00ol0VOoo
ooooo`2>oooo001Woooo0P0001Hco`000`000?ooooooo`0=oooo00?o09Woooooool0S_ooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`0=oooo00?o09Woooooool0S_ooo`00Ioooo`030000
<ol0<ol001Dco`000`000?ooooooo`0=oooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`0>oooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooooooo`0>oooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol001@co`000`000?oo
ooooo`0>oooo00?o09Woooooool0S_ooo`00Ioooo`80000E<ol000<0003oooooool03_ooo`03o`2I
oooooooo08koool006Ooool00`0003?o03?o000C<ol000<0003oooooool03oooo`03o`2Ioooooooo
08koool006Ooool00`0003?o03?o000C<ol000<0003oooooool03oooo`03o`2Ioooooooo08koool0
06Ooool00`0003?o03?o000C<ol000<0003oooooool03oooo`03o`2Ioooooooo08koool005ooool4
00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0?oooo00?o09Woooooool0S_ooo`00Gooo
o`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool04?ooo`03o`2Ioooooooo
08koool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`0@oooo00?o09Wooooo
ool0S_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool04?oo
o`03o`2Ioooooooo08koool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0
003oooooool04Oooo`03o`2Ioooooooo08koool0063oool200001Oooo`030000<ol0<ol0014co`00
0`000?ooooooo`0Aoooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol0014co`000`000?oo
ooooo`0Aoooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`0A
oooo00?o09Woooooool0S_ooo`00Ioooo`80000A<ol000<0003oooooool04_ooo`03o`2Ioooooooo
08koool006Ooool00`0003?o03?o000@<ol000<0003oooooool04_ooo`03o`2Ioooooooo08koool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool04_ooo`03o`2Ioooooooo08koool006Ooool0
0`0003?o03?o000@<ol000<0003oooooool04_ooo`03o`2Ioooooooo08koool006Ooool00`0003?o
03?o000?<ol000<0003oooooool04oooo`03o`2Ioooooooo08koool006Ooool00`0003?o03?o000?
<ol000<0003oooooool04oooo`03o`2Ioooooooo08koool006Ooool00`0003?o03?o000?<ol000<0
003oooooool04oooo`03o`2Ioooooooo08koool006Ooool2000043?o00030000oooooooo01?oool0
0ol0VOooooooo`2>oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01Coool00ol0VOoo
ooooo`2>oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01Coool00ol0VOooooooo`2>
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01Coool00ol0VOooooooo`2>oooo001W
oooo00<0000co`0co`003S?o00030000oooooooo01Coool00ol0VOooooooo`2>oooo001Woooo00<0
000co`0co`003C?o00030000oooooooo01Goool00ol0VOooooooo`2>oooo001Woooo0P0000hco`00
0`000?ooooooo`0Eoooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`0Eoooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0E
oooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Foooo00?o
09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Foooo00?o09Wooooo
ool0S_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Foooo00?o09Woooooool0S_oo
o`00Ioooo`80000=<ol000<0003oooooool05_ooo`03o`2Ioooooooo08koool006Ooool00`0003?o
03?o000<<ol000<0003oooooool05_ooo`03o`2Ioooooooo08koool006Ooool00`0003?o03?o000<
<ol000<0003oooooool05_ooo`03o`2Ioooooooo08koool006Ooool00`0003?o03?o000;<ol000<0
003oooooool05oooo`03o`2Ioooooooo08koool0063oool200001Oooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Goooo00?o09Woooooool0S_ooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol000/co`000`000?ooooooo`0Goooo00?o09Woooooool0S_ooo`00HOooo`030000oooooooo
00?oool2000033?o00030000oooooooo01Ooool00ol0VOooooooo`2>oooo001Roooo00<0003ooooo
ool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`0Goooo00?o09Woooooool0S_ooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0Goooo00?o09Wooooo
ool0S_ooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo01Soool00ol0VOoo
ooooo`2>oooo001Woooo00<0000co`0co`002S?o00030000oooooooo01Soool00ol0VOooooooo`2>
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo01Soool00ol0VOooooooo`2>oooo001W
oooo00<0000co`0co`002S?o00030000oooooooo01Soool00ol0VOooooooo`2>oooo001Woooo0P00
00/co`000`000?ooooooo`0Hoooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0Hoooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0Ioooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0I
oooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Ioooo00?o
09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Ioooo00?o09Wooooo
ool0S_ooo`00Ioooo`80000:<ol000<0003oooooool06Oooo`03o`2Ioooooooo08koool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool06Oooo`03o`2Ioooooooo08koool006Ooool00`0003?o
03?o0009<ol000<0003oooooool06Oooo`03o`2Ioooooooo08koool006Ooool00`0003?o03?o0008
<ol000<0003oooooool06_ooo`03o`2Ioooooooo08koool006Ooool00`0003?o03?o0008<ol000<0
003oooooool06_ooo`03o`2Ioooooooo08koool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo08koool006Ooool200002C?o00030000oooooooo01[oool00ol0VOoo
ooooo`2>oooo001Woooo00<0000co`0co`0023?o00030000oooooooo01[oool00ol0VOooooooo`2>
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo01[oool00ol0VOooooooo`2>oooo001W
oooo00<0000co`0co`001c?o00030000oooooooo01_oool00ol0VOooooooo`2>oooo001Woooo00<0
000co`0co`001c?o00030000oooooooo01_oool00ol0VOooooooo`2>oooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo01_oool00ol0VOooooooo`2>oooo001Woooo0P0000Pco`000`000?oo
ooooo`0Koooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0K
oooo00?o09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Koooo00?o
09Woooooool0S_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Koooo00?o09Wooooo
ool0S_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Koooo00?o09Woooooool0S_oo
o`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo01_oool00ol0VOooooooo`2>
oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`0Koooo00?o
09Woooooool0S_ooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`0Koooo00?o09Wooooo
ool0S_ooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?oo
o`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool0
06Ooool9<ol03?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001Woooo2C?o00_oool0
0`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool006Ooool9<ol02ooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo0P00
00Coool00`000?ooooooo`1koooo001Woooo2C?o00_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001Woooo2C?o00[oool00`000?ooooooo`02oooo00<0003ooooo
ool03Oooo`040000oooooooo00002oooo`030000oooooooo00;oool00`000?ooooooo`1joooo001W
oooo2C?o00_oool00`000?ooooooo`0500003?ooo`040000oooooooo00002Oooo`800004oooo00<0
003oooooool0Noooo`00Ioooo`Tco`0;oooo00D0003oooooooooool000003oooo`040000oooooooo
00002Oooo`030000oooooooo00?oool00`000?ooooooo`1koooo001Woooo2C?o00coool00`000?oo
ooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo07coool006Ooool9<ol0/?ooo`00Iooo
o`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49955 .12361 L
.50205 .12361 L
.50342 .12361 L
.50471 .12361 L
.50592 .12361 L
s
.50592 .12361 m
.50644 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.14415 .12361 L
.16254 .12361 L
.16783 .12361 L
.17044 .12361 L
.17284 .12361 L
.17502 .12361 L
.17612 .12361 L
.17733 .12272 L
.18221 .11905 L
.20325 .10506 L
.2225 .09461 L
.26127 .07915 L
.28025 .07382 L
.30098 .06937 L
.32065 .06627 L
.33165 .06495 L
.34162 .06398 L
.38169 .05882 L
.42024 .05219 L
.46124 .04473 L
.48166 .04117 L
.49164 .0395 L
.50073 .03805 L
.50292 .0377 L
.50411 .03752 L
.50524 .03735 L
.50645 .12361 L
.50709 .12361 L
.50778 .12361 L
.51014 .12361 L
.51906 .12361 L
.5387 .12361 L
.57984 .12361 L
.61947 .12361 L
.65757 .12361 L
.69813 .12361 L
.73718 .12361 L
.77868 .12361 L
.81866 .12361 L
.85713 .12361 L
.89804 .12361 L
.93745 .12361 L
.97533 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0]_ooo`00Ioooo`030000oooooooo02;oool506KoSoooo`00Ioooo`030000oooooooo
01Woool906Ko1?ooo`0306Kooooooooo08goool006Ooool00`000?ooooooo`0Doooo1@1Vo`goool0
0`1Vooooooooo`2=oooo001Woooo0P00013oool506Ko4_ooo`0306Kooooooooo08goool006Ooool0
0`000?ooooooo`0:oooo1@1VoaOoool00`1Vooooooooo`2=oooo001Woooo00<0003oooooool00ooo
o`L0I_lLoooo00<0I_ooooooool0SOooo`00I_ooo`0306Ko000006Ko00@0I_lSoooo00<0I_oooooo
ool0SOooo`00H?ooo`H0I_l00oooo`000?ooo`0Woooo00<0I_ooooooool0SOooo`00Foooo`D0I_l7
oooo00<0003oooooool09_ooo`0306Kooooooooo08goool005Goool606Ko3?ooo`80000Woooo00<0
I_ooooooool0SOooo`005oooo`D0000Noooo0P0000Coool200001?ooo`800009oooo101Voa;oool0
0`000?ooooooo`0Noooo0P0000Coool2000000@0I_ooooooooooool200007oooo`D0000Moooo1@00
00;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003ooooo
ool00008oooo00@0003oooooool00006oooo0P1VoaKoool00`000?ooooooo`0Moooo00@0003ooooo
ool00006oooo00<0I_ooool000000_ooo`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0
003oooooool01oooo`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?oo
ooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`80I_lHoooo00<0003ooooo
ool07Oooo`040000oooooooo00001_ooo`0306Kooooooooo00;oool00`000?ooooooo`0Noooo00<0
003oooooool07oooo`030000oooooooo00[oool00`000?ooooooo`0Noooo00<0003oooooool05_oo
o`004Oooo`@00004oooo00<0003oooooool05oooo`@00002oooo00@0003oooooool00009oooo0P00
00?oool206Ko6_ooo`030000oooooooo01goool010000?ooooooo`0000Koool00`1Vooooooooo`02
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo0080I_lL
oooo00<0003oooooool07Oooo`040000oooooooo00001_ooo`0406Kooooooooo00008_ooo`030000
oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_oo
o`006?ooo`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000Ooool00`1Vooooooooo`03
00007oooo`80000Poooo0P0000[oool300008?ooo`80000Goooo0015oooo0P1Vob3oool00`000?oo
ooooo`0Woooo00<0I_ooooooool0S?ooo`00A?ooo`0306Kooooooooo023oool00`000?ooooooo`0W
oooo00<0I_ooooooool0S?ooo`00@_ooo`80I_lSoooo00<0003oooooool09oooo`0306Kooooooooo
08coool0043oool206Ko9Oooo`030000oooooooo02Ooool00`1Vooooooooo`2<oooo000noooo0P1V
obOoool00`000?ooooooo`0Woooo00<0I_ooooooool0S?ooo`004?ooool0000Aoooo000Foooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
003o09Tco`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o00030000
o`2I<ol002@co`0@00006Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo001Woooo00<0
000co`0co`009S?o0003o`2I<ol0<ol001hco`050000J_ooo`00Ioooo`030000<ol0<ol002Hco`00
0ol0VC?o03?o000I<ol01@0006ooool006Ooool00`0003?o03?o000V<ol000?o09Tco`0co`0053?o
00D0001doooo001Woooo00<0000co`0co`009S?o0003o`2I<ol0<ol0010co`040000NOooo`00Iooo
o`80000W<ol000?o09Tco`0co`003S?o0080001moooo001Woooo00<0000co`0co`009S?o0003o`2I
<ol0<ol000`co`020000Ooooo`00Ioooo`030000<ol0<ol002Hco`000ol0VC?o03?o000:<ol00P00
087oool006Ooool00`0003?o03?o000V<ol000?o09Tco`0co`0023?o00800023oooo001Woooo00<0
000co`0co`009S?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`23oooo001Woooo00<0000co`0c
o`009S?o0003o`2I<ol0<ol000Dco`020000Q_ooo`00Ioooo`80000W<ol000?o09Tco`0co`000c?o
00800028oooo001Woooo00<0000co`0co`009S?o0003o`2I<ol0<ol0008co`000`000?ooooooo`28
oooo001Woooo00<0000co`0co`009S?o0005o`2I<ol0<ol0<ol0000008_oool006Ooool00`0003?o
03?o000V<ol000Co09Tco`0co`00002<oooo001Woooo00<0000co`0co`009S?o0003o`2I<ol00000
08goool006Ooool00`0003?o03?o000V<ol000?o09Tco`000000SOooo`00Ioooo`80000W<ol000?o
09T0003oool0SOooo`00Ioooo`030000<ol0<ol002Hco`000ol0VOooooooo`2=oooo001Woooo00<0
000co`0co`009C?o00030000o`2Ioooo08koool006Ooool00`0003?o03?o000T<ol000<0003ooooo
09T0Soooo`00Ioooo`030000<ol0<ol002<co`0010000?ooooooool0VHooool006Ooool00`0003?o
03?o000S<ol000@0003ooooooooo09V?oooo001Woooo0P0002<co`001@000?ooooooooooool0V@2?
oooo001Woooo00<0000co`0co`008C?o00030000oooooooo00;oool00ol0VOooooooo`2=oooo001W
oooo00<0000co`0co`0083?o00030000oooooooo00?oool00ol0VOooooooo`2=oooo001Woooo00<0
000co`0co`0083?o00030000oooooooo00?oool00ol0VOooooooo`2=oooo001Woooo00<0000co`0c
o`007c?o00030000oooooooo00Coool00ol0VOooooooo`2=oooo001Ooooo1@0000?oool00`0003?o
03?o000O<ol000<0003oooooool01?ooo`03o`2Ioooooooo08goool0067oool00`000?ooooooo`03
oooo00<0000co`0co`007S?o00030000oooooooo00Goool00ol0VOooooooo`2=oooo001Qoooo00<0
003oooooool00oooo`80000O<ol000<0003oooooool01Oooo`03o`2Ioooooooo08goool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo00Koool00ol0VOooooooo`2=
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`06oooo00?o
09Woooooool0SOooo`00H?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo00Ooool0
0ol0VOooooooo`2=oooo001Woooo00<0000co`0co`0073?o00030000oooooooo00Ooool00ol0VOoo
ooooo`2=oooo001Woooo00<0000co`0co`006c?o00030000oooooooo00Soool00ol0VOooooooo`2=
oooo001Woooo0P0001`co`000`000?ooooooo`08oooo00?o09Woooooool0SOooo`00Ioooo`030000
<ol0<ol001Xco`000`000?ooooooo`09oooo00?o09Woooooool0SOooo`00Ioooo`030000<ol0<ol0
01Xco`000`000?ooooooo`09oooo00?o09Woooooool0SOooo`00Ioooo`030000<ol0<ol001Tco`00
0`000?ooooooo`0:oooo00?o09Woooooool0SOooo`00Ioooo`030000<ol0<ol001Tco`000`000?oo
ooooo`0:oooo00?o09Woooooool0SOooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`0;
oooo00?o09Woooooool0SOooo`00Ioooo`80000I<ol000<0003oooooool02oooo`03o`2Ioooooooo
08goool006Ooool00`0003?o03?o000G<ol000<0003oooooool03?ooo`03o`2Ioooooooo08goool0
06Ooool00`0003?o03?o000G<ol000<0003oooooool03?ooo`03o`2Ioooooooo08goool006Ooool0
0`0003?o03?o000F<ol000<0003oooooool03Oooo`03o`2Ioooooooo08goool006Ooool00`0003?o
03?o000F<ol000<0003oooooool03Oooo`03o`2Ioooooooo08goool006Ooool00`0003?o03?o000F
<ol000<0003oooooool03Oooo`03o`2Ioooooooo08goool006Ooool00`0003?o03?o000E<ol000<0
003oooooool03_ooo`03o`2Ioooooooo08goool006Ooool200005S?o00030000oooooooo00koool0
0ol0VOooooooo`2=oooo001Woooo00<0000co`0co`005C?o00030000oooooooo00koool00ol0VOoo
ooooo`2=oooo001Woooo00<0000co`0co`005C?o00030000oooooooo00koool00ol0VOooooooo`2=
oooo001Woooo00<0000co`0co`0053?o00030000oooooooo00ooool00ol0VOooooooo`2=oooo001W
oooo00<0000co`0co`0053?o00030000oooooooo00ooool00ol0VOooooooo`2=oooo001Woooo00<0
000co`0co`0053?o00030000oooooooo00ooool00ol0VOooooooo`2=oooo001Woooo0P0001Dco`00
0`000?ooooooo`0?oooo00?o09Woooooool0SOooo`00Ioooo`030000<ol0<ol001<co`000`000?oo
ooooo`0@oooo00?o09Woooooool0SOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0@
oooo00?o09Woooooool0SOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0@oooo00?o
09Woooooool0SOooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo013oool0
0ol0VOooooooo`2=oooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?oo
ooooo`0Aoooo00?o09Woooooool0SOooo`00H?ooo`030000oooooooo00Coool200004c?o00030000
oooooooo017oool00ol0VOooooooo`2=oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
018co`000`000?ooooooo`0Boooo00?o09Woooooool0S?ooo`00Goooo`040000oooooooo00001?oo
o`030000<ol0<ol0014co`000`000?ooooooo`0Coooo00?o09Woooooool0S?ooo`00H?ooo`800005
oooo00<0000co`0co`004C?o00030000oooooooo01?oool00ol0VOooooooo`2<oooo001Woooo00<0
000co`0co`004C?o00030000oooooooo01?oool00ol0VOooooooo`2<oooo001Woooo00<0000co`0c
o`004C?o00030000oooooooo01?oool00ol0VOooooooo`2<oooo001Woooo0P00014co`000`000?oo
ooooo`0Doooo00?o09Woooooool0S?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0D
oooo00?o09Woooooool0S?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0Doooo00?o
09Woooooool0S?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0Doooo00?o09Wooooo
ool0S?ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`0Eoooo00?o09Woooooool0S?oo
o`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`0Eoooo00?o09Woooooool0S?ooo`00Iooo
o`030000<ol0<ol000lco`000`000?ooooooo`0Eoooo00?o09Woooooool0S?ooo`00Ioooo`80000@
<ol000<0003oooooool05Oooo`03o`2Ioooooooo08coool006Ooool00`0003?o03?o000><ol000<0
003oooooool05_ooo`03o`2Ioooooooo08coool006Ooool00`0003?o03?o000><ol000<0003ooooo
ool05_ooo`03o`2Ioooooooo08coool006Ooool00`0003?o03?o000><ol000<0003oooooool05_oo
o`03o`2Ioooooooo08coool006Ooool00`0003?o03?o000><ol000<0003oooooool05_ooo`03o`2I
oooooooo08coool006Ooool00`0003?o03?o000=<ol000<0003oooooool05oooo`03o`2Ioooooooo
08coool006Ooool200003S?o00030000oooooooo01Ooool00ol0VOooooooo`2<oooo001Woooo00<0
000co`0co`003C?o00030000oooooooo01Ooool00ol0VOooooooo`2<oooo001Woooo00<0000co`0c
o`003C?o00030000oooooooo01Ooool00ol0VOooooooo`2<oooo001Woooo00<0000co`0co`0033?o
00030000oooooooo01Soool00ol0VOooooooo`2<oooo001Woooo00<0000co`0co`0033?o00030000
oooooooo01Soool00ol0VOooooooo`2<oooo001Woooo00<0000co`0co`0033?o00030000oooooooo
01Soool00ol0VOooooooo`2<oooo001Woooo0P0000dco`000`000?ooooooo`0Hoooo00?o09Wooooo
ool0S?ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Hoooo00?o09Woooooool0S?oo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Hoooo00?o09Woooooool0S?ooo`00Iooo
o`030000<ol0<ol000/co`000`000?ooooooo`0Ioooo00?o09Woooooool0S?ooo`00H?ooo`800005
oooo00<0000co`0co`002c?o00030000oooooooo01Woool00ol0VOooooooo`2<oooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo01Woool00ol0VOooooooo`2<
oooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0003oooooool06Oooo`03o`2Ioooooooo
08coool006;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo01Woool0
0ol0VOooooooo`2<oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000
oooooooo01Woool00ol0VOooooooo`2<oooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0
003oooooool06_ooo`03o`2Ioooooooo08coool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo08coool006Ooool00`0003?o03?o000:<ol000<0003oooooool06_oo
o`03o`2Ioooooooo08coool006Ooool00`0003?o03?o000:<ol000<0003oooooool06_ooo`03o`2I
oooooooo08coool006Ooool200002c?o00030000oooooooo01[oool00ol0VOooooooo`2<oooo001W
oooo00<0000co`0co`002S?o00030000oooooooo01[oool00ol0VOooooooo`2<oooo001Woooo00<0
000co`0co`002C?o00030000oooooooo01_oool00ol0VOooooooo`2<oooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo01_oool00ol0VOooooooo`2<oooo001Woooo00<0000co`0co`002C?o
00030000oooooooo01_oool00ol0VOooooooo`2<oooo001Woooo00<0000co`0co`002C?o00030000
oooooooo01_oool00ol0VOooooooo`2<oooo001Woooo0P0000Xco`000`000?ooooooo`0Koooo00?o
09Woooooool0S?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Koooo00?o09Wooooo
ool0S?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Koooo00?o09Woooooool0S?oo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Loooo00?o09Woooooool0S?ooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`0Loooo00?o09Woooooool0S?ooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`0Loooo00?o09Woooooool0S?ooo`00Ioooo`800009<ol000<0
003oooooool07?ooo`03o`2Ioooooooo08coool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool07?ooo`03o`2Ioooooooo08coool006Ooool00`0003?o03?o0008<ol000<0003oooooool07?oo
o`03o`2Ioooooooo08coool006Ooool00`0003?o03?o0007<ol000<0003oooooool07Oooo`03o`2I
oooooooo08coool006Ooool00`0003?o03?o0007<ol000<0003oooooool07Oooo`03o`2Ioooooooo
08coool006Ooool00`0003?o03?o0007<ol000<0003oooooool07Oooo`03o`2Ioooooooo08coool0
06Ooool2000023?o00030000oooooooo01goool00ol0VOooooooo`2<oooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo01goool00ol0VOooooooo`2<oooo001Woooo00<0000co`0co`001c?o
00030000oooooooo01goool00ol0VOooooooo`2<oooo001Woooo00<0000co`0co`001c?o00030000
oooooooo01goool00ol0VOooooooo`2<oooo001Woooo00<0000co`0co`001c?o00030000oooooooo
01goool00ol0VOooooooo`2<oooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003ooooo
ool07Oooo`03o`2Ioooooooo08coool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o
00030000oooooooo01goool00ol0VOooooooo`2<oooo001Ooooo1@0000?oool2000023?o00030000
oooooooo01goool00ol0VOooooooo`2<oooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0
063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o
0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo
07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Coool200000oooo`@00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00@0003oooooool00002oooo00<0003oooooool01?ooo`030000oooooooo
07Soool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003ooooo
ool0000;oooo00D0003oooooooooool000001_ooo`030000oooooooo07Ooool006Ooool9<ol02?oo
o`030000oooooooo00D0000<oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000003oooo`040000
oooooooo00002Oooo`030000oooooooo00;oool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000[oool300000oooo`800003oooo00<0
003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49955 .12361 L
.50431 .12361 L
.50682 .12361 L
.5095 .12361 L
.51083 .12361 L
.51207 .12361 L
s
.51207 .12361 m
.51252 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.14415 .12361 L
.1536 .12361 L
.16254 .12361 L
.16494 .12361 L
.16748 .12361 L
.1688 .12361 L
.16956 .12361 L
.17026 .12328 L
.1715 .12232 L
.17284 .12131 L
.18221 .11452 L
.20192 .10213 L
.22343 .09117 L
.24426 .08274 L
.26314 .07669 L
.28281 .07175 L
.30379 .0678 L
.32303 .0652 L
.33388 .0641 L
.34385 .06329 L
.36268 .06133 L
.38334 .05846 L
.42376 .05169 L
.46267 .04474 L
.48248 .04131 L
.49293 .03957 L
.49866 .03865 L
.50403 .0378 L
.50877 .03707 L
.51007 .03688 L
.51143 .03667 L
.5126 .0365 L
.51387 .12361 L
.51461 .12361 L
.5153 .12361 L
.51659 .12361 L
.5195 .12361 L
.52473 .12361 L
.54388 .12361 L
.58235 .12361 L
.62326 .12361 L
.66267 .12361 L
.70055 .12361 L
.74089 .12361 L
.77972 .12361 L
.821 .12361 L
Mistroke
.86076 .12361 L
.899 .12361 L
.9397 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool09oooo`80I_n=oooo001Woooo00<0003oooooool08oooo`@0I_l00oooo`1Vooooo`2<
oooo001Woooo00<0003oooooool06_ooo`T0I_l5oooo00<0I_ooooooool0Roooo`00Ioooo`030000
oooooooo01Goool506Ko3_ooo`0306Kooooooooo08_oool006Ooool200004Oooo`D0I_lCoooo00<0
I_ooooooool0Roooo`00Ioooo`030000oooooooo00[oool606Ko6?ooo`0306Kooooooooo08_oool0
06Ooool00`000?ooooooo`05oooo1@1Voakoool00`1Vooooooooo`2;oooo001Toooo0`1Vo`030000
06Ko06Ko00D0I_lSoooo00<0I_ooooooool0Roooo`00Foooo`T0I_l3oooo00<0003oooooool0:?oo
o`0306Kooooooooo08_oool005Ooool406Ko3?ooo`030000oooooooo02Soool00`1Vooooooooo`2;
oooo001Eoooo0P1Voa3oool20000:Oooo`0306Kooooooooo08_oool001Ooool500007_ooo`800004
oooo0P0000Coool200002Oooo`@0I_lBoooo00<0003oooooool07_ooo`800004oooo0P0000;oool0
101Vooooo`00000001ooool500007Oooo`D00002oooo0P0000Coool200008?ooo`@0000Foooo000I
oooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`@0I_lF
oooo00<0003oooooool07Oooo`040000oooooooo00001oooo`0506Ko0000oooooooo0000023oool0
0`000?ooooooo`0Ooooo00<0003oooooool01oooo`040000oooooooo00007oooo`030000oooooooo
01Ooool001Woool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool00P1V
oa[oool00`000?ooooooo`0Moooo00@0003oooooool00007oooo00D0I_ooooooooooool000008?oo
o`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Ooo
o`8000000oooo`1Vo`1Vo`0Loooo00<0003oooooool07Oooo`040000oooooooo00001oooo`0406Ko
oooo000000008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`03000006Ko06Ko
01koool00`000?ooooooo`0Moooo00@0003oooooool00007oooo00<0I_ooool000008_ooo`030000
oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_oo
o`006?ooo`80000Poooo0P0000Woool0101Vo`000000000001koool200007oooo`800008oooo00<0
I_ooool000000P0001ooool200008?ooo`80000:oooo0`00023oool200005oooo`00@oooo`80I_lR
oooo00<0003oooooool0:?ooo`0306Kooooooooo08_oool0047oool206Ko9?ooo`030000oooooooo
02Soool00`1Vooooooooo`2;oooo000ooooo0P1VobKoool00`000?ooooooo`0Xoooo00<0I_oooooo
ool0Roooo`00?_ooo`0306Kooooooooo02Koool00`000?ooooooo`0Xoooo00<0I_ooooooool0Rooo
o`00?Oooo`0306Kooooooooo02Ooool00`000?ooooooo`0Xoooo00<0I_ooooooool0Roooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000@0000co`0co`3o09T4<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0004<ol0:00000;oool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool0
0`0003?o03?o000U<ol000@0000co`0co`3o09TS<ol0400001Woool00`000?ooooooo`0Voooo00<0
003oooooool05Oooo`00Ioooo`030000<ol0<ol002Pco`000ol0VC?o03?o000L<ol01@0006[oool0
06Ooool00`0003?o03?o000X<ol000?o09Tco`0co`005c?o00D0001_oooo001Woooo00<0000co`0c
o`00:3?o0003o`2I<ol0<ol0018co`050000M?ooo`00Ioooo`030000<ol0<ol002Pco`000ol0VC?o
03?o000><ol0100007Woool006Ooool20000:C?o0003o`2I<ol0<ol000`co`020000OOooo`00Iooo
o`030000<ol0<ol002Pco`000ol0VC?o03?o000:<ol00P0007ooool006Ooool00`0003?o03?o000X
<ol000?o09Tco`0co`0023?o00800021oooo001Woooo00<0000co`0co`00:3?o0003o`2I<ol0<ol0
00Hco`020000Poooo`00Ioooo`030000<ol0<ol002Pco`000ol0VC?o03?o0005<ol000<0003ooooo
ool0Poooo`00Ioooo`030000<ol0<ol002Pco`000ol0VC?o03?o0003<ol00P0008Koool006Ooool2
0000:C?o0004o`2I<ol0<ol0<ol00P0008Soool006Ooool00`0003?o03?o000X<ol000Co09Tco`0c
o`00002:oooo001Woooo00<0000co`0co`00:3?o0003o`2I<ol0000008_oool006Ooool00`0003?o
03?o000X<ol000?o09T0003oool0Roooo`00Ioooo`030000<ol0<ol002Pco`000ol0VOooooooo`2;
oooo001Woooo00<0000co`0co`00:3?o0003o`2Ioooooooo08_oool006Ooool20000:3?o00030000
o`2Ioooo08coool006Ooool00`0003?o03?o000V<ol000<0003ooooo09T0SOooo`00Ioooo`030000
<ol0<ol002Dco`0010000?ooooooool0VHgoool006Ooool00`0003?o03?o000T<ol000D0003ooooo
oooooooo09T0SOooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`02oooo00?o09Wooooo
ool0Roooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`02oooo00?o09Woooooool0Rooo
o`00Ioooo`80000S<ol000<0003oooooool00oooo`03o`2Ioooooooo08_oool006Ooool00`0003?o
03?o000Q<ol000<0003oooooool01?ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000P
<ol000<0003oooooool01Oooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000P<ol000<0
003oooooool01Oooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000O<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo08_oool005ooool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`06oooo00?o09Woooooool0Roooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool01oooo`03o`2Ioooooooo08_oool0067oool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`07oooo00?o09Woooooool0Roooo`00HOooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool02?ooo`03o`2Ioooooooo08_oool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo00Soool00ol0VOooooooo`2;oooo001P
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool02Oooo`03o`2Ioooooooo08_oool0
06Ooool00`0003?o03?o000L<ol000<0003oooooool02Oooo`03o`2Ioooooooo08_oool006Ooool0
0`0003?o03?o000K<ol000<0003oooooool02_ooo`03o`2Ioooooooo08_oool006Ooool2000073?o
00030000oooooooo00[oool00ol0VOooooooo`2;oooo001Woooo00<0000co`0co`006S?o00030000
oooooooo00_oool00ol0VOooooooo`2;oooo001Woooo00<0000co`0co`006S?o00030000oooooooo
00_oool00ol0VOooooooo`2;oooo001Woooo00<0000co`0co`006C?o00030000oooooooo00coool0
0ol0VOooooooo`2;oooo001Woooo00<0000co`0co`006C?o00030000oooooooo00coool00ol0VOoo
ooooo`2;oooo001Woooo00<0000co`0co`0063?o00030000oooooooo00goool00ol0VOooooooo`2;
oooo001Woooo0P0001Tco`000`000?ooooooo`0=oooo00?o09Woooooool0Roooo`00Ioooo`030000
<ol0<ol001Lco`000`000?ooooooo`0>oooo00?o09Woooooool0Roooo`00Ioooo`030000<ol0<ol0
01Lco`000`000?ooooooo`0>oooo00?o09Woooooool0Roooo`00Ioooo`030000<ol0<ol001Hco`00
0`000?ooooooo`0?oooo00?o09Woooooool0Roooo`00Ioooo`030000<ol0<ol001Hco`000`000?oo
ooooo`0?oooo00?o09Woooooool0Roooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0?
oooo00?o09Woooooool0Roooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0@oooo00?o
09Woooooool0Roooo`00Ioooo`80000F<ol000<0003oooooool04?ooo`03o`2Ioooooooo08_oool0
06Ooool00`0003?o03?o000E<ol000<0003oooooool04?ooo`03o`2Ioooooooo08_oool006Ooool0
0`0003?o03?o000E<ol000<0003oooooool04?ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o
03?o000D<ol000<0003oooooool04Oooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000D
<ol000<0003oooooool04Oooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000D<ol000<0
003oooooool04Oooo`03o`2Ioooooooo08_oool006Ooool200005C?o00030000oooooooo017oool0
0ol0VOooooooo`2;oooo001Woooo00<0000co`0co`004c?o00030000oooooooo01;oool00ol0VOoo
ooooo`2;oooo001Woooo00<0000co`0co`004c?o00030000oooooooo01;oool00ol0VOooooooo`2;
oooo001Woooo00<0000co`0co`004c?o00030000oooooooo01;oool00ol0VOooooooo`2;oooo001O
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool04_ooo`03o`2Ioooooooo08_oool0
05ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo01?oool00ol0VOoo
ooooo`2;oooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool04oooo`03o`2I
oooooooo08_oool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
01?oool00ol0VOooooooo`2;oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo01Coool00ol0VOooooooo`2;oooo001Poooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool05?ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000A<ol000<0
003oooooool05?ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000A<ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo08_oool006Ooool200004C?o00030000oooooooo01Goool00ol0VOoo
ooooo`2;oooo001Woooo00<0000co`0co`0043?o00030000oooooooo01Goool00ol0VOooooooo`2;
oooo001Woooo00<0000co`0co`0043?o00030000oooooooo01Goool00ol0VOooooooo`2;oooo001W
oooo00<0000co`0co`0043?o00030000oooooooo01Goool00ol0VOooooooo`2;oooo001Woooo00<0
000co`0co`003c?o00030000oooooooo01Koool00ol0VOooooooo`2;oooo001Woooo00<0000co`0c
o`003c?o00030000oooooooo01Koool00ol0VOooooooo`2;oooo001Woooo00<0000co`0co`003c?o
00030000oooooooo01Koool00ol0VOooooooo`2;oooo001Woooo0P00010co`000`000?ooooooo`0F
oooo00?o09Woooooool0Roooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Goooo00?o
09Woooooool0Roooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Goooo00?o09Wooooo
ool0Roooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Goooo00?o09Woooooool0Rooo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Goooo00?o09Woooooool0Roooo`00Iooo
o`030000<ol0<ol000dco`000`000?ooooooo`0Hoooo00?o09Woooooool0Roooo`00Ioooo`80000>
<ol000<0003oooooool06?ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000=<ol000<0
003oooooool06?ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000=<ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000<<ol000<0003oooooool06Ooo
o`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000<<ol000<0003oooooool06Oooo`03o`2I
oooooooo08_oool006Ooool00`0003?o03?o000<<ol000<0003oooooool06Oooo`03o`2Ioooooooo
08_oool006Ooool200003C?o00030000oooooooo01Woool00ol0VOooooooo`2;oooo001Woooo00<0
000co`0co`0033?o00030000oooooooo01Woool00ol0VOooooooo`2;oooo001Woooo00<0000co`0c
o`0033?o00030000oooooooo01Woool00ol0VOooooooo`2;oooo001Woooo00<0000co`0co`002c?o
00030000oooooooo01[oool00ol0VOooooooo`2;oooo001Poooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool06_ooo`03o`2Ioooooooo08_oool005ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool06_ooo`03o`2Ioooooooo08_oool0067oool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`0Joooo00?o09Woooooool0Roooo`00H_ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool06_ooo`03o`2Ioooooooo08_oool0
05ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool06_ooo`03o`2I
oooooooo08_oool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`0Koooo00?o
09Woooooool0Roooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Koooo00?o09Wooooo
ool0Roooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Koooo00?o09Woooooool0Rooo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Koooo00?o09Woooooool0Roooo`00Iooo
o`80000;<ol000<0003oooooool06oooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o000:
<ol000<0003oooooool06oooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o0009<ol000<0
003oooooool07?ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool07?ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o0009<ol000<0003oooooool07?oo
o`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o0009<ol000<0003oooooool07?ooo`03o`2I
oooooooo08_oool006Ooool200002S?o00030000oooooooo01coool00ol0VOooooooo`2;oooo001W
oooo00<0000co`0co`002C?o00030000oooooooo01coool00ol0VOooooooo`2;oooo001Woooo00<0
000co`0co`002C?o00030000oooooooo01coool00ol0VOooooooo`2;oooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo01goool00ol0VOooooooo`2;oooo001Woooo00<0000co`0co`0023?o
00030000oooooooo01goool00ol0VOooooooo`2;oooo001Woooo00<0000co`0co`0023?o00030000
oooooooo01goool00ol0VOooooooo`2;oooo001Woooo0P0000Tco`000`000?ooooooo`0Moooo00?o
09Woooooool0Roooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Moooo00?o09Wooooo
ool0Roooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Moooo00?o09Woooooool0Rooo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Noooo00?o09Woooooool0Roooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Noooo00?o09Woooooool0Roooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`0Noooo00?o09Woooooool0Roooo`00Ioooo`800008<ol000<0
003oooooool07_ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o0007<ol000<0003oooooool07_oo
o`03o`2Ioooooooo08_oool006Ooool00`0003?o03?o0007<ol000<0003oooooool07_ooo`03o`2I
oooooooo08_oool006Ooool00`0003?o03?o0007<ol000<0003oooooool07_ooo`03o`2Ioooooooo
08_oool0067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`0Noooo00?o09Wooooo
ool0Roooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool07_oo
o`03o`2Ioooooooo08_oool005ooool500000oooo`800008<ol000<0003oooooool07_ooo`03o`2I
oooooooo08_oool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo0000
00Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`
oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o
00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?oo
o`800005oooo0`0000;oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool01@000?ooooooooooo`00001joooo001Woooo2C?o00Ooool00`000?oo
ooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002oooo`030000oooooooo00D00003
oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000coool010000?oo
ooooo`0000Woool200000oooo`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9
<ol02?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`03
oooo00<0003oool000000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo
017oool200002_ooo`<00004oooo0P0000;oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool0
06Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.5095 .12361 L
.51441 .12361 L
.5168 .12361 L
.51784 .12361 L
.51896 .12361 L
s
.51896 .12361 m
.51948 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.14415 .12361 L
.1536 .12361 L
.15825 .12361 L
.16029 .12361 L
.16137 .12361 L
.16254 .12361 L
.16378 .12339 L
.16494 .12249 L
.16748 .12056 L
.17284 .11664 L
.18221 .11026 L
.20192 .09864 L
.22343 .08839 L
.24426 .08055 L
.26314 .07495 L
.28281 .07042 L
.30379 .06684 L
.32303 .06453 L
.33388 .06358 L
.34385 .06288 L
.36268 .06111 L
.38334 .05841 L
.42376 .05188 L
.46267 .04505 L
.48248 .04164 L
.49293 .03991 L
.50403 .03813 L
.50877 .03739 L
.51387 .03662 L
.5153 .0364 L
.51679 .03618 L
.51807 .03599 L
.5188 .03589 L
.51947 .12361 L
.52016 .12361 L
.5208 .12361 L
.52202 .12361 L
.52473 .12361 L
.54388 .12361 L
.58235 .12361 L
.62326 .12361 L
.66267 .12361 L
.70055 .12361 L
.74089 .12361 L
.77972 .12361 L
.821 .12361 L
Mistroke
.86076 .12361 L
.899 .12361 L
.9397 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0:?ooo`<0I_n;oooo001Woooo00<0003oooooool08oooo`D0I_l2oooo00<0I_oooooo
ool0ROooo`00Ioooo`030000oooooooo01[oool906Ko1oooo`0306Kooooooooo08Woool006Ooool0
0`000?ooooooo`0Eoooo1@1Voa3oool00`1Vooooooooo`29oooo001Woooo0P00017oool506Ko5Ooo
o`0306Kooooooooo08Woool006Ooool00`000?ooooooo`0:oooo1P1Voa[oool00`1Vooooooooo`29
oooo001Woooo00<0003oooooool01Oooo`D0I_lPoooo00<0I_ooooooool0ROooo`00H?ooo`L0I_l0
0`00001Vo`1Vo`0506Ko9Oooo`0306Kooooooooo08Woool005_oool506Ko1oooo`030000oooooooo
02[oool00`1Vooooooooo`29oooo001Foooo1@1Vo`coool00`000?ooooooo`0Zoooo00<0I_oooooo
ool0ROooo`00DOooo`D0I_lAoooo0P0002_oool00`1Vooooooooo`29oooo000Goooo1@0001koool2
00001?ooo`800004oooo0P0000Goool406Ko5_ooo`030000oooooooo01koool200001?ooo`800004
oooo0P0001ooool500007Oooo`D00002oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`80I_lJoooo00<0
003oooooool07Oooo`040000oooooooo00002?ooo`04000006Kooooo00008?ooo`030000oooooooo
01ooool00`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Ooo
o`030000oooooooo01goool010000?ooooooo`0000_oool00`00001Vo`1Vo`0Loooo00<0003ooooo
ool07Oooo`040000oooooooo00002Oooo`0306Kooooo0000023oool00`000?ooooooo`0Ooooo00<0
003oooooool02_ooo`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool0
0`000?ooooooo`0Goooo100000;oool010000?ooooooo`0000Woool2000000<0I_ooooooool07?oo
o`030000oooooooo01goool010000?ooooooo`0000Woool200008Oooo`030000oooooooo01ooool0
0`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00002?ooo`0306Ko0000oooo01ooool00`000?ooooooo`0Moooo00@0003ooooo
ool00009oooo00<0003oooooool08?ooo`030000oooooooo01ooool00`000?ooooooo`08oooo00<0
003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000Ooool206Ko00Co
ool000000000000Noooo0P0001ooool200002_ooo`<0000Ooooo0P00023oool200002_ooo`<0000P
oooo0P0001Ooool0047oool206Ko9?ooo`030000oooooooo02[oool00`1Vooooooooo`29oooo000o
oooo0P1VobKoool00`000?ooooooo`0Zoooo00<0I_ooooooool0ROooo`00?_ooo`0306Kooooooooo
02Koool00`000?ooooooo`0Zoooo00<0I_ooooooool0ROooo`00?Oooo`0306Kooooooooo02Ooool0
0`000?ooooooo`0Zoooo00<0I_ooooooool0ROooo`00??ooo`0306Kooooooooo02Soool00`000?oo
ooooo`0Zoooo00<0I_ooooooool0ROooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`000S?o
0004o`2I<ol0<ol000001c?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`000S?o
0003o`2I<ol0<ol001lco`0@00006Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo001W
oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol001Xco`050000J_ooo`00Ioooo`030000<ol0<ol0
02Xco`000ol0VC?o03?o000E<ol01@0006ooool006Ooool00`0003?o03?o000Z<ol000?o09Tco`0c
o`0043?o00D0001doooo001Woooo00<0000co`0co`00:S?o0003o`2I<ol0<ol000`co`040000NOoo
o`00Ioooo`80000[<ol000?o09Tco`0co`002S?o0080001moooo001Woooo00<0000co`0co`00:S?o
0003o`2I<ol0<ol000Pco`020000Ooooo`00Ioooo`030000<ol0<ol002Xco`000ol0VC?o03?o0006
<ol00P00087oool006Ooool00`0003?o03?o000Z<ol000?o09Tco`0co`0013?o00800023oooo001W
oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol000<co`000`000?ooooooo`23oooo001Woooo00<0
000co`0co`00:S?o0004o`2I<ol0<ol0<ol00P0008Koool006Ooool20000:c?o0004o`2I<ol00000
0000R?ooo`00Ioooo`030000<ol0<ol002Xco`000ol0V@000?ooo`29oooo001Woooo00<0000co`0c
o`00:S?o0003o`2Ioooooooo08Woool006Ooool00`0003?o03?o000Y<ol000<0003o09Woool0R_oo
o`00Ioooo`030000<ol0<ol002Pco`000`000?ooool0V@2;oooo001Woooo00<0000co`0co`00:3?o
00030000ooooo`2I08_oool006Ooool20000:3?o00040000ooooooooo`2IRoooo`00Ioooo`030000
<ol0<ol002Hco`001@000?ooooooooooool0V@2;oooo001Woooo00<0000co`0co`009C?o00030000
oooooooo00;oool00ol0VOooooooo`29oooo001Woooo00<0000co`0co`0093?o00030000oooooooo
00?oool00ol0VOooooooo`29oooo001Woooo00<0000co`0co`008c?o00030000oooooooo00Coool0
0ol0VOooooooo`29oooo001Woooo00<0000co`0co`008c?o00030000oooooooo00Coool00ol0VOoo
ooooo`29oooo001Woooo0P0002<co`000`000?ooooooo`05oooo00?o09Woooooool0ROooo`00Iooo
o`030000<ol0<ol0024co`000`000?ooooooo`06oooo00?o09Woooooool0ROooo`00Ioooo`030000
<ol0<ol0020co`000`000?ooooooo`07oooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol0
020co`000`000?ooooooo`07oooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol001lco`00
0`000?ooooooo`08oooo00?o09Woooooool0ROooo`00Goooo`D00003oooo00<0000co`0co`007c?o
00030000oooooooo00Soool00ol0VOooooooo`29oooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001hco`000`000?ooooooo`09oooo00?o09Woooooool0ROooo`00HOooo`030000oooooooo
00?oool200007c?o00030000oooooooo00Woool00ol0VOooooooo`29oooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0:oooo00?o09Woooooool0ROooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool02_ooo`03o`2Ioooooooo
08Woool0063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`0;oooo00?o09Wooooo
ool0ROooo`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`0;oooo00?o09Woooooool0ROoo
o`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`0<oooo00?o09Woooooool0ROooo`00Iooo
o`80000L<ol000<0003oooooool03?ooo`03o`2Ioooooooo08Woool006Ooool00`0003?o03?o000J
<ol000<0003oooooool03Oooo`03o`2Ioooooooo08Woool006Ooool00`0003?o03?o000J<ol000<0
003oooooool03Oooo`03o`2Ioooooooo08Woool006Ooool00`0003?o03?o000I<ol000<0003ooooo
ool03_ooo`03o`2Ioooooooo08Woool006Ooool00`0003?o03?o000I<ol000<0003oooooool03_oo
o`03o`2Ioooooooo08Woool006Ooool00`0003?o03?o000H<ol000<0003oooooool03oooo`03o`2I
oooooooo08Woool006Ooool200006C?o00030000oooooooo00ooool00ol0VOooooooo`29oooo001W
oooo00<0000co`0co`005c?o00030000oooooooo013oool00ol0VOooooooo`29oooo001Woooo00<0
000co`0co`005c?o00030000oooooooo013oool00ol0VOooooooo`29oooo001Woooo00<0000co`0c
o`005S?o00030000oooooooo017oool00ol0VOooooooo`29oooo001Woooo00<0000co`0co`005S?o
00030000oooooooo017oool00ol0VOooooooo`29oooo001Woooo00<0000co`0co`005S?o00030000
oooooooo017oool00ol0VOooooooo`29oooo001Woooo00<0000co`0co`005C?o00030000oooooooo
01;oool00ol0VOooooooo`29oooo001Woooo0P0001Hco`000`000?ooooooo`0Boooo00?o09Wooooo
ool0ROooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0Boooo00?o09Woooooool0ROoo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0Boooo00?o09Woooooool0ROooo`00Iooo
o`030000<ol0<ol001@co`000`000?ooooooo`0Coooo00?o09Woooooool0ROooo`00Ioooo`030000
<ol0<ol001@co`000`000?ooooooo`0Coooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`0Coooo00?o09Woooooool0ROooo`00Ioooo`80000E<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo08Woool006Ooool00`0003?o03?o000C<ol000<0003oooooool05?oo
o`03o`2Ioooooooo08Woool006Ooool00`0003?o03?o000C<ol000<0003oooooool05?ooo`03o`2I
oooooooo08Woool006Ooool00`0003?o03?o000C<ol000<0003oooooool05?ooo`03o`2Ioooooooo
08Woool005ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0Doooo00?o09Wooooo
ool0ROooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo08Woool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`0E
oooo00?o09Woooooool0ROooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0
003oooooool05Oooo`03o`2Ioooooooo08Woool005ooool010000?ooooooo`0000Coool00`0003?o
03?o000A<ol000<0003oooooool05_ooo`03o`2Ioooooooo08Woool0063oool200001Oooo`030000
<ol0<ol0014co`000`000?ooooooo`0Foooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol0
014co`000`000?ooooooo`0Foooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol0014co`00
0`000?ooooooo`0Foooo00?o09Woooooool0ROooo`00Ioooo`80000A<ol000<0003oooooool05ooo
o`03o`2Ioooooooo08Woool006Ooool00`0003?o03?o000@<ol000<0003oooooool05oooo`03o`2I
oooooooo08Woool006Ooool00`0003?o03?o000@<ol000<0003oooooool05oooo`03o`2Ioooooooo
08Woool006Ooool00`0003?o03?o000@<ol000<0003oooooool05oooo`03o`2Ioooooooo08Woool0
06Ooool00`0003?o03?o000?<ol000<0003oooooool06?ooo`03o`2Ioooooooo08Woool006Ooool0
0`0003?o03?o000?<ol000<0003oooooool06?ooo`03o`2Ioooooooo08Woool006Ooool00`0003?o
03?o000?<ol000<0003oooooool06?ooo`03o`2Ioooooooo08Woool006Ooool2000043?o00030000
oooooooo01Soool00ol0VOooooooo`29oooo001Woooo00<0000co`0co`003S?o00030000oooooooo
01Woool00ol0VOooooooo`29oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01Woool0
0ol0VOooooooo`29oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01Woool00ol0VOoo
ooooo`29oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01Woool00ol0VOooooooo`29
oooo001Woooo00<0000co`0co`003C?o00030000oooooooo01[oool00ol0VOooooooo`29oooo001W
oooo0P0000hco`000`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol0
00dco`000`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`0Koooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0K
oooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Koooo00?o
09Woooooool0ROooo`00Ioooo`80000=<ol000<0003oooooool06oooo`03o`2Ioooooooo08Woool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool06oooo`03o`2Ioooooooo08Woool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool06oooo`03o`2Ioooooooo08Woool006Ooool00`0003?o
03?o000;<ol000<0003oooooool07?ooo`03o`2Ioooooooo08Woool0063oool200001Oooo`030000
<ol0<ol000/co`000`000?ooooooo`0Loooo00?o09Woooooool0ROooo`00Goooo`040000oooooooo
00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0Loooo00?o09Woooooool0ROooo`00HOoo
o`030000oooooooo00?oool2000033?o00030000oooooooo01coool00ol0VOooooooo`29oooo001R
oooo00<0003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`0Loooo00?o09Wooooo
ool0ROooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0L
oooo00?o09Woooooool0ROooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo
01goool00ol0VOooooooo`29oooo001Woooo00<0000co`0co`002S?o00030000oooooooo01goool0
0ol0VOooooooo`29oooo001Woooo00<0000co`0co`002S?o00030000oooooooo01goool00ol0VOoo
ooooo`29oooo001Woooo00<0000co`0co`002S?o00030000oooooooo01goool00ol0VOooooooo`29
oooo001Woooo0P0000/co`000`000?ooooooo`0Moooo00?o09Woooooool0ROooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`0Moooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0Noooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0Noooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0Noooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0N
oooo00?o09Woooooool0ROooo`00Ioooo`80000:<ol000<0003oooooool07_ooo`03o`2Ioooooooo
08Woool006Ooool00`0003?o03?o0009<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Woool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Woool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool07oooo`03o`2Ioooooooo08Woool006Ooool00`0003?o
03?o0008<ol000<0003oooooool07oooo`03o`2Ioooooooo08Woool006Ooool00`0003?o03?o0008
<ol000<0003oooooool07oooo`03o`2Ioooooooo08Woool006Ooool200002C?o00030000oooooooo
01ooool00ol0VOooooooo`29oooo001Woooo00<0000co`0co`0023?o00030000oooooooo01ooool0
0ol0VOooooooo`29oooo001Woooo00<0000co`0co`0023?o00030000oooooooo01ooool00ol0VOoo
ooooo`29oooo001Woooo00<0000co`0co`001c?o00030000oooooooo023oool00ol0VOooooooo`29
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo023oool00ol0VOooooooo`29oooo001W
oooo00<0000co`0co`001c?o00030000oooooooo023oool00ol0VOooooooo`29oooo001Woooo0P00
00Pco`000`000?ooooooo`0Poooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Poooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Poooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0P
oooo00?o09Woooooool0ROooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Poooo00?o
09Woooooool0ROooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo023oool0
0ol0VOooooooo`29oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Poooo00?o09Woooooool0ROooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`0P
oooo00?o09Woooooool0ROooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0
003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001W
oooo2C?o0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001W
oooo2C?o00Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
06Ooool9<ol02?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?oo
o`800004oooo0P0000?oool300001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
06Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000;
oooo00@0003oooooool00002oooo00<0003oooooool00_ooo`030000oooooooo07Ooool006Ooool9
<ol02?ooo`030000oooooooo00D0000<oooo00@0003oooooool00009oooo0P0000?oool300001?oo
o`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Soool0
06Ooool9<ol02Oooo`030000oooooooo017oool200002_ooo`<00003oooo0`0000;oool00`000?oo
ooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.5095 .12361 L
.51896 .12361 L
.52148 .12361 L
.52287 .12361 L
.52417 .12361 L
.52492 .12361 L
s
.52492 .12361 m
.52524 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.13506 .12361 L
.14415 .12361 L
.14868 .12361 L
.15107 .12361 L
.1536 .12361 L
.15581 .12361 L
.15707 .12361 L
.15825 .12275 L
.16254 .11951 L
.18221 .10626 L
.22098 .08678 L
.24211 .07919 L
.2622 .07358 L
.28201 .06936 L
.3004 .06643 L
.31096 .06513 L
.32092 .06413 L
.33953 .06278 L
.3484 .06224 L
.3579 .06144 L
.36834 .06033 L
.37808 .05913 L
.39802 .05628 L
.41908 .0529 L
.46044 .04579 L
.48114 .04225 L
.50029 .03909 L
.50987 .03758 L
.51887 .03622 L
.52107 .0359 L
.52339 .03556 L
.5246 .03539 L
.52529 .03529 L
.52593 .12361 L
.52705 .12361 L
.52826 .12361 L
.53862 .12361 L
.58011 .12361 L
.6201 .12361 L
.65856 .12361 L
.69948 .12361 L
.73888 .12361 L
.77677 .12361 L
.81711 .12361 L
.85594 .12361 L
.89721 .12361 L
Mistroke
.93697 .12361 L
.97522 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0:Oooo`<0I_n:oooo001Woooo00<0003oooooool08oooo`H0I_l2oooo00<0I_oooooo
ool0R?ooo`00Ioooo`030000oooooooo01koool506Ko2?ooo`0306Kooooooooo08Soool006Ooool0
0`000?ooooooo`0Foooo201Vo`goool00`1Vooooooooo`28oooo001Woooo0P0000ooool806Ko5Ooo
o`0306Kooooooooo08Soool006Ooool00`000?ooooooo`09oooo1@1Voagoool00`1Vooooooooo`28
oooo001Woooo00<0003oooooool00oooo`H0I_lRoooo00<0I_ooooooool0R?ooo`00HOooo`H0I_l0
0`00001Vo`1Vo`0306Ko:?ooo`0306Kooooooooo08Soool005_oool606Ko1_ooo`030000oooooooo
02_oool00`1Vooooooooo`28oooo001Foooo1@1Vo`coool00`000?ooooooo`0[oooo00<0I_oooooo
ool0R?ooo`00DOooo`D0I_lAoooo0P0002coool00`1Vooooooooo`28oooo000Goooo1@0001koool2
00001?ooo`800004oooo0P0000Goool406Ko5_ooo`030000oooooooo01koool200001?ooo`800004
oooo0P0001ooool500007Oooo`D00002oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002?ooo`050000oooooooo0000oooo00<0I_lJoooo00<0
003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00008?ooo`030000oooooooo
01ooool00`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Ooo
o`030000oooooooo01goool010000?ooooooo`0000_oool00`00001Vooooo`0Loooo00<0003ooooo
ool07Oooo`040000oooooooo00002oooo`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0
003oooooool02_ooo`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool0
0`000?ooooooo`0Goooo100000;oool010000?ooooooo`0000Woool200007oooo`030000oooooooo
01goool010000?ooooooo`0000Woool2000000<0I_ooooooool07_ooo`030000oooooooo01ooool0
0`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00001oooo`80I_l00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000
oooooooo00002Oooo`030000oooo06Ko023oool00`000?ooooooo`0Ooooo00<0003oooooool02?oo
o`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200008?ooo`800006oooo0P1V
o`;oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Poooo0P0000[oool300008?oo
o`80000Goooo0010oooo0P1VobGoool00`000?ooooooo`0/oooo00<0I_ooooooool0Qoooo`00?_oo
o`80I_lWoooo00<0003oooooool0;?ooo`0306Kooooooooo08Ooool003coool206Ko:Oooo`030000
oooooooo02coool00`1Vooooooooo`27oooo000joooo0P1Vob_oool00`000?ooooooo`0/oooo00<0
I_ooooooool0Qoooo`00>Oooo`0306Kooooooooo02_oool00`000?ooooooo`0/oooo00<0I_oooooo
ool0Qoooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`000c?o0003o`2I<ol0000000Lco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0000co`0co`009C?o00030000<ol0<ol000<co`000ol0VC?o03?o000N<ol04000
01Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol002/co`00
0ol0VC?o03?o000I<ol01@0006[oool006Ooool00`0003?o03?o000[<ol000?o09Tco`0co`0053?o
00D0001_oooo001Woooo00<0000co`0co`00:c?o0003o`2I<ol0<ol000lco`050000M?ooo`00Iooo
o`030000<ol0<ol002/co`000ol0VC?o03?o000;<ol0100007Woool006Ooool20000;3?o0003o`2I
<ol0<ol000Tco`020000OOooo`00Ioooo`030000<ol0<ol002/co`000ol0VC?o03?o0007<ol00P00
07ooool006Ooool00`0003?o03?o000[<ol000?o09Tco`0co`001C?o00800021oooo001Woooo00<0
000co`0co`00:c?o0003o`2I<ol0<ol000<co`020000Poooo`00Ioooo`030000<ol0<ol002/co`00
0ol0VC?o03?o0002<ol000<0003oooooool0Poooo`00Ioooo`030000<ol0<ol002/co`000ol0VC?o
03?o00020000Q_ooo`00Ioooo`80000/<ol000?o09T000000000R?ooo`00Ioooo`030000<ol0<ol0
02/co`000ol0VOooooooo`28oooo001Woooo00<0000co`0co`00:S?o00030000o`2Ioooo08Woool0
06Ooool00`0003?o03?o000Y<ol000<0003ooooo09T0R_ooo`00Ioooo`030000<ol0<ol002Pco`00
10000?ooooooool0VH[oool006Ooool00`0003?o03?o000X<ol000@0003ooooooooo09V:oooo001W
oooo0P0002Pco`001@000?ooooooooooool0V@2:oooo001Woooo00<0000co`0co`009S?o00030000
oooooooo00;oool00ol0VOooooooo`28oooo001Woooo00<0000co`0co`009C?o00030000oooooooo
00?oool00ol0VOooooooo`28oooo001Woooo00<0000co`0co`0093?o00030000oooooooo00Coool0
0ol0VOooooooo`28oooo001Woooo00<0000co`0co`008c?o00030000oooooooo00Goool00ol0VOoo
ooooo`28oooo001Woooo00<0000co`0co`008c?o00030000oooooooo00Goool00ol0VOooooooo`28
oooo001Woooo0P0002<co`000`000?ooooooo`06oooo00?o09Woooooool0R?ooo`00Ioooo`030000
<ol0<ol0024co`000`000?ooooooo`07oooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol0
020co`000`000?ooooooo`08oooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol0020co`00
0`000?ooooooo`08oooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol001lco`000`000?oo
ooooo`09oooo00?o09Woooooool0R?ooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo00Woool00ol0VOooooooo`28oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`0:oooo00?o09Woooooool0R?ooo`00HOooo`030000oooooooo00?oool2
00007c?o00030000oooooooo00[oool00ol0VOooooooo`28oooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`0;oooo00?o09Woooooool0R?ooo`00HOooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool02oooo`03o`2Ioooooooo08Soool0
063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`0<oooo00?o09Woooooool0R?oo
o`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`0<oooo00?o09Woooooool0R?ooo`00Iooo
o`030000<ol0<ol001/co`000`000?ooooooo`0=oooo00?o09Woooooool0R?ooo`00Ioooo`80000L
<ol000<0003oooooool03Oooo`03o`2Ioooooooo08Soool006Ooool00`0003?o03?o000J<ol000<0
003oooooool03_ooo`03o`2Ioooooooo08Soool006Ooool00`0003?o03?o000J<ol000<0003ooooo
ool03_ooo`03o`2Ioooooooo08Soool006Ooool00`0003?o03?o000I<ol000<0003oooooool03ooo
o`03o`2Ioooooooo08Soool006Ooool00`0003?o03?o000I<ol000<0003oooooool03oooo`03o`2I
oooooooo08Soool006Ooool00`0003?o03?o000H<ol000<0003oooooool04?ooo`03o`2Ioooooooo
08Soool006Ooool200006C?o00030000oooooooo013oool00ol0VOooooooo`28oooo001Woooo00<0
000co`0co`005c?o00030000oooooooo017oool00ol0VOooooooo`28oooo001Woooo00<0000co`0c
o`005c?o00030000oooooooo017oool00ol0VOooooooo`28oooo001Woooo00<0000co`0co`005S?o
00030000oooooooo01;oool00ol0VOooooooo`28oooo001Woooo00<0000co`0co`005S?o00030000
oooooooo01;oool00ol0VOooooooo`28oooo001Woooo00<0000co`0co`005S?o00030000oooooooo
01;oool00ol0VOooooooo`28oooo001Woooo00<0000co`0co`005C?o00030000oooooooo01?oool0
0ol0VOooooooo`28oooo001Woooo0P0001Hco`000`000?ooooooo`0Coooo00?o09Woooooool0R?oo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0Coooo00?o09Woooooool0R?ooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`0Coooo00?o09Woooooool0R?ooo`00Ioooo`030000
<ol0<ol001@co`000`000?ooooooo`0Doooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`0Doooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooooooo`0Doooo00?o09Woooooool0R?ooo`00Ioooo`80000E<ol000<0003oooooool05?oo
o`03o`2Ioooooooo08Soool006Ooool00`0003?o03?o000C<ol000<0003oooooool05Oooo`03o`2I
oooooooo08Soool006Ooool00`0003?o03?o000C<ol000<0003oooooool05Oooo`03o`2Ioooooooo
08Soool006Ooool00`0003?o03?o000C<ol000<0003oooooool05Oooo`03o`2Ioooooooo08Soool0
05ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0Eoooo00?o09Woooooool0R?oo
o`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool05_ooo`03o`2I
oooooooo08Soool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`0Foooo00?o
09Woooooool0R?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool05_ooo`03o`2Ioooooooo08Soool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool05oooo`03o`2Ioooooooo08Soool0063oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`0Goooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol0014co`00
0`000?ooooooo`0Goooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol0014co`000`000?oo
ooooo`0Goooo00?o09Woooooool0R?ooo`00Ioooo`80000A<ol000<0003oooooool06?ooo`03o`2I
oooooooo08Soool006Ooool00`0003?o03?o000@<ol000<0003oooooool06?ooo`03o`2Ioooooooo
08Soool006Ooool00`0003?o03?o000@<ol000<0003oooooool06?ooo`03o`2Ioooooooo08Soool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool06?ooo`03o`2Ioooooooo08Soool006Ooool0
0`0003?o03?o000?<ol000<0003oooooool06Oooo`03o`2Ioooooooo08Soool006Ooool00`0003?o
03?o000?<ol000<0003oooooool06Oooo`03o`2Ioooooooo08Soool006Ooool00`0003?o03?o000?
<ol000<0003oooooool06Oooo`03o`2Ioooooooo08Soool006Ooool2000043?o00030000oooooooo
01Woool00ol0VOooooooo`28oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01[oool0
0ol0VOooooooo`28oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01[oool00ol0VOoo
ooooo`28oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01[oool00ol0VOooooooo`28
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01[oool00ol0VOooooooo`28oooo001W
oooo00<0000co`0co`003C?o00030000oooooooo01_oool00ol0VOooooooo`28oooo001Woooo0P00
00hco`000`000?ooooooo`0Koooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`0Koooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`0Koooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0L
oooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Loooo00?o
09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Loooo00?o09Wooooo
ool0R?ooo`00Ioooo`80000=<ol000<0003oooooool07?ooo`03o`2Ioooooooo08Soool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool07?ooo`03o`2Ioooooooo08Soool006Ooool00`0003?o
03?o000<<ol000<0003oooooool07?ooo`03o`2Ioooooooo08Soool006Ooool00`0003?o03?o000;
<ol000<0003oooooool07Oooo`03o`2Ioooooooo08Soool0063oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Moooo00?o09Woooooool0R?ooo`00Goooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`0Moooo00?o09Woooooool0R?ooo`00HOooo`030000
oooooooo00?oool2000033?o00030000oooooooo01goool00ol0VOooooooo`28oooo001Roooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`0Moooo00?o09Woooooool0R?oo
o`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0Moooo00?o
09Woooooool0R?ooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo01koool0
0ol0VOooooooo`28oooo001Woooo00<0000co`0co`002S?o00030000oooooooo01koool00ol0VOoo
ooooo`28oooo001Woooo00<0000co`0co`002S?o00030000oooooooo01koool00ol0VOooooooo`28
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo01koool00ol0VOooooooo`28oooo001W
oooo0P0000/co`000`000?ooooooo`0Noooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0Noooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0Ooooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0Ooooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0O
oooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Ooooo00?o
09Woooooool0R?ooo`00Ioooo`80000:<ol000<0003oooooool07oooo`03o`2Ioooooooo08Soool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool07oooo`03o`2Ioooooooo08Soool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool07oooo`03o`2Ioooooooo08Soool006Ooool00`0003?o
03?o0008<ol000<0003oooooool08?ooo`03o`2Ioooooooo08Soool006Ooool00`0003?o03?o0008
<ol000<0003oooooool08?ooo`03o`2Ioooooooo08Soool006Ooool00`0003?o03?o0008<ol000<0
003oooooool08?ooo`03o`2Ioooooooo08Soool006Ooool200002C?o00030000oooooooo023oool0
0ol0VOooooooo`28oooo001Woooo00<0000co`0co`0023?o00030000oooooooo023oool00ol0VOoo
ooooo`28oooo001Woooo00<0000co`0co`0023?o00030000oooooooo023oool00ol0VOooooooo`28
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo027oool00ol0VOooooooo`28oooo001W
oooo00<0000co`0co`001c?o00030000oooooooo027oool00ol0VOooooooo`28oooo001Woooo00<0
000co`0co`001c?o00030000oooooooo027oool00ol0VOooooooo`28oooo001Woooo0P0000Pco`00
0`000?ooooooo`0Qoooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Qoooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Q
oooo00?o09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Qoooo00?o
09Woooooool0R?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Qoooo00?o09Wooooo
ool0R?ooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo027oool00ol0VOoo
ooooo`28oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`0Q
oooo00?o09Woooooool0R?ooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`0Qoooo00?o
09Woooooool0R?ooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool0
00001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o
0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o
00Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9
<ol02?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800004
oooo0P0000Coool200001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9
<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000;oooo00@0
003oooooool00002oooo00<0003oooooool00_ooo`030000oooooooo07Ooool006Ooool9<ol02?oo
o`030000oooooooo00D0000<oooo00@0003oooooool00009oooo0P0000Coool200001?ooo`030000
oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Woool00`000?ooooooo`02oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Iooo
o`Tco`09oooo00<0003oooooool04Oooo`80000:oooo0`0000?oool200000oooo`030000oooooooo
07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.51896 .12361 L
.52455 .12361 L
.52731 .12361 L
.52865 .12361 L
.52986 .12361 L
.53105 .12361 L
s
.53105 .12361 m
.5315 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.13506 .12361 L
.14415 .12361 L
.14635 .12361 L
.14868 .12361 L
.1499 .12361 L
.15059 .12361 L
.15124 .12326 L
.15238 .12238 L
.1536 .12145 L
.16254 .11495 L
.18221 .10251 L
.20192 .0923 L
.22343 .08339 L
.24402 .07671 L
.26314 .07189 L
.28366 .06798 L
.30227 .0654 L
.31229 .06434 L
.32152 .06355 L
.33164 .06287 L
.34234 .06235 L
.35181 .06179 L
.35713 .06137 L
.36198 .06093 L
.38031 .05887 L
.42015 .05299 L
.45848 .04652 L
.47787 .04321 L
.49927 .03967 L
.50901 .03813 L
.51952 .03652 L
.52435 .03581 L
.52699 .03542 L
.52944 .03507 L
.53052 .03492 L
.53154 .03478 L
.53271 .12361 L
.53378 .12361 L
.53853 .12361 L
.577 .12361 L
.61792 .12361 L
.65732 .12361 L
.69521 .12361 L
.73555 .12361 L
.77437 .12361 L
.81565 .12361 L
Mistroke
.85541 .12361 L
.89365 .12361 L
.93435 .12361 L
.97353 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0:Oooo`D0I_n8oooo001Woooo00<0003oooooool08oooo`H0I_l4oooo00<0I_oooooo
ool0Q_ooo`00Ioooo`030000oooooooo01goool606Ko2_ooo`0306Kooooooooo08Koool006Ooool0
0`000?ooooooo`0Foooo1`1Voa3oool00`1Vooooooooo`26oooo001Woooo0P00013oool706Ko5ooo
o`0306Kooooooooo08Koool006Ooool00`000?ooooooo`0:oooo1@1Voakoool00`1Vooooooooo`26
oooo001Woooo00<0003oooooool01Oooo`D0I_lSoooo00<0I_ooooooool0Q_ooo`00Goooo`P0I_l0
0`00001Vo`1Vo`0506Ko:?ooo`0306Kooooooooo08Koool005Koool906Ko2?ooo`030000oooooooo
02goool00`1Vooooooooo`26oooo001Boooo101Voa7oool00`000?ooooooo`0]oooo00<0I_oooooo
ool0Q_ooo`00D?ooo`80I_lEoooo0P0002koool00`1Vooooooooo`26oooo000Goooo1@0001koool2
00001?ooo`800004oooo0P0000Coool406Ko5oooo`030000oooooooo01koool200001?ooo`800004
oooo0P000003oooo06Kooooo01coool500007Oooo`D00002oooo0P0000Coool200008?ooo`@0000F
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00000`1V
oa_oool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00D0003oooooool00000I_l07ooo
o`030000oooooooo01ooool00`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003ooooo
ool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Soool306Ko00<0003ooooo
ool07?ooo`030000oooooooo01goool010000?ooooooo`0000_oool00`00001Vooooo`0Noooo00<0
003oooooool07oooo`030000oooooooo00[oool00`000?ooooooo`0Noooo00<0003oooooool05_oo
o`004Oooo`@00004oooo00<0003oooooool05oooo`@00002oooo00@0003oooooool00006oooo0P1V
o`03oooo0000000001ooool00`000?ooooooo`0Moooo00@0003oooooool00009oooo0P000003oooo
06Kooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`80000Roooo00<0003ooooo
ool05Oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Coool206Ko0oooo`030000
oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00@0003oooooool0I_lO
oooo00<0003oooooool07oooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00@0003ooooo
ool0000Foooo000Hoooo0P00023oool200000oooo`80I_l5oooo0`0001koool200007oooo`80000:
oooo0`00000306Kooooooooo01coool200008?ooo`80000:oooo0`00023oool200005oooo`00?_oo
o`0306Kooooooooo02Koool00`000?ooooooo`0]oooo00<0I_ooooooool0Q_ooo`00??ooo`80I_lY
oooo00<0003oooooool0;Oooo`0306Kooooooooo08Koool003[oool206Ko:oooo`030000oooooooo
02goool00`1Vooooooooo`26oooo000ioooo00<0I_ooooooool0:oooo`030000oooooooo02goool0
0`1Vooooooooo`26oooo000hoooo00<0I_ooooooool0;?ooo`030000oooooooo02goool00`1Voooo
ooooo`26oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000
oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`001C?o0003o`2I<ol0<ol001`co`0@
00006Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`00;C?o
0003o`2I<ol0<ol001Lco`050000J_ooo`00Ioooo`030000<ol0<ol002dco`000ol0VC?o03?o000B
<ol01@0006ooool006Ooool00`0003?o03?o000]<ol000?o09Tco`0co`003C?o00D0001doooo001W
oooo00<0000co`0co`00;C?o0003o`2I<ol0<ol000Tco`040000NOooo`00Ioooo`80000^<ol000?o
09Tco`0co`001c?o0080001moooo001Woooo00<0000co`0co`00;C?o0003o`2I<ol0<ol000Dco`02
0000Ooooo`00Ioooo`030000<ol0<ol002dco`000ol0VC?o03?o0003<ol00P00087oool006Ooool0
0`0003?o03?o000]<ol000Co09Tco`0co`0co`020000Poooo`00Ioooo`030000<ol0<ol002dco`00
1?l0VC?o03?o000008Goool006Ooool00`0003?o03?o000]<ol000?o09T000000000Q_ooo`00Iooo
o`80000]<ol000<0003o09Woool0Qoooo`00Ioooo`030000<ol0<ol002/co`000`000?ooool0V@28
oooo001Woooo00<0000co`0co`00:S?o00040000ooooooooo`2IR?ooo`00Ioooo`030000<ol0<ol0
02Tco`001@000?ooooooooooool0V@28oooo001Woooo00<0000co`0co`00:3?o00030000oooooooo
00;oool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`00:3?o00030000oooooooo00;oool0
0ol0VOooooooo`26oooo001Woooo0P0002Pco`000`000?ooooooo`03oooo00?o09Woooooool0Q_oo
o`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`04oooo00?o09Woooooool0Q_ooo`00Iooo
o`030000<ol0<ol002Dco`000`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Ioooo`030000
<ol0<ol002@co`000`000?ooooooo`06oooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol0
02<co`000`000?ooooooo`07oooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol002<co`00
0`000?ooooooo`07oooo00?o09Woooooool0Q_ooo`00Ioooo`80000S<ol000<0003oooooool02?oo
o`03o`2Ioooooooo08Koool006Ooool00`0003?o03?o000Q<ol000<0003oooooool02Oooo`03o`2I
oooooooo08Koool006Ooool00`0003?o03?o000P<ol000<0003oooooool02_ooo`03o`2Ioooooooo
08Koool006Ooool00`0003?o03?o000P<ol000<0003oooooool02_ooo`03o`2Ioooooooo08Koool0
06Ooool00`0003?o03?o000O<ol000<0003oooooool02oooo`03o`2Ioooooooo08Koool005ooool5
00000oooo`030000<ol0<ol001lco`000`000?ooooooo`0;oooo00?o09Woooooool0Q_ooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003oooooool03?ooo`03o`2Ioooooooo
08Koool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`0<oooo00?o09Wooooo
ool0Q_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool03Ooo
o`03o`2Ioooooooo08Koool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000
oooooooo00goool00ol0VOooooooo`26oooo001Poooo0P0000Goool00`0003?o03?o000L<ol000<0
003oooooool03_ooo`03o`2Ioooooooo08Koool006Ooool00`0003?o03?o000L<ol000<0003ooooo
ool03_ooo`03o`2Ioooooooo08Koool006Ooool00`0003?o03?o000K<ol000<0003oooooool03ooo
o`03o`2Ioooooooo08Koool006Ooool2000073?o00030000oooooooo00ooool00ol0VOooooooo`26
oooo001Woooo00<0000co`0co`006S?o00030000oooooooo013oool00ol0VOooooooo`26oooo001W
oooo00<0000co`0co`006S?o00030000oooooooo013oool00ol0VOooooooo`26oooo001Woooo00<0
000co`0co`006C?o00030000oooooooo017oool00ol0VOooooooo`26oooo001Woooo00<0000co`0c
o`006C?o00030000oooooooo017oool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`0063?o
00030000oooooooo01;oool00ol0VOooooooo`26oooo001Woooo0P0001Tco`000`000?ooooooo`0B
oooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`0Coooo00?o
09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`0Coooo00?o09Wooooo
ool0Q_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0Doooo00?o09Woooooool0Q_oo
o`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0Doooo00?o09Woooooool0Q_ooo`00Iooo
o`030000<ol0<ol001Hco`000`000?ooooooo`0Doooo00?o09Woooooool0Q_ooo`00Ioooo`030000
<ol0<ol001Dco`000`000?ooooooo`0Eoooo00?o09Woooooool0Q_ooo`00Ioooo`80000F<ol000<0
003oooooool05Oooo`03o`2Ioooooooo08Koool006Ooool00`0003?o03?o000E<ol000<0003ooooo
ool05Oooo`03o`2Ioooooooo08Koool006Ooool00`0003?o03?o000E<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo08Koool006Ooool00`0003?o03?o000D<ol000<0003oooooool05_ooo`03o`2I
oooooooo08Koool006Ooool00`0003?o03?o000D<ol000<0003oooooool05_ooo`03o`2Ioooooooo
08Koool006Ooool00`0003?o03?o000D<ol000<0003oooooool05_ooo`03o`2Ioooooooo08Koool0
06Ooool200005C?o00030000oooooooo01Koool00ol0VOooooooo`26oooo001Woooo00<0000co`0c
o`004c?o00030000oooooooo01Ooool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`004c?o
00030000oooooooo01Ooool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`004c?o00030000
oooooooo01Ooool00ol0VOooooooo`26oooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0
003oooooool05oooo`03o`2Ioooooooo08Koool005ooool00`000?ooooooo`05oooo00<0000co`0c
o`004S?o00030000oooooooo01Soool00ol0VOooooooo`26oooo001Poooo00<0003oooooool01?oo
o`80000C<ol000<0003oooooool06?ooo`03o`2Ioooooooo08Koool0067oool00`000?ooooooo`03
oooo00<0000co`0co`004S?o00030000oooooooo01Soool00ol0VOooooooo`26oooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo01Woool00ol0VOooooooo`26
oooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool06Oooo`03o`2Ioooooooo
08Koool006Ooool00`0003?o03?o000A<ol000<0003oooooool06Oooo`03o`2Ioooooooo08Koool0
06Ooool00`0003?o03?o000A<ol000<0003oooooool06Oooo`03o`2Ioooooooo08Koool006Ooool2
00004C?o00030000oooooooo01[oool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`0043?o
00030000oooooooo01[oool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`0043?o00030000
oooooooo01[oool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`0043?o00030000oooooooo
01[oool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`003c?o00030000oooooooo01_oool0
0ol0VOooooooo`26oooo001Woooo00<0000co`0co`003c?o00030000oooooooo01_oool00ol0VOoo
ooooo`26oooo001Woooo00<0000co`0co`003c?o00030000oooooooo01_oool00ol0VOooooooo`26
oooo001Woooo0P00010co`000`000?ooooooo`0Koooo00?o09Woooooool0Q_ooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`0Loooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`0Loooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`0Loooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol000hco`000`000?oo
ooooo`0Loooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0M
oooo00?o09Woooooool0Q_ooo`00Ioooo`80000><ol000<0003oooooool07Oooo`03o`2Ioooooooo
08Koool006Ooool00`0003?o03?o000=<ol000<0003oooooool07Oooo`03o`2Ioooooooo08Koool0
06Ooool00`0003?o03?o000=<ol000<0003oooooool07Oooo`03o`2Ioooooooo08Koool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Koool006Ooool00`0003?o
03?o000<<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Koool006Ooool00`0003?o03?o000<
<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Koool006Ooool200003C?o00030000oooooooo
01koool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`0033?o00030000oooooooo01koool0
0ol0VOooooooo`26oooo001Woooo00<0000co`0co`0033?o00030000oooooooo01koool00ol0VOoo
ooooo`26oooo001Woooo00<0000co`0co`002c?o00030000oooooooo01ooool00ol0VOooooooo`26
oooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool07oooo`03o`2Ioooooooo
08Koool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool07ooo
o`03o`2Ioooooooo08Koool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`0O
oooo00?o09Woooooool0Q_ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;<ol000<0
003oooooool07oooo`03o`2Ioooooooo08Koool005ooool010000?ooooooo`0000Coool00`0003?o
03?o000;<ol000<0003oooooool07oooo`03o`2Ioooooooo08Koool0063oool200001Oooo`030000
<ol0<ol000Xco`000`000?ooooooo`0Poooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0Poooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0Poooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Poooo00?o09Woooooool0Q_ooo`00Ioooo`80000;<ol000<0003oooooool08?ooo`03o`2I
oooooooo08Koool006Ooool00`0003?o03?o000:<ol000<0003oooooool08?ooo`03o`2Ioooooooo
08Koool006Ooool00`0003?o03?o0009<ol000<0003oooooool08Oooo`03o`2Ioooooooo08Koool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool08Oooo`03o`2Ioooooooo08Koool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool08Oooo`03o`2Ioooooooo08Koool006Ooool00`0003?o
03?o0009<ol000<0003oooooool08Oooo`03o`2Ioooooooo08Koool006Ooool200002S?o00030000
oooooooo027oool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`002C?o00030000oooooooo
027oool00ol0VOooooooo`26oooo001Woooo00<0000co`0co`002C?o00030000oooooooo027oool0
0ol0VOooooooo`26oooo001Woooo00<0000co`0co`0023?o00030000oooooooo02;oool00ol0VOoo
ooooo`26oooo001Woooo00<0000co`0co`0023?o00030000oooooooo02;oool00ol0VOooooooo`26
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo02;oool00ol0VOooooooo`26oooo001W
oooo0P0000Tco`000`000?ooooooo`0Roooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0Roooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0Roooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Soooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0S
oooo00?o09Woooooool0Q_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Soooo00?o
09Woooooool0Q_ooo`00Ioooo`800008<ol000<0003oooooool08oooo`03o`2Ioooooooo08Koool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool08oooo`03o`2Ioooooooo08Koool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool08oooo`03o`2Ioooooooo08Koool006Ooool00`0003?o
03?o0007<ol000<0003oooooool08oooo`03o`2Ioooooooo08Koool006Ooool00`0003?o03?o0007
<ol000<0003oooooool08oooo`03o`2Ioooooooo08Koool0067oool300000oooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Soooo00?o09Woooooool0Q_ooo`00H_ooo`030000oooooooo00;oool0
0`0003?o03?o0007<ol000<0003oooooool08oooo`03o`2Ioooooooo08Koool005ooool500000ooo
o`800008<ol000<0003oooooool08oooo`03o`2Ioooooooo08Koool005ooool010000?ooooooo`00
00Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o
0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00coool00`000?ooooooo`0R
oooo00<0003oooooool0O?ooo`00Ioooo`Tco`0;oooo00<0003oooooool02?ooo`030000oooooooo
01Woool00`000?ooooooo`1koooo001Woooo2C?o00_oool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`07oooo0P0000Coool200000oooo`<00004oooo00<0003oooooool0Noooo`00Iooo
o`Tco`0;oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Iooo
o`Tco`0:oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`1joooo001Woooo2C?o00_oool00`000?ooooooo`05
00003?ooo`040000oooooooo00002?ooo`<00004oooo00<0003oooooool0Noooo`00Ioooo`Tco`0;
oooo00D0003oooooooooool000003oooo`040000oooooooo00002Oooo`030000oooooooo00?oool0
0`000?ooooooo`1koooo001Woooo2C?o00coool00`000?ooooooo`0Aoooo0P0000[oool300000_oo
o`030000oooooooo07coool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.51896 .12361 L
.52455 .12361 L
.52986 .12361 L
.53463 .12361 L
.53594 .12361 L
.53666 .12361 L
.53733 .12361 L
s
.53733 .12361 m
.53786 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.13506 .12361 L
.13979 .12361 L
.14186 .12361 L
.14305 .12361 L
.14415 .12361 L
.14521 .12301 L
.14635 .12213 L
.14868 .12037 L
.1536 .11678 L
.16254 .11067 L
.18221 .09899 L
.20192 .08945 L
.22343 .08115 L
.24402 .07497 L
.26314 .07055 L
.28366 .067 L
.30227 .0647 L
.31229 .06378 L
.32152 .0631 L
.33164 .06254 L
.33674 .06232 L
.34234 .06212 L
.34758 .0619 L
.35254 .0616 L
.36185 .06089 L
.38276 .05866 L
.42109 .05314 L
.46187 .04637 L
.48213 .04295 L
.50114 .03983 L
.51931 .03699 L
.52428 .03624 L
.52952 .03548 L
.534 .03484 L
.53522 .03467 L
.53653 .03448 L
.53777 .03431 L
.53889 .12361 L
.54008 .12361 L
.5412 .12361 L
.54374 .12361 L
.54887 .12361 L
.55807 .12361 L
.57887 .12361 L
.6177 .12361 L
.65897 .12361 L
Mistroke
.69873 .12361 L
.73698 .12361 L
.77768 .12361 L
.81686 .12361 L
.85849 .12361 L
.89861 .12361 L
.93721 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0:?ooo`P0I_n6oooo001Woooo00<0003oooooool08oooo`D0I_l7oooo00<0I_oooooo
ool0Q?ooo`00Ioooo`030000oooooooo01koool506Ko3?ooo`0306Kooooooooo08Coool006Ooool0
0`000?ooooooo`0Ioooo1@1Voa7oool00`1Vooooooooo`24oooo001Woooo0P0001Goool506Ko5_oo
o`0306Kooooooooo08Coool006Ooool00`000?ooooooo`0=oooo1`1Voa_oool00`1Vooooooooo`24
oooo001Woooo00<0003oooooool01Oooo`P0I_lRoooo00<0I_ooooooool0Q?ooo`00Foooo``0I_l0
0`00001Vo`1Vo`0506Ko:_ooo`0306Kooooooooo08Coool005Koool506Ko3?ooo`030000oooooooo
02ooool00`1Vooooooooo`24oooo001Aoooo1@1Voa7oool00`000?ooooooo`0_oooo00<0I_oooooo
ool0Q?ooo`00COooo`@0I_lFoooo0P00033oool00`1Vooooooooo`24oooo000Goooo1@0001koool2
00001?ooo`800004oooo0P0000?oool206Ko6_ooo`030000oooooooo01koool200001?ooo`800004
oooo0P0000?oool00`1Vooooooooo`0Ioooo1@0001goool500000_ooo`800004oooo0P00023oool4
00005_ooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00
0080I_lLoooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`0306Kooooooooo01_oool00`000?ooooooo`0Ooooo00<0003oooooool01oooo`040000oooooooo
00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo0`1Vo`030000oooooooo01coool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00@0
003oooooool0I_lMoooo00<0003oooooool07oooo`030000oooooooo00[oool00`000?ooooooo`0N
oooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool05oooo`@00002oooo00@0
003oooooool00005oooo0`1Vo`03oooo0000000001ooool00`000?ooooooo`0Moooo00@0003ooooo
ool00009oooo0P0000?oool00`1Vooooooooo`0Koooo00<0003oooooool07oooo`030000oooooooo
00Soool200008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0003ooooo
ool00003oooo0P1Vo`Coool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`030000oooooooo00;oool00`1Vooooooooo`0Koooo00<0003oooooool07oooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00023oool2
00000_ooo`80I_l6oooo0`0001koool200007oooo`80000:oooo0`0000;oool00`1Vooooooooo`0J
oooo0P00023oool200002_ooo`<0000Poooo0P0001Ooool003coool206Ko:Oooo`030000oooooooo
02ooool00`1Vooooooooo`24oooo000joooo0P1Vob_oool00`000?ooooooo`0_oooo00<0I_oooooo
ool0Q?ooo`00>Oooo`0306Kooooooooo02_oool00`000?ooooooo`0_oooo00<0I_ooooooool0Q?oo
o`00>?ooo`0306Kooooooooo02coool00`000?ooooooo`0_oooo00<0I_ooooooool0Q?ooo`00=ooo
o`0306Kooooooooo02goool00`000?ooooooo`0_oooo00<0I_ooooooool0Q?ooo`004?ooool0000A
oooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000o`2I<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o
02P00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0c
o`009C?o00030000<ol0<ol000Hco`000ol0VC?o03?o000K<ol0400001Woool00`000?ooooooo`0V
oooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol002hco`000ol0VC?o03?o000F<ol01@00
06[oool006Ooool00`0003?o03?o000^<ol000?o09Tco`0co`004C?o00D0001_oooo001Woooo00<0
000co`0co`00;S?o0003o`2I<ol0<ol000`co`050000M?ooo`00Ioooo`030000<ol0<ol002hco`00
0ol0VC?o03?o0008<ol0100007Woool006Ooool20000;c?o0003o`2I<ol0<ol000Hco`020000OOoo
o`00Ioooo`030000<ol0<ol002hco`000ol0VC?o03?o0004<ol00P0007ooool006Ooool00`0003?o
03?o000^<ol000?o09Tco`0co`000S?o00800021oooo001Woooo00<0000co`0co`00;S?o0003o`2I
<ol0<ol000800023oooo001Woooo00<0000co`0co`00;S?o0003o`2I<ol0000008Goool006Ooool0
0`0003?o03?o000^<ol000?o09T0003oool0QOooo`00Ioooo`80000]<ol00P000003o`2Ioooooooo
08Goool006Ooool00`0003?o03?o000[<ol000@0003ooooooooo09V7oooo001Woooo00<0000co`0c
o`00:S?o00050000ooooooooooooo`2I08Ooool006Ooool00`0003?o03?o000Y<ol000<0003ooooo
ool00_ooo`03o`2Ioooooooo08Goool006Ooool00`0003?o03?o000X<ol000<0003oooooool00ooo
o`03o`2Ioooooooo08Goool006Ooool00`0003?o03?o000X<ol000<0003oooooool00oooo`03o`2I
oooooooo08Goool006Ooool20000:3?o00030000oooooooo00Coool00ol0VOooooooo`25oooo001W
oooo00<0000co`0co`009S?o00030000oooooooo00Goool00ol0VOooooooo`25oooo001Woooo00<0
000co`0co`009C?o00030000oooooooo00Koool00ol0VOooooooo`25oooo001Woooo00<0000co`0c
o`0093?o00030000oooooooo00Ooool00ol0VOooooooo`25oooo001Woooo00<0000co`0co`008c?o
00030000oooooooo00Soool00ol0VOooooooo`25oooo001Woooo00<0000co`0co`008c?o00030000
oooooooo00Soool00ol0VOooooooo`25oooo001Woooo0P0002<co`000`000?ooooooo`09oooo00?o
09Woooooool0QOooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`0:oooo00?o09Wooooo
ool0QOooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0;oooo00?o09Woooooool0QOoo
o`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0;oooo00?o09Woooooool0QOooo`00Iooo
o`030000<ol0<ol001lco`000`000?ooooooo`0<oooo00?o09Woooooool0QOooo`00Goooo`D00003
oooo00<0000co`0co`007c?o00030000oooooooo00coool00ol0VOooooooo`25oooo001Qoooo00<0
003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`0=oooo00?o09Woooooool0QOoo
o`00HOooo`030000oooooooo00?oool200007c?o00030000oooooooo00goool00ol0VOooooooo`25
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0>oooo00?o
09Woooooool0QOooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003ooooo
ool03_ooo`03o`2Ioooooooo08Goool0063oool200001Oooo`030000<ol0<ol001`co`000`000?oo
ooooo`0?oooo00?o09Woooooool0QOooo`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`0?
oooo00?o09Woooooool0QOooo`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`0@oooo00?o
09Woooooool0QOooo`00Ioooo`80000L<ol000<0003oooooool04?ooo`03o`2Ioooooooo08Goool0
06Ooool00`0003?o03?o000J<ol000<0003oooooool04Oooo`03o`2Ioooooooo08Goool006Ooool0
0`0003?o03?o000J<ol000<0003oooooool04Oooo`03o`2Ioooooooo08Goool006Ooool00`0003?o
03?o000I<ol000<0003oooooool04_ooo`03o`2Ioooooooo08Goool006Ooool00`0003?o03?o000I
<ol000<0003oooooool04_ooo`03o`2Ioooooooo08Goool006Ooool00`0003?o03?o000H<ol000<0
003oooooool04oooo`03o`2Ioooooooo08Goool006Ooool200006C?o00030000oooooooo01?oool0
0ol0VOooooooo`25oooo001Woooo00<0000co`0co`005c?o00030000oooooooo01Coool00ol0VOoo
ooooo`25oooo001Woooo00<0000co`0co`005c?o00030000oooooooo01Coool00ol0VOooooooo`25
oooo001Woooo00<0000co`0co`005S?o00030000oooooooo01Goool00ol0VOooooooo`25oooo001W
oooo00<0000co`0co`005S?o00030000oooooooo01Goool00ol0VOooooooo`25oooo001Woooo00<0
000co`0co`005S?o00030000oooooooo01Goool00ol0VOooooooo`25oooo001Woooo00<0000co`0c
o`005C?o00030000oooooooo01Koool00ol0VOooooooo`25oooo001Woooo0P0001Hco`000`000?oo
ooooo`0Foooo00?o09Woooooool0QOooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0F
oooo00?o09Woooooool0QOooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0Foooo00?o
09Woooooool0QOooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0Goooo00?o09Wooooo
ool0QOooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0Goooo00?o09Woooooool0QOoo
o`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0Goooo00?o09Woooooool0QOooo`00Iooo
o`80000E<ol000<0003oooooool05oooo`03o`2Ioooooooo08Goool006Ooool00`0003?o03?o000C
<ol000<0003oooooool06?ooo`03o`2Ioooooooo08Goool006Ooool00`0003?o03?o000C<ol000<0
003oooooool06?ooo`03o`2Ioooooooo08Goool006Ooool00`0003?o03?o000C<ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo08Goool005ooool400001?ooo`030000<ol0<ol001<co`000`000?oo
ooooo`0Hoooo00?o09Woooooool0QOooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000B
<ol000<0003oooooool06Oooo`03o`2Ioooooooo08Goool0063oool00`000?ooooooo`04oooo0P00
01<co`000`000?ooooooo`0Ioooo00?o09Woooooool0QOooo`00HOooo`030000oooooooo00?oool0
0`0003?o03?o000B<ol000<0003oooooool06_ooo`03o`2Ioooooooo08Coool005ooool010000?oo
ooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool06oooo`03o`2Ioooooooo08Coool0
063oool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`0Koooo00?o09Woooooool0Q?oo
o`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`0Koooo00?o09Woooooool0Q?ooo`00Iooo
o`030000<ol0<ol0014co`000`000?ooooooo`0Koooo00?o09Woooooool0Q?ooo`00Ioooo`80000A
<ol000<0003oooooool07?ooo`03o`2Ioooooooo08Coool006Ooool00`0003?o03?o000@<ol000<0
003oooooool07?ooo`03o`2Ioooooooo08Coool006Ooool00`0003?o03?o000@<ol000<0003ooooo
ool07?ooo`03o`2Ioooooooo08Coool006Ooool00`0003?o03?o000@<ol000<0003oooooool07?oo
o`03o`2Ioooooooo08Coool006Ooool00`0003?o03?o000?<ol000<0003oooooool07Oooo`03o`2I
oooooooo08Coool006Ooool00`0003?o03?o000?<ol000<0003oooooool07Oooo`03o`2Ioooooooo
08Coool006Ooool00`0003?o03?o000?<ol000<0003oooooool07Oooo`03o`2Ioooooooo08Coool0
06Ooool2000043?o00030000oooooooo01goool00ol0VOooooooo`24oooo001Woooo00<0000co`0c
o`003S?o00030000oooooooo01koool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`003S?o
00030000oooooooo01koool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`003S?o00030000
oooooooo01koool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`003S?o00030000oooooooo
01koool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`003C?o00030000oooooooo01ooool0
0ol0VOooooooo`24oooo001Woooo0P0000hco`000`000?ooooooo`0Ooooo00?o09Woooooool0Q?oo
o`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0Ooooo00?o09Woooooool0Q?ooo`00Iooo
o`030000<ol0<ol000dco`000`000?ooooooo`0Ooooo00?o09Woooooool0Q?ooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`0Poooo00?o09Woooooool0Q?ooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`0Poooo00?o09Woooooool0Q?ooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`0Poooo00?o09Woooooool0Q?ooo`00Ioooo`80000=<ol000<0003oooooool08?oo
o`03o`2Ioooooooo08Coool006Ooool00`0003?o03?o000<<ol000<0003oooooool08?ooo`03o`2I
oooooooo08Coool006Ooool00`0003?o03?o000<<ol000<0003oooooool08?ooo`03o`2Ioooooooo
08Coool006Ooool00`0003?o03?o000;<ol000<0003oooooool08Oooo`03o`2Ioooooooo08Coool0
063oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`0Qoooo00?o09Woooooool0Q?oo
o`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0Qoooo00?o
09Woooooool0Q?ooo`00HOooo`030000oooooooo00?oool2000033?o00030000oooooooo027oool0
0ol0VOooooooo`24oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`000`000?oo
ooooo`0Qoooo00?o09Woooooool0Q?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Qoooo00?o09Woooooool0Q?ooo`00H?ooo`800005oooo00<0000co`0c
o`002S?o00030000oooooooo02;oool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`002S?o
00030000oooooooo02;oool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`002S?o00030000
oooooooo02;oool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`002S?o00030000oooooooo
02;oool00ol0VOooooooo`24oooo001Woooo0P0000/co`000`000?ooooooo`0Roooo00?o09Wooooo
ool0Q?ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Roooo00?o09Woooooool0Q?oo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Soooo00?o09Woooooool0Q?ooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0Soooo00?o09Woooooool0Q?ooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`0Soooo00?o09Woooooool0Q?ooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0Soooo00?o09Woooooool0Q?ooo`00Ioooo`80000:<ol000<0003ooooo
ool08oooo`03o`2Ioooooooo08Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool08ooo
o`03o`2Ioooooooo08Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool08oooo`03o`2I
oooooooo08Coool006Ooool00`0003?o03?o0008<ol000<0003oooooool09?ooo`03o`2Ioooooooo
08Coool006Ooool00`0003?o03?o0008<ol000<0003oooooool09?ooo`03o`2Ioooooooo08Coool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool09?ooo`03o`2Ioooooooo08Coool006Ooool2
00002C?o00030000oooooooo02Coool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`0023?o
00030000oooooooo02Coool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`0023?o00030000
oooooooo02Coool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`001c?o00030000oooooooo
02Goool00ol0VOooooooo`24oooo001Woooo00<0000co`0co`001c?o00030000oooooooo02Goool0
0ol0VOooooooo`24oooo001Woooo00<0000co`0co`001c?o00030000oooooooo02Goool00ol0VOoo
ooooo`24oooo001Woooo0P0000Pco`000`000?ooooooo`0Uoooo00?o09Woooooool0Q?ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Uoooo00?o09Woooooool0Q?ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`0Uoooo00?o09Woooooool0Q?ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Uoooo00?o09Woooooool0Q?ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Uoooo00?o09Woooooool0Q?ooo`00HOooo`<00003oooo00<0000co`0co`001c?o
00030000oooooooo02Goool00ol0VOooooooo`24oooo001Roooo00<0003oooooool00_ooo`030000
<ol0<ol000Lco`000`000?ooooooo`0Uoooo00?o09Woooooool0Q?ooo`00Goooo`D00003oooo0P00
00Pco`000`000?ooooooo`0Uoooo00?o09Woooooool0Q?ooo`00Goooo`040000oooooooo00001?oo
o`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[ooo
o`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800003oooo0`0000?oool400000oooo`030000oooooooo07Soool0
06Ooool9<ol02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000oooooooo00Coool0
0`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03Ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002?oo
o`<00005oooo00<0003oooooool00_ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`02oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:
oooo0`0000?oool200000oooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2a
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53057 .12361 L
.53984 .12361 L
.54221 .12361 L
.54337 .12361 L
.54444 .12361 L
s
.54444 .12361 m
.54493 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.10458 .12361 L
.11448 .12361 L
.12507 .12361 L
.1302 .12361 L
.13273 .12361 L
.13506 .12361 L
.13615 .12361 L
.13718 .12361 L
.13824 .12349 L
.13942 .12258 L
.14415 .11902 L
.18292 .09534 L
.20406 .08593 L
.22415 .07885 L
.24395 .07338 L
.26234 .06947 L
.27291 .06767 L
.28286 .06623 L
.30147 .06416 L
.31123 .06337 L
.32155 .06273 L
.33035 .06232 L
.33535 .06215 L
.34002 .06202 L
.34245 .06196 L
.34503 .06188 L
.34786 .06177 L
.35047 .06164 L
.36037 .06101 L
.36919 .06025 L
.37893 .05924 L
.41913 .05378 L
.45782 .04751 L
.49896 .04068 L
.51949 .03744 L
.52949 .03594 L
.53858 .03464 L
.54079 .03433 L
.54313 .03401 L
.54435 .03384 L
.54505 .12361 L
.5457 .12361 L
.54806 .12361 L
.55701 .12361 L
.57669 .12361 L
.61552 .12361 L
.65679 .12361 L
Mistroke
.69655 .12361 L
.7348 .12361 L
.7755 .12361 L
.81468 .12361 L
.85631 .12361 L
.89643 .12361 L
.93504 .12361 L
.97609 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0;?ooo`D0I_n5oooo001Woooo00<0003oooooool08oooo`T0I_l4oooo00<0I_oooooo
ool0Poooo`00Ioooo`030000oooooooo01goool606Ko3Oooo`0306Kooooooooo08?oool006Ooool0
0`000?ooooooo`0Hoooo1@1Voa?oool00`1Vooooooooo`23oooo001Woooo0P0001Coool506Ko6?oo
o`0306Kooooooooo08?oool006Ooool00`000?ooooooo`0<oooo1`1Voagoool00`1Vooooooooo`23
oooo001Woooo00<0003oooooool01?ooo`P0I_lToooo00<0I_ooooooool0Poooo`00Foooo``0I_l0
0`00001Vo`1Vo`0406Ko;?ooo`0306Kooooooooo08?oool005Goool606Ko3?ooo`030000oooooooo
033oool00`1Vooooooooo`23oooo001Aoooo101Voa;oool00`000?ooooooo`0`oooo00<0I_oooooo
ool0Poooo`00C?ooo`D0I_lFoooo0P00037oool00`1Vooooooooo`23oooo000Goooo1@0001koool2
00001?ooo`800004oooo0P0000@0I_lKoooo00<0003oooooool07_ooo`800004oooo0P0000Coool2
00001?ooo`0306Kooooooooo01Soool500007Oooo`D00002oooo0P0000Coool200008?ooo`@0000F
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`04000006Ko06Ko00007_oo
o`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`1Voooo
ooooo`0Joooo00<0003oooooool07oooo`030000oooooooo00Ooool010000?ooooooo`0001ooool0
0`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00001_ooo`<0I_l2
oooo00<0003oooooool07?ooo`030000oooooooo01goool010000?ooooooo`0000_oool01@000?oo
ooooooooo`1Vo`0Loooo00<0003oooooool07oooo`030000oooooooo00[oool00`000?ooooooo`0N
oooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool05oooo`@00002oooo00@0
003oooooool00004oooo0P1Vo`?oool200007oooo`030000oooooooo01goool010000?ooooooo`00
00Woool200001?ooo`0306Kooooooooo01[oool00`000?ooooooo`0Ooooo00<0003oooooool02?oo
o`80000Roooo00<0003oooooool05Oooo`006Oooo`030000oooooooo01goool010000?ooooooo`00
00;oool206Ko1Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009
oooo00<0003oooooool00oooo`0306Kooooooooo01[oool00`000?ooooooo`0Ooooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200008?ooo`800000
0oooo`1Vo`1Vo`07oooo0`0001koool200007oooo`80000:oooo0`0000?oool00`1Vooooooooo`0I
oooo0P00023oool200002_ooo`<0000Poooo0P0001Ooool003_oool206Ko:_ooo`030000oooooooo
033oool00`1Vooooooooo`23oooo000joooo00<0I_ooooooool0:_ooo`030000oooooooo033oool0
0`1Vooooooooo`23oooo000hoooo0P1Vobgoool00`000?ooooooo`0`oooo00<0I_ooooooool0Pooo
o`00=_ooo`80I_l_oooo00<0003oooooool0<?ooo`0306Kooooooooo08?oool003Goool00`1Voooo
ooooo`0_oooo00<0003oooooool0<?ooo`0306Kooooooooo08?oool0013ooooo00004Oooo`005_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`00100003?o03?o0?l0V@@co`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o02P00002
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o
00030000<ol0<ol000Pco`000ol0VC?o03?o000I<ol0400001Woool00`000?ooooooo`0Voooo00<0
003oooooool05Oooo`00Ioooo`030000<ol0<ol0030co`000ol0VC?o03?o000D<ol01@0006[oool0
06Ooool00`0003?o03?o000`<ol000?o09Tco`0co`003c?o00D0001_oooo001Woooo00<0000co`0c
o`00<3?o0003o`2I<ol0<ol000Xco`050000M?ooo`00Ioooo`030000<ol0<ol0030co`000ol0VC?o
03?o0006<ol0100007Woool006Ooool20000<C?o0003o`2I<ol0<ol000@co`020000OOooo`00Iooo
o`030000<ol0<ol0030co`000ol0VC?o03?o0002<ol00P0007ooool006Ooool00`0003?o03?o000`
<ol000?o09Tco`0co`000P00087oool006Ooool00`0003?o03?o000`<ol000?o09T000000000Pooo
o`00Ioooo`030000<ol0<ol0030co`000ol0VOooooooo`23oooo001Woooo00<0000co`0co`00;S?o
008000000ol0VOooooooo`23oooo001Woooo0P0002dco`0200000_ooo`03o`2Ioooooooo08?oool0
06Ooool00`0003?o03?o000[<ol000<0003oooooool00_ooo`03o`2Ioooooooo08?oool006Ooool0
0`0003?o03?o000Z<ol000<0003oooooool00oooo`03o`2Ioooooooo08?oool006Ooool00`0003?o
03?o000Y<ol000<0003oooooool01?ooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o000X
<ol000<0003oooooool01Oooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o000X<ol000<0
003oooooool01Oooo`03o`2Ioooooooo08?oool006Ooool20000:3?o00030000oooooooo00Koool0
0ol0VOooooooo`23oooo001Woooo00<0000co`0co`009S?o00030000oooooooo00Ooool00ol0VOoo
ooooo`23oooo001Woooo00<0000co`0co`009C?o00030000oooooooo00Soool00ol0VOooooooo`23
oooo001Woooo00<0000co`0co`0093?o00030000oooooooo00Woool00ol0VOooooooo`23oooo001W
oooo00<0000co`0co`008c?o00030000oooooooo00[oool00ol0VOooooooo`23oooo001Woooo00<0
000co`0co`008c?o00030000oooooooo00[oool00ol0VOooooooo`23oooo001Woooo0P0002<co`00
0`000?ooooooo`0;oooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol0024co`000`000?oo
ooooo`0<oooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0=
oooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0=oooo00?o
09Woooooool0Poooo`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`0>oooo00?o09Wooooo
ool0Poooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo00koool00ol0VOoo
ooooo`23oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`0?
oooo00?o09Woooooool0Poooo`00HOooo`030000oooooooo00?oool200007c?o00030000oooooooo
00ooool00ol0VOooooooo`23oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`00
0`000?ooooooo`0@oooo00?o09Woooooool0Poooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o000M<ol000<0003oooooool04?ooo`03o`2Ioooooooo08?oool0063oool200001Oooo`030000
<ol0<ol001`co`000`000?ooooooo`0Aoooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol0
01`co`000`000?ooooooo`0Aoooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol001/co`00
0`000?ooooooo`0Boooo00?o09Woooooool0Poooo`00Ioooo`80000L<ol000<0003oooooool04_oo
o`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o000J<ol000<0003oooooool04oooo`03o`2I
oooooooo08?oool006Ooool00`0003?o03?o000J<ol000<0003oooooool04oooo`03o`2Ioooooooo
08?oool006Ooool00`0003?o03?o000I<ol000<0003oooooool05?ooo`03o`2Ioooooooo08?oool0
06Ooool00`0003?o03?o000I<ol000<0003oooooool05?ooo`03o`2Ioooooooo08?oool006Ooool0
0`0003?o03?o000H<ol000<0003oooooool05Oooo`03o`2Ioooooooo08?oool006Ooool200006C?o
00030000oooooooo01Goool00ol0VOooooooo`23oooo001Woooo00<0000co`0co`005c?o00030000
oooooooo01Koool00ol0VOooooooo`23oooo001Woooo00<0000co`0co`005c?o00030000oooooooo
01Koool00ol0VOooooooo`23oooo001Woooo00<0000co`0co`005S?o00030000oooooooo01Ooool0
0ol0VOooooooo`23oooo001Woooo00<0000co`0co`005S?o00030000oooooooo01Ooool00ol0VOoo
ooooo`23oooo001Woooo00<0000co`0co`005S?o00030000oooooooo01Ooool00ol0VOooooooo`23
oooo001Woooo00<0000co`0co`005C?o00030000oooooooo01Soool00ol0VOooooooo`23oooo001W
oooo0P0001Hco`000`000?ooooooo`0Hoooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0Hoooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol001Dco`00
0`000?ooooooo`0Hoooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol001@co`000`000?oo
ooooo`0Ioooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0I
oooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0Ioooo00?o
09Woooooool0Poooo`00Ioooo`80000E<ol000<0003oooooool06Oooo`03o`2Ioooooooo08?oool0
06Ooool00`0003?o03?o000C<ol000<0003oooooool06_ooo`03o`2Ioooooooo08?oool006Ooool0
0`0003?o03?o000C<ol000<0003oooooool06_ooo`03o`2Ioooooooo08?oool006Ooool00`0003?o
03?o000C<ol000<0003oooooool06_ooo`03o`2Ioooooooo08?oool005ooool400001?ooo`030000
<ol0<ol001<co`000`000?ooooooo`0Joooo00?o09Woooooool0Poooo`00Goooo`030000oooooooo
00Goool00`0003?o03?o000B<ol000<0003oooooool06oooo`03o`2Ioooooooo08?oool0063oool0
0`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`0Koooo00?o09Woooooool0Poooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool06oooo`03o`2Ioooooooo
08?oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool07?oo
o`03o`2Ioooooooo08?oool0063oool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`0L
oooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`0Loooo00?o
09Woooooool0Poooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`0Loooo00?o09Wooooo
ool0Poooo`00Ioooo`80000A<ol000<0003oooooool07Oooo`03o`2Ioooooooo08?oool006Ooool0
0`0003?o03?o000@<ol000<0003oooooool07Oooo`03o`2Ioooooooo08?oool006Ooool00`0003?o
03?o000@<ol000<0003oooooool07Oooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o000@
<ol000<0003oooooool07Oooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o000?<ol000<0
003oooooool07_ooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o000?<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o000?<ol000<0003oooooool07_oo
o`03o`2Ioooooooo08?oool006Ooool2000043?o00030000oooooooo01koool00ol0VOooooooo`23
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo01ooool00ol0VOooooooo`23oooo001W
oooo00<0000co`0co`003S?o00030000oooooooo01ooool00ol0VOooooooo`23oooo001Woooo00<0
000co`0co`003S?o00030000oooooooo01ooool00ol0VOooooooo`23oooo001Woooo00<0000co`0c
o`003S?o00030000oooooooo01ooool00ol0VOooooooo`23oooo001Woooo00<0000co`0co`003C?o
00030000oooooooo023oool00ol0VOooooooo`23oooo001Woooo0P0000hco`000`000?ooooooo`0P
oooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0Poooo00?o
09Woooooool0Poooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0Poooo00?o09Wooooo
ool0Poooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Qoooo00?o09Woooooool0Pooo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Qoooo00?o09Woooooool0Poooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`0Qoooo00?o09Woooooool0Poooo`00Ioooo`80000=
<ol000<0003oooooool08Oooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o000<<ol000<0
003oooooool08Oooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool08Oooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o000;<ol000<0003oooooool08_oo
o`03o`2Ioooooooo08?oool0063oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`0R
oooo00?o09Woooooool0Poooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Roooo00?o09Woooooool0Poooo`00HOooo`030000oooooooo00?oool2000033?o
00030000oooooooo02;oool00ol0VOooooooo`23oooo001Roooo00<0003oooooool00_ooo`030000
<ol0<ol000/co`000`000?ooooooo`0Roooo00?o09Woooooool0Poooo`00Goooo`040000oooooooo
00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0Roooo00?o09Woooooool0Poooo`00H?oo
o`800005oooo00<0000co`0co`002S?o00030000oooooooo02?oool00ol0VOooooooo`23oooo001W
oooo00<0000co`0co`002S?o00030000oooooooo02?oool00ol0VOooooooo`23oooo001Woooo00<0
000co`0co`002S?o00030000oooooooo02?oool00ol0VOooooooo`23oooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo02?oool00ol0VOooooooo`23oooo001Woooo0P0000/co`000`000?oo
ooooo`0Soooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0S
oooo00?o09Woooooool0Poooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Toooo00?o
09Woooooool0Poooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Toooo00?o09Wooooo
ool0Poooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Toooo00?o09Woooooool0Pooo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Toooo00?o09Woooooool0Poooo`00Iooo
o`80000:<ol000<0003oooooool09?ooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o0009
<ol000<0003oooooool09?ooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o0009<ol000<0
003oooooool09?ooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool09Oooo`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o0008<ol000<0003oooooool09Ooo
o`03o`2Ioooooooo08?oool006Ooool00`0003?o03?o0008<ol000<0003oooooool09Oooo`03o`2I
oooooooo08?oool006Ooool200002C?o00030000oooooooo02Goool00ol0VOooooooo`23oooo001W
oooo00<0000co`0co`0023?o00030000oooooooo02Goool00ol0VOooooooo`23oooo001Woooo00<0
000co`0co`0023?o00030000oooooooo02Goool00ol0VOooooooo`23oooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo02Koool00ol0VOooooooo`23oooo001Woooo00<0000co`0co`001c?o
00030000oooooooo02Koool00ol0VOooooooo`23oooo001Woooo00<0000co`0co`001c?o00030000
oooooooo02Koool00ol0VOooooooo`23oooo001Woooo0P0000Pco`000`000?ooooooo`0Voooo00?o
09Woooooool0Poooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Voooo00?o09Wooooo
ool0Poooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Voooo00?o09Woooooool0Pooo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Voooo00?o09Woooooool0Poooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Voooo00?o09Woooooool0Poooo`00HOooo`<00003
oooo00<0000co`0co`001c?o00030000oooooooo02Koool00ol0VOooooooo`23oooo001Roooo00<0
003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`0Voooo00?o09Woooooool0Pooo
o`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`0Voooo00?o09Woooooool0Poooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Ooo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo0`0000Goool300000_oo
o`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`050000oooooooooooo000007[oool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00002oooo1@0000?oool00`000?oo
ooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002?oo
o`<00003oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0
003oooooooooool000003oooo`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?oo
o`000003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:
oooo0`0000Coool200000_ooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2a
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54444 .12361 L
.54696 .12361 L
.54934 .12361 L
.55 .12361 L
.5507 .12361 L
s
.5507 .12361 m
.551 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.10458 .12361 L
.11448 .12361 L
.11992 .12361 L
.12507 .12361 L
.12739 .12361 L
.12986 .12361 L
.13115 .12361 L
.13188 .1235 L
.13256 .12297 L
.13506 .12107 L
.14415 .1145 L
.18292 .09228 L
.20406 .08351 L
.22415 .07694 L
.24395 .07192 L
.26234 .06835 L
.27291 .06672 L
.28286 .06544 L
.30147 .06363 L
.31123 .06295 L
.31657 .06265 L
.32155 .06242 L
.33035 .06211 L
.33502 .06199 L
.34002 .06189 L
.34258 .06185 L
.34388 .06183 L
.34531 .06179 L
.35019 .06162 L
.35294 .06149 L
.3559 .06133 L
.36126 .06099 L
.38138 .05914 L
.40142 .05668 L
.42252 .05364 L
.46063 .04754 L
.50119 .04085 L
.51993 .03789 L
.52979 .0364 L
.54024 .03488 L
.54553 .03414 L
.54697 .03394 L
.54853 .03373 L
.54928 .03363 L
.55 .03353 L
.55064 .03345 L
.55134 .12361 L
Mistroke
.55204 .12361 L
.55269 .12361 L
.55392 .12361 L
.55666 .12361 L
.56158 .12361 L
.58173 .12361 L
.62034 .12361 L
.66139 .12361 L
.70093 .12361 L
.73896 .12361 L
.77943 .12361 L
.81839 .12361 L
.85981 .12361 L
.8997 .12361 L
.93809 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`2foooo001Woooo00<0
003oooooool0;?ooo`L0I_n3oooo001Woooo00<0003oooooool08oooo`T0I_l6oooo00<0I_oooooo
ool0POooo`00Ioooo`030000oooooooo01koool506Ko3oooo`0306Kooooooooo087oool006Ooool0
0`000?ooooooo`0Ioooo1@1VoaCoool00`1Vooooooooo`21oooo001Woooo0P0001Goool506Ko6Ooo
o`0306Kooooooooo087oool006Ooool00`000?ooooooo`0:oooo2P1Voakoool00`1Vooooooooo`21
oooo001Woooo00<0003oooooool01Oooo`D0I_lXoooo00<0I_ooooooool0POooo`00Foooo``0I_l0
0`00001Vo`1Vo`0506Ko;Oooo`0306Kooooooooo087oool0057oool:06Ko3?ooo`030000oooooooo
03;oool00`1Vooooooooo`21oooo001=oooo101VoaKoool00`000?ooooooo`0boooo00<0I_oooooo
ool0POooo`00Boooo`80I_lJoooo0P0003?oool00`1Vooooooooo`21oooo000Goooo1@0001koool2
00001?ooo`800004oooo0P0000<0I_lLoooo00<0003oooooool07_ooo`800004oooo0P0000Coool2
00001_ooo`0306Kooooooooo01Koool500007Oooo`D00002oooo0P0000Coool200008?ooo`@0000F
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00001_ooo`80I_l01000001Vooooo`00
01koool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0
I_ooooooool06?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0003oooooool0000O
oooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Coool2
06Ko1Oooo`030000oooooooo01coool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0
003oooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0Ooooo00<0003oooooool02_oo
o`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0G
oooo100000;oool010000?ooooooo`0000;oool206Ko1Oooo`80000Ooooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`800006oooo00<0I_ooooooool06?ooo`030000oooooooo01ooool0
0`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00000P1Vo`Ooool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`1Vooooooooo`0Hoooo00<0003oooooool07ooo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00
023oool2000000<0I_ooooooool01oooo`<0000Noooo0P0001ooool200002_ooo`<00005oooo00<0
I_ooooooool05oooo`80000Poooo0P0000[oool300008?ooo`80000Goooo000joooo00<0I_oooooo
ool0:_ooo`030000oooooooo03;oool00`1Vooooooooo`21oooo000hoooo0P1Vobgoool00`000?oo
ooooo`0boooo00<0I_ooooooool0POooo`00=_ooo`80I_l_oooo00<0003oooooool0<_ooo`0306Ko
oooooooo087oool003Goool00`1Vooooooooo`0_oooo00<0003oooooool0<_ooo`0306Kooooooooo
087oool003?oool206Ko<_ooo`030000oooooooo03;oool00`1Vooooooooo`21oooo000@ooooo`00
017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`000S?o0004o`2I<ol0<ol000001c?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000
<ol0<ol002Dco`000`0003?o03?o000:<ol000?o09Tco`0co`005c?o0100000Ioooo00<0003ooooo
ool09_ooo`030000oooooooo01Goool006Ooool00`0003?o03?o000b<ol000?o09Tco`0co`004S?o
00D0001Zoooo001Woooo00<0000co`0co`00<S?o0003o`2I<ol0<ol000dco`050000Koooo`00Iooo
o`030000<ol0<ol0038co`000ol0VC?o03?o0008<ol01@0007Coool006Ooool00`0003?o03?o000b
<ol000?o09Tco`0co`0013?o00@0001ioooo001Woooo0P0003<co`000ol0VC?o03?o0002<ol00P00
07goool006Ooool00`0003?o03?o000b<ol000?o09Tco`0co`000P0007ooool006Ooool00`0003?o
03?o000b<ol000?o09T000000000POooo`00Ioooo`030000<ol0<ol0034co`000`000?l0VOooo`22
oooo001Woooo00<0000co`0co`00<3?o00030000ooooo`2I08?oool006Ooool00`0003?o03?o000^
<ol00P0000;oool00ol0VOooooooo`21oooo001Woooo0P0002dco`0200001?ooo`03o`2Ioooooooo
087oool006Ooool00`0003?o03?o000[<ol000<0003oooooool01?ooo`03o`2Ioooooooo087oool0
06Ooool00`0003?o03?o000Z<ol000<0003oooooool01Oooo`03o`2Ioooooooo087oool006Ooool0
0`0003?o03?o000Y<ol000<0003oooooool01_ooo`03o`2Ioooooooo087oool006Ooool00`0003?o
03?o000X<ol000<0003oooooool01oooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o000X
<ol000<0003oooooool01oooo`03o`2Ioooooooo087oool006Ooool20000:3?o00030000oooooooo
00Soool00ol0VOooooooo`21oooo001Woooo00<0000co`0co`009S?o00030000oooooooo00Woool0
0ol0VOooooooo`21oooo001Woooo00<0000co`0co`009C?o00030000oooooooo00[oool00ol0VOoo
ooooo`21oooo001Woooo00<0000co`0co`0093?o00030000oooooooo00_oool00ol0VOooooooo`21
oooo001Woooo00<0000co`0co`008c?o00030000oooooooo00coool00ol0VOooooooo`21oooo001W
oooo00<0000co`0co`008c?o00030000oooooooo00coool00ol0VOooooooo`21oooo001Woooo0P00
02<co`000`000?ooooooo`0=oooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol0024co`00
0`000?ooooooo`0>oooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol0020co`000`000?oo
ooooo`0?oooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0?
oooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`0@oooo00?o
09Woooooool0POooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo013oool0
0ol0VOooooooo`21oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?oo
ooooo`0Aoooo00?o09Woooooool0POooo`00HOooo`030000oooooooo00?oool200007c?o00030000
oooooooo017oool00ol0VOooooooo`21oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`000`000?ooooooo`0Boooo00?o09Woooooool0POooo`00HOooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool04_ooo`03o`2Ioooooooo087oool0063oool200001Ooo
o`030000<ol0<ol001`co`000`000?ooooooo`0Coooo00?o09Woooooool0POooo`00Ioooo`030000
<ol0<ol001`co`000`000?ooooooo`0Coooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol0
01/co`000`000?ooooooo`0Doooo00?o09Woooooool0POooo`00Ioooo`80000L<ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o000J<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo087oool006Ooool00`0003?o03?o000J<ol000<0003oooooool05Oooo`03o`2I
oooooooo087oool006Ooool00`0003?o03?o000I<ol000<0003oooooool05_ooo`03o`2Ioooooooo
087oool006Ooool00`0003?o03?o000I<ol000<0003oooooool05_ooo`03o`2Ioooooooo087oool0
06Ooool00`0003?o03?o000H<ol000<0003oooooool05oooo`03o`2Ioooooooo087oool006Ooool2
00006C?o00030000oooooooo01Ooool00ol0VOooooooo`21oooo001Woooo00<0000co`0co`005c?o
00030000oooooooo01Soool00ol0VOooooooo`21oooo001Woooo00<0000co`0co`005c?o00030000
oooooooo01Soool00ol0VOooooooo`21oooo001Woooo00<0000co`0co`005S?o00030000oooooooo
01Woool00ol0VOooooooo`21oooo001Woooo00<0000co`0co`005S?o00030000oooooooo01Woool0
0ol0VOooooooo`21oooo001Woooo00<0000co`0co`005S?o00030000oooooooo01Woool00ol0VOoo
ooooo`21oooo001Woooo00<0000co`0co`005C?o00030000oooooooo01[oool00ol0VOooooooo`21
oooo001Woooo0P0001Hco`000`000?ooooooo`0Joooo00?o09Woooooool0POooo`00Ioooo`030000
<ol0<ol001Dco`000`000?ooooooo`0Joooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0Joooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooooooo`0Koooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol001@co`000`000?oo
ooooo`0Koooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0K
oooo00?o09Woooooool0POooo`00Ioooo`80000E<ol000<0003oooooool06oooo`03o`2Ioooooooo
087oool006Ooool00`0003?o03?o000C<ol000<0003oooooool07?ooo`03o`2Ioooooooo087oool0
06Ooool00`0003?o03?o000C<ol000<0003oooooool07?ooo`03o`2Ioooooooo087oool006Ooool0
0`0003?o03?o000C<ol000<0003oooooool07?ooo`03o`2Ioooooooo087oool005ooool400001?oo
o`030000<ol0<ol001<co`000`000?ooooooo`0Loooo00?o09Woooooool0POooo`00Goooo`030000
oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool07Oooo`03o`2Ioooooooo087oool0
063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`0Moooo00?o09Woooooool0POoo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool07Oooo`03o`2I
oooooooo087oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo087oool0063oool200001Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`0Noooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`0N
oooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`0Noooo00?o
09Woooooool0POooo`00Ioooo`80000A<ol000<0003oooooool07oooo`03o`2Ioooooooo087oool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool07oooo`03o`2Ioooooooo087oool006Ooool0
0`0003?o03?o000@<ol000<0003oooooool07oooo`03o`2Ioooooooo087oool006Ooool00`0003?o
03?o000@<ol000<0003oooooool07oooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o000?
<ol000<0003oooooool08?ooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o000?<ol000<0
003oooooool08?ooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o000?<ol000<0003ooooo
ool08?ooo`03o`2Ioooooooo087oool006Ooool2000043?o00030000oooooooo023oool00ol0VOoo
ooooo`21oooo001Woooo00<0000co`0co`003S?o00030000oooooooo027oool00ol0VOooooooo`21
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo027oool00ol0VOooooooo`21oooo001W
oooo00<0000co`0co`003S?o00030000oooooooo027oool00ol0VOooooooo`21oooo001Woooo00<0
000co`0co`003S?o00030000oooooooo027oool00ol0VOooooooo`21oooo001Woooo00<0000co`0c
o`003C?o00030000oooooooo02;oool00ol0VOooooooo`21oooo001Woooo0P0000hco`000`000?oo
ooooo`0Roooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0R
oooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0Roooo00?o
09Woooooool0POooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Soooo00?o09Wooooo
ool0POooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Soooo00?o09Woooooool0POoo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0Soooo00?o09Woooooool0POooo`00Iooo
o`80000=<ol000<0003oooooool08oooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o000<
<ol000<0003oooooool08oooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o000<<ol000<0
003oooooool08oooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o000;<ol000<0003ooooo
ool09?ooo`03o`2Ioooooooo087oool0063oool200001Oooo`030000<ol0<ol000/co`000`000?oo
ooooo`0Toooo00?o09Woooooool0POooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Toooo00?o09Woooooool0POooo`00HOooo`030000oooooooo00?oool2
000033?o00030000oooooooo02Coool00ol0VOooooooo`21oooo001Roooo00<0003oooooool00_oo
o`030000<ol0<ol000/co`000`000?ooooooo`0Toooo00?o09Woooooool0POooo`00Goooo`040000
oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0Toooo00?o09Woooooool0POoo
o`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo02Goool00ol0VOooooooo`21
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo02Goool00ol0VOooooooo`21oooo001W
oooo00<0000co`0co`002S?o00030000oooooooo02Goool00ol0VOooooooo`21oooo001Woooo00<0
000co`0co`002S?o00030000oooooooo02Goool00ol0VOooooooo`21oooo001Woooo0P0000/co`00
0`000?ooooooo`0Uoooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Uoooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0V
oooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Voooo00?o
09Woooooool0POooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Voooo00?o09Wooooo
ool0POooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0Voooo00?o09Woooooool0POoo
o`00Ioooo`80000:<ol000<0003oooooool09_ooo`03o`2Ioooooooo087oool006Ooool00`0003?o
03?o0009<ol000<0003oooooool09_ooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o0009
<ol000<0003oooooool09_ooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o0008<ol000<0
003oooooool09oooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool09oooo`03o`2Ioooooooo087oool006Ooool00`0003?o03?o0008<ol000<0003oooooool09ooo
o`03o`2Ioooooooo087oool006Ooool200002C?o00030000oooooooo02Ooool00ol0VOooooooo`21
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo02Ooool00ol0VOooooooo`21oooo001W
oooo00<0000co`0co`0023?o00030000oooooooo02Ooool00ol0VOooooooo`21oooo001Woooo00<0
000co`0co`001c?o00030000oooooooo02Soool00ol0VOooooooo`21oooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo02Soool00ol0VOooooooo`21oooo001Woooo00<0000co`0co`001c?o
00030000oooooooo02Soool00ol0VOooooooo`21oooo001Woooo0P0000Pco`000`000?ooooooo`0X
oooo00?o09Woooooool0POooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Xoooo00?o
09Woooooool0POooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0POooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Xoooo00?o09Woooooool0POoo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0Xoooo00?o09Woooooool0POooo`00HOoo
o`<00003oooo00<0000co`0co`001c?o00030000oooooooo02Soool00ol0VOooooooo`21oooo001R
oooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0POooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`0Xoooo00?o09Woooooool0POoo
o`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_
oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9
<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo0`0000?oool3
00001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol01oooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000Soool300000oooo`<00004oooo00<0003oooooool0N?oo
o`00Ioooo`Tco`08oooo00D0003oooooooooool000003oooo`040000oooooooo00002Oooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0
003oooooool04Oooo`80000:oooo0`0000?oool300000_ooo`030000oooooooo07Woool006Ooool9
<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55195 .12361 L
.55338 .12361 L
.55472 .12361 L
.55598 .12361 L
.55669 .12361 L
s
.55669 .12361 m
.55695 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.10458 .12361 L
.11448 .12361 L
.11992 .12361 L
.1226 .12361 L
.12377 .12361 L
.12507 .12361 L
.12627 .12293 L
.12739 .12207 L
.12986 .12021 L
.13506 .11642 L
.14415 .11024 L
.18292 .08942 L
.20406 .08126 L
.22415 .07519 L
.24395 .07057 L
.26234 .06734 L
.27291 .06588 L
.28286 .06474 L
.29173 .0639 L
.30147 .06317 L
.31123 .0626 L
.31621 .06238 L
.32155 .06218 L
.32655 .06204 L
.3311 .06194 L
.3333 .0619 L
.33568 .06186 L
.33794 .06184 L
.34002 .06182 L
.34119 .06181 L
.34228 .06181 L
.34341 .06179 L
.34465 .06178 L
.34591 .06175 L
.34726 .06172 L
.34965 .06165 L
.35438 .06146 L
.35869 .06124 L
.36928 .06049 L
.37929 .05958 L
.41775 .05475 L
.45867 .04838 L
.49808 .04192 L
.53596 .03602 L
.54594 .03459 L
.55085 .03391 L
.55325 .03358 L
Mistroke
.55541 .03329 L
.55671 .03312 L
.55794 .12361 L
.55924 .12361 L
.56063 .12361 L
.56633 .12361 L
.5763 .12361 L
.61736 .12361 L
.6569 .12361 L
.69492 .12361 L
.7354 .12361 L
.77436 .12361 L
.81577 .12361 L
.85567 .12361 L
.89405 .12361 L
.93489 .12361 L
.9742 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0coooo00<0I_oooooo
ool0P?ooo`00Ioooo`030000oooooooo02coool806KoP_ooo`00Ioooo`030000oooooooo02Ooool5
06Ko1oooo`0306Kooooooooo083oool006Ooool00`000?ooooooo`0Poooo1`1Vo`coool00`1Voooo
ooooo`20oooo001Woooo00<0003oooooool06?ooo`P0I_lCoooo00<0I_ooooooool0P?ooo`00Iooo
o`80000Doooo1@1Voa_oool00`1Vooooooooo`20oooo001Woooo00<0003oooooool03?ooo`L0I_lP
oooo00<0I_ooooooool0P?ooo`00Ioooo`030000oooooooo00?oool906Ko9oooo`0306Kooooooooo
083oool005Ooool@06Ko00<00000I_l0I_l00`1Voc3oool00`1Vooooooooo`20oooo001Aoooo1P1V
oa3oool00`000?ooooooo`0coooo00<0I_ooooooool0P?ooo`00C?ooo`D0I_lFoooo00<0003ooooo
ool0<oooo`0306Kooooooooo083oool004Soool406Ko6oooo`80000doooo00<0I_ooooooool0P?oo
o`005oooo`D0000Noooo0P0000Coool200001?ooo`80000Ooooo00<0003oooooool07_ooo`800004
oooo0P0000Coool200002?ooo`0306Kooooooooo01Coool500007Oooo`D00002oooo0P0000Coool2
00008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00001_ooo`80I_l0
10000?ooooooo`0001koool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003ooooo
ool00007oooo00<0I_ooooooool05_ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000Coool206Ko1Oooo`030000oooooooo01coool00`000?ooooooo`0Moooo00@0003ooooo
ool0000;oooo00<0003oooooool01Oooo`0306Kooooooooo01Koool00`000?ooooooo`0Ooooo00<0
003oooooool02_ooo`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool0
0`000?ooooooo`0Goooo100000;oool010000?ooooooo`0000;oool206Ko1Oooo`80000Ooooo00<0
003oooooool07Oooo`040000oooooooo00002Oooo`800008oooo00<0I_ooooooool05_ooo`030000
oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00000P1Vo`Ooool00`000?ooooooo`0Noooo00<0003ooooo
ool07Oooo`040000oooooooo00002Oooo`030000oooooooo00Ooool00`1Vooooooooo`0Foooo00<0
003oooooool07oooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000F
oooo000Hoooo0P00023oool2000000<0I_ooooooool01oooo`<0000Noooo0P0001ooool200002_oo
o`<00007oooo00<0I_ooooooool05Oooo`80000Poooo0P0000[oool300008?ooo`80000Goooo000i
oooo0P1Vobcoool00`000?ooooooo`0doooo00<0I_ooooooool0Ooooo`00=oooo`80I_l^oooo00<0
003oooooool0=?ooo`0306Kooooooooo07ooool003Goool206Ko<?ooo`030000oooooooo03Coool0
0`1Vooooooooo`1ooooo000coooo0P1Voc;oool00`000?ooooooo`0doooo00<0I_ooooooool0Oooo
o`00<_ooo`0306Kooooooooo03;oool00`000?ooooooo`0doooo00<0I_ooooooool0Ooooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000<co`000ol0VC?o00000007
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
000co`0co`009C?o00030000<ol0<ol000/co`000ol0VC?o03?o000F<ol0400001Woool00`000?oo
ooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol003<co`000ol0VC?o03?o000A
<ol01@0006[oool006Ooool00`0003?o03?o000c<ol000?o09Tco`0co`0033?o00D0001_oooo001W
oooo00<0000co`0co`00<c?o0003o`2I<ol0<ol000Lco`050000M?ooo`00Ioooo`030000<ol0<ol0
03<co`000ol0VC?o03?o0003<ol0100007Woool006Ooool20000=3?o0004o`2I<ol0<ol0<ol00P00
07goool006Ooool00`0003?o03?o000c<ol000Co09Tco`000000001ooooo001Woooo00<0000co`0c
o`00<c?o0003o`2I0000oooo083oool006Ooool00`0003?o03?o000a<ol00P000003o`2Ioooooooo
083oool006Ooool00`0003?o03?o000`<ol000@0003ooooooooo09V2oooo001Woooo00<0000co`0c
o`00;S?o00800003oooo00?o09Woooooool0P?ooo`00Ioooo`80000]<ol00P0000Goool00ol0VOoo
ooooo`20oooo001Woooo00<0000co`0co`00:c?o00030000oooooooo00Goool00ol0VOooooooo`20
oooo001Woooo00<0000co`0co`00:S?o00030000oooooooo00Koool00ol0VOooooooo`20oooo001W
oooo00<0000co`0co`00:C?o00030000oooooooo00Ooool00ol0VOooooooo`20oooo001Woooo00<0
000co`0co`00:3?o00030000oooooooo00Soool00ol0VOooooooo`20oooo001Woooo00<0000co`0c
o`00:3?o00030000oooooooo00Soool00ol0VOooooooo`20oooo001Woooo0P0002Pco`000`000?oo
ooooo`09oooo00?o09Woooooool0P?ooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`0:
oooo00?o09Woooooool0P?ooo`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`0<oooo00?o09Wooooo
ool0P?ooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`0=oooo00?o09Woooooool0P?oo
o`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`0=oooo00?o09Woooooool0P?ooo`00Iooo
o`80000S<ol000<0003oooooool03_ooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000Q
<ol000<0003oooooool03oooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000P<ol000<0
003oooooool04?ooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000P<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000O<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo083oool005ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`0A
oooo00?o09Woooooool0P?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0
003oooooool04_ooo`03o`2Ioooooooo083oool0067oool00`000?ooooooo`03oooo0P0001lco`00
0`000?ooooooo`0Boooo00?o09Woooooool0P?ooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o000M<ol000<0003oooooool04oooo`03o`2Ioooooooo083oool0067oool00`000?ooooooo`03
oooo00<0000co`0co`007C?o00030000oooooooo01?oool00ol0VOooooooo`20oooo001Poooo0P00
00Goool00`0003?o03?o000L<ol000<0003oooooool05?ooo`03o`2Ioooooooo083oool006Ooool0
0`0003?o03?o000L<ol000<0003oooooool05?ooo`03o`2Ioooooooo083oool006Ooool00`0003?o
03?o000K<ol000<0003oooooool05Oooo`03o`2Ioooooooo083oool006Ooool2000073?o00030000
oooooooo01Goool00ol0VOooooooo`20oooo001Woooo00<0000co`0co`006S?o00030000oooooooo
01Koool00ol0VOooooooo`20oooo001Woooo00<0000co`0co`006S?o00030000oooooooo01Koool0
0ol0VOooooooo`20oooo001Woooo00<0000co`0co`006C?o00030000oooooooo01Ooool00ol0VOoo
ooooo`20oooo001Woooo00<0000co`0co`006C?o00030000oooooooo01Ooool00ol0VOooooooo`20
oooo001Woooo00<0000co`0co`0063?o00030000oooooooo01Soool00ol0VOooooooo`20oooo001W
oooo0P0001Tco`000`000?ooooooo`0Hoooo00?o09Woooooool0P?ooo`00Ioooo`030000<ol0<ol0
01Lco`000`000?ooooooo`0Ioooo00?o09Woooooool0P?ooo`00Ioooo`030000<ol0<ol001Lco`00
0`000?ooooooo`0Ioooo00?o09Woooooool0P?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?oo
ooooo`0Joooo00?o09Woooooool0P?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0J
oooo00?o09Woooooool0P?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0Joooo00?o
09Woooooool0P?ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0Koooo00?o09Wooooo
ool0P?ooo`00Ioooo`80000F<ol000<0003oooooool06oooo`03o`2Ioooooooo083oool006Ooool0
0`0003?o03?o000E<ol000<0003oooooool06oooo`03o`2Ioooooooo083oool006Ooool00`0003?o
03?o000E<ol000<0003oooooool06oooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000D
<ol000<0003oooooool07?ooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000D<ol000<0
003oooooool07?ooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000D<ol000<0003ooooo
ool07?ooo`03o`2Ioooooooo083oool006Ooool200005C?o00030000oooooooo01coool00ol0VOoo
ooooo`20oooo001Woooo00<0000co`0co`004c?o00030000oooooooo01goool00ol0VOooooooo`20
oooo001Woooo00<0000co`0co`004c?o00030000oooooooo01goool00ol0VOooooooo`20oooo001W
oooo00<0000co`0co`004c?o00030000oooooooo01goool00ol0VOooooooo`20oooo001Ooooo1000
00Coool00`0003?o03?o000C<ol000<0003oooooool07Oooo`03o`2Ioooooooo083oool005ooool0
0`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo01koool00ol0VOooooooo`20
oooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool07_ooo`03o`2Ioooooooo
083oool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo01koool0
0ol0VOooooooo`20oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000
oooooooo01ooool00ol0VOooooooo`20oooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0
003oooooool07oooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000A<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000A<ol000<0003oooooool07ooo
o`03o`2Ioooooooo083oool006Ooool200004C?o00030000oooooooo023oool00ol0VOooooooo`20
oooo001Woooo00<0000co`0co`0043?o00030000oooooooo023oool00ol0VOooooooo`20oooo001W
oooo00<0000co`0co`0043?o00030000oooooooo023oool00ol0VOooooooo`20oooo001Woooo00<0
000co`0co`0043?o00030000oooooooo023oool00ol0VOooooooo`20oooo001Woooo00<0000co`0c
o`003c?o00030000oooooooo027oool00ol0VOooooooo`20oooo001Woooo00<0000co`0co`003c?o
00030000oooooooo027oool00ol0VOooooooo`20oooo001Woooo00<0000co`0co`003c?o00030000
oooooooo027oool00ol0VOooooooo`20oooo001Woooo0P00010co`000`000?ooooooo`0Qoooo00?o
09Woooooool0P?ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Roooo00?o09Wooooo
ool0P?ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Roooo00?o09Woooooool0P?oo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Roooo00?o09Woooooool0P?ooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`0Roooo00?o09Woooooool0P?ooo`00Ioooo`030000
<ol0<ol000dco`000`000?ooooooo`0Soooo00?o09Woooooool0P?ooo`00Ioooo`80000><ol000<0
003oooooool08oooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000=<ol000<0003ooooo
ool08oooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000=<ol000<0003oooooool08ooo
o`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000<<ol000<0003oooooool09?ooo`03o`2I
oooooooo083oool006Ooool00`0003?o03?o000<<ol000<0003oooooool09?ooo`03o`2Ioooooooo
083oool006Ooool00`0003?o03?o000<<ol000<0003oooooool09?ooo`03o`2Ioooooooo083oool0
06Ooool200003C?o00030000oooooooo02Coool00ol0VOooooooo`20oooo001Woooo00<0000co`0c
o`0033?o00030000oooooooo02Coool00ol0VOooooooo`20oooo001Woooo00<0000co`0co`0033?o
00030000oooooooo02Coool00ol0VOooooooo`20oooo001Woooo00<0000co`0co`002c?o00030000
oooooooo02Goool00ol0VOooooooo`20oooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0
003oooooool09Oooo`03o`2Ioooooooo083oool005ooool010000?ooooooo`0000Coool00`0003?o
03?o000;<ol000<0003oooooool09Oooo`03o`2Ioooooooo083oool0067oool00`000?ooooooo`03
oooo0P0000`co`000`000?ooooooo`0Uoooo00?o09Woooooool0P?ooo`00H_ooo`030000oooooooo
00;oool00`0003?o03?o000;<ol000<0003oooooool09Oooo`03o`2Ioooooooo083oool005ooool0
10000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool09Oooo`03o`2Ioooooooo
083oool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`0Voooo00?o09Wooooo
ool0P?ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Voooo00?o09Woooooool0P?oo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Voooo00?o09Woooooool0P?ooo`00Iooo
o`030000<ol0<ol000Xco`000`000?ooooooo`0Voooo00?o09Woooooool0P?ooo`00Ioooo`80000;
<ol000<0003oooooool09_ooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o000:<ol000<0
003oooooool09_ooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool09oooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o0009<ol000<0003oooooool09ooo
o`03o`2Ioooooooo083oool006Ooool00`0003?o03?o0009<ol000<0003oooooool09oooo`03o`2I
oooooooo083oool006Ooool00`0003?o03?o0009<ol000<0003oooooool09oooo`03o`2Ioooooooo
083oool006Ooool200002S?o00030000oooooooo02Ooool00ol0VOooooooo`20oooo001Woooo00<0
000co`0co`002C?o00030000oooooooo02Ooool00ol0VOooooooo`20oooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo02Ooool00ol0VOooooooo`20oooo001Woooo00<0000co`0co`0023?o
00030000oooooooo02Soool00ol0VOooooooo`20oooo001Woooo00<0000co`0co`0023?o00030000
oooooooo02Soool00ol0VOooooooo`20oooo001Woooo00<0000co`0co`0023?o00030000oooooooo
02Soool00ol0VOooooooo`20oooo001Woooo0P0000Tco`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0P?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Xoooo00?o09Woooooool0P?oo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Xoooo00?o09Woooooool0P?ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Yoooo00?o09Woooooool0P?ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`0Yoooo00?o09Woooooool0P?ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Yoooo00?o09Woooooool0P?ooo`00Ioooo`800008<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo083oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo083oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0:Oooo`03o`2I
oooooooo083oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0:Oooo`03o`2Ioooooooo
083oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0:Oooo`03o`2Ioooooooo083oool0
067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`0Yoooo00?o09Woooooool0P?oo
o`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0:Oooo`03o`2I
oooooooo083oool005ooool500000oooo`800008<ol000<0003oooooool0:Oooo`03o`2Ioooooooo
083oool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:
<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001W
oooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`<00004
oooo0P0000Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Ooool0
0`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`040000oooooooo
00000_ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool006Ooool9<ol02?ooo`030000
oooooooo00D0000<oooo00@0003oooooool00008oooo0`0000Coool200001?ooo`030000oooooooo
07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Woool0
0`000?ooooooo`02oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09
oooo00<0003oooooool04Oooo`80000:oooo0`0000?oool200000oooo`030000oooooooo07Woool0
06Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55436 .12361 L
.55712 .12361 L
.55972 .12361 L
.56092 .12361 L
.56218 .12361 L
.56285 .12361 L
s
.56285 .12361 m
.56314 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.10458 .12361 L
.11009 .12361 L
.1128 .12361 L
.11531 .12361 L
.11758 .12361 L
.11872 .12361 L
.11999 .12288 L
.12507 .11905 L
.14415 .10624 L
.16519 .09469 L
.18444 .08615 L
.20455 .07902 L
.22321 .0738 L
.2422 .06968 L
.25287 .06782 L
.26292 .06635 L
.27278 .06514 L
.28344 .06407 L
.29307 .06331 L
.30205 .06275 L
.31155 .06231 L
.31659 .06214 L
.32199 .06199 L
.3247 .06194 L
.32765 .06189 L
.33043 .06185 L
.33176 .06184 L
.33301 .06183 L
.33421 .06182 L
.33532 .06181 L
.33655 .06181 L
.3372 .06181 L
.33788 .0618 L
.33916 .0618 L
.34035 .0618 L
.34166 .06181 L
.34239 .06181 L
.34305 .06181 L
.34425 .0618 L
.34536 .06179 L
.34659 .06177 L
.3479 .06175 L
.35058 .06168 L
.35303 .0616 L
.35776 .0614 L
.36224 .06116 L
Mistroke
.37219 .06045 L
.38303 .05946 L
.42373 .05433 L
.46291 .04824 L
.50455 .04147 L
.52546 .03818 L
.54467 .03531 L
.55439 .03395 L
.55913 .0333 L
.5612 .03303 L
.56229 .03288 L
.56345 .03273 L
.56467 .12361 L
.5658 .12361 L
.56802 .12361 L
.57291 .12361 L
.58327 .12361 L
.62107 .12361 L
.66133 .12361 L
.70007 .12361 L
.74126 .12361 L
.78094 .12361 L
.8191 .12361 L
.85971 .12361 L
.89881 .12361 L
.94036 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0doooo0P1Voh3oool0
06Ooool00`000?ooooooo`0^oooo201Voh3oool006Ooool00`000?ooooooo`0Yoooo1@1Vo`Ooool0
0`1Vooooooooo`1noooo001Woooo00<0003oooooool08_ooo`L0I_l<oooo00<0I_ooooooool0O_oo
o`00Ioooo`030000oooooooo01[oool806Ko4oooo`0306Kooooooooo07koool006Ooool200005_oo
o`D0I_lKoooo00<0I_ooooooool0O_ooo`00Ioooo`030000oooooooo00goool806Ko8?ooo`0306Ko
oooooooo07koool006Ooool00`000?ooooooo`04oooo2@1VobSoool00`1Vooooooooo`1noooo001G
oooo401Vo`03000006Ko06Ko00@0I_laoooo00<0I_ooooooool0O_ooo`00D?ooo`L0I_l@oooo00<0
003oooooool0=Oooo`0306Kooooooooo07koool004coool406Ko5oooo`030000oooooooo03Goool0
0`1Vooooooooo`1noooo0017oooo1@1Voa_oool20000=_ooo`0306Kooooooooo07koool001Ooool5
00007_ooo`800004oooo0P000004oooo06Ko06Ko06Ko0P0001ooool00`000?ooooooo`0Noooo0P00
00Coool200001?ooo`800009oooo00<0I_ooooooool04oooo`D0000Moooo1@0000;oool200001?oo
o`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00004oooo0P1V
o`;oool010000?ooooooo`0001koool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0
003oooooool00008oooo00<0I_ooooooool05Oooo`030000oooooooo01ooool00`000?ooooooo`07
oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool0
1@000?ooooooo`000?ooo`0306Ko1oooo`030000oooooooo01coool00`000?ooooooo`0Moooo00@0
003oooooool0000;oooo00<0003oooooool01_ooo`0306Kooooooooo01Goool00`000?ooooooo`0O
oooo00<0003oooooool02_ooo`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo1000
00Coool00`000?ooooooo`0Goooo100000;oool01@000?ooooooo`00001Vo`08oooo0P0001ooool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo0P0000Woool00`1Vooooooooo`0Eoooo00<0
003oooooool07oooo`030000oooooooo00Soool200008_ooo`030000oooooooo01Goool001Woool0
0`000?ooooooo`0Moooo00@00000I_l0I_l00009oooo00<0003oooooool07_ooo`030000oooooooo
01goool010000?ooooooo`0000Woool00`000?ooooooo`08oooo00<0I_ooooooool05Oooo`030000
oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_oo
o`006?ooo`80000Noooo0P1Vo`80000:oooo0`0001koool200007oooo`80000:oooo0`0000Soool0
0`1Vooooooooo`0Doooo0P00023oool200002_ooo`<0000Poooo0P0001Ooool003Koool206Ko;ooo
o`030000oooooooo03Goool00`1Vooooooooo`1noooo000eoooo00<0I_ooooooool0;oooo`030000
oooooooo03Goool00`1Vooooooooo`1noooo000coooo0P1Voc;oool00`000?ooooooo`0eoooo00<0
I_ooooooool0O_ooo`00<Oooo`80I_ldoooo00<0003oooooool0=Oooo`0306Kooooooooo07koool0
033oool00`1Vooooooooo`0doooo00<0003oooooool0=Oooo`0306Kooooooooo07koool0013ooooo
00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000
<ol0<ol002Dco`000`0003?o03?o000=<ol000?o09Tco`0co`0053?o0100000Ioooo00<0003ooooo
ool09_ooo`030000oooooooo01Goool006Ooool00`0003?o03?o000e<ol000?o09Tco`0co`003c?o
00D0001Zoooo001Woooo00<0000co`0co`00=C?o0003o`2I<ol0<ol000Xco`050000Koooo`00Iooo
o`030000<ol0<ol003Dco`000ol0VC?o03?o0005<ol01@0007Coool006Ooool00`0003?o03?o000e
<ol000Co09Tco`0co`0co`040000NOooo`00Ioooo`80000f<ol000Co09Tco`000000001moooo001W
oooo00<0000co`0co`00=C?o0003o`2I0000oooo07koool006Ooool00`0003?o03?o000c<ol00P00
0003o`2Ioooooooo07koool006Ooool00`0003?o03?o000a<ol00P0000;oool00ol0VOooooooo`1n
oooo001Woooo00<0000co`0co`00<3?o00030000oooooooo00;oool00ol0VOooooooo`1noooo001W
oooo00<0000co`0co`00;S?o00800005oooo00?o09Woooooool0O_ooo`00Ioooo`80000]<ol00P00
00Ooool00ol0VOooooooo`1noooo001Woooo00<0000co`0co`00:c?o00030000oooooooo00Ooool0
0ol0VOooooooo`1noooo001Woooo00<0000co`0co`00:S?o00030000oooooooo00Soool00ol0VOoo
ooooo`1noooo001Woooo00<0000co`0co`00:C?o00030000oooooooo00Woool00ol0VOooooooo`1n
oooo001Woooo00<0000co`0co`00:3?o00030000oooooooo00[oool00ol0VOooooooo`1noooo001W
oooo00<0000co`0co`00:3?o00030000oooooooo00[oool00ol0VOooooooo`1noooo001Woooo0P00
02Pco`000`000?ooooooo`0;oooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol002Hco`00
0`000?ooooooo`0<oooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol002Dco`000`000?oo
ooooo`0=oooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`0>
oooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`0?oooo00?o
09Woooooool0O_ooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`0?oooo00?o09Wooooo
ool0O_ooo`00Ioooo`80000S<ol000<0003oooooool04?ooo`03o`2Ioooooooo07koool006Ooool0
0`0003?o03?o000Q<ol000<0003oooooool04Oooo`03o`2Ioooooooo07koool006Ooool00`0003?o
03?o000P<ol000<0003oooooool04_ooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o000P
<ol000<0003oooooool04_ooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o000O<ol000<0
003oooooool04oooo`03o`2Ioooooooo07koool005ooool500000oooo`030000<ol0<ol001lco`00
0`000?ooooooo`0Coooo00?o09Woooooool0O_ooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o000N<ol000<0003oooooool05?ooo`03o`2Ioooooooo07koool0067oool00`000?ooooooo`03
oooo0P0001lco`000`000?ooooooo`0Doooo00?o09Woooooool0O_ooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003oooooool05Oooo`03o`2Ioooooooo07koool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo01Goool00ol0VOooooooo`1n
oooo001Poooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool05_ooo`03o`2Ioooooooo
07koool006Ooool00`0003?o03?o000L<ol000<0003oooooool05_ooo`03o`2Ioooooooo07koool0
06Ooool00`0003?o03?o000K<ol000<0003oooooool05oooo`03o`2Ioooooooo07koool006Ooool2
000073?o00030000oooooooo01Ooool00ol0VOooooooo`1noooo001Woooo00<0000co`0co`006S?o
00030000oooooooo01Soool00ol0VOooooooo`1noooo001Woooo00<0000co`0co`006S?o00030000
oooooooo01Soool00ol0VOooooooo`1noooo001Woooo00<0000co`0co`006C?o00030000oooooooo
01Woool00ol0VOooooooo`1noooo001Woooo00<0000co`0co`006C?o00030000oooooooo01Woool0
0ol0VOooooooo`1noooo001Woooo00<0000co`0co`0063?o00030000oooooooo01[oool00ol0VOoo
ooooo`1noooo001Woooo0P0001Tco`000`000?ooooooo`0Joooo00?o09Woooooool0O_ooo`00Iooo
o`030000<ol0<ol001Lco`000`000?ooooooo`0Koooo00?o09Woooooool0O_ooo`00Ioooo`030000
<ol0<ol001Lco`000`000?ooooooo`0Koooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol0
01Hco`000`000?ooooooo`0Loooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol001Hco`00
0`000?ooooooo`0Loooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?oo
ooooo`0Loooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0M
oooo00?o09Woooooool0O_ooo`00Ioooo`80000F<ol000<0003oooooool07Oooo`03o`2Ioooooooo
07koool006Ooool00`0003?o03?o000E<ol000<0003oooooool07Oooo`03o`2Ioooooooo07koool0
06Ooool00`0003?o03?o000E<ol000<0003oooooool07Oooo`03o`2Ioooooooo07koool006Ooool0
0`0003?o03?o000D<ol000<0003oooooool07_ooo`03o`2Ioooooooo07koool006Ooool00`0003?o
03?o000D<ol000<0003oooooool07_ooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o000D
<ol000<0003oooooool07_ooo`03o`2Ioooooooo07koool006Ooool200005C?o00030000oooooooo
01koool00ol0VOooooooo`1noooo001Woooo00<0000co`0co`004c?o00030000oooooooo01ooool0
0ol0VOooooooo`1noooo001Woooo00<0000co`0co`004c?o00030000oooooooo01ooool00ol0VOoo
ooooo`1noooo001Woooo00<0000co`0co`004c?o00030000oooooooo01ooool00ol0VOooooooo`1n
oooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003oooooool07oooo`03o`2Ioooooooo
07koool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo023oool0
0ol0VOooooooo`1noooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool08?oo
o`03o`2Ioooooooo07koool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000
oooooooo023oool00ol0VOooooooo`1noooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`004C?o00030000oooooooo027oool00ol0VOooooooo`1noooo001Poooo0P0000Goool00`0003?o
03?o000A<ol000<0003oooooool08Oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o000A
<ol000<0003oooooool08Oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o000A<ol000<0
003oooooool08Oooo`03o`2Ioooooooo07koool006Ooool200004C?o00030000oooooooo02;oool0
0ol0VOooooooo`1noooo001Woooo00<0000co`0co`0043?o00030000oooooooo02;oool00ol0VOoo
ooooo`1noooo001Woooo00<0000co`0co`0043?o00030000oooooooo02;oool00ol0VOooooooo`1n
oooo001Woooo00<0000co`0co`0043?o00030000oooooooo02;oool00ol0VOooooooo`1noooo001W
oooo00<0000co`0co`003c?o00030000oooooooo02?oool00ol0VOooooooo`1noooo001Woooo00<0
000co`0co`003c?o00030000oooooooo02?oool00ol0VOooooooo`1noooo001Woooo00<0000co`0c
o`003c?o00030000oooooooo02?oool00ol0VOooooooo`1noooo001Woooo0P00010co`000`000?oo
ooooo`0Soooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0T
oooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Toooo00?o
09Woooooool0O_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Toooo00?o09Wooooo
ool0O_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0Toooo00?o09Woooooool0O_oo
o`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0Uoooo00?o09Woooooool0O_ooo`00Iooo
o`80000><ol000<0003oooooool09Oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o000=
<ol000<0003oooooool09Oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o000=<ol000<0
003oooooool09Oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool09_ooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o000<<ol000<0003oooooool09_oo
o`03o`2Ioooooooo07koool006Ooool00`0003?o03?o000<<ol000<0003oooooool09_ooo`03o`2I
oooooooo07koool006Ooool200003C?o00030000oooooooo02Koool00ol0VOooooooo`1noooo001W
oooo00<0000co`0co`0033?o00030000oooooooo02Koool00ol0VOooooooo`1noooo001Woooo00<0
000co`0co`0033?o00030000oooooooo02Koool00ol0VOooooooo`1noooo001Woooo00<0000co`0c
o`002c?o00030000oooooooo02Ooool00ol0VOooooooo`1noooo001Poooo0P0000Goool00`0003?o
03?o000;<ol000<0003oooooool09oooo`03o`2Ioooooooo07koool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool09oooo`03o`2Ioooooooo07koool0067oool0
0`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`0Woooo00?o09Woooooool0O_ooo`00H_oo
o`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool09oooo`03o`2Ioooooooo
07koool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool09ooo
o`03o`2Ioooooooo07koool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`0X
oooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Xoooo00?o
09Woooooool0O_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0O_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0Xoooo00?o09Woooooool0O_oo
o`00Ioooo`80000;<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07koool006Ooool00`0003?o
03?o000:<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o0009
<ol000<0003oooooool0:Oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o0009<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o0009<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo07koool006Ooool200002S?o00030000oooooooo02Woool00ol0VOooooooo`1n
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo02Woool00ol0VOooooooo`1noooo001W
oooo00<0000co`0co`002C?o00030000oooooooo02Woool00ol0VOooooooo`1noooo001Woooo00<0
000co`0co`0023?o00030000oooooooo02[oool00ol0VOooooooo`1noooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo02[oool00ol0VOooooooo`1noooo001Woooo00<0000co`0co`0023?o
00030000oooooooo02[oool00ol0VOooooooo`1noooo001Woooo0P0000Tco`000`000?ooooooo`0Z
oooo00?o09Woooooool0O_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Zoooo00?o
09Woooooool0O_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0Zoooo00?o09Wooooo
ool0O_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0[oooo00?o09Woooooool0O_oo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0[oooo00?o09Woooooool0O_ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0[oooo00?o09Woooooool0O_ooo`00Ioooo`800008
<ol000<0003oooooool0:oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0:oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0:oooo`03o`2Ioooooooo07koool006Ooool00`0003?o03?o0007<ol000<0003oooooool0:ooo
o`03o`2Ioooooooo07koool006Ooool00`0003?o03?o0007<ol000<0003oooooool0:oooo`03o`2I
oooooooo07koool0067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`0[oooo00?o
09Woooooool0O_ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003ooooo
ool0:oooo`03o`2Ioooooooo07koool005ooool500000oooo`800008<ol000<0003oooooool0:ooo
o`03o`2Ioooooooo07koool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000
oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Iooo
o`Tco`2`oooo001Woooo2C?o00coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Iooo
o`Tco`0;oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001W
oooo2C?o00_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool2
00001Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001Woooo2C?o00_oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Ioooo`Tco`0:oooo00<0003ooooo
ool00_ooo`030000oooooooo00goool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0
003oooooool0N_ooo`00Ioooo`Tco`0;oooo00<0003oooooool01@0000coool010000?ooooooo`00
00_oool01@000?ooooooooooo`00001moooo001Woooo2C?o00_oool01@000?ooooooooooo`00000?
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Iooo
o`Tco`0<oooo00<0003oooooool04Oooo`800009oooo100000;oool00`000?ooooooo`1loooo001W
oooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55972 .12361 L
.56446 .12361 L
.56706 .12361 L
.56834 .12361 L
.56951 .12361 L
s
.56951 .12361 m
.56996 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.09905 .12361 L
.10458 .12361 L
.10972 .12361 L
.11113 .12361 L
.1119 .12361 L
.11263 .12361 L
.1139 .12267 L
.11531 .1216 L
.12507 .11452 L
.14415 .10249 L
.18292 .08428 L
.20406 .07724 L
.22415 .07209 L
.24395 .06824 L
.26234 .06561 L
.27291 .06446 L
.28286 .06359 L
.2918 .06297 L
.2968 .06269 L
.30147 .06247 L
.30644 .06226 L
.31098 .06211 L
.31601 .06198 L
.31882 .06193 L
.32141 .06189 L
.32392 .06185 L
.32659 .06183 L
.32797 .06182 L
.32927 .06181 L
.33001 .06181 L
.33069 .06181 L
.33144 .0618 L
.33223 .0618 L
.33345 .0618 L
.33476 .06181 L
.336 .06181 L
.33712 .06181 L
.33844 .06182 L
.33987 .06183 L
.34123 .06185 L
.34247 .06186 L
.34368 .06186 L
.34483 .06186 L
.34604 .06185 L
.34736 .06184 L
.34851 .06183 L
Mistroke
.34974 .0618 L
.35194 .06175 L
.35475 .06167 L
.3574 .06157 L
.36235 .06133 L
.37246 .06067 L
.38339 .05972 L
.42445 .0547 L
.46399 .04866 L
.50201 .04251 L
.5232 .03914 L
.54249 .03622 L
.55208 .03483 L
.55714 .03412 L
.56251 .03339 L
.56476 .03309 L
.56719 .03277 L
.56787 .03268 L
.56858 .03258 L
.56986 .12361 L
.57105 .12361 L
.57235 .12361 L
.58145 .12361 L
.62206 .12361 L
.66116 .12361 L
.70271 .12361 L
.74274 .12361 L
.78126 .12361 L
.82223 .12361 L
.86169 .12361 L
.89963 .12361 L
.94002 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0eoooo0P1Vogooool0
06Ooool00`000?ooooooo`0^oooo2@1Vogooool006Ooool00`000?ooooooo`0Yoooo1@1Vo`Soool0
0`1Vooooooooo`1moooo001Woooo00<0003oooooool08Oooo`P0I_l=oooo00<0I_ooooooool0OOoo
o`00Ioooo`030000oooooooo01[oool706Ko5Oooo`0306Kooooooooo07goool006Ooool200005_oo
o`D0I_lLoooo00<0I_ooooooool0OOooo`00Ioooo`030000oooooooo00goool806Ko8Oooo`0306Ko
oooooooo07goool006Ooool00`000?ooooooo`04oooo2@1VobWoool00`1Vooooooooo`1moooo001E
oooo4P1Vo`03000006Ko06Ko00@0I_lboooo00<0I_ooooooool0OOooo`00C?ooo`T0I_lBoooo00<0
003oooooool0=_ooo`0306Kooooooooo07goool004Soool406Ko6oooo`030000oooooooo03Koool0
0`1Vooooooooo`1moooo0016oooo0P1Voaooool20000=oooo`0306Kooooooooo07goool001Ooool5
00007_ooo`800004oooo0P0000@0I_l200007oooo`030000oooooooo01koool200001?ooo`800004
oooo0P0000_oool00`1Vooooooooo`0Aoooo1@0001goool500000_ooo`800004oooo0P00023oool4
00005_ooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000;oool306Ko0oooo`040000
oooooooo00007_ooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00
00[oool00`1Vooooooooo`0Coooo00<0003oooooool07oooo`030000oooooooo00Ooool010000?oo
ooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00000P1Vo`Woool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo00Soool00`1Vooooooooo`0Coooo00<0003oooooool07oooo`030000oooooooo
00[oool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003ooooo
ool05oooo`@00002oooo00@0003oool0I_l00009oooo0P0001ooool00`000?ooooooo`0Moooo00@0
003oooooool00009oooo0P0000_oool00`1Vooooooooo`0Coooo00<0003oooooool07oooo`030000
oooooooo00Soool200008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0
0000I_ooool00009oooo00<0003oooooool07_ooo`030000oooooooo01goool010000?ooooooo`00
00Woool00`000?ooooooo`0:oooo00<0I_ooooooool04oooo`030000oooooooo01ooool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Moooo0P1V
o`03oooo0000000000[oool300007_ooo`80000Ooooo0P0000[oool300002_ooo`0306Kooooooooo
01;oool200008?ooo`80000:oooo0`00023oool200005oooo`00=Oooo`80I_l`oooo00<0003ooooo
ool0=oooo`0306Kooooooooo07coool003?oool206Ko<_ooo`030000oooooooo03Ooool00`1Voooo
ooooo`1loooo000aoooo0P1VocCoool00`000?ooooooo`0goooo00<0I_ooooooool0O?ooo`00<?oo
o`0306Kooooooooo03Coool00`000?ooooooo`0goooo00<0I_ooooooool0O?ooo`00;_ooo`80I_lg
oooo00<0003oooooool0=oooo`0306Kooooooooo07coool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`3o09T01C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o
03?o000?<ol000?o09Tco`0co`004S?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo
01Goool006Ooool00`0003?o03?o000g<ol000?o09Tco`0co`003C?o00D0001Zoooo001Woooo00<0
000co`0co`00=c?o0003o`2I<ol0<ol000Pco`050000Koooo`00Ioooo`030000<ol0<ol003Lco`00
0ol0VC?o03?o0003<ol01@0007Coool006Ooool00`0003?o03?o000g<ol000?o09Tco`0000000`00
07Woool006Ooool20000>3?o0003o`2I0000oooo07coool006Ooool00`0003?o03?o000e<ol00P00
0003o`2Ioooooooo07coool006Ooool00`0003?o03?o000c<ol00P0000;oool00ol0VOooooooo`1l
oooo001Woooo00<0000co`0co`00<C?o00800004oooo00?o09Woooooool0O?ooo`00Ioooo`030000
<ol0<ol0030co`000`000?ooooooo`04oooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol0
02hco`0200001oooo`03o`2Ioooooooo07coool006Ooool20000;C?o00800009oooo00?o09Wooooo
ool0O?ooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`09oooo00?o09Woooooool0O?oo
o`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`0:oooo00?o09Woooooool0O?ooo`00Iooo
o`030000<ol0<ol002Tco`000`000?ooooooo`0;oooo00?o09Woooooool0O?ooo`00Ioooo`030000
<ol0<ol002Pco`000`000?ooooooo`0<oooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol0
02Pco`000`000?ooooooo`0<oooo00?o09Woooooool0O?ooo`00Ioooo`80000X<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo07coool006Ooool00`0003?o03?o000V<ol000<0003oooooool03_oo
o`03o`2Ioooooooo07coool006Ooool00`0003?o03?o000U<ol000<0003oooooool03oooo`03o`2I
oooooooo07coool006Ooool00`0003?o03?o000T<ol000<0003oooooool04?ooo`03o`2Ioooooooo
07coool006Ooool00`0003?o03?o000S<ol000<0003oooooool04Oooo`03o`2Ioooooooo07coool0
06Ooool00`0003?o03?o000S<ol000<0003oooooool04Oooo`03o`2Ioooooooo07coool006Ooool2
00008c?o00030000oooooooo01;oool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`008C?o
00030000oooooooo01?oool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`0083?o00030000
oooooooo01Coool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`0083?o00030000oooooooo
01Coool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`007c?o00030000oooooooo01Goool0
0ol0VOooooooo`1loooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo07coool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o00030000
oooooooo01Koool00ol0VOooooooo`1loooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0
003oooooool05_ooo`03o`2Ioooooooo07coool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`007C?o00030000oooooooo01Ooool00ol0VOooooooo`1loooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`0Goooo00?o09Woooooool0O?ooo`00H?ooo`800005
oooo00<0000co`0co`0073?o00030000oooooooo01Soool00ol0VOooooooo`1loooo001Woooo00<0
000co`0co`0073?o00030000oooooooo01Soool00ol0VOooooooo`1loooo001Woooo00<0000co`0c
o`006c?o00030000oooooooo01Woool00ol0VOooooooo`1loooo001Woooo0P0001`co`000`000?oo
ooooo`0Ioooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0J
oooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0Joooo00?o
09Woooooool0O?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0Koooo00?o09Wooooo
ool0O?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0Koooo00?o09Woooooool0O?oo
o`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`0Loooo00?o09Woooooool0O?ooo`00Iooo
o`80000I<ol000<0003oooooool07?ooo`03o`2Ioooooooo07coool006Ooool00`0003?o03?o000G
<ol000<0003oooooool07Oooo`03o`2Ioooooooo07coool006Ooool00`0003?o03?o000G<ol000<0
003oooooool07Oooo`03o`2Ioooooooo07coool006Ooool00`0003?o03?o000F<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo07coool006Ooool00`0003?o03?o000F<ol000<0003oooooool07_oo
o`03o`2Ioooooooo07coool006Ooool00`0003?o03?o000F<ol000<0003oooooool07_ooo`03o`2I
oooooooo07coool006Ooool00`0003?o03?o000E<ol000<0003oooooool07oooo`03o`2Ioooooooo
07coool006Ooool200005S?o00030000oooooooo01ooool00ol0VOooooooo`1loooo001Woooo00<0
000co`0co`005C?o00030000oooooooo01ooool00ol0VOooooooo`1loooo001Woooo00<0000co`0c
o`005C?o00030000oooooooo01ooool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`0053?o
00030000oooooooo023oool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`0053?o00030000
oooooooo023oool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`0053?o00030000oooooooo
023oool00ol0VOooooooo`1loooo001Woooo0P0001Dco`000`000?ooooooo`0Poooo00?o09Wooooo
ool0O?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0Qoooo00?o09Woooooool0O?oo
o`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0Qoooo00?o09Woooooool0O?ooo`00Iooo
o`030000<ol0<ol001<co`000`000?ooooooo`0Qoooo00?o09Woooooool0O?ooo`00Goooo`@00004
oooo00<0000co`0co`004c?o00030000oooooooo027oool00ol0VOooooooo`1loooo001Ooooo00<0
003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`0Roooo00?o09Woooooool0O?oo
o`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo02;oool00ol0VOooooooo`1l
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`0Roooo00?o
09Woooooool0O?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`000`000?oo
ooooo`0Soooo00?o09Woooooool0O?ooo`00H?ooo`800005oooo00<0000co`0co`004C?o00030000
oooooooo02?oool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`004C?o00030000oooooooo
02?oool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`004C?o00030000oooooooo02?oool0
0ol0VOooooooo`1loooo001Woooo0P00014co`000`000?ooooooo`0Toooo00?o09Woooooool0O?oo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0Toooo00?o09Woooooool0O?ooo`00Iooo
o`030000<ol0<ol0010co`000`000?ooooooo`0Toooo00?o09Woooooool0O?ooo`00Ioooo`030000
<ol0<ol0010co`000`000?ooooooo`0Toooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`0Uoooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol000lco`00
0`000?ooooooo`0Uoooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol000lco`000`000?oo
ooooo`0Uoooo00?o09Woooooool0O?ooo`00Ioooo`80000@<ol000<0003oooooool09Oooo`03o`2I
oooooooo07coool006Ooool00`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2Ioooooooo
07coool006Ooool00`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2Ioooooooo07coool0
06Ooool00`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2Ioooooooo07coool006Ooool0
0`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2Ioooooooo07coool006Ooool00`0003?o
03?o000=<ol000<0003oooooool09oooo`03o`2Ioooooooo07coool006Ooool200003S?o00030000
oooooooo02Ooool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`003C?o00030000oooooooo
02Ooool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`003C?o00030000oooooooo02Ooool0
0ol0VOooooooo`1loooo001Woooo00<0000co`0co`0033?o00030000oooooooo02Soool00ol0VOoo
ooooo`1loooo001Woooo00<0000co`0co`0033?o00030000oooooooo02Soool00ol0VOooooooo`1l
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo02Soool00ol0VOooooooo`1loooo001W
oooo0P0000dco`000`000?ooooooo`0Xoooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`0Xoooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`0Xoooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol000/co`000`000?oo
ooooo`0Yoooo00?o09Woooooool0O?ooo`00H?ooo`800005oooo00<0000co`0co`002c?o00030000
oooooooo02Woool00ol0VOooooooo`1loooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`002c?o00030000oooooooo02Woool00ol0VOooooooo`1loooo001Qoooo00<0003oooooool00ooo
o`80000<<ol000<0003oooooool0:Oooo`03o`2Ioooooooo07coool006;oool00`000?ooooooo`02
oooo00<0000co`0co`002c?o00030000oooooooo02Woool00ol0VOooooooo`1loooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo02Woool00ol0VOooooooo`1l
oooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0:_ooo`03o`2Ioooooooo
07coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0:_ooo`03o`2Ioooooooo07coool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool0:_ooo`03o`2Ioooooooo07coool006Ooool0
0`0003?o03?o000:<ol000<0003oooooool0:_ooo`03o`2Ioooooooo07coool006Ooool200002c?o
00030000oooooooo02[oool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`002S?o00030000
oooooooo02[oool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`002C?o00030000oooooooo
02_oool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`002C?o00030000oooooooo02_oool0
0ol0VOooooooo`1loooo001Woooo00<0000co`0co`002C?o00030000oooooooo02_oool00ol0VOoo
ooooo`1loooo001Woooo00<0000co`0co`002C?o00030000oooooooo02_oool00ol0VOooooooo`1l
oooo001Woooo0P0000Xco`000`000?ooooooo`0[oooo00?o09Woooooool0O?ooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`0[oooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0[oooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0/oooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0/oooo00?o09Woooooool0O?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0/
oooo00?o09Woooooool0O?ooo`00Ioooo`800009<ol000<0003oooooool0;?ooo`03o`2Ioooooooo
07coool006Ooool00`0003?o03?o0008<ol000<0003oooooool0;?ooo`03o`2Ioooooooo07coool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool0;?ooo`03o`2Ioooooooo07coool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07coool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07coool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07coool006Ooool2000023?o00030000oooooooo
02goool00ol0VOooooooo`1loooo001Woooo00<0000co`0co`001c?o00030000oooooooo02goool0
0ol0VOooooooo`1loooo001Woooo00<0000co`0co`001c?o00030000oooooooo02goool00ol0VOoo
ooooo`1loooo001Woooo00<0000co`0co`001c?o00030000oooooooo02goool00ol0VOooooooo`1l
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo02goool00ol0VOooooooo`1loooo001Q
oooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07coool0
06;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo02goool00ol0VOoo
ooooo`1loooo001Ooooo1@0000?oool2000023?o00030000oooooooo02goool00ol0VOooooooo`1l
oooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o
0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Iooo
o`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Goool010000?oo
ooooooooo`@00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0
003oooooooooool000001_ooo`030000oooooooo07Soool006Ooool9<ol01oooo`030000oooooooo
00;oool00`000?ooooooo`0=oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000
oooooooo00Coool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003?oo
o`040000oooooooo00002oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000003oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9
<ol02Oooo`030000oooooooo017oool200002Oooo`@00003oooo0P0000?oool00`000?ooooooo`1i
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55972 .12361 L
.56446 .12361 L
.56951 .12361 L
.57197 .12361 L
.57318 .12361 L
.57429 .12361 L
.5753 .12361 L
s
.5753 .12361 m
.57572 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.09905 .12361 L
.10192 .12361 L
.10319 .12361 L
.10458 .12361 L
.10587 .12361 L
.10708 .12304 L
.10835 .12206 L
.10972 .12102 L
.11531 .11692 L
.12507 .11026 L
.14415 .09897 L
.16386 .08943 L
.18538 .08113 L
.20597 .07496 L
.22508 .07054 L
.24561 .06699 L
.26421 .0647 L
.27424 .06377 L
.28346 .0631 L
.29359 .06254 L
.29868 .06232 L
.30428 .06213 L
.30952 .06199 L
.3121 .06193 L
.31449 .06189 L
.3166 .06186 L
.31894 .06184 L
.32129 .06182 L
.32258 .06181 L
.32379 .06181 L
.32501 .0618 L
.3257 .0618 L
.32635 .0618 L
.32765 .0618 L
.32838 .06181 L
.32904 .06181 L
.33023 .06181 L
.33152 .06182 L
.33386 .06184 L
.3366 .06187 L
.3395 .0619 L
.34078 .06192 L
.34217 .06195 L
.34349 .06196 L
.34471 .06197 L
.34596 .06197 L
Mistroke
.34709 .06197 L
.3484 .06196 L
.34964 .06195 L
.35076 .06193 L
.3518 .06191 L
.35414 .06186 L
.35649 .06179 L
.35907 .0617 L
.36428 .06146 L
.37376 .06085 L
.38259 .06013 L
.42155 .0556 L
.46297 .04943 L
.50286 .04302 L
.54125 .03702 L
.56106 .03416 L
.56587 .0335 L
.57106 .03281 L
.57251 .03262 L
.57403 .03242 L
.57533 .03225 L
.57606 .03216 L
.57675 .12361 L
.57744 .12361 L
.5781 .12361 L
.57933 .12361 L
.58208 .12361 L
.6206 .12361 L
.66157 .12361 L
.70102 .12361 L
.73896 .12361 L
.77936 .12361 L
.81823 .12361 L
.85956 .12361 L
.89937 .12361 L
.93767 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0goooo0P1Voggoool0
06Ooool00`000?ooooooo`0]oooo2P1Vo`03oooo06Kooooo07coool006Ooool00`000?ooooooo`0Y
oooo101Vo`_oool00`1Vooooooooo`1koooo001Woooo00<0003oooooool09?ooo`D0I_l?oooo00<0
I_ooooooool0Noooo`00Ioooo`030000oooooooo01ooool506Ko5?ooo`0306Kooooooooo07_oool0
06Ooool200006?ooo`P0I_lIoooo00<0I_ooooooool0Noooo`00Ioooo`030000oooooooo00goool:
06Ko8Oooo`0306Kooooooooo07_oool006Ooool00`000?ooooooo`05oooo201Vob_oool00`1Voooo
ooooo`1koooo001Aoooo5P1Vo`03000006Ko06Ko00D0I_lcoooo00<0I_ooooooool0Noooo`00C?oo
o`D0I_lFoooo00<0003oooooool0>?ooo`0306Kooooooooo07_oool004Ooool506Ko6oooo`030000
oooooooo03Soool00`1Vooooooooo`1koooo0013oooo101Vob3oool20000>Oooo`0306Kooooooooo
07_oool001Ooool500007_ooo`800004oooo0P00000406Kooooooooooooo0P0001ooool00`000?oo
ooooo`0Noooo0P0000Coool200001?ooo`80000<oooo00<0I_ooooooool04?ooo`D0000Moooo1@00
00;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00D0003ooooo
ool0003oool00`1Vo`Coool010000?ooooooo`0001koool00`000?ooooooo`0Moooo00@0003ooooo
ool00008oooo00@0003oooooool0000;oooo00<0I_ooooooool04_ooo`030000oooooooo01ooool0
0`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000
oooooooo01goool01@000?ooooooo`00001Vo`0:oooo00<0003oooooool07?ooo`030000oooooooo
01goool010000?ooooooo`0000_oool00`000?ooooooo`09oooo00<0I_ooooooool04_ooo`030000
oooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo01Ooool400000_ooo`04000006Ko06Ko00002Oooo`80000O
oooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`80000<oooo00<0I_ooooooool04_oo
o`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000I
oooo00<0003oooooool06oooo`80I_l010000?ooooooo`0000Woool00`000?ooooooo`0Noooo00<0
003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo00_oool00`1Vooooooooo`0B
oooo00<0003oooooool07oooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00@0003ooooo
ool0000Foooo000Hoooo0P0001_oool206Ko0oooo`80000:oooo0`0001koool200007oooo`80000:
oooo0`0000_oool00`1Vooooooooo`0Aoooo0P00023oool200002_ooo`<0000Poooo0P0001Ooool0
03?oool206Ko<_ooo`030000oooooooo03Soool00`1Vooooooooo`1koooo000aoooo0P1VocCoool0
0`000?ooooooo`0hoooo00<0I_ooooooool0Noooo`00<?ooo`0306Kooooooooo03Coool00`000?oo
ooooo`0hoooo00<0I_ooooooool0Noooo`00;_ooo`80I_lgoooo00<0003oooooool0>?ooo`0306Ko
oooooooo07_oool002goool00`1Vooooooooo`0goooo00<0003oooooool0>?ooo`0306Kooooooooo
07_oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000@0
000co`0co`3o09T4<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0000co`0co`009C?o00030000<ol0<ol0010co`000ol0VC?o03?o000A<ol04000
01Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol003Pco`00
0ol0VC?o03?o000<<ol01@0006[oool006Ooool00`0003?o03?o000h<ol000?o09Tco`0co`001c?o
00D0001_oooo001Woooo00<0000co`0co`00>3?o0003o`2I<ol0<ol0008co`050000M?ooo`00Iooo
o`030000<ol0<ol003Pco`000ol0V@00000000020000NOooo`00Ioooo`80000h<ol000<0003o09Wo
ool0O?ooo`00Ioooo`030000<ol0<ol003Dco`02000000?ooooo09Woool0O?ooo`00Ioooo`030000
<ol0<ol003<co`0200000oooo`03o`2Ioooooooo07_oool006Ooool00`0003?o03?o000a<ol00P00
00Goool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`00<3?o00030000oooooooo00Goool0
0ol0VOooooooo`1koooo001Woooo00<0000co`0co`00;S?o00800008oooo00?o09Woooooool0Nooo
o`00Ioooo`80000]<ol00P0000[oool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`00:c?o
00030000oooooooo00[oool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`00:S?o00030000
oooooooo00_oool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`00:C?o00030000oooooooo
00coool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`00:3?o00030000oooooooo00goool0
0ol0VOooooooo`1koooo001Woooo00<0000co`0co`00:3?o00030000oooooooo00goool00ol0VOoo
ooooo`1koooo001Woooo0P0002Pco`000`000?ooooooo`0>oooo00?o09Woooooool0Noooo`00Iooo
o`030000<ol0<ol002Hco`000`000?ooooooo`0?oooo00?o09Woooooool0Noooo`00Ioooo`030000
<ol0<ol002Dco`000`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol0
02@co`000`000?ooooooo`0Aoooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol002<co`00
0`000?ooooooo`0Boooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol002<co`000`000?oo
ooooo`0Boooo00?o09Woooooool0Noooo`00Ioooo`80000S<ol000<0003oooooool04oooo`03o`2I
oooooooo07_oool006Ooool00`0003?o03?o000Q<ol000<0003oooooool05?ooo`03o`2Ioooooooo
07_oool006Ooool00`0003?o03?o000P<ol000<0003oooooool05Oooo`03o`2Ioooooooo07_oool0
06Ooool00`0003?o03?o000P<ol000<0003oooooool05Oooo`03o`2Ioooooooo07_oool006Ooool0
0`0003?o03?o000O<ol000<0003oooooool05_ooo`03o`2Ioooooooo07_oool005ooool500000ooo
o`030000<ol0<ol001lco`000`000?ooooooo`0Foooo00?o09Woooooool0Noooo`00HOooo`030000
oooooooo00?oool00`0003?o03?o000N<ol000<0003oooooool05oooo`03o`2Ioooooooo07_oool0
067oool00`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`0Goooo00?o09Woooooool0Nooo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool06?ooo`03o`2I
oooooooo07_oool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo
01Soool00ol0VOooooooo`1koooo001Poooo0P0000Goool00`0003?o03?o000L<ol000<0003ooooo
ool06Oooo`03o`2Ioooooooo07_oool006Ooool00`0003?o03?o000L<ol000<0003oooooool06Ooo
o`03o`2Ioooooooo07_oool006Ooool00`0003?o03?o000K<ol000<0003oooooool06_ooo`03o`2I
oooooooo07_oool006Ooool2000073?o00030000oooooooo01[oool00ol0VOooooooo`1koooo001W
oooo00<0000co`0co`006S?o00030000oooooooo01_oool00ol0VOooooooo`1koooo001Woooo00<0
000co`0co`006S?o00030000oooooooo01_oool00ol0VOooooooo`1koooo001Woooo00<0000co`0c
o`006C?o00030000oooooooo01coool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`006C?o
00030000oooooooo01coool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`0063?o00030000
oooooooo01goool00ol0VOooooooo`1koooo001Woooo0P0001Tco`000`000?ooooooo`0Moooo00?o
09Woooooool0Noooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`0Noooo00?o09Wooooo
ool0Noooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`0Noooo00?o09Woooooool0Nooo
o`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0Ooooo00?o09Woooooool0Noooo`00Iooo
o`030000<ol0<ol001Hco`000`000?ooooooo`0Ooooo00?o09Woooooool0Noooo`00Ioooo`030000
<ol0<ol001Hco`000`000?ooooooo`0Ooooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0Poooo00?o09Woooooool0Noooo`00Ioooo`80000F<ol000<0003ooooo
ool08?ooo`03o`2Ioooooooo07_oool006Ooool00`0003?o03?o000E<ol000<0003oooooool08?oo
o`03o`2Ioooooooo07_oool006Ooool00`0003?o03?o000E<ol000<0003oooooool08?ooo`03o`2I
oooooooo07_oool006Ooool00`0003?o03?o000D<ol000<0003oooooool08Oooo`03o`2Ioooooooo
07_oool006Ooool00`0003?o03?o000D<ol000<0003oooooool08Oooo`03o`2Ioooooooo07_oool0
06Ooool00`0003?o03?o000D<ol000<0003oooooool08Oooo`03o`2Ioooooooo07_oool006Ooool2
00005C?o00030000oooooooo027oool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`004c?o
00030000oooooooo02;oool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`004c?o00030000
oooooooo02;oool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`004c?o00030000oooooooo
02;oool00ol0VOooooooo`1koooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003ooooo
ool08_ooo`03o`2Ioooooooo07_oool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o
00030000oooooooo02?oool00ol0VOooooooo`1koooo001Poooo00<0003oooooool01?ooo`80000C
<ol000<0003oooooool08oooo`03o`2Ioooooooo07_oool0067oool00`000?ooooooo`03oooo00<0
000co`0co`004S?o00030000oooooooo02?oool00ol0VOooooooo`1koooo001Ooooo00@0003ooooo
ool00004oooo00<0000co`0co`004C?o00030000oooooooo02Coool00ol0VOooooooo`1koooo001P
oooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool09?ooo`03o`2Ioooooooo07_oool0
06Ooool00`0003?o03?o000A<ol000<0003oooooool09?ooo`03o`2Ioooooooo07_oool006Ooool0
0`0003?o03?o000A<ol000<0003oooooool09?ooo`03o`2Ioooooooo07_oool006Ooool200004C?o
00030000oooooooo02Goool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`0043?o00030000
oooooooo02Goool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`0043?o00030000oooooooo
02Goool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`0043?o00030000oooooooo02Goool0
0ol0VOooooooo`1koooo001Woooo00<0000co`0co`003c?o00030000oooooooo02Koool00ol0VOoo
ooooo`1koooo001Woooo00<0000co`0co`003c?o00030000oooooooo02Koool00ol0VOooooooo`1k
oooo001Woooo00<0000co`0co`003c?o00030000oooooooo02Koool00ol0VOooooooo`1koooo001W
oooo0P00010co`000`000?ooooooo`0Voooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`0Woooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`0Woooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000hco`000`000?oo
ooooo`0Woooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0W
oooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0Xoooo00?o
09Woooooool0Noooo`00Ioooo`80000><ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool0
06Ooool00`0003?o03?o000=<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool006Ooool0
0`0003?o03?o000=<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0:Oooo`03o`2Ioooooooo07_oool006Ooool00`0003?o03?o000<
<ol000<0003oooooool0:Oooo`03o`2Ioooooooo07_oool006Ooool00`0003?o03?o000<<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo07_oool006Ooool200003C?o00030000oooooooo02Woool0
0ol0VOooooooo`1koooo001Woooo00<0000co`0co`0033?o00030000oooooooo02Woool00ol0VOoo
ooooo`1koooo001Woooo00<0000co`0co`0033?o00030000oooooooo02Woool00ol0VOooooooo`1k
oooo001Woooo00<0000co`0co`002c?o00030000oooooooo02[oool00ol0VOooooooo`1koooo001P
oooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool0:_ooo`03o`2Ioooooooo07_oool0
05ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0:_ooo`03o`2I
oooooooo07_oool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`0Zoooo00?o
09Woooooool0Noooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003ooooo
ool0:_ooo`03o`2Ioooooooo07_oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;
<ol000<0003oooooool0:_ooo`03o`2Ioooooooo07_oool0063oool200001Oooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0[oooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0[oooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0[oooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0[
oooo00?o09Woooooool0Noooo`00Ioooo`80000;<ol000<0003oooooool0:oooo`03o`2Ioooooooo
07_oool006Ooool00`0003?o03?o000:<ol000<0003oooooool0:oooo`03o`2Ioooooooo07_oool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0;?ooo`03o`2Ioooooooo07_oool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0;?ooo`03o`2Ioooooooo07_oool006Ooool00`0003?o
03?o0009<ol000<0003oooooool0;?ooo`03o`2Ioooooooo07_oool006Ooool00`0003?o03?o0009
<ol000<0003oooooool0;?ooo`03o`2Ioooooooo07_oool006Ooool200002S?o00030000oooooooo
02coool00ol0VOooooooo`1koooo001Woooo00<0000co`0co`002C?o00030000oooooooo02coool0
0ol0VOooooooo`1koooo001Woooo00<0000co`0co`002C?o00030000oooooooo02coool00ol0VOoo
ooooo`1koooo001Woooo00<0000co`0co`0023?o00030000oooooooo02goool00ol0VOooooooo`1k
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo02goool00ol0VOooooooo`1koooo001W
oooo00<0000co`0co`0023?o00030000oooooooo02goool00ol0VOooooooo`1koooo001Woooo0P00
00Tco`000`000?ooooooo`0]oooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0]oooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0]oooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0^
oooo00?o09Woooooool0Noooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0^oooo00?o
09Woooooool0Noooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0^oooo00?o09Wooooo
ool0Noooo`00Ioooo`800008<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07_oool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07_oool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07_oool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07_oool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo07_oool0067oool300000oooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0^oooo00?o09Woooooool0Noooo`00H_ooo`030000oooooooo00;oool00`0003?o
03?o0007<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07_oool005ooool500000oooo`800008
<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07_oool005ooool010000?ooooooo`0000Coool:
<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool0
06Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200001Oooo`030000oooooooo00?oool300000_ooo`030000oooooooo
07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo00Coool01@000?oooooooooo
o`00001joooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002_ooo`040000oooooooooooo1@0000?oool00`000?ooooooo`1goooo001Woooo2C?o
00Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002oooo`040000oooooooo00000_oo
o`050000oooooooooooo000007[oool006Ooool9<ol02?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooo`000003oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`800009oooo100000Coool200000_oo
o`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.56817 .12361 L
.57355 .12361 L
.57861 .12361 L
.57995 .12361 L
.58137 .12361 L
.58211 .12361 L
s
.58211 .12361 m
.58244 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.08255 .12361 L
.08806 .12361 L
.09396 .12361 L
.09682 .12361 L
.09822 .12361 L
.09952 .12361 L
.1007 .12307 L
.10195 .12211 L
.10458 .12012 L
.14241 .09656 L
.16182 .0876 L
.1827 .07991 L
.20384 .07388 L
.22393 .06953 L
.24373 .06637 L
.26212 .06428 L
.27269 .0634 L
.28264 .06277 L
.29158 .06235 L
.29662 .06217 L
.30125 .06203 L
.30595 .06193 L
.30858 .06189 L
.31099 .06186 L
.31322 .06183 L
.31448 .06182 L
.31565 .06182 L
.31667 .06181 L
.3178 .06181 L
.31897 .0618 L
.32007 .0618 L
.32128 .0618 L
.3226 .06181 L
.32327 .06181 L
.32398 .06181 L
.32526 .06182 L
.32775 .06184 L
.33002 .06186 L
.33553 .06194 L
.34074 .06205 L
.34188 .06208 L
.34297 .0621 L
.34422 .06211 L
.34537 .06213 L
.34662 .06213 L
.34734 .06214 L
.348 .06214 L
Mistroke
.34919 .06213 L
.35046 .06212 L
.35116 .06212 L
.3518 .06211 L
.35324 .06209 L
.35586 .06203 L
.35824 .06196 L
.36075 .06187 L
.36955 .06144 L
.3792 .06077 L
.39875 .05891 L
.41968 .05637 L
.46109 .05035 L
.50099 .044 L
.53937 .03796 L
.5588 .03509 L
.56911 .03365 L
.57452 .03293 L
.57747 .03254 L
.5789 .03235 L
.58021 .03218 L
.58147 .03202 L
.58266 .12361 L
.58391 .12361 L
.58527 .12361 L
.5908 .12361 L
.6005 .12361 L
.61953 .12361 L
.6605 .12361 L
.69995 .12361 L
.73789 .12361 L
.77828 .12361 L
.81716 .12361 L
.85849 .12361 L
.8983 .12361 L
.9366 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0hoooo0`1Vog_oool0
06Ooool00`000?ooooooo`0boooo1P1Vo`;oool00`1Vooooooooo`1ioooo001Woooo00<0003ooooo
ool0:oooo`L0I_l8oooo00<0I_ooooooool0NOooo`00Ioooo`030000oooooooo02?oool806Ko3ooo
o`0306Kooooooooo07Woool006Ooool00`000?ooooooo`0Noooo1@1VoaOoool00`1Vooooooooo`1i
oooo001Woooo0P0001Soool706Ko7?ooo`0306Kooooooooo07Woool006Ooool00`000?ooooooo`0?
oooo201Vob?oool00`1Vooooooooo`1ioooo001Woooo00<0003oooooool01_ooo`T0I_l[oooo00<0
I_ooooooool0NOooo`00DOoooaH0I_l00`00001Vo`1Vo`0606Ko=?ooo`0306Kooooooooo07Woool0
04coool506Ko5_ooo`030000oooooooo03[oool00`1Vooooooooo`1ioooo0017oooo1@1Voa_oool0
0`000?ooooooo`0joooo00<0I_ooooooool0NOooo`00@_ooo`D0I_lPoooo0P0003_oool00`1Voooo
ooooo`1ioooo000Goooo1@0001koool200000_ooo`80I_l200001?ooo`80000Ooooo00<0003ooooo
ool07_ooo`800004oooo0P0000Coool200003_ooo`0306Kooooooooo00koool500007Oooo`D00002
oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`050000oooo06Ko
000006Ko00Ooool010000?ooooooo`0001koool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool0000=oooo00<0I_ooooooool04?ooo`030000oooooooo01ooool00`000?oo
ooooo`07oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo
01goool01000001Vooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000
oooooooo00002oooo`030000oooooooo00_oool00`1Vooooooooo`0@oooo00<0003oooooool07ooo
o`030000oooooooo00[oool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004
oooo00<0003oooooool05oooo`@0000206Ko00@0003oooooool00009oooo0P0001ooool00`000?oo
ooooo`0Moooo00@0003oooooool00009oooo0P0000koool00`1Vooooooooo`0@oooo00<0003ooooo
ool07oooo`030000oooooooo00Soool200008_ooo`030000oooooooo01Goool001Woool00`000?oo
ooooo`0Ioooo0P1Vo`;oool010000?ooooooo`0000Woool00`000?ooooooo`0Noooo00<0003ooooo
ool07Oooo`040000oooooooo00002Oooo`030000oooooooo00goool00`1Vooooooooo`0@oooo00<0
003oooooool07oooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000F
oooo000Hoooo0P0001[oool00`1Vooooooooo`03oooo0P0000[oool300007_ooo`80000Ooooo0P00
00[oool300003Oooo`0306Kooooooooo00ooool200008?ooo`80000:oooo0`00023oool200005ooo
o`00<_ooo`80I_lcoooo00<0003oooooool0>_ooo`0306Kooooooooo07Woool0037oool00`1Voooo
ooooo`0coooo00<0003oooooool0>_ooo`0306Kooooooooo07Woool002ooool206Ko=_ooo`030000
oooooooo03[oool00`1Vooooooooo`1ioooo000^oooo00<0I_ooooooool0=_ooo`030000oooooooo
03[oool00`1Vooooooooo`1ioooo000/oooo0P1VocWoool00`000?ooooooo`0joooo00<0I_oooooo
ool0NOooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0002<ol000Co09Tco`0co`000007<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000
oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`004S?o0003o`2I<ol0<ol000lco`0@
00006Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`00>S?o
0003o`2I<ol0<ol000Xco`050000J_ooo`00Ioooo`030000<ol0<ol003Xco`000ol0VC?o03?o0005
<ol01@0006ooool006Ooool00`0003?o03?o000j<ol000?o09Tco`0co`001@0007Coool006Ooool0
0`0003?o03?o000i<ol000@0003o09T00000001ioooo001Woooo0P0003Pco`02000000?ooooo09Wo
ool0N_ooo`00Ioooo`030000<ol0<ol003Dco`0200000oooo`03o`2Ioooooooo07Woool006Ooool0
0`0003?o03?o000c<ol00P0000Goool00ol0VOooooooo`1ioooo001Woooo00<0000co`0co`00<C?o
00800007oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`07
oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol002hco`0200002_ooo`03o`2Ioooooooo
07Woool006Ooool20000;C?o0080000<oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol0
02/co`000`000?ooooooo`0<oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol002Xco`00
0`000?ooooooo`0=oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol002Tco`000`000?oo
ooooo`0>oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0?
oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0?oooo00?o
09Woooooool0NOooo`00Ioooo`80000X<ol000<0003oooooool04?ooo`03o`2Ioooooooo07Woool0
06Ooool00`0003?o03?o000V<ol000<0003oooooool04Oooo`03o`2Ioooooooo07Woool006Ooool0
0`0003?o03?o000U<ol000<0003oooooool04_ooo`03o`2Ioooooooo07Woool006Ooool00`0003?o
03?o000T<ol000<0003oooooool04oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o000S
<ol000<0003oooooool05?ooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o000S<ol000<0
003oooooool05?ooo`03o`2Ioooooooo07Woool006Ooool200008c?o00030000oooooooo01Goool0
0ol0VOooooooo`1ioooo001Woooo00<0000co`0co`008C?o00030000oooooooo01Koool00ol0VOoo
ooooo`1ioooo001Woooo00<0000co`0co`0083?o00030000oooooooo01Ooool00ol0VOooooooo`1i
oooo001Woooo00<0000co`0co`0083?o00030000oooooooo01Ooool00ol0VOooooooo`1ioooo001W
oooo00<0000co`0co`007c?o00030000oooooooo01Soool00ol0VOooooooo`1ioooo001Ooooo1@00
00?oool00`0003?o03?o000O<ol000<0003oooooool06?ooo`03o`2Ioooooooo07Woool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`007S?o00030000oooooooo01Woool00ol0VOooooooo`1i
oooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0003oooooool06Oooo`03o`2Ioooooooo
07Woool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo01[oool0
0ol0VOooooooo`1ioooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?oo
ooooo`0Joooo00?o09Woooooool0NOooo`00H?ooo`800005oooo00<0000co`0co`0073?o00030000
oooooooo01_oool00ol0VOooooooo`1ioooo001Woooo00<0000co`0co`0073?o00030000oooooooo
01_oool00ol0VOooooooo`1ioooo001Woooo00<0000co`0co`006c?o00030000oooooooo01coool0
0ol0VOooooooo`1ioooo001Woooo0P0001`co`000`000?ooooooo`0Loooo00?o09Woooooool0NOoo
o`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0Moooo00?o09Woooooool0NOooo`00Iooo
o`030000<ol0<ol001Xco`000`000?ooooooo`0Moooo00?o09Woooooool0NOooo`00Ioooo`030000
<ol0<ol001Tco`000`000?ooooooo`0Noooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol0
01Tco`000`000?ooooooo`0Noooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol001Pco`00
0`000?ooooooo`0Ooooo00?o09Woooooool0NOooo`00Ioooo`80000I<ol000<0003oooooool07ooo
o`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o000G<ol000<0003oooooool08?ooo`03o`2I
oooooooo07Woool006Ooool00`0003?o03?o000G<ol000<0003oooooool08?ooo`03o`2Ioooooooo
07Woool006Ooool00`0003?o03?o000F<ol000<0003oooooool08Oooo`03o`2Ioooooooo07Woool0
06Ooool00`0003?o03?o000F<ol000<0003oooooool08Oooo`03o`2Ioooooooo07Woool006Ooool0
0`0003?o03?o000F<ol000<0003oooooool08Oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o
03?o000E<ol000<0003oooooool08_ooo`03o`2Ioooooooo07Woool006Ooool200005S?o00030000
oooooooo02;oool00ol0VOooooooo`1ioooo001Woooo00<0000co`0co`005C?o00030000oooooooo
02;oool00ol0VOooooooo`1ioooo001Woooo00<0000co`0co`005C?o00030000oooooooo02;oool0
0ol0VOooooooo`1ioooo001Woooo00<0000co`0co`0053?o00030000oooooooo02?oool00ol0VOoo
ooooo`1ioooo001Woooo00<0000co`0co`0053?o00030000oooooooo02?oool00ol0VOooooooo`1i
oooo001Woooo00<0000co`0co`0053?o00030000oooooooo02?oool00ol0VOooooooo`1ioooo001W
oooo0P0001Dco`000`000?ooooooo`0Soooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol0
01<co`000`000?ooooooo`0Toooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol001<co`00
0`000?ooooooo`0Toooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol001<co`000`000?oo
ooooo`0Toooo00?o09Woooooool0NOooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000
oooooooo02Coool00ol0VOooooooo`1ioooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0
018co`000`000?ooooooo`0Uoooo00?o09Woooooool0NOooo`00H?ooo`030000oooooooo00Coool2
00004c?o00030000oooooooo02Goool00ol0VOooooooo`1ioooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol0018co`000`000?ooooooo`0Uoooo00?o09Woooooool0NOooo`00Goooo`040000
oooooooo00001?ooo`030000<ol0<ol0014co`000`000?ooooooo`0Voooo00?o09Woooooool0NOoo
o`00H?ooo`800005oooo00<0000co`0co`004C?o00030000oooooooo02Koool00ol0VOooooooo`1i
oooo001Woooo00<0000co`0co`004C?o00030000oooooooo02Koool00ol0VOooooooo`1ioooo001W
oooo00<0000co`0co`004C?o00030000oooooooo02Koool00ol0VOooooooo`1ioooo001Woooo0P00
014co`000`000?ooooooo`0Woooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol0010co`00
0`000?ooooooo`0Woooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol0010co`000`000?oo
ooooo`0Woooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0W
oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`0Xoooo00?o
09Woooooool0NOooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0NOooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`0Xoooo00?o09Woooooool0NOoo
o`00Ioooo`80000@<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07Woool006Ooool00`0003?o
03?o000><ol000<0003oooooool0:Oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o000>
<ol000<0003oooooool0:Oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o000><ol000<0
003oooooool0:Oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o000><ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o000=<ol000<0003oooooool0:_oo
o`03o`2Ioooooooo07Woool006Ooool200003S?o00030000oooooooo02[oool00ol0VOooooooo`1i
oooo001Woooo00<0000co`0co`003C?o00030000oooooooo02[oool00ol0VOooooooo`1ioooo001W
oooo00<0000co`0co`003C?o00030000oooooooo02[oool00ol0VOooooooo`1ioooo001Woooo00<0
000co`0co`0033?o00030000oooooooo02_oool00ol0VOooooooo`1ioooo001Woooo00<0000co`0c
o`0033?o00030000oooooooo02_oool00ol0VOooooooo`1ioooo001Woooo00<0000co`0co`0033?o
00030000oooooooo02_oool00ol0VOooooooo`1ioooo001Woooo0P0000dco`000`000?ooooooo`0[
oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0[oooo00?o
09Woooooool0NOooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0[oooo00?o09Wooooo
ool0NOooo`00Ioooo`030000<ol0<ol000/co`000`000?ooooooo`0/oooo00?o09Woooooool0NOoo
o`00H?ooo`800005oooo00<0000co`0co`002c?o00030000oooooooo02coool00ol0VOooooooo`1i
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo02coool0
0ol0VOooooooo`1ioooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0003oooooool0;?oo
o`03o`2Ioooooooo07Woool006;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000
oooooooo02coool00ol0VOooooooo`1ioooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`002c?o00030000oooooooo02coool00ol0VOooooooo`1ioooo001Poooo0P0000Goool00`0003?o
03?o000:<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o000:
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o000:<ol000<0
003oooooool0;Oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo07Woool006Ooool200002c?o00030000oooooooo02goool00ol0VOoo
ooooo`1ioooo001Woooo00<0000co`0co`002S?o00030000oooooooo02goool00ol0VOooooooo`1i
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo02koool00ol0VOooooooo`1ioooo001W
oooo00<0000co`0co`002C?o00030000oooooooo02koool00ol0VOooooooo`1ioooo001Woooo00<0
000co`0co`002C?o00030000oooooooo02koool00ol0VOooooooo`1ioooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo02koool00ol0VOooooooo`1ioooo001Woooo0P0000Xco`000`000?oo
ooooo`0^oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0^
oooo00?o09Woooooool0NOooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0^oooo00?o
09Woooooool0NOooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0_oooo00?o09Wooooo
ool0NOooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0_oooo00?o09Woooooool0NOoo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0_oooo00?o09Woooooool0NOooo`00Iooo
o`800009<ol000<0003oooooool0;oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0;oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0;oooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0<?ooo`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o0007<ol000<0003oooooool0<?oo
o`03o`2Ioooooooo07Woool006Ooool00`0003?o03?o0007<ol000<0003oooooool0<?ooo`03o`2I
oooooooo07Woool006Ooool2000023?o00030000oooooooo033oool00ol0VOooooooo`1ioooo001W
oooo00<0000co`0co`001c?o00030000oooooooo033oool00ol0VOooooooo`1ioooo001Woooo00<0
000co`0co`001c?o00030000oooooooo033oool00ol0VOooooooo`1ioooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo033oool00ol0VOooooooo`1ioooo001Woooo00<0000co`0co`001c?o
00030000oooooooo033oool00ol0VOooooooo`1ioooo001Qoooo0`0000?oool00`0003?o03?o0007
<ol000<0003oooooool0<?ooo`03o`2Ioooooooo07Woool006;oool00`000?ooooooo`02oooo00<0
000co`0co`001c?o00030000oooooooo033oool00ol0VOooooooo`1ioooo001Ooooo1@0000?oool2
000023?o00030000oooooooo033oool00ol0VOooooooo`1ioooo001Ooooo00@0003oooooool00004
oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_
oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?oo
o`030000oooooooo07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01oooo`800004oooo0P0000Goool010000?ooooooooooo`<00004oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`050000
oooooooooooo000007[oool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003?ooo`040000oooooooo
00002oooo`030000oooooooo00<00004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0
003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P00
00Woool400000oooo`<00002oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o
0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.56817 .12361 L
.57861 .12361 L
.58157 .12361 L
.58436 .12361 L
.58686 .12361 L
.58755 .12361 L
.58827 .12361 L
s
.58827 .12361 m
.58879 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.07216 .12361 L
.08255 .12361 L
.08562 .12361 L
.08852 .12361 L
.09113 .12361 L
.09184 .12361 L
.0926 .12361 L
.09325 .12361 L
.09396 .12337 L
.09466 .12282 L
.09534 .1223 L
.0966 .12134 L
.09944 .11922 L
.10458 .11552 L
.14277 .09325 L
.16245 .08483 L
.18342 .07771 L
.20483 .07215 L
.225 .06822 L
.23476 .06673 L
.24508 .0654 L
.26355 .06361 L
.27303 .06296 L
.27825 .06267 L
.28319 .06243 L
.28778 .06225 L
.29278 .06209 L
.29732 .06198 L
.30152 .0619 L
.30394 .06186 L
.30616 .06184 L
.30859 .06182 L
.30981 .06181 L
.3105 .06181 L
.31115 .06181 L
.31234 .0618 L
.31341 .0618 L
.31457 .0618 L
.31583 .06181 L
.31693 .06181 L
.3181 .06182 L
.32019 .06183 L
.32263 .06185 L
.32526 .06188 L
.33 .06196 L
.33564 .06208 L
.34079 .06222 L
Mistroke
.34197 .06225 L
.34325 .06228 L
.34438 .0623 L
.34557 .06232 L
.34623 .06233 L
.34696 .06234 L
.34824 .06235 L
.34949 .06235 L
.35066 .06235 L
.35185 .06234 L
.35297 .06233 L
.35398 .06232 L
.35508 .0623 L
.35754 .06225 L
.35981 .06219 L
.3646 .06201 L
.36987 .06175 L
.38055 .06104 L
.39994 .05924 L
.42081 .05676 L
.462 .05086 L
.50167 .04459 L
.53983 .03857 L
.56113 .03541 L
.57119 .03399 L
.58045 .03274 L
.58514 .03213 L
.58751 .03183 L
.58816 .03175 L
.58885 .03166 L
.59011 .12361 L
.59081 .12361 L
.59145 .12361 L
.59292 .12361 L
.59558 .12361 L
.60057 .12361 L
.61955 .12361 L
.65878 .12361 L
.6965 .12361 L
.73667 .12361 L
.77532 .12361 L
.81643 .12361 L
.85602 .12361 L
.8941 .12361 L
.93463 .12361 L
.97364 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0ioooo0`1Vog[oool0
06Ooool00`000?ooooooo`0boooo1`1Vo`;oool00`1Vooooooooo`1hoooo001Woooo00<0003ooooo
ool0:oooo`L0I_l9oooo00<0I_ooooooool0N?ooo`00Ioooo`030000oooooooo02?oool806Ko4?oo
o`0306Kooooooooo07Soool006Ooool00`000?ooooooo`0Noooo1@1VoaSoool00`1Vooooooooo`1h
oooo001Woooo0P0001Soool706Ko7Oooo`0306Kooooooooo07Soool006Ooool00`000?ooooooo`0?
oooo201VobCoool00`1Vooooooooo`1hoooo001Woooo00<0003oooooool02_ooo`D0I_l/oooo00<0
I_ooooooool0N?ooo`00DOoooaH0I_l00`00001Vo`1Vo`0:06Ko<Oooo`0306Kooooooooo07Soool0
04Ooool:06Ko5_ooo`030000oooooooo03_oool00`1Vooooooooo`1hoooo0013oooo101Vob3oool0
0`000?ooooooo`0koooo00<0I_ooooooool0N?ooo`00@Oooo`80I_lToooo0P0003coool00`1Voooo
ooooo`1hoooo000Goooo1@0001koool200000_ooo`80I_l200001?ooo`80000Ooooo00<0003ooooo
ool07_ooo`800004oooo0P0000Coool200004?ooo`0306Kooooooooo00coool500007Oooo`D00002
oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`050000oooo06Ko
000006Ko00Ooool010000?ooooooo`0001koool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool0000?oooo00<0I_ooooooool03_ooo`030000oooooooo01ooool00`000?oo
ooooo`07oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000oooooooo
01coool01@1Vo`00001Vooooo`00000;oooo00<0003oooooool07?ooo`030000oooooooo01goool0
10000?ooooooo`0000_oool00`000?ooooooo`0=oooo00<0I_ooooooool03_ooo`030000oooooooo
01ooool00`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo01Koool0017oool4
00001?ooo`030000oooooooo01Ooool4000000<0I_ooool000000_ooo`030000oooooooo00Ooool2
00007oooo`030000oooooooo01goool010000?ooooooo`0000Woool200004?ooo`0306Kooooooooo
00koool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`80000Roooo00<0003oooooool05Ooo
o`006Oooo`030000oooooooo01Soool206Ko0oooo`040000oooooooo00002Oooo`030000oooooooo
01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool03oooo`0306Ko
oooooooo00koool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`030000oooooooo01ooool0
10000?ooooooo`0001Koool001Soool200006?ooo`80I_l6oooo0P0000[oool300007_ooo`80000O
oooo0P0000[oool300003oooo`0306Kooooooooo00goool200008?ooo`80000:oooo0`00023oool2
00005oooo`00<?ooo`80I_leoooo00<0003oooooool0??ooo`0306Kooooooooo07Ooool002koool2
06Ko=oooo`030000oooooooo03coool00`1Vooooooooo`1goooo000/oooo0P1VocWoool00`000?oo
ooooo`0loooo00<0I_ooooooool0Moooo`00:oooo`0306Kooooooooo03Woool00`000?ooooooo`0l
oooo00<0I_ooooooool0Moooo`00:Oooo`80I_lloooo00<0003oooooool0??ooo`0306Kooooooooo
07Ooool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`000c?o0003o`2I<ol0000000Lco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000C<ol000?o09Tco`0co`003S?o0100000I
oooo00<0003oooooool09_ooo`030000oooooooo01Goool006Ooool00`0003?o03?o000k<ol000?o
09Tco`0co`002C?o00D0001Zoooo001Woooo00<0000co`0co`00>c?o0003o`2I<ol0<ol000@co`05
0000Koooo`00Ioooo`030000<ol0<ol003/co`000ol0VC?o000000040000M?ooo`00Ioooo`030000
<ol0<ol003Tco`02000000?o09T0003oool0N?ooo`00Ioooo`80000h<ol00P0000;oool00ol0VOoo
ooooo`1hoooo001Woooo00<0000co`0co`00=C?o00800004oooo00?o09Woooooool0N?ooo`00Iooo
o`030000<ol0<ol003<co`0200001_ooo`03o`2Ioooooooo07Soool006Ooool00`0003?o03?o000a
<ol00P0000Soool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`00<3?o00030000oooooooo
00Soool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`00;S?o0080000;oooo00?o09Wooooo
ool0N?ooo`00Ioooo`80000]<ol00P0000goool00ol0VOooooooo`1hoooo001Woooo00<0000co`0c
o`00:c?o00030000oooooooo00goool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`00:S?o
00030000oooooooo00koool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`00:C?o00030000
oooooooo00ooool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`00:3?o00030000oooooooo
013oool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`00:3?o00030000oooooooo013oool0
0ol0VOooooooo`1hoooo001Woooo0P0002Pco`000`000?ooooooo`0Aoooo00?o09Woooooool0N?oo
o`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`0Boooo00?o09Woooooool0N?ooo`00Iooo
o`030000<ol0<ol002Dco`000`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Ioooo`030000
<ol0<ol002@co`000`000?ooooooo`0Doooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol0
02<co`000`000?ooooooo`0Eoooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol002<co`00
0`000?ooooooo`0Eoooo00?o09Woooooool0N?ooo`00Ioooo`80000S<ol000<0003oooooool05_oo
o`03o`2Ioooooooo07Soool006Ooool00`0003?o03?o000Q<ol000<0003oooooool05oooo`03o`2I
oooooooo07Soool006Ooool00`0003?o03?o000P<ol000<0003oooooool06?ooo`03o`2Ioooooooo
07Soool006Ooool00`0003?o03?o000P<ol000<0003oooooool06?ooo`03o`2Ioooooooo07Soool0
06Ooool00`0003?o03?o000O<ol000<0003oooooool06Oooo`03o`2Ioooooooo07Soool005ooool5
00000oooo`030000<ol0<ol001lco`000`000?ooooooo`0Ioooo00?o09Woooooool0N?ooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003oooooool06_ooo`03o`2Ioooooooo
07Soool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`0Joooo00?o09Wooooo
ool0N?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool06ooo
o`03o`2Ioooooooo07Soool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000
oooooooo01_oool00ol0VOooooooo`1hoooo001Poooo0P0000Goool00`0003?o03?o000L<ol000<0
003oooooool07?ooo`03o`2Ioooooooo07Soool006Ooool00`0003?o03?o000L<ol000<0003ooooo
ool07?ooo`03o`2Ioooooooo07Soool006Ooool00`0003?o03?o000K<ol000<0003oooooool07Ooo
o`03o`2Ioooooooo07Soool006Ooool2000073?o00030000oooooooo01goool00ol0VOooooooo`1h
oooo001Woooo00<0000co`0co`006S?o00030000oooooooo01koool00ol0VOooooooo`1hoooo001W
oooo00<0000co`0co`006S?o00030000oooooooo01koool00ol0VOooooooo`1hoooo001Woooo00<0
000co`0co`006C?o00030000oooooooo01ooool00ol0VOooooooo`1hoooo001Woooo00<0000co`0c
o`006C?o00030000oooooooo01ooool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`0063?o
00030000oooooooo023oool00ol0VOooooooo`1hoooo001Woooo0P0001Tco`000`000?ooooooo`0P
oooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`0Qoooo00?o
09Woooooool0N?ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`0Qoooo00?o09Wooooo
ool0N?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0Roooo00?o09Woooooool0N?oo
o`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0Roooo00?o09Woooooool0N?ooo`00Iooo
o`030000<ol0<ol001Hco`000`000?ooooooo`0Roooo00?o09Woooooool0N?ooo`00Ioooo`030000
<ol0<ol001Dco`000`000?ooooooo`0Soooo00?o09Woooooool0N?ooo`00Ioooo`80000F<ol000<0
003oooooool08oooo`03o`2Ioooooooo07Soool006Ooool00`0003?o03?o000E<ol000<0003ooooo
ool08oooo`03o`2Ioooooooo07Soool006Ooool00`0003?o03?o000E<ol000<0003oooooool08ooo
o`03o`2Ioooooooo07Soool006Ooool00`0003?o03?o000D<ol000<0003oooooool09?ooo`03o`2I
oooooooo07Soool006Ooool00`0003?o03?o000D<ol000<0003oooooool09?ooo`03o`2Ioooooooo
07Soool006Ooool00`0003?o03?o000D<ol000<0003oooooool09?ooo`03o`2Ioooooooo07Soool0
06Ooool200005C?o00030000oooooooo02Coool00ol0VOooooooo`1hoooo001Woooo00<0000co`0c
o`004c?o00030000oooooooo02Goool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`004c?o
00030000oooooooo02Goool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`004c?o00030000
oooooooo02Goool00ol0VOooooooo`1hoooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0
003oooooool09Oooo`03o`2Ioooooooo07Soool005ooool00`000?ooooooo`05oooo00<0000co`0c
o`004S?o00030000oooooooo02Koool00ol0VOooooooo`1hoooo001Poooo00<0003oooooool01?oo
o`80000C<ol000<0003oooooool09_ooo`03o`2Ioooooooo07Soool0067oool00`000?ooooooo`03
oooo00<0000co`0co`004S?o00030000oooooooo02Koool00ol0VOooooooo`1hoooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo02Ooool00ol0VOooooooo`1h
oooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool09oooo`03o`2Ioooooooo
07Soool006Ooool00`0003?o03?o000A<ol000<0003oooooool09oooo`03o`2Ioooooooo07Soool0
06Ooool00`0003?o03?o000A<ol000<0003oooooool09oooo`03o`2Ioooooooo07Soool006Ooool2
00004C?o00030000oooooooo02Soool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`0043?o
00030000oooooooo02Soool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`0043?o00030000
oooooooo02Soool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`0043?o00030000oooooooo
02Soool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`003c?o00030000oooooooo02Woool0
0ol0VOooooooo`1hoooo001Woooo00<0000co`0co`003c?o00030000oooooooo02Woool00ol0VOoo
ooooo`1hoooo001Woooo00<0000co`0co`003c?o00030000oooooooo02Woool00ol0VOooooooo`1h
oooo001Woooo0P00010co`000`000?ooooooo`0Yoooo00?o09Woooooool0N?ooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`0Zoooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`0Zoooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`0Zoooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol000hco`000`000?oo
ooooo`0Zoooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0[
oooo00?o09Woooooool0N?ooo`00Ioooo`80000><ol000<0003oooooool0:oooo`03o`2Ioooooooo
07Soool006Ooool00`0003?o03?o000=<ol000<0003oooooool0:oooo`03o`2Ioooooooo07Soool0
06Ooool00`0003?o03?o000=<ol000<0003oooooool0:oooo`03o`2Ioooooooo07Soool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0;?ooo`03o`2Ioooooooo07Soool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0;?ooo`03o`2Ioooooooo07Soool006Ooool00`0003?o03?o000<
<ol000<0003oooooool0;?ooo`03o`2Ioooooooo07Soool006Ooool200003C?o00030000oooooooo
02coool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`0033?o00030000oooooooo02coool0
0ol0VOooooooo`1hoooo001Woooo00<0000co`0co`0033?o00030000oooooooo02coool00ol0VOoo
ooooo`1hoooo001Woooo00<0000co`0co`002c?o00030000oooooooo02goool00ol0VOooooooo`1h
oooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool0;Oooo`03o`2Ioooooooo
07Soool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0;Ooo
o`03o`2Ioooooooo07Soool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`0]
oooo00?o09Woooooool0N?ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;<ol000<0
003oooooool0;Oooo`03o`2Ioooooooo07Soool005ooool010000?ooooooo`0000Coool00`0003?o
03?o000;<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Soool0063oool200001Oooo`030000
<ol0<ol000Xco`000`000?ooooooo`0^oooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0^oooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0^oooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0^oooo00?o09Woooooool0N?ooo`00Ioooo`80000;<ol000<0003oooooool0;_ooo`03o`2I
oooooooo07Soool006Ooool00`0003?o03?o000:<ol000<0003oooooool0;_ooo`03o`2Ioooooooo
07Soool006Ooool00`0003?o03?o0009<ol000<0003oooooool0;oooo`03o`2Ioooooooo07Soool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0;oooo`03o`2Ioooooooo07Soool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0;oooo`03o`2Ioooooooo07Soool006Ooool00`0003?o
03?o0009<ol000<0003oooooool0;oooo`03o`2Ioooooooo07Soool006Ooool200002S?o00030000
oooooooo02ooool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`002C?o00030000oooooooo
02ooool00ol0VOooooooo`1hoooo001Woooo00<0000co`0co`002C?o00030000oooooooo02ooool0
0ol0VOooooooo`1hoooo001Woooo00<0000co`0co`0023?o00030000oooooooo033oool00ol0VOoo
ooooo`1hoooo001Woooo00<0000co`0co`0023?o00030000oooooooo033oool00ol0VOooooooo`1h
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo033oool00ol0VOooooooo`1hoooo001W
oooo0P0000Tco`000`000?ooooooo`0`oooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0`oooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0`oooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0aoooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0a
oooo00?o09Woooooool0N?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0aoooo00?o
09Woooooool0N?ooo`00Ioooo`800008<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Soool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Soool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Soool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Soool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Soool0067oool300000oooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0aoooo00?o09Woooooool0N?ooo`00H_ooo`030000oooooooo00;oool0
0`0003?o03?o0007<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Soool005ooool500000ooo
o`800008<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Soool005ooool010000?ooooooo`00
00Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o
0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo
01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`07oooo0P0000Coool200001Oooo`030000oooooooo00;oool200001?ooo`030000
oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool0
1@000?ooooooooooo`00001joooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03Oooo`040000oooooooo00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000coool010000?oo
ooooo`0000_oool010000?ooooooooooo`800004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo
017oool200002Oooo`@00003oooo0P0000?oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool0
06Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.57861 .12361 L
.58392 .12361 L
.58957 .12361 L
.59232 .12361 L
.59367 .12361 L
.59491 .12361 L
s
.59491 .12361 m
.59536 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.07216 .12361 L
.0775 .12361 L
.08255 .12361 L
.08542 .12361 L
.0862 .12361 L
.08703 .12361 L
.08774 .12326 L
.08852 .12266 L
.09396 .11858 L
.10458 .11121 L
.12562 .09869 L
.14487 .08941 L
.16497 .0816 L
.18364 .07584 L
.20262 .07124 L
.22335 .06747 L
.23392 .06599 L
.24387 .06483 L
.25274 .06398 L
.26248 .06323 L
.27224 .06265 L
.27722 .06242 L
.28256 .06221 L
.28755 .06206 L
.29211 .06195 L
.2943 .06191 L
.29669 .06188 L
.29895 .06185 L
.30103 .06183 L
.30216 .06182 L
.30336 .06181 L
.30456 .06181 L
.30588 .0618 L
.30702 .0618 L
.30823 .0618 L
.30938 .06181 L
.31043 .06181 L
.31107 .06181 L
.31176 .06182 L
.31299 .06182 L
.31576 .06185 L
.31816 .06187 L
.3208 .06191 L
.32604 .06201 L
.33166 .06214 L
.33693 .06229 L
.34181 .06246 L
Mistroke
.34303 .06249 L
.34434 .06253 L
.3455 .06255 L
.34672 .06257 L
.3474 .06258 L
.34815 .06259 L
.34946 .0626 L
.35074 .06261 L
.35194 .06261 L
.35263 .0626 L
.35338 .0626 L
.35408 .06259 L
.35473 .06259 L
.35597 .06257 L
.35727 .06255 L
.35999 .06249 L
.36299 .0624 L
.36798 .0622 L
.37336 .06191 L
.38309 .06125 L
.40317 .05938 L
.42428 .05688 L
.46244 .05146 L
.50305 .04509 L
.54215 .03893 L
.5621 .03594 L
.5726 .03444 L
.5837 .03293 L
.58849 .0323 L
.59113 .03196 L
.59363 .03164 L
.59432 .03156 L
.59504 .03147 L
.59584 .12361 L
.59658 .12361 L
.59927 .12361 L
.60454 .12361 L
.62373 .12361 L
.66145 .12361 L
.70162 .12361 L
.74028 .12361 L
.78139 .12361 L
.82098 .12361 L
.85905 .12361 L
.89958 .12361 L
.9386 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0ioooo1@1VogSoool0
06Ooool00`000?ooooooo`0coooo1P1Vo`Coool00`1Vooooooooo`1foooo001Woooo00<0003ooooo
ool0;?ooo`L0I_l:oooo00<0I_ooooooool0M_ooo`00Ioooo`030000oooooooo02Coool806Ko4Ooo
o`0306Kooooooooo07Koool006Ooool00`000?ooooooo`0Noooo1P1VoaWoool00`1Vooooooooo`1f
oooo001Woooo0P0001Soool706Ko7oooo`0306Kooooooooo07Koool006Ooool00`000?ooooooo`0@
oooo1`1VobKoool00`1Vooooooooo`1foooo001Woooo00<0003oooooool02_ooo`H0I_l]oooo00<0
I_ooooooool0M_ooo`00C_oooaT0I_l00`00001Vo`1Vo`0:06Ko<oooo`0306Kooooooooo07Koool0
04Ooool706Ko6Oooo`030000oooooooo03goool00`1Vooooooooo`1foooo0012oooo1@1Vob3oool0
0`000?ooooooo`0moooo00<0I_ooooooool0M_ooo`00?_ooo`@0I_lUoooo0P0003koool00`1Voooo
ooooo`1foooo000Goooo1@0001koool200000P1Vo`;oool200001?ooo`80000Ooooo00<0003ooooo
ool07_ooo`800004oooo0P0000Coool200004Oooo`0306Kooooooooo00_oool500007Oooo`D00002
oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`04000006Ko06Ko
00002?ooo`040000oooooooo00007_ooo`030000oooooooo01goool010000?ooooooo`0000Soool0
10000?ooooooo`00013oool00`1Vooooooooo`0=oooo00<0003oooooool07oooo`030000oooooooo
00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool06ooo
o`80I_l010000?ooooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000
oooooooo00002oooo`030000oooooooo00koool00`1Vooooooooo`0=oooo00<0003oooooool07ooo
o`030000oooooooo00[oool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004
oooo00<0003oooooool05oooo`@00002oooo00@0003oooooool00009oooo0P0001ooool00`000?oo
ooooo`0Moooo00@0003oooooool00009oooo0P00017oool00`1Vooooooooo`0=oooo00<0003ooooo
ool07oooo`030000oooooooo00Soool200008_ooo`030000oooooooo01Goool001Woool00`000?oo
ooooo`0Foooo0P1Vo`Goool010000?ooooooo`0000Woool00`000?ooooooo`0Noooo00<0003ooooo
ool07Oooo`040000oooooooo00002Oooo`030000oooooooo013oool00`1Vooooooooo`0=oooo00<0
003oooooool07oooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000F
oooo000Hoooo0P0001Koool206Ko2?ooo`80000:oooo0`0001koool200007oooo`80000:oooo0`00
013oool00`1Vooooooooo`0<oooo0P00023oool200002_ooo`<0000Poooo0P0001Ooool002koool2
06Ko=oooo`030000oooooooo03goool00`1Vooooooooo`1foooo000/oooo0P1VocWoool00`000?oo
ooooo`0moooo00<0I_ooooooool0M_ooo`00:oooo`0306Kooooooooo03Woool00`000?ooooooo`0m
oooo00<0I_ooooooool0M_ooo`00:Oooo`80I_lloooo00<0003oooooool0?Oooo`0306Kooooooooo
07Koool002Soool00`1Vooooooooo`0loooo00<0003oooooool0?Oooo`0306Kooooooooo07Koool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_oo
o`030000<ol0<ol002Dco`000`0003?o03?o000E<ol000?o09Tco`0co`0033?o0100000Ioooo00<0
003oooooool09_ooo`030000oooooooo01Goool006Ooool00`0003?o03?o000m<ol000?o09Tco`0c
o`001c?o00D0001Zoooo001Woooo00<0000co`0co`00?C?o0003o`2I<ol0<ol0008co`050000Kooo
o`00Ioooo`030000<ol0<ol003dco`000ol0V@00000000020000M?ooo`00Ioooo`030000<ol0<ol0
03Tco`04000000?o09Woooooool0M_ooo`00Ioooo`80000h<ol00P0000Coool00ol0VOooooooo`1f
oooo001Woooo00<0000co`0co`00=C?o00800006oooo00?o09Woooooool0M_ooo`00Ioooo`030000
<ol0<ol003<co`0200002?ooo`03o`2Ioooooooo07Koool006Ooool00`0003?o03?o000a<ol00P00
00[oool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`00<3?o00030000oooooooo00[oool0
0ol0VOooooooo`1foooo001Woooo00<0000co`0co`00;S?o0080000=oooo00?o09Woooooool0M_oo
o`00Ioooo`80000]<ol00P0000ooool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`00:c?o
00030000oooooooo00ooool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`00:S?o00030000
oooooooo013oool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`00:C?o00030000oooooooo
017oool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`00:3?o00030000oooooooo01;oool0
0ol0VOooooooo`1foooo001Woooo00<0000co`0co`00:3?o00030000oooooooo01;oool00ol0VOoo
ooooo`1foooo001Woooo0P0002Pco`000`000?ooooooo`0Coooo00?o09Woooooool0M_ooo`00Iooo
o`030000<ol0<ol002Hco`000`000?ooooooo`0Doooo00?o09Woooooool0M_ooo`00Ioooo`030000
<ol0<ol002Dco`000`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol0
02@co`000`000?ooooooo`0Foooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol002<co`00
0`000?ooooooo`0Goooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol002<co`000`000?oo
ooooo`0Goooo00?o09Woooooool0M_ooo`00Ioooo`80000S<ol000<0003oooooool06?ooo`03o`2I
oooooooo07Koool006Ooool00`0003?o03?o000Q<ol000<0003oooooool06Oooo`03o`2Ioooooooo
07Koool006Ooool00`0003?o03?o000P<ol000<0003oooooool06_ooo`03o`2Ioooooooo07Koool0
06Ooool00`0003?o03?o000P<ol000<0003oooooool06_ooo`03o`2Ioooooooo07Koool006Ooool0
0`0003?o03?o000O<ol000<0003oooooool06oooo`03o`2Ioooooooo07Koool005ooool500000ooo
o`030000<ol0<ol001lco`000`000?ooooooo`0Koooo00?o09Woooooool0M_ooo`00HOooo`030000
oooooooo00?oool00`0003?o03?o000N<ol000<0003oooooool07?ooo`03o`2Ioooooooo07Koool0
067oool00`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`0Loooo00?o09Woooooool0M_oo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool07Oooo`03o`2I
oooooooo07Koool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo
01goool00ol0VOooooooo`1foooo001Poooo0P0000Goool00`0003?o03?o000L<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo07Koool006Ooool00`0003?o03?o000L<ol000<0003oooooool07_oo
o`03o`2Ioooooooo07Koool006Ooool00`0003?o03?o000K<ol000<0003oooooool07oooo`03o`2I
oooooooo07Koool006Ooool2000073?o00030000oooooooo01ooool00ol0VOooooooo`1foooo001W
oooo00<0000co`0co`006S?o00030000oooooooo023oool00ol0VOooooooo`1foooo001Woooo00<0
000co`0co`006S?o00030000oooooooo023oool00ol0VOooooooo`1foooo001Woooo00<0000co`0c
o`006C?o00030000oooooooo027oool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`006C?o
00030000oooooooo027oool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`0063?o00030000
oooooooo02;oool00ol0VOooooooo`1foooo001Woooo0P0001Tco`000`000?ooooooo`0Roooo00?o
09Woooooool0M_ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`0Soooo00?o09Wooooo
ool0M_ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`0Soooo00?o09Woooooool0M_oo
o`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0Toooo00?o09Woooooool0M_ooo`00Iooo
o`030000<ol0<ol001Hco`000`000?ooooooo`0Toooo00?o09Woooooool0M_ooo`00Ioooo`030000
<ol0<ol001Hco`000`000?ooooooo`0Toooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0Uoooo00?o09Woooooool0M_ooo`00Ioooo`80000F<ol000<0003ooooo
ool09Oooo`03o`2Ioooooooo07Koool006Ooool00`0003?o03?o000E<ol000<0003oooooool09Ooo
o`03o`2Ioooooooo07Koool006Ooool00`0003?o03?o000E<ol000<0003oooooool09Oooo`03o`2I
oooooooo07Koool006Ooool00`0003?o03?o000D<ol000<0003oooooool09_ooo`03o`2Ioooooooo
07Koool006Ooool00`0003?o03?o000D<ol000<0003oooooool09_ooo`03o`2Ioooooooo07Koool0
06Ooool00`0003?o03?o000D<ol000<0003oooooool09_ooo`03o`2Ioooooooo07Koool006Ooool2
00005C?o00030000oooooooo02Koool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`004c?o
00030000oooooooo02Ooool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`004c?o00030000
oooooooo02Ooool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`004c?o00030000oooooooo
02Ooool00ol0VOooooooo`1foooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003ooooo
ool09oooo`03o`2Ioooooooo07Koool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o
00030000oooooooo02Soool00ol0VOooooooo`1foooo001Poooo00<0003oooooool01?ooo`80000C
<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07Koool0067oool00`000?ooooooo`03oooo00<0
000co`0co`004S?o00030000oooooooo02Soool00ol0VOooooooo`1foooo001Ooooo00@0003ooooo
ool00004oooo00<0000co`0co`004C?o00030000oooooooo02Woool00ol0VOooooooo`1foooo001P
oooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool0:Oooo`03o`2Ioooooooo07Koool0
06Ooool00`0003?o03?o000A<ol000<0003oooooool0:Oooo`03o`2Ioooooooo07Koool006Ooool0
0`0003?o03?o000A<ol000<0003oooooool0:Oooo`03o`2Ioooooooo07Koool006Ooool200004C?o
00030000oooooooo02[oool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`0043?o00030000
oooooooo02[oool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`0043?o00030000oooooooo
02[oool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`0043?o00030000oooooooo02[oool0
0ol0VOooooooo`1foooo001Woooo00<0000co`0co`003c?o00030000oooooooo02_oool00ol0VOoo
ooooo`1foooo001Woooo00<0000co`0co`003c?o00030000oooooooo02_oool00ol0VOooooooo`1f
oooo001Woooo00<0000co`0co`003c?o00030000oooooooo02_oool00ol0VOooooooo`1foooo001W
oooo0P00010co`000`000?ooooooo`0[oooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`0/oooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`0/oooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000hco`000`000?oo
ooooo`0/oooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0/
oooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0]oooo00?o
09Woooooool0M_ooo`00Ioooo`80000><ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Koool0
06Ooool00`0003?o03?o000=<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Koool006Ooool0
0`0003?o03?o000=<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Koool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07Koool006Ooool00`0003?o03?o000<
<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07Koool006Ooool00`0003?o03?o000<<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo07Koool006Ooool200003C?o00030000oooooooo02koool0
0ol0VOooooooo`1foooo001Woooo00<0000co`0co`0033?o00030000oooooooo02koool00ol0VOoo
ooooo`1foooo001Woooo00<0000co`0co`0033?o00030000oooooooo02koool00ol0VOooooooo`1f
oooo001Woooo00<0000co`0co`002c?o00030000oooooooo02ooool00ol0VOooooooo`1foooo001P
oooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool0;oooo`03o`2Ioooooooo07Koool0
05ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0;oooo`03o`2I
oooooooo07Koool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`0_oooo00?o
09Woooooool0M_ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003ooooo
ool0;oooo`03o`2Ioooooooo07Koool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;
<ol000<0003oooooool0;oooo`03o`2Ioooooooo07Koool0063oool200001Oooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0`oooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0`oooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0`oooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0`
oooo00?o09Woooooool0M_ooo`00Ioooo`80000;<ol000<0003oooooool0<?ooo`03o`2Ioooooooo
07Koool006Ooool00`0003?o03?o000:<ol000<0003oooooool0<?ooo`03o`2Ioooooooo07Koool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Koool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Koool006Ooool00`0003?o
03?o0009<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Koool006Ooool00`0003?o03?o0009
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Koool006Ooool200002S?o00030000oooooooo
037oool00ol0VOooooooo`1foooo001Woooo00<0000co`0co`002C?o00030000oooooooo037oool0
0ol0VOooooooo`1foooo001Woooo00<0000co`0co`002C?o00030000oooooooo037oool00ol0VOoo
ooooo`1foooo001Woooo00<0000co`0co`0023?o00030000oooooooo03;oool00ol0VOooooooo`1f
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo03;oool00ol0VOooooooo`1foooo001W
oooo00<0000co`0co`0023?o00030000oooooooo03;oool00ol0VOooooooo`1foooo001Woooo0P00
00Tco`000`000?ooooooo`0boooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0boooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0boooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0c
oooo00?o09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0coooo00?o
09Woooooool0M_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0coooo00?o09Wooooo
ool0M_ooo`00Ioooo`800008<ol000<0003oooooool0<oooo`03o`2Ioooooooo07Koool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0<oooo`03o`2Ioooooooo07Koool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0<oooo`03o`2Ioooooooo07Koool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0<oooo`03o`2Ioooooooo07Koool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0<oooo`03o`2Ioooooooo07Koool0067oool300000oooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0coooo00?o09Woooooool0M_ooo`00H_ooo`030000oooooooo00;oool00`0003?o
03?o0007<ol000<0003oooooool0<oooo`03o`2Ioooooooo07Koool005ooool500000oooo`800008
<ol000<0003oooooool0<oooo`03o`2Ioooooooo07Koool005ooool010000?ooooooo`0000Coool:
<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool0
06Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00coool00`000?ooooooo`0Roooo00<0
003oooooool0O?ooo`00Ioooo`Tco`0;oooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001Woooo2C?o00_oool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0Noooo`00Ioooo`Tco`0;
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Ioooo`Tco`0:
oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`1joooo001Woooo2C?o00_oool00`000?ooooooo`0500003?oo
o`040000oooooooo00002Oooo`800004oooo00<0003oooooool0Noooo`00Ioooo`Tco`0;oooo00D0
003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo07_oool006Ooool9<ol03?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0
003oooooool0O?ooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59405 .12361 L
.59698 .12361 L
.59842 .12361 L
.59975 .12361 L
.60102 .12361 L
s
.60102 .12361 m
.60128 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.06747 .12361 L
.07286 .12361 L
.07547 .12361 L
.07793 .12361 L
.07901 .12361 L
.08015 .12361 L
.0814 .12326 L
.08255 .12237 L
.10458 .10715 L
.14241 .08775 L
.16182 .08051 L
.1827 .07441 L
.20384 .06973 L
.21356 .06802 L
.22393 .06647 L
.23431 .06518 L
.24373 .06422 L
.25267 .06347 L
.26212 .06285 L
.2669 .0626 L
.27214 .06236 L
.27697 .06219 L
.28137 .06205 L
.28656 .06194 L
.28942 .06189 L
.29213 .06185 L
.29335 .06184 L
.29463 .06183 L
.29575 .06182 L
.29695 .06181 L
.29823 .06181 L
.29944 .0618 L
.30014 .0618 L
.30087 .0618 L
.30219 .0618 L
.30342 .06181 L
.30412 .06181 L
.30476 .06181 L
.30594 .06182 L
.30719 .06183 L
.30935 .06185 L
.31173 .06187 L
.317 .06195 L
.32193 .06205 L
.33078 .0623 L
.34029 .06264 L
.34284 .06274 L
Mistroke
.34424 .06278 L
.34555 .06282 L
.34678 .06285 L
.34811 .06287 L
.34932 .06289 L
.35043 .0629 L
.35107 .0629 L
.35175 .0629 L
.35299 .06291 L
.35374 .0629 L
.35446 .0629 L
.3551 .0629 L
.3558 .06289 L
.35723 .06287 L
.35875 .06285 L
.36147 .06279 L
.36385 .06272 L
.3664 .06263 L
.37103 .06243 L
.38157 .0618 L
.39117 .06105 L
.40165 .06006 L
.42276 .05766 L
.46338 .052 L
.50247 .04592 L
.54402 .03937 L
.56487 .03624 L
.57401 .03492 L
.58406 .03352 L
.58873 .0329 L
.59374 .03224 L
.59616 .03193 L
.59847 .03164 L
.59947 .03151 L
.60053 .03138 L
.6017 .12361 L
.60278 .12361 L
.62258 .12361 L
.66029 .12361 L
.70047 .12361 L
.73912 .12361 L
.78023 .12361 L
.81982 .12361 L
.8579 .12361 L
.89843 .12361 L
.93744 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0koooo101VogOoool0
06Ooool00`000?ooooooo`0coooo201Vo`?oool00`1Vooooooooo`1eoooo001Woooo00<0003ooooo
ool0;_ooo`D0I_l;oooo00<0I_ooooooool0MOooo`00Ioooo`030000oooooooo02Woool506Ko4?oo
o`0306Kooooooooo07Goool006Ooool00`000?ooooooo`0Roooo1`1VoaGoool00`1Vooooooooo`1e
oooo001Woooo0P0001_oool806Ko7?ooo`0306Kooooooooo07Goool006Ooool00`000?ooooooo`0D
oooo1P1VobCoool00`1Vooooooooo`1eoooo001Woooo00<0003oooooool02oooo`T0I_lZoooo00<0
I_ooooooool0MOooo`00C_oooaT0I_l00`00001Vo`1Vo`0;06Ko<oooo`0306Kooooooooo07Goool0
04Koool806Ko6Oooo`030000oooooooo03koool00`1Vooooooooo`1eoooo0012oooo101Vob7oool0
0`000?ooooooo`0noooo00<0I_ooooooool0MOooo`00?Oooo`D0I_lUoooo0P0003ooool00`1Voooo
ooooo`1eoooo000Goooo1@0001coool206Ko0P00000406Kooooooooooooo0P0000Coool200007ooo
o`030000oooooooo01koool200001?ooo`800004oooo0P0001?oool00`1Vooooooooo`09oooo1@00
01goool500000_ooo`800004oooo0P00023oool400005_ooo`006Oooo`030000oooooooo01[oool2
06Ko00Goool0003oooooool000002?ooo`040000oooooooo00007_ooo`030000oooooooo01goool0
10000?ooooooo`0000Soool010000?ooooooo`0001;oool00`1Vooooooooo`0;oooo00<0003ooooo
ool07oooo`030000oooooooo00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0Goooo000I
oooo00<0003oooooool06?ooo`80I_l3oooo00@0003oooooool0000;oooo00<0003oooooool07?oo
o`030000oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0@oooo00<0I_oooooo
ool02oooo`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000
oooooooo01Koool0017oool400001?ooo`030000oooooooo01Koool00`1Vo`000000000200000_oo
o`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo00002Ooo
o`80000Coooo00<0I_ooooooool02oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P00
02;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool05?ooo`80I_l7oooo00@0003ooooo
ool00009oooo00<0003oooooool07_ooo`030000oooooooo01goool010000?ooooooo`0000Woool0
0`000?ooooooo`0Boooo00<0I_ooooooool02oooo`030000oooooooo01ooool00`000?ooooooo`08
oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Doooo0P1Vo`[oool2
00002_ooo`<0000Noooo0P0001ooool200002_ooo`<0000Boooo00<0I_ooooooool02_ooo`80000P
oooo0P0000[oool300008?ooo`80000Goooo000/oooo0P1VocWoool00`000?ooooooo`0ooooo00<0
I_ooooooool0M?ooo`00:oooo`0306Kooooooooo03Woool00`000?ooooooo`0ooooo00<0I_oooooo
ool0M?ooo`00:Oooo`80I_lloooo00<0003oooooool0?oooo`0306Kooooooooo07Coool002Soool0
0`1Vooooooooo`0loooo00<0003oooooool0?oooo`0306Kooooooooo07Coool002Koool206Ko?ooo
o`030000oooooooo03ooool00`1Vooooooooo`1doooo000@ooooo`00017oool001Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o0?l0V@05<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0c
o`005c?o0003o`2I<ol0<ol000Xco`0@00006Oooo`030000oooooooo02Koool00`000?ooooooo`0E
oooo001Woooo00<0000co`0co`00?c?o0003o`2I<ol0<ol000Dco`050000J_ooo`00Ioooo`030000
<ol0<ol003lco`000ol0VC?o03?o00050000Koooo`00Ioooo`030000<ol0<ol003dco`02000000?o
09T000000000M?ooo`00Ioooo`030000<ol0<ol003Tco`0400000_ooo`03o`2Ioooooooo07Coool0
06Ooool20000>3?o00800006oooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol003Dco`02
00002?ooo`03o`2Ioooooooo07Coool006Ooool00`0003?o03?o000c<ol00P0000[oool00ol0VOoo
ooooo`1doooo001Woooo00<0000co`0co`00<C?o0080000<oooo00?o09Woooooool0M?ooo`00Iooo
o`030000<ol0<ol0030co`000`000?ooooooo`0<oooo00?o09Woooooool0M?ooo`00Ioooo`030000
<ol0<ol002hco`0200003oooo`03o`2Ioooooooo07Coool006Ooool20000;C?o0080000Aoooo00?o
09Woooooool0M?ooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`0Aoooo00?o09Wooooo
ool0M?ooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`0Boooo00?o09Woooooool0M?oo
o`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`0Coooo00?o09Woooooool0M?ooo`00Iooo
o`030000<ol0<ol002Pco`000`000?ooooooo`0Doooo00?o09Woooooool0M?ooo`00Ioooo`030000
<ol0<ol002Pco`000`000?ooooooo`0Doooo00?o09Woooooool0M?ooo`00Ioooo`80000X<ol000<0
003oooooool05Oooo`03o`2Ioooooooo07Coool006Ooool00`0003?o03?o000V<ol000<0003ooooo
ool05_ooo`03o`2Ioooooooo07Coool006Ooool00`0003?o03?o000U<ol000<0003oooooool05ooo
o`03o`2Ioooooooo07Coool006Ooool00`0003?o03?o000T<ol000<0003oooooool06?ooo`03o`2I
oooooooo07Coool006Ooool00`0003?o03?o000S<ol000<0003oooooool06Oooo`03o`2Ioooooooo
07Coool006Ooool00`0003?o03?o000S<ol000<0003oooooool06Oooo`03o`2Ioooooooo07Coool0
06Ooool200008c?o00030000oooooooo01[oool00ol0VOooooooo`1doooo001Woooo00<0000co`0c
o`008C?o00030000oooooooo01_oool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`0083?o
00030000oooooooo01coool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`0083?o00030000
oooooooo01coool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`007c?o00030000oooooooo
01goool00ol0VOooooooo`1doooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003ooooo
ool07Oooo`03o`2Ioooooooo07Coool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o
00030000oooooooo01koool00ol0VOooooooo`1doooo001Qoooo00<0003oooooool00oooo`80000O
<ol000<0003oooooool07_ooo`03o`2Ioooooooo07Coool0067oool00`000?ooooooo`03oooo00<0
000co`0co`007C?o00030000oooooooo01ooool00ol0VOooooooo`1doooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0Ooooo00?o09Woooooool0M?ooo`00H?oo
o`800005oooo00<0000co`0co`0073?o00030000oooooooo023oool00ol0VOooooooo`1doooo001W
oooo00<0000co`0co`0073?o00030000oooooooo023oool00ol0VOooooooo`1doooo001Woooo00<0
000co`0co`006c?o00030000oooooooo027oool00ol0VOooooooo`1doooo001Woooo0P0001`co`00
0`000?ooooooo`0Qoooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0Roooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0R
oooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0Soooo00?o
09Woooooool0M?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0Soooo00?o09Wooooo
ool0M?ooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`0Toooo00?o09Woooooool0M?oo
o`00Ioooo`80000I<ol000<0003oooooool09?ooo`03o`2Ioooooooo07Coool006Ooool00`0003?o
03?o000G<ol000<0003oooooool09Oooo`03o`2Ioooooooo07Coool006Ooool00`0003?o03?o000G
<ol000<0003oooooool09Oooo`03o`2Ioooooooo07Coool006Ooool00`0003?o03?o000F<ol000<0
003oooooool09_ooo`03o`2Ioooooooo07Coool006Ooool00`0003?o03?o000F<ol000<0003ooooo
ool09_ooo`03o`2Ioooooooo07Coool006Ooool00`0003?o03?o000F<ol000<0003oooooool09_oo
o`03o`2Ioooooooo07Coool006Ooool00`0003?o03?o000E<ol000<0003oooooool09oooo`03o`2I
oooooooo07Coool006Ooool200005S?o00030000oooooooo02Ooool00ol0VOooooooo`1doooo001W
oooo00<0000co`0co`005C?o00030000oooooooo02Ooool00ol0VOooooooo`1doooo001Woooo00<0
000co`0co`005C?o00030000oooooooo02Ooool00ol0VOooooooo`1doooo001Woooo00<0000co`0c
o`0053?o00030000oooooooo02Soool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`0053?o
00030000oooooooo02Soool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`0053?o00030000
oooooooo02Soool00ol0VOooooooo`1doooo001Woooo0P0001Dco`000`000?ooooooo`0Xoooo00?o
09Woooooool0M?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0Yoooo00?o09Wooooo
ool0M?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0Yoooo00?o09Woooooool0M?oo
o`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0Yoooo00?o09Woooooool0M?ooo`00Gooo
o`@00004oooo00<0000co`0co`004c?o00030000oooooooo02Woool00ol0VOooooooo`1doooo001O
oooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`0Zoooo00?o09Wooooo
ool0M?ooo`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo02[oool00ol0VOoo
ooooo`1doooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`0Z
oooo00?o09Woooooool0M?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`00
0`000?ooooooo`0[oooo00?o09Woooooool0M?ooo`00H?ooo`800005oooo00<0000co`0co`004C?o
00030000oooooooo02_oool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`004C?o00030000
oooooooo02_oool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`004C?o00030000oooooooo
02_oool00ol0VOooooooo`1doooo001Woooo0P00014co`000`000?ooooooo`0/oooo00?o09Wooooo
ool0M?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0/oooo00?o09Woooooool0M?oo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0/oooo00?o09Woooooool0M?ooo`00Iooo
o`030000<ol0<ol0010co`000`000?ooooooo`0/oooo00?o09Woooooool0M?ooo`00Ioooo`030000
<ol0<ol000lco`000`000?ooooooo`0]oooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`0]oooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol000lco`00
0`000?ooooooo`0]oooo00?o09Woooooool0M?ooo`00Ioooo`80000@<ol000<0003oooooool0;Ooo
o`03o`2Ioooooooo07Coool006Ooool00`0003?o03?o000><ol000<0003oooooool0;_ooo`03o`2I
oooooooo07Coool006Ooool00`0003?o03?o000><ol000<0003oooooool0;_ooo`03o`2Ioooooooo
07Coool006Ooool00`0003?o03?o000><ol000<0003oooooool0;_ooo`03o`2Ioooooooo07Coool0
06Ooool00`0003?o03?o000><ol000<0003oooooool0;_ooo`03o`2Ioooooooo07Coool006Ooool0
0`0003?o03?o000=<ol000<0003oooooool0;oooo`03o`2Ioooooooo07Coool006Ooool200003S?o
00030000oooooooo02ooool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`003C?o00030000
oooooooo02ooool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`003C?o00030000oooooooo
02ooool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`0033?o00030000oooooooo033oool0
0ol0VOooooooo`1doooo001Woooo00<0000co`0co`0033?o00030000oooooooo033oool00ol0VOoo
ooooo`1doooo001Woooo00<0000co`0co`0033?o00030000oooooooo033oool00ol0VOooooooo`1d
oooo001Woooo0P0000dco`000`000?ooooooo`0`oooo00?o09Woooooool0M?ooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`0`oooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`0`oooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol000/co`00
0`000?ooooooo`0aoooo00?o09Woooooool0M?ooo`00H?ooo`800005oooo00<0000co`0co`002c?o
00030000oooooooo037oool00ol0VOooooooo`1doooo001Ooooo00@0003oooooool00004oooo00<0
000co`0co`002c?o00030000oooooooo037oool00ol0VOooooooo`1doooo001Qoooo00<0003ooooo
ool00oooo`80000<<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07Coool006;oool00`000?oo
ooooo`02oooo00<0000co`0co`002c?o00030000oooooooo037oool00ol0VOooooooo`1doooo001O
oooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo037oool00ol0VOoo
ooooo`1doooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0<_ooo`03o`2I
oooooooo07Coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0<_ooo`03o`2Ioooooooo
07Coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0<_ooo`03o`2Ioooooooo07Coool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool0<_ooo`03o`2Ioooooooo07Coool006Ooool2
00002c?o00030000oooooooo03;oool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`002S?o
00030000oooooooo03;oool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`002C?o00030000
oooooooo03?oool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`002C?o00030000oooooooo
03?oool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`002C?o00030000oooooooo03?oool0
0ol0VOooooooo`1doooo001Woooo00<0000co`0co`002C?o00030000oooooooo03?oool00ol0VOoo
ooooo`1doooo001Woooo0P0000Xco`000`000?ooooooo`0coooo00?o09Woooooool0M?ooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0coooo00?o09Woooooool0M?ooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`0coooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0doooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0doooo00?o09Woooooool0M?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0doooo00?o09Woooooool0M?ooo`00Ioooo`800009<ol000<0003oooooool0=?ooo`03o`2I
oooooooo07Coool006Ooool00`0003?o03?o0008<ol000<0003oooooool0=?ooo`03o`2Ioooooooo
07Coool006Ooool00`0003?o03?o0008<ol000<0003oooooool0=?ooo`03o`2Ioooooooo07Coool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0=Oooo`03o`2Ioooooooo07Coool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0=Oooo`03o`2Ioooooooo07Coool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0=Oooo`03o`2Ioooooooo07Coool006Ooool2000023?o00030000
oooooooo03Goool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`001c?o00030000oooooooo
03Goool00ol0VOooooooo`1doooo001Woooo00<0000co`0co`001c?o00030000oooooooo03Goool0
0ol0VOooooooo`1doooo001Woooo00<0000co`0co`001c?o00030000oooooooo03Goool00ol0VOoo
ooooo`1doooo001Woooo00<0000co`0co`001c?o00030000oooooooo03Goool00ol0VOooooooo`1d
oooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0=Oooo`03o`2Ioooooooo
07Coool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo03Goool0
0ol0VOooooooo`1doooo001Ooooo1@0000?oool2000023?o00030000oooooooo03Goool00ol0VOoo
ooooo`1doooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004
oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?oo
o`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?oo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Coool2
00000oooo`@00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00<0003oooooool01?ooo`030000oooooooo07Soool006Ooool9<ol01ooo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo07Ooool006Ooool9<ol02?ooo`030000
oooooooo00D0000<oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000003oooo`040000oooooooo
00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
06Ooool9<ol02Oooo`030000oooooooo017oool200002_ooo`800004oooo0P0000?oool00`000?oo
ooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59405 .12361 L
.59975 .12361 L
.60256 .12361 L
.60521 .12361 L
.60637 .12361 L
.60759 .12361 L
s
.60759 .12361 m
.60784 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.06747 .12361 L
.07024 .12361 L
.0716 .12361 L
.07286 .12361 L
.07404 .12361 L
.07529 .12307 L
.07655 .12211 L
.07793 .12105 L
.08255 .11764 L
.10458 .10334 L
.12562 .09236 L
.14487 .08427 L
.16497 .07754 L
.18364 .07263 L
.20262 .06879 L
.2133 .06708 L
.22335 .06572 L
.23321 .06462 L
.24387 .06366 L
.25356 .06298 L
.26248 .06251 L
.26718 .06231 L
.27221 .06213 L
.27697 .06201 L
.2813 .06192 L
.28394 .06188 L
.28638 .06185 L
.28777 .06183 L
.28907 .06182 L
.29042 .06181 L
.29113 .06181 L
.29191 .06181 L
.29314 .0618 L
.29444 .0618 L
.29564 .0618 L
.29675 .06181 L
.29807 .06181 L
.29927 .06182 L
.30066 .06183 L
.30197 .06184 L
.30436 .06186 L
.30659 .06189 L
.31169 .06197 L
.31665 .06208 L
.32198 .06222 L
.34043 .06292 L
.34296 .06303 L
Mistroke
.34534 .06311 L
.34666 .06315 L
.34808 .06318 L
.34937 .0632 L
.35056 .06322 L
.35125 .06323 L
.35189 .06323 L
.3526 .06324 L
.35335 .06324 L
.35414 .06324 L
.35489 .06324 L
.35556 .06324 L
.35629 .06323 L
.35693 .06323 L
.35763 .06322 L
.35905 .06321 L
.36037 .06318 L
.36161 .06316 L
.36407 .0631 L
.36666 .06302 L
.37129 .06283 L
.38171 .06225 L
.39128 .06153 L
.40149 .06061 L
.41987 .0586 L
.46142 .05299 L
.50145 .04683 L
.53997 .04076 L
.55949 .03776 L
.58094 .03464 L
.59078 .03328 L
.5962 .03256 L
.60134 .0319 L
.60365 .0316 L
.60611 .0313 L
.60739 .03114 L
.60812 .12361 L
.60881 .12361 L
.6113 .12361 L
.6204 .12361 L
.65905 .12361 L
.70016 .12361 L
.73975 .12361 L
.77783 .12361 L
.81836 .12361 L
.85737 .12361 L
.89884 .12361 L
.93879 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0koooo1P1VogGoool0
06Ooool00`000?ooooooo`0goooo101Vo`Goool00`1Vooooooooo`1coooo001Woooo00<0003ooooo
ool0;Oooo`X0I_l9oooo00<0I_ooooooool0Loooo`00Ioooo`030000oooooooo02Soool506Ko4ooo
o`0306Kooooooooo07?oool006Ooool00`000?ooooooo`0Qoooo1`1VoaSoool00`1Vooooooooo`1c
oooo001Woooo0P0001[oool806Ko7oooo`0306Kooooooooo07?oool006Ooool00`000?ooooooo`0D
oooo1@1VobOoool00`1Vooooooooo`1coooo001Woooo00<0003oooooool02oooo`T0I_l/oooo00<0
I_ooooooool0Loooo`00Booooa`0I_l00`00001Vo`1Vo`0;06Ko=Oooo`0306Kooooooooo07?oool0
04Koool506Ko7?ooo`030000oooooooo043oool00`1Vooooooooo`1coooo000noooo201Vob7oool0
0`000?ooooooo`10oooo00<0I_ooooooool0Loooo`00??ooo`80I_lYoooo0P00047oool00`1Voooo
ooooo`1coooo000Goooo1@0001coool206Ko0P0000Coool200001?ooo`80000Ooooo00<0003ooooo
ool07_ooo`800004oooo0P0000Coool200005?ooo`0306Kooooooooo00Soool500007Oooo`D00002
oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0003oooooool06?ooo`@0I_l01Oooo`00
0?ooooooo`000008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00004oooo`0306Kooooooooo00[oool00`000?ooooooo`0Ooooo00<0
003oooooool01oooo`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?oo
ooooo`0Foooo0P1Vo`Goool010000?ooooooo`0000_oool00`000?ooooooo`0Loooo00<0003ooooo
ool07Oooo`040000oooooooo00002oooo`030000oooooooo017oool00`1Vooooooooo`0:oooo00<0
003oooooool07oooo`030000oooooooo00[oool00`000?ooooooo`0Noooo00<0003oooooool05_oo
o`004Oooo`@00004oooo00<0003oooooool05?ooo`80I_l00oooo`000000000200000_ooo`040000
oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`80000D
oooo00<0I_ooooooool02_ooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool0
0`000?ooooooo`0Eoooo000Ioooo00<0003oooooool04_ooo`80I_l9oooo00@0003oooooool00009
oooo00<0003oooooool07_ooo`030000oooooooo01goool010000?ooooooo`0000Woool00`000?oo
ooooo`0Coooo00<0I_ooooooool02_ooo`030000oooooooo01ooool00`000?ooooooo`08oooo00<0
003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Boooo0P1Vo`coool200002_oo
o`<0000Noooo0P0001ooool200002_ooo`<0000Coooo00<0I_ooooooool02Oooo`80000Poooo0P00
00[oool300008?ooo`80000Goooo000[oooo00<0I_ooooooool0>Oooo`030000oooooooo043oool0
0`1Vooooooooo`1coooo000Yoooo0P1Voccoool00`000?ooooooo`10oooo00<0I_ooooooool0Looo
o`00:?ooo`0306Kooooooooo03coool00`000?ooooooo`10oooo00<0I_ooooooool0Loooo`009_oo
o`80I_looooo00<0003oooooool0@?ooo`0306Kooooooooo07?oool002Goool00`1Vooooooooo`0o
oooo00<0003oooooool0@?ooo`0306Kooooooooo07?oool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00040000<ol0<ol0o`2I13?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o00030000
<ol0<ol001Pco`000ol0VC?o03?o0009<ol0400001Woool00`000?ooooooo`0Voooo00<0003ooooo
ool05Oooo`00Ioooo`030000<ol0<ol0040co`000ol0VC?o03?o0004<ol01@0006[oool006Ooool0
0`0003?o03?o0010<ol000?o09Tco`000000100006ooool006Ooool00`0003?o03?o000m<ol00`00
0003o`2I0000oooo07?oool006Ooool00`0003?o03?o000i<ol0100000?oool00ol0VOooooooo`1c
oooo001Woooo0P0003Pco`0200001oooo`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o000e
<ol00P0000Woool00ol0VOooooooo`1coooo001Woooo00<0000co`0co`00<c?o0080000;oooo00?o
09Woooooool0Loooo`00Ioooo`030000<ol0<ol0034co`0200003Oooo`03o`2Ioooooooo07?oool0
06Ooool00`0003?o03?o000`<ol000<0003oooooool03Oooo`03o`2Ioooooooo07?oool006Ooool0
0`0003?o03?o000^<ol00P00013oool00ol0VOooooooo`1coooo001Woooo0P0002dco`0200004_oo
o`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o000[<ol000<0003oooooool04_ooo`03o`2I
oooooooo07?oool006Ooool00`0003?o03?o000Z<ol000<0003oooooool04oooo`03o`2Ioooooooo
07?oool006Ooool00`0003?o03?o000Y<ol000<0003oooooool05?ooo`03o`2Ioooooooo07?oool0
06Ooool00`0003?o03?o000X<ol000<0003oooooool05Oooo`03o`2Ioooooooo07?oool006Ooool0
0`0003?o03?o000X<ol000<0003oooooool05Oooo`03o`2Ioooooooo07?oool006Ooool20000:3?o
00030000oooooooo01Koool00ol0VOooooooo`1coooo001Woooo00<0000co`0co`009S?o00030000
oooooooo01Ooool00ol0VOooooooo`1coooo001Woooo00<0000co`0co`009C?o00030000oooooooo
01Soool00ol0VOooooooo`1coooo001Woooo00<0000co`0co`0093?o00030000oooooooo01Woool0
0ol0VOooooooo`1coooo001Woooo00<0000co`0co`008c?o00030000oooooooo01[oool00ol0VOoo
ooooo`1coooo001Woooo00<0000co`0co`008c?o00030000oooooooo01[oool00ol0VOooooooo`1c
oooo001Woooo0P0002<co`000`000?ooooooo`0Koooo00?o09Woooooool0Loooo`00Ioooo`030000
<ol0<ol0024co`000`000?ooooooo`0Loooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol0
020co`000`000?ooooooo`0Moooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol0020co`00
0`000?ooooooo`0Moooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol001lco`000`000?oo
ooooo`0Noooo00?o09Woooooool0Loooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo01koool00ol0VOooooooo`1coooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`0Ooooo00?o09Woooooool0Loooo`00HOooo`030000oooooooo00?oool2
00007c?o00030000oooooooo01ooool00ol0VOooooooo`1coooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`0Poooo00?o09Woooooool0Loooo`00HOooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool08?ooo`03o`2Ioooooooo07?oool0
063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`0Qoooo00?o09Woooooool0Looo
o`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`0Qoooo00?o09Woooooool0Loooo`00Iooo
o`030000<ol0<ol001/co`000`000?ooooooo`0Roooo00?o09Woooooool0Loooo`00Ioooo`80000L
<ol000<0003oooooool08_ooo`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o000J<ol000<0
003oooooool08oooo`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o000J<ol000<0003ooooo
ool08oooo`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o000I<ol000<0003oooooool09?oo
o`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o000I<ol000<0003oooooool09?ooo`03o`2I
oooooooo07?oool006Ooool00`0003?o03?o000H<ol000<0003oooooool09Oooo`03o`2Ioooooooo
07?oool006Ooool200006C?o00030000oooooooo02Goool00ol0VOooooooo`1coooo001Woooo00<0
000co`0co`005c?o00030000oooooooo02Koool00ol0VOooooooo`1coooo001Woooo00<0000co`0c
o`005c?o00030000oooooooo02Koool00ol0VOooooooo`1coooo001Woooo00<0000co`0co`005S?o
00030000oooooooo02Ooool00ol0VOooooooo`1coooo001Woooo00<0000co`0co`005S?o00030000
oooooooo02Ooool00ol0VOooooooo`1coooo001Woooo00<0000co`0co`005S?o00030000oooooooo
02Ooool00ol0VOooooooo`1coooo001Woooo00<0000co`0co`005C?o00030000oooooooo02Soool0
0ol0VOooooooo`1coooo001Woooo0P0001Hco`000`000?ooooooo`0Xoooo00?o09Woooooool0Looo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0Xoooo00?o09Woooooool0Loooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`0Xoooo00?o09Woooooool0Loooo`00Ioooo`030000
<ol0<ol001@co`000`000?ooooooo`0Yoooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`0Yoooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooooooo`0Yoooo00?o09Woooooool0Loooo`00Ioooo`80000E<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0:_ooo`03o`2I
oooooooo07?oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0:_ooo`03o`2Ioooooooo
07?oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0:_ooo`03o`2Ioooooooo07?oool0
05ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0Zoooo00?o09Woooooool0Looo
o`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0:oooo`03o`2I
oooooooo07?oool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`0[oooo00?o
09Woooooool0Loooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0:oooo`03o`2Ioooooooo07?oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0;?ooo`03o`2Ioooooooo07?oool0063oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`0/oooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol0014co`00
0`000?ooooooo`0/oooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol0014co`000`000?oo
ooooo`0/oooo00?o09Woooooool0Loooo`00Ioooo`80000A<ol000<0003oooooool0;Oooo`03o`2I
oooooooo07?oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0;Oooo`03o`2Ioooooooo
07?oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07?oool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07?oool006Ooool0
0`0003?o03?o000?<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07?oool006Ooool00`0003?o
03?o000?<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o000?
<ol000<0003oooooool0;_ooo`03o`2Ioooooooo07?oool006Ooool2000043?o00030000oooooooo
02koool00ol0VOooooooo`1coooo001Woooo00<0000co`0co`003S?o00030000oooooooo02ooool0
0ol0VOooooooo`1coooo001Woooo00<0000co`0co`003S?o00030000oooooooo02ooool00ol0VOoo
ooooo`1coooo001Woooo00<0000co`0co`003S?o00030000oooooooo02ooool00ol0VOooooooo`1c
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo02ooool00ol0VOooooooo`1coooo001W
oooo00<0000co`0co`003C?o00030000oooooooo033oool00ol0VOooooooo`1coooo001Woooo0P00
00hco`000`000?ooooooo`0`oooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`0`oooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`0`oooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0a
oooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0aoooo00?o
09Woooooool0Loooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0aoooo00?o09Wooooo
ool0Loooo`00Ioooo`80000=<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07?oool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07?oool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0<Oooo`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o000;
<ol000<0003oooooool0<_ooo`03o`2Ioooooooo07?oool0063oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`0boooo00?o09Woooooool0Loooo`00Goooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`0boooo00?o09Woooooool0Loooo`00HOooo`030000
oooooooo00?oool2000033?o00030000oooooooo03;oool00ol0VOooooooo`1coooo001Roooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`0boooo00?o09Woooooool0Looo
o`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0boooo00?o
09Woooooool0Loooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo03?oool0
0ol0VOooooooo`1coooo001Woooo00<0000co`0co`002S?o00030000oooooooo03?oool00ol0VOoo
ooooo`1coooo001Woooo00<0000co`0co`002S?o00030000oooooooo03?oool00ol0VOooooooo`1c
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo03?oool00ol0VOooooooo`1coooo001W
oooo0P0000/co`000`000?ooooooo`0coooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0coooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0doooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0doooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0d
oooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0doooo00?o
09Woooooool0Loooo`00Ioooo`80000:<ol000<0003oooooool0=?ooo`03o`2Ioooooooo07?oool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0=?ooo`03o`2Ioooooooo07?oool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0=?ooo`03o`2Ioooooooo07?oool006Ooool00`0003?o
03?o0008<ol000<0003oooooool0=Oooo`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0=Oooo`03o`2Ioooooooo07?oool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo07?oool006Ooool200002C?o00030000oooooooo03Goool0
0ol0VOooooooo`1coooo001Woooo00<0000co`0co`0023?o00030000oooooooo03Goool00ol0VOoo
ooooo`1coooo001Woooo00<0000co`0co`0023?o00030000oooooooo03Goool00ol0VOooooooo`1c
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo03Koool00ol0VOooooooo`1coooo001W
oooo00<0000co`0co`001c?o00030000oooooooo03Koool00ol0VOooooooo`1coooo001Woooo00<0
000co`0co`001c?o00030000oooooooo03Koool00ol0VOooooooo`1coooo001Woooo0P0000Pco`00
0`000?ooooooo`0foooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0foooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0f
oooo00?o09Woooooool0Loooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0foooo00?o
09Woooooool0Loooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0foooo00?o09Wooooo
ool0Loooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo03Koool00ol0VOoo
ooooo`1coooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`0f
oooo00?o09Woooooool0Loooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`0foooo00?o
09Woooooool0Loooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool0
00001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o
0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o
00Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9
<ol02?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800004
oooo0P0000Goool300000_ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?oo
o`040000oooooooo00001Oooo`050000oooooooooooo000007[oool006Ooool9<ol01oooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo1@0000?oool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003?oo
o`040000oooooooo00002Oooo`800003oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Ioooo`Tco`08oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool0
0`000?ooooooo`0Aoooo0P0000[oool200001Oooo`800002oooo00<0003oooooool0NOooo`00Iooo
o`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59975 .12361 L
.60479 .12361 L
.60756 .12361 L
.61016 .12361 L
.6126 .12361 L
.61327 .12361 L
.61397 .12361 L
s
.61397 .12361 m
.61448 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.0522 .12361 L
.06244 .12361 L
.06525 .12361 L
.06662 .12361 L
.0679 .12361 L
.06905 .12299 L
.07027 .12205 L
.07286 .1201 L
.08255 .1132 L
.10458 .09977 L
.14241 .08283 L
.16182 .07661 L
.1827 .07143 L
.20384 .06755 L
.21356 .06616 L
.22393 .06493 L
.23431 .06393 L
.24373 .06321 L
.2532 .06265 L
.26212 .06226 L
.26677 .06211 L
.27188 .06198 L
.27446 .06193 L
.27722 .06188 L
.27982 .06185 L
.28097 .06184 L
.2822 .06183 L
.28332 .06182 L
.28456 .06181 L
.28568 .06181 L
.28674 .0618 L
.28798 .0618 L
.28912 .0618 L
.29037 .06181 L
.29168 .06181 L
.29276 .06182 L
.29391 .06182 L
.29598 .06184 L
.29844 .06186 L
.30067 .06189 L
.30552 .06198 L
.31065 .06209 L
.31986 .06236 L
.32976 .06273 L
.34065 .06323 L
.34315 .06335 L
.34587 .06345 L
.34711 .06349 L
Mistroke
.34843 .06353 L
.34967 .06355 L
.35081 .06357 L
.35202 .06359 L
.35333 .0636 L
.35447 .06361 L
.35569 .06361 L
.35678 .06361 L
.35779 .0636 L
.35891 .06359 L
.3601 .06358 L
.3615 .06356 L
.36279 .06354 L
.36572 .06346 L
.3683 .06338 L
.37104 .06328 L
.38099 .06277 L
.39039 .06212 L
.4005 .06125 L
.4188 .05934 L
.45999 .05392 L
.49966 .04789 L
.53782 .04187 L
.55912 .03858 L
.57844 .03571 L
.5881 .03434 L
.59856 .03291 L
.60336 .03228 L
.60844 .03163 L
.61053 .03137 L
.61277 .03109 L
.61406 .03094 L
.61523 .12361 L
.61642 .12361 L
.61753 .12361 L
.65583 .12361 L
.69658 .12361 L
.73582 .12361 L
.77353 .12361 L
.81371 .12361 L
.85236 .12361 L
.89347 .12361 L
.93306 .12361 L
.97114 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0moooo1P1Vog?oool0
06Ooool00`000?ooooooo`0goooo1P1Vo`Goool00`1Vooooooooo`1aoooo001Woooo00<0003ooooo
ool0<_ooo`D0I_l;oooo00<0I_ooooooool0LOooo`00Ioooo`030000oooooooo02_oool706Ko4?oo
o`0306Kooooooooo077oool006Ooool00`000?ooooooo`0Soooo201VoaOoool00`1Vooooooooo`1a
oooo001Woooo0P0001ooool506Ko7oooo`0306Kooooooooo077oool006Ooool00`000?ooooooo`0F
oooo201VobCoool00`1Vooooooooo`1aoooo001Woooo00<0003oooooool03oooo`L0I_l/oooo00<0
I_ooooooool0LOooo`00Booooa`0I_l00`00001Vo`1Vo`0?06Ko<oooo`0306Kooooooooo077oool0
04;oool906Ko7?ooo`030000oooooooo04;oool00`1Vooooooooo`1aoooo000moooo1@1VobGoool0
0`000?ooooooo`12oooo00<0I_ooooooool0LOooo`00>?ooo`D0I_lZoooo0P0004?oool00`1Voooo
ooooo`1aoooo000Goooo1@0001[oool206Ko0_ooo`800004oooo0P0000Coool200007oooo`030000
oooooooo01koool200001?ooo`800004oooo0P0001Koool00`1Vooooooooo`06oooo1@0001goool5
00000_ooo`800004oooo0P00023oool400005_ooo`006Oooo`030000oooooooo01Ooool306Ko0ooo
o`040000oooooooo00002?ooo`040000oooooooo00007_ooo`030000oooooooo01goool010000?oo
ooooo`0000Soool010000?ooooooo`0001Goool00`1Vooooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool05Oooo`80I_l6oooo00@0003oooooool0000;oooo00<0003oooooool07?ooo`030000
oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0Coooo00<0I_ooooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01?oool206Ko0_ooo`@00002oooo00@0003ooooo
ool00009oooo0P0001ooool00`000?ooooooo`0Moooo00@0003oooooool00009oooo0P0001Koool0
0`1Vooooooooo`08oooo00<0003oooooool07oooo`030000oooooooo00Soool200008_ooo`030000
oooooooo01Goool001Woool00`000?ooooooo`0Aoooo0P1Vo`[oool010000?ooooooo`0000Woool0
0`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo
01Goool00`1Vooooooooo`08oooo00<0003oooooool07oooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00017oool206Ko3Oooo`80000:oooo0`00
01koool200007oooo`80000:oooo0`0001Goool00`1Vooooooooo`07oooo0P00023oool200002_oo
o`<0000Poooo0P0001Ooool002Woool206Ko??ooo`030000oooooooo04;oool00`1Vooooooooo`1a
oooo000Xoooo00<0I_ooooooool0??ooo`030000oooooooo04;oool00`1Vooooooooo`1aoooo000V
oooo0P1Vocooool00`000?ooooooo`12oooo00<0I_ooooooool0LOooo`009Oooo`0306Kooooooooo
03ooool00`000?ooooooo`12oooo00<0I_ooooooool0LOooo`009?ooo`0306Kooooooooo043oool0
0`000?ooooooo`12oooo00<0I_ooooooool0LOooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`000S?o0004o`2I
<ol0<ol000001c?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0c
o`006S?o0003o`2I<ol0<ol000Lco`0@00006Oooo`030000oooooooo02Koool00`000?ooooooo`0E
oooo001Woooo00<0000co`0co`00@S?o0003o`2I<ol0<ol0008co`050000J_ooo`00Ioooo`030000
<ol0<ol0048co`000ol0V@00000000020000Koooo`00Ioooo`030000<ol0<ol003dco`05000000?o
09Woooooool0LOooo`00Ioooo`030000<ol0<ol003Tco`0400001Oooo`03o`2Ioooooooo077oool0
06Ooool20000>3?o00800009oooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol003Dco`02
00002oooo`03o`2Ioooooooo077oool006Ooool00`0003?o03?o000c<ol00P0000goool00ol0VOoo
ooooo`1aoooo001Woooo00<0000co`0co`00<C?o0080000?oooo00?o09Woooooool0LOooo`00Iooo
o`030000<ol0<ol0030co`000`000?ooooooo`0?oooo00?o09Woooooool0LOooo`00Ioooo`030000
<ol0<ol002hco`0200004_ooo`03o`2Ioooooooo077oool006Ooool20000;C?o0080000Doooo00?o
09Woooooool0LOooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`0Doooo00?o09Wooooo
ool0LOooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0LOoo
o`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`0Foooo00?o09Woooooool0LOooo`00Iooo
o`030000<ol0<ol002Pco`000`000?ooooooo`0Goooo00?o09Woooooool0LOooo`00Ioooo`030000
<ol0<ol002Pco`000`000?ooooooo`0Goooo00?o09Woooooool0LOooo`00Ioooo`80000X<ol000<0
003oooooool06?ooo`03o`2Ioooooooo077oool006Ooool00`0003?o03?o000V<ol000<0003ooooo
ool06Oooo`03o`2Ioooooooo077oool006Ooool00`0003?o03?o000U<ol000<0003oooooool06_oo
o`03o`2Ioooooooo077oool006Ooool00`0003?o03?o000T<ol000<0003oooooool06oooo`03o`2I
oooooooo077oool006Ooool00`0003?o03?o000S<ol000<0003oooooool07?ooo`03o`2Ioooooooo
077oool006Ooool00`0003?o03?o000S<ol000<0003oooooool07?ooo`03o`2Ioooooooo077oool0
06Ooool200008c?o00030000oooooooo01goool00ol0VOooooooo`1aoooo001Woooo00<0000co`0c
o`008C?o00030000oooooooo01koool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`0083?o
00030000oooooooo01ooool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`0083?o00030000
oooooooo01ooool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`007c?o00030000oooooooo
023oool00ol0VOooooooo`1aoooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003ooooo
ool08?ooo`03o`2Ioooooooo077oool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o
00030000oooooooo027oool00ol0VOooooooo`1aoooo001Qoooo00<0003oooooool00oooo`80000O
<ol000<0003oooooool08Oooo`03o`2Ioooooooo077oool0067oool00`000?ooooooo`03oooo00<0
000co`0co`007C?o00030000oooooooo02;oool00ol0VOooooooo`1aoooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0Roooo00?o09Woooooool0LOooo`00H?oo
o`800005oooo00<0000co`0co`0073?o00030000oooooooo02?oool00ol0VOooooooo`1aoooo001W
oooo00<0000co`0co`0073?o00030000oooooooo02?oool00ol0VOooooooo`1aoooo001Woooo00<0
000co`0co`006c?o00030000oooooooo02Coool00ol0VOooooooo`1aoooo001Woooo0P0001`co`00
0`000?ooooooo`0Toooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0Uoooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0U
oooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0Voooo00?o
09Woooooool0LOooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0Voooo00?o09Wooooo
ool0LOooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`0Woooo00?o09Woooooool0LOoo
o`00Ioooo`80000I<ol000<0003oooooool09oooo`03o`2Ioooooooo077oool006Ooool00`0003?o
03?o000G<ol000<0003oooooool0:?ooo`03o`2Ioooooooo077oool006Ooool00`0003?o03?o000G
<ol000<0003oooooool0:?ooo`03o`2Ioooooooo077oool006Ooool00`0003?o03?o000F<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo077oool006Ooool00`0003?o03?o000F<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo077oool006Ooool00`0003?o03?o000F<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo077oool006Ooool00`0003?o03?o000E<ol000<0003oooooool0:_ooo`03o`2I
oooooooo077oool006Ooool200005S?o00030000oooooooo02[oool00ol0VOooooooo`1aoooo001W
oooo00<0000co`0co`005C?o00030000oooooooo02[oool00ol0VOooooooo`1aoooo001Woooo00<0
000co`0co`005C?o00030000oooooooo02[oool00ol0VOooooooo`1aoooo001Woooo00<0000co`0c
o`0053?o00030000oooooooo02_oool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`0053?o
00030000oooooooo02_oool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`0053?o00030000
oooooooo02_oool00ol0VOooooooo`1aoooo001Woooo0P0001Dco`000`000?ooooooo`0[oooo00?o
09Woooooool0LOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0/oooo00?o09Wooooo
ool0LOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0/oooo00?o09Woooooool0LOoo
o`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0/oooo00?o09Woooooool0LOooo`00Gooo
o`@00004oooo00<0000co`0co`004c?o00030000oooooooo02coool00ol0VOooooooo`1aoooo001O
oooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`0]oooo00?o09Wooooo
ool0LOooo`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo02goool00ol0VOoo
ooooo`1aoooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`0]
oooo00?o09Woooooool0LOooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`00
0`000?ooooooo`0^oooo00?o09Woooooool0LOooo`00H?ooo`800005oooo00<0000co`0co`004C?o
00030000oooooooo02koool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`004C?o00030000
oooooooo02koool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`004C?o00030000oooooooo
02koool00ol0VOooooooo`1aoooo001Woooo0P00014co`000`000?ooooooo`0_oooo00?o09Wooooo
ool0LOooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0_oooo00?o09Woooooool0LOoo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0_oooo00?o09Woooooool0LOooo`00Iooo
o`030000<ol0<ol0010co`000`000?ooooooo`0_oooo00?o09Woooooool0LOooo`00Ioooo`030000
<ol0<ol000lco`000`000?ooooooo`0`oooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`0`oooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol000lco`00
0`000?ooooooo`0`oooo00?o09Woooooool0LOooo`00Ioooo`80000@<ol000<0003oooooool0<?oo
o`03o`2Ioooooooo077oool006Ooool00`0003?o03?o000><ol000<0003oooooool0<Oooo`03o`2I
oooooooo077oool006Ooool00`0003?o03?o000><ol000<0003oooooool0<Oooo`03o`2Ioooooooo
077oool006Ooool00`0003?o03?o000><ol000<0003oooooool0<Oooo`03o`2Ioooooooo077oool0
06Ooool00`0003?o03?o000><ol000<0003oooooool0<Oooo`03o`2Ioooooooo077oool006Ooool0
0`0003?o03?o000=<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool006Ooool200003S?o
00030000oooooooo03;oool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`003C?o00030000
oooooooo03;oool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`003C?o00030000oooooooo
03;oool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`0033?o00030000oooooooo03?oool0
0ol0VOooooooo`1aoooo001Woooo00<0000co`0co`0033?o00030000oooooooo03?oool00ol0VOoo
ooooo`1aoooo001Woooo00<0000co`0co`0033?o00030000oooooooo03?oool00ol0VOooooooo`1a
oooo001Woooo0P0000dco`000`000?ooooooo`0coooo00?o09Woooooool0LOooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`0coooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`0coooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol000/co`00
0`000?ooooooo`0doooo00?o09Woooooool0LOooo`00H?ooo`800005oooo00<0000co`0co`002c?o
00030000oooooooo03Coool00ol0VOooooooo`1aoooo001Ooooo00@0003oooooool00004oooo00<0
000co`0co`002c?o00030000oooooooo03Coool00ol0VOooooooo`1aoooo001Qoooo00<0003ooooo
ool00oooo`80000<<ol000<0003oooooool0=?ooo`03o`2Ioooooooo077oool006;oool00`000?oo
ooooo`02oooo00<0000co`0co`002c?o00030000oooooooo03Coool00ol0VOooooooo`1aoooo001O
oooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo03Coool00ol0VOoo
ooooo`1aoooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0=Oooo`03o`2I
oooooooo077oool006Ooool00`0003?o03?o000:<ol000<0003oooooool0=Oooo`03o`2Ioooooooo
077oool006Ooool00`0003?o03?o000:<ol000<0003oooooool0=Oooo`03o`2Ioooooooo077oool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool0=Oooo`03o`2Ioooooooo077oool006Ooool2
00002c?o00030000oooooooo03Goool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`002S?o
00030000oooooooo03Goool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`002C?o00030000
oooooooo03Koool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`002C?o00030000oooooooo
03Koool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`002C?o00030000oooooooo03Koool0
0ol0VOooooooo`1aoooo001Woooo00<0000co`0co`002C?o00030000oooooooo03Koool00ol0VOoo
ooooo`1aoooo001Woooo0P0000Xco`000`000?ooooooo`0foooo00?o09Woooooool0LOooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0foooo00?o09Woooooool0LOooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`0foooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0goooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0goooo00?o09Woooooool0LOooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0goooo00?o09Woooooool0LOooo`00Ioooo`800009<ol000<0003oooooool0=oooo`03o`2I
oooooooo077oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0=oooo`03o`2Ioooooooo
077oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0=oooo`03o`2Ioooooooo077oool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0>?ooo`03o`2Ioooooooo077oool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0>?ooo`03o`2Ioooooooo077oool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0>?ooo`03o`2Ioooooooo077oool006Ooool2000023?o00030000
oooooooo03Soool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`001c?o00030000oooooooo
03Soool00ol0VOooooooo`1aoooo001Woooo00<0000co`0co`001c?o00030000oooooooo03Soool0
0ol0VOooooooo`1aoooo001Woooo00<0000co`0co`001c?o00030000oooooooo03Soool00ol0VOoo
ooooo`1aoooo001Woooo00<0000co`0co`001c?o00030000oooooooo03Soool00ol0VOooooooo`1a
oooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0>?ooo`03o`2Ioooooooo
077oool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo03Soool0
0ol0VOooooooo`1aoooo001Ooooo1@0000?oool2000023?o00030000oooooooo03Soool00ol0VOoo
ooooo`1aoooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004
oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?oo
o`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?oo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Coool2
00000oooo`<00004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`07
oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001Woooo2C?o00Soool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002Oooo`800003oooo0`0000Coool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool006Ooool9
<ol02Oooo`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1i
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61445 .12361 L
.61726 .12361 L
.61849 .12361 L
.61914 .12361 L
.61984 .12361 L
s
.61984 .12361 m
.62036 .61803 L
s
0 .4 1 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.05546 .12361 L
.05789 .12361 L
.06007 .12361 L
.06131 .12361 L
.06244 .12319 L
.06371 .12221 L
.06487 .12133 L
.06747 .11939 L
.07218 .11599 L
.0829 .1088 L
.10458 .09642 L
.12517 .08701 L
.14429 .08002 L
.16395 .07433 L
.18248 .07017 L
.203 .06673 L
.22161 .06451 L
.23137 .06365 L
.24169 .06293 L
.2505 .06247 L
.25513 .06228 L
.26016 .06212 L
.2654 .06198 L
.26781 .06193 L
.27037 .06189 L
.27266 .06186 L
.27388 .06184 L
.2752 .06183 L
.2764 .06182 L
.27751 .06182 L
.27856 .06181 L
.27967 .06181 L
.28098 .0618 L
.28217 .0618 L
.28283 .0618 L
.28355 .0618 L
.28485 .06181 L
.28606 .06181 L
.28735 .06182 L
.28966 .06184 L
.29235 .06187 L
.29486 .0619 L
.30059 .062 L
.30557 .06212 L
.31099 .06228 L
Mistroke
.32087 .06263 L
.33941 .0635 L
.34197 .06364 L
.34474 .06377 L
.34735 .06386 L
.34975 .06393 L
.35193 .06397 L
.35316 .06399 L
.35431 .064 L
.35553 .06401 L
.35664 .06401 L
.35791 .06401 L
.35912 .064 L
.36033 .06399 L
.36101 .06399 L
.36166 .06398 L
.36435 .06393 L
.36668 .06388 L
.36918 .0638 L
.37488 .06358 L
.38011 .06332 L
.38994 .06268 L
.39907 .06194 L
.41978 .05985 L
.45888 .0548 L
.50043 .04855 L
.54047 .04225 L
.57898 .03638 L
.59851 .03362 L
.60885 .03224 L
.61455 .03151 L
.61736 .03116 L
.61859 .03101 L
.61925 .03093 L
.61996 .03084 L
.62123 .12361 L
.62243 .12361 L
.62506 .12361 L
.63062 .12361 L
.64035 .12361 L
.65941 .12361 L
.70052 .12361 L
.74011 .12361 L
.77819 .12361 L
.81871 .12361 L
.85773 .12361 L
.89919 .12361 L
.93914 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`10oooo101Vog;oool0
06Ooool00`000?ooooooo`0goooo2@1Vo`?oool00`1Vooooooooo`1`oooo001Woooo00<0003ooooo
ool0<_ooo`D0I_l<oooo00<0I_ooooooool0L?ooo`00Ioooo`030000oooooooo02_oool706Ko4Ooo
o`0306Kooooooooo073oool006Ooool00`000?ooooooo`0Soooo201VoaSoool00`1Vooooooooo`1`
oooo001Woooo0P0001ooool506Ko8?ooo`0306Kooooooooo073oool006Ooool00`000?ooooooo`0G
oooo1`1VobGoool00`1Vooooooooo`1`oooo001Woooo00<0003oooooool03oooo`P0I_l/oooo00<0
I_ooooooool0L?ooo`00Aoooob00I_l00`00001Vo`1Vo`0?06Ko=?ooo`0306Kooooooooo073oool0
04;oool506Ko8?ooo`030000oooooooo04?oool00`1Vooooooooo`1`oooo000moooo1@1VobGoool0
0`000?ooooooo`13oooo00<0I_ooooooool0L?ooo`00>?ooo`D0I_lZoooo0P0004Coool00`1Voooo
ooooo`1`oooo000Goooo1@0001Soool406Ko0_ooo`800004oooo0P0000Coool200007oooo`030000
oooooooo01koool200001?ooo`800004oooo0P0001Soool00`1Vooooooooo`04oooo1@0001goool5
00000_ooo`800004oooo0P00023oool400005_ooo`006Oooo`030000oooooooo01Koool206Ko1Ooo
o`040000oooooooo00002?ooo`040000oooooooo00007_ooo`030000oooooooo01goool010000?oo
ooooo`0000Soool010000?ooooooo`0001Ooool00`1Vooooooooo`06oooo00<0003oooooool07ooo
o`030000oooooooo00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool05?ooo`80I_l7oooo00@0003oooooool0000;oooo00<0003oooooool07?ooo`030000
oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0Eoooo00<0I_ooooooool01_oo
o`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01;oool206Ko0oooo`@00002oooo00@0003ooooo
ool00009oooo0P0001ooool00`000?ooooooo`0Moooo00@0003oooooool00009oooo0P0001Soool0
0`1Vooooooooo`06oooo00<0003oooooool07oooo`030000oooooooo00Soool200008_ooo`030000
oooooooo01Goool001Woool00`000?ooooooo`0@oooo0P1Vo`_oool010000?ooooooo`0000Woool0
0`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo
01Ooool00`1Vooooooooo`06oooo00<0003oooooool07oooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00017oool00`1Vooooooooo`0<oooo0P00
00[oool300007_ooo`80000Ooooo0P0000[oool300005oooo`0306Kooooooooo00Goool200008?oo
o`80000:oooo0`00023oool200005oooo`00:Oooo`80I_lloooo00<0003oooooool0A?ooo`0306Ko
oooooooo06ooool002Ooool206Ko?_ooo`030000oooooooo04Coool00`1Vooooooooo`1_oooo000T
oooo0`1Vod3oool00`000?ooooooo`14oooo00<0I_ooooooool0Koooo`008_ooo`80I_m3oooo00<0
003oooooool0A?ooo`0306Kooooooooo06ooool0027oool00`1Vooooooooo`13oooo00<0003ooooo
ool0A?ooo`0306Kooooooooo06ooool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000<co`000ol0VC?o00000007
<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000K<ol000?o
09Tco`0co`001S?o0100000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool006Ooool0
0`0003?o03?o0013<ol000Co09Tco`0co`0co`050000J_ooo`00Ioooo`030000<ol0<ol0048co`00
0`000?l0V@0000020000Koooo`00Ioooo`030000<ol0<ol003dco`05000000?ooooo09Woool0LOoo
o`00Ioooo`030000<ol0<ol003Tco`0400001_ooo`03o`2Ioooooooo073oool006Ooool20000>3?o
0080000:oooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol003Dco`0200003?ooo`03o`2I
oooooooo073oool006Ooool00`0003?o03?o000c<ol00P0000koool00ol0VOooooooo`1`oooo001W
oooo00<0000co`0co`00<C?o0080000@oooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol0
030co`000`000?ooooooo`0@oooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol002hco`02
00004oooo`03o`2Ioooooooo073oool006Ooool20000;C?o0080000Eoooo00?o09Woooooool0L?oo
o`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`0Eoooo00?o09Woooooool0L?ooo`00Iooo
o`030000<ol0<ol002Xco`000`000?ooooooo`0Foooo00?o09Woooooool0L?ooo`00Ioooo`030000
<ol0<ol002Tco`000`000?ooooooo`0Goooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol0
02Pco`000`000?ooooooo`0Hoooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol002Pco`00
0`000?ooooooo`0Hoooo00?o09Woooooool0L?ooo`00Ioooo`80000X<ol000<0003oooooool06Ooo
o`03o`2Ioooooooo073oool006Ooool00`0003?o03?o000V<ol000<0003oooooool06_ooo`03o`2I
oooooooo073oool006Ooool00`0003?o03?o000U<ol000<0003oooooool06oooo`03o`2Ioooooooo
073oool006Ooool00`0003?o03?o000T<ol000<0003oooooool07?ooo`03o`2Ioooooooo073oool0
06Ooool00`0003?o03?o000S<ol000<0003oooooool07Oooo`03o`2Ioooooooo073oool006Ooool0
0`0003?o03?o000S<ol000<0003oooooool07Oooo`03o`2Ioooooooo073oool006Ooool200008c?o
00030000oooooooo01koool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`008C?o00030000
oooooooo01ooool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`0083?o00030000oooooooo
023oool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`0083?o00030000oooooooo023oool0
0ol0VOooooooo`1`oooo001Woooo00<0000co`0co`007c?o00030000oooooooo027oool00ol0VOoo
ooooo`1`oooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003oooooool08Oooo`03o`2I
oooooooo073oool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o00030000oooooooo
02;oool00ol0VOooooooo`1`oooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0003ooooo
ool08_ooo`03o`2Ioooooooo073oool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o
00030000oooooooo02?oool00ol0VOooooooo`1`oooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001dco`000`000?ooooooo`0Soooo00?o09Woooooool0L?ooo`00H?ooo`800005oooo00<0
000co`0co`0073?o00030000oooooooo02Coool00ol0VOooooooo`1`oooo001Woooo00<0000co`0c
o`0073?o00030000oooooooo02Coool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`006c?o
00030000oooooooo02Goool00ol0VOooooooo`1`oooo001Woooo0P0001`co`000`000?ooooooo`0U
oooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0Voooo00?o
09Woooooool0L?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0Voooo00?o09Wooooo
ool0L?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0Woooo00?o09Woooooool0L?oo
o`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0Woooo00?o09Woooooool0L?ooo`00Iooo
o`030000<ol0<ol001Pco`000`000?ooooooo`0Xoooo00?o09Woooooool0L?ooo`00Ioooo`80000I
<ol000<0003oooooool0:?ooo`03o`2Ioooooooo073oool006Ooool00`0003?o03?o000G<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo073oool006Ooool00`0003?o03?o000G<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo073oool006Ooool00`0003?o03?o000F<ol000<0003oooooool0:_oo
o`03o`2Ioooooooo073oool006Ooool00`0003?o03?o000F<ol000<0003oooooool0:_ooo`03o`2I
oooooooo073oool006Ooool00`0003?o03?o000F<ol000<0003oooooool0:_ooo`03o`2Ioooooooo
073oool006Ooool00`0003?o03?o000E<ol000<0003oooooool0:oooo`03o`2Ioooooooo073oool0
06Ooool200005S?o00030000oooooooo02_oool00ol0VOooooooo`1`oooo001Woooo00<0000co`0c
o`005C?o00030000oooooooo02_oool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`005C?o
00030000oooooooo02_oool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`0053?o00030000
oooooooo02coool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`0053?o00030000oooooooo
02coool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`0053?o00030000oooooooo02coool0
0ol0VOooooooo`1`oooo001Woooo0P0001Dco`000`000?ooooooo`0/oooo00?o09Woooooool0L?oo
o`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0]oooo00?o09Woooooool0L?ooo`00Iooo
o`030000<ol0<ol001<co`000`000?ooooooo`0]oooo00?o09Woooooool0L?ooo`00Ioooo`030000
<ol0<ol001<co`000`000?ooooooo`0]oooo00?o09Woooooool0L?ooo`00Goooo`@00004oooo00<0
000co`0co`004c?o00030000oooooooo02goool00ol0VOooooooo`1`oooo001Ooooo00<0003ooooo
ool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`0^oooo00?o09Woooooool0L?ooo`00H?oo
o`030000oooooooo00Coool200004c?o00030000oooooooo02koool00ol0VOooooooo`1`oooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`0^oooo00?o09Wooooo
ool0L?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`000`000?ooooooo`0_
oooo00?o09Woooooool0L?ooo`00H?ooo`800005oooo00<0000co`0co`004C?o00030000oooooooo
02ooool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`004C?o00030000oooooooo02ooool0
0ol0VOooooooo`1`oooo001Woooo00<0000co`0co`004C?o00030000oooooooo02ooool00ol0VOoo
ooooo`1`oooo001Woooo0P00014co`000`000?ooooooo`0`oooo00?o09Woooooool0L?ooo`00Iooo
o`030000<ol0<ol0010co`000`000?ooooooo`0`oooo00?o09Woooooool0L?ooo`00Ioooo`030000
<ol0<ol0010co`000`000?ooooooo`0`oooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol0
010co`000`000?ooooooo`0`oooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol000lco`00
0`000?ooooooo`0aoooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol000lco`000`000?oo
ooooo`0aoooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`0a
oooo00?o09Woooooool0L?ooo`00Ioooo`80000@<ol000<0003oooooool0<Oooo`03o`2Ioooooooo
073oool006Ooool00`0003?o03?o000><ol000<0003oooooool0<_ooo`03o`2Ioooooooo073oool0
06Ooool00`0003?o03?o000><ol000<0003oooooool0<_ooo`03o`2Ioooooooo073oool006Ooool0
0`0003?o03?o000><ol000<0003oooooool0<_ooo`03o`2Ioooooooo073oool006Ooool00`0003?o
03?o000><ol000<0003oooooool0<_ooo`03o`2Ioooooooo073oool006Ooool00`0003?o03?o000=
<ol000<0003oooooool0<oooo`03o`2Ioooooooo073oool006Ooool200003S?o00030000oooooooo
03?oool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`003C?o00030000oooooooo03?oool0
0ol0VOooooooo`1`oooo001Woooo00<0000co`0co`003C?o00030000oooooooo03?oool00ol0VOoo
ooooo`1`oooo001Woooo00<0000co`0co`0033?o00030000oooooooo03Coool00ol0VOooooooo`1`
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo03Coool00ol0VOooooooo`1`oooo001W
oooo00<0000co`0co`0033?o00030000oooooooo03Coool00ol0VOooooooo`1`oooo001Woooo0P00
00dco`000`000?ooooooo`0doooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`0doooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`0doooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol000/co`000`000?ooooooo`0e
oooo00?o09Woooooool0L?ooo`00H?ooo`800005oooo00<0000co`0co`002c?o00030000oooooooo
03Goool00ol0VOooooooo`1`oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o
00030000oooooooo03Goool00ol0VOooooooo`1`oooo001Qoooo00<0003oooooool00oooo`80000<
<ol000<0003oooooool0=Oooo`03o`2Ioooooooo073oool006;oool00`000?ooooooo`02oooo00<0
000co`0co`002c?o00030000oooooooo03Goool00ol0VOooooooo`1`oooo001Ooooo00@0003ooooo
ool00004oooo00<0000co`0co`002c?o00030000oooooooo03Goool00ol0VOooooooo`1`oooo001P
oooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0=_ooo`03o`2Ioooooooo073oool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool0=_ooo`03o`2Ioooooooo073oool006Ooool0
0`0003?o03?o000:<ol000<0003oooooool0=_ooo`03o`2Ioooooooo073oool006Ooool00`0003?o
03?o000:<ol000<0003oooooool0=_ooo`03o`2Ioooooooo073oool006Ooool200002c?o00030000
oooooooo03Koool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`002S?o00030000oooooooo
03Koool00ol0VOooooooo`1`oooo001Woooo00<0000co`0co`002C?o00030000oooooooo03Ooool0
0ol0VOooooooo`1`oooo001Woooo00<0000co`0co`002C?o00030000oooooooo03Ooool00ol0VOoo
ooooo`1`oooo001Woooo00<0000co`0co`002C?o00030000oooooooo03Ooool00ol0VOooooooo`1`
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo03Ooool00ol0VOooooooo`1`oooo001W
oooo0P0000Xco`000`000?ooooooo`0goooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0goooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0goooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0hoooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0h
oooo00?o09Woooooool0L?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0hoooo00?o
09Woooooool0L?ooo`00Ioooo`800009<ol000<0003oooooool0>?ooo`03o`2Ioooooooo073oool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool0>?ooo`03o`2Ioooooooo073oool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0>?ooo`03o`2Ioooooooo073oool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0>Oooo`03o`2Ioooooooo073oool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0>Oooo`03o`2Ioooooooo073oool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo073oool006Ooool2000023?o00030000oooooooo03Woool0
0ol0VOooooooo`1`oooo001Woooo00<0000co`0co`001c?o00030000oooooooo03Woool00ol0VOoo
ooooo`1`oooo001Woooo00<0000co`0co`001c?o00030000oooooooo03Woool00ol0VOooooooo`1`
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo03Woool00ol0VOooooooo`1`oooo001W
oooo00<0000co`0co`001c?o00030000oooooooo03Woool00ol0VOooooooo`1`oooo001Qoooo0`00
00?oool00`0003?o03?o0007<ol000<0003oooooool0>Oooo`03o`2Ioooooooo073oool006;oool0
0`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo03Woool00ol0VOooooooo`1`
oooo001Ooooo1@0000?oool2000023?o00030000oooooooo03Woool00ol0VOooooooo`1`oooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Coool200001?ooo`800004
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`07oooo00<0003ooooo
ool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool0
10000?ooooooo`0000Coool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`05
00003?ooo`040000oooooooo00002Oooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0
003oooooool04Oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Woool006Ooool9
<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61445 .12361 L
.61984 .12361 L
.62236 .12361 L
.62502 .12361 L
.6257 .12361 L
.62642 .12361 L
s
.62642 .12361 m
.62673 .61803 L
s
0 .4 1 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.0503 .12361 L
.05288 .12361 L
.05405 .12361 L
.05528 .12361 L
.05593 .12332 L
.05664 .12277 L
.05789 .12181 L
.06244 .11841 L
.08274 .10498 L
.10458 .09329 L
.12384 .08502 L
.14487 .07785 L
.166 .07231 L
.18609 .06836 L
.20576 .06555 L
.21676 .06437 L
.22674 .06351 L
.23676 .06285 L
.24598 .06239 L
.25081 .06221 L
.25611 .06205 L
.25878 .06199 L
.26164 .06193 L
.26409 .06189 L
.2668 .06185 L
.26937 .06183 L
.27077 .06182 L
.27209 .06181 L
.27332 .06181 L
.27444 .0618 L
.27568 .0618 L
.27698 .0618 L
.27767 .06181 L
.2783 .06181 L
.27971 .06181 L
.28103 .06182 L
.28226 .06183 L
.28504 .06186 L
.28804 .06189 L
.29313 .06198 L
.29851 .0621 L
.30816 .06239 L
.3176 .06275 L
.32774 .06322 L
.33724 .06373 L
.34187 .064 L
Mistroke
.34605 .0642 L
.34858 .06429 L
.35096 .06435 L
.35227 .06438 L
.35347 .0644 L
.35479 .06442 L
.35545 .06442 L
.35618 .06443 L
.35693 .06443 L
.35763 .06444 L
.35894 .06444 L
.35968 .06443 L
.36036 .06443 L
.36111 .06443 L
.3619 .06442 L
.36321 .0644 L
.36443 .06438 L
.36723 .06433 L
.36969 .06426 L
.37228 .06418 L
.37691 .06399 L
.38733 .0634 L
.3969 .06269 L
.40711 .06179 L
.42549 .05984 L
.46704 .05437 L
.50707 .04831 L
.54559 .04226 L
.58656 .03604 L
.60696 .03318 L
.61692 .03187 L
.62165 .03128 L
.62372 .03102 L
.62491 .03088 L
.62602 .03074 L
.62707 .12361 L
.6282 .12361 L
.63052 .12361 L
.63541 .12361 L
.64432 .12361 L
.66396 .12361 L
.70507 .12361 L
.74466 .12361 L
.78273 .12361 L
.82326 .12361 L
.86227 .12361 L
.90374 .12361 L
.94369 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`0noooo201Vog3oool0
06Ooool00`000?ooooooo`0ioooo1@1Vo`Ooool00`1Vooooooooo`1^oooo001Woooo00<0003ooooo
ool0=?ooo`D0I_l<oooo00<0I_ooooooool0K_ooo`00Ioooo`030000oooooooo02goool706Ko4Ooo
o`0306Kooooooooo06koool006Ooool00`000?ooooooo`0Uoooo201VoaSoool00`1Vooooooooo`1^
oooo001Woooo0P00027oool506Ko8?ooo`0306Kooooooooo06koool006Ooool00`000?ooooooo`0H
oooo201VobGoool00`1Vooooooooo`1^oooo001Woooo00<0003oooooool04?ooo`P0I_l]oooo00<0
I_ooooooool0K_ooo`00A_ooob40I_l00`00001Vo`1Vo`0@06Ko=Oooo`0306Kooooooooo06koool0
03goool906Ko8Oooo`030000oooooooo04Goool00`1Vooooooooo`1^oooo000ioooo101Vob[oool0
0`000?ooooooo`15oooo00<0I_ooooooool0K_ooo`00=oooo`80I_l^oooo0P0004Koool00`1Voooo
ooooo`1^oooo000Goooo1@0001Soool306Ko0oooo`800004oooo0P0000Coool200007oooo`030000
oooooooo01koool200001?ooo`800004oooo0P0001Woool00`1Vooooooooo`03oooo1@0001goool5
00000_ooo`800004oooo0P00023oool400005_ooo`006Oooo`030000oooooooo01Koool206Ko1Ooo
o`040000oooooooo00002?ooo`040000oooooooo00007_ooo`030000oooooooo01goool010000?oo
ooooo`0000Soool010000?ooooooo`0001Soool00`1Vooooooooo`05oooo00<0003oooooool07ooo
o`030000oooooooo00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool04oooo`<0I_l7oooo00@0003oooooool0000;oooo00<0003oooooool07?ooo`030000
oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0Foooo00<0I_ooooooool01Ooo
o`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo017oool206Ko1?ooo`@00002oooo00@0003ooooo
ool00009oooo0P0001ooool00`000?ooooooo`0Moooo00@0003oooooool00009oooo0P0001Woool0
0`1Vooooooooo`05oooo00<0003oooooool07oooo`030000oooooooo00Soool200008_ooo`030000
oooooooo01Goool001Woool00`000?ooooooo`0?oooo0P1Vo`coool010000?ooooooo`0000Woool0
0`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo
01Soool00`1Vooooooooo`05oooo00<0003oooooool07oooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P0000ooool206Ko3oooo`80000:oooo0`00
01koool200007oooo`80000:oooo0`0001Soool00`1Vooooooooo`04oooo0P00023oool200002_oo
o`<0000Poooo0P0001Ooool002Ooool206Ko?_ooo`030000oooooooo04Goool00`1Vooooooooo`1^
oooo000Uoooo0P1Vod3oool00`000?ooooooo`15oooo00<0I_ooooooool0K_ooo`008oooo`80I_m2
oooo00<0003oooooool0AOooo`0306Kooooooooo06koool0027oool206KoA?ooo`030000oooooooo
04Goool00`1Vooooooooo`1^oooo000Poooo00<0I_ooooooool0A?ooo`030000oooooooo04Goool0
0`1Vooooooooo`1^oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`007C?o0003o`2I<ol0<ol0
00@co`0@00006Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0c
o`00AC?o0003o`2I<ol0000000@0001Zoooo001Woooo00<0000co`0co`00@S?o00<000000ol0V@00
0?ooo`1^oooo001Woooo00<0000co`0co`00?C?o00D00003oooo00?o09Woooooool0K_ooo`00Iooo
o`030000<ol0<ol003Tco`0400002?ooo`03o`2Ioooooooo06koool006Ooool20000>3?o0080000<
oooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol003Dco`0200003_ooo`03o`2Ioooooooo
06koool006Ooool00`0003?o03?o000c<ol00P00013oool00ol0VOooooooo`1^oooo001Woooo00<0
000co`0co`00<C?o0080000Boooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol0030co`00
0`000?ooooooo`0Boooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol002hco`0200005Ooo
o`03o`2Ioooooooo06koool006Ooool20000;C?o0080000Goooo00?o09Woooooool0K_ooo`00Iooo
o`030000<ol0<ol002/co`000`000?ooooooo`0Goooo00?o09Woooooool0K_ooo`00Ioooo`030000
<ol0<ol002Xco`000`000?ooooooo`0Hoooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol0
02Tco`000`000?ooooooo`0Ioooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol002Pco`00
0`000?ooooooo`0Joooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol002Pco`000`000?oo
ooooo`0Joooo00?o09Woooooool0K_ooo`00Ioooo`80000X<ol000<0003oooooool06oooo`03o`2I
oooooooo06koool006Ooool00`0003?o03?o000V<ol000<0003oooooool07?ooo`03o`2Ioooooooo
06koool006Ooool00`0003?o03?o000U<ol000<0003oooooool07Oooo`03o`2Ioooooooo06koool0
06Ooool00`0003?o03?o000T<ol000<0003oooooool07_ooo`03o`2Ioooooooo06koool006Ooool0
0`0003?o03?o000S<ol000<0003oooooool07oooo`03o`2Ioooooooo06koool006Ooool00`0003?o
03?o000S<ol000<0003oooooool07oooo`03o`2Ioooooooo06koool006Ooool200008c?o00030000
oooooooo023oool00ol0VOooooooo`1^oooo001Woooo00<0000co`0co`008C?o00030000oooooooo
027oool00ol0VOooooooo`1^oooo001Woooo00<0000co`0co`0083?o00030000oooooooo02;oool0
0ol0VOooooooo`1^oooo001Woooo00<0000co`0co`0083?o00030000oooooooo02;oool00ol0VOoo
ooooo`1^oooo001Woooo00<0000co`0co`007c?o00030000oooooooo02?oool00ol0VOooooooo`1^
oooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003oooooool08oooo`03o`2Ioooooooo
06koool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o00030000oooooooo02Coool0
0ol0VOooooooo`1^oooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0003oooooool09?oo
o`03o`2Ioooooooo06koool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000
oooooooo02Goool00ol0VOooooooo`1^oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`000`000?ooooooo`0Uoooo00?o09Woooooool0K_ooo`00H?ooo`800005oooo00<0000co`0c
o`0073?o00030000oooooooo02Koool00ol0VOooooooo`1^oooo001Woooo00<0000co`0co`0073?o
00030000oooooooo02Koool00ol0VOooooooo`1^oooo001Woooo00<0000co`0co`006c?o00030000
oooooooo02Ooool00ol0VOooooooo`1^oooo001Woooo0P0001`co`000`000?ooooooo`0Woooo00?o
09Woooooool0K_ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0K_ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0Xoooo00?o09Woooooool0K_oo
o`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0Yoooo00?o09Woooooool0K_ooo`00Iooo
o`030000<ol0<ol001Tco`000`000?ooooooo`0Yoooo00?o09Woooooool0K_ooo`00Ioooo`030000
<ol0<ol001Pco`000`000?ooooooo`0Zoooo00?o09Woooooool0K_ooo`00Ioooo`80000I<ol000<0
003oooooool0:_ooo`03o`2Ioooooooo06koool006Ooool00`0003?o03?o000G<ol000<0003ooooo
ool0:oooo`03o`2Ioooooooo06koool006Ooool00`0003?o03?o000G<ol000<0003oooooool0:ooo
o`03o`2Ioooooooo06koool006Ooool00`0003?o03?o000F<ol000<0003oooooool0;?ooo`03o`2I
oooooooo06koool006Ooool00`0003?o03?o000F<ol000<0003oooooool0;?ooo`03o`2Ioooooooo
06koool006Ooool00`0003?o03?o000F<ol000<0003oooooool0;?ooo`03o`2Ioooooooo06koool0
06Ooool00`0003?o03?o000E<ol000<0003oooooool0;Oooo`03o`2Ioooooooo06koool006Ooool2
00005S?o00030000oooooooo02goool00ol0VOooooooo`1^oooo001Woooo00<0000co`0co`005C?o
00030000oooooooo02goool00ol0VOooooooo`1^oooo001Woooo00<0000co`0co`005C?o00030000
oooooooo02goool00ol0VOooooooo`1^oooo001Woooo00<0000co`0co`0053?o00030000oooooooo
02koool00ol0VOooooooo`1^oooo001Woooo00<0000co`0co`0053?o00030000oooooooo02koool0
0ol0VOooooooo`1^oooo001Woooo00<0000co`0co`0053?o00030000oooooooo02koool00ol0VOoo
ooooo`1^oooo001Woooo0P0001Dco`000`000?ooooooo`0^oooo00?o09Woooooool0K_ooo`00Iooo
o`030000<ol0<ol001<co`000`000?ooooooo`0_oooo00?o09Woooooool0K_ooo`00Ioooo`030000
<ol0<ol001<co`000`000?ooooooo`0_oooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol0
01<co`000`000?ooooooo`0_oooo00?o09Woooooool0K_ooo`00Goooo`@00004oooo00<0000co`0c
o`004c?o00030000oooooooo02ooool00ol0VOooooooo`1^oooo001Ooooo00<0003oooooool01Ooo
o`030000<ol0<ol0018co`000`000?ooooooo`0`oooo00?o09Woooooool0K_ooo`00H?ooo`030000
oooooooo00Coool200004c?o00030000oooooooo033oool00ol0VOooooooo`1^oooo001Qoooo00<0
003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`0`oooo00?o09Woooooool0K_oo
o`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`000`000?ooooooo`0aoooo00?o
09Woooooool0K_ooo`00H?ooo`800005oooo00<0000co`0co`004C?o00030000oooooooo037oool0
0ol0VOooooooo`1^oooo001Woooo00<0000co`0co`004C?o00030000oooooooo037oool00ol0VOoo
ooooo`1^oooo001Woooo00<0000co`0co`004C?o00030000oooooooo037oool00ol0VOooooooo`1^
oooo001Woooo0P00014co`000`000?ooooooo`0boooo00?o09Woooooool0K_ooo`00Ioooo`030000
<ol0<ol0010co`000`000?ooooooo`0boooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol0
010co`000`000?ooooooo`0boooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol0010co`00
0`000?ooooooo`0boooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000lco`000`000?oo
ooooo`0coooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`0c
oooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`0coooo00?o
09Woooooool0K_ooo`00Ioooo`80000@<ol000<0003oooooool0<oooo`03o`2Ioooooooo06koool0
06Ooool00`0003?o03?o000><ol000<0003oooooool0=?ooo`03o`2Ioooooooo06koool006Ooool0
0`0003?o03?o000><ol000<0003oooooool0=?ooo`03o`2Ioooooooo06koool006Ooool00`0003?o
03?o000><ol000<0003oooooool0=?ooo`03o`2Ioooooooo06koool006Ooool00`0003?o03?o000>
<ol000<0003oooooool0=?ooo`03o`2Ioooooooo06koool006Ooool00`0003?o03?o000=<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo06koool006Ooool200003S?o00030000oooooooo03Goool0
0ol0VOooooooo`1^oooo001Woooo00<0000co`0co`003C?o00030000oooooooo03Goool00ol0VOoo
ooooo`1^oooo001Woooo00<0000co`0co`003C?o00030000oooooooo03Goool00ol0VOooooooo`1^
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo03Koool00ol0VOooooooo`1^oooo001W
oooo00<0000co`0co`0033?o00030000oooooooo03Koool00ol0VOooooooo`1^oooo001Woooo00<0
000co`0co`0033?o00030000oooooooo03Koool00ol0VOooooooo`1^oooo001Woooo0P0000dco`00
0`000?ooooooo`0foooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`0foooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0f
oooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000/co`000`000?ooooooo`0goooo00?o
09Woooooool0K_ooo`00H?ooo`800005oooo00<0000co`0co`002c?o00030000oooooooo03Ooool0
0ol0VOooooooo`1^oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000
oooooooo03Ooool00ol0VOooooooo`1^oooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0
003oooooool0=oooo`03o`2Ioooooooo06koool006;oool00`000?ooooooo`02oooo00<0000co`0c
o`002c?o00030000oooooooo03Ooool00ol0VOooooooo`1^oooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`002c?o00030000oooooooo03Ooool00ol0VOooooooo`1^oooo001Poooo0P00
00Goool00`0003?o03?o000:<ol000<0003oooooool0>?ooo`03o`2Ioooooooo06koool006Ooool0
0`0003?o03?o000:<ol000<0003oooooool0>?ooo`03o`2Ioooooooo06koool006Ooool00`0003?o
03?o000:<ol000<0003oooooool0>?ooo`03o`2Ioooooooo06koool006Ooool00`0003?o03?o000:
<ol000<0003oooooool0>?ooo`03o`2Ioooooooo06koool006Ooool200002c?o00030000oooooooo
03Soool00ol0VOooooooo`1^oooo001Woooo00<0000co`0co`002S?o00030000oooooooo03Soool0
0ol0VOooooooo`1^oooo001Woooo00<0000co`0co`002C?o00030000oooooooo03Woool00ol0VOoo
ooooo`1^oooo001Woooo00<0000co`0co`002C?o00030000oooooooo03Woool00ol0VOooooooo`1^
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo03Woool00ol0VOooooooo`1^oooo001W
oooo00<0000co`0co`002C?o00030000oooooooo03Woool00ol0VOooooooo`1^oooo001Woooo0P00
00Xco`000`000?ooooooo`0ioooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0ioooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0ioooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0j
oooo00?o09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0joooo00?o
09Woooooool0K_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`0joooo00?o09Wooooo
ool0K_ooo`00Ioooo`800009<ol000<0003oooooool0>_ooo`03o`2Ioooooooo06koool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0>_ooo`03o`2Ioooooooo06koool006Ooool00`0003?o
03?o0008<ol000<0003oooooool0>_ooo`03o`2Ioooooooo06koool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0>oooo`03o`2Ioooooooo06koool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0>oooo`03o`2Ioooooooo06koool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0>oooo`03o`2Ioooooooo06koool006Ooool2000023?o00030000oooooooo03_oool00ol0VOoo
ooooo`1^oooo001Woooo00<0000co`0co`001c?o00030000oooooooo03_oool00ol0VOooooooo`1^
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo03_oool00ol0VOooooooo`1^oooo001W
oooo00<0000co`0co`001c?o00030000oooooooo03_oool00ol0VOooooooo`1^oooo001Woooo00<0
000co`0co`001c?o00030000oooooooo03_oool00ol0VOooooooo`1^oooo001Qoooo0`0000?oool0
0`0003?o03?o0007<ol000<0003oooooool0>oooo`03o`2Ioooooooo06koool006;oool00`000?oo
ooooo`02oooo00<0000co`0co`001c?o00030000oooooooo03_oool00ol0VOooooooo`1^oooo001O
oooo1@0000?oool2000023?o00030000oooooooo03_oool00ol0VOooooooo`1^oooo001Ooooo00@0
003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool2
00001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`0<oooo00<0
003oooooool08_ooo`030000oooooooo07coool006Ooool9<ol02oooo`030000oooooooo00Soool0
0`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Ioooo`Tco`0;oooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool300001?ooo`030000oooooooo
07_oool006Ooool9<ol02oooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1k
oooo001Woooo2C?o00[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00002Oooo`<00004oooo00<0003oooooool0N_ooo`00Ioooo`Tco`0;oooo00<0003oooooool01@00
00coool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001W
oooo2C?o00_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0Noooo`00Ioooo`Tco`0<oooo00<0003oooooool04Oooo`80000:
oooo0`0000;oool00`000?ooooooo`1loooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.92) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61984 .12361 L
.6254 .12361 L
.62812 .12361 L
.63064 .12361 L
.63182 .12361 L
.63292 .12361 L
s
.63292 .12361 m
.63338 .61803 L
s
0 .4 1 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04517 .12361 L
.04758 .12361 L
.04822 .12361 L
.04891 .12361 L
.04966 .12325 L
.05035 .12272 L
.05288 .12079 L
.06244 .11392 L
.0842 .1005 L
.10458 .09037 L
.12398 .08262 L
.14241 .07671 L
.16266 .07164 L
.18119 .06812 L
.19077 .06666 L
.20099 .06536 L
.21938 .06359 L
.22967 .06289 L
.23508 .0626 L
.24079 .06235 L
.2458 .06217 L
.2513 .06201 L
.25371 .06196 L
.2563 .06191 L
.25851 .06188 L
.26096 .06185 L
.26352 .06182 L
.26493 .06182 L
.26625 .06181 L
.26747 .06181 L
.2686 .0618 L
.26983 .0618 L
.27114 .06181 L
.27183 .06181 L
.27246 .06181 L
.27387 .06182 L
.27518 .06182 L
.27642 .06183 L
.27919 .06186 L
.2822 .0619 L
.28729 .06199 L
.29267 .06212 L
.30232 .06241 L
.3219 .06325 L
.34021 .06428 L
.34519 .06457 L
.34801 .06468 L
Mistroke
.35062 .06477 L
.35191 .0648 L
.35313 .06483 L
.35424 .06485 L
.3554 .06486 L
.35668 .06488 L
.35785 .06489 L
.35911 .06489 L
.35983 .06489 L
.3605 .06489 L
.36165 .06488 L
.36291 .06487 L
.36409 .06486 L
.36518 .06485 L
.36725 .06481 L
.36945 .06476 L
.37401 .06462 L
.37903 .06441 L
.38915 .06383 L
.39842 .06315 L
.41929 .06118 L
.45897 .05626 L
.49713 .05066 L
.53774 .04432 L
.57684 .03827 L
.59679 .03534 L
.60729 .03386 L
.61839 .03237 L
.62318 .03176 L
.62832 .03111 L
.62983 .03092 L
.63127 .03075 L
.63256 .03059 L
.63329 .03051 L
.63396 .12361 L
.63517 .12361 L
.63651 .12361 L
.63923 .12361 L
.65842 .12361 L
.69859 .12361 L
.73725 .12361 L
.77836 .12361 L
.81795 .12361 L
.85602 .12361 L
.89655 .12361 L
.93556 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.92) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`12oooo1P1Vofkoool0
06Ooool00`000?ooooooo`0loooo1P1Vo`Goool00`1Vooooooooo`1/oooo001Woooo00<0003ooooo
ool0=?ooo`P0I_l;oooo00<0I_ooooooool0K?ooo`00Ioooo`030000oooooooo02goool706Ko4ooo
o`0306Kooooooooo06coool006Ooool00`000?ooooooo`0Woooo1P1Voa[oool00`1Vooooooooo`1/
oooo001Woooo0P00027oool706Ko8?ooo`0306Kooooooooo06coool006Ooool00`000?ooooooo`0I
oooo1`1VobOoool00`1Vooooooooo`1/oooo001Woooo00<0003oooooool05?ooo`D0I_l^oooo00<0
I_ooooooool0K?ooo`00A_ooob40I_l01000001Vo`1Vo`1Vo`;ooolA06Ko<oooo`0306Kooooooooo
06coool003coool:06Ko8Oooo`030000oooooooo00@0I_m3oooo00<0I_ooooooool0K?ooo`00>?oo
o`@0I_l[oooo00<0003oooooool0Aoooo`0306Kooooooooo06coool003Koool206Ko;oooo`800018
oooo00<0I_ooooooool0K?ooo`005oooo`D0000Goooo0`1Vo`Coool200001?ooo`800004oooo0P00
01ooool00`000?ooooooo`0Noooo0P0000Coool200001?ooo`80000Koooo00@0I_ooooooooooool5
00007Oooo`D00002oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0003oooooool04ooo
o`@0I_l6oooo00@0003oooooool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Ooo
o`040000oooooooo00002?ooo`040000oooooooo00006_ooo`0306Kooooooooo00?oool00`000?oo
ooooo`0Ooooo00<0003oooooool01oooo`040000oooooooo00007oooo`030000oooooooo01Ooool0
01Woool00`000?ooooooo`0Aoooo0P1Vo`[oool010000?ooooooo`0000_oool00`000?ooooooo`0L
oooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo01Soool00`1Voooo
ooooo`03oooo00<0003oooooool07oooo`030000oooooooo00[oool00`000?ooooooo`0Noooo00<0
003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool03oooo`80I_l6oooo100000;oool0
10000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool2
00006oooo`0306Kooooooooo00?oool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`80000R
oooo00<0003oooooool05Oooo`006Oooo`030000oooooooo00goool206Ko3_ooo`040000oooooooo
00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0
003oooooool06_ooo`0306Kooooooooo00?oool00`000?ooooooo`0Ooooo00<0003oooooool02?oo
o`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200003Oooo`80I_lAoooo0P00
00[oool300007_ooo`80000Ooooo0P0000[oool300006_ooo`0306Kooooooooo00;oool200008?oo
o`80000:oooo0`00023oool200005oooo`009_ooo`0306Kooooooooo03koool00`000?ooooooo`17
oooo00<0I_ooooooool0K?ooo`009?ooo`80I_m1oooo00<0003oooooool0Aoooo`0306Kooooooooo
06coool002;oool206Ko@oooo`030000oooooooo04Ooool00`1Vooooooooo`1/oooo000Poooo0P1V
odGoool00`000?ooooooo`17oooo00<0I_ooooooool0K?ooo`007oooo`0306Kooooooooo04Goool0
0`000?ooooooo`17oooo00<0I_ooooooool0K?ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0o`2I00Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o02P00002oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o00030000<ol0<ol0
01lco`000ol0VC?o03?o0002<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00Ioooo`030000<ol0<ol004Lco`000ol0V@00000000020000J_ooo`00Ioooo`030000<ol0<ol0
048co`05000000?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol003dco`0500001Oooo`03o`2I
oooooooo06coool006Ooool00`0003?o03?o000i<ol0100000[oool00ol0VOooooooo`1/oooo001W
oooo0P0003Pco`0200003_ooo`03o`2Ioooooooo06coool006Ooool00`0003?o03?o000e<ol00P00
013oool00ol0VOooooooo`1/oooo001Woooo00<0000co`0co`00<c?o0080000Boooo00?o09Wooooo
ool0K?ooo`00Ioooo`030000<ol0<ol0034co`0200005?ooo`03o`2Ioooooooo06coool006Ooool0
0`0003?o03?o000`<ol000<0003oooooool05?ooo`03o`2Ioooooooo06coool006Ooool00`0003?o
03?o000^<ol00P0001Ooool00ol0VOooooooo`1/oooo001Woooo0P0002dco`0200006Oooo`03o`2I
oooooooo06coool006Ooool00`0003?o03?o000[<ol000<0003oooooool06Oooo`03o`2Ioooooooo
06coool006Ooool00`0003?o03?o000Z<ol000<0003oooooool06_ooo`03o`2Ioooooooo06coool0
06Ooool00`0003?o03?o000Y<ol000<0003oooooool06oooo`03o`2Ioooooooo06coool006Ooool0
0`0003?o03?o000X<ol000<0003oooooool07?ooo`03o`2Ioooooooo06coool006Ooool00`0003?o
03?o000X<ol000<0003oooooool07?ooo`03o`2Ioooooooo06coool006Ooool20000:3?o00030000
oooooooo01goool00ol0VOooooooo`1/oooo001Woooo00<0000co`0co`009S?o00030000oooooooo
01koool00ol0VOooooooo`1/oooo001Woooo00<0000co`0co`009C?o00030000oooooooo01ooool0
0ol0VOooooooo`1/oooo001Woooo00<0000co`0co`0093?o00030000oooooooo023oool00ol0VOoo
ooooo`1/oooo001Woooo00<0000co`0co`008c?o00030000oooooooo027oool00ol0VOooooooo`1/
oooo001Woooo00<0000co`0co`008c?o00030000oooooooo027oool00ol0VOooooooo`1/oooo001W
oooo0P0002<co`000`000?ooooooo`0Roooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol0
024co`000`000?ooooooo`0Soooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol0020co`00
0`000?ooooooo`0Toooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol0020co`000`000?oo
ooooo`0Toooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`0U
oooo00?o09Woooooool0K?ooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo
02Goool00ol0VOooooooo`1/oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`00
0`000?ooooooo`0Voooo00?o09Woooooool0K?ooo`00HOooo`030000oooooooo00?oool200007c?o
00030000oooooooo02Koool00ol0VOooooooo`1/oooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001dco`000`000?ooooooo`0Woooo00?o09Woooooool0K?ooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003oooooool09oooo`03o`2Ioooooooo06coool0063oool2
00001Oooo`030000<ol0<ol001`co`000`000?ooooooo`0Xoooo00?o09Woooooool0K?ooo`00Iooo
o`030000<ol0<ol001`co`000`000?ooooooo`0Xoooo00?o09Woooooool0K?ooo`00Ioooo`030000
<ol0<ol001/co`000`000?ooooooo`0Yoooo00?o09Woooooool0K?ooo`00Ioooo`80000L<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo06coool006Ooool00`0003?o03?o000J<ol000<0003ooooo
ool0:_ooo`03o`2Ioooooooo06coool006Ooool00`0003?o03?o000J<ol000<0003oooooool0:_oo
o`03o`2Ioooooooo06coool006Ooool00`0003?o03?o000I<ol000<0003oooooool0:oooo`03o`2I
oooooooo06coool006Ooool00`0003?o03?o000I<ol000<0003oooooool0:oooo`03o`2Ioooooooo
06coool006Ooool00`0003?o03?o000H<ol000<0003oooooool0;?ooo`03o`2Ioooooooo06coool0
06Ooool200006C?o00030000oooooooo02coool00ol0VOooooooo`1/oooo001Woooo00<0000co`0c
o`005c?o00030000oooooooo02goool00ol0VOooooooo`1/oooo001Woooo00<0000co`0co`005c?o
00030000oooooooo02goool00ol0VOooooooo`1/oooo001Woooo00<0000co`0co`005S?o00030000
oooooooo02koool00ol0VOooooooo`1/oooo001Woooo00<0000co`0co`005S?o00030000oooooooo
02koool00ol0VOooooooo`1/oooo001Woooo00<0000co`0co`005S?o00030000oooooooo02koool0
0ol0VOooooooo`1/oooo001Woooo00<0000co`0co`005C?o00030000oooooooo02ooool00ol0VOoo
ooooo`1/oooo001Woooo0P0001Hco`000`000?ooooooo`0_oooo00?o09Woooooool0K?ooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`0_oooo00?o09Woooooool0K?ooo`00Ioooo`030000
<ol0<ol001Dco`000`000?ooooooo`0_oooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`0`oooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooooooo`0`oooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol001@co`000`000?oo
ooooo`0`oooo00?o09Woooooool0K?ooo`00Ioooo`80000E<ol000<0003oooooool0<?ooo`03o`2I
oooooooo06coool006Ooool00`0003?o03?o000C<ol000<0003oooooool0<Oooo`03o`2Ioooooooo
06coool006Ooool00`0003?o03?o000C<ol000<0003oooooool0<Oooo`03o`2Ioooooooo06coool0
06Ooool00`0003?o03?o000C<ol000<0003oooooool0<Oooo`03o`2Ioooooooo06coool005ooool4
00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0aoooo00?o09Woooooool0K?ooo`00Gooo
o`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0<_ooo`03o`2Ioooooooo
06coool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`0boooo00?o09Wooooo
ool0K?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0<_oo
o`03o`2Ioooooooo06coool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0
003oooooool0<oooo`03o`2Ioooooooo06coool0063oool200001Oooo`030000<ol0<ol0014co`00
0`000?ooooooo`0coooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol0014co`000`000?oo
ooooo`0coooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`0c
oooo00?o09Woooooool0K?ooo`00Ioooo`80000A<ol000<0003oooooool0=?ooo`03o`2Ioooooooo
06coool006Ooool00`0003?o03?o000@<ol000<0003oooooool0=?ooo`03o`2Ioooooooo06coool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool0=?ooo`03o`2Ioooooooo06coool006Ooool0
0`0003?o03?o000@<ol000<0003oooooool0=?ooo`03o`2Ioooooooo06coool006Ooool00`0003?o
03?o000?<ol000<0003oooooool0=Oooo`03o`2Ioooooooo06coool006Ooool00`0003?o03?o000?
<ol000<0003oooooool0=Oooo`03o`2Ioooooooo06coool006Ooool00`0003?o03?o000?<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo06coool006Ooool2000043?o00030000oooooooo03Goool0
0ol0VOooooooo`1/oooo001Woooo00<0000co`0co`003S?o00030000oooooooo03Koool00ol0VOoo
ooooo`1/oooo001Woooo00<0000co`0co`003S?o00030000oooooooo03Koool00ol0VOooooooo`1/
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo03Koool00ol0VOooooooo`1/oooo001W
oooo00<0000co`0co`003S?o00030000oooooooo03Koool00ol0VOooooooo`1/oooo001Woooo00<0
000co`0co`003C?o00030000oooooooo03Ooool00ol0VOooooooo`1/oooo001Woooo0P0000hco`00
0`000?ooooooo`0goooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`0goooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0g
oooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0hoooo00?o
09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0hoooo00?o09Wooooo
ool0K?ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0hoooo00?o09Woooooool0K?oo
o`00Ioooo`80000=<ol000<0003oooooool0>?ooo`03o`2Ioooooooo06coool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0>?ooo`03o`2Ioooooooo06coool006Ooool00`0003?o03?o000<
<ol000<0003oooooool0>?ooo`03o`2Ioooooooo06coool006Ooool00`0003?o03?o000;<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo06coool0063oool200001Oooo`030000<ol0<ol000/co`00
0`000?ooooooo`0ioooo00?o09Woooooool0K?ooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol000/co`000`000?ooooooo`0ioooo00?o09Woooooool0K?ooo`00HOooo`030000oooooooo
00?oool2000033?o00030000oooooooo03Woool00ol0VOooooooo`1/oooo001Roooo00<0003ooooo
ool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`0ioooo00?o09Woooooool0K?ooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0ioooo00?o09Wooooo
ool0K?ooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo03[oool00ol0VOoo
ooooo`1/oooo001Woooo00<0000co`0co`002S?o00030000oooooooo03[oool00ol0VOooooooo`1/
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo03[oool00ol0VOooooooo`1/oooo001W
oooo00<0000co`0co`002S?o00030000oooooooo03[oool00ol0VOooooooo`1/oooo001Woooo0P00
00/co`000`000?ooooooo`0joooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0joooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0koooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0k
oooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0koooo00?o
09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0koooo00?o09Wooooo
ool0K?ooo`00Ioooo`80000:<ol000<0003oooooool0>oooo`03o`2Ioooooooo06coool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0>oooo`03o`2Ioooooooo06coool006Ooool00`0003?o
03?o0009<ol000<0003oooooool0>oooo`03o`2Ioooooooo06coool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0??ooo`03o`2Ioooooooo06coool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0??ooo`03o`2Ioooooooo06coool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool0??ooo`03o`2Ioooooooo06coool006Ooool200002C?o00030000oooooooo03coool00ol0VOoo
ooooo`1/oooo001Woooo00<0000co`0co`0023?o00030000oooooooo03coool00ol0VOooooooo`1/
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo03coool00ol0VOooooooo`1/oooo001W
oooo00<0000co`0co`001c?o00030000oooooooo03goool00ol0VOooooooo`1/oooo001Woooo00<0
000co`0co`001c?o00030000oooooooo03goool00ol0VOooooooo`1/oooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo03goool00ol0VOooooooo`1/oooo001Woooo0P0000Pco`000`000?oo
ooooo`0moooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0m
oooo00?o09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0moooo00?o
09Woooooool0K?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0moooo00?o09Wooooo
ool0K?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0moooo00?o09Woooooool0K?oo
o`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo03goool00ol0VOooooooo`1/
oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`0moooo00?o
09Woooooool0K?ooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`0moooo00?o09Wooooo
ool0K?ooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?oo
o`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool0
06Ooool9<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo0`00
00?oool400000oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`050000
oooooooooooo000000Koool00`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02
oooo00<0003oooooool03Oooo`040000oooooooo00002Oooo`<00003oooo00<0003oooooool01?oo
o`030000oooooooo07Ooool006Ooool9<ol02?ooo`030000oooooooo00D0000<oooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo07Soool0
06Ooool9<ol02?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool0
0`000?ooooooo`0Aoooo0P0000[oool300000oooo`800003oooo00<0003oooooool0NOooo`00Iooo
o`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.94) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61984 .12361 L
.6254 .12361 L
.63064 .12361 L
.63534 .12361 L
.63663 .12361 L
.63799 .12361 L
.63915 .12361 L
s
.63915 .12361 m
.63966 .61803 L
s
0 .4 1 r
.02381 .12361 m
.03279 .12361 L
.03793 .12361 L
.04018 .12361 L
.04136 .12361 L
.04262 .12361 L
.04325 .1233 L
.04394 .12277 L
.04517 .12183 L
.04758 .12001 L
.05288 .11616 L
.06244 .1097 L
.08274 .09786 L
.10458 .08764 L
.12384 .08048 L
.14487 .07434 L
.166 .06968 L
.17654 .06784 L
.18609 .06643 L
.20576 .06421 L
.21656 .06333 L
.22674 .0627 L
.2365 .06227 L
.24142 .06211 L
.24682 .06197 L
.25143 .06189 L
.25401 .06185 L
.25524 .06184 L
.25637 .06183 L
.25741 .06182 L
.25856 .06182 L
.25972 .06181 L
.26095 .06181 L
.26203 .0618 L
.26319 .0618 L
.26428 .0618 L
.26529 .06181 L
.26657 .06181 L
.26777 .06182 L
.27003 .06183 L
.27246 .06186 L
.27509 .06189 L
.27984 .06197 L
.28421 .06206 L
.29427 .06235 L
.30491 .06275 L
.32449 .06372 L
.33325 .06424 L
.3428 .06486 L
.34541 .065 L
Mistroke
.3482 .06513 L
.35083 .06522 L
.35321 .06528 L
.3544 .06531 L
.35565 .06533 L
.35631 .06534 L
.35703 .06535 L
.3583 .06536 L
.35949 .06536 L
.36078 .06537 L
.36199 .06537 L
.36309 .06536 L
.36424 .06535 L
.36546 .06534 L
.36765 .0653 L
.37001 .06525 L
.37261 .06518 L
.37726 .06502 L
.38162 .06482 L
.39148 .06425 L
.40185 .06348 L
.42036 .06173 L
.45852 .05707 L
.49914 .05117 L
.53823 .04508 L
.57978 .03864 L
.60063 .03556 L
.61982 .0329 L
.6295 .03164 L
.63423 .03105 L
.63629 .0308 L
.63738 .03066 L
.63854 .03052 L
.63975 .12361 L
.64088 .12361 L
.64309 .12361 L
.64797 .12361 L
.65834 .12361 L
.69606 .12361 L
.73623 .12361 L
.77488 .12361 L
.81599 .12361 L
.85558 .12361 L
.89366 .12361 L
.93419 .12361 L
.9732 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.94) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`11oooo201Vofgoool0
06Ooool00`000?ooooooo`0loooo1@1Vo`Ooool00`1Vooooooooo`1[oooo001Woooo00<0003ooooo
ool0=Oooo`L0I_l<oooo00<0I_ooooooool0Joooo`00Ioooo`030000oooooooo02goool806Ko4ooo
o`0306Kooooooooo06_oool006Ooool00`000?ooooooo`0Xoooo1@1Voa_oool00`1Vooooooooo`1[
oooo001Woooo0P0002Coool506Ko8?ooo`0306Kooooooooo06_oool006Ooool00`000?ooooooo`0M
oooo1P1VobGoool00`1Vooooooooo`1[oooo001Woooo00<0003oooooool05_ooo`L0I_l[oooo00<0
I_ooooooool0Joooo`00@_ooob@0I_l00oooo`000?ooo`08oooo3`1Voc;oool00`1Vooooooooo`1[
oooo000loooo1P1VobCoool00`1Vo`00001Vo`0806Ko@Oooo`0306Kooooooooo06_oool003Soool4
06Ko:oooo`030000oooooooo04Soool00`1Vooooooooo`1[oooo000coooo1@1Vobooool20000BOoo
o`0306Kooooooooo06_oool001Ooool500004oooo`@0I_l7oooo0P0000Coool200001?ooo`80000O
oooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007?ooo`0306Kooooooooo00D0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Aoooo0P1V
o`[oool010000?ooooooo`0000Soool010000?ooooooo`0001koool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Koooo00<0I_ooooooool00_ooo`030000oooooooo
01ooool00`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Ooo
o`030000oooooooo00ooool206Ko3?ooo`040000oooooooo00002oooo`030000oooooooo01coool0
0`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool06Oooo`0306Kooooooooo
00;oool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo01koool00`000?oo
ooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0=oooo0P1Vo`Soool400000_ooo`040000
oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`80000L
oooo00<0I_ooooooool00_ooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0002;oool0
0`000?ooooooo`0Eoooo000Ioooo00<0003oooooool02oooo`80I_l@oooo00@0003oooooool00009
oooo00<0003oooooool07_ooo`030000oooooooo01goool010000?ooooooo`0000Woool00`000?oo
ooooo`0Koooo00<0I_ooooooool00_ooo`030000oooooooo01ooool00`000?ooooooo`08oooo00<0
003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000;oooo0P1Voa?oool200002_oo
o`<0000Noooo0P0001ooool200002_ooo`<0000Koooo00@0I_ooooooooooool200008?ooo`80000:
oooo0`00023oool200005oooo`008oooo`80I_m2oooo00<0003oooooool0B?ooo`0306Kooooooooo
06_oool0027oool206KoA?ooo`030000oooooooo04Soool00`1Vooooooooo`1[oooo000Poooo00<0
I_ooooooool0A?ooo`030000oooooooo04Soool00`1Vooooooooo`1[oooo000Ooooo00<0I_oooooo
ool0AOooo`030000oooooooo04Soool00`1Vooooooooo`1[oooo000Loooo0`1VodSoool00`000?oo
ooooo`18oooo00<0I_ooooooool0Joooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00040000<ol0<ol0
o`2I13?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0083?o
0004o`2I<ol0<ol0<ol0400001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Iooo
o`030000<ol0<ol004Lco`000`000?l0V@0000020000J_ooo`00Ioooo`030000<ol0<ol0048co`05
000000?ooooo09Woool0K?ooo`00Ioooo`030000<ol0<ol003dco`0500001_ooo`03o`2Ioooooooo
06_oool006Ooool00`0003?o03?o000i<ol0100000_oool00ol0VOooooooo`1[oooo001Woooo0P00
03Pco`0200003oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000e<ol00P00017oool0
0ol0VOooooooo`1[oooo001Woooo00<0000co`0co`00<c?o0080000Coooo00?o09Woooooool0Jooo
o`00Ioooo`030000<ol0<ol0034co`0200005Oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o
03?o000`<ol000<0003oooooool05Oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000^
<ol00P0001Soool00ol0VOooooooo`1[oooo001Woooo0P0002dco`0200006_ooo`03o`2Ioooooooo
06_oool006Ooool00`0003?o03?o000[<ol000<0003oooooool06_ooo`03o`2Ioooooooo06_oool0
06Ooool00`0003?o03?o000Z<ol000<0003oooooool06oooo`03o`2Ioooooooo06_oool006Ooool0
0`0003?o03?o000Y<ol000<0003oooooool07?ooo`03o`2Ioooooooo06_oool006Ooool00`0003?o
03?o000X<ol000<0003oooooool07Oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000X
<ol000<0003oooooool07Oooo`03o`2Ioooooooo06_oool006Ooool20000:3?o00030000oooooooo
01koool00ol0VOooooooo`1[oooo001Woooo00<0000co`0co`009S?o00030000oooooooo01ooool0
0ol0VOooooooo`1[oooo001Woooo00<0000co`0co`009C?o00030000oooooooo023oool00ol0VOoo
ooooo`1[oooo001Woooo00<0000co`0co`0093?o00030000oooooooo027oool00ol0VOooooooo`1[
oooo001Woooo00<0000co`0co`008c?o00030000oooooooo02;oool00ol0VOooooooo`1[oooo001W
oooo00<0000co`0co`008c?o00030000oooooooo02;oool00ol0VOooooooo`1[oooo001Woooo0P00
02<co`000`000?ooooooo`0Soooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol0024co`00
0`000?ooooooo`0Toooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol0020co`000`000?oo
ooooo`0Uoooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0U
oooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`0Voooo00?o
09Woooooool0Joooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo02Koool0
0ol0VOooooooo`1[oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?oo
ooooo`0Woooo00?o09Woooooool0Joooo`00HOooo`030000oooooooo00?oool200007c?o00030000
oooooooo02Ooool00ol0VOooooooo`1[oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`000`000?ooooooo`0Xoooo00?o09Woooooool0Joooo`00HOooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0:?ooo`03o`2Ioooooooo06_oool0063oool200001Ooo
o`030000<ol0<ol001`co`000`000?ooooooo`0Yoooo00?o09Woooooool0Joooo`00Ioooo`030000
<ol0<ol001`co`000`000?ooooooo`0Yoooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol0
01/co`000`000?ooooooo`0Zoooo00?o09Woooooool0Joooo`00Ioooo`80000L<ol000<0003ooooo
ool0:_ooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000J<ol000<0003oooooool0:ooo
o`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000J<ol000<0003oooooool0:oooo`03o`2I
oooooooo06_oool006Ooool00`0003?o03?o000I<ol000<0003oooooool0;?ooo`03o`2Ioooooooo
06_oool006Ooool00`0003?o03?o000I<ol000<0003oooooool0;?ooo`03o`2Ioooooooo06_oool0
06Ooool00`0003?o03?o000H<ol000<0003oooooool0;Oooo`03o`2Ioooooooo06_oool006Ooool2
00006C?o00030000oooooooo02goool00ol0VOooooooo`1[oooo001Woooo00<0000co`0co`005c?o
00030000oooooooo02koool00ol0VOooooooo`1[oooo001Woooo00<0000co`0co`005c?o00030000
oooooooo02koool00ol0VOooooooo`1[oooo001Woooo00<0000co`0co`005S?o00030000oooooooo
02ooool00ol0VOooooooo`1[oooo001Woooo00<0000co`0co`005S?o00030000oooooooo02ooool0
0ol0VOooooooo`1[oooo001Woooo00<0000co`0co`005S?o00030000oooooooo02ooool00ol0VOoo
ooooo`1[oooo001Woooo00<0000co`0co`005C?o00030000oooooooo033oool00ol0VOooooooo`1[
oooo001Woooo0P0001Hco`000`000?ooooooo`0`oooo00?o09Woooooool0Joooo`00Ioooo`030000
<ol0<ol001Dco`000`000?ooooooo`0`oooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0`oooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooooooo`0aoooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol001@co`000`000?oo
ooooo`0aoooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0a
oooo00?o09Woooooool0Joooo`00Ioooo`80000E<ol000<0003oooooool0<Oooo`03o`2Ioooooooo
06_oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0<_ooo`03o`2Ioooooooo06_oool0
06Ooool00`0003?o03?o000C<ol000<0003oooooool0<_ooo`03o`2Ioooooooo06_oool006Ooool0
0`0003?o03?o000C<ol000<0003oooooool0<_ooo`03o`2Ioooooooo06_oool005ooool400001?oo
o`030000<ol0<ol001<co`000`000?ooooooo`0boooo00?o09Woooooool0Joooo`00Goooo`030000
oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0<oooo`03o`2Ioooooooo06_oool0
063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`0coooo00?o09Woooooool0Jooo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0<oooo`03o`2I
oooooooo06_oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003ooooo
ool0=?ooo`03o`2Ioooooooo06_oool0063oool200001Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`0doooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`0d
oooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`0doooo00?o
09Woooooool0Joooo`00Ioooo`80000A<ol000<0003oooooool0=Oooo`03o`2Ioooooooo06_oool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool0=Oooo`03o`2Ioooooooo06_oool006Ooool0
0`0003?o03?o000@<ol000<0003oooooool0=Oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o
03?o000@<ol000<0003oooooool0=Oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000?
<ol000<0003oooooool0=_ooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000?<ol000<0
003oooooool0=_ooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000?<ol000<0003ooooo
ool0=_ooo`03o`2Ioooooooo06_oool006Ooool2000043?o00030000oooooooo03Koool00ol0VOoo
ooooo`1[oooo001Woooo00<0000co`0co`003S?o00030000oooooooo03Ooool00ol0VOooooooo`1[
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo03Ooool00ol0VOooooooo`1[oooo001W
oooo00<0000co`0co`003S?o00030000oooooooo03Ooool00ol0VOooooooo`1[oooo001Woooo00<0
000co`0co`003S?o00030000oooooooo03Ooool00ol0VOooooooo`1[oooo001Woooo00<0000co`0c
o`003C?o00030000oooooooo03Soool00ol0VOooooooo`1[oooo001Woooo0P0000hco`000`000?oo
ooooo`0hoooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0h
oooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`0hoooo00?o
09Woooooool0Joooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0ioooo00?o09Wooooo
ool0Joooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0ioooo00?o09Woooooool0Jooo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0ioooo00?o09Woooooool0Joooo`00Iooo
o`80000=<ol000<0003oooooool0>Oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000<
<ol000<0003oooooool0>Oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000<<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o000;<ol000<0003ooooo
ool0>_ooo`03o`2Ioooooooo06_oool0063oool200001Oooo`030000<ol0<ol000/co`000`000?oo
ooooo`0joooo00?o09Woooooool0Joooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0
00/co`000`000?ooooooo`0joooo00?o09Woooooool0Joooo`00HOooo`030000oooooooo00?oool2
000033?o00030000oooooooo03[oool00ol0VOooooooo`1[oooo001Roooo00<0003oooooool00_oo
o`030000<ol0<ol000/co`000`000?ooooooo`0joooo00?o09Woooooool0Joooo`00Goooo`040000
oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0joooo00?o09Woooooool0Jooo
o`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo03_oool00ol0VOooooooo`1[
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo03_oool00ol0VOooooooo`1[oooo001W
oooo00<0000co`0co`002S?o00030000oooooooo03_oool00ol0VOooooooo`1[oooo001Woooo00<0
000co`0co`002S?o00030000oooooooo03_oool00ol0VOooooooo`1[oooo001Woooo0P0000/co`00
0`000?ooooooo`0koooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0koooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0l
oooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0loooo00?o
09Woooooool0Joooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0loooo00?o09Wooooo
ool0Joooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`0loooo00?o09Woooooool0Jooo
o`00Ioooo`80000:<ol000<0003oooooool0??ooo`03o`2Ioooooooo06_oool006Ooool00`0003?o
03?o0009<ol000<0003oooooool0??ooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o0009
<ol000<0003oooooool0??ooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0?Oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool0?Oooo`03o`2Ioooooooo06_oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0?Ooo
o`03o`2Ioooooooo06_oool006Ooool200002C?o00030000oooooooo03goool00ol0VOooooooo`1[
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo03goool00ol0VOooooooo`1[oooo001W
oooo00<0000co`0co`0023?o00030000oooooooo03goool00ol0VOooooooo`1[oooo001Woooo00<0
000co`0co`001c?o00030000oooooooo03koool00ol0VOooooooo`1[oooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo03koool00ol0VOooooooo`1[oooo001Woooo00<0000co`0co`001c?o
00030000oooooooo03koool00ol0VOooooooo`1[oooo001Woooo0P0000Pco`000`000?ooooooo`0n
oooo00?o09Woooooool0Joooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0noooo00?o
09Woooooool0Joooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0noooo00?o09Wooooo
ool0Joooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0noooo00?o09Woooooool0Jooo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`0noooo00?o09Woooooool0Joooo`00HOoo
o`<00003oooo00<0000co`0co`001c?o00030000oooooooo03koool00ol0VOooooooo`1[oooo001R
oooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`0noooo00?o09Wooooo
ool0Joooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`0noooo00?o09Woooooool0Jooo
o`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_
oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9
<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo0`0000Goool3
00000_ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo
00Coool01@000?ooooooooooo`00001joooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000oooooooo00002Oooo`<00002oooo1@0000?oool00`000?ooooooo`1g
oooo001Woooo2C?o00Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`040000
oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02?oo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooo`000003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Ooo
o`80000:oooo0`0000Coool200000_ooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Iooo
o`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.63527 .12361 L
.64043 .12361 L
.64277 .12361 L
.64405 .12361 L
.64524 .12361 L
s
.64524 .12361 m
.64576 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .10573 L
.08255 .09474 L
.10458 .0851 L
.12507 .07808 L
.14415 .07296 L
.16457 .06878 L
.18314 .06599 L
.20229 .06395 L
.2131 .06313 L
.22307 .06257 L
.22773 .06236 L
.23274 .06218 L
.23707 .06205 L
.2418 .06194 L
.24466 .06189 L
.24732 .06186 L
.24986 .06183 L
.25128 .06182 L
.25257 .06181 L
.25384 .06181 L
.25501 .0618 L
.25629 .0618 L
.25694 .0618 L
.25765 .0618 L
.25884 .06181 L
.26012 .06181 L
.26132 .06182 L
.26243 .06182 L
.26471 .06184 L
.26723 .06187 L
.27234 .06195 L
.27707 .06205 L
.28151 .06216 L
.2915 .06247 L
.30227 .06292 L
.32231 .06397 L
.33251 .0646 L
.33812 .06498 L
.34341 .06533 L
.34837 .06559 L
.35117 .0657 L
.35375 .06577 L
.35593 .06581 L
.35716 .06583 L
.35832 .06585 L
.35954 .06586 L
.36065 .06586 L
.36193 .06587 L
.36315 .06586 L
Mistroke
.36431 .06586 L
.36536 .06585 L
.36657 .06584 L
.36771 .06582 L
.36974 .06578 L
.37194 .06573 L
.37693 .06558 L
.38152 .06539 L
.39128 .06485 L
.40038 .06421 L
.42106 .06233 L
.46002 .05763 L
.50143 .05165 L
.54133 .04545 L
.57971 .03948 L
.59914 .03657 L
.62055 .03354 L
.63032 .03224 L
.63545 .03158 L
.64084 .03091 L
.64314 .03063 L
.6444 .03048 L
.64559 .03034 L
.64626 .12361 L
.64699 .12361 L
.64827 .12361 L
.65077 .12361 L
.65986 .12361 L
.70084 .12361 L
.74029 .12361 L
.77823 .12361 L
.81862 .12361 L
.8575 .12361 L
.89883 .12361 L
.93864 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`16oooo1@1Vof_oool0
06Ooool00`000?ooooooo`0loooo2P1Vo`Coool00`1Vooooooooo`1Yoooo001Woooo00<0003ooooo
ool0=oooo`D0I_l>oooo00<0I_ooooooool0JOooo`00Ioooo`030000oooooooo03;oool506Ko4ooo
o`0306Kooooooooo06Woool006Ooool00`000?ooooooo`0[oooo1`1VoaSoool00`1Vooooooooo`1Y
oooo001Woooo0P0002Coool806Ko7oooo`0306Kooooooooo06Woool006Ooool00`000?ooooooo`0N
oooo1@1VobOoool00`1Vooooooooo`1Yoooo001Woooo00<0003oooooool05oooo`L0I_l/oooo00<0
I_ooooooool0JOooo`00@_ooob@0I_l00oooo`000?ooo`0<oooo301Voc?oool00`1Vooooooooo`1Y
oooo000moooo1@1VobCoool00`1Vo`00001Vo`0<06Ko?oooo`0306Kooooooooo06Woool003Soool5
06Ko:_ooo`030000oooooooo04[oool00`1Vooooooooo`1Yoooo000coooo1@1Vobooool20000Booo
o`0306Kooooooooo06Woool001Ooool500004oooo`@0I_l7oooo0P0000Coool200001?ooo`80000O
oooo00<0003oooooool07_ooo`800004oooo0P0000Coool200007_ooo`0306Ko0000000000<0000M
oooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Aoooo0P1V
o`[oool010000?ooooooo`0000Soool010000?ooooooo`0001koool00`000?ooooooo`0Moooo00@0
003oooooool00008oooo00@0003oooooool0000Moooo00@0I_ooooooool0000Qoooo00<0003ooooo
ool01oooo`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0>
oooo0`1Vo`coool010000?ooooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Ooo
o`040000oooooooo00002oooo`030000oooooooo01_oool0101Vooooooooo`00027oool00`000?oo
ooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo01Koool0017oool400001?ooo`030000
oooooooo00_oool306Ko2Oooo`@00002oooo00@0003oooooool00009oooo0P0001ooool00`000?oo
ooooo`0Moooo00@0003oooooool00009oooo0P0001koool0101Vooooooooo`00027oool00`000?oo
ooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool02Oooo`80I_lB
oooo00@0003oooooool00009oooo00<0003oooooool07_ooo`030000oooooooo01goool010000?oo
ooooo`0000Woool00`000?ooooooo`0Moooo00@0I_ooooooool0000Qoooo00<0003oooooool02?oo
o`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200002Oooo`80I_lEoooo0P00
00[oool300007_ooo`80000Ooooo0P0000[oool300007Oooo`0406Kooooo000000008?ooo`80000:
oooo0`00023oool200005oooo`008Oooo`80I_m4oooo00<0003oooooool0B_ooo`0306Kooooooooo
06Woool001ooool206KoA_ooo`030000oooooooo04[oool00`1Vooooooooo`1Yoooo000Moooo0P1V
odSoool00`000?ooooooo`1:oooo00<0I_ooooooool0JOooo`006_ooo`<0I_m:oooo00<0003ooooo
ool0B_ooo`0306Kooooooooo06Woool001Soool206KoCOooo`030000oooooooo04[oool00`1Voooo
ooooo`1Yoooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`000S?o0004o`2I<ol0<ol0
00001c?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000R<ol000?o09Tco`0000003`00
01Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol004Lco`03
000000?o09T0003oool0JOooo`00Ioooo`030000<ol0<ol0048co`0500000oooo`03o`2Ioooooooo
06Woool006Ooool00`0003?o03?o000m<ol01@0000Soool00ol0VOooooooo`1Yoooo001Woooo00<0
000co`0co`00>C?o00@0000=oooo00?o09Woooooool0JOooo`00Ioooo`80000h<ol00P00017oool0
0ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`00=C?o0080000Coooo00?o09Woooooool0JOoo
o`00Ioooo`030000<ol0<ol003<co`0200005Oooo`03o`2Ioooooooo06Woool006Ooool00`0003?o
03?o000a<ol00P0001Ooool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`00<3?o00030000
oooooooo01Ooool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`00;S?o0080000Joooo00?o
09Woooooool0JOooo`00Ioooo`80000]<ol00P0001coool00ol0VOooooooo`1Yoooo001Woooo00<0
000co`0co`00:c?o00030000oooooooo01coool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0c
o`00:S?o00030000oooooooo01goool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`00:C?o
00030000oooooooo01koool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`00:3?o00030000
oooooooo01ooool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`00:3?o00030000oooooooo
01ooool00ol0VOooooooo`1Yoooo001Woooo0P0002Pco`000`000?ooooooo`0Poooo00?o09Wooooo
ool0JOooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`0Qoooo00?o09Woooooool0JOoo
o`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Iooo
o`030000<ol0<ol002@co`000`000?ooooooo`0Soooo00?o09Woooooool0JOooo`00Ioooo`030000
<ol0<ol002<co`000`000?ooooooo`0Toooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol0
02<co`000`000?ooooooo`0Toooo00?o09Woooooool0JOooo`00Ioooo`80000S<ol000<0003ooooo
ool09Oooo`03o`2Ioooooooo06Woool006Ooool00`0003?o03?o000Q<ol000<0003oooooool09_oo
o`03o`2Ioooooooo06Woool006Ooool00`0003?o03?o000P<ol000<0003oooooool09oooo`03o`2I
oooooooo06Woool006Ooool00`0003?o03?o000P<ol000<0003oooooool09oooo`03o`2Ioooooooo
06Woool006Ooool00`0003?o03?o000O<ol000<0003oooooool0:?ooo`03o`2Ioooooooo06Woool0
05ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`0Xoooo00?o09Woooooool0JOoo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003oooooool0:Oooo`03o`2I
oooooooo06Woool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`0Yoooo00?o
09Woooooool0JOooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003ooooo
ool0:_ooo`03o`2Ioooooooo06Woool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o
00030000oooooooo02[oool00ol0VOooooooo`1Yoooo001Poooo0P0000Goool00`0003?o03?o000L
<ol000<0003oooooool0:oooo`03o`2Ioooooooo06Woool006Ooool00`0003?o03?o000L<ol000<0
003oooooool0:oooo`03o`2Ioooooooo06Woool006Ooool00`0003?o03?o000K<ol000<0003ooooo
ool0;?ooo`03o`2Ioooooooo06Woool006Ooool2000073?o00030000oooooooo02coool00ol0VOoo
ooooo`1Yoooo001Woooo00<0000co`0co`006S?o00030000oooooooo02goool00ol0VOooooooo`1Y
oooo001Woooo00<0000co`0co`006S?o00030000oooooooo02goool00ol0VOooooooo`1Yoooo001W
oooo00<0000co`0co`006C?o00030000oooooooo02koool00ol0VOooooooo`1Yoooo001Woooo00<0
000co`0co`006C?o00030000oooooooo02koool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0c
o`0063?o00030000oooooooo02ooool00ol0VOooooooo`1Yoooo001Woooo0P0001Tco`000`000?oo
ooooo`0_oooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`0`
oooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`0`oooo00?o
09Woooooool0JOooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0aoooo00?o09Wooooo
ool0JOooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0aoooo00?o09Woooooool0JOoo
o`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0aoooo00?o09Woooooool0JOooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`0boooo00?o09Woooooool0JOooo`00Ioooo`80000F
<ol000<0003oooooool0<_ooo`03o`2Ioooooooo06Woool006Ooool00`0003?o03?o000E<ol000<0
003oooooool0<_ooo`03o`2Ioooooooo06Woool006Ooool00`0003?o03?o000E<ol000<0003ooooo
ool0<_ooo`03o`2Ioooooooo06Woool006Ooool00`0003?o03?o000D<ol000<0003oooooool0<ooo
o`03o`2Ioooooooo06Woool006Ooool00`0003?o03?o000D<ol000<0003oooooool0<oooo`03o`2I
oooooooo06Woool006Ooool00`0003?o03?o000D<ol000<0003oooooool0<oooo`03o`2Ioooooooo
06Woool006Ooool200005C?o00030000oooooooo03?oool00ol0VOooooooo`1Yoooo001Woooo00<0
000co`0co`004c?o00030000oooooooo03Coool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0c
o`004c?o00030000oooooooo03Coool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`004c?o
00030000oooooooo03Coool00ol0VOooooooo`1Yoooo001Ooooo100000Coool00`0003?o03?o000C
<ol000<0003oooooool0=?ooo`03o`2Ioooooooo06Woool005ooool00`000?ooooooo`05oooo00<0
000co`0co`004S?o00030000oooooooo03Goool00ol0VOooooooo`1Yoooo001Poooo00<0003ooooo
ool01?ooo`80000C<ol000<0003oooooool0=Oooo`03o`2Ioooooooo06Woool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`004S?o00030000oooooooo03Goool00ol0VOooooooo`1Yoooo001O
oooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo03Koool00ol0VOoo
ooooo`1Yoooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool0=_ooo`03o`2I
oooooooo06Woool006Ooool00`0003?o03?o000A<ol000<0003oooooool0=_ooo`03o`2Ioooooooo
06Woool006Ooool00`0003?o03?o000A<ol000<0003oooooool0=_ooo`03o`2Ioooooooo06Woool0
06Ooool200004C?o00030000oooooooo03Ooool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo03Ooool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`0043?o
00030000oooooooo03Ooool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`0043?o00030000
oooooooo03Ooool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`003c?o00030000oooooooo
03Soool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`003c?o00030000oooooooo03Soool0
0ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`003c?o00030000oooooooo03Soool00ol0VOoo
ooooo`1Yoooo001Woooo0P00010co`000`000?ooooooo`0hoooo00?o09Woooooool0JOooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`0ioooo00?o09Woooooool0JOooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`0ioooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`0ioooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`0ioooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`0joooo00?o09Woooooool0JOooo`00Ioooo`80000><ol000<0003oooooool0>_ooo`03o`2I
oooooooo06Woool006Ooool00`0003?o03?o000=<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
06Woool006Ooool00`0003?o03?o000=<ol000<0003oooooool0>_ooo`03o`2Ioooooooo06Woool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Woool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Woool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Woool006Ooool200003C?o00030000
oooooooo03_oool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`0033?o00030000oooooooo
03_oool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`0033?o00030000oooooooo03_oool0
0ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`002c?o00030000oooooooo03coool00ol0VOoo
ooooo`1Yoooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool0??ooo`03o`2I
oooooooo06Woool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003ooooo
ool0??ooo`03o`2Ioooooooo06Woool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?oo
ooooo`0loooo00?o09Woooooool0JOooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;
<ol000<0003oooooool0??ooo`03o`2Ioooooooo06Woool005ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0??ooo`03o`2Ioooooooo06Woool0063oool200001Ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`0moooo00?o09Woooooool0JOooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`0moooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0moooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0moooo00?o09Woooooool0JOooo`00Ioooo`80000;<ol000<0003oooooool0?Ooo
o`03o`2Ioooooooo06Woool006Ooool00`0003?o03?o000:<ol000<0003oooooool0?Oooo`03o`2I
oooooooo06Woool006Ooool00`0003?o03?o0009<ol000<0003oooooool0?_ooo`03o`2Ioooooooo
06Woool006Ooool00`0003?o03?o0009<ol000<0003oooooool0?_ooo`03o`2Ioooooooo06Woool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0?_ooo`03o`2Ioooooooo06Woool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0?_ooo`03o`2Ioooooooo06Woool006Ooool200002S?o
00030000oooooooo03koool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`002C?o00030000
oooooooo03koool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`002C?o00030000oooooooo
03koool00ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`0023?o00030000oooooooo03ooool0
0ol0VOooooooo`1Yoooo001Woooo00<0000co`0co`0023?o00030000oooooooo03ooool00ol0VOoo
ooooo`1Yoooo001Woooo00<0000co`0co`0023?o00030000oooooooo03ooool00ol0VOooooooo`1Y
oooo001Woooo0P0000Tco`000`000?ooooooo`0ooooo00?o09Woooooool0JOooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`0ooooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0ooooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`10oooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`10oooo00?o09Woooooool0JOooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`10
oooo00?o09Woooooool0JOooo`00Ioooo`800008<ol000<0003oooooool0@?ooo`03o`2Ioooooooo
06Woool006Ooool00`0003?o03?o0007<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06Woool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06Woool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06Woool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06Woool0067oool300000oooo`030000
<ol0<ol000Lco`000`000?ooooooo`10oooo00?o09Woooooool0JOooo`00H_ooo`030000oooooooo
00;oool00`0003?o03?o0007<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06Woool005ooool5
00000oooo`800008<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06Woool005ooool010000?oo
ooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004
oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`<00003oooo0`0000Coool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00D0
003oooooooooool00000N_ooo`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000Woool300000_ooo`040000oooooooo00001?ooo`030000oooooooo
07Ooool006Ooool9<ol02?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0
003oooooool00002oooo0`0000Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool00oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo017oool200002_oo
o`<00003oooo0`0000;oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.98) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.64043 .12361 L
.64559 .12361 L
.64812 .12361 L
.64923 .12361 L
.65045 .12361 L
.65155 .12361 L
s
.65155 .12361 m
.65196 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .10201 L
.08255 .09172 L
.10458 .08274 L
.12507 .07623 L
.14415 .07153 L
.16457 .06773 L
.18314 .06522 L
.1931 .0642 L
.20229 .06344 L
.21238 .06279 L
.21796 .06251 L
.22307 .0623 L
.22757 .06214 L
.23249 .06201 L
.23518 .06195 L
.23768 .0619 L
.24022 .06187 L
.24261 .06184 L
.24484 .06182 L
.2461 .06181 L
.24725 .06181 L
.24823 .06181 L
.2493 .0618 L
.25042 .0618 L
.25147 .0618 L
.25269 .06181 L
.25385 .06181 L
.25489 .06182 L
.25602 .06182 L
.25856 .06185 L
.26091 .06187 L
.26554 .06194 L
.27054 .06204 L
.27957 .06229 L
.29032 .06267 L
.30018 .06311 L
.3207 .06425 L
.33071 .0649 L
.3398 .06554 L
.34435 .06585 L
.34674 .06599 L
.34928 .0661 L
.35149 .06619 L
.35393 .06626 L
.35615 .06632 L
.35823 .06635 L
.35944 .06636 L
.36013 .06637 L
.36077 .06638 L
Mistroke
.36194 .06638 L
.36318 .06638 L
.36441 .06638 L
.36556 .06637 L
.3666 .06636 L
.36771 .06635 L
.3703 .06631 L
.37303 .06625 L
.37791 .06611 L
.38288 .0659 L
.38741 .06568 L
.39759 .06504 L
.41593 .06351 L
.45583 .05895 L
.49421 .05356 L
.53505 .0473 L
.57436 .04115 L
.61217 .03549 L
.63155 .03281 L
.63686 .03212 L
.64245 .0314 L
.64721 .03081 L
.64852 .03065 L
.64991 .03048 L
.65123 .03033 L
.65242 .12361 L
.65362 .12361 L
.65474 .12361 L
.65729 .12361 L
.66243 .12361 L
.67165 .12361 L
.69246 .12361 L
.73133 .12361 L
.77266 .12361 L
.81248 .12361 L
.85077 .12361 L
.89152 .12361 L
.93076 .12361 L
.96847 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.98) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`14oooo201Vof[oool0
06Ooool00`000?ooooooo`0moooo1`1Vo`Ooool00`1Vooooooooo`1Xoooo001Woooo00<0003ooooo
ool0=_ooo`L0I_l>oooo00<0I_ooooooool0J?ooo`00Ioooo`030000oooooooo037oool506Ko5Ooo
o`0306Kooooooooo06Soool006Ooool00`000?ooooooo`0/oooo1@1Voa[oool00`1Vooooooooo`1X
oooo001Woooo0P0002Soool506Ko7oooo`0306Kooooooooo06Soool006Ooool00`000?ooooooo`0P
oooo1`1VobCoool00`1Vooooooooo`1Xoooo001Woooo00<0003oooooool05_ooo`X0I_l[oooo00<0
I_ooooooool0J?ooo`00@Oooob80I_l4oooo00<0003oooooool03_ooo`P0I_leoooo00<0I_oooooo
ool0J?ooo`00>?ooo`T0I_lRoooo101Vo`03000006Ko06Ko00h0I_lmoooo00<0I_ooooooool0J?oo
o`00<oooo`D0I_l_oooo00<0003oooooool0Boooo`0306Kooooooooo06Soool002ooool406Ko=?oo
o`80001<oooo00<0I_ooooooool0J?ooo`005oooo`D0000Aoooo0P1Vo`_oool200001?ooo`800004
oooo0P0001ooool00`000?ooooooo`0Noooo0P0000Coool200001?ooo`80000Ooooo1@0001goool5
00000_ooo`800004oooo0P00023oool400005_ooo`006Oooo`030000oooooooo00koool306Ko3?oo
o`040000oooooooo00002?ooo`040000oooooooo00007_ooo`030000oooooooo01goool010000?oo
ooooo`0000Soool010000?ooooooo`0001ooool00`1Vo`000?ooo`0Poooo00<0003oooooool01ooo
o`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0;oooo0`1V
o`ooool010000?ooooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000
oooooooo00002oooo`030000oooooooo01goool00`1Vo`000?ooo`0Poooo00<0003oooooool02_oo
o`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`09
oooo0P1Vo`coool400000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`80000Poooo00<0I_l0003oool08?ooo`030000oooooooo00Soool2
00008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`07oooo0P1VoaCoool010000?oo
ooooo`0000Woool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Ooo
o`030000oooooooo01ooool00`1Vo`000?ooo`0Poooo00<0003oooooool02?ooo`030000oooooooo
01ooool010000?ooooooo`0001Koool001Soool200001oooo`80I_lGoooo0P0000[oool300007_oo
o`80000Ooooo0P0000[oool300007oooo`80000Poooo0P0000[oool300008?ooo`80000Goooo000P
oooo00<0I_ooooooool0A?ooo`030000oooooooo04coool00`1Vooooooooo`1Woooo000Noooo0P1V
odOoool00`000?ooooooo`1<oooo00<0I_ooooooool0Ioooo`007?ooo`80I_m9oooo00<0003ooooo
ool0C?ooo`0306Kooooooooo06Ooool001[oool206KoBoooo`030000oooooooo04coool00`1Voooo
ooooo`1Woooo000Hoooo0P1Vodgoool00`000?ooooooo`1<oooo00<0I_ooooooool0Ioooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000<co`000ol0VC?o00000007<ol000<0000co`0c
o`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
000co`0co`009C?o00030000<ol0<ol002<co`000ol0V@000000000>00006Oooo`030000oooooooo
02Koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`00Ac?o00@000000ol0VOooooooo`1X
oooo001Woooo00<0000co`0co`00@S?o00D00004oooo00?o09Woooooool0J?ooo`00Ioooo`030000
<ol0<ol003dco`0500002Oooo`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000i<ol01000
00koool00ol0VOooooooo`1Xoooo001Woooo0P0003Pco`0200004_ooo`03o`2Ioooooooo06Soool0
06Ooool00`0003?o03?o000e<ol00P0001Coool00ol0VOooooooo`1Xoooo001Woooo00<0000co`0c
o`00<c?o0080000Foooo00?o09Woooooool0J?ooo`00Ioooo`030000<ol0<ol0034co`0200006?oo
o`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000`<ol000<0003oooooool06?ooo`03o`2I
oooooooo06Soool006Ooool00`0003?o03?o000^<ol00P0001_oool00ol0VOooooooo`1Xoooo001W
oooo0P0002dco`0200007Oooo`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000[<ol000<0
003oooooool07Oooo`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000Z<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000Y<ol000<0003oooooool07ooo
o`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000X<ol000<0003oooooool08?ooo`03o`2I
oooooooo06Soool006Ooool00`0003?o03?o000X<ol000<0003oooooool08?ooo`03o`2Ioooooooo
06Soool006Ooool20000:3?o00030000oooooooo027oool00ol0VOooooooo`1Xoooo001Woooo00<0
000co`0co`009S?o00030000oooooooo02;oool00ol0VOooooooo`1Xoooo001Woooo00<0000co`0c
o`009C?o00030000oooooooo02?oool00ol0VOooooooo`1Xoooo001Woooo00<0000co`0co`0093?o
00030000oooooooo02Coool00ol0VOooooooo`1Xoooo001Woooo00<0000co`0co`008c?o00030000
oooooooo02Goool00ol0VOooooooo`1Xoooo001Woooo00<0000co`0co`008c?o00030000oooooooo
02Goool00ol0VOooooooo`1Xoooo001Woooo0P0002<co`000`000?ooooooo`0Voooo00?o09Wooooo
ool0J?ooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`0Woooo00?o09Woooooool0J?oo
o`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0Xoooo00?o09Woooooool0J?ooo`00Iooo
o`030000<ol0<ol0020co`000`000?ooooooo`0Xoooo00?o09Woooooool0J?ooo`00Ioooo`030000
<ol0<ol001lco`000`000?ooooooo`0Yoooo00?o09Woooooool0J?ooo`00Goooo`D00003oooo00<0
000co`0co`007c?o00030000oooooooo02Woool00ol0VOooooooo`1Xoooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001hco`000`000?ooooooo`0Zoooo00?o09Woooooool0J?ooo`00HOoo
o`030000oooooooo00?oool200007c?o00030000oooooooo02[oool00ol0VOooooooo`1Xoooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0[oooo00?o09Wooooo
ool0J?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0:ooo
o`03o`2Ioooooooo06Soool0063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`0/
oooo00?o09Woooooool0J?ooo`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`0/oooo00?o
09Woooooool0J?ooo`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`0]oooo00?o09Wooooo
ool0J?ooo`00Ioooo`80000L<ol000<0003oooooool0;Oooo`03o`2Ioooooooo06Soool006Ooool0
0`0003?o03?o000J<ol000<0003oooooool0;_ooo`03o`2Ioooooooo06Soool006Ooool00`0003?o
03?o000J<ol000<0003oooooool0;_ooo`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000I
<ol000<0003oooooool0;oooo`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000I<ol000<0
003oooooool0;oooo`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000H<ol000<0003ooooo
ool0<?ooo`03o`2Ioooooooo06Soool006Ooool200006C?o00030000oooooooo033oool00ol0VOoo
ooooo`1Xoooo001Woooo00<0000co`0co`005c?o00030000oooooooo037oool00ol0VOooooooo`1X
oooo001Woooo00<0000co`0co`005c?o00030000oooooooo037oool00ol0VOooooooo`1Xoooo001W
oooo00<0000co`0co`005S?o00030000oooooooo03;oool00ol0VOooooooo`1Xoooo001Woooo00<0
000co`0co`005S?o00030000oooooooo03;oool00ol0VOooooooo`1Xoooo001Woooo00<0000co`0c
o`005S?o00030000oooooooo03;oool00ol0VOooooooo`1Xoooo001Woooo00<0000co`0co`005C?o
00030000oooooooo03?oool00ol0VOooooooo`1Xoooo001Woooo0P0001Hco`000`000?ooooooo`0c
oooo00?o09Woooooool0J?ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0coooo00?o
09Woooooool0J?ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0coooo00?o09Wooooo
ool0J?ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0doooo00?o09Woooooool0J?oo
o`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0doooo00?o09Woooooool0J?ooo`00Iooo
o`030000<ol0<ol001@co`000`000?ooooooo`0doooo00?o09Woooooool0J?ooo`00Ioooo`80000E
<ol000<0003oooooool0=?ooo`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000C<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000C<ol000<0003ooooo
ool0=Oooo`03o`2Ioooooooo06Soool006Ooool00`0003?o03?o000C<ol000<0003oooooool0=Ooo
o`03o`2Ioooooooo06Soool005ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0e
oooo00?o09Woooooool0J?ooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0
003oooooool0=_ooo`03o`2Ioooooooo06Soool0063oool00`000?ooooooo`04oooo0P0001<co`00
0`000?ooooooo`0foooo00?o09Woooooool0J?ooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o000B<ol000<0003oooooool0=oooo`03o`2Ioooooooo06Ooool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000A<ol000<0003oooooool0>?ooo`03o`2Ioooooooo06Ooool0063oool2
00001Oooo`030000<ol0<ol0014co`000`000?ooooooo`0hoooo00?o09Woooooool0Ioooo`00Iooo
o`030000<ol0<ol0014co`000`000?ooooooo`0hoooo00?o09Woooooool0Ioooo`00Ioooo`030000
<ol0<ol0014co`000`000?ooooooo`0hoooo00?o09Woooooool0Ioooo`00Ioooo`80000A<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo06Ooool006Ooool00`0003?o03?o000@<ol000<0003ooooo
ool0>Oooo`03o`2Ioooooooo06Ooool006Ooool00`0003?o03?o000@<ol000<0003oooooool0>Ooo
o`03o`2Ioooooooo06Ooool006Ooool00`0003?o03?o000@<ol000<0003oooooool0>Oooo`03o`2I
oooooooo06Ooool006Ooool00`0003?o03?o000?<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
06Ooool006Ooool00`0003?o03?o000?<ol000<0003oooooool0>_ooo`03o`2Ioooooooo06Ooool0
06Ooool00`0003?o03?o000?<ol000<0003oooooool0>_ooo`03o`2Ioooooooo06Ooool006Ooool2
000043?o00030000oooooooo03[oool00ol0VOooooooo`1Woooo001Woooo00<0000co`0co`003S?o
00030000oooooooo03_oool00ol0VOooooooo`1Woooo001Woooo00<0000co`0co`003S?o00030000
oooooooo03_oool00ol0VOooooooo`1Woooo001Woooo00<0000co`0co`003S?o00030000oooooooo
03_oool00ol0VOooooooo`1Woooo001Woooo00<0000co`0co`003S?o00030000oooooooo03_oool0
0ol0VOooooooo`1Woooo001Woooo00<0000co`0co`003C?o00030000oooooooo03coool00ol0VOoo
ooooo`1Woooo001Woooo0P0000hco`000`000?ooooooo`0loooo00?o09Woooooool0Ioooo`00Iooo
o`030000<ol0<ol000dco`000`000?ooooooo`0loooo00?o09Woooooool0Ioooo`00Ioooo`030000
<ol0<ol000dco`000`000?ooooooo`0loooo00?o09Woooooool0Ioooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`0moooo00?o09Woooooool0Ioooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`0moooo00?o09Woooooool0Ioooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`0moooo00?o09Woooooool0Ioooo`00Ioooo`80000=<ol000<0003oooooool0?Oooo`03o`2I
oooooooo06Ooool006Ooool00`0003?o03?o000<<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
06Ooool006Ooool00`0003?o03?o000<<ol000<0003oooooool0?Oooo`03o`2Ioooooooo06Ooool0
06Ooool00`0003?o03?o000;<ol000<0003oooooool0?_ooo`03o`2Ioooooooo06Ooool0063oool2
00001Oooo`030000<ol0<ol000/co`000`000?ooooooo`0noooo00?o09Woooooool0Ioooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0noooo00?o09Wooooo
ool0Ioooo`00HOooo`030000oooooooo00?oool2000033?o00030000oooooooo03koool00ol0VOoo
ooooo`1Woooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`0n
oooo00?o09Woooooool0Ioooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`0noooo00?o09Woooooool0Ioooo`00H?ooo`800005oooo00<0000co`0co`002S?o
00030000oooooooo03ooool00ol0VOooooooo`1Woooo001Woooo00<0000co`0co`002S?o00030000
oooooooo03ooool00ol0VOooooooo`1Woooo001Woooo00<0000co`0co`002S?o00030000oooooooo
03ooool00ol0VOooooooo`1Woooo001Woooo00<0000co`0co`002S?o00030000oooooooo03ooool0
0ol0VOooooooo`1Woooo001Woooo0P0000/co`000`000?ooooooo`0ooooo00?o09Woooooool0Iooo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`0ooooo00?o09Woooooool0Ioooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`10oooo00?o09Woooooool0Ioooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`10oooo00?o09Woooooool0Ioooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`10oooo00?o09Woooooool0Ioooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`10oooo00?o09Woooooool0Ioooo`00Ioooo`80000:<ol000<0003oooooool0@?oo
o`03o`2Ioooooooo06Ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0@?ooo`03o`2I
oooooooo06Ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0@?ooo`03o`2Ioooooooo
06Ooool006Ooool00`0003?o03?o0008<ol000<0003oooooool0@Oooo`03o`2Ioooooooo06Ooool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool0@Oooo`03o`2Ioooooooo06Ooool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0@Oooo`03o`2Ioooooooo06Ooool006Ooool200002C?o
00030000oooooooo047oool00ol0VOooooooo`1Woooo001Woooo00<0000co`0co`0023?o00030000
oooooooo047oool00ol0VOooooooo`1Woooo001Woooo00<0000co`0co`0023?o00030000oooooooo
047oool00ol0VOooooooo`1Woooo001Woooo00<0000co`0co`001c?o00030000oooooooo04;oool0
0ol0VOooooooo`1Woooo001Woooo00<0000co`0co`001c?o00030000oooooooo04;oool00ol0VOoo
ooooo`1Woooo001Woooo00<0000co`0co`001c?o00030000oooooooo04;oool00ol0VOooooooo`1W
oooo001Woooo0P0000Pco`000`000?ooooooo`12oooo00?o09Woooooool0Ioooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`12oooo00?o09Woooooool0Ioooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`12oooo00?o09Woooooool0Ioooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`12oooo00?o09Woooooool0Ioooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`12oooo00?o09Woooooool0Ioooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000
oooooooo04;oool00ol0VOooooooo`1Woooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol0
00Lco`000`000?ooooooo`12oooo00?o09Woooooool0Ioooo`00Goooo`D00003oooo0P0000Pco`00
0`000?ooooooo`12oooo00?o09Woooooool0Ioooo`00Goooo`040000oooooooo00001?ooo`Xco`2_
oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Iooo
o`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000
oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool200001?ooo`800003oooo0`0000Coool200001?ooo`030000oooooooo07Soool006Ooool9
<ol02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001j
oooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00002Oooo`<00002oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00Ioooo`Tco`08
oooo00<0003oooooool01@0000coool010000?ooooooo`0000Soool010000?ooooooo`0000?oool2
00001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000[oool300000oooo`800003
oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.64043 .12361 L
.64559 .12361 L
.65045 .12361 L
.65482 .12361 L
.65602 .12361 L
.65728 .12361 L
.65836 .12361 L
s
.65836 .12361 m
.65883 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .1102 L
.06244 .09853 L
.08426 .08818 L
.10458 .08055 L
.12297 .07508 L
.14264 .07052 L
.15285 .06861 L
.16394 .06687 L
.17353 .0656 L
.18408 .06446 L
.19364 .06362 L
.20392 .06291 L
.20959 .06261 L
.21478 .06237 L
.2197 .06219 L
.22495 .06204 L
.22761 .06197 L
.23011 .06192 L
.23255 .06188 L
.23479 .06186 L
.23693 .06183 L
.23802 .06182 L
.23918 .06182 L
.24035 .06181 L
.24145 .06181 L
.24275 .0618 L
.24393 .0618 L
.24522 .0618 L
.24587 .06181 L
.24658 .06181 L
.24784 .06181 L
.24903 .06182 L
.2517 .06184 L
.25458 .06187 L
.25983 .06195 L
.26466 .06205 L
.27446 .06233 L
.28358 .06266 L
.30428 .06366 L
.32302 .06481 L
.33288 .0655 L
.34333 .06627 L
.34861 .06657 L
.35162 .0667 L
.35443 .06679 L
.35576 .06682 L
.35701 .06685 L
.35815 .06687 L
.35937 .06689 L
Mistroke
.36069 .0669 L
.36191 .06691 L
.36265 .06691 L
.36336 .06692 L
.36467 .06692 L
.36584 .06691 L
.36713 .0669 L
.36778 .0669 L
.36847 .06689 L
.36972 .06687 L
.37215 .06683 L
.37436 .06678 L
.37974 .06662 L
.38482 .0664 L
.3945 .06587 L
.40477 .06514 L
.42321 .06348 L
.46101 .05904 L
.50126 .05335 L
.54 .0474 L
.5812 .04096 L
.60176 .03784 L
.62087 .03506 L
.63933 .03253 L
.64465 .03184 L
.64966 .0312 L
.65416 .03065 L
.65539 .0305 L
.6567 .03034 L
.65781 .03021 L
.65903 .12361 L
.66033 .12361 L
.66154 .12361 L
.66426 .12361 L
.66922 .12361 L
.67852 .12361 L
.69942 .12361 L
.73866 .12361 L
.77638 .12361 L
.81655 .12361 L
.8552 .12361 L
.89631 .12361 L
.9359 .12361 L
.97398 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`17oooo1`1VofSoool0
06Ooool00`000?ooooooo`12oooo1@1Vo`Koool00`1Vooooooooo`1Voooo001Woooo00<0003ooooo
ool0>?ooo`X0I_l;oooo00<0I_ooooooool0I_ooo`00Ioooo`030000oooooooo03;oool606Ko5Ooo
o`0306Kooooooooo06Koool006Ooool00`000?ooooooo`0]oooo1@1Voa_oool00`1Vooooooooo`1V
oooo001Woooo0P0002Woool506Ko8?ooo`0306Kooooooooo06Koool006Ooool00`000?ooooooo`0Q
oooo1`1VobGoool00`1Vooooooooo`1Voooo001Woooo00<0003oooooool05oooo`X0I_l/oooo00<0
I_ooooooool0I_ooo`00?_ooobH0I_l3oooo00<0003oooooool04?ooo`L0I_lfoooo00<0I_oooooo
ool0I_ooo`00=_ooo`P0I_lVoooo0`1Vo`03000006Ko06Ko0100I_lmoooo00<0I_ooooooool0I_oo
o`00<_ooo`@0I_laoooo00<0003oooooool0COooo`0306Kooooooooo06Koool002koool406Ko=Ooo
o`80001>oooo00<0I_ooooooool0I_ooo`005oooo`D0000>oooo101Vo`coool200001?ooo`800004
oooo0P0001ooool00`000?ooooooo`0Noooo0P0000Coool200001?ooo`80000Ooooo1@0001goool5
00000_ooo`800004oooo0P00023oool400005_ooo`006Oooo`030000oooooooo00coool206Ko3ooo
o`040000oooooooo00002?ooo`040000oooooooo00007_ooo`030000oooooooo01goool010000?oo
ooooo`0000Soool010000?ooooooo`00023oool00`000?ooooooo`0Ooooo00<0003oooooool01ooo
o`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0:oooo0P1V
oa7oool010000?ooooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000
oooooooo00002oooo`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_oo
o`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`08
oooo0P1Vo`goool400000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool07oooo`030000oooooooo00Soool2
00008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`06oooo0P1VoaGoool010000?oo
ooooo`0000Woool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Ooo
o`030000oooooooo023oool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`030000oooooooo
01ooool010000?ooooooo`0001Koool001Soool200001_ooo`80I_lHoooo0P0000[oool300007_oo
o`80000Ooooo0P0000[oool300007oooo`80000Poooo0P0000[oool300008?ooo`80000Goooo000N
oooo0P1VodOoool00`000?ooooooo`1=oooo00<0I_ooooooool0I_ooo`007?ooo`80I_m9oooo00<0
003oooooool0COooo`0306Kooooooooo06Koool001_oool00`1Vooooooooo`19oooo00<0003ooooo
ool0COooo`0306Kooooooooo06Koool001Woool206KoC?ooo`030000oooooooo04goool00`1Voooo
ooooo`1Voooo000Goooo0P1Vodkoool00`000?ooooooo`1=oooo00<0I_ooooooool0I_ooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`0013?o02P00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
000co`0co`009C?o00030000<ol0<ol002@co`0@00006Oooo`030000oooooooo02Koool00`000?oo
ooooo`0Eoooo001Woooo00<0000co`0co`00Ac?o00D000000oooool0VOooo`1Woooo001Woooo00<0
000co`0co`00@S?o00D00006oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol003dco`05
00002oooo`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000i<ol01000013oool00ol0VOoo
ooooo`1Voooo001Woooo0P0003Pco`0200005?ooo`03o`2Ioooooooo06Koool006Ooool00`0003?o
03?o000e<ol00P0001Koool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`00<c?o0080000H
oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol0034co`0200006_ooo`03o`2Ioooooooo
06Koool006Ooool00`0003?o03?o000`<ol000<0003oooooool06_ooo`03o`2Ioooooooo06Koool0
06Ooool00`0003?o03?o000^<ol00P0001goool00ol0VOooooooo`1Voooo001Woooo0P0002dco`02
00007oooo`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000[<ol000<0003oooooool07ooo
o`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000Z<ol000<0003oooooool08?ooo`03o`2I
oooooooo06Koool006Ooool00`0003?o03?o000Y<ol000<0003oooooool08Oooo`03o`2Ioooooooo
06Koool006Ooool00`0003?o03?o000X<ol000<0003oooooool08_ooo`03o`2Ioooooooo06Koool0
06Ooool00`0003?o03?o000X<ol000<0003oooooool08_ooo`03o`2Ioooooooo06Koool006Ooool2
0000:3?o00030000oooooooo02?oool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`009S?o
00030000oooooooo02Coool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`009C?o00030000
oooooooo02Goool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`0093?o00030000oooooooo
02Koool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`008c?o00030000oooooooo02Ooool0
0ol0VOooooooo`1Voooo001Woooo00<0000co`0co`008c?o00030000oooooooo02Ooool00ol0VOoo
ooooo`1Voooo001Woooo0P0002<co`000`000?ooooooo`0Xoooo00?o09Woooooool0I_ooo`00Iooo
o`030000<ol0<ol0024co`000`000?ooooooo`0Yoooo00?o09Woooooool0I_ooo`00Ioooo`030000
<ol0<ol0020co`000`000?ooooooo`0Zoooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol0
020co`000`000?ooooooo`0Zoooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol001lco`00
0`000?ooooooo`0[oooo00?o09Woooooool0I_ooo`00Goooo`D00003oooo00<0000co`0co`007c?o
00030000oooooooo02_oool00ol0VOooooooo`1Voooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001hco`000`000?ooooooo`0/oooo00?o09Woooooool0I_ooo`00HOooo`030000oooooooo
00?oool200007c?o00030000oooooooo02coool00ol0VOooooooo`1Voooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0]oooo00?o09Woooooool0I_ooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0;Oooo`03o`2Ioooooooo
06Koool0063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`0^oooo00?o09Wooooo
ool0I_ooo`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`0^oooo00?o09Woooooool0I_oo
o`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`0_oooo00?o09Woooooool0I_ooo`00Iooo
o`80000L<ol000<0003oooooool0;oooo`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000J
<ol000<0003oooooool0<?ooo`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000J<ol000<0
003oooooool0<?ooo`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000I<ol000<0003ooooo
ool0<Oooo`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000I<ol000<0003oooooool0<Ooo
o`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000H<ol000<0003oooooool0<_ooo`03o`2I
oooooooo06Koool006Ooool200006C?o00030000oooooooo03;oool00ol0VOooooooo`1Voooo001W
oooo00<0000co`0co`005c?o00030000oooooooo03?oool00ol0VOooooooo`1Voooo001Woooo00<0
000co`0co`005c?o00030000oooooooo03?oool00ol0VOooooooo`1Voooo001Woooo00<0000co`0c
o`005S?o00030000oooooooo03Coool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`005S?o
00030000oooooooo03Coool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`005S?o00030000
oooooooo03Coool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`005C?o00030000oooooooo
03Goool00ol0VOooooooo`1Voooo001Woooo0P0001Hco`000`000?ooooooo`0eoooo00?o09Wooooo
ool0I_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0eoooo00?o09Woooooool0I_oo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0eoooo00?o09Woooooool0I_ooo`00Iooo
o`030000<ol0<ol001@co`000`000?ooooooo`0foooo00?o09Woooooool0I_ooo`00Ioooo`030000
<ol0<ol001@co`000`000?ooooooo`0foooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`0foooo00?o09Woooooool0I_ooo`00Ioooo`80000E<ol000<0003ooooo
ool0=_ooo`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000C<ol000<0003oooooool0=ooo
o`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000C<ol000<0003oooooool0=oooo`03o`2I
oooooooo06Koool006Ooool00`0003?o03?o000C<ol000<0003oooooool0=oooo`03o`2Ioooooooo
06Koool005ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0goooo00?o09Wooooo
ool0I_ooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0>?oo
o`03o`2Ioooooooo06Koool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`0h
oooo00?o09Woooooool0I_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0
003oooooool0>?ooo`03o`2Ioooooooo06Koool005ooool010000?ooooooo`0000Coool00`0003?o
03?o000A<ol000<0003oooooool0>Oooo`03o`2Ioooooooo06Koool0063oool200001Oooo`030000
<ol0<ol0014co`000`000?ooooooo`0ioooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol0
014co`000`000?ooooooo`0ioooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol0014co`00
0`000?ooooooo`0ioooo00?o09Woooooool0I_ooo`00Ioooo`80000A<ol000<0003oooooool0>_oo
o`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o000@<ol000<0003oooooool0>_ooo`03o`2I
oooooooo06Koool006Ooool00`0003?o03?o000@<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
06Koool006Ooool00`0003?o03?o000@<ol000<0003oooooool0>_ooo`03o`2Ioooooooo06Koool0
06Ooool00`0003?o03?o000?<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Koool006Ooool0
0`0003?o03?o000?<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Koool006Ooool00`0003?o
03?o000?<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Koool006Ooool2000043?o00030000
oooooooo03_oool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`003S?o00030000oooooooo
03coool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`003S?o00030000oooooooo03coool0
0ol0VOooooooo`1Voooo001Woooo00<0000co`0co`003S?o00030000oooooooo03coool00ol0VOoo
ooooo`1Voooo001Woooo00<0000co`0co`003S?o00030000oooooooo03coool00ol0VOooooooo`1V
oooo001Woooo00<0000co`0co`003C?o00030000oooooooo03goool00ol0VOooooooo`1Voooo001W
oooo0P0000hco`000`000?ooooooo`0moooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol0
00dco`000`000?ooooooo`0moooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`0moooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`0noooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0n
oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`0noooo00?o
09Woooooool0I_ooo`00Ioooo`80000=<ol000<0003oooooool0?_ooo`03o`2Ioooooooo06Koool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0?_ooo`03o`2Ioooooooo06Koool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0?_ooo`03o`2Ioooooooo06Koool006Ooool00`0003?o
03?o000;<ol000<0003oooooool0?oooo`03o`2Ioooooooo06Koool0063oool200001Oooo`030000
<ol0<ol000/co`000`000?ooooooo`0ooooo00?o09Woooooool0I_ooo`00Goooo`040000oooooooo
00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0ooooo00?o09Woooooool0I_ooo`00HOoo
o`030000oooooooo00?oool2000033?o00030000oooooooo03ooool00ol0VOooooooo`1Voooo001R
oooo00<0003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`0ooooo00?o09Wooooo
ool0I_ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`0o
oooo00?o09Woooooool0I_ooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo
043oool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`002S?o00030000oooooooo043oool0
0ol0VOooooooo`1Voooo001Woooo00<0000co`0co`002S?o00030000oooooooo043oool00ol0VOoo
ooooo`1Voooo001Woooo00<0000co`0co`002S?o00030000oooooooo043oool00ol0VOooooooo`1V
oooo001Woooo0P0000/co`000`000?ooooooo`10oooo00?o09Woooooool0I_ooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`10oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`11oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`11oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`11oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`11
oooo00?o09Woooooool0I_ooo`00Ioooo`80000:<ol000<0003oooooool0@Oooo`03o`2Ioooooooo
06Koool006Ooool00`0003?o03?o0009<ol000<0003oooooool0@Oooo`03o`2Ioooooooo06Koool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0@Oooo`03o`2Ioooooooo06Koool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0@_ooo`03o`2Ioooooooo06Koool006Ooool00`0003?o
03?o0008<ol000<0003oooooool0@_ooo`03o`2Ioooooooo06Koool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0@_ooo`03o`2Ioooooooo06Koool006Ooool200002C?o00030000oooooooo
04;oool00ol0VOooooooo`1Voooo001Woooo00<0000co`0co`0023?o00030000oooooooo04;oool0
0ol0VOooooooo`1Voooo001Woooo00<0000co`0co`0023?o00030000oooooooo04;oool00ol0VOoo
ooooo`1Voooo001Woooo00<0000co`0co`001c?o00030000oooooooo04?oool00ol0VOooooooo`1V
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo04?oool00ol0VOooooooo`1Voooo001W
oooo00<0000co`0co`001c?o00030000oooooooo04?oool00ol0VOooooooo`1Voooo001Woooo0P00
00Pco`000`000?ooooooo`13oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`13oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`13oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`13
oooo00?o09Woooooool0I_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`13oooo00?o
09Woooooool0I_ooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo04?oool0
0ol0VOooooooo`1Voooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`13oooo00?o09Woooooool0I_ooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`13
oooo00?o09Woooooool0I_ooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0
003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001W
oooo2C?o0;3oool006Ooool9<ol03oooo`030000oooooooo01coool00`000?ooooooo`1ooooo001W
oooo2C?o00koool00`000?ooooooo`08oooo00<0003oooooool04oooo`030000oooooooo07koool0
06Ooool9<ol03_ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_oo
o`800004oooo00<0003oooooool0O_ooo`00Ioooo`Tco`0>oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo
07koool006Ooool9<ol03Oooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003ooooo
ool02Oooo`030000oooooooo07goool006Ooool9<ol03_ooo`030000oooooooo00D0000>oooo00<0
003oooooool02?ooo`030000oooooooo07koool006Ooool9<ol03_ooo`050000oooooooooooo0000
017oool00`000?ooooooo`08oooo00<0003oooooool0O_ooo`00Ioooo`Tco`0?oooo00<0003ooooo
ool04Oooo`800009oooo00<0003oooooool0Ooooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66177 .12361 L
.66298 .12361 L
.66412 .12361 L
s
.66412 .12361 m
.66461 .61803 L
s
0 .4 1 r
.02381 .11881 m
.04262 .10621 L
.06244 .09526 L
.08426 .0856 L
.10458 .07852 L
.12297 .07347 L
.14264 .0693 L
.15285 .06758 L
.16394 .06601 L
.17353 .06488 L
.18408 .06388 L
.19432 .06312 L
.20392 .06257 L
.20911 .06234 L
.21405 .06217 L
.21974 .06201 L
.22242 .06195 L
.22495 .0619 L
.22736 .06187 L
.22998 .06184 L
.23113 .06183 L
.23235 .06182 L
.23339 .06181 L
.23453 .06181 L
.23522 .06181 L
.23587 .06181 L
.23709 .0618 L
.23839 .0618 L
.23913 .06181 L
.23982 .06181 L
.24096 .06181 L
.24221 .06182 L
.24352 .06183 L
.24475 .06183 L
.247 .06186 L
.24937 .06189 L
.2536 .06195 L
.25816 .06205 L
.26314 .06218 L
.27342 .06251 L
.28275 .06289 L
.3037 .06399 L
.3245 .06535 L
.33364 .06602 L
.33848 .06639 L
.34368 .06678 L
.34873 .06708 L
.35334 .06727 L
.35555 .06734 L
.35672 .06737 L
Mistroke
.35797 .0674 L
.35917 .06742 L
.36025 .06744 L
.36134 .06745 L
.36237 .06746 L
.36352 .06746 L
.36478 .06747 L
.3661 .06747 L
.36732 .06746 L
.36848 .06745 L
.36952 .06744 L
.37188 .06741 L
.37441 .06736 L
.37716 .06729 L
.38215 .06712 L
.39157 .06667 L
.40196 .066 L
.42298 .0642 L
.46324 .05953 L
.50198 .05409 L
.54317 .04778 L
.58285 .04158 L
.62101 .03585 L
.6423 .03289 L
.65236 .03158 L
.65677 .03103 L
.65928 .03072 L
.66162 .03043 L
.66278 .0303 L
.66389 .03016 L
.66516 .12361 L
.66632 .12361 L
.67128 .12361 L
.68175 .12361 L
.70072 .12361 L
.73902 .12361 L
.77977 .12361 L
.819 .12361 L
.85672 .12361 L
.89689 .12361 L
.93554 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`17oooo2@1VofKoool0
06Ooool00`000?ooooooo`12oooo1@1Vo`Soool00`1Vooooooooo`1Toooo001Woooo00<0003ooooo
ool0?Oooo`D0I_l=oooo00<0I_ooooooool0I?ooo`00Ioooo`030000oooooooo03Koool706Ko4_oo
o`0306Kooooooooo06Coool006Ooool00`000?ooooooo`0^oooo201VoaWoool00`1Vooooooooo`1T
oooo001Woooo0P0002Woool606Ko8Oooo`0306Kooooooooo06Coool006Ooool00`000?ooooooo`0Q
oooo1`1VobOoool00`1Vooooooooo`1Toooo001Woooo00<0003oooooool05oooo`X0I_l^oooo00<0
I_ooooooool0I?ooo`00?_ooob80I_l7oooo00<0003oooooool03oooo`P0I_lhoooo00<0I_oooooo
ool0I?ooo`00=_ooo`P0I_lRoooo1`1Vo`03000006Ko06Ko00l0I_m0oooo00<0I_ooooooool0I?oo
o`00<_ooo`@0I_laoooo00<0003oooooool0Coooo`0306Kooooooooo06Coool002koool406Ko=Ooo
o`80001@oooo00<0I_ooooooool0I?ooo`005oooo`D0000>oooo101Vo`coool200001?ooo`800004
oooo0P0001ooool00`000?ooooooo`0Noooo0P0000Coool200001?ooo`80000Ooooo1@0001goool5
00000_ooo`800004oooo0P00023oool400005_ooo`006Oooo`030000oooooooo00coool206Ko3ooo
o`040000oooooooo00002?ooo`040000oooooooo00007_ooo`030000oooooooo01goool010000?oo
ooooo`0000Soool010000?ooooooo`00023oool00`000?ooo`1Vo`0Ooooo00<0003oooooool01ooo
o`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`09oooo0`1V
oa7oool010000?ooooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000
oooooooo00002oooo`030000oooooooo01koool00`000?ooo`1Vo`0Ooooo00<0003oooooool02_oo
o`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`06
oooo0`1Vo`koool400000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`80000Qoooo00<0003oool0I_l07oooo`030000oooooooo00Soool2
00008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`04oooo0P1VoaOoool010000?oo
ooooo`0000Woool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Ooo
o`030000oooooooo023oool00`000?ooo`1Vo`0Ooooo00<0003oooooool02?ooo`030000oooooooo
01ooool010000?ooooooo`0001Koool001Soool200001?ooo`80I_lJoooo0P0000[oool300007_oo
o`80000Ooooo0P0000[oool300007oooo`8000000oooo`1Vooooo`0Moooo0P0000[oool300008?oo
o`80000Goooo000Loooo0P1VodWoool00`000?ooooooo`1?oooo00<0I_ooooooool0I?ooo`006ooo
o`0306Kooooooooo04Woool00`000?ooooooo`1?oooo00<0I_ooooooool0I?ooo`006Oooo`80I_m<
oooo00<0003oooooool0Coooo`0306Kooooooooo06Coool001Ooool206KoC_ooo`030000oooooooo
04ooool00`1Vooooooooo`1Toooo000Foooo00<0I_ooooooool0C_ooo`030000oooooooo04ooool0
0`1Vooooooooo`1Toooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0o`2I00Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o00<000000ol0V@00
0000000:00006Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0c
o`00Ac?o00D00003oooo00?o09Woooooool0I?ooo`00Ioooo`030000<ol0<ol0048co`0500002?oo
o`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000m<ol01@0000goool00ol0VOooooooo`1T
oooo001Woooo00<0000co`0co`00>C?o00@0000Boooo00?o09Woooooool0I?ooo`00Ioooo`80000h
<ol00P0001Koool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`00=C?o0080000Hoooo00?o
09Woooooool0I?ooo`00Ioooo`030000<ol0<ol003<co`0200006_ooo`03o`2Ioooooooo06Coool0
06Ooool00`0003?o03?o000a<ol00P0001coool00ol0VOooooooo`1Toooo001Woooo00<0000co`0c
o`00<3?o00030000oooooooo01coool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`00;S?o
0080000Ooooo00?o09Woooooool0I?ooo`00Ioooo`80000]<ol00P00027oool00ol0VOooooooo`1T
oooo001Woooo00<0000co`0co`00:c?o00030000oooooooo027oool00ol0VOooooooo`1Toooo001W
oooo00<0000co`0co`00:S?o00030000oooooooo02;oool00ol0VOooooooo`1Toooo001Woooo00<0
000co`0co`00:C?o00030000oooooooo02?oool00ol0VOooooooo`1Toooo001Woooo00<0000co`0c
o`00:3?o00030000oooooooo02Coool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`00:3?o
00030000oooooooo02Coool00ol0VOooooooo`1Toooo001Woooo0P0002Pco`000`000?ooooooo`0U
oooo00?o09Woooooool0I?ooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`0Voooo00?o
09Woooooool0I?ooo`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`0Woooo00?o09Wooooo
ool0I?ooo`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`0Xoooo00?o09Woooooool0I?oo
o`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`0Yoooo00?o09Woooooool0I?ooo`00Iooo
o`030000<ol0<ol002<co`000`000?ooooooo`0Yoooo00?o09Woooooool0I?ooo`00Ioooo`80000S
<ol000<0003oooooool0:_ooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000Q<ol000<0
003oooooool0:oooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000P<ol000<0003ooooo
ool0;?ooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000P<ol000<0003oooooool0;?oo
o`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000O<ol000<0003oooooool0;Oooo`03o`2I
oooooooo06Coool005ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`0]oooo00?o
09Woooooool0I?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003ooooo
ool0;_ooo`03o`2Ioooooooo06Coool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?oo
ooooo`0^oooo00?o09Woooooool0I?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M
<ol000<0003oooooool0;oooo`03o`2Ioooooooo06Coool0067oool00`000?ooooooo`03oooo00<0
000co`0co`007C?o00030000oooooooo02ooool00ol0VOooooooo`1Toooo001Poooo0P0000Goool0
0`0003?o03?o000L<ol000<0003oooooool0<?ooo`03o`2Ioooooooo06Coool006Ooool00`0003?o
03?o000L<ol000<0003oooooool0<?ooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000K
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo06Coool006Ooool2000073?o00030000oooooooo
037oool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`006S?o00030000oooooooo03;oool0
0ol0VOooooooo`1Toooo001Woooo00<0000co`0co`006S?o00030000oooooooo03;oool00ol0VOoo
ooooo`1Toooo001Woooo00<0000co`0co`006C?o00030000oooooooo03?oool00ol0VOooooooo`1T
oooo001Woooo00<0000co`0co`006C?o00030000oooooooo03?oool00ol0VOooooooo`1Toooo001W
oooo00<0000co`0co`0063?o00030000oooooooo03Coool00ol0VOooooooo`1Toooo001Woooo0P00
01Tco`000`000?ooooooo`0doooo00?o09Woooooool0I?ooo`00Ioooo`030000<ol0<ol001Lco`00
0`000?ooooooo`0eoooo00?o09Woooooool0I?ooo`00Ioooo`030000<ol0<ol001Lco`000`000?oo
ooooo`0eoooo00?o09Woooooool0I?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0f
oooo00?o09Woooooool0I?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0foooo00?o
09Woooooool0I?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`0foooo00?o09Wooooo
ool0I?ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0goooo00?o09Woooooool0I?oo
o`00Ioooo`80000F<ol000<0003oooooool0=oooo`03o`2Ioooooooo06Coool006Ooool00`0003?o
03?o000E<ol000<0003oooooool0=oooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000E
<ol000<0003oooooool0=oooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000D<ol000<0
003oooooool0>?ooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000D<ol000<0003ooooo
ool0>?ooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000D<ol000<0003oooooool0>?oo
o`03o`2Ioooooooo06Coool006Ooool200005C?o00030000oooooooo03Soool00ol0VOooooooo`1T
oooo001Woooo00<0000co`0co`004c?o00030000oooooooo03Woool00ol0VOooooooo`1Toooo001W
oooo00<0000co`0co`004c?o00030000oooooooo03Woool00ol0VOooooooo`1Toooo001Woooo00<0
000co`0co`004c?o00030000oooooooo03Woool00ol0VOooooooo`1Toooo001Ooooo100000Coool0
0`0003?o03?o000C<ol000<0003oooooool0>Oooo`03o`2Ioooooooo06Coool005ooool00`000?oo
ooooo`05oooo00<0000co`0co`004S?o00030000oooooooo03[oool00ol0VOooooooo`1Toooo001P
oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0>_ooo`03o`2Ioooooooo06Coool0
067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo03[oool00ol0VOoo
ooooo`1Toooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo
03_oool00ol0VOooooooo`1Toooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003ooooo
ool0>oooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000A<ol000<0003oooooool0>ooo
o`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000A<ol000<0003oooooool0>oooo`03o`2I
oooooooo06Coool006Ooool200004C?o00030000oooooooo03coool00ol0VOooooooo`1Toooo001W
oooo00<0000co`0co`0043?o00030000oooooooo03coool00ol0VOooooooo`1Toooo001Woooo00<0
000co`0co`0043?o00030000oooooooo03coool00ol0VOooooooo`1Toooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo03coool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`003c?o
00030000oooooooo03goool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`003c?o00030000
oooooooo03goool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`003c?o00030000oooooooo
03goool00ol0VOooooooo`1Toooo001Woooo0P00010co`000`000?ooooooo`0moooo00?o09Wooooo
ool0I?ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0noooo00?o09Woooooool0I?oo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`0noooo00?o09Woooooool0I?ooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`0noooo00?o09Woooooool0I?ooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`0noooo00?o09Woooooool0I?ooo`00Ioooo`030000<ol0<ol0
00dco`000`000?ooooooo`0ooooo00?o09Woooooool0I?ooo`00Ioooo`80000><ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000=<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000=<ol000<0003oooooool0?oooo`03o`2I
oooooooo06Coool006Ooool00`0003?o03?o000<<ol000<0003oooooool0@?ooo`03o`2Ioooooooo
06Coool006Ooool00`0003?o03?o000<<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06Coool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06Coool006Ooool2
00003C?o00030000oooooooo043oool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`0033?o
00030000oooooooo043oool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`0033?o00030000
oooooooo043oool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`002c?o00030000oooooooo
047oool00ol0VOooooooo`1Toooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003ooooo
ool0@Oooo`03o`2Ioooooooo06Coool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo06Coool0067oool00`000?ooooooo`03oooo0P00
00`co`000`000?ooooooo`11oooo00?o09Woooooool0I?ooo`00H_ooo`030000oooooooo00;oool0
0`0003?o03?o000;<ol000<0003oooooool0@Oooo`03o`2Ioooooooo06Coool005ooool010000?oo
ooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0@Oooo`03o`2Ioooooooo06Coool0
063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`12oooo00?o09Woooooool0I?oo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`12oooo00?o09Woooooool0I?ooo`00Iooo
o`030000<ol0<ol000Xco`000`000?ooooooo`12oooo00?o09Woooooool0I?ooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`12oooo00?o09Woooooool0I?ooo`00Ioooo`80000;<ol000<0
003oooooool0@_ooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0@ooo
o`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0@oooo`03o`2I
oooooooo06Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0@oooo`03o`2Ioooooooo
06Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0@oooo`03o`2Ioooooooo06Coool0
06Ooool200002S?o00030000oooooooo04?oool00ol0VOooooooo`1Toooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo04?oool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`002C?o
00030000oooooooo04?oool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`0023?o00030000
oooooooo04Coool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`0023?o00030000oooooooo
04Coool00ol0VOooooooo`1Toooo001Woooo00<0000co`0co`0023?o00030000oooooooo04Coool0
0ol0VOooooooo`1Toooo001Woooo0P0000Tco`000`000?ooooooo`14oooo00?o09Woooooool0I?oo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`14oooo00?o09Woooooool0I?ooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`14oooo00?o09Woooooool0I?ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`15oooo00?o09Woooooool0I?ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`15oooo00?o09Woooooool0I?ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`15oooo00?o09Woooooool0I?ooo`00Ioooo`800008<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo06Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0AOooo`03o`2I
oooooooo06Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0AOooo`03o`2Ioooooooo
06Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0AOooo`03o`2Ioooooooo06Coool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0AOooo`03o`2Ioooooooo06Coool0067oool3
00000oooo`030000<ol0<ol000Lco`000`000?ooooooo`15oooo00?o09Woooooool0I?ooo`00H_oo
o`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0AOooo`03o`2Ioooooooo
06Coool005ooool500000oooo`800008<ol000<0003oooooool0AOooo`03o`2Ioooooooo06Coool0
05ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[ooo
o`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o
00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001?ooo`800003oooo1000
00?oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00002
oooo00<0003oooooool01?ooo`030000oooooooo07Soool006Ooool9<ol01oooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003_oo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001Woooo2C?o
00Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`800003oooo00<0003oooooool0NOoo
o`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66412 .12361 L
.66652 .12361 L
.66906 .12361 L
.67014 .12361 L
.67129 .12361 L
s
.67129 .12361 m
.67179 .61803 L
s
0 .4 1 r
.02381 .11429 m
.04262 .10246 L
.06244 .09221 L
.08426 .0832 L
.10458 .07664 L
.12297 .07199 L
.14264 .0682 L
.15285 .06664 L
.16394 .06524 L
.17353 .06425 L
.18408 .06338 L
.19432 .06274 L
.20392 .0623 L
.20921 .06212 L
.21405 .06199 L
.21672 .06194 L
.21964 .06189 L
.22239 .06185 L
.22495 .06183 L
.22623 .06182 L
.22694 .06181 L
.22759 .06181 L
.22875 .06181 L
.23002 .0618 L
.23074 .0618 L
.23141 .0618 L
.23267 .0618 L
.23338 .06181 L
.23404 .06181 L
.23552 .06181 L
.2367 .06182 L
.23781 .06183 L
.24034 .06185 L
.24281 .06188 L
.24547 .06192 L
.2502 .06201 L
.25518 .06213 L
.26408 .0624 L
.28382 .06325 L
.30219 .06429 L
.32092 .06555 L
.34123 .06711 L
.34663 .06749 L
.34958 .06765 L
.35234 .06777 L
.35489 .06786 L
.35721 .06793 L
.3598 .06798 L
.36122 .068 L
.36192 .06801 L
Mistroke
.36258 .06802 L
.36385 .06802 L
.365 .06803 L
.36624 .06803 L
.36694 .06803 L
.36758 .06803 L
.36866 .06802 L
.36984 .06801 L
.37107 .068 L
.37222 .06798 L
.37488 .06793 L
.37729 .06788 L
.38273 .0677 L
.38755 .0675 L
.39267 .06724 L
.40185 .06666 L
.42263 .06494 L
.46043 .06068 L
.50068 .05513 L
.53942 .04926 L
.58062 .04281 L
.62029 .03679 L
.6403 .03394 L
.65845 .03154 L
.66331 .03093 L
.66587 .03062 L
.66857 .03029 L
.66971 .03015 L
.67093 .03001 L
.67164 .12361 L
.67228 .12361 L
.67353 .12361 L
.6781 .12361 L
.69907 .12361 L
.73888 .12361 L
.77718 .12361 L
.81793 .12361 L
.85716 .12361 L
.89488 .12361 L
.93505 .12361 L
.97371 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1<oooo1@1VofGoool0
06Ooool00`000?ooooooo`11oooo2`1Vo`Coool00`1Vooooooooo`1Soooo001Woooo00<0003ooooo
ool0??ooo`D0I_l?oooo00<0I_ooooooool0Hoooo`00Ioooo`030000oooooooo03Ooool506Ko5?oo
o`0306Kooooooooo06?oool006Ooool00`000?ooooooo`0boooo1@1VoaWoool00`1Vooooooooo`1S
oooo001Woooo0P0002coool706Ko7_ooo`0306Kooooooooo06?oool006Ooool00`000?ooooooo`0Q
oooo2P1VobGoool00`1Vooooooooo`1Soooo001Woooo00<0003oooooool06Oooo`P0I_l_oooo00<0
I_ooooooool0Hoooo`00??ooob@0I_l7oooo00<0003oooooool05?ooo`D0I_lgoooo00<0I_oooooo
ool0Hoooo`00<_ooo`X0I_lToooo1`1Vo`03000006Ko06Ko01@0I_lloooo00<0I_ooooooool0Hooo
o`00;_ooo`@0I_leoooo00<0003oooooool0D?ooo`0306Kooooooooo06?oool002[oool406Ko>Ooo
o`80001Aoooo00<0I_ooooooool0Hoooo`005oooo`D0000<oooo0P1Voa3oool200001?ooo`800004
oooo0P0001ooool00`000?ooooooo`0Noooo0P0000Coool200001?ooo`80000Ooooo1@00000306Ko
oooooooo01[oool500000_ooo`800004oooo0P00023oool400005_ooo`006Oooo`030000oooooooo
00Woool306Ko4Oooo`040000oooooooo00002?ooo`040000oooooooo00007_ooo`030000oooooooo
01goool010000?ooooooo`0000Soool010000?ooooooo`00023oool010000?ooooooo`1Voakoool0
0`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003oooooool05oooo`006Oooo`030000
oooooooo00Koool306Ko5?ooo`040000oooooooo00002oooo`030000oooooooo01coool00`000?oo
ooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool07_ooo`040000oooooooo06Ko7_oo
o`030000oooooooo00[oool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004
oooo00<0003oooooool01?ooo`80I_lAoooo100000;oool010000?ooooooo`0000Woool200007ooo
o`030000oooooooo01goool010000?ooooooo`0000Woool200008Oooo`040000oooooooo06Ko7_oo
o`030000oooooooo00Soool200008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`02
oooo0P1VoaWoool010000?ooooooo`0000Woool00`000?ooooooo`0Noooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`030000oooooooo023oool010000?ooooooo`1Voakoool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`800002oooo0P1V
oacoool200002_ooo`<0000Noooo0P0001ooool200002_ooo`<0000Ooooo0P0000;oool00`1Voooo
ooooo`0Koooo0P0000[oool300008?ooo`80000Goooo000Koooo00<0I_ooooooool0BOooo`030000
oooooooo053oool00`1Vooooooooo`1Soooo000Ioooo0P1Vodcoool00`000?ooooooo`1@oooo00<0
I_ooooooool0Hoooo`005oooo`80I_m>oooo00<0003oooooool0D?ooo`0306Kooooooooo06?oool0
01Koool00`1Vooooooooo`1>oooo00<0003oooooool0D?ooo`0306Kooooooooo06?oool006Ooool0
0`000?ooooooo`1@oooo00<0I_ooooooool0Hoooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`00100003?o03?o0?l0V@@co`000`0003?o03?o0004<ol0:00000;oool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0c
o`0093?o00@000000ol0V@000000000900006Oooo`030000oooooooo02Koool00`000?ooooooo`0E
oooo001Woooo00<0000co`0co`00Ac?o00D00004oooo00?o09Woooooool0Hoooo`00Ioooo`030000
<ol0<ol0048co`0500002Oooo`03o`2Ioooooooo06?oool006Ooool00`0003?o03?o000m<ol01@00
00koool00ol0VOooooooo`1Soooo001Woooo00<0000co`0co`00>C?o00@0000Coooo00?o09Wooooo
ool0Hoooo`00Ioooo`80000h<ol00P0001Ooool00ol0VOooooooo`1Soooo001Woooo00<0000co`0c
o`00=C?o0080000Ioooo00?o09Woooooool0Hoooo`00Ioooo`030000<ol0<ol003<co`0200006ooo
o`03o`2Ioooooooo06?oool006Ooool00`0003?o03?o000a<ol00P0001goool00ol0VOooooooo`1S
oooo001Woooo00<0000co`0co`00<3?o00030000oooooooo01goool00ol0VOooooooo`1Soooo001W
oooo00<0000co`0co`00;S?o0080000Poooo00?o09Woooooool0Hoooo`00Ioooo`80000]<ol00P00
02;oool00ol0VOooooooo`1Soooo001Woooo00<0000co`0co`00:c?o00030000oooooooo02;oool0
0ol0VOooooooo`1Soooo001Woooo00<0000co`0co`00:S?o00030000oooooooo02?oool00ol0VOoo
ooooo`1Soooo001Woooo00<0000co`0co`00:C?o00030000oooooooo02Coool00ol0VOooooooo`1S
oooo001Woooo00<0000co`0co`00:3?o00030000oooooooo02Goool00ol0VOooooooo`1Soooo001W
oooo00<0000co`0co`00:3?o00030000oooooooo02Goool00ol0VOooooooo`1Soooo001Woooo0P00
02Pco`000`000?ooooooo`0Voooo00?o09Woooooool0Hoooo`00Ioooo`030000<ol0<ol002Hco`00
0`000?ooooooo`0Woooo00?o09Woooooool0Hoooo`00Ioooo`030000<ol0<ol002Dco`000`000?oo
ooooo`0Xoooo00?o09Woooooool0Hoooo`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`0Y
oooo00?o09Woooooool0Hoooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`0Zoooo00?o
09Woooooool0Hoooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`0Zoooo00?o09Wooooo
ool0Hoooo`00Ioooo`80000S<ol000<0003oooooool0:oooo`03o`2Ioooooooo06?oool006Ooool0
0`0003?o03?o000Q<ol000<0003oooooool0;?ooo`03o`2Ioooooooo06?oool006Ooool00`0003?o
03?o000P<ol000<0003oooooool0;Oooo`03o`2Ioooooooo06?oool006Ooool00`0003?o03?o000P
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo06?oool006Ooool00`0003?o03?o000O<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo06?oool005ooool500000oooo`030000<ol0<ol001lco`00
0`000?ooooooo`0^oooo00?o09Woooooool0Hoooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o000N<ol000<0003oooooool0;oooo`03o`2Ioooooooo06?oool0067oool00`000?ooooooo`03
oooo0P0001lco`000`000?ooooooo`0_oooo00?o09Woooooool0Hoooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003oooooool0<?ooo`03o`2Ioooooooo06?oool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo033oool00ol0VOooooooo`1S
oooo001Poooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0<Oooo`03o`2Ioooooooo
06?oool006Ooool00`0003?o03?o000L<ol000<0003oooooool0<Oooo`03o`2Ioooooooo06?oool0
06Ooool00`0003?o03?o000K<ol000<0003oooooool0<_ooo`03o`2Ioooooooo06?oool006Ooool2
000073?o00030000oooooooo03;oool00ol0VOooooooo`1Soooo001Woooo00<0000co`0co`006S?o
00030000oooooooo03?oool00ol0VOooooooo`1Soooo001Woooo00<0000co`0co`006S?o00030000
oooooooo03?oool00ol0VOooooooo`1Soooo001Woooo00<0000co`0co`006C?o00030000oooooooo
03Coool00ol0VOooooooo`1Soooo001Woooo00<0000co`0co`006C?o00030000oooooooo03Coool0
0ol0VOooooooo`1Soooo001Woooo00<0000co`0co`0063?o00030000oooooooo03Goool00ol0VOoo
ooooo`1Soooo001Woooo0P0001Tco`000`000?ooooooo`0eoooo00?o09Woooooool0Hoooo`00Iooo
o`030000<ol0<ol001Lco`000`000?ooooooo`0foooo00?o09Woooooool0Hoooo`00Ioooo`030000
<ol0<ol001Lco`000`000?ooooooo`0foooo00?o09Woooooool0Hoooo`00Ioooo`030000<ol0<ol0
01Hco`000`000?ooooooo`0goooo00?o09Woooooool0Hoooo`00Ioooo`030000<ol0<ol001Hco`00
0`000?ooooooo`0goooo00?o09Woooooool0Hoooo`00Ioooo`030000<ol0<ol001Hco`000`000?oo
ooooo`0goooo00?o09Woooooool0Hoooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0h
oooo00?o09Woooooool0Hoooo`00Ioooo`80000F<ol000<0003oooooool0>?ooo`03o`2Ioooooooo
06?oool006Ooool00`0003?o03?o000E<ol000<0003oooooool0>?ooo`03o`2Ioooooooo06?oool0
06Ooool00`0003?o03?o000E<ol000<0003oooooool0>?ooo`03o`2Ioooooooo06?oool006Ooool0
0`0003?o03?o000D<ol000<0003oooooool0>Oooo`03o`2Ioooooooo06?oool006Ooool00`0003?o
03?o000D<ol000<0003oooooool0>Oooo`03o`2Ioooooooo06?oool006Ooool00`0003?o03?o000D
<ol000<0003oooooool0>Oooo`03o`2Ioooooooo06?oool006Ooool200005C?o00030000oooooooo
03Woool00ol0VOooooooo`1Soooo001Woooo00<0000co`0co`004c?o00030000oooooooo03[oool0
0ol0VOooooooo`1Soooo001Woooo00<0000co`0co`004c?o00030000oooooooo03[oool00ol0VOoo
ooooo`1Soooo001Woooo00<0000co`0co`004c?o00030000oooooooo03[oool00ol0VOooooooo`1S
oooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
06?oool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo03_oool0
0ol0VOooooooo`1Soooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0>ooo
o`03o`2Ioooooooo06?oool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000
oooooooo03coool00ol0VOooooooo`1Roooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`004C?o00030000oooooooo03goool00ol0VOooooooo`1Roooo001Poooo0P0000Goool00`0003?o
03?o000A<ol000<0003oooooool0?Oooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o000A
<ol000<0003oooooool0?Oooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o000A<ol000<0
003oooooool0?Oooo`03o`2Ioooooooo06;oool006Ooool200004C?o00030000oooooooo03koool0
0ol0VOooooooo`1Roooo001Woooo00<0000co`0co`0043?o00030000oooooooo03koool00ol0VOoo
ooooo`1Roooo001Woooo00<0000co`0co`0043?o00030000oooooooo03koool00ol0VOooooooo`1R
oooo001Woooo00<0000co`0co`0043?o00030000oooooooo03koool00ol0VOooooooo`1Roooo001W
oooo00<0000co`0co`003c?o00030000oooooooo03ooool00ol0VOooooooo`1Roooo001Woooo00<0
000co`0co`003c?o00030000oooooooo03ooool00ol0VOooooooo`1Roooo001Woooo00<0000co`0c
o`003c?o00030000oooooooo03ooool00ol0VOooooooo`1Roooo001Woooo0P00010co`000`000?oo
ooooo`0ooooo00?o09Woooooool0H_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`10
oooo00?o09Woooooool0H_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`10oooo00?o
09Woooooool0H_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`10oooo00?o09Wooooo
ool0H_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`10oooo00?o09Woooooool0H_oo
o`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`11oooo00?o09Woooooool0H_ooo`00Iooo
o`80000><ol000<0003oooooool0@Oooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o000=
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o000=<ol000<0
003oooooool0@Oooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0@_oo
o`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0@_ooo`03o`2I
oooooooo06;oool006Ooool200003C?o00030000oooooooo04;oool00ol0VOooooooo`1Roooo001W
oooo00<0000co`0co`0033?o00030000oooooooo04;oool00ol0VOooooooo`1Roooo001Woooo00<0
000co`0co`0033?o00030000oooooooo04;oool00ol0VOooooooo`1Roooo001Woooo00<0000co`0c
o`002c?o00030000oooooooo04?oool00ol0VOooooooo`1Roooo001Poooo0P0000Goool00`0003?o
03?o000;<ol000<0003oooooool0@oooo`03o`2Ioooooooo06;oool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool0@oooo`03o`2Ioooooooo06;oool0067oool0
0`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`13oooo00?o09Woooooool0H_ooo`00H_oo
o`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0@oooo`03o`2Ioooooooo
06;oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0@ooo
o`03o`2Ioooooooo06;oool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`14
oooo00?o09Woooooool0H_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`14oooo00?o
09Woooooool0H_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`14oooo00?o09Wooooo
ool0H_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`14oooo00?o09Woooooool0H_oo
o`00Ioooo`80000;<ol000<0003oooooool0A?ooo`03o`2Ioooooooo06;oool006Ooool00`0003?o
03?o000:<ol000<0003oooooool0A?ooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o0009
<ol000<0003oooooool0AOooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o0009<ol000<0
003oooooool0AOooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo06;oool006Ooool200002S?o00030000oooooooo04Goool00ol0VOooooooo`1R
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo04Goool00ol0VOooooooo`1Roooo001W
oooo00<0000co`0co`002C?o00030000oooooooo04Goool00ol0VOooooooo`1Roooo001Woooo00<0
000co`0co`0023?o00030000oooooooo04Koool00ol0VOooooooo`1Roooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo04Koool00ol0VOooooooo`1Roooo001Woooo00<0000co`0co`0023?o
00030000oooooooo04Koool00ol0VOooooooo`1Roooo001Woooo0P0000Tco`000`000?ooooooo`16
oooo00?o09Woooooool0H_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`16oooo00?o
09Woooooool0H_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`16oooo00?o09Wooooo
ool0H_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`17oooo00?o09Woooooool0H_oo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`17oooo00?o09Woooooool0H_ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`17oooo00?o09Woooooool0H_ooo`00Ioooo`800008
<ol000<0003oooooool0Aoooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo06;oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Aoooo`03o`2I
oooooooo06;oool0067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`17oooo00?o
09Woooooool0H_ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo06;oool005ooool500000oooo`800008<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo06;oool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000
oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Iooo
o`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Iooo
o`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool2
00001?ooo`800005oooo0`0000;oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00@0003oooooool00005oooo00D0003oooooooooool00000N_ooo`00Ioooo`Tco`07oooo00<0
003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo00@0003oooooool00002
oooo1@0000?oool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003_oo
o`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000Aoooo00<0003oooooool01ooo
o`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001Woooo2C?o
00Woool00`000?ooooooo`0Aoooo0P0000[oool200001Oooo`800002oooo00<0003oooooool0NOoo
o`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66412 .12361 L
.66906 .12361 L
.67133 .12361 L
.67373 .12361 L
.67578 .12361 L
.67694 .12361 L
s
.67694 .12361 m
.67738 .61803 L
s
0 .4 1 r
.02381 .11005 m
.04262 .09894 L
.06244 .08936 L
.08426 .08097 L
.10458 .0749 L
.12297 .07064 L
.14264 .0672 L
.15285 .0658 L
.16394 .06456 L
.17353 .0637 L
.18408 .06296 L
.18902 .06268 L
.19432 .06243 L
.19891 .06225 L
.20392 .06209 L
.20684 .06201 L
.20955 .06195 L
.21236 .0619 L
.2149 .06187 L
.2174 .06184 L
.21855 .06183 L
.21976 .06182 L
.22106 .06181 L
.22225 .06181 L
.22354 .0618 L
.22427 .0618 L
.22495 .0618 L
.22621 .0618 L
.22685 .06181 L
.22755 .06181 L
.22879 .06181 L
.22995 .06182 L
.23257 .06184 L
.2354 .06187 L
.24056 .06195 L
.2453 .06204 L
.25434 .06229 L
.26386 .06263 L
.2836 .06357 L
.30197 .06468 L
.3207 .066 L
.34101 .06761 L
.3464 .068 L
.34936 .06817 L
.35212 .06831 L
.35466 .0684 L
.35699 .06848 L
.35958 .06854 L
.361 .06856 L
.36236 .06858 L
Mistroke
.36363 .06859 L
.36478 .0686 L
.36542 .0686 L
.36611 .06861 L
.36736 .06861 L
.36854 .0686 L
.36978 .0686 L
.37084 .06859 L
.372 .06858 L
.37462 .06853 L
.37744 .06847 L
.38251 .06832 L
.38781 .06811 L
.39271 .06788 L
.40379 .06719 L
.42392 .06552 L
.46324 .06111 L
.50104 .05594 L
.5413 .04986 L
.58004 .0438 L
.62123 .0375 L
.6418 .03454 L
.65182 .03316 L
.66091 .03196 L
.66547 .03138 L
.67041 .03077 L
.67268 .03049 L
.67507 .0302 L
.67606 .03009 L
.67712 .02996 L
.67828 .12361 L
.67937 .12361 L
.69907 .12361 L
.7404 .12361 L
.78021 .12361 L
.81851 .12361 L
.85926 .12361 L
.89849 .12361 L
.93621 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1;oooo201Vof?oool0
06Ooool00`000?ooooooo`17oooo101Vo`Ooool00`1Vooooooooo`1Qoooo001Woooo00<0003ooooo
ool0?oooo`P0I_l;oooo00<0I_ooooooool0HOooo`00Ioooo`030000oooooooo03Ooool806Ko4ooo
o`0306Kooooooooo067oool006Ooool00`000?ooooooo`0boooo1@1Voa_oool00`1Vooooooooo`1Q
oooo001Woooo0P0002coool706Ko8?ooo`0306Kooooooooo067oool006Ooool00`000?ooooooo`0S
oooo201VobOoool00`1Vooooooooo`1Qoooo001Woooo00<0003oooooool07oooo`@0I_l_oooo00<0
I_ooooooool0HOooo`00>OooobL0I_l7oooo00<0003oooooool06?ooo`L0I_lcoooo00<0I_oooooo
ool0HOooo`00<_ooo`L0I_lWoooo1`1Vo`03000006Ko06Ko01P0I_ljoooo00<0I_ooooooool0HOoo
o`00;_ooo`@0I_leoooo00<0003oooooool0D_ooo`0306Kooooooooo067oool002[oool406Ko>Ooo
o`80001Coooo00<0I_ooooooool0HOooo`005oooo`D0000<oooo0P1Voa3oool200001?ooo`800004
oooo0P0001ooool00`000?ooooooo`0Noooo0P0000Coool200001?ooo`80000Ooooo1@0000;oool0
0`1Vooooooooo`0Hoooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?oo
ooooo`09oooo0`1Voa7oool010000?ooooooo`0000Soool010000?ooooooo`0001koool00`000?oo
ooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000Poooo00<0003oooooool00_oo
o`0306Kooooooooo01[oool00`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0003ooooo
ool05oooo`006Oooo`030000oooooooo00Koool306Ko5?ooo`040000oooooooo00002oooo`030000
oooooooo01coool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool07_oo
o`030000oooooooo00;oool00`1Vooooooooo`0Joooo00<0003oooooool02_ooo`030000oooooooo
01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`03oooo0`1Voa7oool4
00000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`80000Qoooo00<0003oooooool00_ooo`0306Kooooooooo01[oool00`000?ooooooo`08
oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00@0003oooooooooool206Ko6_ooo`040000
oooooooo00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009
oooo00<0003oooooool08?ooo`030000oooooooo00;oool00`1Vooooooooo`0Joooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool2000000?oool0I_l0
I_l07Oooo`80000:oooo0`0001koool200007oooo`80000:oooo0`0001ooool200001?ooo`0306Ko
oooooooo01Woool200002_ooo`<0000Poooo0P0001Ooool001Woool206KoC?ooo`030000oooooooo
05;oool00`1Vooooooooo`1Qoooo000Goooo0P1Vodkoool00`000?ooooooo`1Boooo00<0I_oooooo
ool0HOooo`005_ooo`0306Kooooooooo04koool00`000?ooooooo`1Boooo00<0I_ooooooool0HOoo
o`00Ioooo`030000oooooooo05;oool00`1Vooooooooo`1Qoooo001Woooo00<0003oooooool0D_oo
o`0306Kooooooooo067oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`000S?o0004o`2I<ol0<ol000001S?o02P00002oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o00030000<ol0<ol002@co`06000000?o
09T0000000001`0001Woool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000
<ol0<ol004Lco`0500001_ooo`03o`2Ioooooooo067oool006Ooool00`0003?o03?o0012<ol01@00
00_oool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`00?C?o00D0000@oooo00?o09Wooooo
ool0HOooo`00Ioooo`030000<ol0<ol003Tco`0400005Oooo`03o`2Ioooooooo067oool006Ooool2
0000>3?o0080000Ioooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol003Dco`0200006ooo
o`03o`2Ioooooooo067oool006Ooool00`0003?o03?o000c<ol00P0001goool00ol0VOooooooo`1Q
oooo001Woooo00<0000co`0co`00<C?o0080000Ooooo00?o09Woooooool0HOooo`00Ioooo`030000
<ol0<ol0030co`000`000?ooooooo`0Ooooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol0
02hco`0200008_ooo`03o`2Ioooooooo067oool006Ooool20000;C?o0080000Toooo00?o09Wooooo
ool0HOooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`0Toooo00?o09Woooooool0HOoo
o`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`0Uoooo00?o09Woooooool0HOooo`00Iooo
o`030000<ol0<ol002Tco`000`000?ooooooo`0Voooo00?o09Woooooool0HOooo`00Ioooo`030000
<ol0<ol002Pco`000`000?ooooooo`0Woooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol0
02Pco`000`000?ooooooo`0Woooo00?o09Woooooool0HOooo`00Ioooo`80000X<ol000<0003ooooo
ool0:?ooo`03o`2Ioooooooo067oool006Ooool00`0003?o03?o000V<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo067oool006Ooool00`0003?o03?o000U<ol000<0003oooooool0:_ooo`03o`2I
oooooooo067oool006Ooool00`0003?o03?o000T<ol000<0003oooooool0:oooo`03o`2Ioooooooo
067oool006Ooool00`0003?o03?o000S<ol000<0003oooooool0;?ooo`03o`2Ioooooooo067oool0
06Ooool00`0003?o03?o000S<ol000<0003oooooool0;?ooo`03o`2Ioooooooo067oool006Ooool2
00008c?o00030000oooooooo02goool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`008C?o
00030000oooooooo02koool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`0083?o00030000
oooooooo02ooool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`0083?o00030000oooooooo
02ooool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`007c?o00030000oooooooo033oool0
0ol0VOooooooo`1Qoooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003oooooool0<?oo
o`03o`2Ioooooooo067oool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o00030000
oooooooo037oool00ol0VOooooooo`1Qoooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0
003oooooool0<Oooo`03o`2Ioooooooo067oool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`007C?o00030000oooooooo03;oool00ol0VOooooooo`1Qoooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`0boooo00?o09Woooooool0HOooo`00H?ooo`800005
oooo00<0000co`0co`0073?o00030000oooooooo03?oool00ol0VOooooooo`1Qoooo001Woooo00<0
000co`0co`0073?o00030000oooooooo03?oool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0c
o`006c?o00030000oooooooo03Coool00ol0VOooooooo`1Qoooo001Woooo0P0001`co`000`000?oo
ooooo`0doooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0e
oooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`0eoooo00?o
09Woooooool0HOooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0foooo00?o09Wooooo
ool0HOooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0foooo00?o09Woooooool0HOoo
o`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`0goooo00?o09Woooooool0HOooo`00Iooo
o`80000I<ol000<0003oooooool0=oooo`03o`2Ioooooooo067oool006Ooool00`0003?o03?o000G
<ol000<0003oooooool0>?ooo`03o`2Ioooooooo067oool006Ooool00`0003?o03?o000G<ol000<0
003oooooool0>?ooo`03o`2Ioooooooo067oool006Ooool00`0003?o03?o000F<ol000<0003ooooo
ool0>Oooo`03o`2Ioooooooo067oool006Ooool00`0003?o03?o000F<ol000<0003oooooool0>Ooo
o`03o`2Ioooooooo067oool006Ooool00`0003?o03?o000F<ol000<0003oooooool0>Oooo`03o`2I
oooooooo067oool006Ooool00`0003?o03?o000E<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
067oool006Ooool200005S?o00030000oooooooo03[oool00ol0VOooooooo`1Qoooo001Woooo00<0
000co`0co`005C?o00030000oooooooo03[oool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0c
o`005C?o00030000oooooooo03[oool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`0053?o
00030000oooooooo03_oool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`0053?o00030000
oooooooo03_oool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`0053?o00030000oooooooo
03_oool00ol0VOooooooo`1Qoooo001Woooo0P0001Dco`000`000?ooooooo`0koooo00?o09Wooooo
ool0HOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0loooo00?o09Woooooool0HOoo
o`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`0loooo00?o09Woooooool0HOooo`00Iooo
o`030000<ol0<ol001<co`000`000?ooooooo`0loooo00?o09Woooooool0HOooo`00Goooo`@00004
oooo00<0000co`0co`004c?o00030000oooooooo03coool00ol0VOooooooo`1Qoooo001Ooooo00<0
003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`0moooo00?o09Woooooool0HOoo
o`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo03goool00ol0VOooooooo`1Q
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`0moooo00?o
09Woooooool0HOooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`000`000?oo
ooooo`0noooo00?o09Woooooool0HOooo`00H?ooo`800005oooo00<0000co`0co`004C?o00030000
oooooooo03koool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`004C?o00030000oooooooo
03koool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`004C?o00030000oooooooo03koool0
0ol0VOooooooo`1Qoooo001Woooo0P00014co`000`000?ooooooo`0ooooo00?o09Woooooool0HOoo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`0ooooo00?o09Woooooool0HOooo`00Iooo
o`030000<ol0<ol0010co`000`000?ooooooo`0ooooo00?o09Woooooool0HOooo`00Ioooo`030000
<ol0<ol0010co`000`000?ooooooo`0ooooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`10oooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol000lco`00
0`000?ooooooo`10oooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol000lco`000`000?oo
ooooo`10oooo00?o09Woooooool0HOooo`00Ioooo`80000@<ol000<0003oooooool0@?ooo`03o`2I
oooooooo067oool006Ooool00`0003?o03?o000><ol000<0003oooooool0@Oooo`03o`2Ioooooooo
067oool006Ooool00`0003?o03?o000><ol000<0003oooooool0@Oooo`03o`2Ioooooooo067oool0
06Ooool00`0003?o03?o000><ol000<0003oooooool0@Oooo`03o`2Ioooooooo067oool006Ooool0
0`0003?o03?o000><ol000<0003oooooool0@Oooo`03o`2Ioooooooo067oool006Ooool00`0003?o
03?o000=<ol000<0003oooooool0@_ooo`03o`2Ioooooooo067oool006Ooool200003S?o00030000
oooooooo04;oool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`003C?o00030000oooooooo
04;oool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`003C?o00030000oooooooo04;oool0
0ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`0033?o00030000oooooooo04?oool00ol0VOoo
ooooo`1Qoooo001Woooo00<0000co`0co`0033?o00030000oooooooo04?oool00ol0VOooooooo`1Q
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo04?oool00ol0VOooooooo`1Qoooo001W
oooo0P0000dco`000`000?ooooooo`13oooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`13oooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`13oooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol000/co`000`000?oo
ooooo`14oooo00?o09Woooooool0HOooo`00H?ooo`800005oooo00<0000co`0co`002c?o00030000
oooooooo04Coool00ol0VOooooooo`1Qoooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`002c?o00030000oooooooo04Coool00ol0VOooooooo`1Qoooo001Qoooo00<0003oooooool00ooo
o`80000<<ol000<0003oooooool0A?ooo`03o`2Ioooooooo067oool006;oool00`000?ooooooo`02
oooo00<0000co`0co`002c?o00030000oooooooo04Coool00ol0VOooooooo`1Qoooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo04Coool00ol0VOooooooo`1Q
oooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0AOooo`03o`2Ioooooooo
067oool006Ooool00`0003?o03?o000:<ol000<0003oooooool0AOooo`03o`2Ioooooooo067oool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool0AOooo`03o`2Ioooooooo067oool006Ooool0
0`0003?o03?o000:<ol000<0003oooooool0AOooo`03o`2Ioooooooo067oool006Ooool200002c?o
00030000oooooooo04Goool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`002S?o00030000
oooooooo04Goool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`002C?o00030000oooooooo
04Koool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`002C?o00030000oooooooo04Koool0
0ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`002C?o00030000oooooooo04Koool00ol0VOoo
ooooo`1Qoooo001Woooo00<0000co`0co`002C?o00030000oooooooo04Koool00ol0VOooooooo`1Q
oooo001Woooo0P0000Xco`000`000?ooooooo`16oooo00?o09Woooooool0HOooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`16oooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`16oooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`17oooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`17oooo00?o09Woooooool0HOooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`17
oooo00?o09Woooooool0HOooo`00Ioooo`800009<ol000<0003oooooool0Aoooo`03o`2Ioooooooo
067oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Aoooo`03o`2Ioooooooo067oool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool0Aoooo`03o`2Ioooooooo067oool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0B?ooo`03o`2Ioooooooo067oool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0B?ooo`03o`2Ioooooooo067oool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0B?ooo`03o`2Ioooooooo067oool006Ooool2000023?o00030000oooooooo
04Soool00ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`001c?o00030000oooooooo04Soool0
0ol0VOooooooo`1Qoooo001Woooo00<0000co`0co`001c?o00030000oooooooo04Soool00ol0VOoo
ooooo`1Qoooo001Woooo00<0000co`0co`001c?o00030000oooooooo04Soool00ol0VOooooooo`1Q
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo04Soool00ol0VOooooooo`1Qoooo001Q
oooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0B?ooo`03o`2Ioooooooo067oool0
06;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo04Soool00ol0VOoo
ooooo`1Qoooo001Ooooo1@0000?oool2000023?o00030000oooooooo04Soool00ol0VOooooooo`1Q
oooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o
0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Iooo
o`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool200000ooo
o`<00004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol01oooo`030000
oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00000_oo
o`040000oooooooo00001?ooo`030000oooooooo07Ooool006Ooool9<ol02?ooo`030000oooooooo
00D0000>oooo00<0003oooooool01oooo`040000oooooooo00000_ooo`<00004oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09
oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool0
06Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.66906 .12361 L
.67803 .12361 L
.68044 .12361 L
.68176 .12361 L
.683 .12361 L
.68364 .12361 L
s
.68364 .12361 m
.68391 .61803 L
s
0 .4 1 r
.02381 .10606 m
.04262 .09565 L
.06244 .0867 L
.08426 .07891 L
.10458 .07331 L
.12297 .06942 L
.14264 .0663 L
.15285 .06506 L
.16394 .06397 L
.17441 .06317 L
.18408 .06261 L
.18874 .0624 L
.19375 .06221 L
.19808 .06208 L
.20281 .06196 L
.20567 .06191 L
.20833 .06187 L
.21087 .06184 L
.21229 .06183 L
.21358 .06182 L
.21485 .06181 L
.21602 .06181 L
.2173 .0618 L
.21794 .0618 L
.21865 .0618 L
.21985 .0618 L
.22112 .06181 L
.22233 .06181 L
.22343 .06182 L
.22572 .06183 L
.22824 .06186 L
.23335 .06193 L
.23808 .06203 L
.24252 .06213 L
.25251 .06244 L
.26328 .06287 L
.28332 .06391 L
.30442 .06528 L
.32438 .06678 L
.34253 .06827 L
.34737 .06861 L
.34992 .06875 L
.35261 .06888 L
.35497 .06897 L
.35757 .06906 L
.35993 .06911 L
.36214 .06915 L
.36343 .06917 L
.36412 .06918 L
.36484 .06918 L
Mistroke
.36554 .06919 L
.36618 .06919 L
.36741 .06919 L
.36861 .06919 L
.3699 .06919 L
.37112 .06918 L
.37224 .06917 L
.37354 .06915 L
.37476 .06914 L
.37752 .06908 L
.38021 .06902 L
.38309 .06893 L
.39329 .06849 L
.40437 .06782 L
.4245 .06619 L
.46533 .06165 L
.50465 .05627 L
.54246 .05058 L
.58271 .0443 L
.62145 .03834 L
.64114 .03546 L
.66264 .0325 L
.67259 .03122 L
.67806 .03055 L
.68074 .03022 L
.68192 .03008 L
.68321 .02993 L
.68442 .12361 L
.68555 .12361 L
.68802 .12361 L
.69323 .12361 L
.70232 .12361 L
.7412 .12361 L
.78252 .12361 L
.82234 .12361 L
.86063 .12361 L
.90138 .12361 L
.94062 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1<oooo201Vof;oool0
06Ooool00`000?ooooooo`17oooo1@1Vo`Ooool00`1Vooooooooo`1Poooo001Woooo00<0003ooooo
ool0@?ooo`L0I_l<oooo00<0I_ooooooool0H?ooo`00Ioooo`030000oooooooo03Soool806Ko4ooo
o`0306Kooooooooo063oool006Ooool00`000?ooooooo`0coooo1@1Voa_oool00`1Vooooooooo`1P
oooo001Woooo0P0002goool706Ko8?ooo`0306Kooooooooo063oool006Ooool00`000?ooooooo`0T
oooo201VobOoool00`1Vooooooooo`1Poooo001Woooo00<0003oooooool07oooo`D0I_l_oooo00<0
I_ooooooool0H?ooo`00>Oooob80I_l<oooo00<0003oooooool06?ooo`L0I_ldoooo00<0I_oooooo
ool0H?ooo`00<_ooo`L0I_lRoooo301Vo`03000006Ko06Ko00Woool?06Ko>oooo`0306Kooooooooo
063oool002koool406Ko=Oooo`030000oooooooo00T0I_m:oooo00<0I_ooooooool0H?ooo`00:Ooo
o`D0I_lioooo0P0005Coool00`1Vooooooooo`1Poooo000Goooo1@0000Woool406Ko4Oooo`800004
oooo0P0000Coool200007oooo`030000oooooooo01koool200001?ooo`800004oooo0P0001ooool5
00001?ooo`0306Kooooooooo01Koool500000_ooo`800004oooo0P00023oool400005_ooo`006Ooo
o`030000oooooooo00Koool306Ko5?ooo`040000oooooooo00002?ooo`040000oooooooo00007_oo
o`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00023oool00`000?oo
ooooo`04oooo00<0I_ooooooool06?ooo`030000oooooooo00Ooool010000?ooooooo`0001ooool0
0`000?ooooooo`0Goooo000Ioooo00<0003oooooool00oooo`<0I_lGoooo00@0003oooooool0000;
oooo00<0003oooooool07?ooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?oo
ooooo`0Noooo00<0003oooooool01?ooo`0306Kooooooooo01Soool00`000?ooooooo`0:oooo00<0
003oooooool07_ooo`030000oooooooo01Koool0017oool400001?ooo`040000oooooooooooo0P1V
oaCoool400000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000
oooooooo00002Oooo`80000Qoooo00<0003oooooool01?ooo`0306Kooooooooo01Soool00`000?oo
ooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00@0003oool0I_l0I_lLoooo00@0
003oooooool00009oooo00<0003oooooool07_ooo`030000oooooooo01goool010000?ooooooo`00
00Woool00`000?ooooooo`0Poooo00<0003oooooool01?ooo`0306Kooooooooo01Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`8000000`1Voooo
ooooo`0Moooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`800006oooo00<0
I_ooooooool05oooo`80000:oooo0`00023oool200005oooo`005oooo`80I_m>oooo00<0003ooooo
ool0E?ooo`0306Kooooooooo05ooool001Koool00`1Vooooooooo`1>oooo00<0003oooooool0E?oo
o`0306Kooooooooo05ooool006Ooool00`000?ooooooo`1Doooo00<0I_ooooooool0Goooo`00Iooo
o`030000oooooooo05Coool00`1Vooooooooo`1Ooooo001Woooo00<0003oooooool0E?ooo`0306Ko
oooooooo05ooool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`0013?o0003o`2I0000<ol000Dco`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol020000003o`2I00000000
00D0000Ioooo00<0003oooooool09_ooo`030000oooooooo01Goool006Ooool00`0003?o03?o0017
<ol01@0000Soool00ol0VOooooooo`1Ooooo001Woooo00<0000co`0co`00@S?o00D0000=oooo00?o
09Woooooool0Goooo`00Ioooo`030000<ol0<ol003dco`0500004_ooo`03o`2Ioooooooo05ooool0
06Ooool00`0003?o03?o000i<ol0100001Ooool00ol0VOooooooo`1Ooooo001Woooo0P0003Pco`02
00006oooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000e<ol00P0001goool00ol0VOoo
ooooo`1Ooooo001Woooo00<0000co`0co`00<c?o0080000Ooooo00?o09Woooooool0Goooo`00Iooo
o`030000<ol0<ol0034co`0200008Oooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000`
<ol000<0003oooooool08Oooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000^<ol00P00
02Coool00ol0VOooooooo`1Ooooo001Woooo0P0002dco`0200009_ooo`03o`2Ioooooooo05ooool0
06Ooool00`0003?o03?o000[<ol000<0003oooooool09_ooo`03o`2Ioooooooo05ooool006Ooool0
0`0003?o03?o000Z<ol000<0003oooooool09oooo`03o`2Ioooooooo05ooool006Ooool00`0003?o
03?o000Y<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000X
<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000X<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo05ooool006Ooool20000:3?o00030000oooooooo02[oool0
0ol0VOooooooo`1Ooooo001Woooo00<0000co`0co`009S?o00030000oooooooo02_oool00ol0VOoo
ooooo`1Ooooo001Woooo00<0000co`0co`009C?o00030000oooooooo02coool00ol0VOooooooo`1O
oooo001Woooo00<0000co`0co`0093?o00030000oooooooo02goool00ol0VOooooooo`1Ooooo001W
oooo00<0000co`0co`008c?o00030000oooooooo02koool00ol0VOooooooo`1Ooooo001Woooo00<0
000co`0co`008c?o00030000oooooooo02koool00ol0VOooooooo`1Ooooo001Woooo0P0002<co`00
0`000?ooooooo`0_oooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol0024co`000`000?oo
ooooo`0`oooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0a
oooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0aoooo00?o
09Woooooool0Goooo`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`0boooo00?o09Wooooo
ool0Goooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo03;oool00ol0VOoo
ooooo`1Ooooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`0c
oooo00?o09Woooooool0Goooo`00HOooo`030000oooooooo00?oool200007c?o00030000oooooooo
03?oool00ol0VOooooooo`1Ooooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`00
0`000?ooooooo`0doooo00?o09Woooooool0Goooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o000M<ol000<0003oooooool0=?ooo`03o`2Ioooooooo05ooool0063oool200001Oooo`030000
<ol0<ol001`co`000`000?ooooooo`0eoooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol0
01`co`000`000?ooooooo`0eoooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol001/co`00
0`000?ooooooo`0foooo00?o09Woooooool0Goooo`00Ioooo`80000L<ol000<0003oooooool0=_oo
o`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000J<ol000<0003oooooool0=oooo`03o`2I
oooooooo05ooool006Ooool00`0003?o03?o000J<ol000<0003oooooool0=oooo`03o`2Ioooooooo
05ooool006Ooool00`0003?o03?o000I<ol000<0003oooooool0>?ooo`03o`2Ioooooooo05ooool0
06Ooool00`0003?o03?o000I<ol000<0003oooooool0>?ooo`03o`2Ioooooooo05ooool006Ooool0
0`0003?o03?o000H<ol000<0003oooooool0>Oooo`03o`2Ioooooooo05ooool006Ooool200006C?o
00030000oooooooo03Woool00ol0VOooooooo`1Ooooo001Woooo00<0000co`0co`005c?o00030000
oooooooo03[oool00ol0VOooooooo`1Ooooo001Woooo00<0000co`0co`005c?o00030000oooooooo
03[oool00ol0VOooooooo`1Ooooo001Woooo00<0000co`0co`005S?o00030000oooooooo03_oool0
0ol0VOooooooo`1Ooooo001Woooo00<0000co`0co`005S?o00030000oooooooo03_oool00ol0VOoo
ooooo`1Ooooo001Woooo00<0000co`0co`005S?o00030000oooooooo03_oool00ol0VOooooooo`1O
oooo001Woooo00<0000co`0co`005C?o00030000oooooooo03coool00ol0VOooooooo`1Ooooo001W
oooo0P0001Hco`000`000?ooooooo`0loooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0loooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol001Dco`00
0`000?ooooooo`0loooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol001@co`000`000?oo
ooooo`0moooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0m
oooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0moooo00?o
09Woooooool0Goooo`00Ioooo`80000E<ol000<0003oooooool0?Oooo`03o`2Ioooooooo05ooool0
06Ooool00`0003?o03?o000C<ol000<0003oooooool0?_ooo`03o`2Ioooooooo05ooool006Ooool0
0`0003?o03?o000C<ol000<0003oooooool0?_ooo`03o`2Ioooooooo05ooool006Ooool00`0003?o
03?o000C<ol000<0003oooooool0?_ooo`03o`2Ioooooooo05ooool005ooool400001?ooo`030000
<ol0<ol001<co`000`000?ooooooo`0noooo00?o09Woooooool0Goooo`00Goooo`030000oooooooo
00Goool00`0003?o03?o000B<ol000<0003oooooool0?oooo`03o`2Ioooooooo05ooool0063oool0
0`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`0ooooo00?o09Woooooool0Goooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0?oooo`03o`2Ioooooooo
05ooool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool0@?oo
o`03o`2Ioooooooo05ooool0063oool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`10
oooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`10oooo00?o
09Woooooool0Goooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`10oooo00?o09Wooooo
ool0Goooo`00Ioooo`80000A<ol000<0003oooooool0@Oooo`03o`2Ioooooooo05ooool006Ooool0
0`0003?o03?o000@<ol000<0003oooooool0@Oooo`03o`2Ioooooooo05ooool006Ooool00`0003?o
03?o000@<ol000<0003oooooool0@Oooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000@
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000?<ol000<0
003oooooool0@_ooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000?<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000?<ol000<0003oooooool0@_oo
o`03o`2Ioooooooo05ooool006Ooool2000043?o00030000oooooooo04;oool00ol0VOooooooo`1O
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo04?oool00ol0VOooooooo`1Ooooo001W
oooo00<0000co`0co`003S?o00030000oooooooo04?oool00ol0VOooooooo`1Ooooo001Woooo00<0
000co`0co`003S?o00030000oooooooo04?oool00ol0VOooooooo`1Ooooo001Woooo00<0000co`0c
o`003S?o00030000oooooooo04?oool00ol0VOooooooo`1Ooooo001Woooo00<0000co`0co`003C?o
00030000oooooooo04Coool00ol0VOooooooo`1Ooooo001Woooo0P0000hco`000`000?ooooooo`14
oooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`14oooo00?o
09Woooooool0Goooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`14oooo00?o09Wooooo
ool0Goooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`15oooo00?o09Woooooool0Gooo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`15oooo00?o09Woooooool0Goooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`15oooo00?o09Woooooool0Goooo`00Ioooo`80000=
<ol000<0003oooooool0AOooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000<<ol000<0
003oooooool0AOooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o000;<ol000<0003oooooool0A_oo
o`03o`2Ioooooooo05ooool0063oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`16
oooo00?o09Woooooool0Goooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`16oooo00?o09Woooooool0Goooo`00HOooo`030000oooooooo00?oool2000033?o
00030000oooooooo04Koool00ol0VOooooooo`1Ooooo001Roooo00<0003oooooool00_ooo`030000
<ol0<ol000/co`000`000?ooooooo`16oooo00?o09Woooooool0Goooo`00Goooo`040000oooooooo
00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`16oooo00?o09Woooooool0Goooo`00H?oo
o`800005oooo00<0000co`0co`002S?o00030000oooooooo04Ooool00ol0VOooooooo`1Ooooo001W
oooo00<0000co`0co`002S?o00030000oooooooo04Ooool00ol0VOooooooo`1Ooooo001Woooo00<0
000co`0co`002S?o00030000oooooooo04Ooool00ol0VOooooooo`1Ooooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo04Ooool00ol0VOooooooo`1Ooooo001Woooo0P0000/co`000`000?oo
ooooo`17oooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`17
oooo00?o09Woooooool0Goooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`18oooo00?o
09Woooooool0Goooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`18oooo00?o09Wooooo
ool0Goooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`18oooo00?o09Woooooool0Gooo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`18oooo00?o09Woooooool0Goooo`00Iooo
o`80000:<ol000<0003oooooool0B?ooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o0009
<ol000<0003oooooool0B?ooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o0009<ol000<0
003oooooool0B?ooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool0BOooo`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o0008<ol000<0003oooooool0BOoo
o`03o`2Ioooooooo05ooool006Ooool00`0003?o03?o0008<ol000<0003oooooool0BOooo`03o`2I
oooooooo05ooool006Ooool200002C?o00030000oooooooo04Woool00ol0VOooooooo`1Ooooo001W
oooo00<0000co`0co`0023?o00030000oooooooo04Woool00ol0VOooooooo`1Ooooo001Woooo00<0
000co`0co`0023?o00030000oooooooo04Woool00ol0VOooooooo`1Ooooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo04[oool00ol0VOooooooo`1Ooooo001Woooo00<0000co`0co`001c?o
00030000oooooooo04[oool00ol0VOooooooo`1Ooooo001Woooo00<0000co`0co`001c?o00030000
oooooooo04[oool00ol0VOooooooo`1Ooooo001Woooo0P0000Pco`000`000?ooooooo`1:oooo00?o
09Woooooool0Goooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1:oooo00?o09Wooooo
ool0Goooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1:oooo00?o09Woooooool0Gooo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1:oooo00?o09Woooooool0Goooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1:oooo00?o09Woooooool0Goooo`00HOooo`<00003
oooo00<0000co`0co`001c?o00030000oooooooo04[oool00ol0VOooooooo`1Ooooo001Roooo00<0
003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`1:oooo00?o09Woooooool0Gooo
o`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`1:oooo00?o09Woooooool0Goooo`00Gooo
o`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Q
oooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Ooo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02
oooo00<0003oooooool03oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?oo
ooooo`0000Coool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003_oo
o`030000oooooooo00Ooool010000?ooooooo`0000?oool200001?ooo`030000oooooooo07Soool0
06Ooool9<ol02?ooo`050000oooooooooooo0000017oool00`000?ooooooo`07oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0
003oooooool04Oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Woool006Ooool9
<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.67803 .12361 L
.68335 .12361 L
.68596 .12361 L
.68711 .12361 L
.68837 .12361 L
.6895 .12361 L
s
.6895 .12361 m
.68992 .61803 L
s
0 .4 1 r
.02381 .10232 m
.04262 .09257 L
.06244 .08422 L
.08255 .0775 L
.10458 .07185 L
.12415 .0681 L
.14509 .06522 L
.1553 .06418 L
.16639 .06329 L
.17687 .06266 L
.18653 .06224 L
.19119 .06209 L
.1962 .06197 L
.19863 .06192 L
.20093 .06188 L
.2032 .06185 L
.20526 .06183 L
.20645 .06182 L
.20773 .06182 L
.20844 .06181 L
.20909 .06181 L
.21037 .06181 L
.21147 .0618 L
.21268 .0618 L
.21394 .06181 L
.21512 .06181 L
.21579 .06181 L
.21652 .06182 L
.21784 .06182 L
.22032 .06184 L
.22321 .06188 L
.22588 .06191 L
.23052 .062 L
.23551 .06212 L
.24455 .06239 L
.2553 .0628 L
.26515 .06327 L
.30478 .06576 L
.32474 .06732 L
.34288 .06884 L
.34772 .06919 L
.35027 .06933 L
.35297 .06946 L
.35533 .06956 L
.35793 .06964 L
.36029 .0697 L
.36249 .06974 L
.36379 .06976 L
.36447 .06977 L
.3652 .06978 L
Mistroke
.3659 .06978 L
.36654 .06979 L
.36777 .06979 L
.36897 .06979 L
.37026 .06979 L
.37148 .06978 L
.37259 .06977 L
.3739 .06976 L
.37511 .06974 L
.37787 .06969 L
.38056 .06963 L
.38344 .06955 L
.39364 .06912 L
.3994 .06881 L
.40473 .06847 L
.42486 .06687 L
.46418 .06259 L
.50198 .05752 L
.54223 .05152 L
.58097 .04549 L
.62217 .03911 L
.64273 .03607 L
.66184 .03339 L
.67135 .03213 L
.68031 .03099 L
.68526 .03039 L
.68662 .03022 L
.68806 .03005 L
.68929 .02991 L
.68998 .02983 L
.69063 .12361 L
.69185 .12361 L
.693 .12361 L
.69515 .12361 L
.7 .12361 L
.7383 .12361 L
.77905 .12361 L
.81828 .12361 L
.856 .12361 L
.89617 .12361 L
.93483 .12361 L
.97594 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1@oooo1P1Vof3oool0
06Ooool00`000?ooooooo`17oooo2@1Vo`Goool00`1Vooooooooo`1Noooo001Woooo00<0003ooooo
ool0@_ooo`D0I_l>oooo00<0I_ooooooool0G_ooo`00Ioooo`030000oooooooo03goool506Ko4ooo
o`0306Kooooooooo05koool006Ooool00`000?ooooooo`0foooo1`1VoaSoool00`1Vooooooooo`1N
oooo001Woooo0P0002ooool806Ko7oooo`0306Kooooooooo05koool006Ooool00`000?ooooooo`0X
oooo1P1VobOoool00`1Vooooooooo`1Noooo001Woooo00<0003oooooool08Oooo`L0I_l]oooo00<0
I_ooooooool0G_ooo`00=oooob40I_l?oooo00<0003oooooool06?ooo`T0I_ldoooo00<0I_oooooo
ool0G_ooo`00;_ooo`T0I_lQoooo3@1Vo`;oool00`000?ooooooo`0=oooo2`1Vocgoool00`1Voooo
ooooo`1Noooo000Zoooo101VocOoool206Ko00<00000I_l0I_l03@1VodSoool00`1Vooooooooo`1N
oooo000Woooo0`1Vocgoool20000E_ooo`0306Kooooooooo05koool001Ooool500001oooo`@0I_lC
oooo0P0000Coool200001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool2
00007oooo`D00005oooo00<0I_ooooooool05Oooo`D00002oooo0P0000Coool200008?ooo`@0000F
oooo000Ioooo00<0003oooooool01?ooo`<0I_lFoooo00@0003oooooool00008oooo00@0003ooooo
ool0000Noooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00008?oo
o`030000oooooooo00Goool00`1Vooooooooo`0Goooo00<0003oooooool01oooo`040000oooooooo
00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`02oooo0P1VoaWoool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`05oooo00<0I_ooooooool05oooo`030000oooooooo
00[oool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003ooooo
ool00P1VoaGoool400000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool01Oooo`0306Kooooooooo01Ooool0
0`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<00000I_l0I_l07Ooo
o`040000oooooooo00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003ooooo
ool00009oooo00<0003oooooool08?ooo`030000oooooooo00Goool00`1Vooooooooo`0Goooo00<0
003oooooool02?ooo`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200008?oo
o`80000:oooo0`0001koool200007oooo`80000:oooo0`0001ooool200001oooo`0306Kooooooooo
01Koool200002_ooo`<0000Poooo0P0001Ooool001Koool206KoCoooo`030000oooooooo05Goool0
0`1Vooooooooo`1Noooo001Woooo00<0003oooooool0EOooo`0306Kooooooooo05koool006Ooool0
0`000?ooooooo`1Eoooo00<0I_ooooooool0G_ooo`00Ioooo`030000oooooooo05Goool00`1Voooo
ooooo`1Noooo001Woooo00<0003oooooool0EOooo`0306Kooooooooo05koool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X
00000_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol0
02Dco`000`0003?o03?o000T<ol02@000003o`2I0000000000@0000Ioooo00<0003oooooool09_oo
o`030000oooooooo01Goool006Ooool00`0003?o03?o0017<ol01@0000Woool00ol0VOooooooo`1N
oooo001Woooo00<0000co`0co`00@S?o00D0000>oooo00?o09Woooooool0G_ooo`00Ioooo`030000
<ol0<ol003dco`0500004oooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000i<ol01000
01Soool00ol0VOooooooo`1Noooo001Woooo0P0003Pco`0200007?ooo`03o`2Ioooooooo05koool0
06Ooool00`0003?o03?o000e<ol00P0001koool00ol0VOooooooo`1Noooo001Woooo00<0000co`0c
o`00<c?o0080000Poooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol0034co`0200008_oo
o`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000`<ol000<0003oooooool08_ooo`03o`2I
oooooooo05koool006Ooool00`0003?o03?o000^<ol00P0002Goool00ol0VOooooooo`1Noooo001W
oooo0P0002dco`0200009oooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000[<ol000<0
003oooooool09oooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000Z<ol000<0003ooooo
ool0:?ooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000Y<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000X<ol000<0003oooooool0:_ooo`03o`2I
oooooooo05koool006Ooool00`0003?o03?o000X<ol000<0003oooooool0:_ooo`03o`2Ioooooooo
05koool006Ooool20000:3?o00030000oooooooo02_oool00ol0VOooooooo`1Noooo001Woooo00<0
000co`0co`009S?o00030000oooooooo02coool00ol0VOooooooo`1Noooo001Woooo00<0000co`0c
o`009C?o00030000oooooooo02goool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`0093?o
00030000oooooooo02koool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`008c?o00030000
oooooooo02ooool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`008c?o00030000oooooooo
02ooool00ol0VOooooooo`1Noooo001Woooo0P0002<co`000`000?ooooooo`0`oooo00?o09Wooooo
ool0G_ooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`0aoooo00?o09Woooooool0G_oo
o`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0boooo00?o09Woooooool0G_ooo`00Iooo
o`030000<ol0<ol0020co`000`000?ooooooo`0boooo00?o09Woooooool0G_ooo`00Ioooo`030000
<ol0<ol001lco`000`000?ooooooo`0coooo00?o09Woooooool0G_ooo`00Goooo`D00003oooo00<0
000co`0co`007c?o00030000oooooooo03?oool00ol0VOooooooo`1Noooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001hco`000`000?ooooooo`0doooo00?o09Woooooool0G_ooo`00HOoo
o`030000oooooooo00?oool200007c?o00030000oooooooo03Coool00ol0VOooooooo`1Noooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0eoooo00?o09Wooooo
ool0G_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0=Ooo
o`03o`2Ioooooooo05koool0063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`0f
oooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`0foooo00?o
09Woooooool0G_ooo`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`0goooo00?o09Wooooo
ool0G_ooo`00Ioooo`80000L<ol000<0003oooooool0=oooo`03o`2Ioooooooo05koool006Ooool0
0`0003?o03?o000J<ol000<0003oooooool0>?ooo`03o`2Ioooooooo05koool006Ooool00`0003?o
03?o000J<ol000<0003oooooool0>?ooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000I
<ol000<0003oooooool0>Oooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000I<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000H<ol000<0003ooooo
ool0>_ooo`03o`2Ioooooooo05koool006Ooool200006C?o00030000oooooooo03[oool00ol0VOoo
ooooo`1Noooo001Woooo00<0000co`0co`005c?o00030000oooooooo03_oool00ol0VOooooooo`1N
oooo001Woooo00<0000co`0co`005c?o00030000oooooooo03_oool00ol0VOooooooo`1Noooo001W
oooo00<0000co`0co`005S?o00030000oooooooo03coool00ol0VOooooooo`1Noooo001Woooo00<0
000co`0co`005S?o00030000oooooooo03coool00ol0VOooooooo`1Noooo001Woooo00<0000co`0c
o`005S?o00030000oooooooo03coool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`005C?o
00030000oooooooo03goool00ol0VOooooooo`1Noooo001Woooo0P0001Hco`000`000?ooooooo`0m
oooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0moooo00?o
09Woooooool0G_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`0moooo00?o09Wooooo
ool0G_ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0noooo00?o09Woooooool0G_oo
o`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`0noooo00?o09Woooooool0G_ooo`00Iooo
o`030000<ol0<ol001@co`000`000?ooooooo`0noooo00?o09Woooooool0G_ooo`00Ioooo`80000E
<ol000<0003oooooool0?_ooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000C<ol000<0
003oooooool0?oooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000C<ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000C<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo05koool005ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0o
oooo00?o09Woooooool0G_ooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0
003oooooool0@?ooo`03o`2Ioooooooo05koool0063oool00`000?ooooooo`04oooo0P0001<co`00
0`000?ooooooo`10oooo00?o09Woooooool0G_ooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o000B<ol000<0003oooooool0@?ooo`03o`2Ioooooooo05koool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000A<ol000<0003oooooool0@Oooo`03o`2Ioooooooo05koool0063oool2
00001Oooo`030000<ol0<ol0014co`000`000?ooooooo`11oooo00?o09Woooooool0G_ooo`00Iooo
o`030000<ol0<ol0014co`000`000?ooooooo`11oooo00?o09Woooooool0G_ooo`00Ioooo`030000
<ol0<ol0014co`000`000?ooooooo`11oooo00?o09Woooooool0G_ooo`00Ioooo`80000A<ol000<0
003oooooool0@_ooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000@<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000@<ol000<0003oooooool0@_oo
o`03o`2Ioooooooo05koool006Ooool00`0003?o03?o000@<ol000<0003oooooool0@_ooo`03o`2I
oooooooo05koool006Ooool00`0003?o03?o000?<ol000<0003oooooool0@oooo`03o`2Ioooooooo
05koool006Ooool00`0003?o03?o000?<ol000<0003oooooool0@oooo`03o`2Ioooooooo05koool0
06Ooool00`0003?o03?o000?<ol000<0003oooooool0@oooo`03o`2Ioooooooo05koool006Ooool2
000043?o00030000oooooooo04?oool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`003S?o
00030000oooooooo04Coool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`003S?o00030000
oooooooo04Coool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`003S?o00030000oooooooo
04Coool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`003S?o00030000oooooooo04Coool0
0ol0VOooooooo`1Noooo001Woooo00<0000co`0co`003C?o00030000oooooooo04Goool00ol0VOoo
ooooo`1Noooo001Woooo0P0000hco`000`000?ooooooo`15oooo00?o09Woooooool0G_ooo`00Iooo
o`030000<ol0<ol000dco`000`000?ooooooo`15oooo00?o09Woooooool0G_ooo`00Ioooo`030000
<ol0<ol000dco`000`000?ooooooo`15oooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`16oooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`16oooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`16oooo00?o09Woooooool0G_ooo`00Ioooo`80000=<ol000<0003oooooool0A_ooo`03o`2I
oooooooo05koool006Ooool00`0003?o03?o000<<ol000<0003oooooool0A_ooo`03o`2Ioooooooo
05koool006Ooool00`0003?o03?o000<<ol000<0003oooooool0A_ooo`03o`2Ioooooooo05koool0
06Ooool00`0003?o03?o000;<ol000<0003oooooool0Aoooo`03o`2Ioooooooo05koool0063oool2
00001Oooo`030000<ol0<ol000/co`000`000?ooooooo`17oooo00?o09Woooooool0G_ooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`17oooo00?o09Wooooo
ool0G_ooo`00HOooo`030000oooooooo00?oool2000033?o00030000oooooooo04Ooool00ol0VOoo
ooooo`1Noooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`17
oooo00?o09Woooooool0G_ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`17oooo00?o09Woooooool0G_ooo`00H?ooo`800005oooo00<0000co`0co`002S?o
00030000oooooooo04Soool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`002S?o00030000
oooooooo04Soool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`002S?o00030000oooooooo
04Soool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`002S?o00030000oooooooo04Soool0
0ol0VOooooooo`1Noooo001Woooo0P0000/co`000`000?ooooooo`18oooo00?o09Woooooool0G_oo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`18oooo00?o09Woooooool0G_ooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`19oooo00?o09Woooooool0G_ooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`19oooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`19oooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`19oooo00?o09Woooooool0G_ooo`00Ioooo`80000:<ol000<0003oooooool0BOoo
o`03o`2Ioooooooo05koool006Ooool00`0003?o03?o0009<ol000<0003oooooool0BOooo`03o`2I
oooooooo05koool006Ooool00`0003?o03?o0009<ol000<0003oooooool0BOooo`03o`2Ioooooooo
05koool006Ooool00`0003?o03?o0008<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05koool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05koool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05koool006Ooool200002C?o
00030000oooooooo04[oool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`0023?o00030000
oooooooo04[oool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`0023?o00030000oooooooo
04[oool00ol0VOooooooo`1Noooo001Woooo00<0000co`0co`001c?o00030000oooooooo04_oool0
0ol0VOooooooo`1Noooo001Woooo00<0000co`0co`001c?o00030000oooooooo04_oool00ol0VOoo
ooooo`1Noooo001Woooo00<0000co`0co`001c?o00030000oooooooo04_oool00ol0VOooooooo`1N
oooo001Woooo0P0000Pco`000`000?ooooooo`1;oooo00?o09Woooooool0G_ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`1;oooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1;oooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1;oooo00?o09Woooooool0G_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1;oooo00?o09Woooooool0G_ooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000
oooooooo04_oool00ol0VOooooooo`1Noooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1;oooo00?o09Woooooool0G_ooo`00Goooo`D00003oooo0P0000Pco`00
0`000?ooooooo`1;oooo00?o09Woooooool0G_ooo`00Goooo`040000oooooooo00001?ooo`Xco`2_
oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Iooo
o`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol03?ooo`030000oooooooo02;oool00`000?oo
ooooo`1loooo001Woooo2C?o00_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool006Ooool9<ol02oooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool500000_ooo`800003oooo1@0000;oool00`000?ooooooo`1koooo001Woooo2C?o00_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?oo
ooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07_oool006Ooool9<ol02_ooo`030000
oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00?oool0
0`000?ooooooo`1joooo001Woooo2C?o00_oool00`000?ooooooo`0500003_ooo`030000oooooooo
00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Ioooo`Tco`0;oooo00D0003ooooo
ooooool000004Oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0Nooo
o`00Ioooo`Tco`0<oooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1l
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.67803 .12361 L
.68335 .12361 L
.68837 .12361 L
.69287 .12361 L
.6941 .12361 L
.6954 .12361 L
.69652 .12361 L
s
.69652 .12361 m
.697 .61803 L
s
0 .4 1 r
.02381 .09881 m
.04262 .0897 L
.06244 .08192 L
.08255 .0757 L
.10458 .07051 L
.12415 .06711 L
.14509 .06454 L
.1553 .06364 L
.16639 .06288 L
.17148 .06261 L
.17687 .06236 L
.18191 .06218 L
.18653 .06204 L
.19136 .06194 L
.19358 .0619 L
.19595 .06186 L
.19846 .06184 L
.19957 .06183 L
.20079 .06182 L
.20153 .06181 L
.20221 .06181 L
.20285 .06181 L
.20356 .06181 L
.20478 .0618 L
.20607 .0618 L
.2073 .0618 L
.20846 .06181 L
.2095 .06181 L
.21064 .06182 L
.21318 .06184 L
.21553 .06186 L
.21982 .06192 L
.22437 .062 L
.23374 .06224 L
.24384 .06259 L
.26212 .06344 L
.30326 .06613 L
.32379 .06776 L
.33379 .06861 L
.34288 .0694 L
.34743 .06973 L
.35236 .07001 L
.35462 .07011 L
.35702 .0702 L
.35926 .07027 L
.36131 .07032 L
.36364 .07036 L
.36493 .07037 L
.36615 .07038 L
.36728 .07039 L
Mistroke
.36832 .0704 L
.36946 .0704 L
.37068 .0704 L
.37138 .07039 L
.37202 .07039 L
.37273 .07039 L
.37347 .07038 L
.37472 .07037 L
.37609 .07035 L
.37863 .0703 L
.38099 .07025 L
.38601 .0701 L
.39147 .06988 L
.40138 .06936 L
.41995 .06802 L
.43977 .06615 L
.46079 .0638 L
.49859 .05886 L
.53885 .05295 L
.57759 .04694 L
.61878 .04053 L
.65845 .03468 L
.67846 .03198 L
.68718 .03088 L
.69176 .03032 L
.69427 .03002 L
.6955 .02987 L
.69661 .02974 L
.69782 .12361 L
.69912 .12361 L
.70188 .12361 L
.70673 .12361 L
.71626 .12361 L
.73723 .12361 L
.77704 .12361 L
.81534 .12361 L
.85609 .12361 L
.89532 .12361 L
.93304 .12361 L
.97321 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1@oooo201Voekoool0
06Ooool00`000?ooooooo`19oooo1`1Vo`Ooool00`1Vooooooooo`1Loooo001Woooo00<0003ooooo
ool0@Oooo`P0I_l>oooo00<0I_ooooooool0G?ooo`00Ioooo`030000oooooooo03coool506Ko5_oo
o`0306Kooooooooo05coool006Ooool00`000?ooooooo`0eoooo1`1Voa_oool00`1Vooooooooo`1L
oooo001Woooo0P0002koool806Ko8_ooo`0306Kooooooooo05coool006Ooool00`000?ooooooo`0X
oooo1@1Vob[oool00`1Vooooooooo`1Loooo001Woooo00<0003oooooool08Oooo`L0I_l_oooo00<0
I_ooooooool0G?ooo`00<oooobD0I_l?oooo00<0003oooooool06Oooo`P0I_lfoooo00<0I_oooooo
ool0G?ooo`00;_ooo`D0I_lUoooo3P1Vo`03oooo0000oooo013oool:06Ko?_ooo`0306Kooooooooo
05coool002Woool506Ko>?ooo`0306Ko000006Ko0100I_m8oooo00<0I_ooooooool0G?ooo`009?oo
o`D0I_lnoooo0P0005Soool00`1Vooooooooo`1Loooo000Goooo1@0000Koool206Ko5_ooo`800004
oooo0P0000Coool200007oooo`030000oooooooo01koool200001?ooo`800004oooo0P0001ooool5
00001oooo`0306Kooooooooo01?oool500000_ooo`800004oooo0P00023oool400005_ooo`006Ooo
o`030000oooooooo00?oool306Ko5oooo`040000oooooooo00002?ooo`040000oooooooo00007_oo
o`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00023oool00`000?oo
ooooo`07oooo00<0I_ooooooool05Oooo`030000oooooooo00Ooool010000?ooooooo`0001ooool0
0`000?ooooooo`0Goooo000Ioooo00@0003oooooooooool206Ko6_ooo`040000oooooooo00002ooo
o`030000oooooooo01coool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003ooooo
ool07_ooo`030000oooooooo00Ooool00`1Vooooooooo`0Eoooo00<0003oooooool02_ooo`030000
oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool01000001Vo`1Vo`1VoaKoool4
00000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`80000Qoooo00<0003oooooool01oooo`0306Kooooooooo01Goool00`000?ooooooo`08
oooo0P0002;oool00`000?ooooooo`0Eoooo000Hoooo00<0I_l0003oool07_ooo`040000oooooooo
00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0
003oooooool08?ooo`030000oooooooo00Ooool00`1Vooooooooo`0Eoooo00<0003oooooool02?oo
o`030000oooooooo01ooool010000?ooooooo`0001Koool001Koool206Ko0P00023oool200002_oo
o`<0000Noooo0P0001ooool200002_ooo`<0000Ooooo0P0000Woool00`1Vooooooooo`0Doooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0Eoooo`0306Kooooooooo05coool0
06Ooool00`000?ooooooo`1Goooo00<0I_ooooooool0G?ooo`00Ioooo`030000oooooooo05Ooool0
0`1Vooooooooo`1Loooo001Woooo00<0003oooooool0Eoooo`0306Kooooooooo05coool006Ooool0
0`000?ooooooo`1Goooo00<0I_ooooooool0G?ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`3o09T013?o02P00002oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o00030000<ol0<ol0
02@co`0;000000?o09T0000000000P0001Woool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00Ioooo`030000<ol0<ol004Lco`0500002oooo`03o`2Ioooooooo05coool006Ooool00`0003?o
03?o0012<ol01@00013oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`00?C?o00D0000E
oooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol003Tco`0400006_ooo`03o`2Ioooooooo
05coool006Ooool20000>3?o0080000Noooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol0
03Dco`0200008?ooo`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000c<ol00P0002;oool0
0ol0VOooooooo`1Loooo001Woooo00<0000co`0co`00<C?o0080000Toooo00?o09Woooooool0G?oo
o`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`0Toooo00?o09Woooooool0G?ooo`00Iooo
o`030000<ol0<ol002hco`0200009oooo`03o`2Ioooooooo05coool006Ooool20000;C?o0080000Y
oooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`0Yoooo00?o
09Woooooool0G?ooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`0Zoooo00?o09Wooooo
ool0G?ooo`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`0[oooo00?o09Woooooool0G?oo
o`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0/oooo00?o09Woooooool0G?ooo`00Iooo
o`030000<ol0<ol002Pco`000`000?ooooooo`0/oooo00?o09Woooooool0G?ooo`00Ioooo`80000X
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000V<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000U<ol000<0003ooooo
ool0;oooo`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000T<ol000<0003oooooool0<?oo
o`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000S<ol000<0003oooooool0<Oooo`03o`2I
oooooooo05coool006Ooool00`0003?o03?o000S<ol000<0003oooooool0<Oooo`03o`2Ioooooooo
05coool006Ooool200008c?o00030000oooooooo03;oool00ol0VOooooooo`1Loooo001Woooo00<0
000co`0co`008C?o00030000oooooooo03?oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0c
o`0083?o00030000oooooooo03Coool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`0083?o
00030000oooooooo03Coool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`007c?o00030000
oooooooo03Goool00ol0VOooooooo`1Loooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo05coool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`007S?o00030000oooooooo03Koool00ol0VOooooooo`1Loooo001Qoooo00<0003oooooool00ooo
o`80000O<ol000<0003oooooool0=_ooo`03o`2Ioooooooo05coool0067oool00`000?ooooooo`03
oooo00<0000co`0co`007C?o00030000oooooooo03Ooool00ol0VOooooooo`1Loooo001Qoooo00<0
003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0goooo00?o09Woooooool0G?oo
o`00H?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo03Soool00ol0VOooooooo`1L
oooo001Woooo00<0000co`0co`0073?o00030000oooooooo03Soool00ol0VOooooooo`1Loooo001W
oooo00<0000co`0co`006c?o00030000oooooooo03Woool00ol0VOooooooo`1Loooo001Woooo0P00
01`co`000`000?ooooooo`0ioooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0joooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0joooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0k
oooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0koooo00?o
09Woooooool0G?ooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`0loooo00?o09Wooooo
ool0G?ooo`00Ioooo`80000I<ol000<0003oooooool0??ooo`03o`2Ioooooooo05coool006Ooool0
0`0003?o03?o000G<ol000<0003oooooool0?Oooo`03o`2Ioooooooo05coool006Ooool00`0003?o
03?o000G<ol000<0003oooooool0?Oooo`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000F
<ol000<0003oooooool0?_ooo`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000F<ol000<0
003oooooool0?_ooo`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000F<ol000<0003ooooo
ool0?_ooo`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000E<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo05coool006Ooool200005S?o00030000oooooooo03ooool00ol0VOooooooo`1L
oooo001Woooo00<0000co`0co`005C?o00030000oooooooo03ooool00ol0VOooooooo`1Loooo001W
oooo00<0000co`0co`005C?o00030000oooooooo03ooool00ol0VOooooooo`1Loooo001Woooo00<0
000co`0co`0053?o00030000oooooooo043oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0c
o`0053?o00030000oooooooo043oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`0053?o
00030000oooooooo043oool00ol0VOooooooo`1Loooo001Woooo0P0001Dco`000`000?ooooooo`10
oooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`11oooo00?o
09Woooooool0G?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`11oooo00?o09Wooooo
ool0G?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`11oooo00?o09Woooooool0G?oo
o`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo047oool00ol0VOooooooo`1L
oooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`12oooo00?o
09Woooooool0G?ooo`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo04;oool0
0ol0VOooooooo`1Loooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?oo
ooooo`12oooo00?o09Woooooool0G?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0
014co`000`000?ooooooo`13oooo00?o09Woooooool0G?ooo`00H?ooo`800005oooo00<0000co`0c
o`004C?o00030000oooooooo04?oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`004C?o
00030000oooooooo04?oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`004C?o00030000
oooooooo04?oool00ol0VOooooooo`1Loooo001Woooo0P00014co`000`000?ooooooo`14oooo00?o
09Woooooool0G?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`14oooo00?o09Wooooo
ool0G?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`14oooo00?o09Woooooool0G?oo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`14oooo00?o09Woooooool0G?ooo`00Iooo
o`030000<ol0<ol000lco`000`000?ooooooo`15oooo00?o09Woooooool0G?ooo`00Ioooo`030000
<ol0<ol000lco`000`000?ooooooo`15oooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`15oooo00?o09Woooooool0G?ooo`00Ioooo`80000@<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000><ol000<0003oooooool0A_oo
o`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000><ol000<0003oooooool0A_ooo`03o`2I
oooooooo05coool006Ooool00`0003?o03?o000><ol000<0003oooooool0A_ooo`03o`2Ioooooooo
05coool006Ooool00`0003?o03?o000><ol000<0003oooooool0A_ooo`03o`2Ioooooooo05coool0
06Ooool00`0003?o03?o000=<ol000<0003oooooool0Aoooo`03o`2Ioooooooo05coool006Ooool2
00003S?o00030000oooooooo04Ooool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`003C?o
00030000oooooooo04Ooool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`003C?o00030000
oooooooo04Ooool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`0033?o00030000oooooooo
04Soool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`0033?o00030000oooooooo04Soool0
0ol0VOooooooo`1Loooo001Woooo00<0000co`0co`0033?o00030000oooooooo04Soool00ol0VOoo
ooooo`1Loooo001Woooo0P0000dco`000`000?ooooooo`18oooo00?o09Woooooool0G?ooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`18oooo00?o09Woooooool0G?ooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`18oooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol0
00/co`000`000?ooooooo`19oooo00?o09Woooooool0G?ooo`00H?ooo`800005oooo00<0000co`0c
o`002c?o00030000oooooooo04Woool00ol0VOooooooo`1Loooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`002c?o00030000oooooooo04Woool00ol0VOooooooo`1Loooo001Qoooo00<0
003oooooool00oooo`80000<<ol000<0003oooooool0BOooo`03o`2Ioooooooo05coool006;oool0
0`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo04Woool00ol0VOooooooo`1L
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo04Woool0
0ol0VOooooooo`1Loooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0B_oo
o`03o`2Ioooooooo05coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0B_ooo`03o`2I
oooooooo05coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0B_ooo`03o`2Ioooooooo
05coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05coool0
06Ooool200002c?o00030000oooooooo04[oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo04[oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`002C?o
00030000oooooooo04_oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`002C?o00030000
oooooooo04_oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`002C?o00030000oooooooo
04_oool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`002C?o00030000oooooooo04_oool0
0ol0VOooooooo`1Loooo001Woooo0P0000Xco`000`000?ooooooo`1;oooo00?o09Woooooool0G?oo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1;oooo00?o09Woooooool0G?ooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1;oooo00?o09Woooooool0G?ooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1<oooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1<oooo00?o09Woooooool0G?ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`1<oooo00?o09Woooooool0G?ooo`00Ioooo`800009<ol000<0003oooooool0C?oo
o`03o`2Ioooooooo05coool006Ooool00`0003?o03?o0008<ol000<0003oooooool0C?ooo`03o`2I
oooooooo05coool006Ooool00`0003?o03?o0008<ol000<0003oooooool0C?ooo`03o`2Ioooooooo
05coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0COooo`03o`2Ioooooooo05coool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0COooo`03o`2Ioooooooo05coool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0COooo`03o`2Ioooooooo05coool006Ooool2000023?o
00030000oooooooo04goool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`001c?o00030000
oooooooo04goool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`001c?o00030000oooooooo
04goool00ol0VOooooooo`1Loooo001Woooo00<0000co`0co`001c?o00030000oooooooo04goool0
0ol0VOooooooo`1Loooo001Woooo00<0000co`0co`001c?o00030000oooooooo04goool00ol0VOoo
ooooo`1Loooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0COooo`03o`2I
oooooooo05coool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo
04goool00ol0VOooooooo`1Loooo001Ooooo1@0000?oool2000023?o00030000oooooooo04goool0
0ol0VOooooooo`1Loooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?oo
o`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9
<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9
<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Iooo
o`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P00
00?oool5000000?oool0000000000P0000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?oo
ooooo`09oooo00D0003oooooooooool000001_ooo`030000oooooooo07Soool006Ooool9<ol01ooo
o`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo
00;oool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003ooooo
ool01@0000koool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000Aoooo00<0003ooooo
ool02Oooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001Woooo2C?o
00Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`800003oooo00<0003oooooool0NOoo
o`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.6883 .12361 L
.69774 .12361 L
.7003 .12361 L
.7017 .12361 L
.70301 .12361 L
s
.70301 .12361 m
.70346 .61803 L
s
0 .4 1 r
.02381 .09553 m
.04262 .08702 L
.06244 .07979 L
.08255 .07404 L
.10458 .06929 L
.12415 .06623 L
.13511 .06492 L
.14509 .06396 L
.15438 .06324 L
.16424 .06265 L
.16938 .06241 L
.17504 .0622 L
.18019 .06204 L
.18502 .06194 L
.18759 .06189 L
.18998 .06186 L
.1926 .06183 L
.19407 .06182 L
.1954 .06181 L
.19667 .06181 L
.19784 .0618 L
.19912 .0618 L
.19977 .0618 L
.20048 .0618 L
.20167 .06181 L
.20295 .06181 L
.20416 .06182 L
.20527 .06182 L
.20763 .06184 L
.20982 .06187 L
.21478 .06194 L
.21915 .06203 L
.22379 .06214 L
.23316 .06243 L
.24326 .06283 L
.26154 .06376 L
.30268 .06657 L
.32321 .06825 L
.33321 .06911 L
.3423 .06992 L
.34685 .07027 L
.35178 .07056 L
.35404 .07067 L
.35644 .07077 L
.35868 .07084 L
.36073 .0709 L
.36306 .07095 L
.36435 .07097 L
.36557 .07099 L
.3667 .071 L
Mistroke
.36774 .071 L
.36888 .07101 L
.3701 .07101 L
.3708 .07101 L
.37144 .07101 L
.37215 .07101 L
.37289 .071 L
.37414 .07099 L
.37551 .07098 L
.37805 .07094 L
.38041 .0709 L
.38544 .07076 L
.39089 .07056 L
.40081 .07007 L
.41937 .06878 L
.43919 .06696 L
.46021 .06466 L
.49801 .0598 L
.53827 .05395 L
.57701 .04796 L
.6182 .04153 L
.65787 .0356 L
.67788 .03283 L
.6866 .0317 L
.69604 .03052 L
.69859 .03021 L
.69999 .03005 L
.7013 .02989 L
.70242 .02976 L
.70361 .12361 L
.70429 .12361 L
.70494 .12361 L
.70615 .12361 L
.71568 .12361 L
.73665 .12361 L
.77495 .12361 L
.8157 .12361 L
.85493 .12361 L
.89265 .12361 L
.93282 .12361 L
.97147 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1@oooo2@1Voegoool0
06Ooool00`000?ooooooo`1;oooo1@1Vo`Soool00`1Vooooooooo`1Koooo001Woooo00<0003ooooo
ool0A_ooo`D0I_l=oooo00<0I_ooooooool0Foooo`00Ioooo`030000oooooooo03koool806Ko4_oo
o`0306Kooooooooo05_oool006Ooool00`000?ooooooo`0foooo201Voa[oool00`1Vooooooooo`1K
oooo001Woooo0P0003?oool406Ko8_ooo`0306Kooooooooo05_oool006Ooool00`000?ooooooo`0Z
oooo201VobKoool00`1Vooooooooo`1Koooo001Woooo00<0003oooooool08?ooo`X0I_l^oooo00<0
I_ooooooool0Foooo`00=?ooob@0I_l?oooo00<0003oooooool06Oooo`L0I_lhoooo00<0I_oooooo
ool0Foooo`00;_ooo`H0I_lToooo301Vo`?oool00`000?ooooooo`0Doooo1@1Vocooool00`1Voooo
ooooo`1Koooo000Yoooo1@1VocKoool306Ko00<00000I_l0I_l0501VodCoool00`1Vooooooooo`1K
oooo000Soooo1P1Vockoool20000FOooo`0306Kooooooooo05_oool001Ooool500000oooo`@0I_lG
oooo0P0000Coool200001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool2
00007oooo`D00009oooo00<0I_ooooooool04Oooo`D00002oooo0P0000Coool200008?ooo`@0000F
oooo000Ioooo00@0003oooooooooool206Ko6_ooo`040000oooooooo00002?ooo`040000oooooooo
00007_ooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00023oool0
0`000?ooooooo`09oooo00<0I_ooooooool04oooo`030000oooooooo00Ooool010000?ooooooo`00
01ooool00`000?ooooooo`0Goooo000Ioooo00@00000I_l0I_l0I_lLoooo00@0003oooooool0000;
oooo00<0003oooooool07?ooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?oo
ooooo`0Noooo00<0003oooooool02Oooo`0306Kooooooooo01?oool00`000?ooooooo`0:oooo00<0
003oooooool07_ooo`030000oooooooo01Koool0017oool400000oooo`0306Ko0000oooo01Soool4
00000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`80000Qoooo00<0003oooooool02Oooo`0306Kooooooooo01?oool00`000?ooooooo`08
oooo0P0002;oool00`000?ooooooo`0Eoooo000Foooo0P1Vo`03oooo0000oooo01koool010000?oo
ooooo`0000Woool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Ooo
o`030000oooooooo023oool00`000?ooooooo`09oooo00<0I_ooooooool04oooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00023oool200002_oo
o`<0000Noooo0P0001ooool200002_ooo`<0000Ooooo0P0000_oool00`1Vooooooooo`0Boooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0FOooo`0306Kooooooooo05[oool0
06Ooool00`000?ooooooo`1Ioooo00<0I_ooooooool0F_ooo`00Ioooo`030000oooooooo05Woool0
0`1Vooooooooo`1Joooo001Woooo00<0003oooooool0FOooo`0306Kooooooooo05[oool006Ooool0
0`000?ooooooo`1Ioooo00<0I_ooooooool0F_ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000@0000co`0co`3o09T3<ol0:00000;oool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0c
o`0093?o00`000001?l0V@000000000001Woool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00Ioooo`030000<ol0<ol004Lco`0500003?ooo`03o`2Ioooooooo05_oool006Ooool00`0003?o
03?o0012<ol01@00017oool00ol0VOooooooo`1Koooo001Woooo00<0000co`0co`00?C?o00D0000F
oooo00?o09Woooooool0Foooo`00Ioooo`030000<ol0<ol003Tco`0400006oooo`03o`2Ioooooooo
05_oool006Ooool20000>3?o0080000Ooooo00?o09Woooooool0Foooo`00Ioooo`030000<ol0<ol0
03Dco`0200008Oooo`03o`2Ioooooooo05_oool006Ooool00`0003?o03?o000c<ol00P0002?oool0
0ol0VOooooooo`1Koooo001Woooo00<0000co`0co`00<C?o0080000Uoooo00?o09Woooooool0Fooo
o`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`0Uoooo00?o09Woooooool0Foooo`00Iooo
o`030000<ol0<ol002hco`020000:?ooo`03o`2Ioooooooo05_oool006Ooool20000;C?o0080000Z
oooo00?o09Woooooool0Foooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`0Zoooo00?o
09Woooooool0Foooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`0[oooo00?o09Wooooo
ool0Foooo`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`0/oooo00?o09Woooooool0Fooo
o`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0]oooo00?o09Woooooool0Foooo`00Iooo
o`030000<ol0<ol002Pco`000`000?ooooooo`0]oooo00?o09Woooooool0Foooo`00Ioooo`80000X
<ol000<0003oooooool0;_ooo`03o`2Ioooooooo05_oool006Ooool00`0003?o03?o000V<ol000<0
003oooooool0;oooo`03o`2Ioooooooo05_oool006Ooool00`0003?o03?o000U<ol000<0003ooooo
ool0<?ooo`03o`2Ioooooooo05_oool006Ooool00`0003?o03?o000T<ol000<0003oooooool0<Ooo
o`03o`2Ioooooooo05_oool006Ooool00`0003?o03?o000S<ol000<0003oooooool0<_ooo`03o`2I
oooooooo05_oool006Ooool00`0003?o03?o000S<ol000<0003oooooool0<_ooo`03o`2Ioooooooo
05_oool006Ooool200008c?o00030000oooooooo03?oool00ol0VOooooooo`1Koooo001Woooo00<0
000co`0co`008C?o00030000oooooooo03Coool00ol0VOooooooo`1Koooo001Woooo00<0000co`0c
o`0083?o00030000oooooooo03Goool00ol0VOooooooo`1Koooo001Woooo00<0000co`0co`0083?o
00030000oooooooo03Goool00ol0VOooooooo`1Koooo001Woooo00<0000co`0co`007c?o00030000
oooooooo03Koool00ol0VOooooooo`1Koooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0
003oooooool0=_ooo`03o`2Ioooooooo05_oool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`007S?o00030000oooooooo03Ooool00ol0VOooooooo`1Koooo001Qoooo00<0003oooooool00ooo
o`80000O<ol000<0003oooooool0=oooo`03o`2Ioooooooo05_oool0067oool00`000?ooooooo`03
oooo00<0000co`0co`007C?o00030000oooooooo03Soool00ol0VOooooooo`1Koooo001Qoooo00<0
003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0hoooo00?o09Woooooool0Fooo
o`00H?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo03Woool00ol0VOooooooo`1K
oooo001Woooo00<0000co`0co`0073?o00030000oooooooo03Woool00ol0VOooooooo`1Koooo001W
oooo00<0000co`0co`006c?o00030000oooooooo03[oool00ol0VOooooooo`1Koooo001Woooo0P00
01`co`000`000?ooooooo`0joooo00?o09Woooooool0Foooo`00Ioooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0koooo00?o09Woooooool0Foooo`00Ioooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0koooo00?o09Woooooool0Foooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0l
oooo00?o09Woooooool0Foooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0loooo00?o
09Woooooool0Foooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`0moooo00?o09Wooooo
ool0Foooo`00Ioooo`80000I<ol000<0003oooooool0?Oooo`03o`2Ioooooooo05_oool006Ooool0
0`0003?o03?o000G<ol000<0003oooooool0?_ooo`03o`2Ioooooooo05_oool006Ooool00`0003?o
03?o000G<ol000<0003oooooool0?_ooo`03o`2Ioooooooo05_oool006Ooool00`0003?o03?o000F
<ol000<0003oooooool0?oooo`03o`2Ioooooooo05_oool006Ooool00`0003?o03?o000F<ol000<0
003oooooool0?oooo`03o`2Ioooooooo05_oool006Ooool00`0003?o03?o000F<ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo05_oool006Ooool00`0003?o03?o000E<ol000<0003oooooool0@?oo
o`03o`2Ioooooooo05_oool006Ooool200005S?o00030000oooooooo043oool00ol0VOooooooo`1K
oooo001Woooo00<0000co`0co`005C?o00030000oooooooo043oool00ol0VOooooooo`1Koooo001W
oooo00<0000co`0co`005C?o00030000oooooooo043oool00ol0VOooooooo`1Koooo001Woooo00<0
000co`0co`0053?o00030000oooooooo047oool00ol0VOooooooo`1Koooo001Woooo00<0000co`0c
o`0053?o00030000oooooooo047oool00ol0VOooooooo`1Koooo001Woooo00<0000co`0co`0053?o
00030000oooooooo047oool00ol0VOooooooo`1Koooo001Woooo0P0001Dco`000`000?ooooooo`11
oooo00?o09Woooooool0Foooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`12oooo00?o
09Woooooool0Foooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`12oooo00?o09Wooooo
ool0Foooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`12oooo00?o09Woooooool0Fooo
o`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo04;oool00ol0VOooooooo`1K
oooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`13oooo00?o
09Woooooool0Foooo`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo04?oool0
0ol0VOooooooo`1Koooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?oo
ooooo`14oooo00?o09Woooooool0F_ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0
014co`000`000?ooooooo`15oooo00?o09Woooooool0F_ooo`00H?ooo`800005oooo00<0000co`0c
o`004C?o00030000oooooooo04Goool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`004C?o
00030000oooooooo04Goool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`004C?o00030000
oooooooo04Goool00ol0VOooooooo`1Joooo001Woooo0P00014co`000`000?ooooooo`16oooo00?o
09Woooooool0F_ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`16oooo00?o09Wooooo
ool0F_ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`16oooo00?o09Woooooool0F_oo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`16oooo00?o09Woooooool0F_ooo`00Iooo
o`030000<ol0<ol000lco`000`000?ooooooo`17oooo00?o09Woooooool0F_ooo`00Ioooo`030000
<ol0<ol000lco`000`000?ooooooo`17oooo00?o09Woooooool0F_ooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`17oooo00?o09Woooooool0F_ooo`00Ioooo`80000@<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo05[oool006Ooool00`0003?o03?o000><ol000<0003oooooool0B?oo
o`03o`2Ioooooooo05[oool006Ooool00`0003?o03?o000><ol000<0003oooooool0B?ooo`03o`2I
oooooooo05[oool006Ooool00`0003?o03?o000><ol000<0003oooooool0B?ooo`03o`2Ioooooooo
05[oool006Ooool00`0003?o03?o000><ol000<0003oooooool0B?ooo`03o`2Ioooooooo05[oool0
06Ooool00`0003?o03?o000=<ol000<0003oooooool0BOooo`03o`2Ioooooooo05[oool006Ooool2
00003S?o00030000oooooooo04Woool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`003C?o
00030000oooooooo04Woool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`003C?o00030000
oooooooo04Woool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`0033?o00030000oooooooo
04[oool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`0033?o00030000oooooooo04[oool0
0ol0VOooooooo`1Joooo001Woooo00<0000co`0co`0033?o00030000oooooooo04[oool00ol0VOoo
ooooo`1Joooo001Woooo0P0000dco`000`000?ooooooo`1:oooo00?o09Woooooool0F_ooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`1:oooo00?o09Woooooool0F_ooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`1:oooo00?o09Woooooool0F_ooo`00Ioooo`030000<ol0<ol0
00/co`000`000?ooooooo`1;oooo00?o09Woooooool0F_ooo`00H?ooo`800005oooo00<0000co`0c
o`002c?o00030000oooooooo04_oool00ol0VOooooooo`1Joooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`002c?o00030000oooooooo04_oool00ol0VOooooooo`1Joooo001Qoooo00<0
003oooooool00oooo`80000<<ol000<0003oooooool0Boooo`03o`2Ioooooooo05[oool006;oool0
0`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo04_oool00ol0VOooooooo`1J
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo04_oool0
0ol0VOooooooo`1Joooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0C?oo
o`03o`2Ioooooooo05[oool006Ooool00`0003?o03?o000:<ol000<0003oooooool0C?ooo`03o`2I
oooooooo05[oool006Ooool00`0003?o03?o000:<ol000<0003oooooool0C?ooo`03o`2Ioooooooo
05[oool006Ooool00`0003?o03?o000:<ol000<0003oooooool0C?ooo`03o`2Ioooooooo05[oool0
06Ooool200002c?o00030000oooooooo04coool00ol0VOooooooo`1Joooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo04coool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`002C?o
00030000oooooooo04goool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`002C?o00030000
oooooooo04goool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`002C?o00030000oooooooo
04goool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`002C?o00030000oooooooo04goool0
0ol0VOooooooo`1Joooo001Woooo0P0000Xco`000`000?ooooooo`1=oooo00?o09Woooooool0F_oo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1=oooo00?o09Woooooool0F_ooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1=oooo00?o09Woooooool0F_ooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1>oooo00?o09Woooooool0F_ooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1>oooo00?o09Woooooool0F_ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`1>oooo00?o09Woooooool0F_ooo`00Ioooo`800009<ol000<0003oooooool0C_oo
o`03o`2Ioooooooo05[oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0C_ooo`03o`2I
oooooooo05[oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0C_ooo`03o`2Ioooooooo
05[oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Coooo`03o`2Ioooooooo05[oool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0Coooo`03o`2Ioooooooo05[oool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0Coooo`03o`2Ioooooooo05[oool006Ooool2000023?o
00030000oooooooo04ooool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`001c?o00030000
oooooooo04ooool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`001c?o00030000oooooooo
04ooool00ol0VOooooooo`1Joooo001Woooo00<0000co`0co`001c?o00030000oooooooo04ooool0
0ol0VOooooooo`1Joooo001Woooo00<0000co`0co`001c?o00030000oooooooo04ooool00ol0VOoo
ooooo`1Joooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0Coooo`03o`2I
oooooooo05[oool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo
04ooool00ol0VOooooooo`1Joooo001Ooooo1@0000?oool2000023?o00030000oooooooo04ooool0
0ol0VOooooooo`1Joooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?oo
o`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9
<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9
<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Iooo
o`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P00
00?oool500000oooo`<00002oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02Ooo
o`030000oooooooo00Coool01@000?ooooooooooo`00001joooo001Woooo2C?o00Ooool00`000?oo
ooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Woool010000?ooooooooooo`D00003
oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000koool00`000?oo
ooooo`09oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000007[oool006Ooool9
<ol02?ooo`050000oooooooooooo0000017oool00`000?ooooooo`09oooo00<0003oooooool00_oo
o`030000oooo000000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?ooooooo`0A
oooo0P0000[oool200001Oooo`800002oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001W
oooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.69774 .12361 L
.7026 .12361 L
.70516 .12361 L
.70656 .12361 L
.70787 .12361 L
.70901 .12361 L
s
.70901 .12361 m
.7095 .61803 L
s
0 .4 1 r
.02381 .09246 m
.04262 .08452 L
.06244 .07782 L
.08255 .07252 L
.10458 .06819 L
.12415 .06544 L
.13511 .06428 L
.14509 .06345 L
.15504 .0628 L
.16424 .06236 L
.16904 .06219 L
.17432 .06203 L
.17698 .06197 L
.17985 .06192 L
.18256 .06187 L
.18502 .06184 L
.18624 .06183 L
.18755 .06182 L
.18895 .06181 L
.19026 .06181 L
.19149 .0618 L
.19279 .0618 L
.1939 .0618 L
.19512 .06181 L
.19586 .06181 L
.19656 .06181 L
.19788 .06182 L
.19929 .06183 L
.20083 .06184 L
.20359 .06187 L
.20615 .0619 L
.21078 .06199 L
.21589 .0621 L
.22624 .06241 L
.23634 .06281 L
.24559 .06324 L
.26645 .06444 L
.30607 .06735 L
.32604 .06904 L
.33474 .06981 L
.34418 .07065 L
.34943 .07102 L
.35427 .07127 L
.35889 .07145 L
.36122 .07152 L
.36379 .07157 L
.36519 .07159 L
.36652 .07161 L
.36771 .07162 L
.36901 .07163 L
Mistroke
.36975 .07163 L
.37042 .07163 L
.37119 .07163 L
.37192 .07163 L
.37321 .07163 L
.37394 .07162 L
.37461 .07162 L
.37583 .07161 L
.37696 .07159 L
.37954 .07155 L
.38205 .0715 L
.38474 .07143 L
.39004 .07125 L
.39494 .07104 L
.40602 .07044 L
.42615 .06893 L
.46547 .06483 L
.50327 .05993 L
.54353 .05406 L
.58227 .04807 L
.62346 .04164 L
.66314 .03571 L
.68314 .03293 L
.69186 .03179 L
.7013 .03061 L
.70386 .0303 L
.70656 .02998 L
.70768 .02985 L
.70887 .02971 L
.71019 .12361 L
.71141 .12361 L
.72095 .12361 L
.74191 .12361 L
.78324 .12361 L
.82305 .12361 L
.86135 .12361 L
.9021 .12361 L
.94133 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Aoooo2P1Voe_oool0
06Ooool00`000?ooooooo`1<oooo1@1Vo`Woool00`1Vooooooooo`1Ioooo001Woooo00<0003ooooo
ool0Aoooo`D0I_l>oooo00<0I_ooooooool0FOooo`00Ioooo`030000oooooooo043oool706Ko4ooo
o`0306Kooooooooo05Woool006Ooool00`000?ooooooo`0hoooo201Voa[oool00`1Vooooooooo`1I
oooo001Woooo0P0003Coool506Ko8_ooo`0306Kooooooooo05Woool006Ooool00`000?ooooooo`0/
oooo1`1VobOoool00`1Vooooooooo`1Ioooo001Woooo00<0003oooooool08_ooo`X0I_l^oooo00<0
I_ooooooool0FOooo`00<_ooobL0I_l>oooo00<0003oooooool06_ooo`P0I_lhoooo00<0I_oooooo
ool0FOooo`00:Oooo`T0I_lWoooo201Vo`Koool00`000?ooooooo`0Eoooo1@1Vod3oool00`1Voooo
ooooo`1Ioooo000Toooo1@1VocSoool606Ko00<00000I_l0I_l05@1VodGoool00`1Vooooooooo`1I
oooo000Roooo0P1Vod?oool20000Foooo`0306Kooooooooo05Woool001Ooool500000_ooo`@0I_lH
oooo0P0000Coool200001?ooo`80000Ooooo00<0003oooooool07_ooo`800004oooo0P0000Coool2
00007oooo`D0000:oooo00<0I_ooooooool04?ooo`D00002oooo0P0000Coool200008?ooo`@0000F
oooo000Ioooo00<0003oool0I_l00P1Voa_oool010000?ooooooo`0000Soool010000?ooooooo`00
01koool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000Poooo00<0
003oooooool02_ooo`0306Kooooooooo01;oool00`000?ooooooo`07oooo00@0003oooooool0000O
oooo00<0003oooooool05oooo`006Oooo`03000006Kooooo01goool010000?ooooooo`0000_oool0
0`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo
01koool00`000?ooooooo`0:oooo00<0I_ooooooool04_ooo`030000oooooooo00[oool00`000?oo
ooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00002oooo0P1Vo`030000oooooooo01Ooool4
00000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`80000Qoooo00<0003oooooool02_ooo`0306Kooooooooo01;oool00`000?ooooooo`08
oooo0P0002;oool00`000?ooooooo`0Eoooo000Foooo00@0I_ooooooool0000Ooooo00@0003ooooo
ool00009oooo00<0003oooooool07_ooo`030000oooooooo01goool010000?ooooooo`0000Woool0
0`000?ooooooo`0Poooo00<0003oooooool02_ooo`0306Kooooooooo01;oool00`000?ooooooo`08
oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool3
00007_ooo`80000Ooooo0P0000[oool300007oooo`80000<oooo00<0I_ooooooool04Oooo`80000:
oooo0`00023oool200005oooo`00Ioooo`030000oooooooo05[oool00`1Vooooooooo`1Ioooo001W
oooo00<0003oooooool0F_ooo`0306Kooooooooo05Woool006Ooool00`000?ooooooo`1Joooo00<0
I_ooooooool0FOooo`00Ioooo`030000oooooooo05[oool00`1Vooooooooo`1Ioooo001Woooo00<0
003oooooool0F_ooo`0306Kooooooooo05Woool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0008co`000ol0VC?o0000000W00000_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`00
0`0003?o03?o000T<ol03P000003o`2I0000oooo01Soool00`000?ooooooo`0Voooo00<0003ooooo
ool05Oooo`00Ioooo`030000<ol0<ol004Lco`0500003_ooo`03o`2Ioooooooo05Woool006Ooool0
0`0003?o03?o0012<ol01@0001?oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`00?C?o
00D0000Hoooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol003Tco`0400007Oooo`03o`2I
oooooooo05Woool006Ooool20000>3?o0080000Qoooo00?o09Woooooool0FOooo`00Ioooo`030000
<ol0<ol003Dco`0200008oooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000c<ol00P00
02Goool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`00<C?o0080000Woooo00?o09Wooooo
ool0FOooo`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`0Woooo00?o09Woooooool0FOoo
o`00Ioooo`030000<ol0<ol002hco`020000:_ooo`03o`2Ioooooooo05Woool006Ooool20000;C?o
0080000/oooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`0/
oooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`0]oooo00?o
09Woooooool0FOooo`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`0^oooo00?o09Wooooo
ool0FOooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0_oooo00?o09Woooooool0FOoo
o`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0_oooo00?o09Woooooool0FOooo`00Iooo
o`80000X<ol000<0003oooooool0<?ooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000V
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000U<ol000<0
003oooooool0<_ooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000T<ol000<0003ooooo
ool0<oooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000S<ol000<0003oooooool0=?oo
o`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000S<ol000<0003oooooool0=?ooo`03o`2I
oooooooo05Woool006Ooool200008c?o00030000oooooooo03Goool00ol0VOooooooo`1Ioooo001W
oooo00<0000co`0co`008C?o00030000oooooooo03Koool00ol0VOooooooo`1Ioooo001Woooo00<0
000co`0co`0083?o00030000oooooooo03Ooool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0c
o`0083?o00030000oooooooo03Ooool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`007c?o
00030000oooooooo03Soool00ol0VOooooooo`1Ioooo001Ooooo1@0000?oool00`0003?o03?o000O
<ol000<0003oooooool0>?ooo`03o`2Ioooooooo05Woool0067oool00`000?ooooooo`03oooo00<0
000co`0co`007S?o00030000oooooooo03Woool00ol0VOooooooo`1Ioooo001Qoooo00<0003ooooo
ool00oooo`80000O<ol000<0003oooooool0>Oooo`03o`2Ioooooooo05Woool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo03[oool00ol0VOooooooo`1Ioooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0joooo00?o09Wooooo
ool0FOooo`00H?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo03_oool00ol0VOoo
ooooo`1Ioooo001Woooo00<0000co`0co`0073?o00030000oooooooo03_oool00ol0VOooooooo`1I
oooo001Woooo00<0000co`0co`006c?o00030000oooooooo03coool00ol0VOooooooo`1Ioooo001W
oooo0P0001`co`000`000?ooooooo`0loooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol0
01Xco`000`000?ooooooo`0moooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0moooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol001Tco`000`000?oo
ooooo`0noooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`0n
oooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`0ooooo00?o
09Woooooool0FOooo`00Ioooo`80000I<ol000<0003oooooool0?oooo`03o`2Ioooooooo05Woool0
06Ooool00`0003?o03?o000G<ol000<0003oooooool0@?ooo`03o`2Ioooooooo05Woool006Ooool0
0`0003?o03?o000G<ol000<0003oooooool0@?ooo`03o`2Ioooooooo05Woool006Ooool00`0003?o
03?o000F<ol000<0003oooooool0@Oooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000F
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000F<ol000<0
003oooooool0@Oooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000E<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo05Woool006Ooool200005S?o00030000oooooooo04;oool00ol0VOoo
ooooo`1Ioooo001Woooo00<0000co`0co`005C?o00030000oooooooo04;oool00ol0VOooooooo`1I
oooo001Woooo00<0000co`0co`005C?o00030000oooooooo04;oool00ol0VOooooooo`1Ioooo001W
oooo00<0000co`0co`0053?o00030000oooooooo04?oool00ol0VOooooooo`1Ioooo001Woooo00<0
000co`0co`0053?o00030000oooooooo04?oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0c
o`0053?o00030000oooooooo04?oool00ol0VOooooooo`1Ioooo001Woooo0P0001Dco`000`000?oo
ooooo`13oooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`14
oooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`14oooo00?o
09Woooooool0FOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`14oooo00?o09Wooooo
ool0FOooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo04Coool00ol0VOoo
ooooo`1Ioooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`15
oooo00?o09Woooooool0FOooo`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo
04Goool00ol0VOooooooo`1Ioooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`00
0`000?ooooooo`15oooo00?o09Woooooool0FOooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol0014co`000`000?ooooooo`16oooo00?o09Woooooool0FOooo`00H?ooo`800005oooo00<0
000co`0co`004C?o00030000oooooooo04Koool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0c
o`004C?o00030000oooooooo04Koool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`004C?o
00030000oooooooo04Koool00ol0VOooooooo`1Ioooo001Woooo0P00014co`000`000?ooooooo`17
oooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`17oooo00?o
09Woooooool0FOooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`17oooo00?o09Wooooo
ool0FOooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`17oooo00?o09Woooooool0FOoo
o`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`18oooo00?o09Woooooool0FOooo`00Iooo
o`030000<ol0<ol000lco`000`000?ooooooo`18oooo00?o09Woooooool0FOooo`00Ioooo`030000
<ol0<ol000lco`000`000?ooooooo`18oooo00?o09Woooooool0FOooo`00Ioooo`80000@<ol000<0
003oooooool0B?ooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000><ol000<0003ooooo
ool0BOooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0BOoo
o`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0BOooo`03o`2I
oooooooo05Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0BOooo`03o`2Ioooooooo
05Woool006Ooool00`0003?o03?o000=<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05Woool0
06Ooool200003S?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0c
o`003C?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`003C?o
00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`0033?o00030000
oooooooo04_oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`0033?o00030000oooooooo
04_oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`0033?o00030000oooooooo04_oool0
0ol0VOooooooo`1Ioooo001Woooo0P0000dco`000`000?ooooooo`1;oooo00?o09Woooooool0FOoo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1;oooo00?o09Woooooool0FOooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`1;oooo00?o09Woooooool0FOooo`00Ioooo`030000
<ol0<ol000/co`000`000?ooooooo`1<oooo00?o09Woooooool0FOooo`00H?ooo`800005oooo00<0
000co`0co`002c?o00030000oooooooo04coool00ol0VOooooooo`1Ioooo001Ooooo00@0003ooooo
ool00004oooo00<0000co`0co`002c?o00030000oooooooo04coool00ol0VOooooooo`1Ioooo001Q
oooo00<0003oooooool00oooo`80000<<ol000<0003oooooool0C?ooo`03o`2Ioooooooo05Woool0
06;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo04coool00ol0VOoo
ooooo`1Ioooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo
04coool00ol0VOooooooo`1Ioooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003ooooo
ool0COooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000:<ol000<0003oooooool0COoo
o`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o000:<ol000<0003oooooool0COooo`03o`2I
oooooooo05Woool006Ooool00`0003?o03?o000:<ol000<0003oooooool0COooo`03o`2Ioooooooo
05Woool006Ooool200002c?o00030000oooooooo04goool00ol0VOooooooo`1Ioooo001Woooo00<0
000co`0co`002S?o00030000oooooooo04goool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo04koool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`002C?o
00030000oooooooo04koool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`002C?o00030000
oooooooo04koool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`002C?o00030000oooooooo
04koool00ol0VOooooooo`1Ioooo001Woooo0P0000Xco`000`000?ooooooo`1>oooo00?o09Wooooo
ool0FOooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1>oooo00?o09Woooooool0FOoo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1>oooo00?o09Woooooool0FOooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`1?oooo00?o09Woooooool0FOooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1?oooo00?o09Woooooool0FOooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1?oooo00?o09Woooooool0FOooo`00Ioooo`800009<ol000<0003ooooo
ool0Coooo`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Cooo
o`03o`2Ioooooooo05Woool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Coooo`03o`2I
oooooooo05Woool006Ooool00`0003?o03?o0007<ol000<0003oooooool0D?ooo`03o`2Ioooooooo
05Woool006Ooool00`0003?o03?o0007<ol000<0003oooooool0D?ooo`03o`2Ioooooooo05Woool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0D?ooo`03o`2Ioooooooo05Woool006Ooool2
000023?o00030000oooooooo053oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`001c?o
00030000oooooooo053oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`001c?o00030000
oooooooo053oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`001c?o00030000oooooooo
053oool00ol0VOooooooo`1Ioooo001Woooo00<0000co`0co`001c?o00030000oooooooo053oool0
0ol0VOooooooo`1Ioooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0D?oo
o`03o`2Ioooooooo05Woool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000
oooooooo053oool00ol0VOooooooo`1Ioooo001Ooooo1@0000?oool2000023?o00030000oooooooo
053oool00ol0VOooooooo`1Ioooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool0
0`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool0
06Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
06Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
oooo0P0000?oool5000000Coool0000000000004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0
003oooooool02Oooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001W
oooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Woool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo07Ooool006Ooool9
<ol02?ooo`030000oooooooo00D0000>oooo00<0003oooooool02Oooo`040000oooooooooooo0`00
00Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000Aoooo00<0
003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000
oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.69774 .12361 L
.7026 .12361 L
.70787 .12361 L
.71028 .12361 L
.71284 .12361 L
.71389 .12361 L
.71502 .12361 L
s
.71502 .12361 m
.71551 .61803 L
s
0 .4 1 r
.02381 .08959 m
.04262 .0822 L
.06244 .07599 L
.08255 .07112 L
.09409 .0689 L
.10458 .06719 L
.12415 .06474 L
.13491 .06374 L
.14509 .06302 L
.15478 .0625 L
.15968 .06229 L
.16506 .06211 L
.16965 .06199 L
.17218 .06194 L
.17458 .0619 L
.17681 .06187 L
.17924 .06184 L
.18031 .06183 L
.18145 .06182 L
.18251 .06181 L
.1835 .06181 L
.18474 .06181 L
.1854 .0618 L
.18611 .0618 L
.18685 .0618 L
.18755 .0618 L
.18886 .06181 L
.19009 .06181 L
.19122 .06182 L
.19247 .06182 L
.19379 .06183 L
.19652 .06186 L
.19908 .06189 L
.20491 .062 L
.20998 .06211 L
.21462 .06224 L
.22508 .0626 L
.24401 .06349 L
.26471 .06474 L
.30527 .06781 L
.32401 .06942 L
.33387 .07031 L
.34432 .07125 L
.3496 .07162 L
.35241 .07178 L
.35542 .07193 L
.35819 .07203 L
.36071 .07211 L
.36325 .07217 L
.36566 .07221 L
Mistroke
.36693 .07223 L
.36808 .07224 L
.36872 .07225 L
.36941 .07225 L
.37066 .07226 L
.37184 .07226 L
.37308 .07226 L
.37414 .07225 L
.3753 .07224 L
.37668 .07223 L
.37793 .07221 L
.38074 .07217 L
.38335 .07211 L
.38581 .07205 L
.39549 .07169 L
.40038 .07145 L
.40576 .07114 L
.42419 .06982 L
.46445 .06575 L
.50319 .0608 L
.54438 .05485 L
.58406 .04873 L
.62222 .04277 L
.66283 .03662 L
.68161 .03396 L
.70193 .03128 L
.70734 .03061 L
.7103 .03025 L
.71306 .02992 L
.71427 .02978 L
.71542 .02964 L
.71674 .12361 L
.71795 .12361 L
.72332 .12361 L
.74348 .12361 L
.78178 .12361 L
.82253 .12361 L
.86176 .12361 L
.89948 .12361 L
.93965 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Foooo1`1VoeWoool0
06Ooool00`000?ooooooo`1<oooo2P1Vo`Koool00`1Vooooooooo`1Goooo001Woooo00<0003ooooo
ool0Aoooo`D0I_l@oooo00<0I_ooooooool0Eoooo`00Ioooo`030000oooooooo043oool706Ko5Ooo
o`0306Kooooooooo05Ooool006Ooool00`000?ooooooo`0hoooo201Voacoool00`1Vooooooooo`1G
oooo001Woooo0P0003Coool506Ko9?ooo`0306Kooooooooo05Ooool006Ooool00`000?ooooooo`0/
oooo1`1VobWoool00`1Vooooooooo`1Goooo001Woooo00<0003oooooool09?ooo`P0I_l`oooo00<0
I_ooooooool0Eoooo`00;_ooob/0I_l>oooo00<0003oooooool07oooo`D0I_lhoooo00<0I_oooooo
ool0Eoooo`00:_ooo`@0I_l[oooo1`1Vo`Ooool00`000?ooooooo`0Hoooo1`1Vocgoool00`1Voooo
ooooo`1Goooo000Soooo1`1VocKoool706Ko00<00000I_l0I_l0601VodCoool00`1Vooooooooo`1G
oooo000Ooooo101VodCoool20000GOooo`0306Kooooooooo05Ooool001Ooool5000000?oool0I_l0
I_l06oooo`800004oooo0P0000Coool200007oooo`030000oooooooo01koool200001?ooo`800004
oooo0P0001ooool500003?ooo`0306Kooooooooo00koool500000_ooo`800004oooo0P00023oool4
00005_ooo`006Oooo`04000006Ko06Ko06Ko7?ooo`040000oooooooo00002?ooo`040000oooooooo
00007_ooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00023oool0
0`000?ooooooo`0<oooo00<0I_ooooooool04?ooo`030000oooooooo00Ooool010000?ooooooo`00
01ooool00`000?ooooooo`0Goooo000Hoooo00<0I_l0003oool07_ooo`040000oooooooo00002ooo
o`030000oooooooo01coool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003ooooo
ool07_ooo`030000oooooooo00coool00`1Vooooooooo`0@oooo00<0003oooooool02_ooo`030000
oooooooo01koool00`000?ooooooo`0Foooo000Aoooo10000005oooo06Ko06Kooooo000001Woool4
00000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`80000Qoooo00<0003oooooool03?ooo`0306Kooooooooo013oool00`000?ooooooo`08
oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0
003oooooool08?ooo`030000oooooooo00coool00`1Vooooooooo`0@oooo00<0003oooooool02?oo
o`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`00
01koool200007oooo`80000:oooo0`0001ooool200003_ooo`0306Kooooooooo00ooool200002_oo
o`<0000Poooo0P0001Ooool006Ooool00`000?ooooooo`1Loooo00<0I_ooooooool0Eoooo`00Iooo
o`030000oooooooo05coool00`1Vooooooooo`1Goooo001Woooo00<0003oooooool0G?ooo`0306Ko
oooooooo05Ooool006Ooool00`000?ooooooo`1Loooo00<0I_ooooooool0Eoooo`00Ioooo`030000
oooooooo05coool00`1Vooooooooo`1Goooo000@ooooo`00017oool001Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0003<ol000?o09T0000000009P0000;oool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0
000co`0co`0093?o00l000000ol0VOooooooo`0Goooo00<0003oooooool09_ooo`030000oooooooo
01Goool006Ooool00`0003?o03?o0017<ol01@0000ooool00ol0VOooooooo`1Hoooo001Woooo00<0
000co`0co`00@S?o00D0000Doooo00?o09Woooooool0F?ooo`00Ioooo`030000<ol0<ol003dco`05
00006Oooo`03o`2Ioooooooo05Soool006Ooool00`0003?o03?o000i<ol0100001koool00ol0VOoo
ooooo`1Hoooo001Woooo0P0003Pco`0200008_ooo`03o`2Ioooooooo05Soool006Ooool00`0003?o
03?o000e<ol00P0002Coool00ol0VOooooooo`1Hoooo001Woooo00<0000co`0co`00<c?o0080000V
oooo00?o09Woooooool0F?ooo`00Ioooo`030000<ol0<ol0034co`020000:?ooo`03o`2Ioooooooo
05Soool006Ooool00`0003?o03?o000`<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Soool0
06Ooool00`0003?o03?o000^<ol00P0002_oool00ol0VOooooooo`1Hoooo001Woooo0P0002dco`02
0000;Oooo`03o`2Ioooooooo05Soool006Ooool00`0003?o03?o000[<ol000<0003oooooool0;Ooo
o`03o`2Ioooooooo05Soool006Ooool00`0003?o03?o000Z<ol000<0003oooooool0;_ooo`03o`2I
oooooooo05Soool006Ooool00`0003?o03?o000Y<ol000<0003oooooool0;oooo`03o`2Ioooooooo
05Soool006Ooool00`0003?o03?o000X<ol000<0003oooooool0<?ooo`03o`2Ioooooooo05Soool0
06Ooool00`0003?o03?o000X<ol000<0003oooooool0<?ooo`03o`2Ioooooooo05Soool006Ooool2
0000:3?o00030000oooooooo037oool00ol0VOooooooo`1Hoooo001Woooo00<0000co`0co`009S?o
00030000oooooooo03;oool00ol0VOooooooo`1Hoooo001Woooo00<0000co`0co`009C?o00030000
oooooooo03?oool00ol0VOooooooo`1Hoooo001Woooo00<0000co`0co`0093?o00030000oooooooo
03Coool00ol0VOooooooo`1Hoooo001Woooo00<0000co`0co`008c?o00030000oooooooo03Goool0
0ol0VOooooooo`1Hoooo001Woooo00<0000co`0co`008c?o00030000oooooooo03Goool00ol0VOoo
ooooo`1Hoooo001Woooo0P0002<co`000`000?ooooooo`0foooo00?o09Woooooool0F?ooo`00Iooo
o`030000<ol0<ol0024co`000`000?ooooooo`0goooo00?o09Woooooool0F?ooo`00Ioooo`030000
<ol0<ol0020co`000`000?ooooooo`0hoooo00?o09Woooooool0F?ooo`00Ioooo`030000<ol0<ol0
020co`000`000?ooooooo`0hoooo00?o09Woooooool0F?ooo`00Ioooo`030000<ol0<ol001lco`00
0`000?ooooooo`0ioooo00?o09Woooooool0F?ooo`00Goooo`D00003oooo00<0000co`0co`007c?o
00030000oooooooo03Woool00ol0VOooooooo`1Hoooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001hco`000`000?ooooooo`0joooo00?o09Woooooool0F?ooo`00HOooo`030000oooooooo
00?oool200007c?o00030000oooooooo03[oool00ol0VOooooooo`1Hoooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0koooo00?o09Woooooool0F?ooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0>oooo`03o`2Ioooooooo
05Soool0063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`0loooo00?o09Wooooo
ool0F?ooo`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`0loooo00?o09Woooooool0F?oo
o`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`0moooo00?o09Woooooool0F?ooo`00Iooo
o`80000L<ol000<0003oooooool0?Oooo`03o`2Ioooooooo05Soool006Ooool00`0003?o03?o000J
<ol000<0003oooooool0?_ooo`03o`2Ioooooooo05Soool006Ooool00`0003?o03?o000J<ol000<0
003oooooool0?_ooo`03o`2Ioooooooo05Soool006Ooool00`0003?o03?o000I<ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo05Soool006Ooool00`0003?o03?o000I<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo05Soool006Ooool00`0003?o03?o000H<ol000<0003oooooool0@?ooo`03o`2I
oooooooo05Soool006Ooool200006C?o00030000oooooooo043oool00ol0VOooooooo`1Hoooo001W
oooo00<0000co`0co`005c?o00030000oooooooo047oool00ol0VOooooooo`1Hoooo001Woooo00<0
000co`0co`005c?o00030000oooooooo047oool00ol0VOooooooo`1Hoooo001Woooo00<0000co`0c
o`005S?o00030000oooooooo04;oool00ol0VOooooooo`1Hoooo001Woooo00<0000co`0co`005S?o
00030000oooooooo04;oool00ol0VOooooooo`1Hoooo001Woooo00<0000co`0co`005S?o00030000
oooooooo04;oool00ol0VOooooooo`1Hoooo001Woooo00<0000co`0co`005C?o00030000oooooooo
04?oool00ol0VOooooooo`1Hoooo001Woooo0P0001Hco`000`000?ooooooo`13oooo00?o09Wooooo
ool0F?ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`13oooo00?o09Woooooool0F?oo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`13oooo00?o09Woooooool0F?ooo`00Iooo
o`030000<ol0<ol001@co`000`000?ooooooo`14oooo00?o09Woooooool0F?ooo`00Ioooo`030000
<ol0<ol001@co`000`000?ooooooo`14oooo00?o09Woooooool0F?ooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`14oooo00?o09Woooooool0F?ooo`00Ioooo`80000E<ol000<0003ooooo
ool0A?ooo`03o`2Ioooooooo05Soool006Ooool00`0003?o03?o000C<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo05Soool006Ooool00`0003?o03?o000C<ol000<0003oooooool0AOooo`03o`2I
oooooooo05Soool006Ooool00`0003?o03?o000C<ol000<0003oooooool0AOooo`03o`2Ioooooooo
05Soool005ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`15oooo00?o09Wooooo
ool0F?ooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0A_oo
o`03o`2Ioooooooo05Soool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`16
oooo00?o09Woooooool0F?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo05Ooool005ooool010000?ooooooo`0000Coool00`0003?o
03?o000A<ol000<0003oooooool0B?ooo`03o`2Ioooooooo05Ooool0063oool200001Oooo`030000
<ol0<ol0014co`000`000?ooooooo`18oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol0
014co`000`000?ooooooo`18oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol0014co`00
0`000?ooooooo`18oooo00?o09Woooooool0Eoooo`00Ioooo`80000A<ol000<0003oooooool0BOoo
o`03o`2Ioooooooo05Ooool006Ooool00`0003?o03?o000@<ol000<0003oooooool0BOooo`03o`2I
oooooooo05Ooool006Ooool00`0003?o03?o000@<ol000<0003oooooool0BOooo`03o`2Ioooooooo
05Ooool006Ooool00`0003?o03?o000@<ol000<0003oooooool0BOooo`03o`2Ioooooooo05Ooool0
06Ooool00`0003?o03?o000?<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05Ooool006Ooool0
0`0003?o03?o000?<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05Ooool006Ooool00`0003?o
03?o000?<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05Ooool006Ooool2000043?o00030000
oooooooo04[oool00ol0VOooooooo`1Goooo001Woooo00<0000co`0co`003S?o00030000oooooooo
04_oool00ol0VOooooooo`1Goooo001Woooo00<0000co`0co`003S?o00030000oooooooo04_oool0
0ol0VOooooooo`1Goooo001Woooo00<0000co`0co`003S?o00030000oooooooo04_oool00ol0VOoo
ooooo`1Goooo001Woooo00<0000co`0co`003S?o00030000oooooooo04_oool00ol0VOooooooo`1G
oooo001Woooo00<0000co`0co`003C?o00030000oooooooo04coool00ol0VOooooooo`1Goooo001W
oooo0P0000hco`000`000?ooooooo`1<oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol0
00dco`000`000?ooooooo`1<oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`1<oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`1=oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1=
oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1=oooo00?o
09Woooooool0Eoooo`00Ioooo`80000=<ol000<0003oooooool0COooo`03o`2Ioooooooo05Ooool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0COooo`03o`2Ioooooooo05Ooool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0COooo`03o`2Ioooooooo05Ooool006Ooool00`0003?o
03?o000;<ol000<0003oooooool0C_ooo`03o`2Ioooooooo05Ooool0063oool200001Oooo`030000
<ol0<ol000/co`000`000?ooooooo`1>oooo00?o09Woooooool0Eoooo`00Goooo`040000oooooooo
00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1>oooo00?o09Woooooool0Eoooo`00HOoo
o`030000oooooooo00?oool2000033?o00030000oooooooo04koool00ol0VOooooooo`1Goooo001R
oooo00<0003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`1>oooo00?o09Wooooo
ool0Eoooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1>
oooo00?o09Woooooool0Eoooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo
04ooool00ol0VOooooooo`1Goooo001Woooo00<0000co`0co`002S?o00030000oooooooo04ooool0
0ol0VOooooooo`1Goooo001Woooo00<0000co`0co`002S?o00030000oooooooo04ooool00ol0VOoo
ooooo`1Goooo001Woooo00<0000co`0co`002S?o00030000oooooooo04ooool00ol0VOooooooo`1G
oooo001Woooo0P0000/co`000`000?ooooooo`1?oooo00?o09Woooooool0Eoooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`1?oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1@oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`1@oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1@oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1@
oooo00?o09Woooooool0Eoooo`00Ioooo`80000:<ol000<0003oooooool0D?ooo`03o`2Ioooooooo
05Ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0D?ooo`03o`2Ioooooooo05Ooool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0D?ooo`03o`2Ioooooooo05Ooool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0DOooo`03o`2Ioooooooo05Ooool006Ooool00`0003?o
03?o0008<ol000<0003oooooool0DOooo`03o`2Ioooooooo05Ooool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0DOooo`03o`2Ioooooooo05Ooool006Ooool200002C?o00030000oooooooo
057oool00ol0VOooooooo`1Goooo001Woooo00<0000co`0co`0023?o00030000oooooooo057oool0
0ol0VOooooooo`1Goooo001Woooo00<0000co`0co`0023?o00030000oooooooo057oool00ol0VOoo
ooooo`1Goooo001Woooo00<0000co`0co`001c?o00030000oooooooo05;oool00ol0VOooooooo`1G
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo05;oool00ol0VOooooooo`1Goooo001W
oooo00<0000co`0co`001c?o00030000oooooooo05;oool00ol0VOooooooo`1Goooo001Woooo0P00
00Pco`000`000?ooooooo`1Boooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1Boooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Boooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1B
oooo00?o09Woooooool0Eoooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1Boooo00?o
09Woooooool0Eoooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo05;oool0
0ol0VOooooooo`1Goooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Boooo00?o09Woooooool0Eoooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`1B
oooo00?o09Woooooool0Eoooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0
003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001W
oooo2C?o0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001W
oooo2C?o00Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
06Ooool9<ol02?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_oo
o`800003oooo1@0000;oool200001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo
00Woool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00Ioooo`Tco`07
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1goooo001Woooo2C?o00Soool0
0`000?ooooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000Aoooo00<0003ooooo
ool02Oooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001Woooo2C?o
00Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`800003oooo00<0003oooooool0NOoo
o`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.70787 .12361 L
.71284 .12361 L
.71741 .12361 L
.71998 .12361 L
.72127 .12361 L
.72201 .12361 L
s
.72201 .12361 m
.72228 .61803 L
s
0 .4 1 r
.02381 .08692 m
.04262 .08004 L
.06244 .07431 L
.08255 .06985 L
.09409 .06783 L
.10458 .0663 L
.12415 .06412 L
.13491 .06327 L
.14509 .06266 L
.15478 .06224 L
.15968 .06208 L
.16506 .06195 L
.16965 .06188 L
.17223 .06185 L
.17345 .06183 L
.17458 .06182 L
.17573 .06182 L
.17677 .06181 L
.17792 .06181 L
.17916 .0618 L
.18023 .0618 L
.18139 .0618 L
.18249 .06181 L
.1835 .06181 L
.18476 .06182 L
.18596 .06182 L
.1882 .06184 L
.19061 .06187 L
.19324 .0619 L
.19796 .06198 L
.20233 .06208 L
.21235 .06237 L
.22299 .06278 L
.24246 .06375 L
.26074 .0649 L
.29943 .06785 L
.31908 .06955 L
.32947 .07048 L
.34057 .07151 L
.3461 .07198 L
.35132 .07232 L
.35601 .07256 L
.35843 .07265 L
.36109 .07273 L
.36359 .0728 L
.36592 .07284 L
.36721 .07286 L
.36838 .07287 L
.36903 .07287 L
.36974 .07288 L
Mistroke
.37103 .07289 L
.37224 .07289 L
.37333 .07289 L
.3746 .07288 L
.37578 .07287 L
.37689 .07287 L
.3779 .07285 L
.38019 .07282 L
.38266 .07278 L
.38491 .07272 L
.38995 .07257 L
.39905 .07219 L
.40968 .07159 L
.41973 .07089 L
.45811 .06726 L
.49895 .06224 L
.53827 .05667 L
.57607 .05092 L
.61632 .04463 L
.65506 .03866 L
.67475 .03577 L
.69626 .03279 L
.70621 .0315 L
.71167 .03082 L
.71682 .03019 L
.71916 .02991 L
.72044 .02976 L
.72163 .02962 L
.72293 .12361 L
.72361 .12361 L
.72435 .12361 L
.72684 .12361 L
.73593 .12361 L
.77726 .12361 L
.81707 .12361 L
.85537 .12361 L
.89612 .12361 L
.93536 .12361 L
.97307 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Eoooo2@1VoeSoool0
06Ooool00`000?ooooooo`1?oooo1P1Vo`Soool00`1Vooooooooo`1Foooo001Woooo00<0003ooooo
ool0B?ooo`L0I_l>oooo00<0I_ooooooool0E_ooo`00Ioooo`030000oooooooo043oool806Ko5Ooo
o`0306Kooooooooo05Koool006Ooool00`000?ooooooo`0koooo1@1Voagoool00`1Vooooooooo`1F
oooo001Woooo0P0003Goool706Ko8_ooo`0306Kooooooooo05Koool006Ooool00`000?ooooooo`0]
oooo1`1VobWoool00`1Vooooooooo`1Foooo001Woooo00<0003oooooool0:?ooo`D0I_l`oooo00<0
I_ooooooool0E_ooo`00;_ooob80I_lGoooo00<0003oooooool08?ooo`P0I_leoooo00<0I_oooooo
ool0E_ooo`009oooo`L0I_lRoooo3`1Vo`Soool00`000?ooooooo`0Foooo2P1Vocgoool00`1Voooo
ooooo`1Foooo000Soooo101VocSoool806Ko00<00000I_l0I_l00P1Vo`Koool>06KoAoooo`0306Ko
oooooooo05Koool001koool506KoA?ooo`800003oooo1P1VoeGoool00`1Vooooooooo`1Foooo000G
oooo1@000080I_lLoooo0P0000Coool200001?ooo`80000Ooooo00<0003oooooool07_ooo`800004
oooo0P0000Coool200007oooo`D0000=oooo00<0I_ooooooool03Oooo`D00002oooo0P0000Coool2
00008?ooo`@0000Foooo000Hoooo00<0I_l0003oool07_ooo`040000oooooooo00002?ooo`040000
oooooooo00007_ooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00
023oool00`000?ooooooo`0=oooo00<0I_ooooooool03oooo`030000oooooooo00Ooool010000?oo
ooooo`0001ooool00`000?ooooooo`0Goooo000Foooo0P1Vo`03oooo0000oooo01koool010000?oo
ooooo`0000_oool00`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01koool00`000?ooooooo`0=oooo00<0I_ooooooool03oooo`030000oooooooo
00[oool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003ooooo
ool05oooo`@00002oooo00@0003oooooool00009oooo0P0001ooool00`000?ooooooo`0Moooo00@0
003oooooool00009oooo0P00027oool00`000?ooooooo`0=oooo00<0I_ooooooool03oooo`030000
oooooooo00Soool200008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0
003oooooool00009oooo00<0003oooooool07_ooo`030000oooooooo01goool010000?ooooooo`00
00Woool00`000?ooooooo`0Poooo00<0003oooooool03Oooo`0306Kooooooooo00ooool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P00
00[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000?oooo00<0I_ooooooool03_oo
o`80000:oooo0`00023oool200005oooo`00Ioooo`030000oooooooo05goool00`1Vooooooooo`1F
oooo001Woooo00<0003oooooool0GOooo`0306Kooooooooo05Koool006Ooool00`000?ooooooo`1M
oooo00<0I_ooooooool0E_ooo`00Ioooo`030000oooooooo05goool00`1Vooooooooo`1Foooo001W
oooo00<0003oooooool0GOooo`0306Kooooooooo05Koool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o
03?o000T<ol040000003ooooo`2Ioooo01Koool00`000?ooooooo`0Voooo00<0003oooooool05Ooo
o`00Ioooo`030000<ol0<ol004Lco`0500004Oooo`03o`2Ioooooooo05Koool006Ooool00`0003?o
03?o0012<ol01@0001Koool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`00?C?o00D0000K
oooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol003Tco`0400008?ooo`03o`2Ioooooooo
05Koool006Ooool20000>3?o0080000Toooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol0
03Dco`0200009_ooo`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000c<ol00P0002Soool0
0ol0VOooooooo`1Foooo001Woooo00<0000co`0co`00<C?o0080000Zoooo00?o09Woooooool0E_oo
o`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`0Zoooo00?o09Woooooool0E_ooo`00Iooo
o`030000<ol0<ol002hco`020000;Oooo`03o`2Ioooooooo05Koool006Ooool20000;C?o0080000_
oooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`0_oooo00?o
09Woooooool0E_ooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`0`oooo00?o09Wooooo
ool0E_ooo`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`0aoooo00?o09Woooooool0E_oo
o`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0boooo00?o09Woooooool0E_ooo`00Iooo
o`030000<ol0<ol002Pco`000`000?ooooooo`0boooo00?o09Woooooool0E_ooo`00Ioooo`80000X
<ol000<0003oooooool0<oooo`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000V<ol000<0
003oooooool0=?ooo`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000U<ol000<0003ooooo
ool0=Oooo`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000T<ol000<0003oooooool0=_oo
o`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000S<ol000<0003oooooool0=oooo`03o`2I
oooooooo05Koool006Ooool00`0003?o03?o000S<ol000<0003oooooool0=oooo`03o`2Ioooooooo
05Koool006Ooool200008c?o00030000oooooooo03Soool00ol0VOooooooo`1Foooo001Woooo00<0
000co`0co`008C?o00030000oooooooo03Woool00ol0VOooooooo`1Foooo001Woooo00<0000co`0c
o`0083?o00030000oooooooo03[oool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`0083?o
00030000oooooooo03[oool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`007c?o00030000
oooooooo03_oool00ol0VOooooooo`1Foooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0
003oooooool0>oooo`03o`2Ioooooooo05Koool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`007S?o00030000oooooooo03coool00ol0VOooooooo`1Foooo001Qoooo00<0003oooooool00ooo
o`80000O<ol000<0003oooooool0??ooo`03o`2Ioooooooo05Koool0067oool00`000?ooooooo`03
oooo00<0000co`0co`007C?o00030000oooooooo03goool00ol0VOooooooo`1Foooo001Qoooo00<0
003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0moooo00?o09Woooooool0E_oo
o`00H?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo03koool00ol0VOooooooo`1F
oooo001Woooo00<0000co`0co`0073?o00030000oooooooo03koool00ol0VOooooooo`1Foooo001W
oooo00<0000co`0co`006c?o00030000oooooooo03ooool00ol0VOooooooo`1Foooo001Woooo0P00
01`co`000`000?ooooooo`0ooooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol001Xco`00
0`000?ooooooo`10oooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol001Xco`000`000?oo
ooooo`10oooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`11
oooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`11oooo00?o
09Woooooool0E_ooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`12oooo00?o09Wooooo
ool0E_ooo`00Ioooo`80000I<ol000<0003oooooool0@_ooo`03o`2Ioooooooo05Koool006Ooool0
0`0003?o03?o000G<ol000<0003oooooool0@oooo`03o`2Ioooooooo05Koool006Ooool00`0003?o
03?o000G<ol000<0003oooooool0@oooo`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000F
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000F<ol000<0
003oooooool0A?ooo`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000F<ol000<0003ooooo
ool0A?ooo`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000E<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo05Koool006Ooool200005S?o00030000oooooooo04Goool00ol0VOooooooo`1F
oooo001Woooo00<0000co`0co`005C?o00030000oooooooo04Goool00ol0VOooooooo`1Foooo001W
oooo00<0000co`0co`005C?o00030000oooooooo04Goool00ol0VOooooooo`1Foooo001Woooo00<0
000co`0co`0053?o00030000oooooooo04Koool00ol0VOooooooo`1Foooo001Woooo00<0000co`0c
o`0053?o00030000oooooooo04Koool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`0053?o
00030000oooooooo04Koool00ol0VOooooooo`1Foooo001Woooo0P0001Dco`000`000?ooooooo`16
oooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`17oooo00?o
09Woooooool0E_ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`17oooo00?o09Wooooo
ool0E_ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`17oooo00?o09Woooooool0E_oo
o`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo04Ooool00ol0VOooooooo`1F
oooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`18oooo00?o
09Woooooool0E_ooo`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo04Soool0
0ol0VOooooooo`1Foooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?oo
ooooo`18oooo00?o09Woooooool0E_ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0
014co`000`000?ooooooo`19oooo00?o09Woooooool0E_ooo`00H?ooo`800005oooo00<0000co`0c
o`004C?o00030000oooooooo04Woool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`004C?o
00030000oooooooo04Woool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`004C?o00030000
oooooooo04Woool00ol0VOooooooo`1Foooo001Woooo0P00014co`000`000?ooooooo`1:oooo00?o
09Woooooool0E_ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1:oooo00?o09Wooooo
ool0E_ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1:oooo00?o09Woooooool0E_oo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1:oooo00?o09Woooooool0E_ooo`00Iooo
o`030000<ol0<ol000lco`000`000?ooooooo`1;oooo00?o09Woooooool0E_ooo`00Ioooo`030000
<ol0<ol000lco`000`000?ooooooo`1;oooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`1;oooo00?o09Woooooool0E_ooo`00Ioooo`80000@<ol000<0003ooooo
ool0Boooo`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000><ol000<0003oooooool0C?oo
o`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000><ol000<0003oooooool0C?ooo`03o`2I
oooooooo05Koool006Ooool00`0003?o03?o000><ol000<0003oooooool0C?ooo`03o`2Ioooooooo
05Koool006Ooool00`0003?o03?o000><ol000<0003oooooool0C?ooo`03o`2Ioooooooo05Koool0
06Ooool00`0003?o03?o000=<ol000<0003oooooool0COooo`03o`2Ioooooooo05Koool006Ooool2
00003S?o00030000oooooooo04goool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`003C?o
00030000oooooooo04goool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`003C?o00030000
oooooooo04goool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`0033?o00030000oooooooo
04koool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`0033?o00030000oooooooo04koool0
0ol0VOooooooo`1Foooo001Woooo00<0000co`0co`0033?o00030000oooooooo04koool00ol0VOoo
ooooo`1Foooo001Woooo0P0000dco`000`000?ooooooo`1>oooo00?o09Woooooool0E_ooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`1>oooo00?o09Woooooool0E_ooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`1>oooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol0
00/co`000`000?ooooooo`1?oooo00?o09Woooooool0E_ooo`00H?ooo`800005oooo00<0000co`0c
o`002c?o00030000oooooooo04ooool00ol0VOooooooo`1Foooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`002c?o00030000oooooooo04ooool00ol0VOooooooo`1Foooo001Qoooo00<0
003oooooool00oooo`80000<<ol000<0003oooooool0Coooo`03o`2Ioooooooo05Koool006;oool0
0`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo04ooool00ol0VOooooooo`1F
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo04ooool0
0ol0VOooooooo`1Foooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0D?oo
o`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o000:<ol000<0003oooooool0D?ooo`03o`2I
oooooooo05Koool006Ooool00`0003?o03?o000:<ol000<0003oooooool0D?ooo`03o`2Ioooooooo
05Koool006Ooool00`0003?o03?o000:<ol000<0003oooooool0D?ooo`03o`2Ioooooooo05Koool0
06Ooool200002c?o00030000oooooooo053oool00ol0VOooooooo`1Foooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo053oool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`002C?o
00030000oooooooo057oool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`002C?o00030000
oooooooo057oool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`002C?o00030000oooooooo
057oool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`002C?o00030000oooooooo057oool0
0ol0VOooooooo`1Foooo001Woooo0P0000Xco`000`000?ooooooo`1Aoooo00?o09Woooooool0E_oo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Aoooo00?o09Woooooool0E_ooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1Aoooo00?o09Woooooool0E_ooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1Boooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1Boooo00?o09Woooooool0E_ooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`1Boooo00?o09Woooooool0E_ooo`00Ioooo`800009<ol000<0003oooooool0D_oo
o`03o`2Ioooooooo05Koool006Ooool00`0003?o03?o0008<ol000<0003oooooool0D_ooo`03o`2I
oooooooo05Koool006Ooool00`0003?o03?o0008<ol000<0003oooooool0D_ooo`03o`2Ioooooooo
05Koool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Doooo`03o`2Ioooooooo05Koool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0Doooo`03o`2Ioooooooo05Koool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0Doooo`03o`2Ioooooooo05Koool006Ooool2000023?o
00030000oooooooo05?oool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`001c?o00030000
oooooooo05?oool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`001c?o00030000oooooooo
05?oool00ol0VOooooooo`1Foooo001Woooo00<0000co`0co`001c?o00030000oooooooo05?oool0
0ol0VOooooooo`1Foooo001Woooo00<0000co`0co`001c?o00030000oooooooo05?oool00ol0VOoo
ooooo`1Foooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0Doooo`03o`2I
oooooooo05Koool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo
05?oool00ol0VOooooooo`1Foooo001Ooooo1@0000?oool2000023?o00030000oooooooo05?oool0
0ol0VOooooooo`1Foooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?oo
o`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9
<ol0/?ooo`00Ioooo`Tco`0<oooo00<0003oooooool08_ooo`030000oooooooo07coool006Ooool9
<ol02oooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Iooo
o`Tco`0;oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P00
00?oool400000oooo`030000oooooooo07_oool006Ooool9<ol02oooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`04oooo00<0003oooooool0Noooo`00Ioooo`Tco`0:oooo00<0003oooooool00_ooo`030000
oooooooo00ooool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo07[oool0
06Ooool9<ol02oooo`030000oooooooo00D0000>oooo00<0003oooooool02Oooo`030000oooooooo
00;oool00`000?ooooooo`1koooo001Woooo2C?o00_oool01@000?ooooooooooo`00000Aoooo00<0
003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool006Ooool9<ol03?oo
o`030000oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00Ioooo`Tco`2`
oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71741 .12361 L
.72307 .12361 L
.72585 .12361 L
.72707 .12361 L
.72772 .12361 L
.72841 .12361 L
s
.72841 .12361 m
.72889 .61803 L
s
0 .4 1 r
.02381 .08443 m
.04262 .07805 L
.06244 .07276 L
.08255 .06869 L
.09409 .06687 L
.10458 .0655 L
.11396 .06448 L
.12415 .06359 L
.13491 .06287 L
.14017 .06259 L
.14509 .06237 L
.15002 .06218 L
.15453 .06205 L
.15954 .06194 L
.1623 .06189 L
.16493 .06186 L
.16745 .06183 L
.16886 .06182 L
.17014 .06181 L
.17134 .06181 L
.17263 .0618 L
.17385 .0618 L
.17498 .0618 L
.1763 .06181 L
.17752 .06181 L
.17823 .06181 L
.17887 .06182 L
.18032 .06183 L
.18321 .06185 L
.18596 .06189 L
.19054 .06196 L
.19561 .06207 L
.20586 .06237 L
.21537 .06273 L
.22428 .06313 L
.26297 .06549 L
.30411 .06879 L
.32464 .07062 L
.33464 .07155 L
.34374 .07239 L
.34828 .07274 L
.35321 .07303 L
.35787 .07324 L
.36216 .07338 L
.36451 .07344 L
.36671 .07347 L
.36798 .07349 L
.36913 .0735 L
.36976 .07351 L
.37046 .07351 L
Mistroke
.37172 .07352 L
.37241 .07352 L
.37306 .07352 L
.37427 .07352 L
.37557 .07351 L
.3763 .07351 L
.37697 .0735 L
.37934 .07348 L
.38054 .07346 L
.38184 .07344 L
.3871 .07332 L
.39208 .07316 L
.40139 .07275 L
.41142 .07218 L
.42232 .07141 L
.46316 .06749 L
.50247 .06262 L
.54028 .05728 L
.58053 .05117 L
.61927 .04511 L
.66046 .03877 L
.68103 .03574 L
.70014 .03309 L
.70964 .03184 L
.7186 .03071 L
.72356 .03011 L
.72492 .02995 L
.72636 .02978 L
.72758 .02964 L
.72828 .02956 L
.72893 .12361 L
.73014 .12361 L
.73129 .12361 L
.73345 .12361 L
.7383 .12361 L
.7766 .12361 L
.81735 .12361 L
.85658 .12361 L
.8943 .12361 L
.93447 .12361 L
.97313 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Foooo2P1VoeKoool0
06Ooool00`000?ooooooo`1Aoooo1@1Vo`Woool00`1Vooooooooo`1Doooo001Woooo00<0003ooooo
ool0BOooo`P0I_l>oooo00<0I_ooooooool0E?ooo`00Ioooo`030000oooooooo047oool806Ko5_oo
o`0306Kooooooooo05Coool006Ooool00`000?ooooooo`0loooo1@1Voakoool00`1Vooooooooo`1D
oooo001Woooo0P0003Soool506Ko8oooo`0306Kooooooooo05Coool006Ooool00`000?ooooooo`0b
oooo1@1VobSoool00`1Vooooooooo`1Doooo001Woooo00<0003oooooool0:oooo`L0I_l]oooo00<0
I_ooooooool0E?ooo`00;Oooob40I_lIoooo00<0003oooooool08_ooo`T0I_ldoooo00<0I_oooooo
ool0E?ooo`009?ooo`T0I_lQoooo2P1Vo`ooool00`000?ooooooo`0Goooo2`1Vocgoool00`1Voooo
ooooo`1Doooo000Roooo0P1VocCoool?06Ko00<0003oooooool03_ooo`T0I_m8oooo00<0I_oooooo
ool0E?ooo`007_ooo`@0I_m5oooo0P0000l0I_mAoooo00<0I_ooooooool0E?ooo`005oooo`D00002
06Ko7?ooo`800004oooo0P0000Coool200007oooo`030000oooooooo01koool200001?ooo`800004
oooo0P0001ooool500003oooo`0306Kooooooooo00_oool500000_ooo`800004oooo0P00023oool4
00005_ooo`005_ooo`<0I_l00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003ooooo
ool0000Noooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00008?oo
o`030000oooooooo00ooool00`1Vooooooooo`0=oooo00<0003oooooool01oooo`040000oooooooo
00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0Moooo00@0003oooooool0000;
oooo00<0003oooooool07?ooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?oo
ooooo`0Noooo00<0003oooooool03oooo`0306Kooooooooo00goool00`000?ooooooo`0:oooo00<0
003oooooool07_ooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo01Ooool4
00000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`80000Qoooo00<0003oooooool03oooo`0306Kooooooooo00goool00`000?ooooooo`08
oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0
003oooooool08?ooo`030000oooooooo00ooool00`1Vooooooooo`0=oooo00<0003oooooool02?oo
o`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`00
01koool200007oooo`80000:oooo0`0001ooool200004Oooo`0306Kooooooooo00coool200002_oo
o`<0000Poooo0P0001Ooool006Ooool00`000?ooooooo`1Ooooo00<0I_ooooooool0E?ooo`00Iooo
o`030000oooooooo05ooool00`1Vooooooooo`1Doooo001Woooo00<0003oooooool0Goooo`0306Ko
oooooooo05Coool006Ooool00`000?ooooooo`1Ooooo00<0I_ooooooool0E?ooo`00Ioooo`030000
oooooooo05ooool00`1Vooooooooo`1Doooo000@ooooo`00017oool001Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol00`000003o`2I0000000002800002
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o
00030000<ol0<ol002@co`0@00000oooo`03o`2Ioooooooo01?oool00`000?ooooooo`0Voooo00<0
003oooooool05Oooo`00Ioooo`030000<ol0<ol004Lco`0500004oooo`03o`2Ioooooooo05Coool0
06Ooool00`0003?o03?o0012<ol01@0001Soool00ol0VOooooooo`1Doooo001Woooo00<0000co`0c
o`00?C?o00D0000Moooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol003Tco`0400008_oo
o`03o`2Ioooooooo05Coool006Ooool20000>3?o0080000Voooo00?o09Woooooool0E?ooo`00Iooo
o`030000<ol0<ol003Dco`020000:?ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000c
<ol00P0002[oool00ol0VOooooooo`1Doooo001Woooo00<0000co`0co`00<C?o0080000/oooo00?o
09Woooooool0E?ooo`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`0/oooo00?o09Wooooo
ool0E?ooo`00Ioooo`030000<ol0<ol002hco`020000;oooo`03o`2Ioooooooo05Coool006Ooool2
0000;C?o0080000aoooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol002/co`000`000?oo
ooooo`0aoooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`0b
oooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`0coooo00?o
09Woooooool0E?ooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0doooo00?o09Wooooo
ool0E?ooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0doooo00?o09Woooooool0E?oo
o`00Ioooo`80000X<ol000<0003oooooool0=Oooo`03o`2Ioooooooo05Coool006Ooool00`0003?o
03?o000V<ol000<0003oooooool0=_ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000U
<ol000<0003oooooool0=oooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000T<ol000<0
003oooooool0>?ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000S<ol000<0003ooooo
ool0>Oooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000S<ol000<0003oooooool0>Ooo
o`03o`2Ioooooooo05Coool006Ooool200008c?o00030000oooooooo03[oool00ol0VOooooooo`1D
oooo001Woooo00<0000co`0co`008C?o00030000oooooooo03_oool00ol0VOooooooo`1Doooo001W
oooo00<0000co`0co`0083?o00030000oooooooo03coool00ol0VOooooooo`1Doooo001Woooo00<0
000co`0co`0083?o00030000oooooooo03coool00ol0VOooooooo`1Doooo001Woooo00<0000co`0c
o`007c?o00030000oooooooo03goool00ol0VOooooooo`1Doooo001Ooooo1@0000?oool00`0003?o
03?o000O<ol000<0003oooooool0?Oooo`03o`2Ioooooooo05Coool0067oool00`000?ooooooo`03
oooo00<0000co`0co`007S?o00030000oooooooo03koool00ol0VOooooooo`1Doooo001Qoooo00<0
003oooooool00oooo`80000O<ol000<0003oooooool0?_ooo`03o`2Ioooooooo05Coool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo03ooool00ol0VOooooooo`1D
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0ooooo00?o
09Woooooool0E?ooo`00H?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo043oool0
0ol0VOooooooo`1Doooo001Woooo00<0000co`0co`0073?o00030000oooooooo043oool00ol0VOoo
ooooo`1Doooo001Woooo00<0000co`0co`006c?o00030000oooooooo047oool00ol0VOooooooo`1D
oooo001Woooo0P0001`co`000`000?ooooooo`11oooo00?o09Woooooool0E?ooo`00Ioooo`030000
<ol0<ol001Xco`000`000?ooooooo`12oooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol0
01Xco`000`000?ooooooo`12oooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol001Tco`00
0`000?ooooooo`13oooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?oo
ooooo`13oooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`14
oooo00?o09Woooooool0E?ooo`00Ioooo`80000I<ol000<0003oooooool0A?ooo`03o`2Ioooooooo
05Coool006Ooool00`0003?o03?o000G<ol000<0003oooooool0AOooo`03o`2Ioooooooo05Coool0
06Ooool00`0003?o03?o000G<ol000<0003oooooool0AOooo`03o`2Ioooooooo05Coool006Ooool0
0`0003?o03?o000F<ol000<0003oooooool0A_ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o
03?o000F<ol000<0003oooooool0A_ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000F
<ol000<0003oooooool0A_ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000E<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo05Coool006Ooool200005S?o00030000oooooooo04Ooool0
0ol0VOooooooo`1Doooo001Woooo00<0000co`0co`005C?o00030000oooooooo04Ooool00ol0VOoo
ooooo`1Doooo001Woooo00<0000co`0co`005C?o00030000oooooooo04Ooool00ol0VOooooooo`1D
oooo001Woooo00<0000co`0co`0053?o00030000oooooooo04Soool00ol0VOooooooo`1Doooo001W
oooo00<0000co`0co`0053?o00030000oooooooo04Soool00ol0VOooooooo`1Doooo001Woooo00<0
000co`0co`0053?o00030000oooooooo04Soool00ol0VOooooooo`1Doooo001Woooo0P0001Dco`00
0`000?ooooooo`18oooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol001<co`000`000?oo
ooooo`19oooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`19
oooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`19oooo00?o
09Woooooool0E?ooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo04Woool0
0ol0VOooooooo`1Doooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?oo
ooooo`1:oooo00?o09Woooooool0E?ooo`00H?ooo`030000oooooooo00Coool200004c?o00030000
oooooooo04[oool00ol0VOooooooo`1Doooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
018co`000`000?ooooooo`1:oooo00?o09Woooooool0E?ooo`00Goooo`040000oooooooo00001?oo
o`030000<ol0<ol0014co`000`000?ooooooo`1;oooo00?o09Woooooool0E?ooo`00H?ooo`800005
oooo00<0000co`0co`004C?o00030000oooooooo04_oool00ol0VOooooooo`1Doooo001Woooo00<0
000co`0co`004C?o00030000oooooooo04_oool00ol0VOooooooo`1Doooo001Woooo00<0000co`0c
o`004C?o00030000oooooooo04_oool00ol0VOooooooo`1Doooo001Woooo0P00014co`000`000?oo
ooooo`1<oooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1<
oooo00?o09Woooooool0E?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1<oooo00?o
09Woooooool0E?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1<oooo00?o09Wooooo
ool0E?ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1=oooo00?o09Woooooool0E?oo
o`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1=oooo00?o09Woooooool0E?ooo`00Iooo
o`030000<ol0<ol000lco`000`000?ooooooo`1=oooo00?o09Woooooool0E?ooo`00Ioooo`80000@
<ol000<0003oooooool0COooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000><ol000<0
003oooooool0C_ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000><ol000<0003ooooo
ool0C_ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000><ol000<0003oooooool0C_oo
o`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000><ol000<0003oooooool0C_ooo`03o`2I
oooooooo05Coool006Ooool00`0003?o03?o000=<ol000<0003oooooool0Coooo`03o`2Ioooooooo
05Coool006Ooool200003S?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Woooo00<0
000co`0co`003C?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Woooo00<0000co`0c
o`003C?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Woooo00<0000co`0co`0033?o
00030000oooooooo053oool00ol0VOooooooo`1Doooo001Woooo00<0000co`0co`0033?o00030000
oooooooo053oool00ol0VOooooooo`1Doooo001Woooo00<0000co`0co`0033?o00030000oooooooo
053oool00ol0VOooooooo`1Doooo001Woooo0P0000dco`000`000?ooooooo`1@oooo00?o09Wooooo
ool0E?ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1@oooo00?o09Woooooool0E?oo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1@oooo00?o09Woooooool0E?ooo`00Iooo
o`030000<ol0<ol000/co`000`000?ooooooo`1Aoooo00?o09Woooooool0E?ooo`00H?ooo`800005
oooo00<0000co`0co`002c?o00030000oooooooo057oool00ol0VOooooooo`1Doooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo057oool00ol0VOooooooo`1D
oooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0003oooooool0DOooo`03o`2Ioooooooo
05Coool006;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo057oool0
0ol0VOooooooo`1Doooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000
oooooooo057oool00ol0VOooooooo`1Doooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0
003oooooool0D_ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0D_ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0D_oo
o`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0D_ooo`03o`2I
oooooooo05Coool006Ooool200002c?o00030000oooooooo05;oool00ol0VOooooooo`1Doooo001W
oooo00<0000co`0co`002S?o00030000oooooooo05;oool00ol0VOooooooo`1Doooo001Woooo00<0
000co`0co`002C?o00030000oooooooo05?oool00ol0VOooooooo`1Doooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo05?oool00ol0VOooooooo`1Doooo001Woooo00<0000co`0co`002C?o
00030000oooooooo05?oool00ol0VOooooooo`1Doooo001Woooo00<0000co`0co`002C?o00030000
oooooooo05?oool00ol0VOooooooo`1Doooo001Woooo0P0000Xco`000`000?ooooooo`1Coooo00?o
09Woooooool0E?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Coooo00?o09Wooooo
ool0E?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Coooo00?o09Woooooool0E?oo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Doooo00?o09Woooooool0E?ooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`1Doooo00?o09Woooooool0E?ooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1Doooo00?o09Woooooool0E?ooo`00Ioooo`800009<ol000<0
003oooooool0E?ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool0E?ooo`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o0008<ol000<0003oooooool0E?oo
o`03o`2Ioooooooo05Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0EOooo`03o`2I
oooooooo05Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0EOooo`03o`2Ioooooooo
05Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0EOooo`03o`2Ioooooooo05Coool0
06Ooool2000023?o00030000oooooooo05Goool00ol0VOooooooo`1Doooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo05Goool00ol0VOooooooo`1Doooo001Woooo00<0000co`0co`001c?o
00030000oooooooo05Goool00ol0VOooooooo`1Doooo001Woooo00<0000co`0co`001c?o00030000
oooooooo05Goool00ol0VOooooooo`1Doooo001Woooo00<0000co`0co`001c?o00030000oooooooo
05Goool00ol0VOooooooo`1Doooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003ooooo
ool0EOooo`03o`2Ioooooooo05Coool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o
00030000oooooooo05Goool00ol0VOooooooo`1Doooo001Ooooo1@0000?oool2000023?o00030000
oooooooo05Goool00ol0VOooooooo`1Doooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0
063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o
0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo
07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`D00002oooo0P0000?oool400000_ooo`@00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool0N?oo
o`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`08
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`1goooo001Woooo2C?o
00Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`03oooo00<0
003oooooool00_ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo0000
017oool00`000?ooooooo`07oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool2
00000oooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71741 .12361 L
.72307 .12361 L
.72841 .12361 L
.73074 .12361 L
.7332 .12361 L
.73449 .12361 L
s
.73449 .12361 m
.73478 .61803 L
s
0 .4 1 r
.02381 .08211 m
.04262 .07621 L
.06244 .07135 L
.08255 .06765 L
.09409 .06601 L
.10458 .06479 L
.11396 .0639 L
.12415 .06314 L
.12975 .0628 L
.13491 .06253 L
.13982 .06232 L
.14509 .06214 L
.15014 .062 L
.15476 .06191 L
.15698 .06188 L
.1594 .06185 L
.16051 .06184 L
.16169 .06183 L
.16272 .06182 L
.16381 .06181 L
.16448 .06181 L
.16521 .06181 L
.16649 .0618 L
.16721 .0618 L
.16799 .0618 L
.16872 .0618 L
.16938 .06181 L
.17067 .06181 L
.1714 .06181 L
.17208 .06182 L
.17463 .06183 L
.17689 .06185 L
.17939 .06188 L
.18444 .06197 L
.18936 .06207 L
.19453 .06221 L
.20379 .06252 L
.22464 .06347 L
.26275 .06594 L
.30331 .06928 L
.32205 .07097 L
.34236 .07287 L
.34775 .07331 L
.35346 .07366 L
.35834 .07388 L
.36111 .07397 L
.3637 .07404 L
.36495 .07407 L
.36631 .0741 L
.3675 .07411 L
Mistroke
.36878 .07413 L
.37004 .07414 L
.37119 .07415 L
.37234 .07416 L
.37342 .07416 L
.37469 .07416 L
.37533 .07415 L
.37603 .07415 L
.37728 .07414 L
.37843 .07413 L
.37981 .07412 L
.38105 .0741 L
.38385 .07405 L
.38868 .07393 L
.39379 .07376 L
.40298 .07336 L
.41286 .07278 L
.42375 .07202 L
.46401 .06819 L
.50275 .06344 L
.54394 .05766 L
.58362 .05164 L
.62178 .04567 L
.66239 .03939 L
.70149 .03373 L
.71176 .03236 L
.72287 .03094 L
.72798 .03031 L
.73076 .02998 L
.73213 .02982 L
.73337 .02967 L
.73451 .02954 L
.73559 .12361 L
.73673 .12361 L
.73798 .12361 L
.74304 .12361 L
.78379 .12361 L
.82302 .12361 L
.86074 .12361 L
.90091 .12361 L
.93957 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Joooo1`1VoeGoool0
06Ooool00`000?ooooooo`1Doooo1P1Vo`Koool00`1Vooooooooo`1Coooo001Woooo00<0003ooooo
ool0C?ooo`P0I_l<oooo00<0I_ooooooool0Doooo`00Ioooo`030000oooooooo04Ooool506Ko5?oo
o`0306Kooooooooo05?oool006Ooool00`000?ooooooo`10oooo1`1VoaWoool00`1Vooooooooo`1C
oooo001Woooo0P0003Woool806Ko8?ooo`0306Kooooooooo05?oool006Ooool00`000?ooooooo`0c
oooo1@1VobSoool00`1Vooooooooo`1Coooo001Woooo00<0003oooooool0;?ooo`L0I_l]oooo00<0
I_ooooooool0Doooo`00:_ooob@0I_lIoooo00<0003oooooool08_ooo`X0I_ldoooo00<0I_oooooo
ool0Doooo`008oooo`L0I_lToooo2P1Vo`ooool00`000?ooooooo`0Hoooo2P1Vockoool00`1Voooo
ooooo`1Coooo000Noooo1@1VocGoool=06Ko0_ooo`030000oooooooo017oool706KoB?ooo`0306Ko
oooooooo05?oool001[oool406KoAoooo`80I_l200004P1Vodooool00`1Vooooooooo`1Coooo000G
oooo1@0001koool200001?ooo`800004oooo0P0001ooool00`000?ooooooo`0Noooo0P0000Coool2
00001?ooo`80000Ooooo1@00017oool00`1Vooooooooo`09oooo1@0000;oool200001?ooo`80000P
oooo100001Koool001Koool206Ko00?oool0003oool07_ooo`040000oooooooo00002?ooo`040000
oooooooo00007_ooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00
023oool00`000?ooooooo`0Aoooo00<0I_ooooooool02oooo`030000oooooooo00Ooool010000?oo
ooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002oooo`030000oooooooo01coool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0
003oooooool07_ooo`030000oooooooo017oool00`1Vooooooooo`0;oooo00<0003oooooool02_oo
o`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0G
oooo100000;oool010000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?oo
ooooo`0000Woool200008Oooo`030000oooooooo017oool00`1Vooooooooo`0;oooo00<0003ooooo
ool02?ooo`80000Roooo00<0003oooooool05Oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000Woool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Ooo
o`030000oooooooo023oool00`000?ooooooo`0Aoooo00<0I_ooooooool02oooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00023oool200002_oo
o`<0000Noooo0P0001ooool200002_ooo`<0000Ooooo0P0001?oool00`1Vooooooooo`0:oooo0P00
00[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0HOooo`0306Kooooooooo05;oool0
06Ooool00`000?ooooooo`1Qoooo00<0I_ooooooool0D_ooo`00Ioooo`030000oooooooo067oool0
0`1Vooooooooo`1Boooo001Woooo00<0003oooooool0HOooo`0306Kooooooooo05;oool006Ooool0
0`000?ooooooo`1Qoooo00<0I_ooooooool0D_ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o00@000000ol0V@000000000Q
00000_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol0
02Dco`000`0003?o03?o000T<ol0400000Coool00ol0VOooooooo`0Boooo00<0003oooooool09_oo
o`030000oooooooo01Goool006Ooool00`0003?o03?o0017<ol01@0001Coool00ol0VOooooooo`1C
oooo001Woooo00<0000co`0co`00@S?o00D0000Ioooo00?o09Woooooool0Doooo`00Ioooo`030000
<ol0<ol003dco`0500007_ooo`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000i<ol01000
02?oool00ol0VOooooooo`1Coooo001Woooo0P0003Pco`0200009oooo`03o`2Ioooooooo05?oool0
06Ooool00`0003?o03?o000e<ol00P0002Woool00ol0VOooooooo`1Coooo001Woooo00<0000co`0c
o`00<c?o0080000[oooo00?o09Woooooool0Doooo`00Ioooo`030000<ol0<ol0034co`020000;Ooo
o`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000`<ol000<0003oooooool0;Oooo`03o`2I
oooooooo05?oool006Ooool00`0003?o03?o000^<ol00P00033oool00ol0VOooooooo`1Coooo001W
oooo0P0002dco`020000<_ooo`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000[<ol000<0
003oooooool0<_ooo`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000Z<ol000<0003ooooo
ool0<oooo`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000Y<ol000<0003oooooool0=?oo
o`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000X<ol000<0003oooooool0=Oooo`03o`2I
oooooooo05?oool006Ooool00`0003?o03?o000X<ol000<0003oooooool0=Oooo`03o`2Ioooooooo
05?oool006Ooool20000:3?o00030000oooooooo03Koool00ol0VOooooooo`1Coooo001Woooo00<0
000co`0co`009S?o00030000oooooooo03Ooool00ol0VOooooooo`1Coooo001Woooo00<0000co`0c
o`009C?o00030000oooooooo03Soool00ol0VOooooooo`1Coooo001Woooo00<0000co`0co`0093?o
00030000oooooooo03Woool00ol0VOooooooo`1Coooo001Woooo00<0000co`0co`008c?o00030000
oooooooo03[oool00ol0VOooooooo`1Coooo001Woooo00<0000co`0co`008c?o00030000oooooooo
03[oool00ol0VOooooooo`1Coooo001Woooo0P0002<co`000`000?ooooooo`0koooo00?o09Wooooo
ool0Doooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`0loooo00?o09Woooooool0Dooo
o`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`0moooo00?o09Woooooool0Doooo`00Iooo
o`030000<ol0<ol0020co`000`000?ooooooo`0moooo00?o09Woooooool0Doooo`00Ioooo`030000
<ol0<ol001lco`000`000?ooooooo`0noooo00?o09Woooooool0Doooo`00Goooo`D00003oooo00<0
000co`0co`007c?o00030000oooooooo03koool00ol0VOooooooo`1Coooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001hco`000`000?ooooooo`0ooooo00?o09Woooooool0Doooo`00HOoo
o`030000oooooooo00?oool200007c?o00030000oooooooo03ooool00ol0VOooooooo`1Coooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`10oooo00?o09Wooooo
ool0Doooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0@?oo
o`03o`2Ioooooooo05?oool0063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`11
oooo00?o09Woooooool0Doooo`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`11oooo00?o
09Woooooool0Doooo`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`12oooo00?o09Wooooo
ool0Doooo`00Ioooo`80000L<ol000<0003oooooool0@_ooo`03o`2Ioooooooo05?oool006Ooool0
0`0003?o03?o000J<ol000<0003oooooool0@oooo`03o`2Ioooooooo05?oool006Ooool00`0003?o
03?o000J<ol000<0003oooooool0@oooo`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000I
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000I<ol000<0
003oooooool0A?ooo`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000H<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo05?oool006Ooool200006C?o00030000oooooooo04Goool00ol0VOoo
ooooo`1Coooo001Woooo00<0000co`0co`005c?o00030000oooooooo04Koool00ol0VOooooooo`1C
oooo001Woooo00<0000co`0co`005c?o00030000oooooooo04Koool00ol0VOooooooo`1Coooo001W
oooo00<0000co`0co`005S?o00030000oooooooo04Ooool00ol0VOooooooo`1Coooo001Woooo00<0
000co`0co`005S?o00030000oooooooo04Ooool00ol0VOooooooo`1Coooo001Woooo00<0000co`0c
o`005S?o00030000oooooooo04Ooool00ol0VOooooooo`1Coooo001Woooo00<0000co`0co`005C?o
00030000oooooooo04Soool00ol0VOooooooo`1Coooo001Woooo0P0001Hco`000`000?ooooooo`18
oooo00?o09Woooooool0Doooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`18oooo00?o
09Woooooool0Doooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`18oooo00?o09Wooooo
ool0Doooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`19oooo00?o09Woooooool0Dooo
o`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`19oooo00?o09Woooooool0Doooo`00Iooo
o`030000<ol0<ol001@co`000`000?ooooooo`19oooo00?o09Woooooool0Doooo`00Ioooo`80000E
<ol000<0003oooooool0BOooo`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000C<ol000<0
003oooooool0B_ooo`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000C<ol000<0003ooooo
ool0B_ooo`03o`2Ioooooooo05?oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0B_oo
o`03o`2Ioooooooo05?oool005ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`1:
oooo00?o09Woooooool0Doooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0
003oooooool0Boooo`03o`2Ioooooooo05?oool0063oool00`000?ooooooo`04oooo0P0001<co`00
0`000?ooooooo`1;oooo00?o09Woooooool0Doooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o000B<ol000<0003oooooool0C?ooo`03o`2Ioooooooo05;oool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000A<ol000<0003oooooool0COooo`03o`2Ioooooooo05;oool0063oool2
00001Oooo`030000<ol0<ol0014co`000`000?ooooooo`1=oooo00?o09Woooooool0D_ooo`00Iooo
o`030000<ol0<ol0014co`000`000?ooooooo`1=oooo00?o09Woooooool0D_ooo`00Ioooo`030000
<ol0<ol0014co`000`000?ooooooo`1=oooo00?o09Woooooool0D_ooo`00Ioooo`80000A<ol000<0
003oooooool0C_ooo`03o`2Ioooooooo05;oool006Ooool00`0003?o03?o000@<ol000<0003ooooo
ool0C_ooo`03o`2Ioooooooo05;oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0C_oo
o`03o`2Ioooooooo05;oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0C_ooo`03o`2I
oooooooo05;oool006Ooool00`0003?o03?o000?<ol000<0003oooooool0Coooo`03o`2Ioooooooo
05;oool006Ooool00`0003?o03?o000?<ol000<0003oooooool0Coooo`03o`2Ioooooooo05;oool0
06Ooool00`0003?o03?o000?<ol000<0003oooooool0Coooo`03o`2Ioooooooo05;oool006Ooool2
000043?o00030000oooooooo04ooool00ol0VOooooooo`1Boooo001Woooo00<0000co`0co`003S?o
00030000oooooooo053oool00ol0VOooooooo`1Boooo001Woooo00<0000co`0co`003S?o00030000
oooooooo053oool00ol0VOooooooo`1Boooo001Woooo00<0000co`0co`003S?o00030000oooooooo
053oool00ol0VOooooooo`1Boooo001Woooo00<0000co`0co`003S?o00030000oooooooo053oool0
0ol0VOooooooo`1Boooo001Woooo00<0000co`0co`003C?o00030000oooooooo057oool00ol0VOoo
ooooo`1Boooo001Woooo0P0000hco`000`000?ooooooo`1Aoooo00?o09Woooooool0D_ooo`00Iooo
o`030000<ol0<ol000dco`000`000?ooooooo`1Aoooo00?o09Woooooool0D_ooo`00Ioooo`030000
<ol0<ol000dco`000`000?ooooooo`1Aoooo00?o09Woooooool0D_ooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`1Boooo00?o09Woooooool0D_ooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`1Boooo00?o09Woooooool0D_ooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`1Boooo00?o09Woooooool0D_ooo`00Ioooo`80000=<ol000<0003oooooool0D_ooo`03o`2I
oooooooo05;oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0D_ooo`03o`2Ioooooooo
05;oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0D_ooo`03o`2Ioooooooo05;oool0
06Ooool00`0003?o03?o000;<ol000<0003oooooool0Doooo`03o`2Ioooooooo05;oool0063oool2
00001Oooo`030000<ol0<ol000/co`000`000?ooooooo`1Coooo00?o09Woooooool0D_ooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1Coooo00?o09Wooooo
ool0D_ooo`00HOooo`030000oooooooo00?oool2000033?o00030000oooooooo05?oool00ol0VOoo
ooooo`1Boooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`1C
oooo00?o09Woooooool0D_ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`1Coooo00?o09Woooooool0D_ooo`00H?ooo`800005oooo00<0000co`0co`002S?o
00030000oooooooo05Coool00ol0VOooooooo`1Boooo001Woooo00<0000co`0co`002S?o00030000
oooooooo05Coool00ol0VOooooooo`1Boooo001Woooo00<0000co`0co`002S?o00030000oooooooo
05Coool00ol0VOooooooo`1Boooo001Woooo00<0000co`0co`002S?o00030000oooooooo05Coool0
0ol0VOooooooo`1Boooo001Woooo0P0000/co`000`000?ooooooo`1Doooo00?o09Woooooool0D_oo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1Doooo00?o09Woooooool0D_ooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1Eoooo00?o09Woooooool0D_ooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`1Eoooo00?o09Woooooool0D_ooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1Eoooo00?o09Woooooool0D_ooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`1Eoooo00?o09Woooooool0D_ooo`00Ioooo`80000:<ol000<0003oooooool0EOoo
o`03o`2Ioooooooo05;oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0EOooo`03o`2I
oooooooo05;oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0EOooo`03o`2Ioooooooo
05;oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0E_ooo`03o`2Ioooooooo05;oool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool0E_ooo`03o`2Ioooooooo05;oool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0E_ooo`03o`2Ioooooooo05;oool006Ooool200002C?o
00030000oooooooo05Koool00ol0VOooooooo`1Boooo001Woooo00<0000co`0co`0023?o00030000
oooooooo05Koool00ol0VOooooooo`1Boooo001Woooo00<0000co`0co`0023?o00030000oooooooo
05Koool00ol0VOooooooo`1Boooo001Woooo00<0000co`0co`001c?o00030000oooooooo05Ooool0
0ol0VOooooooo`1Boooo001Woooo00<0000co`0co`001c?o00030000oooooooo05Ooool00ol0VOoo
ooooo`1Boooo001Woooo00<0000co`0co`001c?o00030000oooooooo05Ooool00ol0VOooooooo`1B
oooo001Woooo0P0000Pco`000`000?ooooooo`1Goooo00?o09Woooooool0D_ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`1Goooo00?o09Woooooool0D_ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1Goooo00?o09Woooooool0D_ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1Goooo00?o09Woooooool0D_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Goooo00?o09Woooooool0D_ooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000
oooooooo05Ooool00ol0VOooooooo`1Boooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1Goooo00?o09Woooooool0D_ooo`00Goooo`D00003oooo0P0000Pco`00
0`000?ooooooo`1Goooo00?o09Woooooool0D_ooo`00Goooo`040000oooooooo00001?ooo`Xco`2_
oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Iooo
o`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000
oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool500000_ooo`800003oooo100000Coool300000_ooo`030000oooooooo07Soool006Ooool9
<ol02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00D0003oooooooooool00000N_ooo`00Iooo
o`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`08oooo00<0
003oooooool00_ooo`D00003oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003ooooo
ool01@0000koool00`000?ooooooo`09oooo00D0003oooooooooool000000_ooo`050000oooooooo
oooo000007[oool006Ooool9<ol02?ooo`050000oooooooooooo0000017oool00`000?ooooooo`07
oooo00@0003oooooool00003oooo00<0003oool000000oooo`030000oooooooo07Soool006Ooool9
<ol02Oooo`030000oooooooo017oool200002_ooo`800005oooo0P0000;oool00`000?ooooooo`1i
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.72912 .12361 L
.73354 .12361 L
.73604 .12361 L
.73838 .12361 L
.73955 .12361 L
.74065 .12361 L
s
.74065 .12361 m
.74116 .61803 L
s
0 .4 1 r
.02381 .07997 m
.04262 .07451 L
.06244 .07006 L
.08255 .0667 L
.09396 .06526 L
.10458 .06417 L
.11508 .06332 L
.125 .06271 L
.1339 .06231 L
.13893 .06213 L
.14357 .06201 L
.14823 .06191 L
.15085 .06187 L
.15324 .06184 L
.15546 .06182 L
.15672 .06182 L
.15788 .06181 L
.159 .06181 L
.16002 .0618 L
.16119 .0618 L
.1623 .0618 L
.16349 .06181 L
.16481 .06181 L
.16547 .06181 L
.16618 .06182 L
.16746 .06183 L
.16994 .06185 L
.17221 .06187 L
.17771 .06196 L
.18292 .06207 L
.19258 .06235 L
.20283 .06273 L
.22125 .06363 L
.259 .06614 L
.29921 .06947 L
.33789 .07305 L
.34291 .07353 L
.34828 .07395 L
.35334 .07427 L
.35793 .07448 L
.36042 .07457 L
.36312 .07465 L
.36566 .07471 L
.36801 .07475 L
.36933 .07477 L
.37056 .07478 L
.37127 .07479 L
.37191 .07479 L
.37266 .07479 L
.37337 .0748 L
Mistroke
.37405 .0748 L
.37477 .0748 L
.37608 .07479 L
.37688 .07479 L
.37763 .07479 L
.37903 .07477 L
.3802 .07476 L
.38145 .07474 L
.3837 .07471 L
.38882 .07459 L
.39423 .07442 L
.39915 .07422 L
.41764 .07317 L
.43676 .07167 L
.45753 .06967 L
.49837 .06486 L
.53769 .05947 L
.57549 .05384 L
.61575 .04758 L
.65449 .04153 L
.69568 .0354 L
.71624 .03257 L
.72626 .03128 L
.73535 .03016 L
.73757 .0299 L
.73992 .02962 L
.74114 .02948 L
.74184 .12361 L
.74249 .12361 L
.74486 .12361 L
.75382 .12361 L
.77351 .12361 L
.81239 .12361 L
.85372 .12361 L
.89353 .12361 L
.93183 .12361 L
.97258 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Joooo2@1Voe?oool0
06Ooool00`000?ooooooo`1Eoooo1@1Vo`Soool00`1Vooooooooo`1Aoooo001Woooo00<0003ooooo
ool0Coooo`H0I_l=oooo00<0I_ooooooool0DOooo`00Ioooo`030000oooooooo04Soool706Ko4ooo
o`0306Kooooooooo057oool006Ooool00`000?ooooooo`10oooo201Voa[oool00`1Vooooooooo`1A
oooo001Woooo0P0003coool506Ko8_ooo`0306Kooooooooo057oool006Ooool00`000?ooooooo`0d
oooo1`1VobOoool00`1Vooooooooo`1Aoooo001Woooo00<0003oooooool0;Oooo`L0I_l^oooo00<0
I_ooooooool0DOooo`00:_ooob<0I_lJoooo00<0003oooooool0:?ooo`D0I_leoooo00<0I_oooooo
ool0DOooo`008oooo`L0I_lSoooo2P1Voa3oool00`000?ooooooo`0Poooo201Voc[oool00`1Voooo
ooooo`1Aoooo000Noooo1@1VocCoool:06Ko1_ooo`030000oooooooo01?oool=06Ko@_ooo`0306Ko
oooooooo057oool001Woool506Ko@oooo`H0I_l20000501Vodooool00`1Vooooooooo`1Aoooo000F
oooo00<0I_l0000000000`0001koool200001?ooo`800004oooo0P0001ooool00`000?ooooooo`0N
oooo0P0000Coool200001?ooo`80000Ooooo1@0001;oool00`1Vooooooooo`08oooo1@0000;oool2
00001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000
oooooooo00008?ooo`030000oooooooo01;oool00`1Vooooooooo`0:oooo00<0003oooooool01ooo
o`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0Moooo00@0
003oooooool0000;oooo00<0003oooooool07?ooo`030000oooooooo01goool010000?ooooooo`00
00_oool00`000?ooooooo`0Noooo00<0003oooooool04_ooo`0306Kooooooooo00[oool00`000?oo
ooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo01Koool0017oool400001?ooo`030000
oooooooo01Ooool400000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool04_ooo`0306Kooooooooo00[oool0
0`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003ooooo
ool00009oooo00<0003oooooool08?ooo`030000oooooooo01;oool00`1Vooooooooo`0:oooo00<0
003oooooool02?ooo`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200008?oo
o`80000:oooo0`0001koool200007oooo`80000:oooo0`0001ooool200005?ooo`0306Kooooooooo
00Woool200002_ooo`<0000Poooo0P0001Ooool006Ooool00`000?ooooooo`1Roooo00<0I_oooooo
ool0DOooo`00Ioooo`030000oooooooo06;oool00`1Vooooooooo`1Aoooo001Woooo00<0003ooooo
ool0H_ooo`0306Kooooooooo057oool006Ooool00`000?ooooooo`1Roooo00<0I_ooooooool0DOoo
o`00Ioooo`030000oooooooo06;oool00`1Vooooooooo`1Aoooo000@ooooo`00017oool001Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol01P000003o`2I
0000000001l00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
000co`0co`009C?o00030000<ol0<ol002@co`0@00001_ooo`03o`2Ioooooooo013oool00`000?oo
ooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol004Lco`0500005_ooo`03o`2I
oooooooo057oool006Ooool00`0003?o03?o0012<ol01@0001_oool00ol0VOooooooo`1Aoooo001W
oooo00<0000co`0co`00?C?o00D0000Poooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol0
03Tco`0400009Oooo`03o`2Ioooooooo057oool006Ooool20000>3?o0080000Yoooo00?o09Wooooo
ool0DOooo`00Ioooo`030000<ol0<ol003Dco`020000:oooo`03o`2Ioooooooo057oool006Ooool0
0`0003?o03?o000c<ol00P0002goool00ol0VOooooooo`1Aoooo001Woooo00<0000co`0co`00<C?o
0080000_oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`0_
oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol002hco`020000<_ooo`03o`2Ioooooooo
057oool006Ooool20000;C?o0080000doooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol0
02/co`000`000?ooooooo`0doooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol002Xco`00
0`000?ooooooo`0eoooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol002Tco`000`000?oo
ooooo`0foooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0g
oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0goooo00?o
09Woooooool0DOooo`00Ioooo`80000X<ol000<0003oooooool0>?ooo`03o`2Ioooooooo057oool0
06Ooool00`0003?o03?o000V<ol000<0003oooooool0>Oooo`03o`2Ioooooooo057oool006Ooool0
0`0003?o03?o000U<ol000<0003oooooool0>_ooo`03o`2Ioooooooo057oool006Ooool00`0003?o
03?o000T<ol000<0003oooooool0>oooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o000S
<ol000<0003oooooool0??ooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o000S<ol000<0
003oooooool0??ooo`03o`2Ioooooooo057oool006Ooool200008c?o00030000oooooooo03goool0
0ol0VOooooooo`1Aoooo001Woooo00<0000co`0co`008C?o00030000oooooooo03koool00ol0VOoo
ooooo`1Aoooo001Woooo00<0000co`0co`0083?o00030000oooooooo03ooool00ol0VOooooooo`1A
oooo001Woooo00<0000co`0co`0083?o00030000oooooooo03ooool00ol0VOooooooo`1Aoooo001W
oooo00<0000co`0co`007c?o00030000oooooooo043oool00ol0VOooooooo`1Aoooo001Ooooo1@00
00?oool00`0003?o03?o000O<ol000<0003oooooool0@?ooo`03o`2Ioooooooo057oool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`007S?o00030000oooooooo047oool00ol0VOooooooo`1A
oooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0003oooooool0@Oooo`03o`2Ioooooooo
057oool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo04;oool0
0ol0VOooooooo`1Aoooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?oo
ooooo`12oooo00?o09Woooooool0DOooo`00H?ooo`800005oooo00<0000co`0co`0073?o00030000
oooooooo04?oool00ol0VOooooooo`1Aoooo001Woooo00<0000co`0co`0073?o00030000oooooooo
04?oool00ol0VOooooooo`1Aoooo001Woooo00<0000co`0co`006c?o00030000oooooooo04Coool0
0ol0VOooooooo`1Aoooo001Woooo0P0001`co`000`000?ooooooo`14oooo00?o09Woooooool0DOoo
o`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`15oooo00?o09Woooooool0DOooo`00Iooo
o`030000<ol0<ol001Xco`000`000?ooooooo`15oooo00?o09Woooooool0DOooo`00Ioooo`030000
<ol0<ol001Tco`000`000?ooooooo`16oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol0
01Tco`000`000?ooooooo`16oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol001Pco`00
0`000?ooooooo`17oooo00?o09Woooooool0DOooo`00Ioooo`80000I<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo057oool006Ooool00`0003?o03?o000G<ol000<0003oooooool0B?ooo`03o`2I
oooooooo057oool006Ooool00`0003?o03?o000G<ol000<0003oooooool0B?ooo`03o`2Ioooooooo
057oool006Ooool00`0003?o03?o000F<ol000<0003oooooool0BOooo`03o`2Ioooooooo057oool0
06Ooool00`0003?o03?o000F<ol000<0003oooooool0BOooo`03o`2Ioooooooo057oool006Ooool0
0`0003?o03?o000F<ol000<0003oooooool0BOooo`03o`2Ioooooooo057oool006Ooool00`0003?o
03?o000E<ol000<0003oooooool0B_ooo`03o`2Ioooooooo057oool006Ooool200005S?o00030000
oooooooo04[oool00ol0VOooooooo`1Aoooo001Woooo00<0000co`0co`005C?o00030000oooooooo
04[oool00ol0VOooooooo`1Aoooo001Woooo00<0000co`0co`005C?o00030000oooooooo04[oool0
0ol0VOooooooo`1Aoooo001Woooo00<0000co`0co`0053?o00030000oooooooo04_oool00ol0VOoo
ooooo`1Aoooo001Woooo00<0000co`0co`0053?o00030000oooooooo04_oool00ol0VOooooooo`1A
oooo001Woooo00<0000co`0co`0053?o00030000oooooooo04_oool00ol0VOooooooo`1Aoooo001W
oooo0P0001Dco`000`000?ooooooo`1;oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol0
01<co`000`000?ooooooo`1<oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol001<co`00
0`000?ooooooo`1<oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol001<co`000`000?oo
ooooo`1<oooo00?o09Woooooool0DOooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000
oooooooo04coool00ol0VOooooooo`1Aoooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0
018co`000`000?ooooooo`1=oooo00?o09Woooooool0DOooo`00H?ooo`030000oooooooo00Coool2
00004c?o00030000oooooooo04goool00ol0VOooooooo`1Aoooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol0018co`000`000?ooooooo`1=oooo00?o09Woooooool0DOooo`00Goooo`040000
oooooooo00001?ooo`030000<ol0<ol0014co`000`000?ooooooo`1>oooo00?o09Woooooool0DOoo
o`00H?ooo`800005oooo00<0000co`0co`004C?o00030000oooooooo04koool00ol0VOooooooo`1A
oooo001Woooo00<0000co`0co`004C?o00030000oooooooo04koool00ol0VOooooooo`1Aoooo001W
oooo00<0000co`0co`004C?o00030000oooooooo04koool00ol0VOooooooo`1Aoooo001Woooo0P00
014co`000`000?ooooooo`1?oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol0010co`00
0`000?ooooooo`1?oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol0010co`000`000?oo
ooooo`1?oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1?
oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1@oooo00?o
09Woooooool0DOooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1@oooo00?o09Wooooo
ool0DOooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1@oooo00?o09Woooooool0DOoo
o`00Ioooo`80000@<ol000<0003oooooool0D?ooo`03o`2Ioooooooo057oool006Ooool00`0003?o
03?o000><ol000<0003oooooool0DOooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o000>
<ol000<0003oooooool0DOooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o000><ol000<0
003oooooool0DOooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o000><ol000<0003ooooo
ool0DOooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o000=<ol000<0003oooooool0D_oo
o`03o`2Ioooooooo057oool006Ooool200003S?o00030000oooooooo05;oool00ol0VOooooooo`1A
oooo001Woooo00<0000co`0co`003C?o00030000oooooooo05;oool00ol0VOooooooo`1Aoooo001W
oooo00<0000co`0co`003C?o00030000oooooooo05;oool00ol0VOooooooo`1Aoooo001Woooo00<0
000co`0co`0033?o00030000oooooooo05?oool00ol0VOooooooo`1Aoooo001Woooo00<0000co`0c
o`0033?o00030000oooooooo05?oool00ol0VOooooooo`1Aoooo001Woooo00<0000co`0co`0033?o
00030000oooooooo05?oool00ol0VOooooooo`1Aoooo001Woooo0P0000dco`000`000?ooooooo`1C
oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1Coooo00?o
09Woooooool0DOooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1Coooo00?o09Wooooo
ool0DOooo`00Ioooo`030000<ol0<ol000/co`000`000?ooooooo`1Doooo00?o09Woooooool0DOoo
o`00H?ooo`800005oooo00<0000co`0co`002c?o00030000oooooooo05Coool00ol0VOooooooo`1A
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo05Coool0
0ol0VOooooooo`1Aoooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0003oooooool0E?oo
o`03o`2Ioooooooo057oool006;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000
oooooooo05Coool00ol0VOooooooo`1Aoooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`002c?o00030000oooooooo05Coool00ol0VOooooooo`1Aoooo001Poooo0P0000Goool00`0003?o
03?o000:<ol000<0003oooooool0EOooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o000:
<ol000<0003oooooool0EOooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o000:<ol000<0
003oooooool0EOooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0EOooo`03o`2Ioooooooo057oool006Ooool200002c?o00030000oooooooo05Goool00ol0VOoo
ooooo`1Aoooo001Woooo00<0000co`0co`002S?o00030000oooooooo05Goool00ol0VOooooooo`1A
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo05Koool00ol0VOooooooo`1Aoooo001W
oooo00<0000co`0co`002C?o00030000oooooooo05Koool00ol0VOooooooo`1Aoooo001Woooo00<0
000co`0co`002C?o00030000oooooooo05Koool00ol0VOooooooo`1Aoooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo05Koool00ol0VOooooooo`1Aoooo001Woooo0P0000Xco`000`000?oo
ooooo`1Foooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1F
oooo00?o09Woooooool0DOooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Foooo00?o
09Woooooool0DOooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Goooo00?o09Wooooo
ool0DOooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Goooo00?o09Woooooool0DOoo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Goooo00?o09Woooooool0DOooo`00Iooo
o`800009<ol000<0003oooooool0Eoooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0Eoooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0Eoooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo057oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0F?oo
o`03o`2Ioooooooo057oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0F?ooo`03o`2I
oooooooo057oool006Ooool2000023?o00030000oooooooo05Soool00ol0VOooooooo`1Aoooo001W
oooo00<0000co`0co`001c?o00030000oooooooo05Soool00ol0VOooooooo`1Aoooo001Woooo00<0
000co`0co`001c?o00030000oooooooo05Soool00ol0VOooooooo`1Aoooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo05Soool00ol0VOooooooo`1Aoooo001Woooo00<0000co`0co`001c?o
00030000oooooooo05Soool00ol0VOooooooo`1Aoooo001Qoooo0`0000?oool00`0003?o03?o0007
<ol000<0003oooooool0F?ooo`03o`2Ioooooooo057oool006;oool00`000?ooooooo`02oooo00<0
000co`0co`001c?o00030000oooooooo05Soool00ol0VOooooooo`1Aoooo001Ooooo1@0000?oool2
000023?o00030000oooooooo05Soool00ol0VOooooooo`1Aoooo001Ooooo00@0003oooooool00004
oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_
oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?oo
o`030000oooooooo07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002oooo0P0000?oool400000_ooo`<00004oooo00<0003oooooool0N?oo
o`00Ioooo`Tco`08oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00?oool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03ooo
o`030000oooooooo00Soool00`000?ooooooo`02oooo00@0003oooooool00004oooo00<0003ooooo
ool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000koool00`000?ooooooo`09oooo00@0
003oooooooooool300001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooo
oooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool00ooo
o`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo017oool200002_ooo`800004
oooo0`0000;oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.72912 .12361 L
.73838 .12361 L
.74309 .12361 L
.74546 .12361 L
.74611 .12361 L
.7468 .12361 L
s
.7468 .12361 m
.74731 .61803 L
s
0 .4 1 r
.02381 .07798 m
.04262 .07295 L
.06244 .06888 L
.08255 .06586 L
.09396 .06458 L
.10458 .06363 L
.11508 .06291 L
.12023 .06263 L
.125 .06241 L
.1339 .06209 L
.1386 .06198 L
.14115 .06193 L
.14357 .06189 L
.14592 .06186 L
.14716 .06184 L
.14849 .06183 L
.14971 .06182 L
.15082 .06181 L
.15193 .06181 L
.15298 .06181 L
.15422 .0618 L
.15552 .0618 L
.15663 .06181 L
.15785 .06181 L
.15916 .06181 L
.16057 .06182 L
.16311 .06184 L
.16546 .06187 L
.16802 .0619 L
.17268 .06199 L
.18141 .0622 L
.19081 .06251 L
.20118 .06294 L
.22219 .06405 L
.26239 .0669 L
.30108 .07021 L
.32073 .07203 L
.33112 .07301 L
.34222 .07407 L
.34775 .07453 L
.35298 .07486 L
.35766 .07509 L
.36008 .07519 L
.36275 .07527 L
.36524 .07533 L
.36757 .07538 L
.36884 .0754 L
.37004 .07541 L
.3707 .07542 L
.37142 .07542 L
Mistroke
.37268 .07543 L
.37389 .07544 L
.37499 .07544 L
.37625 .07544 L
.37744 .07543 L
.37854 .07542 L
.37956 .07542 L
.38184 .07539 L
.38431 .07535 L
.38656 .0753 L
.39161 .07517 L
.39628 .07501 L
.40071 .07482 L
.42138 .07362 L
.44133 .07201 L
.45977 .07021 L
.49908 .06562 L
.53689 .06049 L
.57714 .05453 L
.61588 .04852 L
.65707 .04208 L
.69675 .03612 L
.71676 .03332 L
.73491 .03096 L
.73977 .03037 L
.74232 .03006 L
.74503 .02974 L
.74617 .02961 L
.74739 .02947 L
.74809 .12361 L
.74873 .12361 L
.74999 .12361 L
.75456 .12361 L
.77552 .12361 L
.81534 .12361 L
.85364 .12361 L
.89438 .12361 L
.93362 .12361 L
.97134 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Ooooo1P1Voe7oool0
06Ooool00`000?ooooooo`1Eoooo2P1Vo`Goool00`1Vooooooooo`1?oooo001Woooo00<0003ooooo
ool0D?ooo`D0I_l?oooo00<0I_ooooooool0Coooo`00Ioooo`030000oooooooo04Soool806Ko5?oo
o`0306Kooooooooo04ooool006Ooool00`000?ooooooo`10oooo201Voacoool00`1Vooooooooo`1?
oooo001Woooo0P0003goool406Ko9?ooo`0306Kooooooooo04ooool006Ooool00`000?ooooooo`0d
oooo201VobSoool00`1Vooooooooo`1?oooo001Woooo00<0003oooooool0;?ooo`P0I_l`oooo00<0
I_ooooooool0Coooo`009oooobL0I_lIoooo00<0003oooooool0:?ooo`@0I_lhoooo00<0I_oooooo
ool0Coooo`008oooo`@0I_lWoooo2P1Vo`ooool00`000?ooooooo`0Qoooo1`1Voccoool00`1Voooo
ooooo`1?oooo000Noooo1@1VocGoool;06Ko1?ooo`030000oooooooo01Coool=06Ko@oooo`0306Ko
oooooooo04ooool001Woool506KoAOooo`@0I_l200005@1Voe3oool00`1Vooooooooo`1?oooo000F
oooo00<0I_l0000000000`0001koool200001?ooo`800004oooo0P0001ooool00`000?ooooooo`0N
oooo0P0000Coool200001?ooo`80000Ooooo1@0001Coool00`1Vooooooooo`06oooo1@0000;oool2
00001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000
oooooooo00008?ooo`030000oooooooo01Coool00`1Vooooooooo`08oooo00<0003oooooool01ooo
o`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0Moooo00@0
003oooooool0000;oooo00<0003oooooool07?ooo`030000oooooooo01goool010000?ooooooo`00
00_oool00`000?ooooooo`0Noooo00<0003oooooool05?ooo`0306Kooooooooo00Soool00`000?oo
ooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo01Koool0017oool400001?ooo`030000
oooooooo01Ooool400000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool05?ooo`0306Kooooooooo00Soool0
0`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003ooooo
ool00009oooo00<0003oooooool08?ooo`030000oooooooo01Coool00`1Vooooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200008?oo
o`80000:oooo0`0001koool200007oooo`80000:oooo0`0001ooool200005_ooo`0306Kooooooooo
00Ooool200002_ooo`<0000Poooo0P0001Ooool006Ooool00`000?ooooooo`1Toooo00<0I_oooooo
ool0Coooo`00Ioooo`030000oooooooo06Coool00`1Vooooooooo`1?oooo001Woooo00<0003ooooo
ool0I?ooo`0306Kooooooooo04ooool006Ooool00`000?ooooooo`1Toooo00<0I_ooooooool0Cooo
o`00Ioooo`030000oooooooo06Coool00`1Vooooooooo`1?oooo000@ooooo`00017oool001Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol020000003o`2I
0000000001d00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
000co`0co`009C?o00030000<ol0<ol002@co`0@00002?ooo`03o`2Ioooooooo00koool00`000?oo
ooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol004Lco`0500006?ooo`03o`2I
oooooooo04ooool006Ooool00`0003?o03?o0012<ol01@0001goool00ol0VOooooooo`1?oooo001W
oooo00<0000co`0co`00?C?o00D0000Roooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol0
03Tco`0400009oooo`03o`2Ioooooooo04ooool006Ooool20000>3?o0080000[oooo00?o09Wooooo
ool0Coooo`00Ioooo`030000<ol0<ol003Dco`020000;Oooo`03o`2Ioooooooo04ooool006Ooool0
0`0003?o03?o000c<ol00P0002ooool00ol0VOooooooo`1?oooo001Woooo00<0000co`0co`00<C?o
0080000aoooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`0a
oooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol002hco`020000=?ooo`03o`2Ioooooooo
04ooool006Ooool20000;C?o0080000foooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol0
02/co`000`000?ooooooo`0foooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol002Xco`00
0`000?ooooooo`0goooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol002Tco`000`000?oo
ooooo`0hoooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0i
oooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0ioooo00?o
09Woooooool0Coooo`00Ioooo`80000X<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04ooool0
06Ooool00`0003?o03?o000V<ol000<0003oooooool0>oooo`03o`2Ioooooooo04ooool006Ooool0
0`0003?o03?o000U<ol000<0003oooooool0??ooo`03o`2Ioooooooo04ooool006Ooool00`0003?o
03?o000T<ol000<0003oooooool0?Oooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o000S
<ol000<0003oooooool0?_ooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o000S<ol000<0
003oooooool0?_ooo`03o`2Ioooooooo04ooool006Ooool200008c?o00030000oooooooo03ooool0
0ol0VOooooooo`1?oooo001Woooo00<0000co`0co`008C?o00030000oooooooo043oool00ol0VOoo
ooooo`1?oooo001Woooo00<0000co`0co`0083?o00030000oooooooo047oool00ol0VOooooooo`1?
oooo001Woooo00<0000co`0co`0083?o00030000oooooooo047oool00ol0VOooooooo`1?oooo001W
oooo00<0000co`0co`007c?o00030000oooooooo04;oool00ol0VOooooooo`1?oooo001Ooooo1@00
00?oool00`0003?o03?o000O<ol000<0003oooooool0@_ooo`03o`2Ioooooooo04ooool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`007S?o00030000oooooooo04?oool00ol0VOooooooo`1?
oooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0003oooooool0@oooo`03o`2Ioooooooo
04ooool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo04Coool0
0ol0VOooooooo`1?oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?oo
ooooo`14oooo00?o09Woooooool0Coooo`00H?ooo`800005oooo00<0000co`0co`0073?o00030000
oooooooo04Goool00ol0VOooooooo`1?oooo001Woooo00<0000co`0co`0073?o00030000oooooooo
04Goool00ol0VOooooooo`1?oooo001Woooo00<0000co`0co`006c?o00030000oooooooo04Koool0
0ol0VOooooooo`1?oooo001Woooo0P0001`co`000`000?ooooooo`16oooo00?o09Woooooool0Cooo
o`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`17oooo00?o09Woooooool0Coooo`00Iooo
o`030000<ol0<ol001Xco`000`000?ooooooo`17oooo00?o09Woooooool0Coooo`00Ioooo`030000
<ol0<ol001Tco`000`000?ooooooo`18oooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol0
01Tco`000`000?ooooooo`18oooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol001Pco`00
0`000?ooooooo`19oooo00?o09Woooooool0Coooo`00Ioooo`80000I<ol000<0003oooooool0BOoo
o`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o000G<ol000<0003oooooool0B_ooo`03o`2I
oooooooo04ooool006Ooool00`0003?o03?o000G<ol000<0003oooooool0B_ooo`03o`2Ioooooooo
04ooool006Ooool00`0003?o03?o000F<ol000<0003oooooool0Boooo`03o`2Ioooooooo04ooool0
06Ooool00`0003?o03?o000F<ol000<0003oooooool0Boooo`03o`2Ioooooooo04ooool006Ooool0
0`0003?o03?o000F<ol000<0003oooooool0Boooo`03o`2Ioooooooo04ooool006Ooool00`0003?o
03?o000E<ol000<0003oooooool0C?ooo`03o`2Ioooooooo04ooool006Ooool200005S?o00030000
oooooooo04coool00ol0VOooooooo`1?oooo001Woooo00<0000co`0co`005C?o00030000oooooooo
04coool00ol0VOooooooo`1?oooo001Woooo00<0000co`0co`005C?o00030000oooooooo04coool0
0ol0VOooooooo`1?oooo001Woooo00<0000co`0co`0053?o00030000oooooooo04goool00ol0VOoo
ooooo`1?oooo001Woooo00<0000co`0co`0053?o00030000oooooooo04goool00ol0VOooooooo`1?
oooo001Woooo00<0000co`0co`0053?o00030000oooooooo04goool00ol0VOooooooo`1?oooo001W
oooo0P0001Dco`000`000?ooooooo`1=oooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol0
01<co`000`000?ooooooo`1>oooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol001<co`00
0`000?ooooooo`1>oooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol001<co`000`000?oo
ooooo`1>oooo00?o09Woooooool0Coooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000
oooooooo04koool00ol0VOooooooo`1?oooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0
018co`000`000?ooooooo`1?oooo00?o09Woooooool0Coooo`00H?ooo`030000oooooooo00Coool2
00004c?o00030000oooooooo04ooool00ol0VOooooooo`1?oooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol0018co`000`000?ooooooo`1?oooo00?o09Woooooool0Coooo`00Goooo`040000
oooooooo00001?ooo`030000<ol0<ol0014co`000`000?ooooooo`1@oooo00?o09Woooooool0Cooo
o`00H?ooo`800005oooo00<0000co`0co`004C?o00030000oooooooo053oool00ol0VOooooooo`1?
oooo001Woooo00<0000co`0co`004C?o00030000oooooooo053oool00ol0VOooooooo`1?oooo001W
oooo00<0000co`0co`004C?o00030000oooooooo053oool00ol0VOooooooo`1?oooo001Woooo0P00
014co`000`000?ooooooo`1Aoooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol0010co`00
0`000?ooooooo`1Aoooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol0010co`000`000?oo
ooooo`1Aoooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1A
oooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1Boooo00?o
09Woooooool0Coooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1Boooo00?o09Wooooo
ool0Coooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1Boooo00?o09Woooooool0Cooo
o`00Ioooo`80000@<ol000<0003oooooool0D_ooo`03o`2Ioooooooo04ooool006Ooool00`0003?o
03?o000><ol000<0003oooooool0Doooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o000>
<ol000<0003oooooool0Doooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o000><ol000<0
003oooooool0Doooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o000><ol000<0003ooooo
ool0Doooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o000=<ol000<0003oooooool0E?oo
o`03o`2Ioooooooo04ooool006Ooool200003S?o00030000oooooooo05Coool00ol0VOooooooo`1?
oooo001Woooo00<0000co`0co`003C?o00030000oooooooo05Coool00ol0VOooooooo`1?oooo001W
oooo00<0000co`0co`003C?o00030000oooooooo05Coool00ol0VOooooooo`1?oooo001Woooo00<0
000co`0co`0033?o00030000oooooooo05Goool00ol0VOooooooo`1?oooo001Woooo00<0000co`0c
o`0033?o00030000oooooooo05Goool00ol0VOooooooo`1?oooo001Woooo00<0000co`0co`0033?o
00030000oooooooo05Goool00ol0VOooooooo`1?oooo001Woooo0P0000dco`000`000?ooooooo`1E
oooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1Eoooo00?o
09Woooooool0Coooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1Eoooo00?o09Wooooo
ool0Coooo`00Ioooo`030000<ol0<ol000/co`000`000?ooooooo`1Foooo00?o09Woooooool0Cooo
o`00H?ooo`800005oooo00<0000co`0co`002c?o00030000oooooooo05Koool00ol0VOooooooo`1?
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo05Koool0
0ol0VOooooooo`1?oooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0003oooooool0E_oo
o`03o`2Ioooooooo04ooool006;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000
oooooooo05Koool00ol0VOooooooo`1?oooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`002c?o00030000oooooooo05Koool00ol0VOooooooo`1?oooo001Poooo0P0000Goool00`0003?o
03?o000:<ol000<0003oooooool0Eoooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o000:
<ol000<0003oooooool0Eoooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o000:<ol000<0
003oooooool0Eoooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0Eoooo`03o`2Ioooooooo04ooool006Ooool200002c?o00030000oooooooo05Ooool00ol0VOoo
ooooo`1?oooo001Woooo00<0000co`0co`002S?o00030000oooooooo05Ooool00ol0VOooooooo`1?
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo05Soool00ol0VOooooooo`1?oooo001W
oooo00<0000co`0co`002C?o00030000oooooooo05Soool00ol0VOooooooo`1?oooo001Woooo00<0
000co`0co`002C?o00030000oooooooo05Soool00ol0VOooooooo`1?oooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo05Soool00ol0VOooooooo`1?oooo001Woooo0P0000Xco`000`000?oo
ooooo`1Hoooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1H
oooo00?o09Woooooool0Coooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Hoooo00?o
09Woooooool0Coooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Ioooo00?o09Wooooo
ool0Coooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Ioooo00?o09Woooooool0Cooo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Ioooo00?o09Woooooool0Coooo`00Iooo
o`800009<ol000<0003oooooool0FOooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0FOooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0FOooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0F_ooo`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o0007<ol000<0003oooooool0F_oo
o`03o`2Ioooooooo04ooool006Ooool00`0003?o03?o0007<ol000<0003oooooool0F_ooo`03o`2I
oooooooo04ooool006Ooool2000023?o00030000oooooooo05[oool00ol0VOooooooo`1?oooo001W
oooo00<0000co`0co`001c?o00030000oooooooo05[oool00ol0VOooooooo`1?oooo001Woooo00<0
000co`0co`001c?o00030000oooooooo05[oool00ol0VOooooooo`1?oooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo05[oool00ol0VOooooooo`1?oooo001Woooo00<0000co`0co`001c?o
00030000oooooooo05[oool00ol0VOooooooo`1?oooo001Qoooo0`0000?oool00`0003?o03?o0007
<ol000<0003oooooool0F_ooo`03o`2Ioooooooo04ooool006;oool00`000?ooooooo`02oooo00<0
000co`0co`001c?o00030000oooooooo05[oool00ol0VOooooooo`1?oooo001Ooooo1@0000?oool2
000023?o00030000oooooooo05[oool00ol0VOooooooo`1?oooo001Ooooo00@0003oooooool00004
oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_
oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?oo
o`030000oooooooo07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002oooo0P0000?oool400000oooo`800004oooo00<0003oooooool0N?oo
o`00Ioooo`Tco`08oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00?oool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03ooo
o`030000oooooooo00Soool00`000?ooooooo`02oooo00@0003oooooool00004oooo00<0003ooooo
ool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000koool00`000?ooooooo`09oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003ooooo
ooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000[oool2
00001?ooo`800003oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75071 .12361 L
.75216 .12361 L
.75287 .12361 L
.75351 .12361 L
s
.75351 .12361 m
.75398 .61803 L
s
0 .4 1 r
.02381 .07614 m
.04262 .07152 L
.06244 .06781 L
.08255 .06511 L
.09396 .06399 L
.10458 .06317 L
.10961 .06286 L
.11508 .06257 L
.11989 .06236 L
.125 .06217 L
.12959 .06204 L
.13203 .06198 L
.13466 .06193 L
.13706 .06189 L
.13926 .06186 L
.14147 .06184 L
.14357 .06182 L
.14482 .06181 L
.14552 .06181 L
.14616 .06181 L
.14735 .0618 L
.1486 .0618 L
.14972 .0618 L
.15077 .06181 L
.15192 .06181 L
.15316 .06182 L
.15447 .06182 L
.1559 .06184 L
.1585 .06186 L
.16338 .06193 L
.16801 .06202 L
.17293 .06214 L
.18177 .06241 L
.20124 .06325 L
.21952 .06428 L
.2582 .06707 L
.29934 .07063 L
.31987 .07255 L
.33897 .07437 L
.34352 .0748 L
.34845 .07519 L
.35279 .07547 L
.35739 .0757 L
.35995 .07581 L
.36276 .0759 L
.36531 .07596 L
.36771 .07601 L
.36892 .07603 L
.37007 .07605 L
.37111 .07606 L
Mistroke
.37222 .07607 L
.37343 .07607 L
.37455 .07608 L
.37523 .07608 L
.37587 .07608 L
.37708 .07608 L
.37824 .07607 L
.37949 .07606 L
.38067 .07605 L
.38175 .07604 L
.38438 .076 L
.38687 .07595 L
.39182 .07583 L
.39719 .07564 L
.4068 .07521 L
.41568 .0747 L
.43438 .07334 L
.455 .07147 L
.49525 .06693 L
.53399 .06179 L
.57518 .05577 L
.61486 .04964 L
.65302 .04367 L
.69363 .03748 L
.71241 .03477 L
.73273 .03202 L
.73814 .03133 L
.74387 .03062 L
.74875 .03003 L
.75009 .02987 L
.75153 .0297 L
.75222 .02962 L
.75288 .02955 L
.75412 .12361 L
.75527 .12361 L
.75655 .12361 L
.75913 .12361 L
.76377 .12361 L
.77428 .12361 L
.81445 .12361 L
.85311 .12361 L
.89422 .12361 L
.93381 .12361 L
.97188 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Noooo201Voe3oool0
06Ooool00`000?ooooooo`1Ioooo1@1Vo`Ooool00`1Vooooooooo`1>oooo001Woooo00<0003ooooo
ool0D_ooo`L0I_l<oooo00<0I_ooooooool0C_ooo`00Ioooo`030000oooooooo04[oool806Ko4ooo
o`0306Kooooooooo04koool006Ooool00`000?ooooooo`15oooo1@1Voa_oool00`1Vooooooooo`1>
oooo001Woooo0P0003ooool706Ko8?ooo`0306Kooooooooo04koool006Ooool00`000?ooooooo`0f
oooo201VobOoool00`1Vooooooooo`1>oooo001Woooo00<0003oooooool0<Oooo`D0I_l_oooo00<0
I_ooooooool0C_ooo`009oooobH0I_lJoooo00<0003oooooool0:_ooo`L0I_ldoooo00<0I_oooooo
ool0C_ooo`007_ooo`T0I_lVoooo2P1Voa3oool00`000?ooooooo`0Poooo2P1Voc_oool00`1Voooo
ooooo`1>oooo000Ioooo1@1VocWoool=06Ko0oooo`030000oooooooo01Soool806KoAOooo`0306Ko
oooooooo04koool001Koool306KoBoooo`<0I_l200006@1Vodgoool00`1Vooooooooo`1>oooo000G
oooo1@0001koool200001?ooo`800004oooo0P0001ooool00`000?ooooooo`0Noooo0P0000Coool2
00001?ooo`80000Ooooo1@0001Goool00`1Vooooooooo`05oooo1@0000;oool200001?ooo`80000P
oooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003ooooo
ool0000Noooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00008?oo
o`030000oooooooo01Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`040000oooooooo
00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0Moooo00@0003oooooool0000;
oooo00<0003oooooool07?ooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?oo
ooooo`0Noooo00<0003oooooool05Oooo`0306Kooooooooo00Ooool00`000?ooooooo`0:oooo00<0
003oooooool07_ooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo01Ooool4
00000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`80000Qoooo00<0003oooooool05Oooo`0306Kooooooooo00Ooool00`000?ooooooo`08
oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0
003oooooool08?ooo`030000oooooooo01Goool00`1Vooooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`00
01koool200007oooo`80000:oooo0`0001ooool200005oooo`0306Kooooooooo00Koool200002_oo
o`<0000Poooo0P0001Ooool006Ooool00`000?ooooooo`1Uoooo00<0I_ooooooool0C_ooo`00Iooo
o`030000oooooooo06Goool00`1Vooooooooo`1>oooo001Woooo00<0003oooooool0IOooo`0306Ko
oooooooo04koool006Ooool00`000?ooooooo`1Uoooo00<0I_ooooooool0C_ooo`00Ioooo`030000
oooooooo06Goool00`1Vooooooooo`1>oooo000@ooooo`00017oool001Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o
01000009oooo00?o09Woooooool03Oooo`030000oooooooo02Koool00`000?ooooooo`0Eoooo001W
oooo00<0000co`0co`00Ac?o00D0000Ioooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol0
048co`0500007_ooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000m<ol01@0002?oool0
0ol0VOooooooo`1>oooo001Woooo00<0000co`0co`00>C?o00@0000Xoooo00?o09Woooooool0C_oo
o`00Ioooo`80000h<ol00P0002coool00ol0VOooooooo`1>oooo001Woooo00<0000co`0co`00=C?o
0080000^oooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol003<co`020000<?ooo`03o`2I
oooooooo04koool006Ooool00`0003?o03?o000a<ol00P0003;oool00ol0VOooooooo`1>oooo001W
oooo00<0000co`0co`00<3?o00030000oooooooo03;oool00ol0VOooooooo`1>oooo001Woooo00<0
000co`0co`00;S?o0080000eoooo00?o09Woooooool0C_ooo`00Ioooo`80000]<ol00P0003Ooool0
0ol0VOooooooo`1>oooo001Woooo00<0000co`0co`00:c?o00030000oooooooo03Ooool00ol0VOoo
ooooo`1>oooo001Woooo00<0000co`0co`00:S?o00030000oooooooo03Soool00ol0VOooooooo`1>
oooo001Woooo00<0000co`0co`00:C?o00030000oooooooo03Woool00ol0VOooooooo`1>oooo001W
oooo00<0000co`0co`00:3?o00030000oooooooo03[oool00ol0VOooooooo`1>oooo001Woooo00<0
000co`0co`00:3?o00030000oooooooo03[oool00ol0VOooooooo`1>oooo001Woooo0P0002Pco`00
0`000?ooooooo`0koooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol002Hco`000`000?oo
ooooo`0loooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`0m
oooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`0noooo00?o
09Woooooool0C_ooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`0ooooo00?o09Wooooo
ool0C_ooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`0ooooo00?o09Woooooool0C_oo
o`00Ioooo`80000S<ol000<0003oooooool0@?ooo`03o`2Ioooooooo04koool006Ooool00`0003?o
03?o000Q<ol000<0003oooooool0@Oooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000P
<ol000<0003oooooool0@_ooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000P<ol000<0
003oooooool0@_ooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000O<ol000<0003ooooo
ool0@oooo`03o`2Ioooooooo04koool005ooool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`13oooo00?o09Woooooool0C_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo04koool0067oool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`14oooo00?o09Woooooool0C_ooo`00HOooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0AOooo`03o`2Ioooooooo04koool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo04Goool00ol0VOooooooo`1>oooo001P
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0A_ooo`03o`2Ioooooooo04koool0
06Ooool00`0003?o03?o000L<ol000<0003oooooool0A_ooo`03o`2Ioooooooo04koool006Ooool0
0`0003?o03?o000K<ol000<0003oooooool0Aoooo`03o`2Ioooooooo04koool006Ooool2000073?o
00030000oooooooo04Ooool00ol0VOooooooo`1>oooo001Woooo00<0000co`0co`006S?o00030000
oooooooo04Soool00ol0VOooooooo`1>oooo001Woooo00<0000co`0co`006S?o00030000oooooooo
04Soool00ol0VOooooooo`1>oooo001Woooo00<0000co`0co`006C?o00030000oooooooo04Woool0
0ol0VOooooooo`1>oooo001Woooo00<0000co`0co`006C?o00030000oooooooo04Woool00ol0VOoo
ooooo`1>oooo001Woooo00<0000co`0co`0063?o00030000oooooooo04[oool00ol0VOooooooo`1>
oooo001Woooo0P0001Tco`000`000?ooooooo`1:oooo00?o09Woooooool0C_ooo`00Ioooo`030000
<ol0<ol001Lco`000`000?ooooooo`1;oooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol0
01Lco`000`000?ooooooo`1;oooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol001Hco`00
0`000?ooooooo`1<oooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1<oooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1<
oooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1=oooo00?o
09Woooooool0C_ooo`00Ioooo`80000F<ol000<0003oooooool0COooo`03o`2Ioooooooo04koool0
06Ooool00`0003?o03?o000E<ol000<0003oooooool0COooo`03o`2Ioooooooo04koool006Ooool0
0`0003?o03?o000E<ol000<0003oooooool0COooo`03o`2Ioooooooo04koool006Ooool00`0003?o
03?o000D<ol000<0003oooooool0C_ooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000D
<ol000<0003oooooool0C_ooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000D<ol000<0
003oooooool0C_ooo`03o`2Ioooooooo04koool006Ooool200005C?o00030000oooooooo04koool0
0ol0VOooooooo`1>oooo001Woooo00<0000co`0co`004c?o00030000oooooooo04ooool00ol0VOoo
ooooo`1>oooo001Woooo00<0000co`0co`004c?o00030000oooooooo04ooool00ol0VOooooooo`1>
oooo001Woooo00<0000co`0co`004c?o00030000oooooooo04ooool00ol0VOooooooo`1>oooo001O
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0Coooo`03o`2Ioooooooo04koool0
05ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo053oool00ol0VOoo
ooooo`1>oooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0D?ooo`03o`2I
oooooooo04koool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
053oool00ol0VOooooooo`1>oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo057oool00ol0VOooooooo`1>oooo001Poooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0DOooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000A<ol000<0
003oooooool0DOooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000A<ol000<0003ooooo
ool0DOooo`03o`2Ioooooooo04koool006Ooool200004C?o00030000oooooooo05;oool00ol0VOoo
ooooo`1>oooo001Woooo00<0000co`0co`0043?o00030000oooooooo05;oool00ol0VOooooooo`1>
oooo001Woooo00<0000co`0co`0043?o00030000oooooooo05;oool00ol0VOooooooo`1>oooo001W
oooo00<0000co`0co`0043?o00030000oooooooo05;oool00ol0VOooooooo`1>oooo001Woooo00<0
000co`0co`003c?o00030000oooooooo05?oool00ol0VOooooooo`1>oooo001Woooo00<0000co`0c
o`003c?o00030000oooooooo05?oool00ol0VOooooooo`1>oooo001Woooo00<0000co`0co`003c?o
00030000oooooooo05?oool00ol0VOooooooo`1>oooo001Woooo0P00010co`000`000?ooooooo`1C
oooo00?o09Woooooool0C_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Doooo00?o
09Woooooool0C_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Doooo00?o09Wooooo
ool0C_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Doooo00?o09Woooooool0C_oo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Doooo00?o09Woooooool0C_ooo`00Iooo
o`030000<ol0<ol000dco`000`000?ooooooo`1Eoooo00?o09Woooooool0C_ooo`00Ioooo`80000>
<ol000<0003oooooool0EOooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000=<ol000<0
003oooooool0EOooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000=<ol000<0003ooooo
ool0EOooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000<<ol000<0003oooooool0E_oo
o`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000<<ol000<0003oooooool0E_ooo`03o`2I
oooooooo04koool006Ooool00`0003?o03?o000<<ol000<0003oooooool0E_ooo`03o`2Ioooooooo
04koool006Ooool200003C?o00030000oooooooo05Koool00ol0VOooooooo`1>oooo001Woooo00<0
000co`0co`0033?o00030000oooooooo05Koool00ol0VOooooooo`1>oooo001Woooo00<0000co`0c
o`0033?o00030000oooooooo05Koool00ol0VOooooooo`1>oooo001Woooo00<0000co`0co`002c?o
00030000oooooooo05Ooool00ol0VOooooooo`1>oooo001Poooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0Eoooo`03o`2Ioooooooo04koool005ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0Eoooo`03o`2Ioooooooo04koool0067oool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`1Goooo00?o09Woooooool0C_ooo`00H_ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Eoooo`03o`2Ioooooooo04koool0
05ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Eoooo`03o`2I
oooooooo04koool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`1Hoooo00?o
09Woooooool0C_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1Hoooo00?o09Wooooo
ool0C_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1Hoooo00?o09Woooooool0C_oo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1Hoooo00?o09Woooooool0C_ooo`00Iooo
o`80000;<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o000:
<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o0009<ol000<0
003oooooool0FOooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o0009<ol000<0003oooooool0FOoo
o`03o`2Ioooooooo04koool006Ooool00`0003?o03?o0009<ol000<0003oooooool0FOooo`03o`2I
oooooooo04koool006Ooool200002S?o00030000oooooooo05Woool00ol0VOooooooo`1>oooo001W
oooo00<0000co`0co`002C?o00030000oooooooo05Woool00ol0VOooooooo`1>oooo001Woooo00<0
000co`0co`002C?o00030000oooooooo05Woool00ol0VOooooooo`1>oooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo05[oool00ol0VOooooooo`1>oooo001Woooo00<0000co`0co`0023?o
00030000oooooooo05[oool00ol0VOooooooo`1>oooo001Woooo00<0000co`0co`0023?o00030000
oooooooo05[oool00ol0VOooooooo`1>oooo001Woooo0P0000Tco`000`000?ooooooo`1Joooo00?o
09Woooooool0C_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Joooo00?o09Wooooo
ool0C_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Joooo00?o09Woooooool0C_oo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1Koooo00?o09Woooooool0C_ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1Koooo00?o09Woooooool0C_ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`1Koooo00?o09Woooooool0C_ooo`00Ioooo`800008<ol000<0
003oooooool0Foooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Foooo`03o`2Ioooooooo04koool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Fooo
o`03o`2Ioooooooo04koool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Foooo`03o`2I
oooooooo04koool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Foooo`03o`2Ioooooooo
04koool0067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`1Koooo00?o09Wooooo
ool0C_ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0Fooo
o`03o`2Ioooooooo04koool005ooool500000oooo`800008<ol000<0003oooooool0Foooo`03o`2I
oooooooo04koool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo0000
00Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`
oooo001Woooo2C?o00coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Ioooo`Tco`0;
oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001Woooo2C?o
00_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001?oo
o`800004oooo00<0003oooooool0Noooo`00Ioooo`Tco`0;oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07_oool006Ooool9<ol02_ooo`030000oooooooo00;oool00`000?oo
ooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`1joooo001W
oooo2C?o00_oool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool01@000?oooooooooo
o`00001moooo001Woooo2C?o00_oool01@000?ooooooooooo`00000Aoooo00<0003oooooool01ooo
o`040000oooooooo00000oooo`030000oooooooo07_oool006Ooool9<ol03?ooo`030000oooooooo
017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00Ioooo`Tco`2`oooo001Woooo23?o
0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75315 .12361 L
.75593 .12361 L
.75729 .12361 L
.75853 .12361 L
.7597 .12361 L
s
.7597 .12361 m
.76014 .61803 L
s
0 .4 1 r
.02381 .07445 m
.04262 .07021 L
.06244 .06685 L
.08255 .06445 L
.09396 .06347 L
.10458 .06279 L
.10961 .06253 L
.11508 .0623 L
.11989 .06213 L
.125 .062 L
.12959 .06191 L
.13221 .06187 L
.13466 .06184 L
.13581 .06183 L
.1369 .06182 L
.13789 .06182 L
.13895 .06181 L
.1401 .06181 L
.14116 .0618 L
.14243 .0618 L
.14357 .0618 L
.14477 .06181 L
.1459 .06181 L
.14713 .06182 L
.14845 .06183 L
.15114 .06185 L
.1536 .06188 L
.15833 .06195 L
.16282 .06205 L
.17279 .06232 L
.18364 .06273 L
.20341 .0637 L
.22442 .06502 L
.26217 .06792 L
.30238 .0715 L
.32085 .07324 L
.33132 .07425 L
.34106 .07519 L
.34605 .07563 L
.35075 .07597 L
.35618 .07627 L
.3611 .07647 L
.36366 .07655 L
.36637 .07662 L
.36868 .07666 L
.37 .07668 L
.37123 .07669 L
.37191 .0767 L
.37265 .07671 L
.3733 .07671 L
Mistroke
.37399 .07671 L
.3753 .07672 L
.37652 .07672 L
.37726 .07672 L
.37806 .07672 L
.37881 .07671 L
.3795 .07671 L
.38082 .0767 L
.3822 .07668 L
.38476 .07665 L
.38718 .0766 L
.39171 .07649 L
.39658 .07633 L
.40188 .07612 L
.42023 .07511 L
.44004 .0736 L
.46106 .07162 L
.49886 .06732 L
.53912 .06197 L
.57786 .0563 L
.61905 .04995 L
.65873 .04374 L
.69689 .03791 L
.71818 .03483 L
.7375 .03221 L
.74716 .03097 L
.75225 .03035 L
.75503 .03002 L
.75762 .02971 L
.75879 .02958 L
.7599 .02945 L
.76117 .12361 L
.76233 .12361 L
.7675 .12361 L
.7766 .12361 L
.8149 .12361 L
.85565 .12361 L
.89488 .12361 L
.9326 .12361 L
.97277 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Ooooo2@1Vodkoool0
06Ooool00`000?ooooooo`1Joooo1@1Vo`Soool00`1Vooooooooo`1<oooo001Woooo00<0003ooooo
ool0Doooo`L0I_l=oooo00<0I_ooooooool0C?ooo`00Ioooo`030000oooooooo04_oool806Ko5?oo
o`0306Kooooooooo04coool006Ooool00`000?ooooooo`16oooo1@1Voacoool00`1Vooooooooo`1<
oooo001Woooo0P00043oool706Ko8Oooo`0306Kooooooooo04coool006Ooool00`000?ooooooo`0g
oooo201VobSoool00`1Vooooooooo`1<oooo001Woooo00<0003oooooool0<_ooo`D0I_l`oooo00<0
I_ooooooool0C?ooo`008oooob@0I_lPoooo00<0003oooooool0:oooo`L0I_leoooo00<0I_oooooo
ool0C?ooo`007_ooo`D0I_lToooo4@1Vo`ooool00`000?ooooooo`0Qoooo2P1Voccoool00`1Voooo
ooooo`1<oooo000Ioooo1@1Voc[oool806Ko1oooo`030000oooooooo01Woool806KoA_ooo`0306Ko
oooooooo04coool001Koool306KoAoooo`L0I_l200001P1Vo`?ooolA06KoC_ooo`0306Kooooooooo
04coool001Ooool500007_ooo`800004oooo0P0000Coool200007oooo`030000oooooooo00Coool4
06Ko5_ooo`800004oooo0P0000Coool200007oooo`D0000Goooo00<0I_ooooooool00oooo`D00002
oooo0P0000Coool200008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00007_ooo`030000oooooooo01goool010000?ooooooo`0000Soool0
10000?ooooooo`00023oool00`000?ooooooo`0Goooo00<0I_ooooooool01Oooo`030000oooooooo
00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00002oooo`030000oooooooo01coool00`000?ooooooo`0Moooo00@0003ooooo
ool0000;oooo00<0003oooooool07_ooo`030000oooooooo01Ooool00`1Vooooooooo`05oooo00<0
003oooooool02_ooo`030000oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool0
0`000?ooooooo`0Goooo100000;oool010000?ooooooo`0000Woool200007oooo`030000oooooooo
01goool010000?ooooooo`0000Woool200008Oooo`030000oooooooo01Ooool00`1Vooooooooo`05
oooo00<0003oooooool02?ooo`80000Roooo00<0003oooooool05Oooo`006Oooo`030000oooooooo
01goool010000?ooooooo`0000Woool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000
oooooooo00002Oooo`030000oooooooo023oool00`000?ooooooo`0Goooo00<0I_ooooooool01Ooo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00
023oool200002_ooo`<0000Noooo0P0001ooool200002_ooo`<0000Ooooo0P0001Woool00`1Voooo
ooooo`04oooo0P0000[oool300008?ooo`80000Goooo001Woooo00<0003oooooool0Ioooo`0306Ko
oooooooo04coool006Ooool00`000?ooooooo`1Woooo00<0I_ooooooool0C?ooo`00Ioooo`030000
oooooooo06Ooool00`1Vooooooooo`1<oooo001Woooo00<0003oooooool0Ioooo`0306Kooooooooo
04coool006Ooool00`000?ooooooo`1Woooo00<0I_ooooooool0C?ooo`004?ooool0000Aoooo000F
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o00/00000
0ol0V@000000000J00000_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_oo
o`030000<ol0<ol002Dco`000`0003?o03?o000T<ol0400000_oool00ol0VOooooooo`0;oooo00<0
003oooooool09_ooo`030000oooooooo01Goool006Ooool00`0003?o03?o0017<ol01@0001_oool0
0ol0VOooooooo`1<oooo001Woooo00<0000co`0co`00@S?o00D0000Poooo00?o09Woooooool0C?oo
o`00Ioooo`030000<ol0<ol003dco`0500009Oooo`03o`2Ioooooooo04coool006Ooool00`0003?o
03?o000i<ol0100002[oool00ol0VOooooooo`1<oooo001Woooo0P0003Pco`020000;_ooo`03o`2I
oooooooo04coool006Ooool00`0003?o03?o000e<ol00P00033oool00ol0VOooooooo`1<oooo001W
oooo00<0000co`0co`00<c?o0080000boooo00?o09Woooooool0C?ooo`00Ioooo`030000<ol0<ol0
034co`020000=?ooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000`<ol000<0003ooooo
ool0=?ooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000^<ol00P0003Ooool00ol0VOoo
ooooo`1<oooo001Woooo0P0002dco`020000>Oooo`03o`2Ioooooooo04coool006Ooool00`0003?o
03?o000[<ol000<0003oooooool0>Oooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000Z
<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000Y<ol000<0
003oooooool0>oooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000X<ol000<0003ooooo
ool0??ooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000X<ol000<0003oooooool0??oo
o`03o`2Ioooooooo04coool006Ooool20000:3?o00030000oooooooo03goool00ol0VOooooooo`1<
oooo001Woooo00<0000co`0co`009S?o00030000oooooooo03koool00ol0VOooooooo`1<oooo001W
oooo00<0000co`0co`009C?o00030000oooooooo03ooool00ol0VOooooooo`1<oooo001Woooo00<0
000co`0co`0093?o00030000oooooooo043oool00ol0VOooooooo`1<oooo001Woooo00<0000co`0c
o`008c?o00030000oooooooo047oool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`008c?o
00030000oooooooo047oool00ol0VOooooooo`1<oooo001Woooo0P0002<co`000`000?ooooooo`12
oooo00?o09Woooooool0C?ooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`13oooo00?o
09Woooooool0C?ooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`14oooo00?o09Wooooo
ool0C?ooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`14oooo00?o09Woooooool0C?oo
o`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`15oooo00?o09Woooooool0C?ooo`00Gooo
o`D00003oooo00<0000co`0co`007c?o00030000oooooooo04Goool00ol0VOooooooo`1<oooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`16oooo00?o09Wooooo
ool0C?ooo`00HOooo`030000oooooooo00?oool200007c?o00030000oooooooo04Koool00ol0VOoo
ooooo`1<oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`17
oooo00?o09Woooooool0C?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo04coool0063oool200001Oooo`030000<ol0<ol001`co`00
0`000?ooooooo`18oooo00?o09Woooooool0C?ooo`00Ioooo`030000<ol0<ol001`co`000`000?oo
ooooo`18oooo00?o09Woooooool0C?ooo`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`19
oooo00?o09Woooooool0C?ooo`00Ioooo`80000L<ol000<0003oooooool0BOooo`03o`2Ioooooooo
04coool006Ooool00`0003?o03?o000J<ol000<0003oooooool0B_ooo`03o`2Ioooooooo04coool0
06Ooool00`0003?o03?o000J<ol000<0003oooooool0B_ooo`03o`2Ioooooooo04coool006Ooool0
0`0003?o03?o000I<ol000<0003oooooool0Boooo`03o`2Ioooooooo04coool006Ooool00`0003?o
03?o000I<ol000<0003oooooool0Boooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000H
<ol000<0003oooooool0C?ooo`03o`2Ioooooooo04coool006Ooool200006C?o00030000oooooooo
04coool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`005c?o00030000oooooooo04goool0
0ol0VOooooooo`1<oooo001Woooo00<0000co`0co`005c?o00030000oooooooo04goool00ol0VOoo
ooooo`1<oooo001Woooo00<0000co`0co`005S?o00030000oooooooo04koool00ol0VOooooooo`1<
oooo001Woooo00<0000co`0co`005S?o00030000oooooooo04koool00ol0VOooooooo`1<oooo001W
oooo00<0000co`0co`005S?o00030000oooooooo04koool00ol0VOooooooo`1<oooo001Woooo00<0
000co`0co`005C?o00030000oooooooo04ooool00ol0VOooooooo`1<oooo001Woooo0P0001Hco`00
0`000?ooooooo`1?oooo00?o09Woooooool0C?ooo`00Ioooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1?oooo00?o09Woooooool0C?ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1?
oooo00?o09Woooooool0C?ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1@oooo00?o
09Woooooool0C?ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1@oooo00?o09Wooooo
ool0C?ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1@oooo00?o09Woooooool0C?oo
o`00Ioooo`80000E<ol000<0003oooooool0D?ooo`03o`2Ioooooooo04coool006Ooool00`0003?o
03?o000C<ol000<0003oooooool0DOooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000C
<ol000<0003oooooool0DOooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000C<ol000<0
003oooooool0DOooo`03o`2Ioooooooo04coool005ooool400001?ooo`030000<ol0<ol001<co`00
0`000?ooooooo`1Aoooo00?o09Woooooool0C?ooo`00Goooo`030000oooooooo00Goool00`0003?o
03?o000B<ol000<0003oooooool0D_ooo`03o`2Ioooooooo04coool0063oool00`000?ooooooo`04
oooo0P0001<co`000`000?ooooooo`1Boooo00?o09Woooooool0C?ooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000B<ol000<0003oooooool0D_ooo`03o`2Ioooooooo04coool005ooool0
10000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool0Doooo`03o`2Ioooooooo
04coool0063oool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`1Coooo00?o09Wooooo
ool0C?ooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1Coooo00?o09Woooooool0C?oo
o`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1Coooo00?o09Woooooool0C?ooo`00Iooo
o`80000A<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000@
<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000@<ol000<0
003oooooool0E?ooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000@<ol000<0003ooooo
ool0E?ooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000?<ol000<0003oooooool0EOoo
o`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000?<ol000<0003oooooool0EOooo`03o`2I
oooooooo04coool006Ooool00`0003?o03?o000?<ol000<0003oooooool0EOooo`03o`2Ioooooooo
04coool006Ooool2000043?o00030000oooooooo05Goool00ol0VOooooooo`1<oooo001Woooo00<0
000co`0co`003S?o00030000oooooooo05Koool00ol0VOooooooo`1<oooo001Woooo00<0000co`0c
o`003S?o00030000oooooooo05Koool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`003S?o
00030000oooooooo05Koool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`003S?o00030000
oooooooo05Koool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`003C?o00030000oooooooo
05Ooool00ol0VOooooooo`1<oooo001Woooo0P0000hco`000`000?ooooooo`1Goooo00?o09Wooooo
ool0C?ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1Goooo00?o09Woooooool0C?oo
o`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1Goooo00?o09Woooooool0C?ooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`1Hoooo00?o09Woooooool0C?ooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`1Hoooo00?o09Woooooool0C?ooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`1Hoooo00?o09Woooooool0C?ooo`00Ioooo`80000=<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000<<ol000<0003oooooool0F?oo
o`03o`2Ioooooooo04coool006Ooool00`0003?o03?o000<<ol000<0003oooooool0F?ooo`03o`2I
oooooooo04coool006Ooool00`0003?o03?o000;<ol000<0003oooooool0FOooo`03o`2Ioooooooo
04coool0063oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`1Ioooo00?o09Wooooo
ool0C?ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1I
oooo00?o09Woooooool0C?ooo`00HOooo`030000oooooooo00?oool2000033?o00030000oooooooo
05Woool00ol0VOooooooo`1<oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`00
0`000?ooooooo`1Ioooo00?o09Woooooool0C?ooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol000/co`000`000?ooooooo`1Ioooo00?o09Woooooool0C?ooo`00H?ooo`800005oooo00<0
000co`0co`002S?o00030000oooooooo05[oool00ol0VOooooooo`1<oooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo05[oool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`002S?o
00030000oooooooo05[oool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`002S?o00030000
oooooooo05[oool00ol0VOooooooo`1<oooo001Woooo0P0000/co`000`000?ooooooo`1Joooo00?o
09Woooooool0C?ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1Joooo00?o09Wooooo
ool0C?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Koooo00?o09Woooooool0C?oo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Koooo00?o09Woooooool0C?ooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1Koooo00?o09Woooooool0C?ooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`1Koooo00?o09Woooooool0C?ooo`00Ioooo`80000:<ol000<0
003oooooool0Foooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0Foooo`03o`2Ioooooooo04coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Fooo
o`03o`2Ioooooooo04coool006Ooool00`0003?o03?o0008<ol000<0003oooooool0G?ooo`03o`2I
oooooooo04coool006Ooool00`0003?o03?o0008<ol000<0003oooooool0G?ooo`03o`2Ioooooooo
04coool006Ooool00`0003?o03?o0008<ol000<0003oooooool0G?ooo`03o`2Ioooooooo04coool0
06Ooool200002C?o00030000oooooooo05coool00ol0VOooooooo`1<oooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo05coool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`0023?o
00030000oooooooo05coool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`001c?o00030000
oooooooo05goool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`001c?o00030000oooooooo
05goool00ol0VOooooooo`1<oooo001Woooo00<0000co`0co`001c?o00030000oooooooo05goool0
0ol0VOooooooo`1<oooo001Woooo0P0000Pco`000`000?ooooooo`1Moooo00?o09Woooooool0C?oo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1Moooo00?o09Woooooool0C?ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1Moooo00?o09Woooooool0C?ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`1Moooo00?o09Woooooool0C?ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1Moooo00?o09Woooooool0C?ooo`00HOooo`<00003oooo00<0000co`0c
o`001c?o00030000oooooooo05goool00ol0VOooooooo`1<oooo001Roooo00<0003oooooool00_oo
o`030000<ol0<ol000Lco`000`000?ooooooo`1Moooo00?o09Woooooool0C?ooo`00Goooo`D00003
oooo0P0000Pco`000`000?ooooooo`1Moooo00?o09Woooooool0C?ooo`00Goooo`040000oooooooo
00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:
<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Oooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool500000_ooo`800004oooo0P0000?oool400000oooo`030000oooooooo
07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool00`000?ooooooo`04
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo00Coool00`000?oo
ooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo07Soool006Ooool9<ol02?oo
o`050000oooooooooooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Ooo
o`80000:oooo0P0000Coool200000oooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Iooo
o`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75315 .12361 L
.75853 .12361 L
.76324 .12361 L
.76453 .12361 L
.76525 .12361 L
.76592 .12361 L
s
.76592 .12361 m
.76644 .61803 L
s
0 .4 1 r
.02381 .07289 m
.04262 .06902 L
.06244 .06599 L
.07286 .06479 L
.08255 .06387 L
.0932 .06309 L
.09912 .06274 L
.10458 .06247 L
.10944 .06227 L
.1148 .0621 L
.12018 .06196 L
.12313 .06191 L
.12589 .06187 L
.12713 .06185 L
.12848 .06184 L
.12968 .06183 L
.13095 .06182 L
.13221 .06181 L
.13336 .06181 L
.13451 .0618 L
.13559 .0618 L
.13686 .0618 L
.1375 .0618 L
.1382 .06181 L
.13944 .06181 L
.1406 .06182 L
.14197 .06183 L
.14322 .06184 L
.14603 .06186 L
.15083 .06193 L
.15594 .06203 L
.16511 .06228 L
.17498 .06263 L
.18587 .06311 L
.22607 .06558 L
.26476 .06868 L
.3059 .07243 L
.32643 .07439 L
.33643 .07536 L
.34553 .0762 L
.35007 .07654 L
.355 .07683 L
.35966 .07705 L
.36395 .07719 L
.3663 .07725 L
.3685 .07729 L
.37092 .07733 L
.37227 .07734 L
.37351 .07735 L
.3748 .07736 L
Mistroke
.376 .07736 L
.37731 .07736 L
.37804 .07736 L
.3787 .07736 L
.37992 .07735 L
.38124 .07734 L
.38249 .07733 L
.38363 .07731 L
.38835 .07723 L
.39099 .07717 L
.3934 .0771 L
.4025 .07677 L
.41312 .07624 L
.42317 .07562 L
.46156 .07234 L
.50239 .06771 L
.54171 .0625 L
.57951 .05699 L
.61977 .05081 L
.65851 .04474 L
.6997 .03841 L
.72026 .03541 L
.73937 .03277 L
.74888 .03154 L
.75784 .03042 L
.7628 .02983 L
.76415 .02967 L
.7649 .02959 L
.76559 .0295 L
.76682 .12361 L
.76747 .12361 L
.76816 .12361 L
.77753 .12361 L
.81886 .12361 L
.85868 .12361 L
.89697 .12361 L
.93772 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Poooo2@1Vodgoool0
06Ooool00`000?ooooooo`1Koooo1@1Vo`Soool00`1Vooooooooo`1;oooo001Woooo00<0003ooooo
ool0Doooo`P0I_l=oooo00<0I_ooooooool0Boooo`00Ioooo`030000oooooooo04_oool806Ko5Ooo
o`0306Kooooooooo04_oool006Ooool00`000?ooooooo`16oooo1@1Voagoool00`1Vooooooooo`1;
oooo001Woooo0P0004;oool506Ko8_ooo`0306Kooooooooo04_oool006Ooool00`000?ooooooo`0l
oooo1@1VobOoool00`1Vooooooooo`1;oooo001Woooo00<0003oooooool0=Oooo`L0I_l/oooo00<0
I_ooooooool0Boooo`008_ooob<0I_lRoooo00<0003oooooool0;?ooo`T0I_lcoooo00<0I_oooooo
ool0Boooo`007_ooo`@0I_lSoooo501Vo`koool00`000?ooooooo`0Qoooo2`1Voccoool00`1Voooo
ooooo`1;oooo000Ioooo1@1Voc_oool806Ko1_ooo`030000oooooooo01Ooool:06KoAoooo`0306Ko
oooooooo04_oool001Koool306KoB?ooo`H0I_l2000000<0I_ooooooool03?ooo`T0I_mAoooo00<0
I_ooooooool0Boooo`005oooo`D0000Noooo0P0000Coool200001?ooo`80000Ooooo00<0003ooooo
ool03P1Voa3oool200001?ooo`800004oooo0P0001ooool500006Oooo`0406Kooooooooooooo1@00
00;oool200001?ooo`80000Poooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003ooooo
ool00008oooo00@0003oooooool0000Noooo00<0003oooooool07Oooo`040000oooooooo00002?oo
o`040000oooooooo00008?ooo`030000oooooooo01Woool00`1Vooooooooo`03oooo00<0003ooooo
ool01oooo`040000oooooooo00007oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0M
oooo00@0003oooooool0000;oooo00<0003oooooool07?ooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Noooo00<0003oooooool06Oooo`0306Kooooooooo00?oool0
0`000?ooooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo01Koool0017oool400001?oo
o`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003ooooo
ool07Oooo`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool06Oooo`0306Kooooooooo
00?oool00`000?ooooooo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003ooooo
ool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0
003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo01Woool00`1Vooooooooo`03
oooo00<0003oooooool02?ooo`030000oooooooo01ooool010000?ooooooo`0001Koool001Soool2
00008?ooo`80000:oooo0`0001koool200007oooo`80000:oooo0`0001ooool200006oooo`0306Ko
oooooooo00;oool200002_ooo`<0000Poooo0P0001Ooool006Ooool00`000?ooooooo`1Yoooo00<0
I_ooooooool0B_ooo`00Ioooo`030000oooooooo06Woool00`1Vooooooooo`1:oooo001Woooo00<0
003oooooool0JOooo`0306Kooooooooo04[oool006Ooool00`000?ooooooo`1Yoooo00<0I_oooooo
ool0B_ooo`00Ioooo`030000oooooooo06Woool00`1Vooooooooo`1:oooo000@ooooo`00017oool0
01Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol03000
0003o`2I0000000001T00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0V
oooo00<0000co`0co`009C?o00030000<ol0<ol002@co`0@00003?ooo`03o`2Ioooooooo00[oool0
0`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol004Lco`0500007?oo
o`03o`2Ioooooooo04_oool006Ooool00`0003?o03?o0012<ol01@00027oool00ol0VOooooooo`1;
oooo001Woooo00<0000co`0co`00?C?o00D0000Voooo00?o09Woooooool0Boooo`00Ioooo`030000
<ol0<ol003Tco`040000:oooo`03o`2Ioooooooo04_oool006Ooool20000>3?o0080000_oooo00?o
09Woooooool0Boooo`00Ioooo`030000<ol0<ol003Dco`020000<Oooo`03o`2Ioooooooo04_oool0
06Ooool00`0003?o03?o000c<ol00P0003?oool00ol0VOooooooo`1;oooo001Woooo00<0000co`0c
o`00<C?o0080000eoooo00?o09Woooooool0Boooo`00Ioooo`030000<ol0<ol0030co`000`000?oo
ooooo`0eoooo00?o09Woooooool0Boooo`00Ioooo`030000<ol0<ol002hco`020000>?ooo`03o`2I
oooooooo04_oool006Ooool20000;C?o0080000joooo00?o09Woooooool0Boooo`00Ioooo`030000
<ol0<ol002/co`000`000?ooooooo`0joooo00?o09Woooooool0Boooo`00Ioooo`030000<ol0<ol0
02Xco`000`000?ooooooo`0koooo00?o09Woooooool0Boooo`00Ioooo`030000<ol0<ol002Tco`00
0`000?ooooooo`0loooo00?o09Woooooool0Boooo`00Ioooo`030000<ol0<ol002Pco`000`000?oo
ooooo`0moooo00?o09Woooooool0Boooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0m
oooo00?o09Woooooool0Boooo`00Ioooo`80000X<ol000<0003oooooool0?_ooo`03o`2Ioooooooo
04_oool006Ooool00`0003?o03?o000V<ol000<0003oooooool0?oooo`03o`2Ioooooooo04_oool0
06Ooool00`0003?o03?o000U<ol000<0003oooooool0@?ooo`03o`2Ioooooooo04_oool006Ooool0
0`0003?o03?o000T<ol000<0003oooooool0@Oooo`03o`2Ioooooooo04_oool006Ooool00`0003?o
03?o000S<ol000<0003oooooool0@_ooo`03o`2Ioooooooo04_oool006Ooool00`0003?o03?o000S
<ol000<0003oooooool0@_ooo`03o`2Ioooooooo04_oool006Ooool200008c?o00030000oooooooo
04?oool00ol0VOooooooo`1;oooo001Woooo00<0000co`0co`008C?o00030000oooooooo04Coool0
0ol0VOooooooo`1;oooo001Woooo00<0000co`0co`0083?o00030000oooooooo04Goool00ol0VOoo
ooooo`1;oooo001Woooo00<0000co`0co`0083?o00030000oooooooo04Goool00ol0VOooooooo`1;
oooo001Woooo00<0000co`0co`007c?o00030000oooooooo04Koool00ol0VOooooooo`1;oooo001O
oooo1@0000?oool00`0003?o03?o000O<ol000<0003oooooool0A_ooo`03o`2Ioooooooo04_oool0
067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o00030000oooooooo04Ooool00ol0VOoo
ooooo`1;oooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0003oooooool0Aoooo`03o`2I
oooooooo04_oool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo
04Soool00ol0VOooooooo`1;oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`00
0`000?ooooooo`18oooo00?o09Woooooool0Boooo`00H?ooo`800005oooo00<0000co`0co`0073?o
00030000oooooooo04Woool00ol0VOooooooo`1;oooo001Woooo00<0000co`0co`0073?o00030000
oooooooo04Woool00ol0VOooooooo`1;oooo001Woooo00<0000co`0co`006c?o00030000oooooooo
04[oool00ol0VOooooooo`1;oooo001Woooo0P0001`co`000`000?ooooooo`1:oooo00?o09Wooooo
ool0Boooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`1;oooo00?o09Woooooool0Booo
o`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`1;oooo00?o09Woooooool0Boooo`00Iooo
o`030000<ol0<ol001Tco`000`000?ooooooo`1<oooo00?o09Woooooool0Boooo`00Ioooo`030000
<ol0<ol001Tco`000`000?ooooooo`1<oooo00?o09Woooooool0Boooo`00Ioooo`030000<ol0<ol0
01Pco`000`000?ooooooo`1=oooo00?o09Woooooool0Boooo`00Ioooo`80000I<ol000<0003ooooo
ool0COooo`03o`2Ioooooooo04_oool006Ooool00`0003?o03?o000G<ol000<0003oooooool0C_oo
o`03o`2Ioooooooo04_oool006Ooool00`0003?o03?o000G<ol000<0003oooooool0C_ooo`03o`2I
oooooooo04_oool006Ooool00`0003?o03?o000F<ol000<0003oooooool0Coooo`03o`2Ioooooooo
04_oool006Ooool00`0003?o03?o000F<ol000<0003oooooool0Coooo`03o`2Ioooooooo04_oool0
06Ooool00`0003?o03?o000F<ol000<0003oooooool0Coooo`03o`2Ioooooooo04_oool006Ooool0
0`0003?o03?o000E<ol000<0003oooooool0D?ooo`03o`2Ioooooooo04_oool006Ooool200005S?o
00030000oooooooo053oool00ol0VOooooooo`1;oooo001Woooo00<0000co`0co`005C?o00030000
oooooooo053oool00ol0VOooooooo`1;oooo001Woooo00<0000co`0co`005C?o00030000oooooooo
053oool00ol0VOooooooo`1;oooo001Woooo00<0000co`0co`0053?o00030000oooooooo057oool0
0ol0VOooooooo`1;oooo001Woooo00<0000co`0co`0053?o00030000oooooooo057oool00ol0VOoo
ooooo`1;oooo001Woooo00<0000co`0co`0053?o00030000oooooooo057oool00ol0VOooooooo`1;
oooo001Woooo0P0001Dco`000`000?ooooooo`1Aoooo00?o09Woooooool0Boooo`00Ioooo`030000
<ol0<ol001<co`000`000?ooooooo`1Boooo00?o09Woooooool0Boooo`00Ioooo`030000<ol0<ol0
01<co`000`000?ooooooo`1Boooo00?o09Woooooool0Boooo`00Ioooo`030000<ol0<ol001<co`00
0`000?ooooooo`1Boooo00?o09Woooooool0Boooo`00Goooo`@00004oooo00<0000co`0co`004c?o
00030000oooooooo05;oool00ol0VOooooooo`1;oooo001Ooooo00<0003oooooool01Oooo`030000
<ol0<ol0018co`000`000?ooooooo`1Coooo00?o09Woooooool0Boooo`00H?ooo`030000oooooooo
00Coool200004c?o00030000oooooooo05?oool00ol0VOooooooo`1;oooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol0018co`000`000?ooooooo`1Doooo00?o09Woooooool0B_ooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol0014co`000`000?ooooooo`1Eoooo00?o09Wooooo
ool0B_ooo`00H?ooo`800005oooo00<0000co`0co`004C?o00030000oooooooo05Goool00ol0VOoo
ooooo`1:oooo001Woooo00<0000co`0co`004C?o00030000oooooooo05Goool00ol0VOooooooo`1:
oooo001Woooo00<0000co`0co`004C?o00030000oooooooo05Goool00ol0VOooooooo`1:oooo001W
oooo0P00014co`000`000?ooooooo`1Foooo00?o09Woooooool0B_ooo`00Ioooo`030000<ol0<ol0
010co`000`000?ooooooo`1Foooo00?o09Woooooool0B_ooo`00Ioooo`030000<ol0<ol0010co`00
0`000?ooooooo`1Foooo00?o09Woooooool0B_ooo`00Ioooo`030000<ol0<ol0010co`000`000?oo
ooooo`1Foooo00?o09Woooooool0B_ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1G
oooo00?o09Woooooool0B_ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1Goooo00?o
09Woooooool0B_ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1Goooo00?o09Wooooo
ool0B_ooo`00Ioooo`80000@<ol000<0003oooooool0Eoooo`03o`2Ioooooooo04[oool006Ooool0
0`0003?o03?o000><ol000<0003oooooool0F?ooo`03o`2Ioooooooo04[oool006Ooool00`0003?o
03?o000><ol000<0003oooooool0F?ooo`03o`2Ioooooooo04[oool006Ooool00`0003?o03?o000>
<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04[oool006Ooool00`0003?o03?o000><ol000<0
003oooooool0F?ooo`03o`2Ioooooooo04[oool006Ooool00`0003?o03?o000=<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo04[oool006Ooool200003S?o00030000oooooooo05Woool00ol0VOoo
ooooo`1:oooo001Woooo00<0000co`0co`003C?o00030000oooooooo05Woool00ol0VOooooooo`1:
oooo001Woooo00<0000co`0co`003C?o00030000oooooooo05Woool00ol0VOooooooo`1:oooo001W
oooo00<0000co`0co`0033?o00030000oooooooo05[oool00ol0VOooooooo`1:oooo001Woooo00<0
000co`0co`0033?o00030000oooooooo05[oool00ol0VOooooooo`1:oooo001Woooo00<0000co`0c
o`0033?o00030000oooooooo05[oool00ol0VOooooooo`1:oooo001Woooo0P0000dco`000`000?oo
ooooo`1Joooo00?o09Woooooool0B_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1J
oooo00?o09Woooooool0B_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1Joooo00?o
09Woooooool0B_ooo`00Ioooo`030000<ol0<ol000/co`000`000?ooooooo`1Koooo00?o09Wooooo
ool0B_ooo`00H?ooo`800005oooo00<0000co`0co`002c?o00030000oooooooo05_oool00ol0VOoo
ooooo`1:oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo
05_oool00ol0VOooooooo`1:oooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0003ooooo
ool0Foooo`03o`2Ioooooooo04[oool006;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o
00030000oooooooo05_oool00ol0VOooooooo`1:oooo001Ooooo00@0003oooooool00004oooo00<0
000co`0co`002c?o00030000oooooooo05_oool00ol0VOooooooo`1:oooo001Poooo0P0000Goool0
0`0003?o03?o000:<ol000<0003oooooool0G?ooo`03o`2Ioooooooo04[oool006Ooool00`0003?o
03?o000:<ol000<0003oooooool0G?ooo`03o`2Ioooooooo04[oool006Ooool00`0003?o03?o000:
<ol000<0003oooooool0G?ooo`03o`2Ioooooooo04[oool006Ooool00`0003?o03?o000:<ol000<0
003oooooool0G?ooo`03o`2Ioooooooo04[oool006Ooool200002c?o00030000oooooooo05coool0
0ol0VOooooooo`1:oooo001Woooo00<0000co`0co`002S?o00030000oooooooo05coool00ol0VOoo
ooooo`1:oooo001Woooo00<0000co`0co`002C?o00030000oooooooo05goool00ol0VOooooooo`1:
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo05goool00ol0VOooooooo`1:oooo001W
oooo00<0000co`0co`002C?o00030000oooooooo05goool00ol0VOooooooo`1:oooo001Woooo00<0
000co`0co`002C?o00030000oooooooo05goool00ol0VOooooooo`1:oooo001Woooo0P0000Xco`00
0`000?ooooooo`1Moooo00?o09Woooooool0B_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1Moooo00?o09Woooooool0B_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1M
oooo00?o09Woooooool0B_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Noooo00?o
09Woooooool0B_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Noooo00?o09Wooooo
ool0B_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Noooo00?o09Woooooool0B_oo
o`00Ioooo`800009<ol000<0003oooooool0G_ooo`03o`2Ioooooooo04[oool006Ooool00`0003?o
03?o0008<ol000<0003oooooool0G_ooo`03o`2Ioooooooo04[oool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0G_ooo`03o`2Ioooooooo04[oool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0Goooo`03o`2Ioooooooo04[oool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Goooo`03o`2Ioooooooo04[oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Gooo
o`03o`2Ioooooooo04[oool006Ooool2000023?o00030000oooooooo05ooool00ol0VOooooooo`1:
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo05ooool00ol0VOooooooo`1:oooo001W
oooo00<0000co`0co`001c?o00030000oooooooo05ooool00ol0VOooooooo`1:oooo001Woooo00<0
000co`0co`001c?o00030000oooooooo05ooool00ol0VOooooooo`1:oooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo05ooool00ol0VOooooooo`1:oooo001Qoooo0`0000?oool00`0003?o
03?o0007<ol000<0003oooooool0Goooo`03o`2Ioooooooo04[oool006;oool00`000?ooooooo`02
oooo00<0000co`0co`001c?o00030000oooooooo05ooool00ol0VOooooooo`1:oooo001Ooooo1@00
00?oool2000023?o00030000oooooooo05ooool00ol0VOooooooo`1:oooo001Ooooo00@0003ooooo
ool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?oo
o`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool200001Oooo`<00002oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00001Oooo`050000oooooooo
oooo000007[oool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0
003oooooool02Oooo`040000oooooooooooo1@0000?oool00`000?ooooooo`1goooo001Woooo2C?o
00Soool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool010000?ooooooo`0000;oool0
1@000?ooooooooooo`00001joooo001Woooo2C?o00Soool01@000?ooooooooooo`00000Aoooo00<0
003oooooool01oooo`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1h
oooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000[oool200001Oooo`800002oooo00<0
003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75853 .12361 L
.76334 .12361 L
.76842 .12361 L
.77051 .12361 L
.77166 .12361 L
.77275 .12361 L
s
.77275 .12361 m
.77327 .61803 L
s
0 .4 1 r
.02381 .07146 m
.04262 .06794 L
.06244 .06523 L
.07286 .06417 L
.08255 .06338 L
.0932 .06271 L
.09916 .06243 L
.10458 .06222 L
.10941 .06207 L
.11454 .06195 L
.11891 .06188 L
.1214 .06185 L
.12373 .06182 L
.12501 .06182 L
.12569 .06181 L
.12641 .06181 L
.12773 .06181 L
.12896 .0618 L
.13025 .0618 L
.13146 .06181 L
.13256 .06181 L
.13374 .06181 L
.13504 .06182 L
.13647 .06183 L
.13935 .06186 L
.14202 .06189 L
.14451 .06193 L
.14952 .06203 L
.15496 .06217 L
.16486 .06249 L
.18342 .06331 L
.20319 .06445 L
.2242 .06591 L
.26195 .06899 L
.30215 .07267 L
.32063 .07444 L
.3311 .07545 L
.34084 .0764 L
.35053 .07719 L
.35595 .0775 L
.36088 .07772 L
.36359 .07781 L
.36609 .07787 L
.36883 .07793 L
.37021 .07795 L
.37174 .07797 L
.37307 .07798 L
.37429 .07799 L
.37496 .078 L
.37569 .078 L
Mistroke
.37639 .078 L
.37703 .078 L
.37829 .078 L
.37943 .078 L
.38074 .07799 L
.38198 .07798 L
.3844 .07795 L
.38665 .07792 L
.39177 .07781 L
.39676 .07766 L
.4021 .07746 L
.42058 .07649 L
.44186 .07491 L
.462 .07306 L
.50038 .06879 L
.54121 .06345 L
.58053 .05778 L
.61833 .052 L
.65859 .04569 L
.69733 .0397 L
.71702 .03677 L
.73852 .03373 L
.74847 .03239 L
.75909 .03103 L
.76425 .0304 L
.76678 .03009 L
.76911 .02982 L
.77123 .02957 L
.7723 .02945 L
.77347 .12361 L
.77465 .12361 L
.77592 .12361 L
.7782 .12361 L
.81953 .12361 L
.85934 .12361 L
.89764 .12361 L
.93839 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Soooo201Vod_oool0
06Ooool00`000?ooooooo`1Joooo2@1Vo`Ooool00`1Vooooooooo`19oooo001Woooo00<0003ooooo
ool0EOooo`D0I_l@oooo00<0I_ooooooool0BOooo`00Ioooo`030000oooooooo053oool506Ko5Ooo
o`0306Kooooooooo04Woool006Ooool00`000?ooooooo`19oooo1`1Voa[oool00`1Vooooooooo`19
oooo001Woooo0P0004;oool806Ko8Oooo`0306Kooooooooo04Woool006Ooool00`000?ooooooo`0l
oooo1@1VobWoool00`1Vooooooooo`19oooo001Woooo00<0003oooooool0=Oooo`L0I_l^oooo00<0
I_ooooooool0BOooo`008_ooobD0I_lPoooo00<0003oooooool0;Oooo`P0I_leoooo00<0I_oooooo
ool0BOooo`006Oooo`T0I_lUoooo1`1VoaWoool00`000?ooooooo`0Xoooo1@1Vocgoool00`1Voooo
ooooo`19oooo000Foooo0`1VocGooolA06Ko2?ooo`030000oooooooo027oool706Ko@_ooo`0306Ko
oooooooo04Woool005ooool806Ko0P00013ooolB06KoBOooo`0306Kooooooooo04Woool001Ooool5
00007_ooo`800004oooo0P0000Coool200007oooo`03000006Ko06Ko00l0I_l?oooo0P0000Coool2
00001?ooo`80000Ooooo1@0001[oool00`1Vooooooooo`0500000_ooo`800004oooo0P00023oool4
00005_ooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00
01koool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000Poooo00<0
003oooooool06_ooo`0306Kooooooooo00;oool00`000?ooooooo`07oooo00@0003oooooool0000O
oooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000_oool0
0`000?ooooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo
01koool00`000?ooooooo`0Joooo00<0I_ooooooool00_ooo`030000oooooooo00[oool00`000?oo
ooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool05oooo`@00002
oooo00@0003oooooool00009oooo0P0001ooool00`000?ooooooo`0Moooo00@0003oooooool00009
oooo0P00027oool00`000?ooooooo`0Joooo00<0I_ooooooool00_ooo`030000oooooooo00Soool2
00008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0003oooooool00009
oooo00<0003oooooool07_ooo`030000oooooooo01goool010000?ooooooo`0000Woool00`000?oo
ooooo`0Poooo00<0003oooooool06_ooo`0306Kooooooooo00;oool00`000?ooooooo`08oooo00<0
003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool300007_oo
o`80000Ooooo0P0000[oool300007oooo`80000Loooo00@0I_ooooooooooool200002_ooo`<0000P
oooo0P0001Ooool006Ooool00`000?ooooooo`1Zoooo00<0I_ooooooool0BOooo`00Ioooo`030000
oooooooo06[oool00`1Vooooooooo`19oooo001Woooo00<0003oooooool0J_ooo`0306Kooooooooo
04Woool006Ooool00`000?ooooooo`1Zoooo00<0I_ooooooool0BOooo`00Ioooo`030000oooooooo
06[oool00`1Vooooooooo`19oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0004<ol03P000003o`2I0000000001L00002oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o00030000
<ol0<ol002@co`0@00003_ooo`03o`2Ioooooooo00Soool00`000?ooooooo`0Voooo00<0003ooooo
ool05Oooo`00Ioooo`030000<ol0<ol004Lco`0500007_ooo`03o`2Ioooooooo04Woool006Ooool0
0`0003?o03?o0012<ol01@0002?oool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`00?C?o
00D0000Xoooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol003Tco`040000;Oooo`03o`2I
oooooooo04Woool006Ooool20000>3?o0080000aoooo00?o09Woooooool0BOooo`00Ioooo`030000
<ol0<ol003Dco`020000<oooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000c<ol00P00
03Goool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`00<C?o0080000goooo00?o09Wooooo
ool0BOooo`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`0goooo00?o09Woooooool0BOoo
o`00Ioooo`030000<ol0<ol002hco`020000>_ooo`03o`2Ioooooooo04Woool006Ooool20000;C?o
0080000loooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`0l
oooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`0moooo00?o
09Woooooool0BOooo`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`0noooo00?o09Wooooo
ool0BOooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0ooooo00?o09Woooooool0BOoo
o`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`0ooooo00?o09Woooooool0BOooo`00Iooo
o`80000X<ol000<0003oooooool0@?ooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000V
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000U<ol000<0
003oooooool0@_ooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000T<ol000<0003ooooo
ool0@oooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000S<ol000<0003oooooool0A?oo
o`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000S<ol000<0003oooooool0A?ooo`03o`2I
oooooooo04Woool006Ooool200008c?o00030000oooooooo04Goool00ol0VOooooooo`19oooo001W
oooo00<0000co`0co`008C?o00030000oooooooo04Koool00ol0VOooooooo`19oooo001Woooo00<0
000co`0co`0083?o00030000oooooooo04Ooool00ol0VOooooooo`19oooo001Woooo00<0000co`0c
o`0083?o00030000oooooooo04Ooool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`007c?o
00030000oooooooo04Soool00ol0VOooooooo`19oooo001Ooooo1@0000?oool00`0003?o03?o000O
<ol000<0003oooooool0B?ooo`03o`2Ioooooooo04Woool0067oool00`000?ooooooo`03oooo00<0
000co`0co`007S?o00030000oooooooo04Woool00ol0VOooooooo`19oooo001Qoooo00<0003ooooo
ool00oooo`80000O<ol000<0003oooooool0BOooo`03o`2Ioooooooo04Woool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo04[oool00ol0VOooooooo`19oooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`1:oooo00?o09Wooooo
ool0BOooo`00H?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo04_oool00ol0VOoo
ooooo`19oooo001Woooo00<0000co`0co`0073?o00030000oooooooo04_oool00ol0VOooooooo`19
oooo001Woooo00<0000co`0co`006c?o00030000oooooooo04coool00ol0VOooooooo`19oooo001W
oooo0P0001`co`000`000?ooooooo`1<oooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol0
01Xco`000`000?ooooooo`1=oooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol001Xco`00
0`000?ooooooo`1=oooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol001Tco`000`000?oo
ooooo`1>oooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`1>
oooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`1?oooo00?o
09Woooooool0BOooo`00Ioooo`80000I<ol000<0003oooooool0Coooo`03o`2Ioooooooo04Woool0
06Ooool00`0003?o03?o000G<ol000<0003oooooool0D?ooo`03o`2Ioooooooo04Woool006Ooool0
0`0003?o03?o000G<ol000<0003oooooool0D?ooo`03o`2Ioooooooo04Woool006Ooool00`0003?o
03?o000F<ol000<0003oooooool0DOooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000F
<ol000<0003oooooool0DOooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000F<ol000<0
003oooooool0DOooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000E<ol000<0003ooooo
ool0D_ooo`03o`2Ioooooooo04Woool006Ooool200005S?o00030000oooooooo05;oool00ol0VOoo
ooooo`19oooo001Woooo00<0000co`0co`005C?o00030000oooooooo05;oool00ol0VOooooooo`19
oooo001Woooo00<0000co`0co`005C?o00030000oooooooo05;oool00ol0VOooooooo`19oooo001W
oooo00<0000co`0co`0053?o00030000oooooooo05?oool00ol0VOooooooo`19oooo001Woooo00<0
000co`0co`0053?o00030000oooooooo05?oool00ol0VOooooooo`19oooo001Woooo00<0000co`0c
o`0053?o00030000oooooooo05?oool00ol0VOooooooo`19oooo001Woooo0P0001Dco`000`000?oo
ooooo`1Coooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1D
oooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1Doooo00?o
09Woooooool0BOooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1Doooo00?o09Wooooo
ool0BOooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo05Coool00ol0VOoo
ooooo`19oooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`1E
oooo00?o09Woooooool0BOooo`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo
05Goool00ol0VOooooooo`19oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`00
0`000?ooooooo`1Eoooo00?o09Woooooool0BOooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol0014co`000`000?ooooooo`1Foooo00?o09Woooooool0BOooo`00H?ooo`800005oooo00<0
000co`0co`004C?o00030000oooooooo05Koool00ol0VOooooooo`19oooo001Woooo00<0000co`0c
o`004C?o00030000oooooooo05Koool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`004C?o
00030000oooooooo05Koool00ol0VOooooooo`19oooo001Woooo0P00014co`000`000?ooooooo`1G
oooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1Goooo00?o
09Woooooool0BOooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1Goooo00?o09Wooooo
ool0BOooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1Goooo00?o09Woooooool0BOoo
o`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1Hoooo00?o09Woooooool0BOooo`00Iooo
o`030000<ol0<ol000lco`000`000?ooooooo`1Hoooo00?o09Woooooool0BOooo`00Ioooo`030000
<ol0<ol000lco`000`000?ooooooo`1Hoooo00?o09Woooooool0BOooo`00Ioooo`80000@<ol000<0
003oooooool0F?ooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000><ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0FOoo
o`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0FOooo`03o`2I
oooooooo04Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0FOooo`03o`2Ioooooooo
04Woool006Ooool00`0003?o03?o000=<ol000<0003oooooool0F_ooo`03o`2Ioooooooo04Woool0
06Ooool200003S?o00030000oooooooo05[oool00ol0VOooooooo`19oooo001Woooo00<0000co`0c
o`003C?o00030000oooooooo05[oool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`003C?o
00030000oooooooo05[oool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`0033?o00030000
oooooooo05_oool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`0033?o00030000oooooooo
05_oool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`0033?o00030000oooooooo05_oool0
0ol0VOooooooo`19oooo001Woooo0P0000dco`000`000?ooooooo`1Koooo00?o09Woooooool0BOoo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1Koooo00?o09Woooooool0BOooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`1Koooo00?o09Woooooool0BOooo`00Ioooo`030000
<ol0<ol000/co`000`000?ooooooo`1Loooo00?o09Woooooool0BOooo`00H?ooo`800005oooo00<0
000co`0co`002c?o00030000oooooooo05coool00ol0VOooooooo`19oooo001Ooooo00@0003ooooo
ool00004oooo00<0000co`0co`002c?o00030000oooooooo05coool00ol0VOooooooo`19oooo001Q
oooo00<0003oooooool00oooo`80000<<ol000<0003oooooool0G?ooo`03o`2Ioooooooo04Woool0
06;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo05coool00ol0VOoo
ooooo`19oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo
05coool00ol0VOooooooo`19oooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003ooooo
ool0GOooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000:<ol000<0003oooooool0GOoo
o`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o000:<ol000<0003oooooool0GOooo`03o`2I
oooooooo04Woool006Ooool00`0003?o03?o000:<ol000<0003oooooool0GOooo`03o`2Ioooooooo
04Woool006Ooool200002c?o00030000oooooooo05goool00ol0VOooooooo`19oooo001Woooo00<0
000co`0co`002S?o00030000oooooooo05goool00ol0VOooooooo`19oooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo05koool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`002C?o
00030000oooooooo05koool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`002C?o00030000
oooooooo05koool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`002C?o00030000oooooooo
05koool00ol0VOooooooo`19oooo001Woooo0P0000Xco`000`000?ooooooo`1Noooo00?o09Wooooo
ool0BOooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Noooo00?o09Woooooool0BOoo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Noooo00?o09Woooooool0BOooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`1Ooooo00?o09Woooooool0BOooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1Ooooo00?o09Woooooool0BOooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1Ooooo00?o09Woooooool0BOooo`00Ioooo`800009<ol000<0003ooooo
ool0Goooo`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Gooo
o`03o`2Ioooooooo04Woool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Goooo`03o`2I
oooooooo04Woool006Ooool00`0003?o03?o0007<ol000<0003oooooool0H?ooo`03o`2Ioooooooo
04Woool006Ooool00`0003?o03?o0007<ol000<0003oooooool0H?ooo`03o`2Ioooooooo04Woool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0H?ooo`03o`2Ioooooooo04Woool006Ooool2
000023?o00030000oooooooo063oool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`001c?o
00030000oooooooo063oool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`001c?o00030000
oooooooo063oool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`001c?o00030000oooooooo
063oool00ol0VOooooooo`19oooo001Woooo00<0000co`0co`001c?o00030000oooooooo063oool0
0ol0VOooooooo`19oooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0H?oo
o`03o`2Ioooooooo04Woool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000
oooooooo063oool00ol0VOooooooo`19oooo001Ooooo1@0000?oool2000023?o00030000oooooooo
063oool00ol0VOooooooo`19oooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool0
0`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool0
06Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
06Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
oooo0P0000Coool200000oooo`<00004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
06Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02Ooo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00Iooo
o`Tco`08oooo00<0003oooooool01@0000koool00`000?ooooooo`0:oooo00<0003oooooool00`00
00Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`00000Aoooo00<0
003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1h
oooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002oooo00<0
003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.76707 .12361 L
.77247 .12361 L
.77511 .12361 L
.77751 .12361 L
.77883 .12361 L
s
.77883 .12361 m
.77933 .61803 L
s
0 .4 1 r
.02381 .07016 m
.04262 .06697 L
.06244 .06455 L
.07286 .06363 L
.08255 .06296 L
.0932 .06241 L
.09916 .06219 L
.10458 .06203 L
.10941 .06193 L
.11185 .06189 L
.11454 .06185 L
.11682 .06183 L
.11811 .06182 L
.11928 .06181 L
.12037 .06181 L
.12156 .06181 L
.12268 .0618 L
.12373 .0618 L
.12503 .06181 L
.12577 .06181 L
.12644 .06181 L
.12769 .06182 L
.129 .06182 L
.13128 .06184 L
.13379 .06187 L
.13933 .06195 L
.14451 .06206 L
.15496 .06236 L
.16486 .06274 L
.18342 .06365 L
.22175 .0662 L
.26253 .0696 L
.3018 .07324 L
.33955 .07689 L
.34897 .07771 L
.35371 .07801 L
.35889 .07826 L
.36162 .07837 L
.36453 .07846 L
.36728 .07853 L
.36977 .07858 L
.37097 .07859 L
.37224 .07861 L
.37363 .07862 L
.37491 .07863 L
.3761 .07864 L
.37721 .07864 L
.37844 .07864 L
.37975 .07863 L
.38044 .07863 L
Mistroke
.38109 .07863 L
.3823 .07862 L
.3836 .07861 L
.38501 .07859 L
.38755 .07855 L
.38988 .0785 L
.39525 .07836 L
.40092 .07817 L
.41051 .07775 L
.42103 .07715 L
.44057 .07574 L
.4615 .07386 L
.50292 .0693 L
.54281 .06412 L
.5812 .05861 L
.62203 .05239 L
.66135 .04624 L
.69915 .04037 L
.73941 .03446 L
.75792 .03197 L
.7684 .03065 L
.77351 .03003 L
.77592 .02975 L
.77815 .02949 L
.77931 .02935 L
.78055 .12361 L
.78179 .12361 L
.78315 .12361 L
.78786 .12361 L
.79823 .12361 L
.81934 .12361 L
.85973 .12361 L
.89861 .12361 L
.93994 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Uoooo201VodWoool0
06Ooool00`000?ooooooo`1Moooo201Vo`Ooool00`1Vooooooooo`17oooo001Woooo00<0003ooooo
ool0EOooo`P0I_l?oooo00<0I_ooooooool0Aoooo`00Ioooo`030000oooooooo057oool406Ko5ooo
o`0306Kooooooooo04Ooool006Ooool00`000?ooooooo`1:oooo1`1Voa_oool00`1Vooooooooo`17
oooo001Woooo0P0004?oool806Ko8_ooo`0306Kooooooooo04Ooool006Ooool00`000?ooooooo`0m
oooo1@1Vob[oool00`1Vooooooooo`17oooo001Woooo00<0003oooooool0=_ooo`L0I_l_oooo00<0
I_ooooooool0Aoooo`007_ooobH0I_lSoooo00<0003oooooool0;_ooo`P0I_lfoooo00<0I_oooooo
ool0Aoooo`006Oooo`D0I_lVoooo2P1VoaWoool00`000?ooooooo`0Yoooo1@1Vockoool00`1Voooo
ooooo`17oooo000Foooo0`1VocGoool:06Ko3oooo`030000oooooooo027oool806Ko@oooo`0306Ko
oooooooo04Ooool005Soool:06Ko1Oooo`80000Eoooo3@1Vod_oool00`1Vooooooooo`17oooo000G
oooo1@0001koool200001?ooo`800004oooo0P0001[oool506Ko00<00000I_l0I_l0501Vo`[oool2
00001?ooo`800004oooo0P0001ooool500007?ooo`0306Ko0000000000<00002oooo0P0000Coool2
00008?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000
oooooooo00007_ooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00
023oool00`000?ooooooo`0Loooo00@0I_ooooooool00009oooo00@0003oooooool0000Ooooo00<0
003oooooool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?oo
ooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo01koool0
0`000?ooooooo`0Loooo00@0I_ooooooool0000<oooo00<0003oooooool07_ooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Ooo
o`80000Ooooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`80000Qoooo00<0003ooooo
ool07?ooo`0406Kooooooooo00002_ooo`80000Roooo00<0003oooooool05Oooo`006Oooo`030000
oooooooo01goool010000?ooooooo`0000Woool00`000?ooooooo`0Noooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`030000oooooooo023oool00`000?ooooooo`0Loooo00@0I_oooooo
ool0000:oooo00<0003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P00
00[oool300007_ooo`80000Ooooo0P0000[oool300007oooo`80000Noooo00@0I_ooool00000000:
oooo0`00023oool200005oooo`00Ioooo`030000oooooooo06coool00`1Vooooooooo`17oooo001W
oooo00<0003oooooool0K?ooo`0306Kooooooooo04Ooool006Ooool00`000?ooooooo`1/oooo00<0
I_ooooooool0Aoooo`00Ioooo`030000oooooooo06coool00`1Vooooooooo`17oooo001Woooo00<0
003oooooool0K?ooo`0306Kooooooooo04Ooool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0@000000?o09T0000000005@00
00;oool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo02Koool00`0003?o03?o000U
<ol000<0000co`0co`0093?o0100000@oooo00?o09Woooooool01_ooo`030000oooooooo02Koool0
0`000?ooooooo`0Eoooo001Woooo00<0000co`0co`00Ac?o00D0000Poooo00?o09Woooooool0Aooo
o`00Ioooo`030000<ol0<ol0048co`0500009Oooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o
03?o000m<ol01@0002[oool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`00>C?o00@0000_
oooo00?o09Woooooool0Aoooo`00Ioooo`80000h<ol00P0003?oool00ol0VOooooooo`17oooo001W
oooo00<0000co`0co`00=C?o0080000eoooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol0
03<co`020000=oooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o000a<ol00P0003Woool0
0ol0VOooooooo`17oooo001Woooo00<0000co`0co`00<3?o00030000oooooooo03Woool00ol0VOoo
ooooo`17oooo001Woooo00<0000co`0co`00;S?o0080000loooo00?o09Woooooool0Aoooo`00Iooo
o`80000]<ol00P0003koool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`00:c?o00030000
oooooooo03koool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`00:S?o00030000oooooooo
03ooool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`00:C?o00030000oooooooo043oool0
0ol0VOooooooo`17oooo001Woooo00<0000co`0co`00:3?o00030000oooooooo047oool00ol0VOoo
ooooo`17oooo001Woooo00<0000co`0co`00:3?o00030000oooooooo047oool00ol0VOooooooo`17
oooo001Woooo0P0002Pco`000`000?ooooooo`12oooo00?o09Woooooool0Aoooo`00Ioooo`030000
<ol0<ol002Hco`000`000?ooooooo`13oooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol0
02Dco`000`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol002@co`00
0`000?ooooooo`15oooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol002<co`000`000?oo
ooooo`16oooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`16
oooo00?o09Woooooool0Aoooo`00Ioooo`80000S<ol000<0003oooooool0Aoooo`03o`2Ioooooooo
04Ooool006Ooool00`0003?o03?o000Q<ol000<0003oooooool0B?ooo`03o`2Ioooooooo04Ooool0
06Ooool00`0003?o03?o000P<ol000<0003oooooool0BOooo`03o`2Ioooooooo04Ooool006Ooool0
0`0003?o03?o000P<ol000<0003oooooool0BOooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o
03?o000O<ol000<0003oooooool0B_ooo`03o`2Ioooooooo04Ooool005ooool500000oooo`030000
<ol0<ol001lco`000`000?ooooooo`1:oooo00?o09Woooooool0Aoooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000N<ol000<0003oooooool0Boooo`03o`2Ioooooooo04Ooool0067oool0
0`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`1;oooo00?o09Woooooool0Aoooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0C?ooo`03o`2Ioooooooo
04Ooool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo04coool0
0ol0VOooooooo`17oooo001Poooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0COoo
o`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o000L<ol000<0003oooooool0COooo`03o`2I
oooooooo04Ooool006Ooool00`0003?o03?o000K<ol000<0003oooooool0C_ooo`03o`2Ioooooooo
04Ooool006Ooool2000073?o00030000oooooooo04koool00ol0VOooooooo`17oooo001Woooo00<0
000co`0co`006S?o00030000oooooooo04ooool00ol0VOooooooo`17oooo001Woooo00<0000co`0c
o`006S?o00030000oooooooo04ooool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`006C?o
00030000oooooooo053oool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`006C?o00030000
oooooooo053oool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`0063?o00030000oooooooo
057oool00ol0VOooooooo`17oooo001Woooo0P0001Tco`000`000?ooooooo`1Aoooo00?o09Wooooo
ool0Aoooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1Boooo00?o09Woooooool0Aooo
o`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1Boooo00?o09Woooooool0Aoooo`00Iooo
o`030000<ol0<ol001Hco`000`000?ooooooo`1Coooo00?o09Woooooool0Aoooo`00Ioooo`030000
<ol0<ol001Hco`000`000?ooooooo`1Coooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol0
01Hco`000`000?ooooooo`1Coooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1Doooo00?o09Woooooool0Aoooo`00Ioooo`80000F<ol000<0003oooooool0E?oo
o`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o000E<ol000<0003oooooool0E?ooo`03o`2I
oooooooo04Ooool006Ooool00`0003?o03?o000E<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
04Ooool006Ooool00`0003?o03?o000D<ol000<0003oooooool0EOooo`03o`2Ioooooooo04Ooool0
06Ooool00`0003?o03?o000D<ol000<0003oooooool0EOooo`03o`2Ioooooooo04Ooool006Ooool0
0`0003?o03?o000D<ol000<0003oooooool0EOooo`03o`2Ioooooooo04Ooool006Ooool200005C?o
00030000oooooooo05Goool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`004c?o00030000
oooooooo05Koool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`004c?o00030000oooooooo
05Koool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`004c?o00030000oooooooo05Koool0
0ol0VOooooooo`17oooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0E_oo
o`03o`2Ioooooooo04Ooool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000
oooooooo05Ooool00ol0VOooooooo`17oooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0
003oooooool0Eoooo`03o`2Ioooooooo04Ooool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`004S?o00030000oooooooo05Ooool00ol0VOooooooo`17oooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`004C?o00030000oooooooo05Soool00ol0VOooooooo`17oooo001Poooo0P00
00Goool00`0003?o03?o000A<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04Ooool006Ooool0
0`0003?o03?o000A<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o
03?o000A<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04Ooool006Ooool200004C?o00030000
oooooooo05Woool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`0043?o00030000oooooooo
05Woool00ol0VOooooooo`17oooo001Woooo00<0000co`0co`0043?o00030000oooooooo05Woool0
0ol0VOooooooo`17oooo001Woooo00<0000co`0co`0043?o00030000oooooooo05Woool00ol0VOoo
ooooo`17oooo001Woooo00<0000co`0co`003c?o00030000oooooooo05[oool00ol0VOooooooo`17
oooo001Woooo00<0000co`0co`003c?o00030000oooooooo05[oool00ol0VOooooooo`17oooo001W
oooo00<0000co`0co`003c?o00030000oooooooo05[oool00ol0VOooooooo`17oooo001Woooo0P00
010co`000`000?ooooooo`1Joooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`1Koooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000hco`000`000?oo
ooooo`1Koooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1K
oooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Koooo00?o
09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1Loooo00?o09Wooooo
ool0Aoooo`00Ioooo`80000><ol000<0003oooooool0G?ooo`03o`2Ioooooooo04Ooool006Ooool0
0`0003?o03?o000=<ol000<0003oooooool0G?ooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o
03?o000=<ol000<0003oooooool0G?ooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o000<
<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o000<<ol000<0
003oooooool0GOooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool0GOooo`03o`2Ioooooooo04Ooool006Ooool200003C?o00030000oooooooo05goool00ol0VOoo
ooooo`17oooo001Woooo00<0000co`0co`0033?o00030000oooooooo05goool00ol0VOooooooo`17
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo05goool00ol0VOooooooo`17oooo001W
oooo00<0000co`0co`002c?o00030000oooooooo05koool00ol0VOooooooo`17oooo001Poooo0P00
00Goool00`0003?o03?o000;<ol000<0003oooooool0G_ooo`03o`2Ioooooooo04Ooool005ooool0
10000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0G_ooo`03o`2Ioooooooo
04Ooool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`1Noooo00?o09Wooooo
ool0Aoooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0G_oo
o`03o`2Ioooooooo04Ooool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0
003oooooool0G_ooo`03o`2Ioooooooo04Ooool0063oool200001Oooo`030000<ol0<ol000Xco`00
0`000?ooooooo`1Ooooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`1Ooooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1O
oooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1Ooooo00?o
09Woooooool0Aoooo`00Ioooo`80000;<ol000<0003oooooool0Goooo`03o`2Ioooooooo04Ooool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool0Goooo`03o`2Ioooooooo04Ooool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0H?ooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o
03?o0009<ol000<0003oooooool0H?ooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o0009
<ol000<0003oooooool0H?ooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o0009<ol000<0
003oooooool0H?ooo`03o`2Ioooooooo04Ooool006Ooool200002S?o00030000oooooooo063oool0
0ol0VOooooooo`17oooo001Woooo00<0000co`0co`002C?o00030000oooooooo063oool00ol0VOoo
ooooo`17oooo001Woooo00<0000co`0co`002C?o00030000oooooooo063oool00ol0VOooooooo`17
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo067oool00ol0VOooooooo`17oooo001W
oooo00<0000co`0co`0023?o00030000oooooooo067oool00ol0VOooooooo`17oooo001Woooo00<0
000co`0co`0023?o00030000oooooooo067oool00ol0VOooooooo`17oooo001Woooo0P0000Tco`00
0`000?ooooooo`1Qoooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`1Qoooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Q
oooo00?o09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1Roooo00?o
09Woooooool0Aoooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1Roooo00?o09Wooooo
ool0Aoooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1Roooo00?o09Woooooool0Aooo
o`00Ioooo`800008<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0H_ooo`03o`2Ioooooooo04Ooool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0H_ooo`03o`2Ioooooooo04Ooool0067oool300000oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Roooo00?o09Woooooool0Aoooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04Ooool005ooool500000oooo`800008<ol000<0
003oooooool0H_ooo`03o`2Ioooooooo04Ooool005ooool010000?ooooooo`0000Coool:<ol0[ooo
o`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9
<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06
oooo1@0000;oool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001Woooo2C?o
00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`09oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1g
oooo001Woooo2C?o00Soool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool010000?oo
ooooooooo`800004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool0
00004Oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000[oool200001?oo
o`800003oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.76707 .12361 L
.77751 .12361 L
.78008 .12361 L
.78283 .12361 L
.78364 .12361 L
.78441 .12361 L
.7851 .12361 L
s
.7851 .12361 m
.7854 .61803 L
s
0 .4 1 r
.02381 .06897 m
.03279 .06749 L
.04262 .0661 L
.06244 .06397 L
.07298 .06316 L
.07878 .06281 L
.08426 .06253 L
.08936 .06231 L
.0949 .06212 L
.09993 .06199 L
.10458 .0619 L
.10701 .06186 L
.10924 .06184 L
.11047 .06183 L
.11181 .06182 L
.11307 .06181 L
.11425 .06181 L
.11543 .0618 L
.11655 .0618 L
.11755 .0618 L
.11863 .06181 L
.11982 .06181 L
.12107 .06181 L
.12213 .06182 L
.12331 .06183 L
.126 .06185 L
.12845 .06188 L
.13397 .06197 L
.13909 .06209 L
.14393 .06222 L
.16384 .06297 L
.18226 .06394 L
.22153 .06668 L
.25928 .06988 L
.29948 .07363 L
.33817 .07738 L
.34319 .07786 L
.34855 .07829 L
.35352 .07862 L
.35821 .07886 L
.36074 .07896 L
.36349 .07906 L
.36577 .07912 L
.36828 .07918 L
.37107 .07923 L
.37259 .07925 L
.37402 .07926 L
.3747 .07926 L
.37535 .07927 L
.37657 .07927 L
Mistroke
.37788 .07928 L
.37862 .07928 L
.37931 .07927 L
.3806 .07927 L
.38125 .07927 L
.38196 .07926 L
.38322 .07925 L
.3844 .07924 L
.38706 .0792 L
.3899 .07915 L
.39512 .07902 L
.39987 .07887 L
.40944 .07847 L
.41849 .07799 L
.43844 .07663 L
.45687 .07505 L
.49619 .07092 L
.53399 .06619 L
.57425 .06056 L
.61299 .05476 L
.65418 .04834 L
.69386 .04214 L
.73202 .0364 L
.75331 .03341 L
.77263 .03089 L
.77733 .03032 L
.78229 .02973 L
.78354 .02958 L
.78489 .02943 L
.78566 .02934 L
.78636 .12361 L
.78707 .12361 L
.78774 .12361 L
.79275 .12361 L
.81173 .12361 L
.85002 .12361 L
.89077 .12361 L
.93001 .12361 L
.96773 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Xoooo1P1VodSoool0
06Ooool00`000?ooooooo`1Noooo2P1Vo`Goool00`1Vooooooooo`16oooo001Woooo00<0003ooooo
ool0FOooo`D0I_l?oooo00<0I_ooooooool0A_ooo`00Ioooo`030000oooooooo05;oool706Ko5?oo
o`0306Kooooooooo04Koool006Ooool00`000?ooooooo`1:oooo201Voa_oool00`1Vooooooooo`16
oooo001Woooo0P0004Koool506Ko8oooo`0306Kooooooooo04Koool006Ooool00`000?ooooooo`0n
oooo1`1VobSoool00`1Vooooooooo`16oooo001Woooo00<0003oooooool0=_ooo`P0I_l_oooo00<0
I_ooooooool0A_ooo`007_ooobD0I_lToooo00<0003oooooool0<Oooo`D0I_lgoooo00<0I_oooooo
ool0A_ooo`006?ooo`H0I_lUoooo2P1Voa[oool00`000?ooooooo`0Zoooo1`1Voccoool00`1Voooo
ooooo`16oooo000Foooo0P1VocGoool:06Ko4?ooo`030000oooooooo023oool:06Ko@oooo`0306Ko
oooooooo04Koool005Ooool:06Ko1_ooo`80000Doooo3@1Vodgoool00`1Vooooooooo`16oooo000G
oooo1@0001koool200001?ooo`800004oooo0P0001Woool606Ko00<00000I_l0I_l04`1Vo`_oool2
00001?ooo`800004oooo0P0001ooool500007Oooo`D00002oooo0P0000Coool200008?ooo`@0000F
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00007_oo
o`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00023oool00`000?oo
ooooo`0Noooo00<0I_l0003oool02?ooo`040000oooooooo00007oooo`030000oooooooo01Ooool0
01Woool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool07?ooo`030000
oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0Noooo00<0003oooooool07_oo
o`0306Ko0000oooo00_oool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004
oooo00<0003oooooool05oooo`@00002oooo00@0003oooooool00009oooo0P0001ooool00`000?oo
ooooo`0Moooo00@0003oooooool00009oooo0P00027oool00`000?ooooooo`0Noooo00<0I_l0003o
ool02Oooo`80000Roooo00<0003oooooool05Oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000Woool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Ooo
o`030000oooooooo023oool00`000?ooooooo`0Noooo00<0I_l0003oool02Oooo`030000oooooooo
01ooool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`0001koool200007ooo
o`80000:oooo0`0001ooool200008?ooo`80000:oooo0`00023oool200005oooo`00Ioooo`030000
oooooooo06koool00`1Vooooooooo`15oooo001Woooo00<0003oooooool0K_ooo`0306Kooooooooo
04Goool006Ooool00`000?ooooooo`1^oooo00<0I_ooooooool0AOooo`00Ioooo`030000oooooooo
06koool00`1Vooooooooo`15oooo001Woooo00<0003oooooool0K_ooo`0306Kooooooooo04Goool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_oo
o`030000<ol0<ol002Dco`000`0003?o03?o000T<ol04000017oool00ol0VOooooooo`05oooo00<0
003oooooool09_ooo`030000oooooooo01Goool006Ooool00`0003?o03?o0017<ol01@00027oool0
0ol0VOooooooo`16oooo001Woooo00<0000co`0co`00@S?o00D0000Voooo00?o09Woooooool0A_oo
o`00Ioooo`030000<ol0<ol003dco`050000:oooo`03o`2Ioooooooo04Koool006Ooool00`0003?o
03?o000i<ol01000033oool00ol0VOooooooo`16oooo001Woooo0P0003Pco`020000=?ooo`03o`2I
oooooooo04Koool006Ooool00`0003?o03?o000e<ol00P0003Koool00ol0VOooooooo`16oooo001W
oooo00<0000co`0co`00<c?o0080000hoooo00?o09Woooooool0A_ooo`00Ioooo`030000<ol0<ol0
034co`020000>_ooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000`<ol000<0003ooooo
ool0>_ooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000^<ol00P0003goool00ol0VOoo
ooooo`16oooo001Woooo0P0002dco`020000?oooo`03o`2Ioooooooo04Koool006Ooool00`0003?o
03?o000[<ol000<0003oooooool0?oooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000Z
<ol000<0003oooooool0@?ooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000Y<ol000<0
003oooooool0@Oooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000X<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000X<ol000<0003oooooool0@_oo
o`03o`2Ioooooooo04Koool006Ooool20000:3?o00030000oooooooo04?oool00ol0VOooooooo`16
oooo001Woooo00<0000co`0co`009S?o00030000oooooooo04Coool00ol0VOooooooo`16oooo001W
oooo00<0000co`0co`009C?o00030000oooooooo04Goool00ol0VOooooooo`16oooo001Woooo00<0
000co`0co`0093?o00030000oooooooo04Koool00ol0VOooooooo`16oooo001Woooo00<0000co`0c
o`008c?o00030000oooooooo04Ooool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`008c?o
00030000oooooooo04Ooool00ol0VOooooooo`16oooo001Woooo0P0002<co`000`000?ooooooo`18
oooo00?o09Woooooool0A_ooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`19oooo00?o
09Woooooool0A_ooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`1:oooo00?o09Wooooo
ool0A_ooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`1:oooo00?o09Woooooool0A_oo
o`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`1;oooo00?o09Woooooool0A_ooo`00Gooo
o`D00003oooo00<0000co`0co`007c?o00030000oooooooo04_oool00ol0VOooooooo`16oooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`1<oooo00?o09Wooooo
ool0A_ooo`00HOooo`030000oooooooo00?oool200007c?o00030000oooooooo04coool00ol0VOoo
ooooo`16oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`1=
oooo00?o09Woooooool0A_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0
003oooooool0COooo`03o`2Ioooooooo04Koool0063oool200001Oooo`030000<ol0<ol001`co`00
0`000?ooooooo`1>oooo00?o09Woooooool0A_ooo`00Ioooo`030000<ol0<ol001`co`000`000?oo
ooooo`1>oooo00?o09Woooooool0A_ooo`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`1?
oooo00?o09Woooooool0A_ooo`00Ioooo`80000L<ol000<0003oooooool0Coooo`03o`2Ioooooooo
04Koool006Ooool00`0003?o03?o000J<ol000<0003oooooool0D?ooo`03o`2Ioooooooo04Koool0
06Ooool00`0003?o03?o000J<ol000<0003oooooool0D?ooo`03o`2Ioooooooo04Koool006Ooool0
0`0003?o03?o000I<ol000<0003oooooool0DOooo`03o`2Ioooooooo04Koool006Ooool00`0003?o
03?o000I<ol000<0003oooooool0DOooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000H
<ol000<0003oooooool0D_ooo`03o`2Ioooooooo04Koool006Ooool200006C?o00030000oooooooo
05;oool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`005c?o00030000oooooooo05?oool0
0ol0VOooooooo`16oooo001Woooo00<0000co`0co`005c?o00030000oooooooo05?oool00ol0VOoo
ooooo`16oooo001Woooo00<0000co`0co`005S?o00030000oooooooo05Coool00ol0VOooooooo`16
oooo001Woooo00<0000co`0co`005S?o00030000oooooooo05Coool00ol0VOooooooo`16oooo001W
oooo00<0000co`0co`005S?o00030000oooooooo05Coool00ol0VOooooooo`16oooo001Woooo00<0
000co`0co`005C?o00030000oooooooo05Goool00ol0VOooooooo`16oooo001Woooo0P0001Hco`00
0`000?ooooooo`1Eoooo00?o09Woooooool0A_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1Eoooo00?o09Woooooool0A_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1E
oooo00?o09Woooooool0A_ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1Foooo00?o
09Woooooool0A_ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1Foooo00?o09Wooooo
ool0A_ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1Foooo00?o09Woooooool0A_oo
o`00Ioooo`80000E<ol000<0003oooooool0E_ooo`03o`2Ioooooooo04Koool006Ooool00`0003?o
03?o000C<ol000<0003oooooool0Eoooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000C
<ol000<0003oooooool0Eoooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000C<ol000<0
003oooooool0Eoooo`03o`2Ioooooooo04Koool005ooool400001?ooo`030000<ol0<ol001<co`00
0`000?ooooooo`1Goooo00?o09Woooooool0A_ooo`00Goooo`030000oooooooo00Goool00`0003?o
03?o000B<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04Koool0063oool00`000?ooooooo`04
oooo0P0001<co`000`000?ooooooo`1Hoooo00?o09Woooooool0A_ooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000B<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04Koool005ooool0
10000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool0FOooo`03o`2Ioooooooo
04Koool0063oool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`1Ioooo00?o09Wooooo
ool0A_ooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1Ioooo00?o09Woooooool0A_oo
o`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1Ioooo00?o09Woooooool0A_ooo`00Iooo
o`80000A<ol000<0003oooooool0F_ooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000@
<ol000<0003oooooool0F_ooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000@<ol000<0
003oooooool0F_ooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000@<ol000<0003ooooo
ool0F_ooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000?<ol000<0003oooooool0Fooo
o`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000?<ol000<0003oooooool0Foooo`03o`2I
oooooooo04Koool006Ooool00`0003?o03?o000?<ol000<0003oooooool0Foooo`03o`2Ioooooooo
04Koool006Ooool2000043?o00030000oooooooo05_oool00ol0VOooooooo`16oooo001Woooo00<0
000co`0co`003S?o00030000oooooooo05coool00ol0VOooooooo`16oooo001Woooo00<0000co`0c
o`003S?o00030000oooooooo05coool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`003S?o
00030000oooooooo05coool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`003S?o00030000
oooooooo05coool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`003C?o00030000oooooooo
05goool00ol0VOooooooo`16oooo001Woooo0P0000hco`000`000?ooooooo`1Moooo00?o09Wooooo
ool0A_ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1Moooo00?o09Woooooool0A_oo
o`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1Moooo00?o09Woooooool0A_ooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`1Noooo00?o09Woooooool0A_ooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`1Noooo00?o09Woooooool0A_ooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`1Noooo00?o09Woooooool0A_ooo`00Ioooo`80000=<ol000<0003ooooo
ool0G_ooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000<<ol000<0003oooooool0G_oo
o`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o000<<ol000<0003oooooool0G_ooo`03o`2I
oooooooo04Koool006Ooool00`0003?o03?o000;<ol000<0003oooooool0Goooo`03o`2Ioooooooo
04Koool0063oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`1Ooooo00?o09Wooooo
ool0A_ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1O
oooo00?o09Woooooool0A_ooo`00HOooo`030000oooooooo00?oool2000033?o00030000oooooooo
05ooool00ol0VOooooooo`16oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`00
0`000?ooooooo`1Ooooo00?o09Woooooool0A_ooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol000/co`000`000?ooooooo`1Ooooo00?o09Woooooool0A_ooo`00H?ooo`800005oooo00<0
000co`0co`002S?o00030000oooooooo063oool00ol0VOooooooo`16oooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo063oool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`002S?o
00030000oooooooo063oool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`002S?o00030000
oooooooo063oool00ol0VOooooooo`16oooo001Woooo0P0000/co`000`000?ooooooo`1Poooo00?o
09Woooooool0A_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1Poooo00?o09Wooooo
ool0A_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Qoooo00?o09Woooooool0A_oo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Qoooo00?o09Woooooool0A_ooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1Qoooo00?o09Woooooool0A_ooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`1Qoooo00?o09Woooooool0A_ooo`00Ioooo`80000:<ol000<0
003oooooool0HOooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0HOooo`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o0009<ol000<0003oooooool0HOoo
o`03o`2Ioooooooo04Koool006Ooool00`0003?o03?o0008<ol000<0003oooooool0H_ooo`03o`2I
oooooooo04Koool006Ooool00`0003?o03?o0008<ol000<0003oooooool0H_ooo`03o`2Ioooooooo
04Koool006Ooool00`0003?o03?o0008<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04Koool0
06Ooool200002C?o00030000oooooooo06;oool00ol0VOooooooo`16oooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo06;oool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`0023?o
00030000oooooooo06;oool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`001c?o00030000
oooooooo06?oool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`001c?o00030000oooooooo
06?oool00ol0VOooooooo`16oooo001Woooo00<0000co`0co`001c?o00030000oooooooo06?oool0
0ol0VOooooooo`16oooo001Woooo0P0000Pco`000`000?ooooooo`1Soooo00?o09Woooooool0A_oo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1Soooo00?o09Woooooool0A_ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1Soooo00?o09Woooooool0A_ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`1Soooo00?o09Woooooool0A_ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1Soooo00?o09Woooooool0A_ooo`00HOooo`<00003oooo00<0000co`0c
o`001c?o00030000oooooooo06?oool00ol0VOooooooo`16oooo001Roooo00<0003oooooool00_oo
o`030000<ol0<ol000Lco`000`000?ooooooo`1Soooo00?o09Woooooool0A_ooo`00Goooo`D00003
oooo0P0000Pco`000`000?ooooooo`1Soooo00?o09Woooooool0A_ooo`00Goooo`040000oooooooo
00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:
<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol03?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001Woooo2C?o00_oool00`000?ooooooo`08oooo00<0003ooooo
ool06Oooo`030000oooooooo07_oool006Ooool9<ol02oooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool500000_ooo`800005oooo0`0000;oool00`000?ooooooo`1koooo001W
oooo2C?o00_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Ooool00`000?ooooooo`0:oooo00D0003oooooooooool00000OOooo`00Ioooo`Tco`0:oooo00<0
003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo1@0000?oool00`000?oo
ooooo`1joooo001Woooo2C?o00_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001Woooo2C?o00_oool01@000?oooooooooo
o`00000Aoooo00<0003oooooool02?ooo`030000oooo000000?oool00`000?ooooooo`1koooo001W
oooo2C?o00coool00`000?ooooooo`0Aoooo0P0000_oool200000_ooo`030000oooooooo07coool0
06Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.77751 .12361 L
.78293 .12361 L
.7859 .12361 L
.78866 .12361 L
.78988 .12361 L
.79102 .12361 L
.79166 .12361 L
s
.79166 .12361 m
.79193 .61803 L
s
0 .4 1 r
.02381 .0679 m
.03279 .06656 L
.04262 .06532 L
.053 .06424 L
.06244 .06346 L
.07298 .06278 L
.07839 .0625 L
.08426 .06226 L
.08969 .06209 L
.0947 .06196 L
.0995 .06188 L
.10192 .06185 L
.1033 .06184 L
.10458 .06183 L
.10588 .06182 L
.10706 .06181 L
.10838 .06181 L
.1091 .0618 L
.10978 .0618 L
.11101 .0618 L
.11215 .06181 L
.1134 .06181 L
.11472 .06181 L
.11582 .06182 L
.117 .06183 L
.11914 .06185 L
.12167 .06188 L
.12399 .06191 L
.12912 .062 L
.13471 .06214 L
.14487 .06245 L
.16464 .06332 L
.18565 .06455 L
.2234 .06734 L
.2636 .07085 L
.30229 .07451 L
.32194 .07641 L
.33233 .07743 L
.34343 .0785 L
.34896 .07894 L
.35419 .07927 L
.35887 .07951 L
.36129 .0796 L
.36396 .07969 L
.36628 .07976 L
.36878 .07982 L
.37016 .07984 L
.37142 .07986 L
.37271 .07988 L
.37389 .07989 L
Mistroke
.37498 .0799 L
.37614 .07991 L
.37743 .07991 L
.37859 .07991 L
.3797 .07991 L
.38089 .07991 L
.38202 .0799 L
.38305 .07989 L
.38432 .07988 L
.38552 .07987 L
.38777 .07984 L
.39282 .07973 L
.39718 .07962 L
.40192 .07946 L
.41266 .07899 L
.42259 .07843 L
.46191 .07532 L
.49972 .07131 L
.53997 .06626 L
.57871 .06084 L
.6199 .05465 L
.65958 .04847 L
.69774 .0425 L
.73835 .03638 L
.75713 .03374 L
.77745 .03107 L
.78286 .0304 L
.78582 .03005 L
.78858 .02972 L
.78979 .02958 L
.79094 .02945 L
.79226 .12361 L
.79347 .12361 L
.79884 .12361 L
.819 .12361 L
.8573 .12361 L
.89805 .12361 L
.93728 .12361 L
.975 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Yoooo1`1VodKoool0
06Ooool00`000?ooooooo`1Ooooo2P1Vo`Koool00`1Vooooooooo`14oooo001Woooo00<0003ooooo
ool0F_ooo`D0I_l@oooo00<0I_ooooooool0A?ooo`00Ioooo`030000oooooooo05?oool706Ko5Ooo
o`0306Kooooooooo04Coool006Ooool00`000?ooooooo`1;oooo201Voacoool00`1Vooooooooo`14
oooo001Woooo0P0004Ooool506Ko9?ooo`0306Kooooooooo04Coool006Ooool00`000?ooooooo`0o
oooo1`1VobWoool00`1Vooooooooo`14oooo001Woooo00<0003oooooool0=oooo`P0I_l`oooo00<0
I_ooooooool0A?ooo`007OooobL0I_lSoooo00<0003oooooool0<_ooo`D0I_lhoooo00<0I_oooooo
ool0A?ooo`005_ooo`L0I_lWoooo2P1VoaWoool00`000?ooooooo`0[oooo1`1Vocgoool00`1Voooo
ooooo`14oooo001>oooo2P1Vo`ooool00`000?ooooooo`0Qoooo2P1VodCoool00`1Vooooooooo`14
oooo001Hoooo2`1Vo`Coool200006?ooo`X0I_m>oooo00<0I_ooooooool0A?ooo`005oooo`D0000N
oooo0P0000Coool200001?ooo`80000Koooo101Vo`03000006Ko06Ko01L0I_l7oooo0P0000Coool2
00001?ooo`80000Ooooo1@0001goool500000_ooo`800004oooo0P00023oool400005_ooo`006Ooo
o`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`0001koool00`000?oo
ooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000Poooo00<0003oooooool07ooo
o`030000oooooooo00Ooool010000?ooooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo01coool00`000?ooooooo`0M
oooo00@0003oooooool0000;oooo00<0003oooooool07_ooo`030000oooooooo01ooool00`000?oo
ooooo`0:oooo00<0003oooooool07_ooo`030000oooooooo01Koool0017oool400001?ooo`030000
oooooooo01Ooool400000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool07oooo`030000oooooooo00Soool2
00008_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0003oooooool00009
oooo00<0003oooooool07_ooo`030000oooooooo01goool010000?ooooooo`0000Woool00`000?oo
ooooo`0Poooo00<0003oooooool07oooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00@0
003oooooool0000Foooo000Hoooo0P00023oool200002_ooo`<0000Noooo0P0001ooool200002_oo
o`<0000Ooooo0P00023oool200002_ooo`<0000Poooo0P0001Ooool006Ooool00`000?ooooooo`1_
oooo00<0I_ooooooool0A?ooo`00Ioooo`030000oooooooo06ooool00`1Vooooooooo`14oooo001W
oooo00<0003oooooool0Koooo`0306Kooooooooo04Coool006Ooool00`000?ooooooo`1_oooo00<0
I_ooooooool0A?ooo`00Ioooo`030000oooooooo06ooool00`1Vooooooooo`14oooo000@ooooo`00
017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004
<ol04`000003o`2I0000000001800002oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0000co`0co`009C?o00030000<ol0<ol002@co`0@00004oooo`03o`2Ioooooooo
00?oool00`000?ooooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol004Lco`05
00008oooo`03o`2Ioooooooo04Coool006Ooool00`0003?o03?o0012<ol01@0002Soool00ol0VOoo
ooooo`14oooo001Woooo00<0000co`0co`00?C?o00D0000]oooo00?o09Woooooool0A?ooo`00Iooo
o`030000<ol0<ol003Tco`040000<_ooo`03o`2Ioooooooo04Coool006Ooool20000>3?o0080000f
oooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol003Dco`020000>?ooo`03o`2Ioooooooo
04Coool006Ooool00`0003?o03?o000c<ol00P0003[oool00ol0VOooooooo`14oooo001Woooo00<0
000co`0co`00<C?o0080000loooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol0030co`00
0`000?ooooooo`0loooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol002hco`020000?ooo
o`03o`2Ioooooooo04Coool006Ooool20000;C?o00800011oooo00?o09Woooooool0A?ooo`00Iooo
o`030000<ol0<ol002/co`000`000?ooooooo`11oooo00?o09Woooooool0A?ooo`00Ioooo`030000
<ol0<ol002Xco`000`000?ooooooo`12oooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol0
02Tco`000`000?ooooooo`13oooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol002Pco`00
0`000?ooooooo`14oooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol002Pco`000`000?oo
ooooo`14oooo00?o09Woooooool0A?ooo`00Ioooo`80000X<ol000<0003oooooool0AOooo`03o`2I
oooooooo04Coool006Ooool00`0003?o03?o000V<ol000<0003oooooool0A_ooo`03o`2Ioooooooo
04Coool006Ooool00`0003?o03?o000U<ol000<0003oooooool0Aoooo`03o`2Ioooooooo04Coool0
06Ooool00`0003?o03?o000T<ol000<0003oooooool0B?ooo`03o`2Ioooooooo04Coool006Ooool0
0`0003?o03?o000S<ol000<0003oooooool0BOooo`03o`2Ioooooooo04Coool006Ooool00`0003?o
03?o000S<ol000<0003oooooool0BOooo`03o`2Ioooooooo04Coool006Ooool200008c?o00030000
oooooooo04[oool00ol0VOooooooo`14oooo001Woooo00<0000co`0co`008C?o00030000oooooooo
04_oool00ol0VOooooooo`14oooo001Woooo00<0000co`0co`0083?o00030000oooooooo04coool0
0ol0VOooooooo`14oooo001Woooo00<0000co`0co`0083?o00030000oooooooo04coool00ol0VOoo
ooooo`14oooo001Woooo00<0000co`0co`007c?o00030000oooooooo04goool00ol0VOooooooo`14
oooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003oooooool0COooo`03o`2Ioooooooo
04Coool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o00030000oooooooo04koool0
0ol0VOooooooo`14oooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0003oooooool0C_oo
o`03o`2Ioooooooo04Coool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000
oooooooo04ooool00ol0VOooooooo`14oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`000`000?ooooooo`1?oooo00?o09Woooooool0A?ooo`00H?ooo`800005oooo00<0000co`0c
o`0073?o00030000oooooooo053oool00ol0VOooooooo`14oooo001Woooo00<0000co`0co`0073?o
00030000oooooooo053oool00ol0VOooooooo`14oooo001Woooo00<0000co`0co`006c?o00030000
oooooooo057oool00ol0VOooooooo`14oooo001Woooo0P0001`co`000`000?ooooooo`1Aoooo00?o
09Woooooool0A?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`1Boooo00?o09Wooooo
ool0A?ooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`1Boooo00?o09Woooooool0A?oo
o`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`1Coooo00?o09Woooooool0A?ooo`00Iooo
o`030000<ol0<ol001Tco`000`000?ooooooo`1Coooo00?o09Woooooool0A?ooo`00Ioooo`030000
<ol0<ol001Pco`000`000?ooooooo`1Doooo00?o09Woooooool0A?ooo`00Ioooo`80000I<ol000<0
003oooooool0E?ooo`03o`2Ioooooooo04Coool006Ooool00`0003?o03?o000G<ol000<0003ooooo
ool0EOooo`03o`2Ioooooooo04Coool006Ooool00`0003?o03?o000G<ol000<0003oooooool0EOoo
o`03o`2Ioooooooo04Coool006Ooool00`0003?o03?o000F<ol000<0003oooooool0E_ooo`03o`2I
oooooooo04Coool006Ooool00`0003?o03?o000F<ol000<0003oooooool0E_ooo`03o`2Ioooooooo
04Coool006Ooool00`0003?o03?o000F<ol000<0003oooooool0E_ooo`03o`2Ioooooooo04Coool0
06Ooool00`0003?o03?o000E<ol000<0003oooooool0Eoooo`03o`2Ioooooooo04Coool006Ooool2
00005S?o00030000oooooooo05Ooool00ol0VOooooooo`14oooo001Woooo00<0000co`0co`005C?o
00030000oooooooo05Ooool00ol0VOooooooo`14oooo001Woooo00<0000co`0co`005C?o00030000
oooooooo05Ooool00ol0VOooooooo`14oooo001Woooo00<0000co`0co`0053?o00030000oooooooo
05Soool00ol0VOooooooo`14oooo001Woooo00<0000co`0co`0053?o00030000oooooooo05Soool0
0ol0VOooooooo`14oooo001Woooo00<0000co`0co`0053?o00030000oooooooo05Soool00ol0VOoo
ooooo`14oooo001Woooo0P0001Dco`000`000?ooooooo`1Hoooo00?o09Woooooool0A?ooo`00Iooo
o`030000<ol0<ol001<co`000`000?ooooooo`1Ioooo00?o09Woooooool0A?ooo`00Ioooo`030000
<ol0<ol001<co`000`000?ooooooo`1Ioooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol0
01<co`000`000?ooooooo`1Ioooo00?o09Woooooool0A?ooo`00Goooo`@00004oooo00<0000co`0c
o`004c?o00030000oooooooo05Woool00ol0VOooooooo`14oooo001Ooooo00<0003oooooool01Ooo
o`030000<ol0<ol0018co`000`000?ooooooo`1Joooo00?o09Woooooool0A?ooo`00H?ooo`030000
oooooooo00Coool200004c?o00030000oooooooo05[oool00ol0VOooooooo`14oooo001Qoooo00<0
003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`1Joooo00?o09Woooooool0A?oo
o`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`000`000?ooooooo`1Koooo00?o
09Woooooool0A?ooo`00H?ooo`800005oooo00<0000co`0co`004C?o00030000oooooooo05_oool0
0ol0VOooooooo`14oooo001Woooo00<0000co`0co`004C?o00030000oooooooo05_oool00ol0VOoo
ooooo`14oooo001Woooo00<0000co`0co`004C?o00030000oooooooo05_oool00ol0VOooooooo`14
oooo001Woooo0P00014co`000`000?ooooooo`1Loooo00?o09Woooooool0A?ooo`00Ioooo`030000
<ol0<ol0010co`000`000?ooooooo`1Loooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol0
010co`000`000?ooooooo`1Loooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol0010co`00
0`000?ooooooo`1Loooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000lco`000`000?oo
ooooo`1Moooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1M
oooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1Moooo00?o
09Woooooool0A?ooo`00Ioooo`80000@<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Coool0
06Ooool00`0003?o03?o000><ol000<0003oooooool0G_ooo`03o`2Ioooooooo04Coool006Ooool0
0`0003?o03?o000><ol000<0003oooooool0G_ooo`03o`2Ioooooooo04Coool006Ooool00`0003?o
03?o000><ol000<0003oooooool0G_ooo`03o`2Ioooooooo04Coool006Ooool00`0003?o03?o000>
<ol000<0003oooooool0G_ooo`03o`2Ioooooooo04Coool006Ooool00`0003?o03?o000=<ol000<0
003oooooool0Goooo`03o`2Ioooooooo04Coool006Ooool200003S?o00030000oooooooo05ooool0
0ol0VOooooooo`14oooo001Woooo00<0000co`0co`003C?o00030000oooooooo05ooool00ol0VOoo
ooooo`14oooo001Woooo00<0000co`0co`003C?o00030000oooooooo05ooool00ol0VOooooooo`14
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo063oool00ol0VOooooooo`14oooo001W
oooo00<0000co`0co`0033?o00030000oooooooo063oool00ol0VOooooooo`14oooo001Woooo00<0
000co`0co`0033?o00030000oooooooo063oool00ol0VOooooooo`14oooo001Woooo0P0000dco`00
0`000?ooooooo`1Poooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`1Poooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1P
oooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000/co`000`000?ooooooo`1Qoooo00?o
09Woooooool0A?ooo`00H?ooo`800005oooo00<0000co`0co`002c?o00030000oooooooo067oool0
0ol0VOooooooo`14oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000
oooooooo067oool00ol0VOooooooo`14oooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0
003oooooool0HOooo`03o`2Ioooooooo04Coool006;oool00`000?ooooooo`02oooo00<0000co`0c
o`002c?o00030000oooooooo067oool00ol0VOooooooo`14oooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`002c?o00030000oooooooo067oool00ol0VOooooooo`14oooo001Poooo0P00
00Goool00`0003?o03?o000:<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04Coool006Ooool0
0`0003?o03?o000:<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04Coool006Ooool00`0003?o
03?o000:<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04Coool006Ooool00`0003?o03?o000:
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04Coool006Ooool200002c?o00030000oooooooo
06;oool00ol0VOooooooo`14oooo001Woooo00<0000co`0co`002S?o00030000oooooooo06;oool0
0ol0VOooooooo`14oooo001Woooo00<0000co`0co`002C?o00030000oooooooo06?oool00ol0VOoo
ooooo`14oooo001Woooo00<0000co`0co`002C?o00030000oooooooo06?oool00ol0VOooooooo`14
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo06?oool00ol0VOooooooo`14oooo001W
oooo00<0000co`0co`002C?o00030000oooooooo06?oool00ol0VOooooooo`14oooo001Woooo0P00
00Xco`000`000?ooooooo`1Soooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`1Soooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1Soooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1T
oooo00?o09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Toooo00?o
09Woooooool0A?ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Toooo00?o09Wooooo
ool0A?ooo`00Ioooo`800009<ol000<0003oooooool0I?ooo`03o`2Ioooooooo04Coool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0I?ooo`03o`2Ioooooooo04Coool006Ooool00`0003?o
03?o0008<ol000<0003oooooool0I?ooo`03o`2Ioooooooo04Coool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0IOooo`03o`2Ioooooooo04Coool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0IOooo`03o`2Ioooooooo04Coool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0IOooo`03o`2Ioooooooo04Coool006Ooool2000023?o00030000oooooooo06Goool00ol0VOoo
ooooo`14oooo001Woooo00<0000co`0co`001c?o00030000oooooooo06Goool00ol0VOooooooo`14
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo06Goool00ol0VOooooooo`14oooo001W
oooo00<0000co`0co`001c?o00030000oooooooo06Goool00ol0VOooooooo`14oooo001Woooo00<0
000co`0co`001c?o00030000oooooooo06Goool00ol0VOooooooo`14oooo001Qoooo0`0000?oool0
0`0003?o03?o0007<ol000<0003oooooool0IOooo`03o`2Ioooooooo04Coool006;oool00`000?oo
ooooo`02oooo00<0000co`0co`001c?o00030000oooooooo06Goool00ol0VOooooooo`14oooo001O
oooo1@0000?oool2000023?o00030000oooooooo06Goool00ol0VOooooooo`14oooo001Ooooo00@0
003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool2
00001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0
003oooooool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Goool3000000?oool0000000000P00
00?oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`0:oooo00@0003oooooool00006
oooo00<0003oooooool0N?ooo`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`07oooo1@0000;oool00`000?ooooooo`04oooo00<0003oooooool0Mooo
o`00Ioooo`Tco`08oooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo00@0003ooooo
ool00004oooo00<0003oooooool00_ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000
oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oool000000_ooo`040000oooooooo
00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo017oool200002ooo
o`800003oooo0P0000?oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.77751 .12361 L
.78293 .12361 L
.78866 .12361 L
.79355 .12361 L
.79489 .12361 L
.79633 .12361 L
.79703 .12361 L
.79769 .12361 L
s
.79769 .12361 m
.79818 .61803 L
s
0 .4 1 r
.02381 .06693 m
.03279 .06573 L
.04262 .06463 L
.053 .06369 L
.06244 .06302 L
.07298 .06246 L
.07878 .06223 L
.08426 .06206 L
.08672 .062 L
.08932 .06195 L
.09158 .0619 L
.094 .06187 L
.0966 .06184 L
.09777 .06183 L
.09904 .06182 L
.09981 .06182 L
.10052 .06181 L
.10126 .06181 L
.10193 .06181 L
.10321 .0618 L
.10392 .0618 L
.10458 .0618 L
.10574 .0618 L
.10699 .06181 L
.10816 .06181 L
.10923 .06182 L
.11186 .06184 L
.11434 .06186 L
.11928 .06194 L
.12466 .06204 L
.13425 .06231 L
.14313 .06263 L
.16179 .06351 L
.1824 .06475 L
.2226 .0678 L
.26129 .07122 L
.30243 .07514 L
.32295 .07713 L
.33296 .0781 L
.34205 .07899 L
.3466 .07938 L
.35153 .07973 L
.35579 .07998 L
.36048 .08019 L
.36545 .08036 L
.36817 .08043 L
.37072 .08048 L
.37194 .08049 L
.3731 .08051 L
.37415 .08052 L
Mistroke
.37527 .08053 L
.37648 .08054 L
.37761 .08054 L
.3783 .08054 L
.37895 .08054 L
.38016 .08054 L
.38133 .08054 L
.38258 .08053 L
.38376 .08052 L
.38483 .08051 L
.38746 .08048 L
.38995 .08044 L
.3949 .08033 L
.40028 .08017 L
.40989 .07979 L
.41876 .07934 L
.43747 .07812 L
.45808 .07642 L
.49834 .07227 L
.53708 .0675 L
.57827 .06182 L
.61794 .05592 L
.65611 .05 L
.69672 .04363 L
.73582 .03767 L
.75577 .03479 L
.77737 .03187 L
.7875 .0306 L
.79303 .02993 L
.79574 .02962 L
.79692 .02948 L
.79821 .02933 L
.79938 .12361 L
.80047 .12361 L
.80262 .12361 L
.80735 .12361 L
.8174 .12361 L
.85663 .12361 L
.89435 .12361 L
.93452 .12361 L
.97318 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo077oool00`1Vooooooooo`12oooo001Woooo00<0003ooooo
ool0JOooo`T0I_m4oooo001Woooo00<0003oooooool0I?ooo`D0I_l8oooo00<0I_ooooooool0@_oo
o`00Ioooo`030000oooooooo05goool706Ko3Oooo`0306Kooooooooo04;oool006Ooool00`000?oo
ooooo`1Eoooo201VoaCoool00`1Vooooooooo`12oooo001Woooo00<0003oooooool0D?ooo`D0I_lL
oooo00<0I_ooooooool0@_ooo`00Ioooo`80001:oooo1`1Vob7oool00`1Vooooooooo`12oooo001W
oooo00<0003oooooool0@Oooo`P0I_lXoooo00<0I_ooooooool0@_ooo`00Ioooo`030000oooooooo
03coool506Ko<?ooo`0306Kooooooooo04;oool001_ooolY06Ko8oooo`030000oooooooo03Coool8
06Ko=Oooo`0306Kooooooooo04;oool001Koool506Ko:Oooo`X0I_lIoooo00<0003oooooool0:_oo
o`X0I_lmoooo00<0I_ooooooool0@_ooo`00C_ooo`X0I_l?oooo00<0003oooooool08?ooo`X0I_m7
oooo00<0I_ooooooool0@_ooo`00F?ooo`P0I_l7oooo0P0001Woool806KoDOooo`0306Kooooooooo
04;oool001Ooool500007_ooo`800004oooo0P0000Coool200006?ooo`L0I_l00`00001Vo`1Vo`0H
06Ko1_ooo`800004oooo0P0000Coool200007oooo`D0000Moooo1@0000;oool200001?ooo`80000P
oooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003ooooo
ool0000Noooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo00008?oo
o`030000oooooooo01ooool00`000?ooo`1Vo`07oooo00@0003oooooool0000Ooooo00<0003ooooo
ool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0L
oooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo01koool00`000?oo
ooooo`0Ooooo00<0003oool0I_l02_ooo`030000oooooooo01koool00`000?ooooooo`0Foooo000A
oooo100000Coool00`000?ooooooo`0Goooo100000;oool010000?ooooooo`0000Woool200007ooo
o`030000oooooooo01goool010000?ooooooo`0000Woool200008Oooo`030000oooooooo01ooool0
0`000?ooo`1Vo`08oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003ooooo
ool00009oooo00<0003oooooool08?ooo`030000oooooooo01ooool00`000?ooo`1Vo`08oooo00<0
003oooooool07oooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool300007_oo
o`80000Ooooo0P0000[oool300007oooo`80000Poooo0P000003oooo06Kooooo00Ooool300008?oo
o`80000Goooo001Woooo00<0003oooooool0LOooo`0306Kooooooooo04;oool006Ooool00`000?oo
ooooo`1aoooo00<0I_ooooooool0@_ooo`00Ioooo`030000oooooooo077oool00`1Vooooooooo`12
oooo001Woooo00<0003oooooool0LOooo`0306Kooooooooo04;oool006Ooool00`000?ooooooo`1a
oooo00<0I_ooooooool0@_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`0013?o01@000000ol0V@000000000A00000_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o
03?o000T<ol0400001Coool00ol0VOooooooo`02oooo00<0003oooooool09_ooo`030000oooooooo
01Goool006Ooool00`0003?o03?o0017<ol01@0002Coool00ol0VOooooooo`13oooo001Woooo00<0
000co`0co`00@S?o00D0000Yoooo00?o09Woooooool0@oooo`00Ioooo`030000<ol0<ol003dco`05
0000;_ooo`03o`2Ioooooooo04?oool006Ooool00`0003?o03?o000i<ol0100003?oool00ol0VOoo
ooooo`13oooo001Woooo0P0003Pco`020000=oooo`03o`2Ioooooooo04?oool006Ooool00`0003?o
03?o000e<ol00P0003Woool00ol0VOooooooo`13oooo001Woooo00<0000co`0co`00<c?o0080000k
oooo00?o09Woooooool0@oooo`00Ioooo`030000<ol0<ol0034co`020000?Oooo`03o`2Ioooooooo
04?oool006Ooool00`0003?o03?o000`<ol000<0003oooooool0?Oooo`03o`2Ioooooooo04?oool0
06Ooool00`0003?o03?o000^<ol00P00043oool00ol0VOooooooo`13oooo001Woooo0P0002dco`02
0000@_ooo`03o`2Ioooooooo04?oool006Ooool00`0003?o03?o000[<ol000<0003oooooool0@_oo
o`03o`2Ioooooooo04?oool006Ooool00`0003?o03?o000Z<ol000<0003oooooool0@oooo`03o`2I
oooooooo04?oool006Ooool00`0003?o03?o000Y<ol000<0003oooooool0A?ooo`03o`2Ioooooooo
04?oool006Ooool00`0003?o03?o000X<ol000<0003oooooool0AOooo`03o`2Ioooooooo04?oool0
06Ooool00`0003?o03?o000X<ol000<0003oooooool0AOooo`03o`2Ioooooooo04?oool006Ooool2
0000:3?o00030000oooooooo04Koool00ol0VOooooooo`13oooo001Woooo00<0000co`0co`009S?o
00030000oooooooo04Ooool00ol0VOooooooo`13oooo001Woooo00<0000co`0co`009C?o00030000
oooooooo04Soool00ol0VOooooooo`13oooo001Woooo00<0000co`0co`0093?o00030000oooooooo
04Woool00ol0VOooooooo`13oooo001Woooo00<0000co`0co`008c?o00030000oooooooo04[oool0
0ol0VOooooooo`13oooo001Woooo00<0000co`0co`008c?o00030000oooooooo04[oool00ol0VOoo
ooooo`13oooo001Woooo0P0002<co`000`000?ooooooo`1;oooo00?o09Woooooool0@oooo`00Iooo
o`030000<ol0<ol0024co`000`000?ooooooo`1<oooo00?o09Woooooool0@oooo`00Ioooo`030000
<ol0<ol0020co`000`000?ooooooo`1=oooo00?o09Woooooool0@oooo`00Ioooo`030000<ol0<ol0
020co`000`000?ooooooo`1=oooo00?o09Woooooool0@oooo`00Ioooo`030000<ol0<ol001lco`00
0`000?ooooooo`1>oooo00?o09Woooooool0@oooo`00Goooo`D00003oooo00<0000co`0co`007c?o
00030000oooooooo04koool00ol0VOooooooo`13oooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001hco`000`000?ooooooo`1?oooo00?o09Woooooool0@oooo`00HOooo`030000oooooooo
00?oool200007c?o00030000oooooooo04ooool00ol0VOooooooo`13oooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001dco`000`000?ooooooo`1@oooo00?o09Woooooool0@oooo`00HOoo
o`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0D?ooo`03o`2Ioooooooo
04?oool0063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`1Aoooo00?o09Wooooo
ool0@oooo`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`1Aoooo00?o09Woooooool0@ooo
o`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`1Boooo00?o09Woooooool0@oooo`00Iooo
o`80000L<ol000<0003oooooool0D_ooo`03o`2Ioooooooo04?oool006Ooool00`0003?o03?o000J
<ol000<0003oooooool0Doooo`03o`2Ioooooooo04?oool006Ooool00`0003?o03?o000J<ol000<0
003oooooool0Doooo`03o`2Ioooooooo04?oool006Ooool00`0003?o03?o000I<ol000<0003ooooo
ool0E?ooo`03o`2Ioooooooo04?oool006Ooool00`0003?o03?o000I<ol000<0003oooooool0E?oo
o`03o`2Ioooooooo04?oool006Ooool00`0003?o03?o000H<ol000<0003oooooool0EOooo`03o`2I
oooooooo04?oool006Ooool200006C?o00030000oooooooo05Goool00ol0VOooooooo`13oooo001W
oooo00<0000co`0co`005c?o00030000oooooooo05Koool00ol0VOooooooo`13oooo001Woooo00<0
000co`0co`005c?o00030000oooooooo05Koool00ol0VOooooooo`13oooo001Woooo00<0000co`0c
o`005S?o00030000oooooooo05Ooool00ol0VOooooooo`13oooo001Woooo00<0000co`0co`005S?o
00030000oooooooo05Ooool00ol0VOooooooo`13oooo001Woooo00<0000co`0co`005S?o00030000
oooooooo05Ooool00ol0VOooooooo`13oooo001Woooo00<0000co`0co`005C?o00030000oooooooo
05Soool00ol0VOooooooo`13oooo001Woooo0P0001Hco`000`000?ooooooo`1Hoooo00?o09Wooooo
ool0@oooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1Hoooo00?o09Woooooool0@ooo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1Hoooo00?o09Woooooool0@oooo`00Iooo
o`030000<ol0<ol001@co`000`000?ooooooo`1Ioooo00?o09Woooooool0@oooo`00Ioooo`030000
<ol0<ol001@co`000`000?ooooooo`1Ioooo00?o09Woooooool0@oooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`1Ioooo00?o09Woooooool0@oooo`00Ioooo`80000E<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo04?oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0F_oo
o`03o`2Ioooooooo04?oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0F_ooo`03o`2I
oooooooo04?oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0F_ooo`03o`2Ioooooooo
04?oool005ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`1Joooo00?o09Wooooo
ool0@oooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0Fooo
o`03o`2Ioooooooo04?oool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`1K
oooo00?o09Woooooool0@oooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0
003oooooool0G?ooo`03o`2Ioooooooo04;oool005ooool010000?ooooooo`0000Coool00`0003?o
03?o000A<ol000<0003oooooool0GOooo`03o`2Ioooooooo04;oool0063oool200001Oooo`030000
<ol0<ol0014co`000`000?ooooooo`1Moooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol0
014co`000`000?ooooooo`1Moooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol0014co`00
0`000?ooooooo`1Moooo00?o09Woooooool0@_ooo`00Ioooo`80000A<ol000<0003oooooool0G_oo
o`03o`2Ioooooooo04;oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0G_ooo`03o`2I
oooooooo04;oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0G_ooo`03o`2Ioooooooo
04;oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0G_ooo`03o`2Ioooooooo04;oool0
06Ooool00`0003?o03?o000?<ol000<0003oooooool0Goooo`03o`2Ioooooooo04;oool006Ooool0
0`0003?o03?o000?<ol000<0003oooooool0Goooo`03o`2Ioooooooo04;oool006Ooool00`0003?o
03?o000?<ol000<0003oooooool0Goooo`03o`2Ioooooooo04;oool006Ooool2000043?o00030000
oooooooo05ooool00ol0VOooooooo`12oooo001Woooo00<0000co`0co`003S?o00030000oooooooo
063oool00ol0VOooooooo`12oooo001Woooo00<0000co`0co`003S?o00030000oooooooo063oool0
0ol0VOooooooo`12oooo001Woooo00<0000co`0co`003S?o00030000oooooooo063oool00ol0VOoo
ooooo`12oooo001Woooo00<0000co`0co`003S?o00030000oooooooo063oool00ol0VOooooooo`12
oooo001Woooo00<0000co`0co`003C?o00030000oooooooo067oool00ol0VOooooooo`12oooo001W
oooo0P0000hco`000`000?ooooooo`1Qoooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol0
00dco`000`000?ooooooo`1Qoooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`1Qoooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`1Roooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1R
oooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1Roooo00?o
09Woooooool0@_ooo`00Ioooo`80000=<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04;oool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04;oool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0H_ooo`03o`2Ioooooooo04;oool006Ooool00`0003?o
03?o000;<ol000<0003oooooool0Hoooo`03o`2Ioooooooo04;oool0063oool200001Oooo`030000
<ol0<ol000/co`000`000?ooooooo`1Soooo00?o09Woooooool0@_ooo`00Goooo`040000oooooooo
00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1Soooo00?o09Woooooool0@_ooo`00HOoo
o`030000oooooooo00?oool2000033?o00030000oooooooo06?oool00ol0VOooooooo`12oooo001R
oooo00<0003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`1Soooo00?o09Wooooo
ool0@_ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1S
oooo00?o09Woooooool0@_ooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo
06Coool00ol0VOooooooo`12oooo001Woooo00<0000co`0co`002S?o00030000oooooooo06Coool0
0ol0VOooooooo`12oooo001Woooo00<0000co`0co`002S?o00030000oooooooo06Coool00ol0VOoo
ooooo`12oooo001Woooo00<0000co`0co`002S?o00030000oooooooo06Coool00ol0VOooooooo`12
oooo001Woooo0P0000/co`000`000?ooooooo`1Toooo00?o09Woooooool0@_ooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`1Toooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1Uoooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`1Uoooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1Uoooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1U
oooo00?o09Woooooool0@_ooo`00Ioooo`80000:<ol000<0003oooooool0IOooo`03o`2Ioooooooo
04;oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0IOooo`03o`2Ioooooooo04;oool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0IOooo`03o`2Ioooooooo04;oool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0I_ooo`03o`2Ioooooooo04;oool006Ooool00`0003?o
03?o0008<ol000<0003oooooool0I_ooo`03o`2Ioooooooo04;oool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0I_ooo`03o`2Ioooooooo04;oool006Ooool200002C?o00030000oooooooo
06Koool00ol0VOooooooo`12oooo001Woooo00<0000co`0co`0023?o00030000oooooooo06Koool0
0ol0VOooooooo`12oooo001Woooo00<0000co`0co`0023?o00030000oooooooo06Koool00ol0VOoo
ooooo`12oooo001Woooo00<0000co`0co`001c?o00030000oooooooo06Ooool00ol0VOooooooo`12
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo06Ooool00ol0VOooooooo`12oooo001W
oooo00<0000co`0co`001c?o00030000oooooooo06Ooool00ol0VOooooooo`12oooo001Woooo0P00
00Pco`000`000?ooooooo`1Woooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1Woooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Woooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1W
oooo00?o09Woooooool0@_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1Woooo00?o
09Woooooool0@_ooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo06Ooool0
0ol0VOooooooo`12oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Woooo00?o09Woooooool0@_ooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`1W
oooo00?o09Woooooool0@_ooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0
003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001W
oooo2C?o0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001W
oooo2C?o00Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
06Ooool9<ol02?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_oo
o`800005oooo0`0000?oool300000_ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo
00[oool00`000?ooooooo`03oooo00D0003oooooooooool00000N_ooo`00Ioooo`Tco`07oooo00<0
003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo1@000003oooo00000000
00<00003oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000koool0
0`000?ooooooo`07oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000004Oooo`030000oooooooo00Soool0
0`000?ooo`000003oooo00<0003oool000000oooo`030000oooooooo07Soool006Ooool9<ol02Ooo
o`030000oooooooo017oool200002oooo`800004oooo0P0000;oool00`000?ooooooo`1ioooo001W
oooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79321 .12361 L
.79892 .12361 L
.80134 .12361 L
.80267 .12361 L
.80393 .12361 L
.80464 .12361 L
s
.80464 .12361 m
.80495 .61803 L
s
0 .4 1 r
.02381 .06606 m
.03279 .065 L
.04262 .06403 L
.053 .06322 L
.06244 .06266 L
.0675 .06242 L
.07298 .06221 L
.07878 .06204 L
.08139 .06198 L
.08426 .06192 L
.08673 .06188 L
.08939 .06185 L
.09085 .06183 L
.09219 .06182 L
.09354 .06181 L
.09482 .06181 L
.096 .06181 L
.09724 .0618 L
.09842 .0618 L
.09949 .06181 L
.10075 .06181 L
.10146 .06181 L
.10211 .06181 L
.10338 .06182 L
.10458 .06183 L
.10704 .06185 L
.10928 .06188 L
.11432 .06196 L
.11867 .06205 L
.1234 .06217 L
.13414 .06253 L
.14407 .06294 L
.18333 .06525 L
.22108 .0682 L
.26129 .07181 L
.29997 .07551 L
.31962 .07742 L
.33001 .07844 L
.34111 .07951 L
.34665 .08 L
.35187 .08037 L
.35656 .08063 L
.36164 .08086 L
.36647 .08101 L
.3689 .08106 L
.37158 .08111 L
.37386 .08114 L
.37514 .08115 L
.37631 .08116 L
.3774 .08117 L
Mistroke
.37858 .08117 L
.3797 .08117 L
.38074 .08117 L
.38203 .08117 L
.38268 .08116 L
.38339 .08116 L
.38466 .08115 L
.38583 .08114 L
.38849 .0811 L
.39133 .08105 L
.39655 .08093 L
.4013 .08078 L
.41087 .0804 L
.41992 .07994 L
.43987 .07864 L
.4583 .07713 L
.49762 .07315 L
.53542 .06857 L
.57568 .0631 L
.61442 .05741 L
.65561 .05105 L
.69529 .04483 L
.73345 .03895 L
.75474 .03582 L
.77406 .03313 L
.78372 .03186 L
.79419 .03055 L
.79899 .02997 L
.80161 .02966 L
.80289 .02951 L
.80406 .02938 L
.80514 .12361 L
.80615 .12361 L
.8084 .12361 L
.81316 .12361 L
.85146 .12361 L
.89221 .12361 L
.93144 .12361 L
.96916 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1Yoooo2P1Vod?oool0
06Ooool00`000?ooooooo`1Toooo1@1Vo`Woool00`1Vooooooooo`11oooo001Woooo00<0003ooooo
ool0G?ooo`P0I_l>oooo00<0I_ooooooool0@Oooo`00Ioooo`030000oooooooo05Coool806Ko5_oo
o`0306Kooooooooo047oool006Ooool00`000?ooooooo`1?oooo1@1Voakoool00`1Vooooooooo`11
oooo001Woooo0P0004_oool506Ko8oooo`0306Kooooooooo047oool006Ooool00`000?ooooooo`15
oooo1@1VobSoool00`1Vooooooooo`11oooo001Woooo00<0003oooooool0?_ooo`L0I_l]oooo00<0
I_ooooooool0@Oooo`006ooooal0I_l]oooo00<0003oooooool0=?ooo`X0I_ldoooo00<0I_oooooo
ool0@Oooo`005_ooo`D0I_lOoooo4`1Voa[oool00`000?ooooooo`0/oooo201Vockoool00`1Voooo
ooooo`11oooo001=oooo2P1Voa3oool00`000?ooooooo`0Woooo1@1VodKoool00`1Vooooooooo`11
oooo001Goooo201Vo`Soool200008Oooo`L0I_m;oooo00<0I_ooooooool0@Oooo`005oooo`D0000N
oooo0P0000Coool200001?ooo`80000Goooo201Vo`03000006Ko06Ko00koool@06Ko0P0000Coool2
00001?ooo`80000Ooooo1@0001goool5000000@0I_ooool000000004oooo0P00023oool400005_oo
o`006Oooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`0001koool0
0`000?ooooooo`0>06Ko3oooo`040000oooooooo00002?ooo`040000oooooooo00008?ooo`030000
oooooooo01ooool010000?ooooooo`1Vo`Koool010000?ooooooo`0001ooool00`000?ooooooo`0G
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo01coool0
0`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool07_ooo`030000oooooooo
01ooool010000?ooooooo`1Vo`Woool00`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Ooo
o`@00004oooo00<0003oooooool05oooo`@00002oooo00@0003oooooool00009oooo0P0001ooool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo0P00027oool00`000?ooooooo`0Ooooo00@0
003oooooool0I_l7oooo0P0002;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Ooo
o`040000oooooooo00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003ooooo
ool00009oooo00<0003oooooool08?ooo`030000oooooooo01ooool010000?ooooooo`1Vo`Ooool0
0`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00023oool200002_ooo`<0000N
oooo0P0001ooool200002_ooo`<0000Ooooo0P00023oool200000_ooo`0306Kooooooooo00Goool3
00008?ooo`80000Goooo001Woooo00<0003oooooool0L_ooo`0306Kooooooooo047oool006Ooool0
0`000?ooooooo`1boooo00<0I_ooooooool0@Oooo`00Ioooo`030000oooooooo07;oool00`1Voooo
ooooo`11oooo001Woooo00<0003oooooool0L_ooo`0306Kooooooooo047oool006Ooool00`000?oo
ooooo`1boooo00<0I_ooooooool0@Oooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o01H000000ol0V@000000000?00000_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`00
0`0003?o03?o000T<ol0400001Koool01?l0VOooooooo`0002Soool00`000?ooooooo`0Eoooo001W
oooo00<0000co`0co`00Ac?o00D0000Voooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol0
048co`050000:oooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000m<ol01@00033oool0
0ol0VOooooooo`11oooo001Woooo00<0000co`0co`00>C?o00@0000eoooo00?o09Woooooool0@Ooo
o`00Ioooo`80000h<ol00P0003Woool00ol0VOooooooo`11oooo001Woooo00<0000co`0co`00=C?o
0080000koooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol003<co`020000?Oooo`03o`2I
oooooooo047oool006Ooool00`0003?o03?o000a<ol00P0003ooool00ol0VOooooooo`11oooo001W
oooo00<0000co`0co`00<3?o00030000oooooooo03ooool00ol0VOooooooo`11oooo001Woooo00<0
000co`0co`00;S?o00800012oooo00?o09Woooooool0@Oooo`00Ioooo`80000]<ol00P0004Coool0
0ol0VOooooooo`11oooo001Woooo00<0000co`0co`00:c?o00030000oooooooo04Coool00ol0VOoo
ooooo`11oooo001Woooo00<0000co`0co`00:S?o00030000oooooooo04Goool00ol0VOooooooo`11
oooo001Woooo00<0000co`0co`00:C?o00030000oooooooo04Koool00ol0VOooooooo`11oooo001W
oooo00<0000co`0co`00:3?o00030000oooooooo04Ooool00ol0VOooooooo`11oooo001Woooo00<0
000co`0co`00:3?o00030000oooooooo04Ooool00ol0VOooooooo`11oooo001Woooo0P0002Pco`00
0`000?ooooooo`18oooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol002Hco`000`000?oo
ooooo`19oooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`1:
oooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`1;oooo00?o
09Woooooool0@Oooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`1<oooo00?o09Wooooo
ool0@Oooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`1<oooo00?o09Woooooool0@Ooo
o`00Ioooo`80000S<ol000<0003oooooool0COooo`03o`2Ioooooooo047oool006Ooool00`0003?o
03?o000Q<ol000<0003oooooool0C_ooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000P
<ol000<0003oooooool0Coooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000P<ol000<0
003oooooool0Coooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000O<ol000<0003ooooo
ool0D?ooo`03o`2Ioooooooo047oool005ooool500000oooo`030000<ol0<ol001lco`000`000?oo
ooooo`1@oooo00?o09Woooooool0@Oooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N
<ol000<0003oooooool0DOooo`03o`2Ioooooooo047oool0067oool00`000?ooooooo`03oooo0P00
01lco`000`000?ooooooo`1Aoooo00?o09Woooooool0@Oooo`00HOooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0D_ooo`03o`2Ioooooooo047oool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo05;oool00ol0VOooooooo`11oooo001P
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Doooo`03o`2Ioooooooo047oool0
06Ooool00`0003?o03?o000L<ol000<0003oooooool0Doooo`03o`2Ioooooooo047oool006Ooool0
0`0003?o03?o000K<ol000<0003oooooool0E?ooo`03o`2Ioooooooo047oool006Ooool2000073?o
00030000oooooooo05Coool00ol0VOooooooo`11oooo001Woooo00<0000co`0co`006S?o00030000
oooooooo05Goool00ol0VOooooooo`11oooo001Woooo00<0000co`0co`006S?o00030000oooooooo
05Goool00ol0VOooooooo`11oooo001Woooo00<0000co`0co`006C?o00030000oooooooo05Koool0
0ol0VOooooooo`11oooo001Woooo00<0000co`0co`006C?o00030000oooooooo05Koool00ol0VOoo
ooooo`11oooo001Woooo00<0000co`0co`0063?o00030000oooooooo05Ooool00ol0VOooooooo`11
oooo001Woooo0P0001Tco`000`000?ooooooo`1Goooo00?o09Woooooool0@Oooo`00Ioooo`030000
<ol0<ol001Lco`000`000?ooooooo`1Hoooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol0
01Lco`000`000?ooooooo`1Hoooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol001Hco`00
0`000?ooooooo`1Ioooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1Ioooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1I
oooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1Joooo00?o
09Woooooool0@Oooo`00Ioooo`80000F<ol000<0003oooooool0F_ooo`03o`2Ioooooooo047oool0
06Ooool00`0003?o03?o000E<ol000<0003oooooool0F_ooo`03o`2Ioooooooo047oool006Ooool0
0`0003?o03?o000E<ol000<0003oooooool0F_ooo`03o`2Ioooooooo047oool006Ooool00`0003?o
03?o000D<ol000<0003oooooool0Foooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000D
<ol000<0003oooooool0Foooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000D<ol000<0
003oooooool0Foooo`03o`2Ioooooooo047oool006Ooool200005C?o00030000oooooooo05_oool0
0ol0VOooooooo`11oooo001Woooo00<0000co`0co`004c?o00030000oooooooo05coool00ol0VOoo
ooooo`11oooo001Woooo00<0000co`0co`004c?o00030000oooooooo05coool00ol0VOooooooo`11
oooo001Woooo00<0000co`0co`004c?o00030000oooooooo05coool00ol0VOooooooo`11oooo001O
oooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0G?ooo`03o`2Ioooooooo047oool0
05ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo05goool00ol0VOoo
ooooo`11oooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0GOooo`03o`2I
oooooooo047oool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo
05goool00ol0VOooooooo`11oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o
00030000oooooooo05koool00ol0VOooooooo`11oooo001Poooo0P0000Goool00`0003?o03?o000A
<ol000<0003oooooool0G_ooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000A<ol000<0
003oooooool0G_ooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000A<ol000<0003ooooo
ool0G_ooo`03o`2Ioooooooo047oool006Ooool200004C?o00030000oooooooo05ooool00ol0VOoo
ooooo`11oooo001Woooo00<0000co`0co`0043?o00030000oooooooo05ooool00ol0VOooooooo`11
oooo001Woooo00<0000co`0co`0043?o00030000oooooooo05ooool00ol0VOooooooo`11oooo001W
oooo00<0000co`0co`0043?o00030000oooooooo05ooool00ol0VOooooooo`11oooo001Woooo00<0
000co`0co`003c?o00030000oooooooo063oool00ol0VOooooooo`11oooo001Woooo00<0000co`0c
o`003c?o00030000oooooooo063oool00ol0VOooooooo`11oooo001Woooo00<0000co`0co`003c?o
00030000oooooooo063oool00ol0VOooooooo`11oooo001Woooo0P00010co`000`000?ooooooo`1P
oooo00?o09Woooooool0@Oooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Qoooo00?o
09Woooooool0@Oooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Qoooo00?o09Wooooo
ool0@Oooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Qoooo00?o09Woooooool0@Ooo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Qoooo00?o09Woooooool0@Oooo`00Iooo
o`030000<ol0<ol000dco`000`000?ooooooo`1Roooo00?o09Woooooool0@Oooo`00Ioooo`80000>
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000=<ol000<0
003oooooool0H_ooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000=<ol000<0003ooooo
ool0H_ooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0Hooo
o`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0Hoooo`03o`2I
oooooooo047oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0Hoooo`03o`2Ioooooooo
047oool006Ooool200003C?o00030000oooooooo06?oool00ol0VOooooooo`11oooo001Woooo00<0
000co`0co`0033?o00030000oooooooo06?oool00ol0VOooooooo`11oooo001Woooo00<0000co`0c
o`0033?o00030000oooooooo06?oool00ol0VOooooooo`11oooo001Woooo00<0000co`0co`002c?o
00030000oooooooo06Coool00ol0VOooooooo`11oooo001Poooo0P0000Goool00`0003?o03?o000;
<ol000<0003oooooool0I?ooo`03o`2Ioooooooo047oool005ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0I?ooo`03o`2Ioooooooo047oool0067oool00`000?oo
ooooo`03oooo0P0000`co`000`000?ooooooo`1Toooo00?o09Woooooool0@Oooo`00H_ooo`030000
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0I?ooo`03o`2Ioooooooo047oool0
05ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0I?ooo`03o`2I
oooooooo047oool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`1Uoooo00?o
09Woooooool0@Oooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1Uoooo00?o09Wooooo
ool0@Oooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1Uoooo00?o09Woooooool0@Ooo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1Uoooo00?o09Woooooool0@Oooo`00Iooo
o`80000;<ol000<0003oooooool0IOooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o000:
<ol000<0003oooooool0IOooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o0009<ol000<0
003oooooool0I_ooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0I_ooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0I_oo
o`03o`2Ioooooooo047oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0I_ooo`03o`2I
oooooooo047oool006Ooool200002S?o00030000oooooooo06Koool00ol0VOooooooo`11oooo001W
oooo00<0000co`0co`002C?o00030000oooooooo06Koool00ol0VOooooooo`11oooo001Woooo00<0
000co`0co`002C?o00030000oooooooo06Koool00ol0VOooooooo`11oooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo06Ooool00ol0VOooooooo`11oooo001Woooo00<0000co`0co`0023?o
00030000oooooooo06Ooool00ol0VOooooooo`11oooo001Woooo00<0000co`0co`0023?o00030000
oooooooo06Ooool00ol0VOooooooo`11oooo001Woooo0P0000Tco`000`000?ooooooo`1Woooo00?o
09Woooooool0@Oooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Woooo00?o09Wooooo
ool0@Oooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Woooo00?o09Woooooool0@Ooo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1Xoooo00?o09Woooooool0@Oooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1Xoooo00?o09Woooooool0@Oooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`1Xoooo00?o09Woooooool0@Oooo`00Ioooo`800008<ol000<0
003oooooool0J?ooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0J?ooo`03o`2Ioooooooo047oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0J?oo
o`03o`2Ioooooooo047oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0J?ooo`03o`2I
oooooooo047oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0J?ooo`03o`2Ioooooooo
047oool0067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`1Xoooo00?o09Wooooo
ool0@Oooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0J?oo
o`03o`2Ioooooooo047oool005ooool500000oooo`800008<ol000<0003oooooool0J?ooo`03o`2I
oooooooo047oool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo0000
00Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`
oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o
00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001Ooo
o`<000001?ooo`000000000000Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`0:
oooo00@0003oooooool00002oooo00D0003oooooooooool00000N_ooo`00Ioooo`Tco`07oooo00<0
003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo1@000005oooo0000oooo
oooo000000Coool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003_oo
o`030000oooooooo00Ooool010000?ooooooo`0000;oool300001?ooo`030000oooooooo07Soool0
06Ooool9<ol02?ooo`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oool0
00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?oo
ooooo`0Aoooo0P0000_oool200000oooo`<00002oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`
oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79892 .12361 L
.80403 .12361 L
.80682 .12361 L
.80819 .12361 L
.80943 .12361 L
.81057 .12361 L
s
.81057 .12361 m
.811 .61803 L
s
0 .4 1 r
.02381 .06529 m
.03279 .06435 L
.04262 .06351 L
.05288 .06284 L
.06244 .06237 L
.06792 .06217 L
.0731 .06202 L
.07775 .06192 L
.08038 .06188 L
.0828 .06185 L
.08405 .06184 L
.0854 .06183 L
.08656 .06182 L
.08783 .06181 L
.0886 .06181 L
.08932 .06181 L
.09 .0618 L
.09073 .0618 L
.09144 .0618 L
.09211 .0618 L
.09337 .06181 L
.09402 .06181 L
.09474 .06181 L
.09618 .06182 L
.09751 .06183 L
.09876 .06184 L
.10157 .06186 L
.10458 .0619 L
.10986 .062 L
.11475 .06211 L
.12582 .06245 L
.13558 .06284 L
.14594 .06334 L
.18369 .06573 L
.22389 .06899 L
.26258 .07253 L
.30372 .0765 L
.32425 .07849 L
.33425 .07946 L
.34335 .08034 L
.34789 .08071 L
.35282 .08104 L
.35708 .08127 L
.36177 .08148 L
.36675 .08163 L
.36947 .0817 L
.37201 .08174 L
.37323 .08176 L
.37439 .08177 L
.37544 .08178 L
Mistroke
.37656 .08179 L
.37778 .08179 L
.3789 .0818 L
.37959 .0818 L
.38024 .0818 L
.38145 .0818 L
.38262 .08179 L
.38387 .08178 L
.38505 .08177 L
.38612 .08176 L
.38876 .08173 L
.39124 .08169 L
.39619 .08158 L
.40157 .08142 L
.41118 .08105 L
.42006 .0806 L
.43876 .07941 L
.45938 .07775 L
.49963 .07371 L
.53837 .06904 L
.57956 .06345 L
.61924 .05763 L
.6574 .05175 L
.69801 .04538 L
.73711 .03934 L
.75706 .03639 L
.77866 .03336 L
.78879 .03202 L
.7995 .03066 L
.80391 .03013 L
.80634 .02984 L
.80865 .02957 L
.80995 .02942 L
.81068 .02934 L
.81136 .12361 L
.81257 .12361 L
.81384 .12361 L
.81869 .12361 L
.85641 .12361 L
.89658 .12361 L
.93524 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1^oooo1`1Vod7oool0
06Ooool00`000?ooooooo`1Toooo2P1Vo`Koool00`1Vooooooooo`0ooooo001Woooo00<0003ooooo
ool0Goooo`D0I_l@oooo00<0I_ooooooool0?oooo`00Ioooo`030000oooooooo05[oool506Ko5Ooo
o`0306Kooooooooo03ooool006Ooool00`000?ooooooo`1Coooo1`1Voa[oool00`1Vooooooooo`0o
oooo001Woooo0P0004coool806Ko8Oooo`0306Kooooooooo03ooool006Ooool00`000?ooooooo`16
oooo1@1VobWoool00`1Vooooooooo`0ooooo001Woooo00<0003oooooool0?oooo`L0I_l^oooo00<0
I_ooooooool0?oooo`006?ooob80I_l]oooo00<0003oooooool0=oooo`P0I_leoooo00<0I_oooooo
ool0?oooo`005_ooo`80I_lRoooo2P1Vob?oool00`000?ooooooo`0boooo1@1Vocgoool00`1Voooo
ooooo`0ooooo0014oooo501Vo`ooool00`000?ooooooo`0[oooo1`1Vod;oool00`1Vooooooooo`0o
oooo001Hoooo201Vo`Ooool200008_ooo`X0I_m9oooo00<0I_ooooooool0?oooo`005oooo`D0000N
oooo0P0000Coool200001?ooo`80000Hoooo1`1Vo`030000oooooooo013oool>06Ko0P00000406Ko
oooooooooooo0P0000Coool200007oooo`D0000Moooo1@0000;oool200001?ooo`80000Poooo1000
01Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000N
oooo00<00000I_l0I_l0401Vo`goool010000?ooooooo`0000Soool010000?ooooooo`00023oool0
0`000?ooooooo`0Ooooo00<0003oooooool00_ooo`0306Kooooooooo00;oool010000?ooooooo`00
01ooool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01coool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003ooooo
ool07_ooo`030000oooooooo01ooool00`000?ooooooo`02oooo00<0I_ooooooool01Oooo`030000
oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo1000
00;oool010000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`00
00Woool200008Oooo`030000oooooooo01ooool00`000?ooooooo`02oooo00<0I_ooooooool00ooo
o`80000Roooo00<0003oooooool05Oooo`006Oooo`030000oooooooo01goool010000?ooooooo`00
00Woool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000
oooooooo023oool00`000?ooooooo`0Ooooo00<0003oooooool00_ooo`0306Kooooooooo00?oool0
0`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00023oool200002_ooo`<0000N
oooo0P0001ooool200002_ooo`<0000Ooooo0P00023oool200001?ooo`0306Kooooooooo00?oool3
00008?ooo`80000Goooo001Woooo00<0003oooooool0M?ooo`0306Kooooooooo03ooool006Ooool0
0`000?ooooooo`1doooo00<0I_ooooooool0?oooo`00Ioooo`030000oooooooo07Coool00`1Voooo
ooooo`0ooooo001Woooo00<0003oooooool0M?ooo`0306Kooooooooo03ooool006Ooool00`000?oo
ooooo`1doooo00<0I_ooooooool0?oooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`0013?o01P000000ol0V@000000000=00000_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`00
0`0003?o03?o000T<ol0400001Soool00ol0V@000?ooo`0Woooo00<0003oooooool05Oooo`00Iooo
o`030000<ol0<ol004Lco`050000:?ooo`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o0012
<ol01@0002goool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`00?C?o00D0000boooo00?o
09Woooooool0?oooo`00Ioooo`030000<ol0<ol003Tco`040000=oooo`03o`2Ioooooooo03ooool0
06Ooool20000>3?o0080000koooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol003Dco`02
0000?Oooo`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o000c<ol00P0003ooool00ol0VOoo
ooooo`0ooooo001Woooo00<0000co`0co`00<C?o00800011oooo00?o09Woooooool0?oooo`00Iooo
o`030000<ol0<ol0030co`000`000?ooooooo`11oooo00?o09Woooooool0?oooo`00Ioooo`030000
<ol0<ol002hco`020000A?ooo`03o`2Ioooooooo03ooool006Ooool20000;C?o00800016oooo00?o
09Woooooool0?oooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`16oooo00?o09Wooooo
ool0?oooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`17oooo00?o09Woooooool0?ooo
o`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`18oooo00?o09Woooooool0?oooo`00Iooo
o`030000<ol0<ol002Pco`000`000?ooooooo`19oooo00?o09Woooooool0?oooo`00Ioooo`030000
<ol0<ol002Pco`000`000?ooooooo`19oooo00?o09Woooooool0?oooo`00Ioooo`80000X<ol000<0
003oooooool0B_ooo`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o000V<ol000<0003ooooo
ool0Boooo`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o000U<ol000<0003oooooool0C?oo
o`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o000T<ol000<0003oooooool0COooo`03o`2I
oooooooo03ooool006Ooool00`0003?o03?o000S<ol000<0003oooooool0C_ooo`03o`2Ioooooooo
03ooool006Ooool00`0003?o03?o000S<ol000<0003oooooool0C_ooo`03o`2Ioooooooo03ooool0
06Ooool200008c?o00030000oooooooo04ooool00ol0VOooooooo`0ooooo001Woooo00<0000co`0c
o`008C?o00030000oooooooo053oool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`0083?o
00030000oooooooo057oool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`0083?o00030000
oooooooo057oool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`007c?o00030000oooooooo
05;oool00ol0VOooooooo`0ooooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003ooooo
ool0D_ooo`03o`2Ioooooooo03ooool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o
00030000oooooooo05?oool00ol0VOooooooo`0ooooo001Qoooo00<0003oooooool00oooo`80000O
<ol000<0003oooooool0Doooo`03o`2Ioooooooo03ooool0067oool00`000?ooooooo`03oooo00<0
000co`0co`007C?o00030000oooooooo05Coool00ol0VOooooooo`0ooooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001dco`000`000?ooooooo`1Doooo00?o09Woooooool0?oooo`00H?oo
o`800005oooo00<0000co`0co`0073?o00030000oooooooo05Goool00ol0VOooooooo`0ooooo001W
oooo00<0000co`0co`0073?o00030000oooooooo05Goool00ol0VOooooooo`0ooooo001Woooo00<0
000co`0co`006c?o00030000oooooooo05Koool00ol0VOooooooo`0ooooo001Woooo0P0001`co`00
0`000?ooooooo`1Foooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol001Xco`000`000?oo
ooooo`1Goooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`1G
oooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`1Hoooo00?o
09Woooooool0?oooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`1Hoooo00?o09Wooooo
ool0?oooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`1Ioooo00?o09Woooooool0?ooo
o`00Ioooo`80000I<ol000<0003oooooool0FOooo`03o`2Ioooooooo03ooool006Ooool00`0003?o
03?o000G<ol000<0003oooooool0F_ooo`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o000G
<ol000<0003oooooool0F_ooo`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o000F<ol000<0
003oooooool0Foooo`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o000F<ol000<0003ooooo
ool0Foooo`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o000F<ol000<0003oooooool0Fooo
o`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o000E<ol000<0003oooooool0G?ooo`03o`2I
oooooooo03ooool006Ooool200005S?o00030000oooooooo05coool00ol0VOooooooo`0ooooo001W
oooo00<0000co`0co`005C?o00030000oooooooo05coool00ol0VOooooooo`0ooooo001Woooo00<0
000co`0co`005C?o00030000oooooooo05coool00ol0VOooooooo`0ooooo001Woooo00<0000co`0c
o`0053?o00030000oooooooo05goool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`0053?o
00030000oooooooo05goool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`0053?o00030000
oooooooo05goool00ol0VOooooooo`0ooooo001Woooo0P0001Dco`000`000?ooooooo`1Moooo00?o
09Woooooool0?oooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1Noooo00?o09Wooooo
ool0?oooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1Noooo00?o09Woooooool0?ooo
o`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1Noooo00?o09Woooooool0?oooo`00Gooo
o`@00004oooo00<0000co`0co`004c?o00030000oooooooo05koool00ol0VOooooooo`0ooooo001O
oooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`1Ooooo00?o09Wooooo
ool0?oooo`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo05ooool00ol0VOoo
ooooo`0ooooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`1O
oooo00?o09Woooooool0?oooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`00
0`000?ooooooo`1Poooo00?o09Woooooool0?oooo`00H?ooo`800005oooo00<0000co`0co`004C?o
00030000oooooooo063oool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`004C?o00030000
oooooooo063oool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`004C?o00030000oooooooo
063oool00ol0VOooooooo`0ooooo001Woooo0P00014co`000`000?ooooooo`1Qoooo00?o09Wooooo
ool0?oooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1Qoooo00?o09Woooooool0?ooo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1Qoooo00?o09Woooooool0?oooo`00Iooo
o`030000<ol0<ol0010co`000`000?ooooooo`1Qoooo00?o09Woooooool0?oooo`00Ioooo`030000
<ol0<ol000lco`000`000?ooooooo`1Roooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`1Roooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol000lco`00
0`000?ooooooo`1Roooo00?o09Woooooool0?oooo`00Ioooo`80000@<ol000<0003oooooool0H_oo
o`03o`2Ioooooooo03ooool006Ooool00`0003?o03?o000><ol000<0003oooooool0Hoooo`03o`2I
oooooooo03ooool006Ooool00`0003?o03?o000><ol000<0003oooooool0Hoooo`03o`2Ioooooooo
03ooool006Ooool00`0003?o03?o000><ol000<0003oooooool0Hoooo`03o`2Ioooooooo03ooool0
06Ooool00`0003?o03?o000><ol000<0003oooooool0Hoooo`03o`2Ioooooooo03ooool006Ooool0
0`0003?o03?o000=<ol000<0003oooooool0I?ooo`03o`2Ioooooooo03ooool006Ooool200003S?o
00030000oooooooo06Coool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`003C?o00030000
oooooooo06Coool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`003C?o00030000oooooooo
06Coool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`0033?o00030000oooooooo06Goool0
0ol0VOooooooo`0ooooo001Woooo00<0000co`0co`0033?o00030000oooooooo06Goool00ol0VOoo
ooooo`0ooooo001Woooo00<0000co`0co`0033?o00030000oooooooo06Goool00ol0VOooooooo`0o
oooo001Woooo0P0000dco`000`000?ooooooo`1Uoooo00?o09Woooooool0?oooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`1Uoooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`1Uoooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol000/co`00
0`000?ooooooo`1Voooo00?o09Woooooool0?oooo`00H?ooo`800005oooo00<0000co`0co`002c?o
00030000oooooooo06Koool00ol0VOooooooo`0ooooo001Ooooo00@0003oooooool00004oooo00<0
000co`0co`002c?o00030000oooooooo06Koool00ol0VOooooooo`0ooooo001Qoooo00<0003ooooo
ool00oooo`80000<<ol000<0003oooooool0I_ooo`03o`2Ioooooooo03ooool006;oool00`000?oo
ooooo`02oooo00<0000co`0co`002c?o00030000oooooooo06Koool00ol0VOooooooo`0ooooo001O
oooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo06Koool00ol0VOoo
ooooo`0ooooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0Ioooo`03o`2I
oooooooo03ooool006Ooool00`0003?o03?o000:<ol000<0003oooooool0Ioooo`03o`2Ioooooooo
03ooool006Ooool00`0003?o03?o000:<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03ooool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03ooool006Ooool2
00002c?o00030000oooooooo06Ooool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`002S?o
00030000oooooooo06Ooool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`002C?o00030000
oooooooo06Soool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`002C?o00030000oooooooo
06Soool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`002C?o00030000oooooooo06Soool0
0ol0VOooooooo`0ooooo001Woooo00<0000co`0co`002C?o00030000oooooooo06Soool00ol0VOoo
ooooo`0ooooo001Woooo0P0000Xco`000`000?ooooooo`1Xoooo00?o09Woooooool0?oooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1Xoooo00?o09Woooooool0?oooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`1Xoooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1Yoooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`1Yoooo00?o09Woooooool0?oooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`1Yoooo00?o09Woooooool0?oooo`00Ioooo`800009<ol000<0003oooooool0JOooo`03o`2I
oooooooo03ooool006Ooool00`0003?o03?o0008<ol000<0003oooooool0JOooo`03o`2Ioooooooo
03ooool006Ooool00`0003?o03?o0008<ol000<0003oooooool0JOooo`03o`2Ioooooooo03ooool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0J_ooo`03o`2Ioooooooo03ooool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0J_ooo`03o`2Ioooooooo03ooool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0J_ooo`03o`2Ioooooooo03ooool006Ooool2000023?o00030000
oooooooo06[oool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`001c?o00030000oooooooo
06[oool00ol0VOooooooo`0ooooo001Woooo00<0000co`0co`001c?o00030000oooooooo06[oool0
0ol0VOooooooo`0ooooo001Woooo00<0000co`0co`001c?o00030000oooooooo06[oool00ol0VOoo
ooooo`0ooooo001Woooo00<0000co`0co`001c?o00030000oooooooo06[oool00ol0VOooooooo`0o
oooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0J_ooo`03o`2Ioooooooo
03ooool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo06[oool0
0ol0VOooooooo`0ooooo001Ooooo1@0000?oool2000023?o00030000oooooooo06[oool00ol0VOoo
ooooo`0ooooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004
oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?oo
o`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?oo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Goool3
00000_ooo`800004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02_ooo`040000
oooooooo00000_ooo`050000oooooooooooo000007[oool006Ooool9<ol01oooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`D000001Oooo`000?ooooooo`000004
oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000koool00`000?oo
ooooo`07oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1hoooo001Woooo2C?o
00Soool01@000?ooooooooooo`00000Aoooo00<0003oooooool02?ooo`030000oooo000000;oool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?ooooooo`0A
oooo0P0000_oool200000oooo`800003oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001W
oooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79892 .12361 L
.80403 .12361 L
.80943 .12361 L
.81404 .12361 L
.8153 .12361 L
.81599 .12361 L
.81665 .12361 L
s
.81665 .12361 m
.81716 .61803 L
s
0 .4 1 r
.02381 .06461 m
.03279 .06379 L
.04262 .06307 L
.04758 .06278 L
.05288 .06251 L
.05785 .0623 L
.06244 .06214 L
.06788 .062 L
.07075 .06194 L
.07379 .06189 L
.07642 .06185 L
.07889 .06183 L
.0803 .06182 L
.08159 .06181 L
.08231 .06181 L
.08309 .06181 L
.08382 .0618 L
.08451 .0618 L
.08577 .0618 L
.08648 .0618 L
.08713 .06181 L
.08833 .06181 L
.0896 .06182 L
.09074 .06182 L
.0918 .06183 L
.09422 .06185 L
.09684 .06188 L
.09922 .06192 L
.10458 .06202 L
.11449 .06229 L
.12366 .06261 L
.14443 .0636 L
.18369 .06621 L
.22144 .06934 L
.26165 .07305 L
.30033 .07678 L
.31998 .07869 L
.33037 .0797 L
.34147 .08077 L
.347 .08125 L
.35223 .08161 L
.35731 .0819 L
.362 .0821 L
.36645 .08224 L
.36869 .08229 L
.37116 .08234 L
.37364 .08238 L
.37503 .08239 L
.3763 .0824 L
.37747 .08241 L
Mistroke
.37876 .08242 L
.37997 .08242 L
.3811 .08242 L
.38239 .08242 L
.38304 .08241 L
.38375 .08241 L
.38501 .0824 L
.38619 .08239 L
.38885 .08236 L
.39169 .08231 L
.39691 .0822 L
.40166 .08206 L
.41123 .0817 L
.42028 .08126 L
.44023 .08 L
.45866 .07853 L
.49798 .07467 L
.53578 .07021 L
.57604 .06485 L
.61478 .05925 L
.65597 .05296 L
.69565 .04674 L
.73381 .0408 L
.77442 .03481 L
.79319 .03226 L
.80307 .031 L
.80847 .03033 L
.81352 .02973 L
.81483 .02958 L
.81608 .02944 L
.81676 .02936 L
.81751 .12361 L
.81882 .12361 L
.82465 .12361 L
.8349 .12361 L
.85507 .12361 L
.89582 .12361 L
.93505 .12361 L
.97277 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1^oooo201Vod3oool0
06Ooool00`000?ooooooo`1Voooo201Vo`Ooool00`1Vooooooooo`0noooo001Woooo00<0003ooooo
ool0G_ooo`P0I_l?oooo00<0I_ooooooool0?_ooo`00Ioooo`030000oooooooo05[oool406Ko5ooo
o`0306Kooooooooo03koool006Ooool00`000?ooooooo`1Coooo1`1Voa_oool00`1Vooooooooo`0n
oooo001Woooo0P0004coool806Ko8_ooo`0306Kooooooooo03koool006Ooool00`000?ooooooo`15
oooo1P1Vob[oool00`1Vooooooooo`0noooo001Woooo00<0003oooooool0@?ooo`D0I_l`oooo00<0
I_ooooooool0?_ooo`005_ooob@0I_l]oooo00<0003oooooool0>oooo`D0I_leoooo00<0I_oooooo
ool0?_ooo`00>_ooo`X0I_lSoooo00<0003oooooool0=?ooo`L0I_ljoooo00<0I_ooooooool0?_oo
o`00A?ooo`X0I_lIoooo00<0003oooooool0:_ooo`X0I_m1oooo00<0I_ooooooool0?_ooo`00C_oo
o`X0I_l?oooo0P00027oool:06KoBoooo`0306Kooooooooo03koool001Ooool500007_ooo`800004
oooo0P0000Coool200004?ooo`h0I_l00oooo`000?ooo`0Eoooo2P1Vo`800004oooo0P0000Coool2
00007oooo`D0000Moooo1@0000;oool200001?ooo`80000Poooo100001Koool001Woool00`000?oo
ooooo`0Moooo00@0003oooooool00008oooo00@0003oooooool0000Moooo00<0I_l00000I_l05@1V
o`Woool010000?ooooooo`0000Soool010000?ooooooo`00023oool00`000?ooooooo`0Ooooo00<0
003oooooool00oooo`0506Kooooooooooooo000000;oool00`000?ooooooo`0Moooo00<0003ooooo
ool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0L
oooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo01koool00`000?oo
ooooo`0Ooooo00<0003oooooool00oooo`0306Kooooooooo00Coool00`000?ooooooo`0Noooo00<0
003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool05oooo`@00002oooo00@0003ooooo
ool00009oooo0P0001ooool00`000?ooooooo`0Moooo00@0003oooooool00009oooo0P00027oool0
0`000?ooooooo`0Ooooo00<0003oooooool00oooo`0306Kooooooooo00;oool200008_ooo`030000
oooooooo01Goool001Woool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003ooooo
ool07_ooo`030000oooooooo01goool010000?ooooooo`0000Woool00`000?ooooooo`0Poooo00<0
003oooooool07oooo`030000oooooooo00?oool00`1Vooooooooo`02oooo00<0003oooooool07ooo
o`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P00
00[oool300007oooo`80000Poooo0P0000Goool00`1Vooooooooo`02oooo0`00023oool200005ooo
o`00Ioooo`030000oooooooo07Goool00`1Vooooooooo`0noooo001Woooo00<0003oooooool0MOoo
o`0306Kooooooooo03koool006Ooool00`000?ooooooo`1eoooo00<0I_ooooooool0?_ooo`00Iooo
o`030000oooooooo07Goool00`1Vooooooooo`0noooo001Woooo00<0003oooooool0MOooo`0306Ko
oooooooo03koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0
003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol0400001Woool00`000?oo
ooooo`0Voooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol004Lco`050000:Oooo`03o`2I
oooooooo03koool006Ooool00`0003?o03?o0012<ol01@0002koool00ol0VOooooooo`0noooo001W
oooo00<0000co`0co`00?C?o00D0000coooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol0
03Tco`040000>?ooo`03o`2Ioooooooo03koool006Ooool20000>3?o0080000loooo00?o09Wooooo
ool0?_ooo`00Ioooo`030000<ol0<ol003Dco`020000?_ooo`03o`2Ioooooooo03koool006Ooool0
0`0003?o03?o000c<ol00P00043oool00ol0VOooooooo`0noooo001Woooo00<0000co`0co`00<C?o
00800012oooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`12
oooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol002hco`020000AOooo`03o`2Ioooooooo
03koool006Ooool20000;C?o00800017oooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol0
02/co`000`000?ooooooo`17oooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol002Xco`00
0`000?ooooooo`18oooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol002Tco`000`000?oo
ooooo`19oooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`1:
oooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`1:oooo00?o
09Woooooool0?_ooo`00Ioooo`80000X<ol000<0003oooooool0Boooo`03o`2Ioooooooo03koool0
06Ooool00`0003?o03?o000V<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03koool006Ooool0
0`0003?o03?o000U<ol000<0003oooooool0COooo`03o`2Ioooooooo03koool006Ooool00`0003?o
03?o000T<ol000<0003oooooool0C_ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o000S
<ol000<0003oooooool0Coooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o000S<ol000<0
003oooooool0Coooo`03o`2Ioooooooo03koool006Ooool200008c?o00030000oooooooo053oool0
0ol0VOooooooo`0noooo001Woooo00<0000co`0co`008C?o00030000oooooooo057oool00ol0VOoo
ooooo`0noooo001Woooo00<0000co`0co`0083?o00030000oooooooo05;oool00ol0VOooooooo`0n
oooo001Woooo00<0000co`0co`0083?o00030000oooooooo05;oool00ol0VOooooooo`0noooo001W
oooo00<0000co`0co`007c?o00030000oooooooo05?oool00ol0VOooooooo`0noooo001Ooooo1@00
00?oool00`0003?o03?o000O<ol000<0003oooooool0Doooo`03o`2Ioooooooo03koool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`007S?o00030000oooooooo05Coool00ol0VOooooooo`0n
oooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
03koool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo05Goool0
0ol0VOooooooo`0noooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?oo
ooooo`1Eoooo00?o09Woooooool0?_ooo`00H?ooo`800005oooo00<0000co`0co`0073?o00030000
oooooooo05Koool00ol0VOooooooo`0noooo001Woooo00<0000co`0co`0073?o00030000oooooooo
05Koool00ol0VOooooooo`0noooo001Woooo00<0000co`0co`006c?o00030000oooooooo05Ooool0
0ol0VOooooooo`0noooo001Woooo0P0001`co`000`000?ooooooo`1Goooo00?o09Woooooool0?_oo
o`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`1Hoooo00?o09Woooooool0?_ooo`00Iooo
o`030000<ol0<ol001Xco`000`000?ooooooo`1Hoooo00?o09Woooooool0?_ooo`00Ioooo`030000
<ol0<ol001Tco`000`000?ooooooo`1Ioooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol0
01Tco`000`000?ooooooo`1Ioooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1Joooo00?o09Woooooool0?_ooo`00Ioooo`80000I<ol000<0003oooooool0F_oo
o`03o`2Ioooooooo03koool006Ooool00`0003?o03?o000G<ol000<0003oooooool0Foooo`03o`2I
oooooooo03koool006Ooool00`0003?o03?o000G<ol000<0003oooooool0Foooo`03o`2Ioooooooo
03koool006Ooool00`0003?o03?o000F<ol000<0003oooooool0G?ooo`03o`2Ioooooooo03koool0
06Ooool00`0003?o03?o000F<ol000<0003oooooool0G?ooo`03o`2Ioooooooo03koool006Ooool0
0`0003?o03?o000F<ol000<0003oooooool0G?ooo`03o`2Ioooooooo03koool006Ooool00`0003?o
03?o000E<ol000<0003oooooool0GOooo`03o`2Ioooooooo03koool006Ooool200005S?o00030000
oooooooo05goool00ol0VOooooooo`0noooo001Woooo00<0000co`0co`005C?o00030000oooooooo
05goool00ol0VOooooooo`0noooo001Woooo00<0000co`0co`005C?o00030000oooooooo05goool0
0ol0VOooooooo`0noooo001Woooo00<0000co`0co`0053?o00030000oooooooo05koool00ol0VOoo
ooooo`0noooo001Woooo00<0000co`0co`0053?o00030000oooooooo05koool00ol0VOooooooo`0n
oooo001Woooo00<0000co`0co`0053?o00030000oooooooo05koool00ol0VOooooooo`0noooo001W
oooo0P0001Dco`000`000?ooooooo`1Noooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol0
01<co`000`000?ooooooo`1Ooooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol001<co`00
0`000?ooooooo`1Ooooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol001<co`000`000?oo
ooooo`1Ooooo00?o09Woooooool0?_ooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000
oooooooo05ooool00ol0VOooooooo`0noooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0
018co`000`000?ooooooo`1Poooo00?o09Woooooool0?_ooo`00H?ooo`030000oooooooo00Coool2
00004c?o00030000oooooooo063oool00ol0VOooooooo`0noooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol0018co`000`000?ooooooo`1Poooo00?o09Woooooool0?_ooo`00Goooo`040000
oooooooo00001?ooo`030000<ol0<ol0014co`000`000?ooooooo`1Qoooo00?o09Woooooool0?_oo
o`00H?ooo`800005oooo00<0000co`0co`004C?o00030000oooooooo067oool00ol0VOooooooo`0n
oooo001Woooo00<0000co`0co`004C?o00030000oooooooo067oool00ol0VOooooooo`0noooo001W
oooo00<0000co`0co`004C?o00030000oooooooo067oool00ol0VOooooooo`0noooo001Woooo0P00
014co`000`000?ooooooo`1Roooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol0010co`00
0`000?ooooooo`1Roooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol0010co`000`000?oo
ooooo`1Roooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1R
oooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1Soooo00?o
09Woooooool0?_ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1Soooo00?o09Wooooo
ool0?_ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1Soooo00?o09Woooooool0?_oo
o`00Ioooo`80000@<ol000<0003oooooool0Hoooo`03o`2Ioooooooo03koool006Ooool00`0003?o
03?o000><ol000<0003oooooool0I?ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o000>
<ol000<0003oooooool0I?ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o000><ol000<0
003oooooool0I?ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o000><ol000<0003ooooo
ool0I?ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o000=<ol000<0003oooooool0IOoo
o`03o`2Ioooooooo03koool006Ooool200003S?o00030000oooooooo06Goool00ol0VOooooooo`0n
oooo001Woooo00<0000co`0co`003C?o00030000oooooooo06Goool00ol0VOooooooo`0noooo001W
oooo00<0000co`0co`003C?o00030000oooooooo06Goool00ol0VOooooooo`0noooo001Woooo00<0
000co`0co`0033?o00030000oooooooo06Koool00ol0VOooooooo`0noooo001Woooo00<0000co`0c
o`0033?o00030000oooooooo06Koool00ol0VOooooooo`0noooo001Woooo00<0000co`0co`0033?o
00030000oooooooo06Koool00ol0VOooooooo`0noooo001Woooo0P0000dco`000`000?ooooooo`1V
oooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1Voooo00?o
09Woooooool0?_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1Voooo00?o09Wooooo
ool0?_ooo`00Ioooo`030000<ol0<ol000/co`000`000?ooooooo`1Woooo00?o09Woooooool0?_oo
o`00H?ooo`800005oooo00<0000co`0co`002c?o00030000oooooooo06Ooool00ol0VOooooooo`0n
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo06Ooool0
0ol0VOooooooo`0noooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0003oooooool0Iooo
o`03o`2Ioooooooo03koool006;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000
oooooooo06Ooool00ol0VOooooooo`0noooo001Ooooo00@0003oooooool00004oooo00<0000co`0c
o`002c?o00030000oooooooo06Ooool00ol0VOooooooo`0noooo001Poooo0P0000Goool00`0003?o
03?o000:<ol000<0003oooooool0J?ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o000:
<ol000<0003oooooool0J?ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o000:<ol000<0
003oooooool0J?ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0J?ooo`03o`2Ioooooooo03koool006Ooool200002c?o00030000oooooooo06Soool00ol0VOoo
ooooo`0noooo001Woooo00<0000co`0co`002S?o00030000oooooooo06Soool00ol0VOooooooo`0n
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo06Woool00ol0VOooooooo`0noooo001W
oooo00<0000co`0co`002C?o00030000oooooooo06Woool00ol0VOooooooo`0noooo001Woooo00<0
000co`0co`002C?o00030000oooooooo06Woool00ol0VOooooooo`0noooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo06Woool00ol0VOooooooo`0noooo001Woooo0P0000Xco`000`000?oo
ooooo`1Yoooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Y
oooo00?o09Woooooool0?_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1Yoooo00?o
09Woooooool0?_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Zoooo00?o09Wooooo
ool0?_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Zoooo00?o09Woooooool0?_oo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1Zoooo00?o09Woooooool0?_ooo`00Iooo
o`800009<ol000<0003oooooool0J_ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0J_ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0J_ooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Joooo`03o`2Ioooooooo03koool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Jooo
o`03o`2Ioooooooo03koool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Joooo`03o`2I
oooooooo03koool006Ooool2000023?o00030000oooooooo06_oool00ol0VOooooooo`0noooo001W
oooo00<0000co`0co`001c?o00030000oooooooo06_oool00ol0VOooooooo`0noooo001Woooo00<0
000co`0co`001c?o00030000oooooooo06_oool00ol0VOooooooo`0noooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo06_oool00ol0VOooooooo`0noooo001Woooo00<0000co`0co`001c?o
00030000oooooooo06_oool00ol0VOooooooo`0noooo001Qoooo0`0000?oool00`0003?o03?o0007
<ol000<0003oooooool0Joooo`03o`2Ioooooooo03koool006;oool00`000?ooooooo`02oooo00<0
000co`0co`001c?o00030000oooooooo06_oool00ol0VOooooooo`0noooo001Ooooo1@0000?oool2
000023?o00030000oooooooo06_oool00ol0VOooooooo`0noooo001Ooooo00@0003oooooool00004
oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_
oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`0<oooo00<0003oooooool08_oo
o`030000oooooooo07coool006Ooool9<ol02oooo`030000oooooooo00Soool00`000?ooooooo`0I
oooo00<0003oooooool0Noooo`00Ioooo`Tco`0;oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002oooo0P0000Coool200001?ooo`030000oooooooo07_oool006Ooool9
<ol02oooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001Woooo2C?o
00[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo00<0003oooooool0N_ooo`00Ioooo`Tco`0;oooo00<0003oooooool01@0000koool0
0`000?ooooooo`08oooo0P0000Coool00`000?ooooooo`1koooo001Woooo2C?o00_oool01@000?oo
ooooooooo`00000Aoooo00<0003oooooool02?ooo`030000oooooooo00?oool00`000?ooooooo`1k
oooo001Woooo2C?o00coool00`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo
07coool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.80799 .12361 L
.81373 .12361 L
.81654 .12361 L
.81909 .12361 L
.82028 .12361 L
.82156 .12361 L
.82277 .12361 L
s
.82277 .12361 m
.82322 .61803 L
s
0 .4 1 r
.02381 .06401 m
.03279 .06331 L
.04262 .0627 L
.04758 .06246 L
.05288 .06225 L
.05785 .06209 L
.06244 .06198 L
.06503 .06192 L
.06788 .06188 L
.07075 .06184 L
.07232 .06183 L
.07379 .06182 L
.07445 .06182 L
.07517 .06181 L
.07648 .06181 L
.07776 .0618 L
.07895 .0618 L
.07968 .0618 L
.08036 .0618 L
.08164 .06181 L
.08236 .06181 L
.08302 .06181 L
.08451 .06182 L
.08691 .06184 L
.08916 .06187 L
.09427 .06194 L
.09924 .06204 L
.10458 .06218 L
.11475 .06251 L
.12582 .06298 L
.14594 .06405 L
.18672 .06694 L
.22599 .07031 L
.26374 .07385 L
.30394 .07775 L
.32242 .07955 L
.33289 .08056 L
.34263 .08149 L
.35232 .08223 L
.35774 .08252 L
.36267 .08273 L
.36788 .08289 L
.37082 .08295 L
.37222 .08297 L
.37352 .08299 L
.37476 .08301 L
.37589 .08302 L
.37715 .08303 L
.37784 .08303 L
.3785 .08303 L
Mistroke
.37981 .08304 L
.38102 .08304 L
.38172 .08304 L
.38235 .08304 L
.38308 .08303 L
.38377 .08303 L
.38494 .08302 L
.38619 .08301 L
.38844 .08299 L
.39112 .08295 L
.39356 .0829 L
.39887 .08278 L
.40389 .08262 L
.41275 .08228 L
.42237 .0818 L
.44219 .08054 L
.46321 .07885 L
.50101 .07511 L
.54127 .07035 L
.58001 .06519 L
.6212 .05923 L
.66087 .05317 L
.69903 .04719 L
.73965 .04086 L
.77875 .03508 L
.7987 .03236 L
.80919 .03102 L
.81493 .03031 L
.81774 .02998 L
.8203 .02968 L
.82147 .02954 L
.82275 .02939 L
.82397 .12361 L
.82509 .12361 L
.83023 .12361 L
.84114 .12361 L
.86033 .12361 L
.89956 .12361 L
.93728 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1_oooo2@1Vockoool0
06Ooool00`000?ooooooo`1Xoooo1`1Vo`Soool00`1Vooooooooo`0loooo001Woooo00<0003ooooo
ool0H?ooo`P0I_l?oooo00<0I_ooooooool0??ooo`00Ioooo`030000oooooooo05[oool606Ko5ooo
o`0306Kooooooooo03coool006Ooool00`000?ooooooo`1Eoooo1@1Voagoool00`1Vooooooooo`0l
oooo001Woooo0P0005;oool406Ko8_ooo`0306Kooooooooo03coool006Ooool00`000?ooooooo`1:
oooo1`1VobKoool00`1Vooooooooo`0loooo001Woooo00<0003oooooool0@_ooo`P0I_l]oooo00<0
I_ooooooool0??ooo`005_ooobD0I_l/oooo00<0003oooooool0??ooo`H0I_leoooo00<0I_oooooo
ool0??ooo`00>oooo`X0I_lRoooo00<0003oooooool0=Oooo`L0I_lkoooo00<0I_ooooooool0??oo
o`00AOooo`T0I_lIoooo00<0003oooooool0:oooo`X0I_m2oooo00<0I_ooooooool0??ooo`00C_oo
o`X0I_l?oooo0P0002;oool:06KoC?ooo`0306Kooooooooo03coool001Ooool500007_ooo`800004
oooo0P0000Coool200004?ooo`h0I_l00oooo`000?ooo`0Eoooo2P1Vo`800000101Voooooooooooo
o`800004oooo0P0001ooool500007Oooo`D00002oooo0P000004oooo06Kooooooooo0P00023oool4
00005_ooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00
01goool00`1Vo`00001Vo`0E06Ko2Oooo`040000oooooooo00002?ooo`040000oooooooo00008?oo
o`030000oooooooo01ooool00`000?ooooooo`05oooo00<0I_ooool000000_ooo`030000oooooooo
01goool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002ooo
o`030000oooooooo01coool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003ooooo
ool07_ooo`030000oooooooo01ooool00`000?ooooooo`05oooo00<0I_ooooooool00_ooo`030000
oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo1000
00;oool010000?ooooooo`0000Woool200007oooo`030000oooooooo01goool010000?ooooooo`00
00Woool200008Oooo`030000oooooooo01ooool00`000?ooooooo`05oooo00<0I_ooooooool00P00
02;oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Ooo
o`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003ooooo
ool08?ooo`030000oooooooo01ooool00`000?ooooooo`05oooo00@0I_ooooooool0000Qoooo00@0
003oooooool0000Foooo000Hoooo0P00023oool200002_ooo`<0000Noooo0P0001ooool200002_oo
o`<0000Ooooo0P00023oool200001oooo`0306Kooooooooo00<0000Poooo0P0001Ooool006Ooool0
0`000?ooooooo`1goooo00<0I_ooooooool0??ooo`00Ioooo`030000oooooooo07Ooool00`1Voooo
ooooo`0loooo001Woooo00<0003oooooool0Moooo`0306Kooooooooo03coool006Ooool00`000?oo
ooooo`1goooo00<0I_ooooooool0??ooo`00Ioooo`030000oooooooo07Ooool00`1Vooooooooo`0l
oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0004<ol06`000003o`2I0000000000X00002oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o00030000<ol0<ol002@co`0@00006Ooo
o`030000ooooo`2I02Koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`00Ac?o00D0000[
oooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol0048co`050000<?ooo`03o`2Ioooooooo
03coool006Ooool00`0003?o03?o000m<ol01@0003Goool00ol0VOooooooo`0loooo001Woooo00<0
000co`0co`00>C?o00@0000joooo00?o09Woooooool0??ooo`00Ioooo`80000h<ol00P0003koool0
0ol0VOooooooo`0loooo001Woooo00<0000co`0co`00=C?o00800010oooo00?o09Woooooool0??oo
o`00Ioooo`030000<ol0<ol003<co`020000@_ooo`03o`2Ioooooooo03coool006Ooool00`0003?o
03?o000a<ol00P0004Coool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`00<3?o00030000
oooooooo04Coool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`00;S?o00800017oooo00?o
09Woooooool0??ooo`00Ioooo`80000]<ol00P0004Woool00ol0VOooooooo`0loooo001Woooo00<0
000co`0co`00:c?o00030000oooooooo04Woool00ol0VOooooooo`0loooo001Woooo00<0000co`0c
o`00:S?o00030000oooooooo04[oool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`00:C?o
00030000oooooooo04_oool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`00:3?o00030000
oooooooo04coool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`00:3?o00030000oooooooo
04coool00ol0VOooooooo`0loooo001Woooo0P0002Pco`000`000?ooooooo`1=oooo00?o09Wooooo
ool0??ooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`1>oooo00?o09Woooooool0??oo
o`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Iooo
o`030000<ol0<ol002@co`000`000?ooooooo`1@oooo00?o09Woooooool0??ooo`00Ioooo`030000
<ol0<ol002<co`000`000?ooooooo`1Aoooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol0
02<co`000`000?ooooooo`1Aoooo00?o09Woooooool0??ooo`00Ioooo`80000S<ol000<0003ooooo
ool0D_ooo`03o`2Ioooooooo03coool006Ooool00`0003?o03?o000Q<ol000<0003oooooool0Dooo
o`03o`2Ioooooooo03coool006Ooool00`0003?o03?o000P<ol000<0003oooooool0E?ooo`03o`2I
oooooooo03coool006Ooool00`0003?o03?o000P<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
03coool006Ooool00`0003?o03?o000O<ol000<0003oooooool0EOooo`03o`2Ioooooooo03coool0
05ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`1Eoooo00?o09Woooooool0??oo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003oooooool0E_ooo`03o`2I
oooooooo03coool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`1Foooo00?o
09Woooooool0??ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003ooooo
ool0Eoooo`03o`2Ioooooooo03coool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o
00030000oooooooo05Ooool00ol0VOooooooo`0loooo001Poooo0P0000Goool00`0003?o03?o000L
<ol000<0003oooooool0F?ooo`03o`2Ioooooooo03coool006Ooool00`0003?o03?o000L<ol000<0
003oooooool0F?ooo`03o`2Ioooooooo03coool006Ooool00`0003?o03?o000K<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo03coool006Ooool2000073?o00030000oooooooo05Woool00ol0VOoo
ooooo`0loooo001Woooo00<0000co`0co`006S?o00030000oooooooo05[oool00ol0VOooooooo`0l
oooo001Woooo00<0000co`0co`006S?o00030000oooooooo05[oool00ol0VOooooooo`0loooo001W
oooo00<0000co`0co`006C?o00030000oooooooo05_oool00ol0VOooooooo`0loooo001Woooo00<0
000co`0co`006C?o00030000oooooooo05_oool00ol0VOooooooo`0loooo001Woooo00<0000co`0c
o`0063?o00030000oooooooo05coool00ol0VOooooooo`0loooo001Woooo0P0001Tco`000`000?oo
ooooo`1Loooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1M
oooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1Moooo00?o
09Woooooool0??ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1Noooo00?o09Wooooo
ool0??ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1Noooo00?o09Woooooool0??oo
o`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1Noooo00?o09Woooooool0??ooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`1Ooooo00?o09Woooooool0??ooo`00Ioooo`80000F
<ol000<0003oooooool0Goooo`03o`2Ioooooooo03coool006Ooool00`0003?o03?o000E<ol000<0
003oooooool0Goooo`03o`2Ioooooooo03coool006Ooool00`0003?o03?o000E<ol000<0003ooooo
ool0Goooo`03o`2Ioooooooo03coool006Ooool00`0003?o03?o000D<ol000<0003oooooool0H?oo
o`03o`2Ioooooooo03coool006Ooool00`0003?o03?o000D<ol000<0003oooooool0H?ooo`03o`2I
oooooooo03coool006Ooool00`0003?o03?o000D<ol000<0003oooooool0H?ooo`03o`2Ioooooooo
03coool006Ooool200005C?o00030000oooooooo063oool00ol0VOooooooo`0loooo001Woooo00<0
000co`0co`004c?o00030000oooooooo067oool00ol0VOooooooo`0loooo001Woooo00<0000co`0c
o`004c?o00030000oooooooo067oool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`004c?o
00030000oooooooo067oool00ol0VOooooooo`0loooo001Ooooo100000Coool00`0003?o03?o000C
<ol000<0003oooooool0HOooo`03o`2Ioooooooo03coool005ooool00`000?ooooooo`05oooo00<0
000co`0co`004S?o00030000oooooooo06;oool00ol0VOooooooo`0loooo001Poooo00<0003ooooo
ool01?ooo`80000C<ol000<0003oooooool0H_ooo`03o`2Ioooooooo03coool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`004S?o00030000oooooooo06;oool00ol0VOooooooo`0loooo001O
oooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo06?oool00ol0VOoo
ooooo`0loooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool0Hoooo`03o`2I
oooooooo03coool006Ooool00`0003?o03?o000A<ol000<0003oooooool0Hoooo`03o`2Ioooooooo
03coool006Ooool00`0003?o03?o000A<ol000<0003oooooool0Hoooo`03o`2Ioooooooo03coool0
06Ooool200004C?o00030000oooooooo06Coool00ol0VOooooooo`0loooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo06Coool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`0043?o
00030000oooooooo06Coool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`0043?o00030000
oooooooo06Coool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`003c?o00030000oooooooo
06Goool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`003c?o00030000oooooooo06Goool0
0ol0VOooooooo`0loooo001Woooo00<0000co`0co`003c?o00030000oooooooo06Goool00ol0VOoo
ooooo`0loooo001Woooo0P00010co`000`000?ooooooo`1Uoooo00?o09Woooooool0??ooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`1Voooo00?o09Woooooool0??ooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`1Voooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`1Voooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`1Voooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`1Woooo00?o09Woooooool0??ooo`00Ioooo`80000><ol000<0003oooooool0Ioooo`03o`2I
oooooooo03coool006Ooool00`0003?o03?o000=<ol000<0003oooooool0Ioooo`03o`2Ioooooooo
03coool006Ooool00`0003?o03?o000=<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03coool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0J?ooo`03o`2Ioooooooo03coool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0J?ooo`03o`2Ioooooooo03coool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0J?ooo`03o`2Ioooooooo03coool006Ooool200003C?o00030000
oooooooo06Soool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`0033?o00030000oooooooo
06Soool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`0033?o00030000oooooooo06Soool0
0ol0VOooooooo`0loooo001Woooo00<0000co`0co`002c?o00030000oooooooo06Woool00ol0VOoo
ooooo`0loooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool0JOooo`03o`2I
oooooooo03coool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003ooooo
ool0JOooo`03o`2Ioooooooo03coool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?oo
ooooo`1Yoooo00?o09Woooooool0??ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;
<ol000<0003oooooool0JOooo`03o`2Ioooooooo03coool005ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0JOooo`03o`2Ioooooooo03coool0063oool200001Ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`1Zoooo00?o09Woooooool0??ooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`1Zoooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`1Zoooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`1Zoooo00?o09Woooooool0??ooo`00Ioooo`80000;<ol000<0003oooooool0J_oo
o`03o`2Ioooooooo03coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0J_ooo`03o`2I
oooooooo03coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Joooo`03o`2Ioooooooo
03coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Joooo`03o`2Ioooooooo03coool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0Joooo`03o`2Ioooooooo03coool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0Joooo`03o`2Ioooooooo03coool006Ooool200002S?o
00030000oooooooo06_oool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`002C?o00030000
oooooooo06_oool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`002C?o00030000oooooooo
06_oool00ol0VOooooooo`0loooo001Woooo00<0000co`0co`0023?o00030000oooooooo06coool0
0ol0VOooooooo`0loooo001Woooo00<0000co`0co`0023?o00030000oooooooo06coool00ol0VOoo
ooooo`0loooo001Woooo00<0000co`0co`0023?o00030000oooooooo06coool00ol0VOooooooo`0l
oooo001Woooo0P0000Tco`000`000?ooooooo`1/oooo00?o09Woooooool0??ooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1/oooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1/oooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1]oooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1]oooo00?o09Woooooool0??ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1]
oooo00?o09Woooooool0??ooo`00Ioooo`800008<ol000<0003oooooool0KOooo`03o`2Ioooooooo
03coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0KOooo`03o`2Ioooooooo03coool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0KOooo`03o`2Ioooooooo03coool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0KOooo`03o`2Ioooooooo03coool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0KOooo`03o`2Ioooooooo03coool0067oool300000oooo`030000
<ol0<ol000Lco`000`000?ooooooo`1]oooo00?o09Woooooool0??ooo`00H_ooo`030000oooooooo
00;oool00`0003?o03?o0007<ol000<0003oooooool0KOooo`03o`2Ioooooooo03coool005ooool5
00000oooo`800008<ol000<0003oooooool0KOooo`03o`2Ioooooooo03coool005ooool010000?oo
ooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004
oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo1@0000;oool200001?ooo`800003oooo100000?oool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00002oooo00<0003ooooo
ool01?ooo`030000oooooooo07Soool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?oo
ooooo`0?oooo00<0003oooooool02_ooo`050000oooooooooooo000000Koool00`000?ooooooo`1g
oooo001Woooo2C?o00Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Soool200001Ooo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?oooooooooo
o`00000Aoooo00<0003oooooool02?ooo`030000oooooooo00;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000[oool300000ooo
o`800003oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.80799 .12361 L
.81909 .12361 L
.8239 .12361 L
.82654 .12361 L
.82784 .12361 L
.82904 .12361 L
.82973 .12361 L
s
.82973 .12361 m
.83002 .61803 L
s
0 .4 1 r
.02381 .0635 m
.03279 .0629 L
.04262 .0624 L
.04758 .06221 L
.05288 .06205 L
.05546 .06199 L
.05789 .06194 L
.06024 .0619 L
.06244 .06187 L
.06487 .06184 L
.06616 .06183 L
.06754 .06182 L
.06824 .06181 L
.06899 .06181 L
.06966 .06181 L
.07037 .06181 L
.07107 .0618 L
.07171 .0618 L
.07295 .0618 L
.0742 .06181 L
.07535 .06181 L
.07661 .06181 L
.07794 .06182 L
.08019 .06184 L
.08265 .06187 L
.08812 .06195 L
.09399 .06207 L
.10458 .06238 L
.11475 .06277 L
.12582 .06328 L
.14594 .06444 L
.18672 .06745 L
.22599 .07089 L
.26374 .07447 L
.30394 .07837 L
.32242 .08016 L
.33289 .08117 L
.34263 .0821 L
.35232 .08283 L
.35774 .08313 L
.36267 .08333 L
.36788 .08349 L
.37082 .08356 L
.37222 .08358 L
.37352 .0836 L
.37589 .08363 L
.37715 .08364 L
.37785 .08364 L
.3785 .08365 L
.37918 .08365 L
Mistroke
.37991 .08365 L
.38056 .08365 L
.38125 .08365 L
.38257 .08365 L
.38377 .08365 L
.38498 .08364 L
.3861 .08363 L
.38866 .0836 L
.39115 .08357 L
.39382 .08352 L
.39865 .08341 L
.40306 .08328 L
.41376 .08288 L
.42389 .08237 L
.44384 .0811 L
.46227 .07964 L
.50159 .07582 L
.53939 .07141 L
.57965 .06613 L
.61839 .06059 L
.65958 .05435 L
.69926 .04814 L
.73742 .04217 L
.77803 .03608 L
.7968 .03345 L
.81713 .03081 L
.82254 .03015 L
.8255 .0298 L
.82694 .02963 L
.82826 .02948 L
.82947 .02934 L
.83062 .12361 L
.83183 .12361 L
.83315 .12361 L
.83851 .12361 L
.85868 .12361 L
.89943 .12361 L
.93866 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1coooo1`1Voccoool0
06Ooool00`000?ooooooo`1Yoooo2P1Vo`Koool00`1Vooooooooo`0joooo001Woooo00<0003ooooo
ool0I?ooo`D0I_l@oooo00<0I_ooooooool0>_ooo`00Ioooo`030000oooooooo05goool706Ko5Ooo
o`0306Kooooooooo03[oool006Ooool00`000?ooooooo`1Eoooo201Voacoool00`1Vooooooooo`0j
oooo001Woooo0P00057oool506Ko9?ooo`0306Kooooooooo03[oool006Ooool00`000?ooooooo`19
oooo1`1VobWoool00`1Vooooooooo`0joooo001Woooo00<0003oooooool0@Oooo`P0I_l`oooo00<0
I_ooooooool0>_ooo`005_ooobD0I_l/oooo00<0003oooooool0??ooo`D0I_lhoooo00<0I_oooooo
ool0>_ooo`00>oooo`X0I_lRoooo00<0003oooooool0=Oooo`L0I_lmoooo00<0I_ooooooool0>_oo
o`00AOooo`T0I_lIoooo00<0003oooooool0:oooo`X0I_m4oooo00<0I_ooooooool0>_ooo`00C_oo
o`X0I_l?oooo0P0002;oool:06KoC_ooo`0306Kooooooooo03[oool001Ooool500007_ooo`800004
oooo0P0000Coool200004?ooo``0I_l3oooo00<0003oooooool06_ooo`@0I_l2000000@0I_oooooo
ooooool200001?ooo`80000Ooooo1@0001goool500000_ooo`800003oooo00<0I_l0000000008?oo
o`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002?ooo`040000oooooooo
00006oooo`<0I_l00`00001Vo`1Vo`0J06Ko0oooo`040000oooooooo00002?ooo`040000oooooooo
00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0003oooooool0000Ooooo00<0
003oooooool05oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000_oool00`000?oo
ooooo`0Loooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo01koool0
0`000?ooooooo`0Ooooo00<0003oooooool01oooo`0406Kooooooooo00008?ooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Ooo
o`80000Ooooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`80000Qoooo00<0003ooooo
ool07oooo`030000oooooooo00Ooool00`1Vo`000000000Roooo00<0003oooooool05Oooo`006Ooo
o`030000oooooooo01goool010000?ooooooo`0000Woool00`000?ooooooo`0Noooo00<0003ooooo
ool07Oooo`040000oooooooo00002Oooo`030000oooooooo023oool00`000?ooooooo`0Ooooo00<0
003oooooool01oooo`0306Ko0000oooo023oool010000?ooooooo`0001Koool001Soool200008?oo
o`80000:oooo0`0001koool200007oooo`80000:oooo0`0001ooool200008?ooo`800009oooo00@0
I_l000000000000Poooo0P0001Ooool006Ooool00`000?ooooooo`1ioooo00<0I_ooooooool0>_oo
o`00Ioooo`030000oooooooo07Woool00`1Vooooooooo`0joooo001Woooo00<0003oooooool0NOoo
o`0306Kooooooooo03[oool006Ooool00`000?ooooooo`1ioooo00<0I_ooooooool0>_ooo`00Iooo
o`030000oooooooo07Woool00`1Vooooooooo`0joooo000@ooooo`00017oool001Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol07@000003o`2I00000000
00P00002oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0c
o`009C?o00030000<ol0<ol002@co`0@00006Oooo`050000ooooooooooooo`2I02Coool00`000?oo
ooooo`0Eoooo001Woooo00<0000co`0co`00Ac?o00D0000]oooo00?o09Woooooool0>_ooo`00Iooo
o`030000<ol0<ol0048co`050000<_ooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o000m
<ol01@0003Ooool00ol0VOooooooo`0joooo001Woooo00<0000co`0co`00>C?o00@0000loooo00?o
09Woooooool0>_ooo`00Ioooo`80000h<ol00P00043oool00ol0VOooooooo`0joooo001Woooo00<0
000co`0co`00=C?o00800012oooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol003<co`02
0000A?ooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o000a<ol00P0004Koool00ol0VOoo
ooooo`0joooo001Woooo00<0000co`0co`00<3?o00030000oooooooo04Koool00ol0VOooooooo`0j
oooo001Woooo00<0000co`0co`00;S?o00800019oooo00?o09Woooooool0>_ooo`00Ioooo`80000]
<ol00P0004_oool00ol0VOooooooo`0joooo001Woooo00<0000co`0co`00:c?o00030000oooooooo
04_oool00ol0VOooooooo`0joooo001Woooo00<0000co`0co`00:S?o00030000oooooooo04coool0
0ol0VOooooooo`0joooo001Woooo00<0000co`0co`00:C?o00030000oooooooo04goool00ol0VOoo
ooooo`0joooo001Woooo00<0000co`0co`00:3?o00030000oooooooo04koool00ol0VOooooooo`0j
oooo001Woooo00<0000co`0co`00:3?o00030000oooooooo04koool00ol0VOooooooo`0joooo001W
oooo0P0002Pco`000`000?ooooooo`1?oooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol0
02Hco`000`000?ooooooo`1@oooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol002Dco`00
0`000?ooooooo`1Aoooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol002@co`000`000?oo
ooooo`1Boooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`1C
oooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`1Coooo00?o
09Woooooool0>_ooo`00Ioooo`80000S<ol000<0003oooooool0E?ooo`03o`2Ioooooooo03[oool0
06Ooool00`0003?o03?o000Q<ol000<0003oooooool0EOooo`03o`2Ioooooooo03[oool006Ooool0
0`0003?o03?o000P<ol000<0003oooooool0E_ooo`03o`2Ioooooooo03[oool006Ooool00`0003?o
03?o000P<ol000<0003oooooool0E_ooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o000O
<ol000<0003oooooool0Eoooo`03o`2Ioooooooo03[oool005ooool500000oooo`030000<ol0<ol0
01lco`000`000?ooooooo`1Goooo00?o09Woooooool0>_ooo`00HOooo`030000oooooooo00?oool0
0`0003?o03?o000N<ol000<0003oooooool0F?ooo`03o`2Ioooooooo03[oool0067oool00`000?oo
ooooo`03oooo0P0001lco`000`000?ooooooo`1Hoooo00?o09Woooooool0>_ooo`00HOooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0FOooo`03o`2Ioooooooo03[oool0
067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo05Woool00ol0VOoo
ooooo`0joooo001Poooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0F_ooo`03o`2I
oooooooo03[oool006Ooool00`0003?o03?o000L<ol000<0003oooooool0F_ooo`03o`2Ioooooooo
03[oool006Ooool00`0003?o03?o000K<ol000<0003oooooool0Foooo`03o`2Ioooooooo03[oool0
06Ooool2000073?o00030000oooooooo05_oool00ol0VOooooooo`0joooo001Woooo00<0000co`0c
o`006S?o00030000oooooooo05coool00ol0VOooooooo`0joooo001Woooo00<0000co`0co`006S?o
00030000oooooooo05coool00ol0VOooooooo`0joooo001Woooo00<0000co`0co`006C?o00030000
oooooooo05goool00ol0VOooooooo`0joooo001Woooo00<0000co`0co`006C?o00030000oooooooo
05goool00ol0VOooooooo`0joooo001Woooo00<0000co`0co`0063?o00030000oooooooo05koool0
0ol0VOooooooo`0joooo001Woooo0P0001Tco`000`000?ooooooo`1Noooo00?o09Woooooool0>_oo
o`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1Ooooo00?o09Woooooool0>_ooo`00Iooo
o`030000<ol0<ol001Lco`000`000?ooooooo`1Ooooo00?o09Woooooool0>_ooo`00Ioooo`030000
<ol0<ol001Hco`000`000?ooooooo`1Poooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol0
01Hco`000`000?ooooooo`1Poooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol001Hco`00
0`000?ooooooo`1Poooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1Qoooo00?o09Woooooool0>_ooo`00Ioooo`80000F<ol000<0003oooooool0HOooo`03o`2I
oooooooo03[oool006Ooool00`0003?o03?o000E<ol000<0003oooooool0HOooo`03o`2Ioooooooo
03[oool006Ooool00`0003?o03?o000E<ol000<0003oooooool0HOooo`03o`2Ioooooooo03[oool0
06Ooool00`0003?o03?o000D<ol000<0003oooooool0H_ooo`03o`2Ioooooooo03[oool006Ooool0
0`0003?o03?o000D<ol000<0003oooooool0H_ooo`03o`2Ioooooooo03[oool006Ooool00`0003?o
03?o000D<ol000<0003oooooool0H_ooo`03o`2Ioooooooo03[oool006Ooool200005C?o00030000
oooooooo06;oool00ol0VOooooooo`0joooo001Woooo00<0000co`0co`004c?o00030000oooooooo
06?oool00ol0VOooooooo`0joooo001Woooo00<0000co`0co`004c?o00030000oooooooo06?oool0
0ol0VOooooooo`0joooo001Woooo00<0000co`0co`004c?o00030000oooooooo06?oool00ol0VOoo
ooooo`0joooo001Ooooo100000Coool00`0003?o03?o000C<ol000<0003oooooool0Hoooo`03o`2I
oooooooo03[oool005ooool00`000?ooooooo`05oooo00<0000co`0co`004S?o00030000oooooooo
06Coool00ol0VOooooooo`0joooo001Poooo00<0003oooooool01?ooo`80000C<ol000<0003ooooo
ool0I?ooo`03o`2Ioooooooo03[oool0067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o
00030000oooooooo06Coool00ol0VOooooooo`0joooo001Ooooo00@0003oooooool00004oooo00<0
000co`0co`004C?o00030000oooooooo06Goool00ol0VOooooooo`0joooo001Poooo0P0000Goool0
0`0003?o03?o000A<ol000<0003oooooool0IOooo`03o`2Ioooooooo03[oool006Ooool00`0003?o
03?o000A<ol000<0003oooooool0IOooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o000A
<ol000<0003oooooool0IOooo`03o`2Ioooooooo03[oool006Ooool200004C?o00030000oooooooo
06Koool00ol0VOooooooo`0joooo001Woooo00<0000co`0co`0043?o00030000oooooooo06Koool0
0ol0VOooooooo`0joooo001Woooo00<0000co`0co`0043?o00030000oooooooo06Koool00ol0VOoo
ooooo`0joooo001Woooo00<0000co`0co`0043?o00030000oooooooo06Koool00ol0VOooooooo`0j
oooo001Woooo00<0000co`0co`003c?o00030000oooooooo06Ooool00ol0VOooooooo`0joooo001W
oooo00<0000co`0co`003c?o00030000oooooooo06Ooool00ol0VOooooooo`0joooo001Woooo00<0
000co`0co`003c?o00030000oooooooo06Ooool00ol0VOooooooo`0joooo001Woooo0P00010co`00
0`000?ooooooo`1Woooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol000hco`000`000?oo
ooooo`1Xoooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1X
oooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Xoooo00?o
09Woooooool0>_ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1Xoooo00?o09Wooooo
ool0>_ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1Yoooo00?o09Woooooool0>_oo
o`00Ioooo`80000><ol000<0003oooooool0JOooo`03o`2Ioooooooo03[oool006Ooool00`0003?o
03?o000=<ol000<0003oooooool0JOooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o000=
<ol000<0003oooooool0JOooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o000<<ol000<0
003oooooool0J_ooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool0J_ooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0J_oo
o`03o`2Ioooooooo03[oool006Ooool200003C?o00030000oooooooo06[oool00ol0VOooooooo`0j
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo06[oool00ol0VOooooooo`0joooo001W
oooo00<0000co`0co`0033?o00030000oooooooo06[oool00ol0VOooooooo`0joooo001Woooo00<0
000co`0co`002c?o00030000oooooooo06_oool00ol0VOooooooo`0joooo001Poooo0P0000Goool0
0`0003?o03?o000;<ol000<0003oooooool0Joooo`03o`2Ioooooooo03[oool005ooool010000?oo
ooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Joooo`03o`2Ioooooooo03[oool0
067oool00`000?ooooooo`03oooo0P0000`co`000`000?ooooooo`1[oooo00?o09Woooooool0>_oo
o`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0Joooo`03o`2I
oooooooo03[oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003ooooo
ool0Joooo`03o`2Ioooooooo03[oool0063oool200001Oooo`030000<ol0<ol000Xco`000`000?oo
ooooo`1/oooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1/
oooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1/oooo00?o
09Woooooool0>_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1/oooo00?o09Wooooo
ool0>_ooo`00Ioooo`80000;<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03[oool006Ooool0
0`0003?o03?o000:<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03[oool006Ooool00`0003?o
03?o0009<ol000<0003oooooool0KOooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o0009
<ol000<0003oooooool0KOooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o0009<ol000<0
003oooooool0KOooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0KOooo`03o`2Ioooooooo03[oool006Ooool200002S?o00030000oooooooo06goool00ol0VOoo
ooooo`0joooo001Woooo00<0000co`0co`002C?o00030000oooooooo06goool00ol0VOooooooo`0j
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo06goool00ol0VOooooooo`0joooo001W
oooo00<0000co`0co`0023?o00030000oooooooo06koool00ol0VOooooooo`0joooo001Woooo00<0
000co`0co`0023?o00030000oooooooo06koool00ol0VOooooooo`0joooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo06koool00ol0VOooooooo`0joooo001Woooo0P0000Tco`000`000?oo
ooooo`1^oooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1^
oooo00?o09Woooooool0>_ooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1^oooo00?o
09Woooooool0>_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1_oooo00?o09Wooooo
ool0>_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1_oooo00?o09Woooooool0>_oo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1_oooo00?o09Woooooool0>_ooo`00Iooo
o`800008<ol000<0003oooooool0Koooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0Koooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0Koooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Koooo`03o`2Ioooooooo03[oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Kooo
o`03o`2Ioooooooo03[oool0067oool300000oooo`030000<ol0<ol000Lco`000`000?ooooooo`1_
oooo00?o09Woooooool0>_ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o0007<ol000<0
003oooooool0Koooo`03o`2Ioooooooo03[oool005ooool500000oooo`800008<ol000<0003ooooo
ool0Koooo`03o`2Ioooooooo03[oool005ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?oo
o`030000oooo000000Coool:<ol0[oooo`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?oo
o`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00
00;oool200001?ooo`800005oooo0`0000;oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00@0003oooooool00005oooo00D0003oooooooooool00000N_ooo`00Ioooo`Tco`07
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`0:oooo00<0003ooooo
ool01@0000?oool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003_oo
o`030000oooooooo00Soool200000oooo`040000oooooooo00000oooo`030000oooooooo07Soool0
06Ooool9<ol02?ooo`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003ooooo
ool00oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?oo
ooooo`0Aoooo0P0000[oool300001?ooo`800002oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`
oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.80799 .12361 L
.81909 .12361 L
.82904 .12361 L
.83177 .12361 L
.83327 .12361 L
.83469 .12361 L
.83601 .12361 L
s
.83601 .12361 m
.83631 .61803 L
s
0 .4 1 r
.02381 .06306 m
.03279 .06256 L
.04262 .06217 L
.04758 .06203 L
.0503 .06196 L
.05288 .06191 L
.05528 .06188 L
.05789 .06185 L
.05904 .06183 L
.06026 .06182 L
.0613 .06182 L
.06244 .06181 L
.06314 .06181 L
.06378 .06181 L
.06505 .0618 L
.0662 .0618 L
.06743 .0618 L
.06813 .06181 L
.06888 .06181 L
.06959 .06181 L
.07025 .06181 L
.07157 .06182 L
.0728 .06183 L
.07505 .06185 L
.07751 .06188 L
.0825 .06196 L
.08807 .06208 L
.09315 .06222 L
.10458 .06261 L
.12366 .0635 L
.14443 .06476 L
.18521 .06785 L
.22447 .07134 L
.26222 .07493 L
.30243 .07884 L
.3209 .08063 L
.33137 .08163 L
.34111 .08256 L
.3508 .08334 L
.35623 .08365 L
.36116 .08388 L
.36636 .08406 L
.3693 .08413 L
.37201 .08418 L
.37438 .08422 L
.37573 .08423 L
.37699 .08424 L
.37767 .08425 L
.37831 .08425 L
.37953 .08426 L
Mistroke
.38083 .08426 L
.38157 .08426 L
.38225 .08426 L
.38355 .08426 L
.3842 .08425 L
.38491 .08425 L
.38617 .08424 L
.38735 .08423 L
.39 .0842 L
.39285 .08416 L
.39807 .08405 L
.40282 .08392 L
.41238 .08357 L
.42144 .08315 L
.44139 .08195 L
.45982 .08055 L
.49914 .07684 L
.53694 .07254 L
.5772 .06734 L
.61593 .06188 L
.65713 .0557 L
.6968 .04952 L
.73496 .04353 L
.77558 .03735 L
.81467 .03192 L
.82494 .03062 L
.83035 .02997 L
.8333 .02962 L
.83474 .02946 L
.83606 .02931 L
.8373 .12361 L
.83847 .12361 L
.84106 .12361 L
.84656 .12361 L
.85622 .12361 L
.89452 .12361 L
.93527 .12361 L
.97451 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo07[oool00`1Vooooooooo`0ioooo001Woooo00<0003ooooo
ool0Loooo`P0I_lkoooo001Woooo00<0003oooooool0K_ooo`D0I_l7oooo00<0I_ooooooool0>Ooo
o`00Ioooo`030000oooooooo06Ooool706Ko3?ooo`0306Kooooooooo03Woool006Ooool00`000?oo
ooooo`1Ooooo201Voa?oool00`1Vooooooooo`0ioooo001Woooo00<0003oooooool0F_ooo`D0I_lK
oooo00<0I_ooooooool0>Oooo`00Ioooo`80001Doooo1`1Vob3oool00`1Vooooooooo`0ioooo001W
oooo00<0003oooooool0Boooo`P0I_lWoooo00<0I_ooooooool0>Oooo`00Ioooo`030000oooooooo
04Goool606Ko;oooo`0306Kooooooooo03Woool001KooolT06Ko;Oooo`030000oooooooo03koool7
06Ko=Oooo`0306Kooooooooo03Woool003[oool:06Ko8oooo`030000oooooooo03Coool:06Ko??oo
o`0306Kooooooooo03Woool004Coool:06Ko6Oooo`030000oooooooo02coool806KoA_ooo`0306Ko
oooooooo03Woool004koool:06Ko3oooo`80000Yoooo101Vodkoool00`1Vooooooooo`0ioooo000G
oooo1@0001koool200001?ooo`800004oooo0P00013oool806Ko1oooo`030000oooooooo01Woool5
06Ko0P0000@0I_l200000P1Vo`;oool200007oooo`D0000Moooo1@0000;oool200001?ooo`80000P
oooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008oooo00@0003ooooo
ool0000Goooo1`1Vo`03000006Ko06Ko01T0I_l4oooo00@0003oooooool00008oooo00@0003ooooo
ool0000Poooo00<0003oooooool07oooo`030000oooooooo00Ooool01000001Vooooo`0001ooool0
0`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002oooo`030000
oooooooo01coool00`000?ooooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool07_oo
o`030000oooooooo01ooool00`000?ooooooo`08oooo00<0I_ooool000008?ooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Ooo
o`80000Ooooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`80000Qoooo00<0003ooooo
ool07oooo`030000oooooooo00Soool200008_ooo`030000oooooooo01Goool001Woool00`000?oo
ooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool07_ooo`030000oooooooo01goool0
10000?ooooooo`0000Woool00`000?ooooooo`0Poooo00<0003oooooool07oooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00@0003oooooool0000Foooo000Hoooo0P00023oool200002_oo
o`<0000Noooo0P0001ooool200002_ooo`<0000Ooooo0P00023oool200002_ooo`<0000Poooo0P00
01Ooool006Ooool00`000?ooooooo`1joooo00<0I_ooooooool0>Oooo`00Ioooo`030000oooooooo
07[oool00`1Vooooooooo`0ioooo001Woooo00<0003oooooool0N_ooo`0306Kooooooooo03Woool0
06Ooool00`000?ooooooo`1joooo00<0I_ooooooool0>Oooo`00Ioooo`030000oooooooo07[oool0
0`1Vooooooooo`0ioooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0004<ol07P000003o`2I0000000000L00002oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o00030000<ol0<ol0
02@co`0@00006Oooo`030000oooooooo00;oool00ol0VOooooooo`0Qoooo00<0003oooooool05Ooo
o`00Ioooo`030000<ol0<ol004Lco`050000;_ooo`03o`2Ioooooooo03Woool006Ooool00`0003?o
03?o0012<ol01@0003?oool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`00?C?o00D0000h
oooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol003Tco`040000?Oooo`03o`2Ioooooooo
03Woool006Ooool20000>3?o00800011oooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol0
03Dco`020000@oooo`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000c<ol00P0004Goool0
0ol0VOooooooo`0ioooo001Woooo00<0000co`0co`00<C?o00800017oooo00?o09Woooooool0>Ooo
o`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`17oooo00?o09Woooooool0>Oooo`00Iooo
o`030000<ol0<ol002hco`020000B_ooo`03o`2Ioooooooo03Woool006Ooool20000;C?o0080001<
oooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`1<oooo00?o
09Woooooool0>Oooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`1=oooo00?o09Wooooo
ool0>Oooo`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`1>oooo00?o09Woooooool0>Ooo
o`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`1?oooo00?o09Woooooool0>Oooo`00Iooo
o`030000<ol0<ol002Pco`000`000?ooooooo`1?oooo00?o09Woooooool0>Oooo`00Ioooo`80000X
<ol000<0003oooooool0D?ooo`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000V<ol000<0
003oooooool0DOooo`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000U<ol000<0003ooooo
ool0D_ooo`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000T<ol000<0003oooooool0Dooo
o`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000S<ol000<0003oooooool0E?ooo`03o`2I
oooooooo03Woool006Ooool00`0003?o03?o000S<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
03Woool006Ooool200008c?o00030000oooooooo05Goool00ol0VOooooooo`0ioooo001Woooo00<0
000co`0co`008C?o00030000oooooooo05Koool00ol0VOooooooo`0ioooo001Woooo00<0000co`0c
o`0083?o00030000oooooooo05Ooool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`0083?o
00030000oooooooo05Ooool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`007c?o00030000
oooooooo05Soool00ol0VOooooooo`0ioooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0
003oooooool0F?ooo`03o`2Ioooooooo03Woool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`007S?o00030000oooooooo05Woool00ol0VOooooooo`0ioooo001Qoooo00<0003oooooool00ooo
o`80000O<ol000<0003oooooool0FOooo`03o`2Ioooooooo03Woool0067oool00`000?ooooooo`03
oooo00<0000co`0co`007C?o00030000oooooooo05[oool00ol0VOooooooo`0ioooo001Qoooo00<0
003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`1Joooo00?o09Woooooool0>Ooo
o`00H?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo05_oool00ol0VOooooooo`0i
oooo001Woooo00<0000co`0co`0073?o00030000oooooooo05_oool00ol0VOooooooo`0ioooo001W
oooo00<0000co`0co`006c?o00030000oooooooo05coool00ol0VOooooooo`0ioooo001Woooo0P00
01`co`000`000?ooooooo`1Loooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol001Xco`00
0`000?ooooooo`1Moooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol001Xco`000`000?oo
ooooo`1Moooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`1N
oooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`1Noooo00?o
09Woooooool0>Oooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`1Ooooo00?o09Wooooo
ool0>Oooo`00Ioooo`80000I<ol000<0003oooooool0Goooo`03o`2Ioooooooo03Woool006Ooool0
0`0003?o03?o000G<ol000<0003oooooool0H?ooo`03o`2Ioooooooo03Woool006Ooool00`0003?o
03?o000G<ol000<0003oooooool0H?ooo`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000F
<ol000<0003oooooool0HOooo`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000F<ol000<0
003oooooool0HOooo`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000F<ol000<0003ooooo
ool0HOooo`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000E<ol000<0003oooooool0H_oo
o`03o`2Ioooooooo03Woool006Ooool200005S?o00030000oooooooo06;oool00ol0VOooooooo`0i
oooo001Woooo00<0000co`0co`005C?o00030000oooooooo06;oool00ol0VOooooooo`0ioooo001W
oooo00<0000co`0co`005C?o00030000oooooooo06;oool00ol0VOooooooo`0ioooo001Woooo00<0
000co`0co`0053?o00030000oooooooo06?oool00ol0VOooooooo`0ioooo001Woooo00<0000co`0c
o`0053?o00030000oooooooo06?oool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`0053?o
00030000oooooooo06?oool00ol0VOooooooo`0ioooo001Woooo0P0001Dco`000`000?ooooooo`1S
oooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1Toooo00?o
09Woooooool0>Oooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1Toooo00?o09Wooooo
ool0>Oooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1Toooo00?o09Woooooool0>Ooo
o`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo06Coool00ol0VOooooooo`0i
oooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`1Uoooo00?o
09Woooooool0>Oooo`00H?ooo`030000oooooooo00Coool200004c?o00030000oooooooo06Goool0
0ol0VOooooooo`0ioooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?oo
ooooo`1Uoooo00?o09Woooooool0>Oooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0
014co`000`000?ooooooo`1Voooo00?o09Woooooool0>Oooo`00H?ooo`800005oooo00<0000co`0c
o`004C?o00030000oooooooo06Koool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`004C?o
00030000oooooooo06Koool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`004C?o00030000
oooooooo06Koool00ol0VOooooooo`0ioooo001Woooo0P00014co`000`000?ooooooo`1Woooo00?o
09Woooooool0>Oooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1Woooo00?o09Wooooo
ool0>Oooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1Woooo00?o09Woooooool0>Ooo
o`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1Woooo00?o09Woooooool0>Oooo`00Iooo
o`030000<ol0<ol000lco`000`000?ooooooo`1Xoooo00?o09Woooooool0>Oooo`00Ioooo`030000
<ol0<ol000lco`000`000?ooooooo`1Xoooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol0
00lco`000`000?ooooooo`1Xoooo00?o09Woooooool0>Oooo`00Ioooo`80000@<ol000<0003ooooo
ool0J?ooo`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0JOoo
o`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0JOooo`03o`2I
oooooooo03Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0JOooo`03o`2Ioooooooo
03Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0JOooo`03o`2Ioooooooo03Woool0
06Ooool00`0003?o03?o000=<ol000<0003oooooool0J_ooo`03o`2Ioooooooo03Woool006Ooool2
00003S?o00030000oooooooo06[oool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`003C?o
00030000oooooooo06[oool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`003C?o00030000
oooooooo06[oool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`0033?o00030000oooooooo
06_oool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`0033?o00030000oooooooo06_oool0
0ol0VOooooooo`0ioooo001Woooo00<0000co`0co`0033?o00030000oooooooo06_oool00ol0VOoo
ooooo`0ioooo001Woooo0P0000dco`000`000?ooooooo`1[oooo00?o09Woooooool0>Oooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`1[oooo00?o09Woooooool0>Oooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`1[oooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol0
00/co`000`000?ooooooo`1/oooo00?o09Woooooool0>Oooo`00H?ooo`800005oooo00<0000co`0c
o`002c?o00030000oooooooo06coool00ol0VOooooooo`0ioooo001Ooooo00@0003oooooool00004
oooo00<0000co`0co`002c?o00030000oooooooo06coool00ol0VOooooooo`0ioooo001Qoooo00<0
003oooooool00oooo`80000<<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03Woool006;oool0
0`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo06coool00ol0VOooooooo`0i
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo06coool0
0ol0VOooooooo`0ioooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0KOoo
o`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o000:<ol000<0003oooooool0KOooo`03o`2I
oooooooo03Woool006Ooool00`0003?o03?o000:<ol000<0003oooooool0KOooo`03o`2Ioooooooo
03Woool006Ooool00`0003?o03?o000:<ol000<0003oooooool0KOooo`03o`2Ioooooooo03Woool0
06Ooool200002c?o00030000oooooooo06goool00ol0VOooooooo`0ioooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo06goool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`002C?o
00030000oooooooo06koool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`002C?o00030000
oooooooo06koool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`002C?o00030000oooooooo
06koool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`002C?o00030000oooooooo06koool0
0ol0VOooooooo`0ioooo001Woooo0P0000Xco`000`000?ooooooo`1^oooo00?o09Woooooool0>Ooo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1^oooo00?o09Woooooool0>Oooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1^oooo00?o09Woooooool0>Oooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1_oooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1_oooo00?o09Woooooool0>Oooo`00Ioooo`030000<ol0<ol000Pco`00
0`000?ooooooo`1_oooo00?o09Woooooool0>Oooo`00Ioooo`800009<ol000<0003oooooool0Kooo
o`03o`2Ioooooooo03Woool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Koooo`03o`2I
oooooooo03Woool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Koooo`03o`2Ioooooooo
03Woool006Ooool00`0003?o03?o0007<ol000<0003oooooool0L?ooo`03o`2Ioooooooo03Woool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0L?ooo`03o`2Ioooooooo03Woool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0L?ooo`03o`2Ioooooooo03Woool006Ooool2000023?o
00030000oooooooo073oool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`001c?o00030000
oooooooo073oool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`001c?o00030000oooooooo
073oool00ol0VOooooooo`0ioooo001Woooo00<0000co`0co`001c?o00030000oooooooo073oool0
0ol0VOooooooo`0ioooo001Woooo00<0000co`0co`001c?o00030000oooooooo073oool00ol0VOoo
ooooo`0ioooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003oooooool0L?ooo`03o`2I
oooooooo03Woool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo
073oool00ol0VOooooooo`0ioooo001Ooooo1@0000?oool2000023?o00030000oooooooo073oool0
0ol0VOooooooo`0ioooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?oo
o`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9
<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9
<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Iooo
o`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P00
00Coool200000oooo`<00004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9
<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02_ooo`040000
oooooooo00000_ooo`030000oooooooo00;oool00`000?ooooooo`1goooo001Woooo2C?o00Soool0
0`000?ooooooo`0500003_ooo`030000oooooooo00Soool200000oooo`<00004oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000004Oooo`030000oooooooo00Soool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Soool006Ooool9<ol02Ooo
o`030000oooooooo017oool200002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1ioooo001W
oooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.81909 .12361 L
.82924 .12361 L
.83479 .12361 L
.83749 .12361 L
.83996 .12361 L
.84105 .12361 L
.84223 .12361 L
s
.84223 .12361 m
.84268 .61803 L
s
0 .4 1 r
.02381 .06269 m
.02846 .06247 L
.03279 .06229 L
.03793 .06212 L
.04262 .06199 L
.04498 .06194 L
.04754 .0619 L
.04976 .06187 L
.0522 .06184 L
.05344 .06183 L
.05478 .06182 L
.05552 .06181 L
.0562 .06181 L
.05689 .06181 L
.05753 .06181 L
.05873 .0618 L
.06005 .0618 L
.06121 .0618 L
.06244 .06181 L
.0631 .06181 L
.06383 .06181 L
.06529 .06182 L
.06791 .06184 L
.07097 .06188 L
.07382 .06192 L
.079 .06202 L
.08454 .06215 L
.09502 .06249 L
.10458 .06288 L
.12366 .06386 L
.14443 .06519 L
.18521 .06839 L
.22447 .07193 L
.26222 .07555 L
.30243 .07946 L
.3209 .08124 L
.33137 .08224 L
.34111 .08316 L
.3508 .08393 L
.35623 .08425 L
.36116 .08448 L
.36636 .08465 L
.3693 .08473 L
.37201 .08478 L
.37438 .08482 L
.37573 .08483 L
.37699 .08485 L
.37767 .08485 L
.37831 .08485 L
.37953 .08486 L
Mistroke
.38083 .08486 L
.38157 .08487 L
.38225 .08486 L
.38355 .08486 L
.3842 .08486 L
.38491 .08486 L
.38617 .08485 L
.38735 .08484 L
.39 .08481 L
.39285 .08477 L
.39807 .08467 L
.40282 .08454 L
.41238 .0842 L
.42144 .08379 L
.44139 .08261 L
.45982 .08124 L
.49914 .07759 L
.53694 .07334 L
.5772 .06821 L
.61593 .0628 L
.65713 .05666 L
.6968 .05051 L
.73496 .04451 L
.77558 .03829 L
.81467 .03274 L
.82494 .03141 L
.83035 .03073 L
.83606 .03004 L
.83847 .02976 L
.84106 .02945 L
.84183 .02937 L
.84255 .02928 L
.8432 .12361 L
.8439 .12361 L
.84656 .12361 L
.85622 .12361 L
.89697 .12361 L
.93621 .12361 L
.97393 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo07coool00`1Vooooooooo`0goooo001Woooo00<0003ooooo
ool0Loooo`X0I_lioooo001Woooo00<0003oooooool0K_ooo`D0I_l9oooo00<0I_ooooooool0=ooo
o`00Ioooo`030000oooooooo06Ooool706Ko3_ooo`0306Kooooooooo03Ooool006Ooool00`000?oo
ooooo`1Ooooo201VoaGoool00`1Vooooooooo`0goooo001Woooo00<0003oooooool0F_ooo`D0I_lM
oooo00<0I_ooooooool0=oooo`00Ioooo`80001Doooo1`1Vob;oool00`1Vooooooooo`0goooo001W
oooo00<0003oooooool0Boooo`P0I_lYoooo00<0I_ooooooool0=oooo`00Ioooo`030000oooooooo
04Goool606Ko<Oooo`0306Kooooooooo03Ooool001KooolM06Ko=?ooo`030000oooooooo03koool7
06Ko=oooo`0306Kooooooooo03Ooool003?ooolA06Ko8oooo`030000oooooooo03Ooool706Ko?_oo
o`0306Kooooooooo03Ooool004Coool:06Ko6Oooo`030000oooooooo037oool606KoAOooo`0306Ko
oooooooo03Ooool004koool:06Ko3oooo`80000[oooo1`1Vod_oool00`1Vooooooooo`0goooo000G
oooo1@0001koool200001?ooo`800004oooo0P00013oool806Ko1oooo`030000oooooooo01koool2
000000Coool0I_l0I_l0I_l20000101Vo`80000Ooooo1@0001goool500000_ooo`800004oooo0P00
000306Kooooooooo01goool400005_ooo`006Oooo`030000oooooooo01goool010000?ooooooo`00
00Soool010000?ooooooo`0001Ooool706Ko00<00000I_l0I_l00`1Vo`WooolA06Ko00@00000I_l0
I_l00008oooo00@0003oooooool0000Poooo00<0003oooooool07oooo`030000oooooooo00Ooool0
10000?ooooooo`0001ooool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Oooo`040000
oooooooo00002oooo`030000oooooooo01coool00`000?ooooooo`03oooo2@1Voa7oool010000?oo
ooooo`0000_oool00`000?ooooooo`0Noooo00<0003oooooool07oooo`030000oooooooo00[oool0
0`000?ooooooo`0Noooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool05ooo
o`@00002oooo00@0003oooooool00009oooo0P0001ooool00`000?ooooooo`0Moooo00@0003ooooo
ool00009oooo0P00027oool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`8000000`1Voooo
ooooo`0Ooooo00<0003oooooool05Oooo`006Oooo`030000oooooooo01goool010000?ooooooo`00
00Woool00`000?ooooooo`0Noooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000
oooooooo023oool00`000?ooooooo`0Ooooo00<0003oooooool02?ooo`030000oooo06Ko01ooool0
10000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`0001koool200007oooo`80000:
oooo0`0001ooool200008?ooo`80000:oooo0`00023oool200005oooo`00Ioooo`030000oooooooo
07coool00`1Vooooooooo`0goooo001Woooo00<0003oooooool0O?ooo`0306Kooooooooo03Ooool0
06Ooool00`000?ooooooo`1loooo00<0I_ooooooool0=oooo`00Ioooo`030000oooooooo07coool0
0`1Vooooooooo`0goooo001Woooo00<0003oooooool0O?ooo`0306Kooooooooo03Ooool0013ooooo
00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`0003?o
03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00@co`0P000000?o09T0000000001@0000;oool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000
oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o0100000Ioooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo01ooool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`00Ac?o
00D0000`oooo00?o09Woooooool0=oooo`00Ioooo`030000<ol0<ol0048co`050000=Oooo`03o`2I
oooooooo03Ooool006Ooool00`0003?o03?o000m<ol01@0003[oool00ol0VOooooooo`0goooo001W
oooo00<0000co`0co`00>C?o00@0000ooooo00?o09Woooooool0=oooo`00Ioooo`80000h<ol00P00
04?oool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`00=C?o00800015oooo00?o09Wooooo
ool0=oooo`00Ioooo`030000<ol0<ol003<co`020000Aoooo`03o`2Ioooooooo03Ooool006Ooool0
0`0003?o03?o000a<ol00P0004Woool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`00<3?o
00030000oooooooo04Woool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`00;S?o0080001<
oooo00?o09Woooooool0=oooo`00Ioooo`80000]<ol00P0004koool00ol0VOooooooo`0goooo001W
oooo00<0000co`0co`00:c?o00030000oooooooo04koool00ol0VOooooooo`0goooo001Woooo00<0
000co`0co`00:S?o00030000oooooooo04ooool00ol0VOooooooo`0goooo001Woooo00<0000co`0c
o`00:C?o00030000oooooooo053oool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`00:3?o
00030000oooooooo057oool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`00:3?o00030000
oooooooo057oool00ol0VOooooooo`0goooo001Woooo0P0002Pco`000`000?ooooooo`1Boooo00?o
09Woooooool0=oooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`1Coooo00?o09Wooooo
ool0=oooo`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`1Doooo00?o09Woooooool0=ooo
o`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`1Eoooo00?o09Woooooool0=oooo`00Iooo
o`030000<ol0<ol002<co`000`000?ooooooo`1Foooo00?o09Woooooool0=oooo`00Ioooo`030000
<ol0<ol002<co`000`000?ooooooo`1Foooo00?o09Woooooool0=oooo`00Ioooo`80000S<ol000<0
003oooooool0Eoooo`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000Q<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000P<ol000<0003oooooool0FOoo
o`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000P<ol000<0003oooooool0FOooo`03o`2I
oooooooo03Ooool006Ooool00`0003?o03?o000O<ol000<0003oooooool0F_ooo`03o`2Ioooooooo
03Ooool005ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`1Joooo00?o09Wooooo
ool0=oooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003oooooool0Fooo
o`03o`2Ioooooooo03Ooool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`1K
oooo00?o09Woooooool0=oooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0
003oooooool0G?ooo`03o`2Ioooooooo03Ooool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`007C?o00030000oooooooo05coool00ol0VOooooooo`0goooo001Poooo0P0000Goool00`0003?o
03?o000L<ol000<0003oooooool0GOooo`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000L
<ol000<0003oooooool0GOooo`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000K<ol000<0
003oooooool0G_ooo`03o`2Ioooooooo03Ooool006Ooool2000073?o00030000oooooooo05koool0
0ol0VOooooooo`0goooo001Woooo00<0000co`0co`006S?o00030000oooooooo05ooool00ol0VOoo
ooooo`0goooo001Woooo00<0000co`0co`006S?o00030000oooooooo05ooool00ol0VOooooooo`0g
oooo001Woooo00<0000co`0co`006C?o00030000oooooooo063oool00ol0VOooooooo`0goooo001W
oooo00<0000co`0co`006C?o00030000oooooooo063oool00ol0VOooooooo`0goooo001Woooo00<0
000co`0co`0063?o00030000oooooooo067oool00ol0VOooooooo`0goooo001Woooo0P0001Tco`00
0`000?ooooooo`1Qoooo00?o09Woooooool0=oooo`00Ioooo`030000<ol0<ol001Lco`000`000?oo
ooooo`1Roooo00?o09Woooooool0=oooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1R
oooo00?o09Woooooool0=oooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1Soooo00?o
09Woooooool0=oooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1Soooo00?o09Wooooo
ool0=oooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1Soooo00?o09Woooooool0=ooo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1Toooo00?o09Woooooool0=oooo`00Iooo
o`80000F<ol000<0003oooooool0I?ooo`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000E
<ol000<0003oooooool0I?ooo`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000E<ol000<0
003oooooool0I?ooo`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000D<ol000<0003ooooo
ool0IOooo`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000D<ol000<0003oooooool0IOoo
o`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000D<ol000<0003oooooool0IOooo`03o`2I
oooooooo03Ooool006Ooool200005C?o00030000oooooooo06Goool00ol0VOooooooo`0goooo001W
oooo00<0000co`0co`004c?o00030000oooooooo06Koool00ol0VOooooooo`0goooo001Woooo00<0
000co`0co`004c?o00030000oooooooo06Koool00ol0VOooooooo`0goooo001Woooo00<0000co`0c
o`004c?o00030000oooooooo06Koool00ol0VOooooooo`0goooo001Ooooo100000Coool00`0003?o
03?o000C<ol000<0003oooooool0I_ooo`03o`2Ioooooooo03Ooool005ooool00`000?ooooooo`05
oooo00<0000co`0co`004S?o00030000oooooooo06Ooool00ol0VOooooooo`0goooo001Poooo00<0
003oooooool01?ooo`80000C<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03Ooool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo06Ooool00ol0VOooooooo`0g
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo06Soool0
0ol0VOooooooo`0goooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool0J?oo
o`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000A<ol000<0003oooooool0J?ooo`03o`2I
oooooooo03Ooool006Ooool00`0003?o03?o000A<ol000<0003oooooool0J?ooo`03o`2Ioooooooo
03Ooool006Ooool200004C?o00030000oooooooo06Woool00ol0VOooooooo`0goooo001Woooo00<0
000co`0co`0043?o00030000oooooooo06Woool00ol0VOooooooo`0goooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo06Woool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`0043?o
00030000oooooooo06Woool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`003c?o00030000
oooooooo06[oool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`003c?o00030000oooooooo
06[oool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`003c?o00030000oooooooo06[oool0
0ol0VOooooooo`0goooo001Woooo0P00010co`000`000?ooooooo`1Zoooo00?o09Woooooool0=ooo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1[oooo00?o09Woooooool0=oooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`1[oooo00?o09Woooooool0=oooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`1[oooo00?o09Woooooool0=oooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`1[oooo00?o09Woooooool0=oooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00Ioooo`80000><ol000<0003oooooool0K?oo
o`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000=<ol000<0003oooooool0K?ooo`03o`2I
oooooooo03Ooool006Ooool00`0003?o03?o000=<ol000<0003oooooool0K?ooo`03o`2Ioooooooo
03Ooool006Ooool00`0003?o03?o000<<ol000<0003oooooool0KOooo`03o`2Ioooooooo03Ooool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0KOooo`03o`2Ioooooooo03Ooool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0KOooo`03o`2Ioooooooo03Ooool006Ooool200003C?o
00030000oooooooo06goool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`0033?o00030000
oooooooo06goool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`0033?o00030000oooooooo
06goool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`002c?o00030000oooooooo06koool0
0ol0VOooooooo`0goooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool0K_oo
o`03o`2Ioooooooo03Ooool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0
003oooooool0K_ooo`03o`2Ioooooooo03Ooool0067oool00`000?ooooooo`03oooo0P0000`co`00
0`000?ooooooo`1^oooo00?o09Woooooool0=oooo`00H_ooo`030000oooooooo00;oool00`0003?o
03?o000;<ol000<0003oooooool0K_ooo`03o`2Ioooooooo03Ooool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool0K_ooo`03o`2Ioooooooo03Ooool0063oool2
00001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`1_oooo00?o09Woooooool0=oooo`00Iooo
o`030000<ol0<ol000Xco`000`000?ooooooo`1_oooo00?o09Woooooool0=oooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`1_oooo00?o09Woooooool0=oooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`1_oooo00?o09Woooooool0=oooo`00Ioooo`80000;<ol000<0003ooooo
ool0Koooo`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o000:<ol000<0003oooooool0Kooo
o`03o`2Ioooooooo03Ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0L?ooo`03o`2I
oooooooo03Ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0L?ooo`03o`2Ioooooooo
03Ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0L?ooo`03o`2Ioooooooo03Ooool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0L?ooo`03o`2Ioooooooo03Ooool006Ooool2
00002S?o00030000oooooooo073oool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`002C?o
00030000oooooooo073oool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`002C?o00030000
oooooooo073oool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`0023?o00030000oooooooo
077oool00ol0VOooooooo`0goooo001Woooo00<0000co`0co`0023?o00030000oooooooo077oool0
0ol0VOooooooo`0goooo001Woooo00<0000co`0co`0023?o00030000oooooooo077oool00ol0VOoo
ooooo`0goooo001Woooo0P0000Tco`000`000?ooooooo`1aoooo00?o09Woooooool0=oooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`1aoooo00?o09Woooooool0=oooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1aoooo00?o09Woooooool0=oooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1boooo00?o09Woooooool0=oooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1boooo00?o09Woooooool0=oooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1boooo00?o09Woooooool0=oooo`00Ioooo`800008<ol000<0003oooooool0L_ooo`03o`2I
oooooooo03Ooool006Ooool00`0003?o03?o0007<ol000<0003oooooool0L_ooo`03o`2Ioooooooo
03Ooool006Ooool00`0003?o03?o0007<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03Ooool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03Ooool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03Ooool0067oool300000ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1boooo00?o09Woooooool0=oooo`00H_ooo`030000
oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03Ooool0
05ooool500000oooo`800008<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03Ooool005ooool0
10000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOoo
o`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001?ooo`800004oooo0P0000Coool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`07oooo00<0003oooooool00_oo
o`030000oooooooo00ooool00`000?ooooooo`0:oooo00@0003oooooool00002oooo00<0003ooooo
ool00_ooo`030000oooooooo07Ooool006Ooool9<ol02?ooo`030000oooooooo00D0000>oooo00<0
003oooooool02?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool0
1@000?ooooooooooo`00000Aoooo00<0003oooooool02?ooo`030000oooooooo00;oool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P00
00[oool300000oooo`800003oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o
0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.81909 .12361 L
.82924 .12361 L
.83996 .12361 L
.84438 .12361 L
.84681 .12361 L
.84801 .12361 L
.84911 .12361 L
s
.84911 .12361 m
.84964 .61803 L
s
0 .4 1 r
.02381 .06239 m
.02846 .06222 L
.03279 .06208 L
.03754 .06197 L
.04018 .06191 L
.04262 .06188 L
.04518 .06185 L
.0465 .06183 L
.04795 .06182 L
.04922 .06181 L
.0504 .06181 L
.05165 .06181 L
.05236 .0618 L
.053 .0618 L
.0542 .0618 L
.05531 .06181 L
.05654 .06181 L
.05784 .06182 L
.05908 .06182 L
.06026 .06183 L
.06244 .06185 L
.06489 .06188 L
.06757 .06192 L
.07299 .06203 L
.08269 .06228 L
.09401 .0627 L
.10458 .06317 L
.14349 .06558 L
.18485 .06891 L
.22469 .07255 L
.26302 .07624 L
.30381 .0802 L
.32406 .08215 L
.33398 .08309 L
.34307 .08394 L
.35192 .0846 L
.35637 .08485 L
.36124 .08507 L
.36614 .08524 L
.36889 .08531 L
.37138 .08537 L
.37371 .0854 L
.37494 .08542 L
.37624 .08544 L
.37738 .08545 L
.37862 .08545 L
.37976 .08546 L
.38082 .08546 L
.38207 .08546 L
.38277 .08546 L
Mistroke
.38341 .08546 L
.38464 .08546 L
.3858 .08545 L
.38716 .08545 L
.38841 .08543 L
.39123 .0854 L
.39352 .08537 L
.39604 .08532 L
.40111 .0852 L
.4107 .08489 L
.41965 .08451 L
.44004 .08336 L
.45861 .08202 L
.49851 .07839 L
.53689 .07415 L
.57772 .06901 L
.61704 .06356 L
.65484 .05797 L
.6951 .05176 L
.73384 .04567 L
.77503 .03931 L
.7956 .03627 L
.81471 .03359 L
.83317 .03117 L
.83848 .03051 L
.8435 .02991 L
.84568 .02965 L
.848 .02938 L
.8492 .02924 L
.84989 .12361 L
.85053 .12361 L
.85287 .12361 L
.89174 .12361 L
.93307 .12361 L
.97289 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo07koool00`1Vooooooooo`0eoooo001Woooo00<0003ooooo
ool0N?ooo`L0I_lgoooo001Woooo00<0003oooooool0K_ooo`X0I_l6oooo00<0I_ooooooool0=Ooo
o`00Ioooo`030000oooooooo06Woool506Ko4?ooo`0306Kooooooooo03Goool006Ooool00`000?oo
ooooo`1Soooo1P1VoaGoool00`1Vooooooooo`0eoooo001Woooo00<0003oooooool0G?ooo`L0I_lK
oooo00<0I_ooooooool0=Oooo`00Ioooo`80001Eoooo201Vob;oool00`1Vooooooooo`0eoooo001W
oooo00<0003oooooool0Coooo`D0I_lZoooo00<0I_ooooooool0=Oooo`00Ioooo`030000oooooooo
04Soool706Ko;oooo`0306Kooooooooo03Goool001KooolJ06Ko=oooo`030000oooooooo047oool7
06Ko=_ooo`0306Kooooooooo03Goool0033oool:06Ko;Oooo`030000oooooooo03coool506Ko?Ooo
o`0306Kooooooooo03Goool003[ooolD06Ko6Oooo`030000oooooooo03Coool806Ko@_ooo`0306Ko
oooooooo03Goool004koool:06Ko3oooo`80000[oooo2P1Vod[oool00`1Vooooooooo`0eoooo000G
oooo1@0001koool200001?ooo`800004oooo0P00013oool806Ko1oooo`030000oooooooo01koool2
0000101Vo`80000406Ko0P0001ooool500007Oooo`D00002oooo0P0000Coool200000_ooo`0306Ko
oooooooo01_oool400005_ooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Soool0
10000?ooooooo`0001Ooool706Ko00<0003oooooool04?ooo`d0I_l01000001Vo`1Vo`0000Soool0
10000?ooooooo`00023oool00`000?ooooooo`0Ooooo00<0003oooooool01oooo`060000oooooooo
0000oooo06Ko7Oooo`030000oooooooo01Ooool001Woool00`000?ooooooo`0Moooo00@0003ooooo
ool0000;oooo00<0003oooooool07?ooo`03000006Ko06Ko0100I_l=oooo00@0003oooooool0000;
oooo00<0003oooooool07_ooo`030000oooooooo01ooool00`000?ooooooo`0:oooo00<0003oool0
I_l07_ooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_oo
o`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo00002Ooo
o`80000Qoooo00<0003oooooool07oooo`030000oooooooo00Soool200000_ooo`0306Kooooooooo
01goool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Ooo
o`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003ooooo
ool08?ooo`030000oooooooo01ooool00`000?ooooooo`08oooo00D0003oooooooooool0I_l07Ooo
o`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P00
00[oool300007oooo`80000Poooo0P0000[oool3000000?oool0I_ooool07Oooo`80000Goooo001W
oooo00<0003oooooool0O_ooo`0306Kooooooooo03Goool006Ooool00`000?ooooooo`1noooo00<0
I_ooooooool0=Oooo`00Ioooo`030000oooooooo07koool00`1Vooooooooo`0eoooo001Woooo00<0
003oooooool0O_ooo`0306Kooooooooo03Goool006Ooool00`000?ooooooo`1noooo00<0I_oooooo
ool0=Oooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`0013?o024000000ol0V@000000000400000_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol04000
01Woool00`000?ooooooo`05oooo00?o09Woooooool07_ooo`030000oooooooo01Goool006Ooool0
0`0003?o03?o0017<ol01@00037oool00ol0VOooooooo`0foooo001Woooo00<0000co`0co`00@S?o
00D0000foooo00?o09Woooooool0=_ooo`00Ioooo`030000<ol0<ol003dco`050000>oooo`03o`2I
oooooooo03Koool006Ooool00`0003?o03?o000i<ol01000043oool00ol0VOooooooo`0foooo001W
oooo0P0003Pco`020000A?ooo`03o`2Ioooooooo03Koool006Ooool00`0003?o03?o000e<ol00P00
04Koool00ol0VOooooooo`0foooo001Woooo00<0000co`0co`00<c?o00800018oooo00?o09Wooooo
ool0=_ooo`00Ioooo`030000<ol0<ol0034co`020000B_ooo`03o`2Ioooooooo03Koool006Ooool0
0`0003?o03?o000`<ol000<0003oooooool0B_ooo`03o`2Ioooooooo03Koool006Ooool00`0003?o
03?o000^<ol00P0004goool00ol0VOooooooo`0foooo001Woooo0P0002dco`020000Coooo`03o`2I
oooooooo03Koool006Ooool00`0003?o03?o000[<ol000<0003oooooool0Coooo`03o`2Ioooooooo
03Koool006Ooool00`0003?o03?o000Z<ol000<0003oooooool0D?ooo`03o`2Ioooooooo03Koool0
06Ooool00`0003?o03?o000Y<ol000<0003oooooool0DOooo`03o`2Ioooooooo03Koool006Ooool0
0`0003?o03?o000X<ol000<0003oooooool0D_ooo`03o`2Ioooooooo03Koool006Ooool00`0003?o
03?o000X<ol000<0003oooooool0D_ooo`03o`2Ioooooooo03Koool006Ooool20000:3?o00030000
oooooooo05?oool00ol0VOooooooo`0foooo001Woooo00<0000co`0co`009S?o00030000oooooooo
05Coool00ol0VOooooooo`0foooo001Woooo00<0000co`0co`009C?o00030000oooooooo05Goool0
0ol0VOooooooo`0foooo001Woooo00<0000co`0co`0093?o00030000oooooooo05Koool00ol0VOoo
ooooo`0foooo001Woooo00<0000co`0co`008c?o00030000oooooooo05Ooool00ol0VOooooooo`0f
oooo001Woooo00<0000co`0co`008c?o00030000oooooooo05Ooool00ol0VOooooooo`0foooo001W
oooo0P0002<co`000`000?ooooooo`1Hoooo00?o09Woooooool0=_ooo`00Ioooo`030000<ol0<ol0
024co`000`000?ooooooo`1Ioooo00?o09Woooooool0=_ooo`00Ioooo`030000<ol0<ol0020co`00
0`000?ooooooo`1Joooo00?o09Woooooool0=_ooo`00Ioooo`030000<ol0<ol0020co`000`000?oo
ooooo`1Joooo00?o09Woooooool0=_ooo`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`1K
oooo00?o09Woooooool0=_ooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo
05_oool00ol0VOooooooo`0foooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`00
0`000?ooooooo`1Loooo00?o09Woooooool0=_ooo`00HOooo`030000oooooooo00?oool200007c?o
00030000oooooooo05coool00ol0VOooooooo`0foooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001dco`000`000?ooooooo`1Moooo00?o09Woooooool0=_ooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003oooooool0GOooo`03o`2Ioooooooo03Koool0063oool2
00001Oooo`030000<ol0<ol001`co`000`000?ooooooo`1Noooo00?o09Woooooool0=_ooo`00Iooo
o`030000<ol0<ol001`co`000`000?ooooooo`1Noooo00?o09Woooooool0=_ooo`00Ioooo`030000
<ol0<ol001/co`000`000?ooooooo`1Ooooo00?o09Woooooool0=_ooo`00Ioooo`80000L<ol000<0
003oooooool0Goooo`03o`2Ioooooooo03Koool006Ooool00`0003?o03?o000J<ol000<0003ooooo
ool0H?ooo`03o`2Ioooooooo03Koool006Ooool00`0003?o03?o000J<ol000<0003oooooool0H?oo
o`03o`2Ioooooooo03Koool006Ooool00`0003?o03?o000I<ol000<0003oooooool0HOooo`03o`2I
oooooooo03Koool006Ooool00`0003?o03?o000I<ol000<0003oooooool0HOooo`03o`2Ioooooooo
03Koool006Ooool00`0003?o03?o000H<ol000<0003oooooool0H_ooo`03o`2Ioooooooo03Koool0
06Ooool200006C?o00030000oooooooo06;oool00ol0VOooooooo`0foooo001Woooo00<0000co`0c
o`005c?o00030000oooooooo06?oool00ol0VOooooooo`0foooo001Woooo00<0000co`0co`005c?o
00030000oooooooo06?oool00ol0VOooooooo`0foooo001Woooo00<0000co`0co`005S?o00030000
oooooooo06Coool00ol0VOooooooo`0foooo001Woooo00<0000co`0co`005S?o00030000oooooooo
06Coool00ol0VOooooooo`0foooo001Woooo00<0000co`0co`005S?o00030000oooooooo06Coool0
0ol0VOooooooo`0foooo001Woooo00<0000co`0co`005C?o00030000oooooooo06Goool00ol0VOoo
ooooo`0foooo001Woooo0P0001Hco`000`000?ooooooo`1Uoooo00?o09Woooooool0=_ooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`1Uoooo00?o09Woooooool0=_ooo`00Ioooo`030000
<ol0<ol001Dco`000`000?ooooooo`1Uoooo00?o09Woooooool0=_ooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`1Voooo00?o09Woooooool0=_ooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooooooo`1Voooo00?o09Woooooool0=_ooo`00Ioooo`030000<ol0<ol001@co`000`000?oo
ooooo`1Voooo00?o09Woooooool0=_ooo`00Ioooo`80000E<ol000<0003oooooool0I_ooo`03o`2I
oooooooo03Koool006Ooool00`0003?o03?o000C<ol000<0003oooooool0Ioooo`03o`2Ioooooooo
03Koool006Ooool00`0003?o03?o000C<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03Koool0
06Ooool00`0003?o03?o000C<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03Koool005ooool4
00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`1Woooo00?o09Woooooool0=_ooo`00Gooo
o`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0J?ooo`03o`2Ioooooooo
03Koool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`1Xoooo00?o09Wooooo
ool0=_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0JOoo
o`03o`2Ioooooooo03Goool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0
003oooooool0J_ooo`03o`2Ioooooooo03Goool0063oool200001Oooo`030000<ol0<ol0014co`00
0`000?ooooooo`1Zoooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol0014co`000`000?oo
ooooo`1Zoooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1Z
oooo00?o09Woooooool0=Oooo`00Ioooo`80000A<ol000<0003oooooool0Joooo`03o`2Ioooooooo
03Goool006Ooool00`0003?o03?o000@<ol000<0003oooooool0Joooo`03o`2Ioooooooo03Goool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool0Joooo`03o`2Ioooooooo03Goool006Ooool0
0`0003?o03?o000@<ol000<0003oooooool0Joooo`03o`2Ioooooooo03Goool006Ooool00`0003?o
03?o000?<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03Goool006Ooool00`0003?o03?o000?
<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03Goool006Ooool00`0003?o03?o000?<ol000<0
003oooooool0K?ooo`03o`2Ioooooooo03Goool006Ooool2000043?o00030000oooooooo06coool0
0ol0VOooooooo`0eoooo001Woooo00<0000co`0co`003S?o00030000oooooooo06goool00ol0VOoo
ooooo`0eoooo001Woooo00<0000co`0co`003S?o00030000oooooooo06goool00ol0VOooooooo`0e
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo06goool00ol0VOooooooo`0eoooo001W
oooo00<0000co`0co`003S?o00030000oooooooo06goool00ol0VOooooooo`0eoooo001Woooo00<0
000co`0co`003C?o00030000oooooooo06koool00ol0VOooooooo`0eoooo001Woooo0P0000hco`00
0`000?ooooooo`1^oooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`1^oooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1^
oooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1_oooo00?o
09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1_oooo00?o09Wooooo
ool0=Oooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1_oooo00?o09Woooooool0=Ooo
o`00Ioooo`80000=<ol000<0003oooooool0Koooo`03o`2Ioooooooo03Goool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0Koooo`03o`2Ioooooooo03Goool006Ooool00`0003?o03?o000<
<ol000<0003oooooool0Koooo`03o`2Ioooooooo03Goool006Ooool00`0003?o03?o000;<ol000<0
003oooooool0L?ooo`03o`2Ioooooooo03Goool0063oool200001Oooo`030000<ol0<ol000/co`00
0`000?ooooooo`1`oooo00?o09Woooooool0=Oooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol000/co`000`000?ooooooo`1`oooo00?o09Woooooool0=Oooo`00HOooo`030000oooooooo
00?oool2000033?o00030000oooooooo073oool00ol0VOooooooo`0eoooo001Roooo00<0003ooooo
ool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`1`oooo00?o09Woooooool0=Oooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1`oooo00?o09Wooooo
ool0=Oooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo077oool00ol0VOoo
ooooo`0eoooo001Woooo00<0000co`0co`002S?o00030000oooooooo077oool00ol0VOooooooo`0e
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo077oool00ol0VOooooooo`0eoooo001W
oooo00<0000co`0co`002S?o00030000oooooooo077oool00ol0VOooooooo`0eoooo001Woooo0P00
00/co`000`000?ooooooo`1aoooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`1aoooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1boooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1b
oooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1boooo00?o
09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1boooo00?o09Wooooo
ool0=Oooo`00Ioooo`80000:<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03Goool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03Goool006Ooool00`0003?o
03?o0009<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03Goool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0Loooo`03o`2Ioooooooo03Goool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0Loooo`03o`2Ioooooooo03Goool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool0Loooo`03o`2Ioooooooo03Goool006Ooool200002C?o00030000oooooooo07?oool00ol0VOoo
ooooo`0eoooo001Woooo00<0000co`0co`0023?o00030000oooooooo07?oool00ol0VOooooooo`0e
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo07?oool00ol0VOooooooo`0eoooo001W
oooo00<0000co`0co`001c?o00030000oooooooo07Coool00ol0VOooooooo`0eoooo001Woooo00<0
000co`0co`001c?o00030000oooooooo07Coool00ol0VOooooooo`0eoooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo07Coool00ol0VOooooooo`0eoooo001Woooo0P0000Pco`000`000?oo
ooooo`1doooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1d
oooo00?o09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1doooo00?o
09Woooooool0=Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1doooo00?o09Wooooo
ool0=Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1doooo00?o09Woooooool0=Ooo
o`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo07Coool00ol0VOooooooo`0e
oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`1doooo00?o
09Woooooool0=Oooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`1doooo00?o09Wooooo
ool0=Oooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?oo
o`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool0
06Ooool9<ol03?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001Woooo2C?o00_oool0
0`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool006Ooool9<ol02ooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800003oooo0`00
00Coool00`000?ooooooo`1koooo001Woooo2C?o00_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00Ioooo`Tco`0:oooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0N_ooo`00Iooo
o`Tco`0;oooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo0`0000Coool00`000?oo
ooooo`1koooo001Woooo2C?o00_oool01@000?ooooooooooo`00000Aoooo00<0003oooooool02?oo
o`030000oooooooo00?oool00`000?ooooooo`1koooo001Woooo2C?o00coool00`000?ooooooo`0A
oooo0P0000[oool300000_ooo`030000oooooooo07coool006Ooool9<ol0/?ooo`00Ioooo`Pco`2a
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.81909 .12361 L
.82924 .12361 L
.83996 .12361 L
.84911 .12361 L
.85162 .12361 L
.853 .12361 L
.85431 .12361 L
.85553 .12361 L
s
.85553 .12361 m
.85605 .61803 L
s
0 .4 1 r
.02381 .06216 m
.02846 .06203 L
.03279 .06193 L
.03523 .06189 L
.03754 .06186 L
.03881 .06185 L
.0402 .06183 L
.04145 .06182 L
.04262 .06182 L
.04376 .06181 L
.045 .06181 L
.0457 .0618 L
.04637 .0618 L
.04762 .0618 L
.04894 .06181 L
.05016 .06181 L
.05086 .06181 L
.0515 .06182 L
.05293 .06182 L
.05528 .06184 L
.05783 .06187 L
.06244 .06194 L
.06753 .06205 L
.07312 .06219 L
.08439 .06257 L
.10458 .0635 L
.145 .06616 L
.18391 .06939 L
.22527 .07321 L
.26512 .07706 L
.30345 .08078 L
.32283 .08263 L
.33313 .0836 L
.34423 .08463 L
.34938 .08502 L
.3548 .08536 L
.35981 .0856 L
.36448 .08578 L
.36887 .0859 L
.37133 .08595 L
.37356 .08599 L
.37602 .08602 L
.3774 .08604 L
.37867 .08605 L
.37979 .08605 L
.38102 .08606 L
.3823 .08606 L
.3835 .08606 L
.38475 .08606 L
.38545 .08605 L
Mistroke
.38608 .08605 L
.38732 .08604 L
.38848 .08603 L
.39109 .086 L
.3939 .08596 L
.39905 .08586 L
.40378 .08574 L
.4128 .08543 L
.42232 .08501 L
.442 .08388 L
.46035 .08256 L
.49931 .07905 L
.54072 .07449 L
.58062 .06948 L
.619 .06419 L
.65983 .05818 L
.69915 .05211 L
.73695 .04617 L
.77721 .03994 L
.81595 .03428 L
.83603 .0316 L
.84612 .03035 L
.84888 .03001 L
.85183 .02967 L
.85326 .0295 L
.85397 .02942 L
.85462 .02934 L
.85583 .12361 L
.85714 .12361 L
.8966 .12361 L
.93454 .12361 L
.97493 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`1hoooo201VocKoool0
06Ooool00`000?ooooooo`1aoooo1`1Vo`Ooool00`1Vooooooooo`0doooo001Woooo00<0003ooooo
ool0JOooo`P0I_l>oooo00<0I_ooooooool0=?ooo`00Ioooo`030000oooooooo06Coool506Ko5_oo
o`0306Kooooooooo03Coool006Ooool00`000?ooooooo`1Moooo1`1Voa_oool00`1Vooooooooo`0d
oooo001Woooo0P0005Koool806Ko8_ooo`0306Kooooooooo03Coool006Ooool00`000?ooooooo`1@
oooo1@1Vob[oool00`1Vooooooooo`0doooo001Woooo00<0003oooooool0BOooo`L0I_l_oooo00<0
I_ooooooool0=?ooo`005_oooaX0I_lgoooo00<0003oooooool0@Oooo`P0I_lfoooo00<0I_oooooo
ool0=?ooo`00<?ooo`X0I_l]oooo00<0003oooooool0??ooo`D0I_lnoooo00<0I_ooooooool0=?oo
o`00>_ooo`X0I_lSoooo00<0003oooooool0=Oooo`L0I_m3oooo00<0I_ooooooool0=?ooo`00A?oo
o`X0I_lIoooo0P0002coool:06KoB_ooo`0306Kooooooooo03Coool001Ooool500007_ooo`800004
oooo0P0000Coool200001_ooo`X0I_l?oooo00<0003oooooool07_ooo`8000001?ooo`1Vo`1Vo`1V
o`80000406Ko0P0001ooool500007Oooo`D00002oooo0P0000Coool200000oooo`0306Kooooooooo
01[oool400005_ooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?oo
ooooo`0000ooool>06Ko00?oool0003oool05Oooo`T0I_l01000001Vo`1Vo`0000Soool010000?oo
ooooo`00023oool00`000?ooooooo`0Ooooo00<0003oooooool01oooo`040000oooooooo00000_oo
o`0306Kooooooooo01[oool00`000?ooooooo`0Goooo000Ioooo00<0003oooooool07Oooo`040000
oooooooo00002oooo`030000oooooooo01_oool00`1Vo`00001Vo`0E06Ko2Oooo`040000oooooooo
00002oooo`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`040000
oooooooo06Ko7Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo01Ooool4
00000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`80000Qoooo00<0003oooooool07oooo`030000oooooooo00Soool200000oooo`0306Ko
oooooooo01coool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002Oooo`030000oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0
003oooooool08?ooo`030000oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool00_oo
o`0306Kooooooooo01[oool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`00
01koool200007oooo`80000:oooo0`0001ooool200008?ooo`80000:oooo0`0000;oool00`1Voooo
ooooo`0Koooo0P0001Ooool006Ooool00`000?ooooooo`1ooooo00<0I_ooooooool0=?ooo`00Iooo
o`030000oooooooo07ooool00`1Vooooooooo`0doooo001Woooo00<0003oooooool0Ooooo`0306Ko
oooooooo03Coool006Ooool00`000?ooooooo`1ooooo00<0I_ooooooool0=?ooo`00Ioooo`030000
oooooooo07ooool00`1Vooooooooo`0doooo000@ooooo`00017oool001Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004<ol08`000003o`2I0000000000800002
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo02Goool00`000?ooooooo`0Voooo00<0000co`0co`009C?o
00030000<ol0<ol002@co`0@00006Oooo`030000oooooooo00Ooool00ol0VOooooooo`0Loooo00<0
003oooooool05Oooo`00Ioooo`030000<ol0<ol004Lco`050000<oooo`03o`2Ioooooooo03Coool0
06Ooool00`0003?o03?o0012<ol01@0003Soool00ol0VOooooooo`0doooo001Woooo00<0000co`0c
o`00?C?o00D0000moooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol003Tco`040000@_oo
o`03o`2Ioooooooo03Coool006Ooool20000>3?o00800016oooo00?o09Woooooool0=?ooo`00Iooo
o`030000<ol0<ol003Dco`020000B?ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000c
<ol00P0004[oool00ol0VOooooooo`0doooo001Woooo00<0000co`0co`00<C?o0080001<oooo00?o
09Woooooool0=?ooo`00Ioooo`030000<ol0<ol0030co`000`000?ooooooo`1<oooo00?o09Wooooo
ool0=?ooo`00Ioooo`030000<ol0<ol002hco`020000Coooo`03o`2Ioooooooo03Coool006Ooool2
0000;C?o0080001Aoooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol002/co`000`000?oo
ooooo`1Aoooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol002Xco`000`000?ooooooo`1B
oooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol002Tco`000`000?ooooooo`1Coooo00?o
09Woooooool0=?ooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`1Doooo00?o09Wooooo
ool0=?ooo`00Ioooo`030000<ol0<ol002Pco`000`000?ooooooo`1Doooo00?o09Woooooool0=?oo
o`00Ioooo`80000X<ol000<0003oooooool0EOooo`03o`2Ioooooooo03Coool006Ooool00`0003?o
03?o000V<ol000<0003oooooool0E_ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000U
<ol000<0003oooooool0Eoooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000T<ol000<0
003oooooool0F?ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000S<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000S<ol000<0003oooooool0FOoo
o`03o`2Ioooooooo03Coool006Ooool200008c?o00030000oooooooo05[oool00ol0VOooooooo`0d
oooo001Woooo00<0000co`0co`008C?o00030000oooooooo05_oool00ol0VOooooooo`0doooo001W
oooo00<0000co`0co`0083?o00030000oooooooo05coool00ol0VOooooooo`0doooo001Woooo00<0
000co`0co`0083?o00030000oooooooo05coool00ol0VOooooooo`0doooo001Woooo00<0000co`0c
o`007c?o00030000oooooooo05goool00ol0VOooooooo`0doooo001Ooooo1@0000?oool00`0003?o
03?o000O<ol000<0003oooooool0GOooo`03o`2Ioooooooo03Coool0067oool00`000?ooooooo`03
oooo00<0000co`0co`007S?o00030000oooooooo05koool00ol0VOooooooo`0doooo001Qoooo00<0
003oooooool00oooo`80000O<ol000<0003oooooool0G_ooo`03o`2Ioooooooo03Coool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo05ooool00ol0VOooooooo`0d
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`1Ooooo00?o
09Woooooool0=?ooo`00H?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo063oool0
0ol0VOooooooo`0doooo001Woooo00<0000co`0co`0073?o00030000oooooooo063oool00ol0VOoo
ooooo`0doooo001Woooo00<0000co`0co`006c?o00030000oooooooo067oool00ol0VOooooooo`0d
oooo001Woooo0P0001`co`000`000?ooooooo`1Qoooo00?o09Woooooool0=?ooo`00Ioooo`030000
<ol0<ol001Xco`000`000?ooooooo`1Roooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol0
01Xco`000`000?ooooooo`1Roooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol001Tco`00
0`000?ooooooo`1Soooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol001Tco`000`000?oo
ooooo`1Soooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol001Pco`000`000?ooooooo`1T
oooo00?o09Woooooool0=?ooo`00Ioooo`80000I<ol000<0003oooooool0I?ooo`03o`2Ioooooooo
03Coool006Ooool00`0003?o03?o000G<ol000<0003oooooool0IOooo`03o`2Ioooooooo03Coool0
06Ooool00`0003?o03?o000G<ol000<0003oooooool0IOooo`03o`2Ioooooooo03Coool006Ooool0
0`0003?o03?o000F<ol000<0003oooooool0I_ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o
03?o000F<ol000<0003oooooool0I_ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000F
<ol000<0003oooooool0I_ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000E<ol000<0
003oooooool0Ioooo`03o`2Ioooooooo03Coool006Ooool200005S?o00030000oooooooo06Ooool0
0ol0VOooooooo`0doooo001Woooo00<0000co`0co`005C?o00030000oooooooo06Ooool00ol0VOoo
ooooo`0doooo001Woooo00<0000co`0co`005C?o00030000oooooooo06Ooool00ol0VOooooooo`0d
oooo001Woooo00<0000co`0co`0053?o00030000oooooooo06Soool00ol0VOooooooo`0doooo001W
oooo00<0000co`0co`0053?o00030000oooooooo06Soool00ol0VOooooooo`0doooo001Woooo00<0
000co`0co`0053?o00030000oooooooo06Soool00ol0VOooooooo`0doooo001Woooo0P0001Dco`00
0`000?ooooooo`1Xoooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol001<co`000`000?oo
ooooo`1Yoooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1Y
oooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1Yoooo00?o
09Woooooool0=?ooo`00Goooo`@00004oooo00<0000co`0co`004c?o00030000oooooooo06Woool0
0ol0VOooooooo`0doooo001Ooooo00<0003oooooool01Oooo`030000<ol0<ol0018co`000`000?oo
ooooo`1Zoooo00?o09Woooooool0=?ooo`00H?ooo`030000oooooooo00Coool200004c?o00030000
oooooooo06[oool00ol0VOooooooo`0doooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
018co`000`000?ooooooo`1Zoooo00?o09Woooooool0=?ooo`00Goooo`040000oooooooo00001?oo
o`030000<ol0<ol0014co`000`000?ooooooo`1[oooo00?o09Woooooool0=?ooo`00H?ooo`800005
oooo00<0000co`0co`004C?o00030000oooooooo06_oool00ol0VOooooooo`0doooo001Woooo00<0
000co`0co`004C?o00030000oooooooo06_oool00ol0VOooooooo`0doooo001Woooo00<0000co`0c
o`004C?o00030000oooooooo06_oool00ol0VOooooooo`0doooo001Woooo0P00014co`000`000?oo
ooooo`1/oooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1/
oooo00?o09Woooooool0=?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1/oooo00?o
09Woooooool0=?ooo`00Ioooo`030000<ol0<ol0010co`000`000?ooooooo`1/oooo00?o09Wooooo
ool0=?ooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1]oooo00?o09Woooooool0=?oo
o`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1]oooo00?o09Woooooool0=?ooo`00Iooo
o`030000<ol0<ol000lco`000`000?ooooooo`1]oooo00?o09Woooooool0=?ooo`00Ioooo`80000@
<ol000<0003oooooool0KOooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000><ol000<0
003oooooool0K_ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000><ol000<0003ooooo
ool0K_ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000><ol000<0003oooooool0K_oo
o`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000><ol000<0003oooooool0K_ooo`03o`2I
oooooooo03Coool006Ooool00`0003?o03?o000=<ol000<0003oooooool0Koooo`03o`2Ioooooooo
03Coool006Ooool200003S?o00030000oooooooo06ooool00ol0VOooooooo`0doooo001Woooo00<0
000co`0co`003C?o00030000oooooooo06ooool00ol0VOooooooo`0doooo001Woooo00<0000co`0c
o`003C?o00030000oooooooo06ooool00ol0VOooooooo`0doooo001Woooo00<0000co`0co`0033?o
00030000oooooooo073oool00ol0VOooooooo`0doooo001Woooo00<0000co`0co`0033?o00030000
oooooooo073oool00ol0VOooooooo`0doooo001Woooo00<0000co`0co`0033?o00030000oooooooo
073oool00ol0VOooooooo`0doooo001Woooo0P0000dco`000`000?ooooooo`1`oooo00?o09Wooooo
ool0=?ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1`oooo00?o09Woooooool0=?oo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1`oooo00?o09Woooooool0=?ooo`00Iooo
o`030000<ol0<ol000/co`000`000?ooooooo`1aoooo00?o09Woooooool0=?ooo`00H?ooo`800005
oooo00<0000co`0co`002c?o00030000oooooooo077oool00ol0VOooooooo`0doooo001Ooooo00@0
003oooooool00004oooo00<0000co`0co`002c?o00030000oooooooo077oool00ol0VOooooooo`0d
oooo001Qoooo00<0003oooooool00oooo`80000<<ol000<0003oooooool0LOooo`03o`2Ioooooooo
03Coool006;oool00`000?ooooooo`02oooo00<0000co`0co`002c?o00030000oooooooo077oool0
0ol0VOooooooo`0doooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o00030000
oooooooo077oool00ol0VOooooooo`0doooo001Poooo0P0000Goool00`0003?o03?o000:<ol000<0
003oooooool0L_ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0L_ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0L_oo
o`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0L_ooo`03o`2I
oooooooo03Coool006Ooool200002c?o00030000oooooooo07;oool00ol0VOooooooo`0doooo001W
oooo00<0000co`0co`002S?o00030000oooooooo07;oool00ol0VOooooooo`0doooo001Woooo00<0
000co`0co`002C?o00030000oooooooo07?oool00ol0VOooooooo`0doooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo07?oool00ol0VOooooooo`0doooo001Woooo00<0000co`0co`002C?o
00030000oooooooo07?oool00ol0VOooooooo`0doooo001Woooo00<0000co`0co`002C?o00030000
oooooooo07?oool00ol0VOooooooo`0doooo001Woooo0P0000Xco`000`000?ooooooo`1coooo00?o
09Woooooool0=?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1coooo00?o09Wooooo
ool0=?ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1coooo00?o09Woooooool0=?oo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1doooo00?o09Woooooool0=?ooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`1doooo00?o09Woooooool0=?ooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1doooo00?o09Woooooool0=?ooo`00Ioooo`800009<ol000<0
003oooooool0M?ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool0M?ooo`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o0008<ol000<0003oooooool0M?oo
o`03o`2Ioooooooo03Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0MOooo`03o`2I
oooooooo03Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0MOooo`03o`2Ioooooooo
03Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0MOooo`03o`2Ioooooooo03Coool0
06Ooool2000023?o00030000oooooooo07Goool00ol0VOooooooo`0doooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo07Goool00ol0VOooooooo`0doooo001Woooo00<0000co`0co`001c?o
00030000oooooooo07Goool00ol0VOooooooo`0doooo001Woooo00<0000co`0co`001c?o00030000
oooooooo07Goool00ol0VOooooooo`0doooo001Woooo00<0000co`0co`001c?o00030000oooooooo
07Goool00ol0VOooooooo`0doooo001Qoooo0`0000?oool00`0003?o03?o0007<ol000<0003ooooo
ool0MOooo`03o`2Ioooooooo03Coool006;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o
00030000oooooooo07Goool00ol0VOooooooo`0doooo001Ooooo1@0000?oool2000023?o00030000
oooooooo07Goool00ol0VOooooooo`0doooo001Ooooo00@0003oooooool00004oooo2S?o0:ooool0
063oool00`000?ooo`000004oooo2S?o0:ooool0067oool200001?ooo`Xco`2_oooo001Woooo2C?o
0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09oooo00<0003oooooool0:?ooo`030000oooooooo
07Woool006Ooool9<ol02?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`D00002oooo0P0000?oool300000oooo`@00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0
003oooooool01oooo`040000oooooooo00000_ooo`030000oooooooo00Coool00`000?ooooooo`1h
oooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo
00Ooool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00Iooo
o`Tco`08oooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo0`0000Goool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000004Ooo
o`030000oooooooo00Soool00`000?ooooooo`02oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:oooo0`0000?oool200000ooo
o`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.84911 .12361 L
.85396 .12361 L
.85663 .12361 L
.85916 .12361 L
.86034 .12361 L
.86159 .12361 L
s
.86159 .12361 m
.86185 .61803 L
s
0 .4 1 r
.02381 .06199 m
.02605 .06194 L
.02846 .0619 L
.03053 .06187 L
.03279 .06184 L
.03416 .06183 L
.03543 .06182 L
.03665 .06181 L
.03793 .06181 L
.03908 .0618 L
.04016 .0618 L
.04135 .0618 L
.04262 .06181 L
.04393 .06181 L
.04516 .06182 L
.0465 .06182 L
.04793 .06183 L
.05057 .06186 L
.05297 .06189 L
.05785 .06197 L
.06244 .06207 L
.07299 .06238 L
.08269 .06275 L
.10458 .06386 L
.14407 .06658 L
.18204 .06978 L
.22246 .07355 L
.26137 .07732 L
.30273 .08132 L
.32343 .08329 L
.33253 .08414 L
.34258 .08507 L
.34719 .08545 L
.35216 .08579 L
.35646 .08603 L
.36116 .08624 L
.36618 .08641 L
.36892 .08649 L
.37146 .08654 L
.37386 .08658 L
.37603 .08661 L
.37723 .08662 L
.37854 .08663 L
.37977 .08664 L
.38091 .08665 L
.38216 .08665 L
.38335 .08665 L
.38442 .08665 L
.38558 .08664 L
.38684 .08664 L
Mistroke
.38819 .08663 L
.3906 .0866 L
.39305 .08657 L
.39536 .08653 L
.39967 .08645 L
.40959 .08616 L
.42031 .08573 L
.44029 .08464 L
.46137 .08315 L
.49939 .07976 L
.53987 .07538 L
.57883 .07057 L
.62024 .06493 L
.66014 .05908 L
.69852 .0532 L
.73935 .04679 L
.77867 .04067 L
.81648 .03509 L
.83749 .03223 L
.84669 .03105 L
.85155 .03045 L
.85673 .02983 L
.85937 .02952 L
.86067 .02937 L
.86186 .02924 L
.86295 .12361 L
.8641 .12361 L
.86652 .12361 L
.87562 .12361 L
.89547 .12361 L
.93341 .12361 L
.9738 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo087oool00`1Vooooooooo`0boooo001Woooo00<0003ooooo
ool0NOooo`T0I_ldoooo001Woooo00<0003oooooool0LOooo`P0I_l8oooo00<0I_ooooooool0<_oo
o`00Ioooo`030000oooooooo06[oool706Ko4?ooo`0306Kooooooooo03;oool006Ooool00`000?oo
ooooo`1Uoooo1@1VoaOoool00`1Vooooooooo`0boooo001Woooo00<0003oooooool0H?ooo`D0I_lL
oooo00<0I_ooooooool0<_ooo`00Ioooo`80001Koooo1P1Vob7oool00`1Vooooooooo`0boooo001W
oooo00<0003oooooool0Doooo`L0I_lWoooo00<0I_ooooooool0<_ooo`00Ioooo`030000oooooooo
04coool706Ko;_ooo`0306Kooooooooo03;oool001KooolJ06Ko=oooo`030000oooooooo04Koool6
06Ko=Oooo`0306Kooooooooo03;oool0033oool:06Ko;Oooo`030000oooooooo03ooool706Ko>ooo
o`0306Kooooooooo03;oool003[oool:06Ko8oooo`030000oooooooo03Goool:06Ko@_ooo`0306Ko
oooooooo03;oool004Coool:06Ko6Oooo`80000/oooo2P1Vodcoool00`1Vooooooooo`0boooo000G
oooo1@0001koool200001?ooo`800004oooo0P0000Koool:06Ko3oooo`030000oooooooo01koool2
000000Coool0I_l0I_l0I_l20000101Vo`80000Ooooo1@0001goool500000_ooo`800004oooo0P00
00Goool00`1Vooooooooo`0Hoooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003ooooo
ool00008oooo00@0003oooooool0000?oooo3P1Vo`03oooo0000oooo01[oool406Ko00@00000I_l0
I_l00008oooo00@0003oooooool0000Poooo00<0003oooooool07oooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`1Vooooooooo`0Hoooo00<0003oooooool05oooo`006Oooo`030000
oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0Koooo00<0I_l00000I_l06P1V
o`Coool010000?ooooooo`0000_oool00`000?ooooooo`0Noooo00<0003oooooool07oooo`030000
oooooooo00[oool00`000?ooooooo`02oooo00<0I_ooooooool06Oooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Oooo`80000O
oooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool07ooo
o`030000oooooooo00Soool200001Oooo`0306Kooooooooo01[oool00`000?ooooooo`0Eoooo000I
oooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool00`000?oo
ooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo01ooool0
0`000?ooooooo`08oooo00<0003oooooool01?ooo`0306Kooooooooo01Soool010000?ooooooo`00
01Koool001Soool200008?ooo`80000:oooo0`0001koool200007oooo`80000:oooo0`0001ooool2
00008?ooo`80000:oooo0`0000Coool00`1Vooooooooo`0Ioooo0P0001Ooool006Ooool00`000?oo
ooooo`21oooo00<0I_ooooooool0<_ooo`00Ioooo`030000oooooooo087oool00`1Vooooooooo`0b
oooo001Woooo00<0003oooooool0POooo`0306Kooooooooo03;oool006Ooool00`000?ooooooo`21
oooo00<0I_ooooooool0<_ooo`00Ioooo`030000oooooooo087oool00`1Vooooooooo`0boooo000@
ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o
00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o
03?o0004<ol09@000003o`2I0000000000;oool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000
oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o0100000Ioooo00<0003ooooo
ool02Oooo`03o`2Ioooooooo01[oool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`00Ac?o
00D0000eoooo00?o09Woooooool0<_ooo`00Ioooo`030000<ol0<ol0048co`050000>_ooo`03o`2I
oooooooo03;oool006Ooool00`0003?o03?o000m<ol01@0003ooool00ol0VOooooooo`0boooo001W
oooo00<0000co`0co`00>C?o00@00014oooo00?o09Woooooool0<_ooo`00Ioooo`80000h<ol00P00
04Soool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`00=C?o0080001:oooo00?o09Wooooo
ool0<_ooo`00Ioooo`030000<ol0<ol003<co`020000C?ooo`03o`2Ioooooooo03;oool006Ooool0
0`0003?o03?o000a<ol00P0004koool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`00<3?o
00030000oooooooo04koool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`00;S?o0080001A
oooo00?o09Woooooool0<_ooo`00Ioooo`80000]<ol00P0005?oool00ol0VOooooooo`0boooo001W
oooo00<0000co`0co`00:c?o00030000oooooooo05?oool00ol0VOooooooo`0boooo001Woooo00<0
000co`0co`00:S?o00030000oooooooo05Coool00ol0VOooooooo`0boooo001Woooo00<0000co`0c
o`00:C?o00030000oooooooo05Goool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`00:3?o
00030000oooooooo05Koool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`00:3?o00030000
oooooooo05Koool00ol0VOooooooo`0boooo001Woooo0P0002Pco`000`000?ooooooo`1Goooo00?o
09Woooooool0<_ooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`1Hoooo00?o09Wooooo
ool0<_ooo`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`1Ioooo00?o09Woooooool0<_oo
o`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`1Joooo00?o09Woooooool0<_ooo`00Iooo
o`030000<ol0<ol002<co`000`000?ooooooo`1Koooo00?o09Woooooool0<_ooo`00Ioooo`030000
<ol0<ol002<co`000`000?ooooooo`1Koooo00?o09Woooooool0<_ooo`00Ioooo`80000S<ol000<0
003oooooool0G?ooo`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000Q<ol000<0003ooooo
ool0GOooo`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000P<ol000<0003oooooool0G_oo
o`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000P<ol000<0003oooooool0G_ooo`03o`2I
oooooooo03;oool006Ooool00`0003?o03?o000O<ol000<0003oooooool0Goooo`03o`2Ioooooooo
03;oool005ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`1Ooooo00?o09Wooooo
ool0<_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003oooooool0H?oo
o`03o`2Ioooooooo03;oool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`1P
oooo00?o09Woooooool0<_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0
003oooooool0HOooo`03o`2Ioooooooo03;oool0067oool00`000?ooooooo`03oooo00<0000co`0c
o`007C?o00030000oooooooo067oool00ol0VOooooooo`0boooo001Poooo0P0000Goool00`0003?o
03?o000L<ol000<0003oooooool0H_ooo`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000L
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000K<ol000<0
003oooooool0Hoooo`03o`2Ioooooooo03;oool006Ooool2000073?o00030000oooooooo06?oool0
0ol0VOooooooo`0boooo001Woooo00<0000co`0co`006S?o00030000oooooooo06Coool00ol0VOoo
ooooo`0boooo001Woooo00<0000co`0co`006S?o00030000oooooooo06Coool00ol0VOooooooo`0b
oooo001Woooo00<0000co`0co`006C?o00030000oooooooo06Goool00ol0VOooooooo`0boooo001W
oooo00<0000co`0co`006C?o00030000oooooooo06Goool00ol0VOooooooo`0boooo001Woooo00<0
000co`0co`0063?o00030000oooooooo06Koool00ol0VOooooooo`0boooo001Woooo0P0001Tco`00
0`000?ooooooo`1Voooo00?o09Woooooool0<_ooo`00Ioooo`030000<ol0<ol001Lco`000`000?oo
ooooo`1Woooo00?o09Woooooool0<_ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1W
oooo00?o09Woooooool0<_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1Xoooo00?o
09Woooooool0<_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1Xoooo00?o09Wooooo
ool0<_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1Xoooo00?o09Woooooool0<_oo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1Yoooo00?o09Woooooool0<_ooo`00Iooo
o`80000F<ol000<0003oooooool0JOooo`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000E
<ol000<0003oooooool0JOooo`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000E<ol000<0
003oooooool0JOooo`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000D<ol000<0003ooooo
ool0J_ooo`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000D<ol000<0003oooooool0J_oo
o`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000D<ol000<0003oooooool0J_ooo`03o`2I
oooooooo03;oool006Ooool200005C?o00030000oooooooo06[oool00ol0VOooooooo`0boooo001W
oooo00<0000co`0co`004c?o00030000oooooooo06_oool00ol0VOooooooo`0boooo001Woooo00<0
000co`0co`004c?o00030000oooooooo06_oool00ol0VOooooooo`0boooo001Woooo00<0000co`0c
o`004c?o00030000oooooooo06_oool00ol0VOooooooo`0boooo001Ooooo100000Coool00`0003?o
03?o000C<ol000<0003oooooool0Joooo`03o`2Ioooooooo03;oool005ooool00`000?ooooooo`05
oooo00<0000co`0co`004S?o00030000oooooooo06coool00ol0VOooooooo`0boooo001Poooo00<0
003oooooool01?ooo`80000C<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03;oool0067oool0
0`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo06coool00ol0VOooooooo`0b
oooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo06goool0
0ol0VOooooooo`0boooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool0KOoo
o`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000A<ol000<0003oooooool0KOooo`03o`2I
oooooooo03;oool006Ooool00`0003?o03?o000A<ol000<0003oooooool0KOooo`03o`2Ioooooooo
03;oool006Ooool200004C?o00030000oooooooo06koool00ol0VOooooooo`0boooo001Woooo00<0
000co`0co`0043?o00030000oooooooo06koool00ol0VOooooooo`0boooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo06koool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`0043?o
00030000oooooooo06koool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`003c?o00030000
oooooooo06ooool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`003c?o00030000oooooooo
06ooool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`003c?o00030000oooooooo06ooool0
0ol0VOooooooo`0boooo001Woooo0P00010co`000`000?ooooooo`1_oooo00?o09Woooooool0<_oo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1`oooo00?o09Woooooool0<_ooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`1`oooo00?o09Woooooool0<_ooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`1`oooo00?o09Woooooool0<_ooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`1`oooo00?o09Woooooool0<_ooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`1aoooo00?o09Woooooool0<_ooo`00Ioooo`80000><ol000<0003oooooool0LOoo
o`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000=<ol000<0003oooooool0LOooo`03o`2I
oooooooo03;oool006Ooool00`0003?o03?o000=<ol000<0003oooooool0LOooo`03o`2Ioooooooo
03;oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03;oool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03;oool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0L_ooo`03o`2Ioooooooo03;oool006Ooool200003C?o
00030000oooooooo07;oool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`0033?o00030000
oooooooo07;oool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`0033?o00030000oooooooo
07;oool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`002c?o00030000oooooooo07?oool0
0ol0VOooooooo`0boooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool0Looo
o`03o`2Ioooooooo03;oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0
003oooooool0Loooo`03o`2Ioooooooo03;oool0067oool00`000?ooooooo`03oooo0P0000`co`00
0`000?ooooooo`1coooo00?o09Woooooool0<_ooo`00H_ooo`030000oooooooo00;oool00`0003?o
03?o000;<ol000<0003oooooool0Loooo`03o`2Ioooooooo03;oool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000;<ol000<0003oooooool0Loooo`03o`2Ioooooooo03;oool0063oool2
00001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`1doooo00?o09Woooooool0<_ooo`00Iooo
o`030000<ol0<ol000Xco`000`000?ooooooo`1doooo00?o09Woooooool0<_ooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`1doooo00?o09Woooooool0<_ooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`1doooo00?o09Woooooool0<_ooo`00Ioooo`80000;<ol000<0003ooooo
ool0M?ooo`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o000:<ol000<0003oooooool0M?oo
o`03o`2Ioooooooo03;oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0MOooo`03o`2I
oooooooo03;oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0MOooo`03o`2Ioooooooo
03;oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0MOooo`03o`2Ioooooooo03;oool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0MOooo`03o`2Ioooooooo03;oool006Ooool2
00002S?o00030000oooooooo07Goool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`002C?o
00030000oooooooo07Goool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`002C?o00030000
oooooooo07Goool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`0023?o00030000oooooooo
07Koool00ol0VOooooooo`0boooo001Woooo00<0000co`0co`0023?o00030000oooooooo07Koool0
0ol0VOooooooo`0boooo001Woooo00<0000co`0co`0023?o00030000oooooooo07Koool00ol0VOoo
ooooo`0boooo001Woooo0P0000Tco`000`000?ooooooo`1foooo00?o09Woooooool0<_ooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`1foooo00?o09Woooooool0<_ooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1foooo00?o09Woooooool0<_ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1goooo00?o09Woooooool0<_ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1goooo00?o09Woooooool0<_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1goooo00?o09Woooooool0<_ooo`00Ioooo`800008<ol000<0003oooooool0Moooo`03o`2I
oooooooo03;oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Moooo`03o`2Ioooooooo
03;oool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Moooo`03o`2Ioooooooo03;oool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0Moooo`03o`2Ioooooooo03;oool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0Moooo`03o`2Ioooooooo03;oool0067oool300000ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1goooo00?o09Woooooool0<_ooo`00H_ooo`030000
oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0Moooo`03o`2Ioooooooo03;oool0
05ooool500000oooo`800008<ol000<0003oooooool0Moooo`03o`2Ioooooooo03;oool005ooool0
10000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOoo
o`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200000oooo`<00005oooo0`0000;oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00005oooo00D0
003oooooooooool00000N_ooo`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`07oooo00@0003oooooool00002oooo1@0000?oool00`000?ooooooo`1g
oooo001Woooo2C?o00Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool300000ooo
o`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooo
oooo0000017oool00`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooo000000?oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Woool00`000?ooooooo`0Aoooo0P0000[oool300001?oo
o`800002oooo00<0003oooooool0NOooo`00Ioooo`Tco`2`oooo001Woooo23?o0;7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.84911 .12361 L
.85396 .12361 L
.85916 .12361 L
.86176 .12361 L
.86423 .12361 L
.86645 .12361 L
.8677 .12361 L
s
.8677 .12361 m
.86816 .61803 L
s
0 .4 1 r
.02381 .06187 m
.02605 .06185 L
.02729 .06183 L
.02846 .06182 L
.02954 .06182 L
.03072 .06181 L
.0318 .06181 L
.03279 .0618 L
.03396 .0618 L
.03506 .0618 L
.03626 .06181 L
.03756 .06181 L
.03821 .06181 L
.03891 .06182 L
.0402 .06182 L
.04262 .06184 L
.04523 .06187 L
.04759 .06191 L
.0529 .062 L
.06244 .06225 L
.07287 .06261 L
.08414 .06311 L
.10458 .06424 L
.14558 .0672 L
.18507 .07063 L
.22304 .07421 L
.26347 .07814 L
.30238 .08189 L
.32219 .08377 L
.33264 .08474 L
.34374 .08576 L
.35357 .08645 L
.35917 .08673 L
.36443 .08694 L
.36677 .08701 L
.36924 .08707 L
.37137 .08712 L
.37365 .08716 L
.37494 .08718 L
.37611 .08719 L
.3773 .08721 L
.37839 .08721 L
.37967 .08722 L
.38035 .08723 L
.38106 .08723 L
.38226 .08723 L
.38358 .08723 L
.38488 .08723 L
.38608 .08723 L
.38739 .08722 L
Mistroke
.38879 .08721 L
.39139 .08718 L
.39374 .08715 L
.39853 .08707 L
.40303 .08696 L
.41307 .08664 L
.42392 .08617 L
.4439 .08504 L
.46498 .08353 L
.503 .08013 L
.54348 .07575 L
.58244 .07094 L
.62385 .06532 L
.66375 .05949 L
.70213 .05362 L
.74296 .04721 L
.78228 .04109 L
.82009 .03547 L
.8411 .03258 L
.8503 .03139 L
.85516 .03078 L
.86034 .03015 L
.86298 .02984 L
.86547 .02955 L
.86656 .02942 L
.86771 .02929 L
.86897 .12361 L
.87013 .12361 L
.87923 .12361 L
.89908 .12361 L
.93702 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo08;oool00`1Vooooooooo`0aoooo001Woooo00<0003ooooo
ool0NOooo`X0I_lcoooo001Woooo00<0003oooooool0L_ooo`L0I_l9oooo00<0I_ooooooool0<Ooo
o`00Ioooo`030000oooooooo06_oool706Ko4?ooo`0306Kooooooooo037oool006Ooool00`000?oo
ooooo`1Voooo1@1VoaOoool00`1Vooooooooo`0aoooo001Woooo00<0003oooooool0HOooo`D0I_lL
oooo00<0I_ooooooool0<Oooo`00Ioooo`80001Loooo1P1Vob7oool00`1Vooooooooo`0aoooo001W
oooo00<0003oooooool0E?ooo`L0I_lWoooo00<0I_ooooooool0<Oooo`00Ioooo`030000oooooooo
04coool806Ko;_ooo`0306Kooooooooo037oool001KooolJ06Ko=oooo`030000oooooooo04Ooool5
06Ko=_ooo`0306Kooooooooo037oool0033oool:06Ko;Oooo`030000oooooooo043oool706Ko>ooo
o`0306Kooooooooo037oool003[oool:06Ko8oooo`030000oooooooo03Koool:06Ko@_ooo`0306Ko
oooooooo037oool004Coool:06Ko6Oooo`80000]oooo2P1Vodcoool00`1Vooooooooo`0aoooo000G
oooo1@0001koool200001?ooo`800004oooo0P0000Koool:06Ko3oooo`030000oooooooo01koool2
00000_ooo`80I_l20000101Vo`80000Ooooo1@0001goool500000_ooo`800004oooo0P0000Ooool0
0`1Vooooooooo`0Foooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool0000?oooo301Vo`?oool00`000?ooooooo`0Joooo0`1Vo`05000006Ko06Ko
000006Ko00Ooool010000?ooooooo`00023oool00`000?ooooooo`0Ooooo00<0003oooooool01ooo
o`040000oooooooo00001_ooo`0306Kooooooooo01Koool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo01Woool306Ko00<00000I_l0
I_l06P1Vo`?oool010000?ooooooo`0000_oool00`000?ooooooo`0Noooo00<0003oooooool07ooo
o`030000oooooooo00[oool00`000?ooooooo`04oooo00<0I_ooooooool05oooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Ooo
o`80000Ooooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`80000Qoooo00<0003ooooo
ool07oooo`030000oooooooo00Soool200001oooo`0306Kooooooooo01Soool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool01_ooo`0306Kooooooooo01Koool010000?oo
ooooo`0001Koool001Soool200008?ooo`80000:oooo0`0001koool200007oooo`80000:oooo0`00
01ooool200008?ooo`80000:oooo0`0000Koool00`1Vooooooooo`0Goooo0P0001Ooool006Ooool0
0`000?ooooooo`23oooo00<0I_ooooooool0<?ooo`00Ioooo`030000oooooooo08?oool00`1Voooo
ooooo`0`oooo001Woooo00<0003oooooool0Poooo`0306Kooooooooo033oool006Ooool00`000?oo
ooooo`23oooo00<0I_ooooooool0<?ooo`00Ioooo`030000oooooooo08?oool00`1Vooooooooo`0`
oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0004<ol09P000005o`2I0000oooooooo000000Ooool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol0400001Woool00`000?ooooooo`0:
oooo00?o09Woooooool06Oooo`030000oooooooo01Goool006Ooool00`0003?o03?o0017<ol01@00
03Koool00ol0VOooooooo`0aoooo001Woooo00<0000co`0co`00@S?o00D0000koooo00?o09Wooooo
ool0<Oooo`00Ioooo`030000<ol0<ol003dco`050000@?ooo`03o`2Ioooooooo037oool006Ooool0
0`0003?o03?o000i<ol0100004Goool00ol0VOooooooo`0aoooo001Woooo0P0003Pco`020000BOoo
o`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000e<ol00P0004_oool00ol0VOooooooo`0a
oooo001Woooo00<0000co`0co`00<c?o0080001=oooo00?o09Woooooool0<Oooo`00Ioooo`030000
<ol0<ol0034co`020000Coooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000`<ol000<0
003oooooool0Coooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000^<ol00P0005;oool0
0ol0VOooooooo`0aoooo001Woooo0P0002dco`020000E?ooo`03o`2Ioooooooo037oool006Ooool0
0`0003?o03?o000[<ol000<0003oooooool0E?ooo`03o`2Ioooooooo037oool006Ooool00`0003?o
03?o000Z<ol000<0003oooooool0EOooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000Y
<ol000<0003oooooool0E_ooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000X<ol000<0
003oooooool0Eoooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000X<ol000<0003ooooo
ool0Eoooo`03o`2Ioooooooo037oool006Ooool20000:3?o00030000oooooooo05Soool00ol0VOoo
ooooo`0aoooo001Woooo00<0000co`0co`009S?o00030000oooooooo05Woool00ol0VOooooooo`0a
oooo001Woooo00<0000co`0co`009C?o00030000oooooooo05[oool00ol0VOooooooo`0aoooo001W
oooo00<0000co`0co`0093?o00030000oooooooo05_oool00ol0VOooooooo`0aoooo001Woooo00<0
000co`0co`008c?o00030000oooooooo05coool00ol0VOooooooo`0aoooo001Woooo00<0000co`0c
o`008c?o00030000oooooooo05coool00ol0VOooooooo`0aoooo001Woooo0P0002<co`000`000?oo
ooooo`1Moooo00?o09Woooooool0<Oooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`1N
oooo00?o09Woooooool0<Oooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`1Ooooo00?o
09Woooooool0<Oooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`1Ooooo00?o09Wooooo
ool0<Oooo`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`1Poooo00?o09Woooooool0<Ooo
o`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo063oool00ol0VOooooooo`0a
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`1Qoooo00?o
09Woooooool0<Oooo`00HOooo`030000oooooooo00?oool200007c?o00030000oooooooo067oool0
0ol0VOooooooo`0aoooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?oo
ooooo`1Roooo00?o09Woooooool0<Oooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo037oool0063oool200001Oooo`030000<ol0<ol0
01`co`000`000?ooooooo`1Soooo00?o09Woooooool0<Oooo`00Ioooo`030000<ol0<ol001`co`00
0`000?ooooooo`1Soooo00?o09Woooooool0<Oooo`00Ioooo`030000<ol0<ol001/co`000`000?oo
ooooo`1Toooo00?o09Woooooool0<Oooo`00Ioooo`80000L<ol000<0003oooooool0I?ooo`03o`2I
oooooooo037oool006Ooool00`0003?o03?o000J<ol000<0003oooooool0IOooo`03o`2Ioooooooo
037oool006Ooool00`0003?o03?o000J<ol000<0003oooooool0IOooo`03o`2Ioooooooo037oool0
06Ooool00`0003?o03?o000I<ol000<0003oooooool0I_ooo`03o`2Ioooooooo037oool006Ooool0
0`0003?o03?o000I<ol000<0003oooooool0I_ooo`03o`2Ioooooooo037oool006Ooool00`0003?o
03?o000H<ol000<0003oooooool0Ioooo`03o`2Ioooooooo037oool006Ooool200006C?o00030000
oooooooo06Ooool00ol0VOooooooo`0aoooo001Woooo00<0000co`0co`005c?o00030000oooooooo
06Soool00ol0VOooooooo`0aoooo001Woooo00<0000co`0co`005c?o00030000oooooooo06Soool0
0ol0VOooooooo`0aoooo001Woooo00<0000co`0co`005S?o00030000oooooooo06Woool00ol0VOoo
ooooo`0aoooo001Woooo00<0000co`0co`005S?o00030000oooooooo06Woool00ol0VOooooooo`0a
oooo001Woooo00<0000co`0co`005S?o00030000oooooooo06Woool00ol0VOooooooo`0aoooo001W
oooo00<0000co`0co`005C?o00030000oooooooo06[oool00ol0VOooooooo`0aoooo001Woooo0P00
01Hco`000`000?ooooooo`1Zoooo00?o09Woooooool0<Oooo`00Ioooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1Zoooo00?o09Woooooool0<Oooo`00Ioooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1Zoooo00?o09Woooooool0<Oooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1[
oooo00?o09Woooooool0<Oooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1[oooo00?o
09Woooooool0<Oooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1[oooo00?o09Wooooo
ool0<Oooo`00Ioooo`80000E<ol000<0003oooooool0Joooo`03o`2Ioooooooo037oool006Ooool0
0`0003?o03?o000C<ol000<0003oooooool0K?ooo`03o`2Ioooooooo037oool006Ooool00`0003?o
03?o000C<ol000<0003oooooool0K?ooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000C
<ol000<0003oooooool0K?ooo`03o`2Ioooooooo037oool005ooool400001?ooo`030000<ol0<ol0
01<co`000`000?ooooooo`1/oooo00?o09Woooooool0<Oooo`00Goooo`030000oooooooo00Goool0
0`0003?o03?o000B<ol000<0003oooooool0KOooo`03o`2Ioooooooo037oool0063oool00`000?oo
ooooo`04oooo0P0001<co`000`000?ooooooo`1]oooo00?o09Woooooool0<Oooo`00HOooo`030000
oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0KOooo`03o`2Ioooooooo037oool0
05ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool0K_ooo`03o`2I
oooooooo037oool0063oool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`1^oooo00?o
09Woooooool0<Oooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1^oooo00?o09Wooooo
ool0<Oooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1^oooo00?o09Woooooool0<Ooo
o`00Ioooo`80000A<ol000<0003oooooool0Koooo`03o`2Ioooooooo037oool006Ooool00`0003?o
03?o000@<ol000<0003oooooool0Koooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000@
<ol000<0003oooooool0Koooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000@<ol000<0
003oooooool0Koooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000?<ol000<0003ooooo
ool0L?ooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000?<ol000<0003oooooool0L?oo
o`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000?<ol000<0003oooooool0L?ooo`03o`2I
oooooooo037oool006Ooool2000043?o00030000oooooooo073oool00ol0VOooooooo`0aoooo001W
oooo00<0000co`0co`003S?o00030000oooooooo077oool00ol0VOooooooo`0aoooo001Woooo00<0
000co`0co`003S?o00030000oooooooo077oool00ol0VOooooooo`0aoooo001Woooo00<0000co`0c
o`003S?o00030000oooooooo077oool00ol0VOooooooo`0aoooo001Woooo00<0000co`0co`003S?o
00030000oooooooo077oool00ol0VOooooooo`0aoooo001Woooo00<0000co`0co`003C?o00030000
oooooooo07;oool00ol0VOooooooo`0aoooo001Woooo0P0000hco`000`000?ooooooo`1boooo00?o
09Woooooool0<Oooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1boooo00?o09Wooooo
ool0<Oooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1boooo00?o09Woooooool0<Ooo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`1coooo00?o09Woooooool0<Oooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`1coooo00?o09Woooooool0<Oooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`1coooo00?o09Woooooool0<Oooo`00Ioooo`80000=<ol000<0
003oooooool0Loooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000<<ol000<0003ooooo
ool0Loooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0Looo
o`03o`2Ioooooooo037oool006Ooool00`0003?o03?o000;<ol000<0003oooooool0M?ooo`03o`2I
oooooooo037oool0063oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`1doooo00?o
09Woooooool0<Oooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?oo
ooooo`1doooo00?o09Woooooool0<Oooo`00HOooo`030000oooooooo00?oool2000033?o00030000
oooooooo07Coool00ol0VOooooooo`0aoooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol0
00/co`000`000?ooooooo`1doooo00?o09Woooooool0<Oooo`00Goooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`1doooo00?o09Woooooool0<Oooo`00H?ooo`800005
oooo00<0000co`0co`002S?o00030000oooooooo07Goool00ol0VOooooooo`0aoooo001Woooo00<0
000co`0co`002S?o00030000oooooooo07Goool00ol0VOooooooo`0aoooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo07Goool00ol0VOooooooo`0aoooo001Woooo00<0000co`0co`002S?o
00030000oooooooo07Goool00ol0VOooooooo`0aoooo001Woooo0P0000/co`000`000?ooooooo`1e
oooo00?o09Woooooool0<Oooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1eoooo00?o
09Woooooool0<Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1foooo00?o09Wooooo
ool0<Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1foooo00?o09Woooooool0<Ooo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1foooo00?o09Woooooool0<Oooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1foooo00?o09Woooooool0<Oooo`00Ioooo`80000:
<ol000<0003oooooool0M_ooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o0009<ol000<0
003oooooool0M_ooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0M_ooo`03o`2Ioooooooo037oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Mooo
o`03o`2Ioooooooo037oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Moooo`03o`2I
oooooooo037oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Moooo`03o`2Ioooooooo
037oool006Ooool200002C?o00030000oooooooo07Ooool00ol0VOooooooo`0aoooo001Woooo00<0
000co`0co`0023?o00030000oooooooo07Ooool00ol0VOooooooo`0aoooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo07Ooool00ol0VOooooooo`0aoooo001Woooo00<0000co`0co`001c?o
00030000oooooooo07Soool00ol0VOooooooo`0aoooo001Woooo00<0000co`0co`001c?o00030000
oooooooo07Soool00ol0VOooooooo`0aoooo001Woooo00<0000co`0co`001c?o00030000oooooooo
07Soool00ol0VOooooooo`0aoooo001Woooo0P0000Pco`000`000?ooooooo`1hoooo00?o09Wooooo
ool0<Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1hoooo00?o09Woooooool0<Ooo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1hoooo00?o09Woooooool0<Oooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1hoooo00?o09Woooooool0<Oooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`1hoooo00?o09Woooooool0<Oooo`00HOooo`<00003oooo00<0
000co`0co`001c?o00030000oooooooo07Soool00ol0VOooooooo`0aoooo001Roooo00<0003ooooo
ool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`1hoooo00?o09Woooooool0<Oooo`00Gooo
o`D00003oooo0P0000Pco`000`000?ooooooo`1hoooo00?o09Woooooool0<Oooo`00Goooo`040000
oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P00
00Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Oooo`030000
oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool500000_ooo`800003oooo0`0000?oool300001?ooo`030000
oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0
003oooooool03oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?ooooooo`00
00Coool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003_ooo`030000
oooooooo00Ooool300000oooo`<00004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0
003oooooooooool000004Oooo`030000oooooooo00Soool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo017oool200002_oo
o`<00003oooo0`0000;oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.84911 .12361 L
.85916 .12361 L
.86384 .12361 L
.86886 .12361 L
.87129 .12361 L
.87248 .12361 L
.87359 .12361 L
.87459 .12361 L
s
.87459 .12361 m
.87502 .61803 L
s
0 .4 1 r
.02381 .06181 m
.02499 .06181 L
.02605 .06181 L
.02729 .0618 L
.02846 .0618 L
.02954 .0618 L
.03053 .06181 L
.03163 .06181 L
.03279 .06182 L
.0352 .06183 L
.03746 .06186 L
.04262 .06193 L
.04761 .06203 L
.05217 .06214 L
.06244 .06246 L
.07277 .06287 L
.08405 .06342 L
.10458 .06464 L
.14523 .0677 L
.18435 .07115 L
.22594 .07511 L
.266 .079 L
.30455 .08271 L
.3241 .08454 L
.33446 .0855 L
.34556 .08648 L
.35104 .08687 L
.35624 .08717 L
.3609 .08738 L
.36598 .08756 L
.37078 .08768 L
.37321 .08773 L
.37588 .08777 L
.37816 .08779 L
.37944 .0878 L
.38061 .0878 L
.38164 .08781 L
.38277 .08781 L
.38395 .08781 L
.38505 .08781 L
.38632 .0878 L
.38696 .0878 L
.38767 .0878 L
.39009 .08778 L
.39146 .08776 L
.39292 .08775 L
.39557 .08771 L
.40076 .0876 L
.4055 .08748 L
.41504 .08716 L
Mistroke
.42409 .08677 L
.44394 .08567 L
.46234 .08439 L
.50152 .08099 L
.54315 .07656 L
.58327 .07167 L
.62187 .06649 L
.66293 .06056 L
.70247 .05455 L
.74049 .0486 L
.78097 .04226 L
.81993 .0364 L
.83978 .03361 L
.85024 .03221 L
.86134 .0308 L
.86609 .03022 L
.87121 .02961 L
.87263 .02945 L
.87341 .02936 L
.87414 .02928 L
.87542 .12361 L
.8761 .12361 L
.87682 .12361 L
.88208 .12361 L
.90124 .12361 L
.94279 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo08Coool00`1Vooooooooo`0_oooo001Woooo00<0003ooooo
ool0OOooo`P0I_laoooo001Woooo00<0003oooooool0M?ooo`T0I_l7oooo00<0I_ooooooool0;ooo
o`00Ioooo`030000oooooooo06ooool506Ko4?ooo`0306Kooooooooo02ooool006Ooool00`000?oo
ooooo`1Xoooo1`1VoaGoool00`1Vooooooooo`0_oooo001Woooo00<0003oooooool0H?ooo`P0I_lL
oooo00<0I_ooooooool0;oooo`00Ioooo`80001Loooo1@1VobCoool00`1Vooooooooo`0_oooo001W
oooo00<0003oooooool0E?ooo`L0I_lYoooo00<0I_ooooooool0;oooo`00Ioooo`030000oooooooo
04coool806Ko<?ooo`0306Kooooooooo02ooool001KooolJ06Ko=oooo`030000oooooooo04Ooool5
06Ko>?ooo`0306Kooooooooo02ooool0033oool:06Ko;Oooo`030000oooooooo043oool706Ko?Ooo
o`0306Kooooooooo02ooool003[oool:06Ko8oooo`030000oooooooo03Koool:06KoA?ooo`0306Ko
oooooooo02ooool004Coool;06Ko6?ooo`80000_oooo201Vodkoool00`1Vooooooooo`0_oooo000G
oooo1@0001koool200001?ooo`800004oooo0P0000Ooool:06Ko3_ooo`030000oooooooo01koool2
00001?ooo`800002oooo0P1Vo`80000206Ko7Oooo`D0000Moooo1@0000;oool200001?ooo`800008
oooo00<0I_ooooooool05Oooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00004?ooo`/0I_l3oooo00<0003oooooool06_ooo`<0I_l01000001V
o`1Vo`0000L0I_l01Oooo`000?ooooooo`00000Poooo00<0003oooooool07oooo`030000oooooooo
00Ooool010000?ooooooo`0000Ooool00`1Vooooooooo`0Eoooo00<0003oooooool05oooo`006Ooo
o`030000oooooooo01goool010000?ooooooo`0000_oool00`000?ooooooo`0Ioooo0`1Vo`030000
06Ko06Ko01X0I_l3oooo00@0003oooooool0000;oooo00<0003oooooool07_ooo`030000oooooooo
01ooool00`000?ooooooo`0:oooo00<0003oooooool01Oooo`0306Kooooooooo01Koool00`000?oo
ooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool010000?ooooooo`00
00Woool200007oooo`030000oooooooo01goool010000?ooooooo`0000Woool200008Oooo`030000
oooooooo01ooool00`000?ooooooo`08oooo0P0000Soool00`1Vooooooooo`0Goooo00<0003ooooo
ool05Oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Woool00`000?ooooooo`0N
oooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo023oool00`000?oo
ooooo`0Ooooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`1Vooooooooo`0Eoooo00@0
003oooooool0000Foooo000Hoooo0P00023oool200002_ooo`<0000Noooo0P0001ooool200002_oo
o`<0000Ooooo0P00023oool200002_ooo`<00007oooo00<0I_ooooooool05_ooo`80000Goooo001W
oooo00<0003oooooool0Q?ooo`0306Kooooooooo02ooool006Ooool00`000?ooooooo`24oooo00<0
I_ooooooool0;oooo`00Ioooo`030000oooooooo08Coool00`1Vooooooooo`0_oooo001Woooo00<0
003oooooool0Q?ooo`0306Kooooooooo02ooool006Ooool00`000?ooooooo`24oooo00<0I_oooooo
ool0;oooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`0013?o02P000000ol0VOooo`000007oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo
02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o0100000Ioooo00<0003oooooool03?oo
o`03o`2Ioooooooo01Ooool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`00Ac?o00D0000h
oooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol0048co`050000?Oooo`03o`2Ioooooooo
02ooool006Ooool00`0003?o03?o000m<ol01@0004;oool00ol0VOooooooo`0_oooo001Woooo00<0
000co`0co`00>C?o00@00017oooo00?o09Woooooool0;oooo`00Ioooo`80000h<ol00P0004_oool0
0ol0VOooooooo`0_oooo001Woooo00<0000co`0co`00=C?o0080001=oooo00?o09Woooooool0;ooo
o`00Ioooo`030000<ol0<ol003<co`020000Coooo`03o`2Ioooooooo02ooool006Ooool00`0003?o
03?o000a<ol00P00057oool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`00<3?o00030000
oooooooo057oool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`00;S?o0080001Doooo00?o
09Woooooool0;oooo`00Ioooo`80000]<ol00P0005Koool00ol0VOooooooo`0_oooo001Woooo00<0
000co`0co`00:c?o00030000oooooooo05Koool00ol0VOooooooo`0_oooo001Woooo00<0000co`0c
o`00:S?o00030000oooooooo05Ooool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`00:C?o
00030000oooooooo05Soool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`00:3?o00030000
oooooooo05Woool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`00:3?o00030000oooooooo
05Woool00ol0VOooooooo`0_oooo001Woooo0P0002Pco`000`000?ooooooo`1Joooo00?o09Wooooo
ool0;oooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`1Koooo00?o09Woooooool0;ooo
o`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Iooo
o`030000<ol0<ol002@co`000`000?ooooooo`1Moooo00?o09Woooooool0;oooo`00Ioooo`030000
<ol0<ol002<co`000`000?ooooooo`1Noooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol0
02<co`000`000?ooooooo`1Noooo00?o09Woooooool0;oooo`00Ioooo`80000S<ol000<0003ooooo
ool0Goooo`03o`2Ioooooooo02ooool006Ooool00`0003?o03?o000Q<ol000<0003oooooool0H?oo
o`03o`2Ioooooooo02ooool006Ooool00`0003?o03?o000P<ol000<0003oooooool0HOooo`03o`2I
oooooooo02ooool006Ooool00`0003?o03?o000P<ol000<0003oooooool0HOooo`03o`2Ioooooooo
02ooool006Ooool00`0003?o03?o000O<ol000<0003oooooool0H_ooo`03o`2Ioooooooo02ooool0
05ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`1Roooo00?o09Woooooool0;ooo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003oooooool0Hoooo`03o`2I
oooooooo02ooool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`1Soooo00?o
09Woooooool0;oooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003ooooo
ool0I?ooo`03o`2Ioooooooo02ooool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o
00030000oooooooo06Coool00ol0VOooooooo`0_oooo001Poooo0P0000Goool00`0003?o03?o000L
<ol000<0003oooooool0IOooo`03o`2Ioooooooo02ooool006Ooool00`0003?o03?o000L<ol000<0
003oooooool0IOooo`03o`2Ioooooooo02ooool006Ooool00`0003?o03?o000K<ol000<0003ooooo
ool0I_ooo`03o`2Ioooooooo02ooool006Ooool2000073?o00030000oooooooo06Koool00ol0VOoo
ooooo`0_oooo001Woooo00<0000co`0co`006S?o00030000oooooooo06Ooool00ol0VOooooooo`0_
oooo001Woooo00<0000co`0co`006S?o00030000oooooooo06Ooool00ol0VOooooooo`0_oooo001W
oooo00<0000co`0co`006C?o00030000oooooooo06Soool00ol0VOooooooo`0_oooo001Woooo00<0
000co`0co`006C?o00030000oooooooo06Soool00ol0VOooooooo`0_oooo001Woooo00<0000co`0c
o`0063?o00030000oooooooo06Woool00ol0VOooooooo`0_oooo001Woooo0P0001Tco`000`000?oo
ooooo`1Yoooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1Z
oooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1Zoooo00?o
09Woooooool0;oooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1[oooo00?o09Wooooo
ool0;oooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1[oooo00?o09Woooooool0;ooo
o`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1[oooo00?o09Woooooool0;oooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`1/oooo00?o09Woooooool0;oooo`00Ioooo`80000F
<ol000<0003oooooool0K?ooo`03o`2Ioooooooo02ooool006Ooool00`0003?o03?o000E<ol000<0
003oooooool0K?ooo`03o`2Ioooooooo02ooool006Ooool00`0003?o03?o000E<ol000<0003ooooo
ool0K?ooo`03o`2Ioooooooo02ooool006Ooool00`0003?o03?o000D<ol000<0003oooooool0KOoo
o`03o`2Ioooooooo02ooool006Ooool00`0003?o03?o000D<ol000<0003oooooool0KOooo`03o`2I
oooooooo02ooool006Ooool00`0003?o03?o000D<ol000<0003oooooool0KOooo`03o`2Ioooooooo
02ooool006Ooool200005C?o00030000oooooooo06goool00ol0VOooooooo`0_oooo001Woooo00<0
000co`0co`004c?o00030000oooooooo06koool00ol0VOooooooo`0_oooo001Woooo00<0000co`0c
o`004c?o00030000oooooooo06koool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`004c?o
00030000oooooooo06koool00ol0VOooooooo`0_oooo001Ooooo100000Coool00`0003?o03?o000C
<ol000<0003oooooool0K_ooo`03o`2Ioooooooo02ooool005ooool00`000?ooooooo`05oooo00<0
000co`0co`004S?o00030000oooooooo06ooool00ol0VOooooooo`0_oooo001Poooo00<0003ooooo
ool01?ooo`80000C<ol000<0003oooooool0Koooo`03o`2Ioooooooo02ooool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`004S?o00030000oooooooo06ooool00ol0VOooooooo`0_oooo001O
oooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo073oool00ol0VOoo
ooooo`0_oooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool0L?ooo`03o`2I
oooooooo02ooool006Ooool00`0003?o03?o000A<ol000<0003oooooool0L?ooo`03o`2Ioooooooo
02ooool006Ooool00`0003?o03?o000A<ol000<0003oooooool0L?ooo`03o`2Ioooooooo02ooool0
06Ooool200004C?o00030000oooooooo077oool00ol0VOooooooo`0_oooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo077oool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`0043?o
00030000oooooooo077oool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`0043?o00030000
oooooooo077oool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`003c?o00030000oooooooo
07;oool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`003c?o00030000oooooooo07;oool0
0ol0VOooooooo`0_oooo001Woooo00<0000co`0co`003c?o00030000oooooooo07;oool00ol0VOoo
ooooo`0_oooo001Woooo0P00010co`000`000?ooooooo`1boooo00?o09Woooooool0;oooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`1coooo00?o09Woooooool0;oooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`1coooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`1coooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`1coooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`1doooo00?o09Woooooool0;oooo`00Ioooo`80000><ol000<0003oooooool0M?ooo`03o`2I
oooooooo02ooool006Ooool00`0003?o03?o000=<ol000<0003oooooool0M?ooo`03o`2Ioooooooo
02ooool006Ooool00`0003?o03?o000=<ol000<0003oooooool0M?ooo`03o`2Ioooooooo02ooool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0MOooo`03o`2Ioooooooo02ooool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0MOooo`03o`2Ioooooooo02ooool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0MOooo`03o`2Ioooooooo02ooool006Ooool200003C?o00030000
oooooooo07Goool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`0033?o00030000oooooooo
07Goool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`0033?o00030000oooooooo07Goool0
0ol0VOooooooo`0_oooo001Woooo00<0000co`0co`002c?o00030000oooooooo07Koool00ol0VOoo
ooooo`0_oooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool0M_ooo`03o`2I
oooooooo02ooool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003ooooo
ool0M_ooo`03o`2Ioooooooo02ooool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?oo
ooooo`1foooo00?o09Woooooool0;oooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;
<ol000<0003oooooool0M_ooo`03o`2Ioooooooo02ooool005ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0M_ooo`03o`2Ioooooooo02ooool0063oool200001Ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`1goooo00?o09Woooooool0;oooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`1goooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`1goooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`1goooo00?o09Woooooool0;oooo`00Ioooo`80000;<ol000<0003oooooool0Mooo
o`03o`2Ioooooooo02ooool006Ooool00`0003?o03?o000:<ol000<0003oooooool0Moooo`03o`2I
oooooooo02ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0N?ooo`03o`2Ioooooooo
02ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0N?ooo`03o`2Ioooooooo02ooool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0N?ooo`03o`2Ioooooooo02ooool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0N?ooo`03o`2Ioooooooo02ooool006Ooool200002S?o
00030000oooooooo07Soool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`002C?o00030000
oooooooo07Soool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`002C?o00030000oooooooo
07Soool00ol0VOooooooo`0_oooo001Woooo00<0000co`0co`0023?o00030000oooooooo07Woool0
0ol0VOooooooo`0_oooo001Woooo00<0000co`0co`0023?o00030000oooooooo07Woool00ol0VOoo
ooooo`0_oooo001Woooo00<0000co`0co`0023?o00030000oooooooo07Woool00ol0VOooooooo`0_
oooo001Woooo0P0000Tco`000`000?ooooooo`1ioooo00?o09Woooooool0;oooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1ioooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1ioooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1joooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1joooo00?o09Woooooool0;oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1j
oooo00?o09Woooooool0;oooo`00Ioooo`800008<ol000<0003oooooool0N_ooo`03o`2Ioooooooo
02ooool006Ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02ooool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02ooool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02ooool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02ooool0067oool300000oooo`030000
<ol0<ol000Lco`000`000?ooooooo`1joooo00?o09Woooooool0;oooo`00H_ooo`030000oooooooo
00;oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02ooool005ooool5
00000oooo`800008<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02ooool005ooool010000?oo
ooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004
oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo1@0000;oool200000oooo`<00004oooo0P0000Coool00`000?oo
ooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`07oooo00<0003oooooool00_ooo`030000
oooooooo00ooool00`000?ooooooo`07oooo00@0003oooooool00002oooo00@0003oooooool00004
oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000koool00`000?oo
ooooo`07oooo0`0000Coool200001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000
oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oooooool00_ooo`040000oooooooo
00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo017oool200002_oo
o`<00003oooo0P0000?oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8<ol0/Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.85916 .12361 L
.86886 .12361 L
.87359 .12361 L
.87791 .12361 L
.87903 .12361 L
.88025 .12361 L
s
.88025 .12361 m
.88071 .61803 L
s
0 .4 1 r
.02381 .06181 m
.02499 .06181 L
.02605 .06182 L
.02729 .06182 L
.02846 .06183 L
.03279 .06188 L
.03524 .06191 L
.0375 .06195 L
.04262 .06206 L
.05224 .06233 L
.06244 .0627 L
.0825 .06368 L
.10458 .06507 L
.14487 .0682 L
.18364 .07168 L
.22486 .07562 L
.26457 .07948 L
.30277 .08314 L
.32408 .08513 L
.34341 .08688 L
.35309 .08756 L
.35854 .08785 L
.36356 .08805 L
.36796 .08818 L
.37279 .08829 L
.37522 .08833 L
.37656 .08834 L
.37783 .08836 L
.37901 .08837 L
.38029 .08837 L
.38146 .08838 L
.38254 .08838 L
.38372 .08838 L
.38496 .08838 L
.38602 .08838 L
.38717 .08837 L
.38842 .08837 L
.38976 .08836 L
.39217 .08833 L
.3946 .0883 L
.3969 .08826 L
.4012 .08818 L
.41109 .0879 L
.42181 .08748 L
.44168 .08644 L
.46273 .08501 L
.50061 .08178 L
.54095 .07758 L
.57978 .07295 L
.62105 .06749 L
Mistroke
.66081 .06182 L
.69906 .05605 L
.73976 .0497 L
.77894 .04356 L
.82057 .03723 L
.84148 .03424 L
.86069 .03168 L
.87041 .03046 L
.87516 .02989 L
.87723 .02965 L
.87948 .02939 L
.8807 .02925 L
.88182 .12361 L
.8829 .12361 L
.88404 .12361 L
.88893 .12361 L
.89929 .12361 L
.9371 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo08Goool00`1Vooooooooo`0^oooo001Woooo00<0003ooooo
ool0Ooooo`L0I_l`oooo001Woooo00<0003oooooool0N_ooo`D0I_l6oooo00<0I_ooooooool0;_oo
o`00Ioooo`030000oooooooo07;oool806Ko2oooo`0306Kooooooooo02koool006Ooool00`000?oo
ooooo`1Zoooo201Voa?oool00`1Vooooooooo`0^oooo001Woooo00<0003oooooool0IOooo`D0I_lK
oooo00<0I_ooooooool0;_ooo`00Ioooo`80001Noooo201Vob3oool00`1Vooooooooo`0^oooo001W
oooo00<0003oooooool0EOooo`P0I_lXoooo00<0I_ooooooool0;_ooo`00Ioooo`030000oooooooo
057oool406Ko<?ooo`0306Kooooooooo02koool001KooolB06Ko?oooo`030000oooooooo04[oool7
06Ko=?ooo`0306Kooooooooo02koool002SooolB06Ko;Oooo`030000oooooooo04;oool806Ko>ooo
o`0306Kooooooooo02koool003[oool:06Ko8oooo`030000oooooooo03coool606Ko@oooo`0306Ko
oooooooo02koool004Coool:06Ko6Oooo`80000foooo1`1VodWoool00`1Vooooooooo`0^oooo000G
oooo1@0001koool200001?ooo`800004oooo0P0000Koool:06Ko3oooo`030000oooooooo01koool2
00001?ooo`800004oooo0P0000T0I_lFoooo1@0001goool500000_ooo`800004oooo0P0000[oool0
0`1Vooooooooo`0Coooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool0000?oooo201Vo`Ooool00`000?ooooooo`0Moooo00@0003oooooool00008
06Ko00@00000I_ooool0000Poooo00<0003oooooool07oooo`030000oooooooo00Ooool010000?oo
ooooo`0000Woool00`1Vooooooooo`0Coooo00<0003oooooool05oooo`006Oooo`030000oooooooo
01goool010000?ooooooo`0000_oool00`000?ooooooo`0Eoooo1`1Vo`03000006Ko06Ko01d0I_l0
1000001Vo`1Vo`0000_oool00`000?ooooooo`0Noooo00<0003oooooool07oooo`030000oooooooo
00[oool00`000?ooooooo`07oooo00<0I_ooooooool05?ooo`030000oooooooo01Koool0017oool4
00001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Oooo`80000Ooooo00<0
003oooooool07Oooo`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool07oooo`030000
oooooooo00Soool200002_ooo`0306Kooooooooo01Goool00`000?ooooooo`0Eoooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool00`000?ooooooo`0M
oooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo01ooool00`000?oo
ooooo`08oooo00<0003oooooool02Oooo`0306Kooooooooo01?oool010000?ooooooo`0001Koool0
01Soool200008?ooo`80000:oooo0`0001koool200007oooo`80000:oooo0`0001ooool200008?oo
o`80000:oooo0`0000Woool00`1Vooooooooo`0Doooo0P0001Ooool006Ooool00`000?ooooooo`26
oooo00<0I_ooooooool0;Oooo`00Ioooo`030000oooooooo08Koool00`1Vooooooooo`0]oooo001W
oooo00<0003oooooool0Q_ooo`0306Kooooooooo02goool006Ooool00`000?ooooooo`26oooo00<0
I_ooooooool0;Oooo`00Ioooo`030000oooooooo08Koool00`1Vooooooooo`0]oooo000@ooooo`00
017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004
<ol0:0000003ooooo`2I000000Ooool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol0
02Dco`000`0003?o03?o000T<ol0400001Woool00`000?ooooooo`0=oooo00?o09Woooooool05_oo
o`030000oooooooo01Goool006Ooool00`0003?o03?o0017<ol01@0003Woool00ol0VOooooooo`0^
oooo001Woooo00<0000co`0co`00@S?o00D0000noooo00?o09Woooooool0;_ooo`00Ioooo`030000
<ol0<ol003dco`050000@oooo`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000i<ol01000
04Soool00ol0VOooooooo`0^oooo001Woooo0P0003Pco`020000C?ooo`03o`2Ioooooooo02koool0
06Ooool00`0003?o03?o000e<ol00P0004koool00ol0VOooooooo`0^oooo001Woooo00<0000co`0c
o`00<c?o0080001@oooo00?o09Woooooool0;_ooo`00Ioooo`030000<ol0<ol0034co`020000D_oo
o`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000`<ol000<0003oooooool0D_ooo`03o`2I
oooooooo02koool006Ooool00`0003?o03?o000^<ol00P0005Goool00ol0VOooooooo`0^oooo001W
oooo0P0002dco`020000Eoooo`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000[<ol000<0
003oooooool0Eoooo`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000Z<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000Y<ol000<0003oooooool0FOoo
o`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000X<ol000<0003oooooool0F_ooo`03o`2I
oooooooo02koool006Ooool00`0003?o03?o000X<ol000<0003oooooool0F_ooo`03o`2Ioooooooo
02koool006Ooool20000:3?o00030000oooooooo05_oool00ol0VOooooooo`0^oooo001Woooo00<0
000co`0co`009S?o00030000oooooooo05coool00ol0VOooooooo`0^oooo001Woooo00<0000co`0c
o`009C?o00030000oooooooo05goool00ol0VOooooooo`0^oooo001Woooo00<0000co`0co`0093?o
00030000oooooooo05koool00ol0VOooooooo`0^oooo001Woooo00<0000co`0co`008c?o00030000
oooooooo05ooool00ol0VOooooooo`0^oooo001Woooo00<0000co`0co`008c?o00030000oooooooo
05ooool00ol0VOooooooo`0^oooo001Woooo0P0002<co`000`000?ooooooo`1Poooo00?o09Wooooo
ool0;_ooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`1Qoooo00?o09Woooooool0;_oo
o`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`1Roooo00?o09Woooooool0;_ooo`00Iooo
o`030000<ol0<ol0020co`000`000?ooooooo`1Roooo00?o09Woooooool0;_ooo`00Ioooo`030000
<ol0<ol001lco`000`000?ooooooo`1Soooo00?o09Woooooool0;_ooo`00Goooo`D00003oooo00<0
000co`0co`007c?o00030000oooooooo06?oool00ol0VOooooooo`0^oooo001Qoooo00<0003ooooo
ool00oooo`030000<ol0<ol001hco`000`000?ooooooo`1Toooo00?o09Woooooool0;_ooo`00HOoo
o`030000oooooooo00?oool200007c?o00030000oooooooo06Coool00ol0VOooooooo`0^oooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`1Uoooo00?o09Wooooo
ool0;_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0IOoo
o`03o`2Ioooooooo02koool0063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`1V
oooo00?o09Woooooool0;_ooo`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`1Voooo00?o
09Woooooool0;_ooo`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`1Woooo00?o09Wooooo
ool0;_ooo`00Ioooo`80000L<ol000<0003oooooool0Ioooo`03o`2Ioooooooo02koool006Ooool0
0`0003?o03?o000J<ol000<0003oooooool0J?ooo`03o`2Ioooooooo02koool006Ooool00`0003?o
03?o000J<ol000<0003oooooool0J?ooo`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000I
<ol000<0003oooooool0JOooo`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000I<ol000<0
003oooooool0JOooo`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000H<ol000<0003ooooo
ool0J_ooo`03o`2Ioooooooo02koool006Ooool200006C?o00030000oooooooo06[oool00ol0VOoo
ooooo`0^oooo001Woooo00<0000co`0co`005c?o00030000oooooooo06_oool00ol0VOooooooo`0^
oooo001Woooo00<0000co`0co`005c?o00030000oooooooo06_oool00ol0VOooooooo`0^oooo001W
oooo00<0000co`0co`005S?o00030000oooooooo06coool00ol0VOooooooo`0^oooo001Woooo00<0
000co`0co`005S?o00030000oooooooo06coool00ol0VOooooooo`0^oooo001Woooo00<0000co`0c
o`005S?o00030000oooooooo06coool00ol0VOooooooo`0^oooo001Woooo00<0000co`0co`005C?o
00030000oooooooo06goool00ol0VOooooooo`0^oooo001Woooo0P0001Hco`000`000?ooooooo`1]
oooo00?o09Woooooool0;_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1]oooo00?o
09Woooooool0;_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1]oooo00?o09Wooooo
ool0;_ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1^oooo00?o09Woooooool0;_oo
o`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1^oooo00?o09Woooooool0;_ooo`00Iooo
o`030000<ol0<ol001@co`000`000?ooooooo`1^oooo00?o09Woooooool0;_ooo`00Ioooo`80000E
<ol000<0003oooooool0K_ooo`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000C<ol000<0
003oooooool0Koooo`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000C<ol000<0003ooooo
ool0Koooo`03o`2Ioooooooo02koool006Ooool00`0003?o03?o000C<ol000<0003oooooool0Kooo
o`03o`2Ioooooooo02koool005ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`1_
oooo00?o09Woooooool0;_ooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0
003oooooool0L?ooo`03o`2Ioooooooo02koool0063oool00`000?ooooooo`04oooo0P0001<co`00
0`000?ooooooo`1`oooo00?o09Woooooool0;_ooo`00HOooo`030000oooooooo00?oool00`0003?o
03?o000B<ol000<0003oooooool0LOooo`03o`2Ioooooooo02goool005ooool010000?ooooooo`00
00Coool00`0003?o03?o000A<ol000<0003oooooool0L_ooo`03o`2Ioooooooo02goool0063oool2
00001Oooo`030000<ol0<ol0014co`000`000?ooooooo`1boooo00?o09Woooooool0;Oooo`00Iooo
o`030000<ol0<ol0014co`000`000?ooooooo`1boooo00?o09Woooooool0;Oooo`00Ioooo`030000
<ol0<ol0014co`000`000?ooooooo`1boooo00?o09Woooooool0;Oooo`00Ioooo`80000A<ol000<0
003oooooool0Loooo`03o`2Ioooooooo02goool006Ooool00`0003?o03?o000@<ol000<0003ooooo
ool0Loooo`03o`2Ioooooooo02goool006Ooool00`0003?o03?o000@<ol000<0003oooooool0Looo
o`03o`2Ioooooooo02goool006Ooool00`0003?o03?o000@<ol000<0003oooooool0Loooo`03o`2I
oooooooo02goool006Ooool00`0003?o03?o000?<ol000<0003oooooool0M?ooo`03o`2Ioooooooo
02goool006Ooool00`0003?o03?o000?<ol000<0003oooooool0M?ooo`03o`2Ioooooooo02goool0
06Ooool00`0003?o03?o000?<ol000<0003oooooool0M?ooo`03o`2Ioooooooo02goool006Ooool2
000043?o00030000oooooooo07Coool00ol0VOooooooo`0]oooo001Woooo00<0000co`0co`003S?o
00030000oooooooo07Goool00ol0VOooooooo`0]oooo001Woooo00<0000co`0co`003S?o00030000
oooooooo07Goool00ol0VOooooooo`0]oooo001Woooo00<0000co`0co`003S?o00030000oooooooo
07Goool00ol0VOooooooo`0]oooo001Woooo00<0000co`0co`003S?o00030000oooooooo07Goool0
0ol0VOooooooo`0]oooo001Woooo00<0000co`0co`003C?o00030000oooooooo07Koool00ol0VOoo
ooooo`0]oooo001Woooo0P0000hco`000`000?ooooooo`1foooo00?o09Woooooool0;Oooo`00Iooo
o`030000<ol0<ol000dco`000`000?ooooooo`1foooo00?o09Woooooool0;Oooo`00Ioooo`030000
<ol0<ol000dco`000`000?ooooooo`1foooo00?o09Woooooool0;Oooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`1goooo00?o09Woooooool0;Oooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`1goooo00?o09Woooooool0;Oooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`1goooo00?o09Woooooool0;Oooo`00Ioooo`80000=<ol000<0003oooooool0Moooo`03o`2I
oooooooo02goool006Ooool00`0003?o03?o000<<ol000<0003oooooool0Moooo`03o`2Ioooooooo
02goool006Ooool00`0003?o03?o000<<ol000<0003oooooool0Moooo`03o`2Ioooooooo02goool0
06Ooool00`0003?o03?o000;<ol000<0003oooooool0N?ooo`03o`2Ioooooooo02goool0063oool2
00001Oooo`030000<ol0<ol000/co`000`000?ooooooo`1hoooo00?o09Woooooool0;Oooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1hoooo00?o09Wooooo
ool0;Oooo`00HOooo`030000oooooooo00?oool2000033?o00030000oooooooo07Soool00ol0VOoo
ooooo`0]oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`1h
oooo00?o09Woooooool0;Oooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`1hoooo00?o09Woooooool0;Oooo`00H?ooo`800005oooo00<0000co`0co`002S?o
00030000oooooooo07Woool00ol0VOooooooo`0]oooo001Woooo00<0000co`0co`002S?o00030000
oooooooo07Woool00ol0VOooooooo`0]oooo001Woooo00<0000co`0co`002S?o00030000oooooooo
07Woool00ol0VOooooooo`0]oooo001Woooo00<0000co`0co`002S?o00030000oooooooo07Woool0
0ol0VOooooooo`0]oooo001Woooo0P0000/co`000`000?ooooooo`1ioooo00?o09Woooooool0;Ooo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1ioooo00?o09Woooooool0;Oooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1joooo00?o09Woooooool0;Oooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`1joooo00?o09Woooooool0;Oooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1joooo00?o09Woooooool0;Oooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`1joooo00?o09Woooooool0;Oooo`00Ioooo`80000:<ol000<0003oooooool0N_oo
o`03o`2Ioooooooo02goool006Ooool00`0003?o03?o0009<ol000<0003oooooool0N_ooo`03o`2I
oooooooo02goool006Ooool00`0003?o03?o0009<ol000<0003oooooool0N_ooo`03o`2Ioooooooo
02goool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Noooo`03o`2Ioooooooo02goool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool0Noooo`03o`2Ioooooooo02goool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0Noooo`03o`2Ioooooooo02goool006Ooool200002C?o
00030000oooooooo07_oool00ol0VOooooooo`0]oooo001Woooo00<0000co`0co`0023?o00030000
oooooooo07_oool00ol0VOooooooo`0]oooo001Woooo00<0000co`0co`0023?o00030000oooooooo
07_oool00ol0VOooooooo`0]oooo001Woooo00<0000co`0co`001c?o00030000oooooooo07coool0
0ol0VOooooooo`0]oooo001Woooo00<0000co`0co`001c?o00030000oooooooo07coool00ol0VOoo
ooooo`0]oooo001Woooo00<0000co`0co`001c?o00030000oooooooo07coool00ol0VOooooooo`0]
oooo001Woooo0P0000Pco`000`000?ooooooo`1loooo00?o09Woooooool0;Oooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`1loooo00?o09Woooooool0;Oooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1loooo00?o09Woooooool0;Oooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1loooo00?o09Woooooool0;Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1loooo00?o09Woooooool0;Oooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000
oooooooo07coool00ol0VOooooooo`0]oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1loooo00?o09Woooooool0;Oooo`00Goooo`D00003oooo0P0000Pco`00
0`000?ooooooo`1loooo00?o09Woooooool0;Oooo`00Goooo`040000oooooooo00001?ooo`Xco`2_
oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Iooo
o`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol03?ooo`030000oooooooo02;oool00`000?oo
ooooo`1loooo001Woooo2C?o00_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool006Ooool9<ol02oooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool500000_ooo`800005oooo00<0003oooooool00_ooo`030000oooooooo07_oool006Ooool9
<ol02oooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01ooo
o`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Ioooo`Tco`0:
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003ooooo
ool00oooo`030000oooooooo07[oool006Ooool9<ol02oooo`030000oooooooo00D0000>oooo00<0
003oooooool02_ooo`050000oooooooooooo000007goool006Ooool9<ol02oooo`050000oooooooo
oooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Nooo
o`00Ioooo`Tco`0<oooo00<0003oooooool04Oooo`800009oooo100000;oool00`000?ooooooo`1l
oooo001Woooo2C?o0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.85916 .12361 L
.86886 .12361 L
.87791 .12361 L
.88246 .12361 L
.88378 .12361 L
.88502 .12361 L
.88613 .12361 L
s
.88613 .12361 m
.88662 .61803 L
s
0 .4 1 r
.02381 .06185 m
.02846 .06191 L
.03279 .06198 L
.04262 .06222 L
.0522 .06255 L
.06244 .06298 L
.08451 .06418 L
.10458 .06552 L
.14451 .06871 L
.18292 .07221 L
.22379 .07613 L
.26314 .07995 L
.30098 .08357 L
.32201 .08552 L
.34126 .08727 L
.35077 .08799 L
.35615 .08829 L
.36114 .08852 L
.36594 .08869 L
.37029 .0888 L
.3727 .08885 L
.37531 .08889 L
.3765 .08891 L
.37777 .08892 L
.37895 .08893 L
.38004 .08894 L
.38125 .08894 L
.3819 .08895 L
.38258 .08895 L
.38373 .08895 L
.38499 .08895 L
.38612 .08895 L
.38732 .08894 L
.38847 .08894 L
.38951 .08893 L
.39188 .08891 L
.39446 .08888 L
.39967 .08879 L
.40427 .08868 L
.40917 .08854 L
.41801 .08823 L
.43935 .08719 L
.45951 .08589 L
.49797 .08272 L
.53889 .07856 L
.57829 .07395 L
.61618 .06904 L
.65652 .06337 L
.69534 .05759 L
.73662 .05119 L
Mistroke
.77638 .04494 L
.81463 .03905 L
.83598 .03591 L
.85532 .03321 L
.86503 .03193 L
.87551 .03061 L
.88033 .03003 L
.88296 .02972 L
.88424 .02957 L
.88541 .02943 L
.88649 .02931 L
.88751 .12361 L
.88858 .12361 L
.88975 .12361 L
.89451 .12361 L
.93534 .12361 L
.97466 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo08Ooool00`1Vooooooooo`0/oooo001Woooo00<0003ooooo
ool0OOooo`/0I_l^oooo001Woooo00<0003oooooool0N?ooo`D0I_l:oooo00<0I_ooooooool0;?oo
o`00Ioooo`030000oooooooo077oool706Ko3oooo`0306Kooooooooo02coool006Ooool00`000?oo
ooooo`1Yoooo201VoaKoool00`1Vooooooooo`0/oooo001Woooo00<0003oooooool0I?ooo`D0I_lN
oooo00<0I_ooooooool0;?ooo`00Ioooo`80001Poooo1@1Vob?oool00`1Vooooooooo`0/oooo001W
oooo00<0003oooooool0FOooo`H0I_lXoooo00<0I_ooooooool0;?ooo`00Ioooo`030000oooooooo
05;oool706Ko;_ooo`0306Kooooooooo02coool001KooolC06Ko?_ooo`030000oooooooo04_oool7
06Ko=Oooo`0306Kooooooooo02coool002WooolA06Ko;Oooo`030000oooooooo04Goool606Ko??oo
o`0306Kooooooooo02coool003[oool:06Ko8oooo`030000oooooooo03koool706Ko@_ooo`0306Ko
oooooooo02coool004Coool:06Ko6Oooo`80000foooo2@1VodWoool00`1Vooooooooo`0/oooo000G
oooo1@0001koool200001?ooo`800004oooo0P0000Koool:06Ko3oooo`030000oooooooo01koool2
00001?ooo`800004oooo0P0000T0I_lFoooo1@0001goool500000_ooo`800004oooo0P0000_oool0
0`1Vooooooooo`0Boooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool0000?oooo201Vo`Ooool00`000?ooooooo`0Moooo00@0003oooooool00008
06Ko00@0003oooooool0000Poooo00<0003oooooool07oooo`030000oooooooo00Ooool010000?oo
ooooo`0000[oool00`1Vooooooooo`0Boooo00<0003oooooool05oooo`006Oooo`030000oooooooo
01goool010000?ooooooo`0000_oool00`000?ooooooo`0Eoooo1`1Vo`04000006Ko06Ko06Ko3ooo
o`d0I_l01000001Vo`1Vo`0000_oool00`000?ooooooo`0Noooo00<0003oooooool07oooo`030000
oooooooo00[oool00`000?ooooooo`08oooo00<0I_ooooooool04oooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Oooo`80000O
oooo00@0003oooooooooool?06Ko3Oooo`040000oooooooo00002Oooo`80000Qoooo00<0003ooooo
ool07oooo`030000oooooooo00Soool200002oooo`0306Kooooooooo01Coool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool0
0`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo
01ooool00`000?ooooooo`08oooo00<0003oooooool02_ooo`0306Kooooooooo01;oool010000?oo
ooooo`0001Koool001Soool200008?ooo`80000:oooo0`0001koool200007oooo`80000:oooo0`00
01ooool200008?ooo`80000:oooo0`0000[oool00`1Vooooooooo`0Coooo0P0001Ooool006Ooool0
0`000?ooooooo`27oooo00<0I_ooooooool0;?ooo`00Ioooo`030000oooooooo08Ooool00`1Voooo
ooooo`0/oooo001Woooo00<0003oooooool0Qoooo`0306Kooooooooo02coool006Ooool00`000?oo
ooooo`27oooo00<0I_ooooooool0;?ooo`00Ioooo`030000oooooooo08Ooool00`1Vooooooooo`0/
oooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0004<ol0:00000;oool00`000?l0VOooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Oooo`030000oooooooo
02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o0100000Ioooo00<0003oooooool03ooo
o`03o`2Ioooooooo01Coool00`000?ooooooo`0Eoooo001Woooo00<0000co`0co`00Ac?o00D0000k
oooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol0048co`050000@?ooo`03o`2Ioooooooo
02coool006Ooool00`0003?o03?o000m<ol01@0004Goool00ol0VOooooooo`0/oooo001Woooo00<0
000co`0co`00>C?o00@0001:oooo00?o09Woooooool0;?ooo`00Ioooo`80000h<ol00P0004koool0
0ol0VOooooooo`0/oooo001Woooo00<0000co`0co`00=C?o0080001@oooo00?o09Woooooool0;?oo
o`00Ioooo`030000<ol0<ol003<co`020000D_ooo`03o`2Ioooooooo02coool006Ooool00`0003?o
03?o000a<ol00P0005Coool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`00<3?o00030000
oooooooo05Coool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`00;S?o0080001Goooo00?o
09Woooooool0;?ooo`00Ioooo`80000]<ol00P0005Woool00ol0VOooooooo`0/oooo001Woooo00<0
000co`0co`00:c?o00030000oooooooo05Woool00ol0VOooooooo`0/oooo001Woooo00<0000co`0c
o`00:S?o00030000oooooooo05[oool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`00:C?o
00030000oooooooo05_oool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`00:3?o00030000
oooooooo05coool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`00:3?o00030000oooooooo
05coool00ol0VOooooooo`0/oooo001Woooo0P0002Pco`000`000?ooooooo`1Moooo00?o09Wooooo
ool0;?ooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`1Noooo00?o09Woooooool0;?oo
o`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Iooo
o`030000<ol0<ol002@co`000`000?ooooooo`1Poooo00?o09Woooooool0;?ooo`00Ioooo`030000
<ol0<ol002<co`000`000?ooooooo`1Qoooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol0
02<co`000`000?ooooooo`1Qoooo00?o09Woooooool0;?ooo`00Ioooo`80000S<ol000<0003ooooo
ool0H_ooo`03o`2Ioooooooo02coool006Ooool00`0003?o03?o000Q<ol000<0003oooooool0Hooo
o`03o`2Ioooooooo02coool006Ooool00`0003?o03?o000P<ol000<0003oooooool0I?ooo`03o`2I
oooooooo02coool006Ooool00`0003?o03?o000P<ol000<0003oooooool0I?ooo`03o`2Ioooooooo
02coool006Ooool00`0003?o03?o000O<ol000<0003oooooool0IOooo`03o`2Ioooooooo02coool0
05ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`1Uoooo00?o09Woooooool0;?oo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003oooooool0I_ooo`03o`2I
oooooooo02coool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?ooooooo`1Voooo00?o
09Woooooool0;?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003ooooo
ool0Ioooo`03o`2Ioooooooo02coool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o
00030000oooooooo06Ooool00ol0VOooooooo`0/oooo001Poooo0P0000Goool00`0003?o03?o000L
<ol000<0003oooooool0J?ooo`03o`2Ioooooooo02coool006Ooool00`0003?o03?o000L<ol000<0
003oooooool0J?ooo`03o`2Ioooooooo02coool006Ooool00`0003?o03?o000K<ol000<0003ooooo
ool0JOooo`03o`2Ioooooooo02coool006Ooool2000073?o00030000oooooooo06Woool00ol0VOoo
ooooo`0/oooo001Woooo00<0000co`0co`006S?o00030000oooooooo06[oool00ol0VOooooooo`0/
oooo001Woooo00<0000co`0co`006S?o00030000oooooooo06[oool00ol0VOooooooo`0/oooo001W
oooo00<0000co`0co`006C?o00030000oooooooo06_oool00ol0VOooooooo`0/oooo001Woooo00<0
000co`0co`006C?o00030000oooooooo06_oool00ol0VOooooooo`0/oooo001Woooo00<0000co`0c
o`0063?o00030000oooooooo06coool00ol0VOooooooo`0/oooo001Woooo0P0001Tco`000`000?oo
ooooo`1/oooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1]
oooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol001Lco`000`000?ooooooo`1]oooo00?o
09Woooooool0;?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1^oooo00?o09Wooooo
ool0;?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1^oooo00?o09Woooooool0;?oo
o`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1^oooo00?o09Woooooool0;?ooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`1_oooo00?o09Woooooool0;?ooo`00Ioooo`80000F
<ol000<0003oooooool0Koooo`03o`2Ioooooooo02coool006Ooool00`0003?o03?o000E<ol000<0
003oooooool0Koooo`03o`2Ioooooooo02coool006Ooool00`0003?o03?o000E<ol000<0003ooooo
ool0Koooo`03o`2Ioooooooo02coool006Ooool00`0003?o03?o000D<ol000<0003oooooool0L?oo
o`03o`2Ioooooooo02coool006Ooool00`0003?o03?o000D<ol000<0003oooooool0L?ooo`03o`2I
oooooooo02coool006Ooool00`0003?o03?o000D<ol000<0003oooooool0L?ooo`03o`2Ioooooooo
02coool006Ooool200005C?o00030000oooooooo073oool00ol0VOooooooo`0/oooo001Woooo00<0
000co`0co`004c?o00030000oooooooo077oool00ol0VOooooooo`0/oooo001Woooo00<0000co`0c
o`004c?o00030000oooooooo077oool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`004c?o
00030000oooooooo077oool00ol0VOooooooo`0/oooo001Ooooo100000Coool00`0003?o03?o000C
<ol000<0003oooooool0LOooo`03o`2Ioooooooo02coool005ooool00`000?ooooooo`05oooo00<0
000co`0co`004S?o00030000oooooooo07;oool00ol0VOooooooo`0/oooo001Poooo00<0003ooooo
ool01?ooo`80000C<ol000<0003oooooool0L_ooo`03o`2Ioooooooo02coool0067oool00`000?oo
ooooo`03oooo00<0000co`0co`004S?o00030000oooooooo07;oool00ol0VOooooooo`0/oooo001O
oooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo07?oool00ol0VOoo
ooooo`0/oooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003oooooool0Loooo`03o`2I
oooooooo02coool006Ooool00`0003?o03?o000A<ol000<0003oooooool0Loooo`03o`2Ioooooooo
02coool006Ooool00`0003?o03?o000A<ol000<0003oooooool0Loooo`03o`2Ioooooooo02coool0
06Ooool200004C?o00030000oooooooo07Coool00ol0VOooooooo`0/oooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo07Coool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`0043?o
00030000oooooooo07Coool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`0043?o00030000
oooooooo07Coool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`003c?o00030000oooooooo
07Goool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`003c?o00030000oooooooo07Goool0
0ol0VOooooooo`0/oooo001Woooo00<0000co`0co`003c?o00030000oooooooo07Goool00ol0VOoo
ooooo`0/oooo001Woooo0P00010co`000`000?ooooooo`1eoooo00?o09Woooooool0;?ooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`1foooo00?o09Woooooool0;?ooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`1foooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol0
00hco`000`000?ooooooo`1foooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol000hco`00
0`000?ooooooo`1foooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`1goooo00?o09Woooooool0;?ooo`00Ioooo`80000><ol000<0003oooooool0Moooo`03o`2I
oooooooo02coool006Ooool00`0003?o03?o000=<ol000<0003oooooool0Moooo`03o`2Ioooooooo
02coool006Ooool00`0003?o03?o000=<ol000<0003oooooool0Moooo`03o`2Ioooooooo02coool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0N?ooo`03o`2Ioooooooo02coool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0N?ooo`03o`2Ioooooooo02coool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0N?ooo`03o`2Ioooooooo02coool006Ooool200003C?o00030000
oooooooo07Soool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`0033?o00030000oooooooo
07Soool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`0033?o00030000oooooooo07Soool0
0ol0VOooooooo`0/oooo001Woooo00<0000co`0co`002c?o00030000oooooooo07Woool00ol0VOoo
ooooo`0/oooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003oooooool0NOooo`03o`2I
oooooooo02coool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;<ol000<0003ooooo
ool0NOooo`03o`2Ioooooooo02coool0067oool00`000?ooooooo`03oooo0P0000`co`000`000?oo
ooooo`1ioooo00?o09Woooooool0;?ooo`00H_ooo`030000oooooooo00;oool00`0003?o03?o000;
<ol000<0003oooooool0NOooo`03o`2Ioooooooo02coool005ooool010000?ooooooo`0000Coool0
0`0003?o03?o000;<ol000<0003oooooool0NOooo`03o`2Ioooooooo02coool0063oool200001Ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`1joooo00?o09Woooooool0;?ooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`1joooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`1joooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`1joooo00?o09Woooooool0;?ooo`00Ioooo`80000;<ol000<0003oooooool0N_oo
o`03o`2Ioooooooo02coool006Ooool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`03o`2I
oooooooo02coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Noooo`03o`2Ioooooooo
02coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Noooo`03o`2Ioooooooo02coool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0Noooo`03o`2Ioooooooo02coool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0Noooo`03o`2Ioooooooo02coool006Ooool200002S?o
00030000oooooooo07_oool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`002C?o00030000
oooooooo07_oool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`002C?o00030000oooooooo
07_oool00ol0VOooooooo`0/oooo001Woooo00<0000co`0co`0023?o00030000oooooooo07coool0
0ol0VOooooooo`0/oooo001Woooo00<0000co`0co`0023?o00030000oooooooo07coool00ol0VOoo
ooooo`0/oooo001Woooo00<0000co`0co`0023?o00030000oooooooo07coool00ol0VOooooooo`0/
oooo001Woooo0P0000Tco`000`000?ooooooo`1loooo00?o09Woooooool0;?ooo`00Ioooo`030000
<ol0<ol000Pco`000`000?ooooooo`1loooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1loooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1moooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1moooo00?o09Woooooool0;?ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`1m
oooo00?o09Woooooool0;?ooo`00Ioooo`800008<ol000<0003oooooool0OOooo`03o`2Ioooooooo
02coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0OOooo`03o`2Ioooooooo02coool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0OOooo`03o`2Ioooooooo02coool006Ooool0
0`0003?o03?o0007<ol000<0003oooooool0OOooo`03o`2Ioooooooo02coool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0OOooo`03o`2Ioooooooo02coool0067oool300000oooo`030000
<ol0<ol000Lco`000`000?ooooooo`1moooo00?o09Woooooool0;?ooo`00H_ooo`030000oooooooo
00;oool00`0003?o03?o0007<ol000<0003oooooool0OOooo`03o`2Ioooooooo02coool005ooool5
00000oooo`800008<ol000<0003oooooool0OOooo`03o`2Ioooooooo02coool005ooool010000?oo
ooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[oooo`00HOooo`800004
oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o00Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo1@0000;oool200001Oooo`040000oooooooooooo100000?oool0
0`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`000?ooooooo`09oooo00D0003oooooooooool000001_oo
o`030000oooooooo07Soool006Ooool9<ol01oooo`030000oooooooo00;oool00`000?ooooooo`0?
oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003ooooo
ool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@0000koool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool0
1@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000oooooooo00000_ooo`040000
oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo017oool2
00002Oooo`@00003oooo0P0000?oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8
<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.85916 .12361 L
.87791 .12361 L
.88735 .12361 L
.88993 .12361 L
.89136 .12361 L
.89206 .12361 L
.89271 .12361 L
s
.89271 .12361 m
.89321 .61803 L
s
0 .4 1 r
.02381 .06193 m
.02846 .06202 L
.03279 .06213 L
.04262 .06243 L
.06244 .06329 L
.0828 .06447 L
.10458 .06599 L
.14603 .0694 L
.18596 .07309 L
.22437 .07681 L
.26524 .08077 L
.30459 .0845 L
.32434 .08631 L
.34242 .08793 L
.34718 .08831 L
.35237 .08865 L
.35733 .08891 L
.36183 .0891 L
.36707 .08928 L
.36995 .08935 L
.37266 .08941 L
.37517 .08945 L
.37749 .08948 L
.3787 .08949 L
.38003 .0895 L
.3807 .0895 L
.38141 .0895 L
.38271 .08951 L
.38393 .08951 L
.38462 .08951 L
.38527 .08951 L
.38658 .08951 L
.38732 .0895 L
.38799 .0895 L
.38913 .08949 L
.39038 .08949 L
.39288 .08946 L
.39565 .08942 L
.39862 .08937 L
.40395 .08926 L
.41449 .08894 L
.42407 .08856 L
.44326 .08757 L
.46405 .08619 L
.50497 .08275 L
.54437 .07871 L
.58226 .07427 L
.6226 .06903 L
.66143 .06358 L
.7027 .05743 L
Mistroke
.74246 .05127 L
.78071 .04525 L
.82141 .03898 L
.86059 .03336 L
.8709 .03199 L
.88204 .03059 L
.88716 .02997 L
.88995 .02964 L
.89132 .02948 L
.89256 .02934 L
.8937 .12361 L
.89478 .12361 L
.89717 .12361 L
.90222 .12361 L
.9406 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo0;Koool006Ooool00`000?ooooooo`22oooo201Vobcoool0
06Ooool00`000?ooooooo`1loooo1P1Vo`Ooool00`1Vooooooooo`0Zoooo001Woooo00<0003ooooo
ool0M?ooo`P0I_l=oooo00<0I_ooooooool0:_ooo`00Ioooo`030000oooooooo06ooool506Ko5Ooo
o`0306Kooooooooo02[oool006Ooool00`000?ooooooo`1Xoooo1`1Voa[oool00`1Vooooooooo`0Z
oooo001Woooo0P00067oool806Ko8Oooo`0306Kooooooooo02[oool006Ooool00`000?ooooooo`1K
oooo1@1VobWoool00`1Vooooooooo`0Zoooo001Woooo00<0003oooooool0E?ooo`L0I_l^oooo00<0
I_ooooooool0:_ooo`005_oooa80I_looooo00<0003oooooool0C?ooo`P0I_leoooo00<0I_oooooo
ool0:_ooo`00:?ooo`P0I_lgoooo00<0003oooooool0Aoooo`D0I_lmoooo00<0I_ooooooool0:_oo
o`00<?ooo`X0I_l]oooo00<0003oooooool0@?ooo`L0I_m2oooo00<0I_ooooooool0:_ooo`00>_oo
o`X0I_lSoooo0P0003Ooool:06KoBOooo`0306Kooooooooo02[oool001Ooool500007_ooo`800004
oooo0P0000;oool206Ko0P0000H0I_lIoooo00<0003oooooool07_ooo`800004oooo0P0000Coool2
00002P1VoaGoool500007Oooo`D00002oooo0P0000Coool200003Oooo`0306Kooooooooo013oool4
00005_ooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Soool010000?ooooooo`00
00GooolB06Ko1oooo`030000oooooooo01goool01@000?ooooooo`000?ooo`0706Ko00@00000I_l0
I_l0000Poooo00<0003oooooool07oooo`030000oooooooo00Ooool010000?ooooooo`0000coool0
0`1Vooooooooo`0@oooo00<0003oooooool05oooo`006Oooo`030000oooooooo01goool010000?oo
ooooo`0000_oool00`000?ooooooo`0Eoooo1`1Vo`03000006Kooooo01Goool806Ko00D00000I_l0
I_l00000I_l02_ooo`030000oooooooo01koool00`000?ooooooo`0Ooooo00<0003oooooool02_oo
o`030000oooooooo00[oool00`1Vooooooooo`0Aoooo00<0003oooooool05_ooo`004Oooo`@00004
oooo00<0003oooooool05oooo`@00002oooo00@0003oooooool00009oooo0P0001ooool00`000?oo
o`1Vo`0E06Ko2?ooo`040000oooooooo00002Oooo`80000Qoooo00<0003oooooool07oooo`030000
oooooooo00Soool200003Oooo`0306Kooooooooo01;oool00`000?ooooooo`0Eoooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo01koool00`000?ooooooo`0M
oooo00@0003oooooool00009oooo00<0003oooooool08?ooo`030000oooooooo01ooool00`000?oo
ooooo`08oooo00<0003oooooool03?ooo`0306Kooooooooo013oool010000?ooooooo`0001Koool0
01Soool200008?ooo`80000:oooo0`0001koool200007oooo`80000:oooo0`0001ooool200008?oo
o`80000:oooo0`0000coool00`1Vooooooooo`0Aoooo0P0001Ooool006Ooool00`000?ooooooo`29
oooo00<0I_ooooooool0:_ooo`00Ioooo`030000oooooooo08Woool00`1Vooooooooo`0Zoooo001W
oooo00<0003oooooool0ROooo`0306Kooooooooo02[oool006Ooool00`000?ooooooo`29oooo00<0
I_ooooooool0:_ooo`00Ioooo`030000oooooooo08Woool00`1Vooooooooo`0Zoooo000@ooooo`00
017oool001Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0004
<ol0:00000;oool010000?ooooooool0V@Coool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000
<ol0<ol002Dco`000`0003?o03?o000T<ol0400001Woool00`000?ooooooo`0Aoooo00?o09Wooooo
ool04_ooo`030000oooooooo01Goool006Ooool00`0003?o03?o0017<ol01@0003goool00ol0VOoo
ooooo`0Zoooo001Woooo00<0000co`0co`00@S?o00D00012oooo00?o09Woooooool0:_ooo`00Iooo
o`030000<ol0<ol003dco`050000Aoooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000i
<ol0100004coool00ol0VOooooooo`0Zoooo001Woooo0P0003Pco`020000D?ooo`03o`2Ioooooooo
02[oool006Ooool00`0003?o03?o000e<ol00P0005;oool00ol0VOooooooo`0Zoooo001Woooo00<0
000co`0co`00<c?o0080001Doooo00?o09Woooooool0:_ooo`00Ioooo`030000<ol0<ol0034co`02
0000E_ooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000`<ol000<0003oooooool0E_oo
o`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000^<ol00P0005Woool00ol0VOooooooo`0Z
oooo001Woooo0P0002dco`020000Foooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000[
<ol000<0003oooooool0Foooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000Z<ol000<0
003oooooool0G?ooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000Y<ol000<0003ooooo
ool0GOooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000X<ol000<0003oooooool0G_oo
o`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000X<ol000<0003oooooool0G_ooo`03o`2I
oooooooo02[oool006Ooool20000:3?o00030000oooooooo05ooool00ol0VOooooooo`0Zoooo001W
oooo00<0000co`0co`009S?o00030000oooooooo063oool00ol0VOooooooo`0Zoooo001Woooo00<0
000co`0co`009C?o00030000oooooooo067oool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0c
o`0093?o00030000oooooooo06;oool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`008c?o
00030000oooooooo06?oool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`008c?o00030000
oooooooo06?oool00ol0VOooooooo`0Zoooo001Woooo0P0002<co`000`000?ooooooo`1Toooo00?o
09Woooooool0:_ooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`1Uoooo00?o09Wooooo
ool0:_ooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`1Voooo00?o09Woooooool0:_oo
o`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`1Voooo00?o09Woooooool0:_ooo`00Iooo
o`030000<ol0<ol001lco`000`000?ooooooo`1Woooo00?o09Woooooool0:_ooo`00Goooo`D00003
oooo00<0000co`0co`007c?o00030000oooooooo06Ooool00ol0VOooooooo`0Zoooo001Qoooo00<0
003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`1Xoooo00?o09Woooooool0:_oo
o`00HOooo`030000oooooooo00?oool200007c?o00030000oooooooo06Soool00ol0VOooooooo`0Z
oooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`1Yoooo00?o
09Woooooool0:_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003ooooo
ool0JOooo`03o`2Ioooooooo02[oool0063oool200001Oooo`030000<ol0<ol001`co`000`000?oo
ooooo`1Zoooo00?o09Woooooool0:_ooo`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`1Z
oooo00?o09Woooooool0:_ooo`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`1[oooo00?o
09Woooooool0:_ooo`00Ioooo`80000L<ol000<0003oooooool0Joooo`03o`2Ioooooooo02[oool0
06Ooool00`0003?o03?o000J<ol000<0003oooooool0K?ooo`03o`2Ioooooooo02[oool006Ooool0
0`0003?o03?o000J<ol000<0003oooooool0K?ooo`03o`2Ioooooooo02[oool006Ooool00`0003?o
03?o000I<ol000<0003oooooool0KOooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000I
<ol000<0003oooooool0KOooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000H<ol000<0
003oooooool0K_ooo`03o`2Ioooooooo02[oool006Ooool200006C?o00030000oooooooo06koool0
0ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`005c?o00030000oooooooo06ooool00ol0VOoo
ooooo`0Zoooo001Woooo00<0000co`0co`005c?o00030000oooooooo06ooool00ol0VOooooooo`0Z
oooo001Woooo00<0000co`0co`005S?o00030000oooooooo073oool00ol0VOooooooo`0Zoooo001W
oooo00<0000co`0co`005S?o00030000oooooooo073oool00ol0VOooooooo`0Zoooo001Woooo00<0
000co`0co`005S?o00030000oooooooo073oool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0c
o`005C?o00030000oooooooo077oool00ol0VOooooooo`0Zoooo001Woooo0P0001Hco`000`000?oo
ooooo`1aoooo00?o09Woooooool0:_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1a
oooo00?o09Woooooool0:_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1aoooo00?o
09Woooooool0:_ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1boooo00?o09Wooooo
ool0:_ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1boooo00?o09Woooooool0:_oo
o`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1boooo00?o09Woooooool0:_ooo`00Iooo
o`80000E<ol000<0003oooooool0L_ooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000C
<ol000<0003oooooool0Loooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000C<ol000<0
003oooooool0Loooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000C<ol000<0003ooooo
ool0Loooo`03o`2Ioooooooo02[oool005ooool400001?ooo`030000<ol0<ol001<co`000`000?oo
ooooo`1coooo00?o09Woooooool0:_ooo`00Goooo`030000oooooooo00Goool00`0003?o03?o000B
<ol000<0003oooooool0M?ooo`03o`2Ioooooooo02[oool0063oool00`000?ooooooo`04oooo0P00
01<co`000`000?ooooooo`1doooo00?o09Woooooool0:_ooo`00HOooo`030000oooooooo00?oool0
0`0003?o03?o000B<ol000<0003oooooool0M?ooo`03o`2Ioooooooo02[oool005ooool010000?oo
ooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool0MOooo`03o`2Ioooooooo02[oool0
063oool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`1eoooo00?o09Woooooool0:_oo
o`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1eoooo00?o09Woooooool0:_ooo`00Iooo
o`030000<ol0<ol0014co`000`000?ooooooo`1eoooo00?o09Woooooool0:_ooo`00Ioooo`80000A
<ol000<0003oooooool0M_ooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000@<ol000<0
003oooooool0M_ooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000@<ol000<0003ooooo
ool0M_ooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0M_oo
o`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000?<ol000<0003oooooool0Moooo`03o`2I
oooooooo02[oool006Ooool00`0003?o03?o000?<ol000<0003oooooool0Moooo`03o`2Ioooooooo
02[oool006Ooool00`0003?o03?o000?<ol000<0003oooooool0Moooo`03o`2Ioooooooo02[oool0
06Ooool2000043?o00030000oooooooo07Ooool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0c
o`003S?o00030000oooooooo07Soool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`003S?o
00030000oooooooo07Soool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`003S?o00030000
oooooooo07Soool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`003S?o00030000oooooooo
07Soool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`003C?o00030000oooooooo07Woool0
0ol0VOooooooo`0Zoooo001Woooo0P0000hco`000`000?ooooooo`1ioooo00?o09Woooooool0:_oo
o`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1ioooo00?o09Woooooool0:_ooo`00Iooo
o`030000<ol0<ol000dco`000`000?ooooooo`1ioooo00?o09Woooooool0:_ooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`1joooo00?o09Woooooool0:_ooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`1joooo00?o09Woooooool0:_ooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`1joooo00?o09Woooooool0:_ooo`00Ioooo`80000=<ol000<0003oooooool0N_oo
o`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0N_ooo`03o`2I
oooooooo02[oool006Ooool00`0003?o03?o000<<ol000<0003oooooool0N_ooo`03o`2Ioooooooo
02[oool006Ooool00`0003?o03?o000;<ol000<0003oooooool0Noooo`03o`2Ioooooooo02[oool0
063oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`1koooo00?o09Woooooool0:_oo
o`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1koooo00?o
09Woooooool0:_ooo`00HOooo`030000oooooooo00?oool2000033?o00030000oooooooo07_oool0
0ol0VOooooooo`0Zoooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`000`000?oo
ooooo`1koooo00?o09Woooooool0:_ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0
00/co`000`000?ooooooo`1koooo00?o09Woooooool0:_ooo`00H?ooo`800005oooo00<0000co`0c
o`002S?o00030000oooooooo07coool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`002S?o
00030000oooooooo07coool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`002S?o00030000
oooooooo07coool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`002S?o00030000oooooooo
07coool00ol0VOooooooo`0Zoooo001Woooo0P0000/co`000`000?ooooooo`1loooo00?o09Wooooo
ool0:_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1loooo00?o09Woooooool0:_oo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`1moooo00?o09Woooooool0:_ooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1moooo00?o09Woooooool0:_ooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`1moooo00?o09Woooooool0:_ooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1moooo00?o09Woooooool0:_ooo`00Ioooo`80000:<ol000<0003ooooo
ool0OOooo`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0OOoo
o`03o`2Ioooooooo02[oool006Ooool00`0003?o03?o0009<ol000<0003oooooool0OOooo`03o`2I
oooooooo02[oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0O_ooo`03o`2Ioooooooo
02[oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0O_ooo`03o`2Ioooooooo02[oool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool0O_ooo`03o`2Ioooooooo02[oool006Ooool2
00002C?o00030000oooooooo07koool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`0023?o
00030000oooooooo07koool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`0023?o00030000
oooooooo07koool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`001c?o00030000oooooooo
07ooool00ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`001c?o00030000oooooooo07ooool0
0ol0VOooooooo`0Zoooo001Woooo00<0000co`0co`001c?o00030000oooooooo07ooool00ol0VOoo
ooooo`0Zoooo001Woooo0P0000Pco`000`000?ooooooo`1ooooo00?o09Woooooool0:_ooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1ooooo00?o09Woooooool0:_ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`1ooooo00?o09Woooooool0:_ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1ooooo00?o09Woooooool0:_ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1ooooo00?o09Woooooool0:_ooo`00HOooo`<00003oooo00<0000co`0co`001c?o
00030000oooooooo07ooool00ol0VOooooooo`0Zoooo001Roooo00<0003oooooool00_ooo`030000
<ol0<ol000Lco`000`000?ooooooo`1ooooo00?o09Woooooool0:_ooo`00Goooo`D00003oooo0P00
00Pco`000`000?ooooooo`1ooooo00?o09Woooooool0:_ooo`00Goooo`040000oooooooo00001?oo
o`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[ooo
o`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Koool500000_ooo`800005oooo00<0003oooooool00oooo`<00002oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`07oooo00<0003oooooool02Oooo`030000oooooooo00Coool01@000?oooooooooo
o`00001joooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000
oooooooo00Woool010000?ooooooooooo`D00003oooo00<0003oooooool0Moooo`00Ioooo`Tco`08
oooo00<0003oooooool01@0000koool00`000?ooooooo`0:oooo00@0003oooooool00002oooo00D0
003oooooooooool00000N_ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000004Oooo`030000
oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooo`000003oooo00<0003oooooool0N?oo
o`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`800009oooo100000Coool200000_ooo`030000
oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.87754 .12361 L
.88797 .12361 L
.89307 .12361 L
.89548 .12361 L
.89771 .12361 L
.89886 .12361 L
s
.89886 .12361 m
.89935 .61803 L
s
0 .4 1 r
.02381 .06206 m
.03279 .06231 L
.04262 .06267 L
.06244 .06363 L
.10458 .06647 L
.14509 .06989 L
.18408 .07352 L
.22553 .07754 L
.26546 .0814 L
.30387 .08502 L
.32332 .08679 L
.33364 .08772 L
.34474 .08868 L
.35018 .08907 L
.35535 .08936 L
.36038 .0896 L
.36505 .08977 L
.36946 .08989 L
.37172 .08994 L
.37415 .08998 L
.37555 .09 L
.37684 .09002 L
.37804 .09003 L
.37936 .09004 L
.38055 .09005 L
.38166 .09006 L
.38283 .09006 L
.38409 .09006 L
.38531 .09006 L
.386 .09006 L
.38665 .09006 L
.38796 .09006 L
.3887 .09005 L
.38937 .09005 L
.39175 .09003 L
.39426 .09 L
.397 .08996 L
.39955 .08992 L
.40533 .08979 L
.41506 .0895 L
.42545 .08909 L
.4468 .08796 L
.46695 .08661 L
.50541 .08339 L
.54633 .07924 L
.58574 .07464 L
.62362 .06976 L
.66396 .06414 L
.70279 .05838 L
.74406 .05201 L
Mistroke
.78382 .04576 L
.82207 .03984 L
.84343 .03666 L
.86277 .03392 L
.87247 .03261 L
.88295 .03126 L
.88777 .03066 L
.89285 .03004 L
.89719 .02953 L
.89838 .0294 L
.89965 .02925 L
.90085 .12361 L
.90195 .12361 L
.94185 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo08[oool00`1Vooooooooo`0Yoooo001Woooo00<0003ooooo
ool0Poooo`P0I_l[oooo001Woooo00<0003oooooool0N_ooo`T0I_l7oooo00<0I_ooooooool0:Ooo
o`00Ioooo`030000oooooooo07Goool506Ko4?ooo`0306Kooooooooo02Woool006Ooool00`000?oo
ooooo`1`oooo1@1VoaGoool00`1Vooooooooo`0Yoooo001Woooo00<0003oooooool0JOooo`L0I_lJ
oooo00<0I_ooooooool0:Oooo`00Ioooo`80001Roooo201Vob7oool00`1Vooooooooo`0Yoooo001W
oooo00<0003oooooool0Foooo`H0I_lYoooo00<0I_ooooooool0:Oooo`00Ioooo`030000oooooooo
05Coool706Ko;oooo`0306Kooooooooo02Woool001Koool@06Ko@Oooo`030000oooooooo04goool7
06Ko=_ooo`0306Kooooooooo02Woool002Koool:06Ko=oooo`030000oooooooo04Ooool606Ko?Ooo
o`0306Kooooooooo02Woool0033oool:06Ko;Oooo`030000oooooooo043oool706Ko@oooo`0306Ko
oooooooo02Woool003[oool:06Ko8oooo`80000hoooo2@1Vod[oool00`1Vooooooooo`0Yoooo000G
oooo1@0001koool200001?ooo`800002oooo0P1Vo`80000706Ko6?ooo`030000oooooooo01koool2
00001?ooo`800004oooo0P0000/0I_lDoooo1@0001goool500000_ooo`800004oooo0P0000ooool0
0`1Vooooooooo`0>oooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool00006oooo2P1Vo`koool00`000?ooooooo`0Moooo00D0003oooooool0003o
ool01`1Vo`04000006Ko06Ko00008?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000>oooo00<0I_ooooooool03_ooo`030000oooooooo01Ooool001Woool00`000?oo
ooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool03_ooo`h0I_l00`000?ooooooo`0E
oooo201Vo`05000006Ko06Ko000006Ko00[oool00`000?ooooooo`0Noooo00<0003oooooool07ooo
o`030000oooooooo00[oool00`000?ooooooo`0<oooo00<0I_ooooooool03oooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Ooo
o`80000Ooooo00<00000I_l0I_l05@1Vo`Soool010000?ooooooo`0000Woool200008Oooo`030000
oooooooo01ooool00`000?ooooooo`08oooo0P0000ooool00`1Vooooooooo`0@oooo00<0003ooooo
ool05Oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Woool00`000?ooooooo`0N
oooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo023oool00`000?oo
ooooo`0Ooooo00<0003oooooool02?ooo`030000oooooooo00koool00`1Vooooooooo`0>oooo00@0
003oooooool0000Foooo000Hoooo0P00023oool200002_ooo`<0000Noooo0P0001ooool200002_oo
o`<0000Ooooo0P00023oool200002_ooo`<0000>oooo00<0I_ooooooool03oooo`80000Goooo001W
oooo00<0003oooooool0Roooo`0306Kooooooooo02Soool006Ooool00`000?ooooooo`2;oooo00<0
I_ooooooool0:?ooo`00Ioooo`030000oooooooo08_oool00`1Vooooooooo`0Xoooo001Woooo00<0
003oooooool0Roooo`0306Kooooooooo02Soool006Ooool00`000?ooooooo`2;oooo00<0I_oooooo
ool0:?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`0013?o02P00002oooo00D0003ooooooooooooo09T00oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Voooo00<0000co`0co`009C?o00030000<ol0<ol002@co`0@00006Oooo`030000
oooooooo01;oool00ol0VOooooooo`0Aoooo00<0003oooooool05Oooo`00Ioooo`030000<ol0<ol0
04Lco`050000?_ooo`03o`2Ioooooooo02Woool006Ooool00`0003?o03?o0012<ol01@0004?oool0
0ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`00?C?o00D00018oooo00?o09Woooooool0:Ooo
o`00Ioooo`030000<ol0<ol003Tco`040000COooo`03o`2Ioooooooo02Woool006Ooool20000>3?o
0080001Aoooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol003Dco`020000Doooo`03o`2I
oooooooo02Woool006Ooool00`0003?o03?o000c<ol00P0005Goool00ol0VOooooooo`0Yoooo001W
oooo00<0000co`0co`00<C?o0080001Goooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol0
030co`000`000?ooooooo`1Goooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol002hco`02
0000F_ooo`03o`2Ioooooooo02Woool006Ooool20000;C?o0080001Loooo00?o09Woooooool0:Ooo
o`00Ioooo`030000<ol0<ol002/co`000`000?ooooooo`1Loooo00?o09Woooooool0:Oooo`00Iooo
o`030000<ol0<ol002Xco`000`000?ooooooo`1Moooo00?o09Woooooool0:Oooo`00Ioooo`030000
<ol0<ol002Tco`000`000?ooooooo`1Noooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol0
02Pco`000`000?ooooooo`1Ooooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol002Pco`00
0`000?ooooooo`1Ooooo00?o09Woooooool0:Oooo`00Ioooo`80000X<ol000<0003oooooool0H?oo
o`03o`2Ioooooooo02Woool006Ooool00`0003?o03?o000V<ol000<0003oooooool0HOooo`03o`2I
oooooooo02Woool006Ooool00`0003?o03?o000U<ol000<0003oooooool0H_ooo`03o`2Ioooooooo
02Woool006Ooool00`0003?o03?o000T<ol000<0003oooooool0Hoooo`03o`2Ioooooooo02Woool0
06Ooool00`0003?o03?o000S<ol000<0003oooooool0I?ooo`03o`2Ioooooooo02Woool006Ooool0
0`0003?o03?o000S<ol000<0003oooooool0I?ooo`03o`2Ioooooooo02Woool006Ooool200008c?o
00030000oooooooo06Goool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`008C?o00030000
oooooooo06Koool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`0083?o00030000oooooooo
06Ooool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`0083?o00030000oooooooo06Ooool0
0ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`007c?o00030000oooooooo06Soool00ol0VOoo
ooooo`0Yoooo001Ooooo1@0000?oool00`0003?o03?o000O<ol000<0003oooooool0J?ooo`03o`2I
oooooooo02Woool0067oool00`000?ooooooo`03oooo00<0000co`0co`007S?o00030000oooooooo
06Woool00ol0VOooooooo`0Yoooo001Qoooo00<0003oooooool00oooo`80000O<ol000<0003ooooo
ool0JOooo`03o`2Ioooooooo02Woool0067oool00`000?ooooooo`03oooo00<0000co`0co`007C?o
00030000oooooooo06[oool00ol0VOooooooo`0Yoooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001dco`000`000?ooooooo`1Zoooo00?o09Woooooool0:Oooo`00H?ooo`800005oooo00<0
000co`0co`0073?o00030000oooooooo06_oool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0c
o`0073?o00030000oooooooo06_oool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`006c?o
00030000oooooooo06coool00ol0VOooooooo`0Yoooo001Woooo0P0001`co`000`000?ooooooo`1/
oooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`1]oooo00?o
09Woooooool0:Oooo`00Ioooo`030000<ol0<ol001Xco`000`000?ooooooo`1]oooo00?o09Wooooo
ool0:Oooo`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`1^oooo00?o09Woooooool0:Ooo
o`00Ioooo`030000<ol0<ol001Tco`000`000?ooooooo`1^oooo00?o09Woooooool0:Oooo`00Iooo
o`030000<ol0<ol001Pco`000`000?ooooooo`1_oooo00?o09Woooooool0:Oooo`00Ioooo`80000I
<ol000<0003oooooool0Koooo`03o`2Ioooooooo02Woool006Ooool00`0003?o03?o000G<ol000<0
003oooooool0L?ooo`03o`2Ioooooooo02Woool006Ooool00`0003?o03?o000G<ol000<0003ooooo
ool0L?ooo`03o`2Ioooooooo02Woool006Ooool00`0003?o03?o000F<ol000<0003oooooool0LOoo
o`03o`2Ioooooooo02Woool006Ooool00`0003?o03?o000F<ol000<0003oooooool0LOooo`03o`2I
oooooooo02Woool006Ooool00`0003?o03?o000F<ol000<0003oooooool0LOooo`03o`2Ioooooooo
02Woool006Ooool00`0003?o03?o000E<ol000<0003oooooool0L_ooo`03o`2Ioooooooo02Woool0
06Ooool200005S?o00030000oooooooo07;oool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0c
o`005C?o00030000oooooooo07;oool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`005C?o
00030000oooooooo07;oool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`0053?o00030000
oooooooo07?oool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`0053?o00030000oooooooo
07?oool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`0053?o00030000oooooooo07?oool0
0ol0VOooooooo`0Yoooo001Woooo0P0001Dco`000`000?ooooooo`1coooo00?o09Woooooool0:Ooo
o`00Ioooo`030000<ol0<ol001<co`000`000?ooooooo`1doooo00?o09Woooooool0:Oooo`00Iooo
o`030000<ol0<ol001<co`000`000?ooooooo`1doooo00?o09Woooooool0:Oooo`00Ioooo`030000
<ol0<ol001<co`000`000?ooooooo`1doooo00?o09Woooooool0:Oooo`00Goooo`@00004oooo00<0
000co`0co`004c?o00030000oooooooo07Coool00ol0VOooooooo`0Yoooo001Ooooo00<0003ooooo
ool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`1eoooo00?o09Woooooool0:Oooo`00H?oo
o`030000oooooooo00Coool200004c?o00030000oooooooo07Goool00ol0VOooooooo`0Yoooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol0018co`000`000?ooooooo`1eoooo00?o09Wooooo
ool0:Oooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0014co`000`000?ooooooo`1f
oooo00?o09Woooooool0:Oooo`00H?ooo`800005oooo00<0000co`0co`004C?o00030000oooooooo
07Koool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`004C?o00030000oooooooo07Koool0
0ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`004C?o00030000oooooooo07Koool00ol0VOoo
ooooo`0Yoooo001Woooo0P00014co`000`000?ooooooo`1goooo00?o09Woooooool0:Oooo`00Iooo
o`030000<ol0<ol0010co`000`000?ooooooo`1goooo00?o09Woooooool0:Oooo`00Ioooo`030000
<ol0<ol0010co`000`000?ooooooo`1goooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol0
010co`000`000?ooooooo`1goooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol000lco`00
0`000?ooooooo`1hoooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol000lco`000`000?oo
ooooo`1hoooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol000lco`000`000?ooooooo`1h
oooo00?o09Woooooool0:Oooo`00Ioooo`80000@<ol000<0003oooooool0N?ooo`03o`2Ioooooooo
02Woool006Ooool00`0003?o03?o000><ol000<0003oooooool0NOooo`03o`2Ioooooooo02Woool0
06Ooool00`0003?o03?o000><ol000<0003oooooool0NOooo`03o`2Ioooooooo02Woool006Ooool0
0`0003?o03?o000><ol000<0003oooooool0NOooo`03o`2Ioooooooo02Woool006Ooool00`0003?o
03?o000><ol000<0003oooooool0NOooo`03o`2Ioooooooo02Woool006Ooool00`0003?o03?o000=
<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02Woool006Ooool200003S?o00030000oooooooo
07[oool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`003C?o00030000oooooooo07[oool0
0ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`003C?o00030000oooooooo07[oool00ol0VOoo
ooooo`0Yoooo001Woooo00<0000co`0co`0033?o00030000oooooooo07_oool00ol0VOooooooo`0Y
oooo001Woooo00<0000co`0co`0033?o00030000oooooooo07_oool00ol0VOooooooo`0Yoooo001W
oooo00<0000co`0co`0033?o00030000oooooooo07_oool00ol0VOooooooo`0Yoooo001Woooo0P00
00dco`000`000?ooooooo`1koooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol000`co`00
0`000?ooooooo`1koooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol000`co`000`000?oo
ooooo`1koooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol000/co`000`000?ooooooo`1l
oooo00?o09Woooooool0:Oooo`00H?ooo`800005oooo00<0000co`0co`002c?o00030000oooooooo
07coool00ol0VOooooooo`0Yoooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`002c?o
00030000oooooooo07coool00ol0VOooooooo`0Yoooo001Qoooo00<0003oooooool00oooo`80000<
<ol000<0003oooooool0O?ooo`03o`2Ioooooooo02Woool006;oool00`000?ooooooo`02oooo00<0
000co`0co`002c?o00030000oooooooo07coool00ol0VOooooooo`0Yoooo001Ooooo00@0003ooooo
ool00004oooo00<0000co`0co`002c?o00030000oooooooo07coool00ol0VOooooooo`0Yoooo001P
oooo0P0000Goool00`0003?o03?o000:<ol000<0003oooooool0OOooo`03o`2Ioooooooo02Woool0
06Ooool00`0003?o03?o000:<ol000<0003oooooool0OOooo`03o`2Ioooooooo02Woool006Ooool0
0`0003?o03?o000:<ol000<0003oooooool0OOooo`03o`2Ioooooooo02Woool006Ooool00`0003?o
03?o000:<ol000<0003oooooool0OOooo`03o`2Ioooooooo02Woool006Ooool200002c?o00030000
oooooooo07goool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`002S?o00030000oooooooo
07goool00ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`002C?o00030000oooooooo07koool0
0ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`002C?o00030000oooooooo07koool00ol0VOoo
ooooo`0Yoooo001Woooo00<0000co`0co`002C?o00030000oooooooo07koool00ol0VOooooooo`0Y
oooo001Woooo00<0000co`0co`002C?o00030000oooooooo07koool00ol0VOooooooo`0Yoooo001W
oooo0P0000Xco`000`000?ooooooo`1noooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1noooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`1noooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol000Pco`000`000?oo
ooooo`1ooooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1o
oooo00?o09Woooooool0:Oooo`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`1ooooo00?o
09Woooooool0:Oooo`00Ioooo`800009<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Woool0
06Ooool00`0003?o03?o0008<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Woool006Ooool0
0`0003?o03?o0008<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Woool006Ooool00`0003?o
03?o0007<ol000<0003oooooool0P?ooo`03o`2Ioooooooo02Woool006Ooool00`0003?o03?o0007
<ol000<0003oooooool0P?ooo`03o`2Ioooooooo02Woool006Ooool00`0003?o03?o0007<ol000<0
003oooooool0P?ooo`03o`2Ioooooooo02Woool006Ooool2000023?o00030000oooooooo083oool0
0ol0VOooooooo`0Yoooo001Woooo00<0000co`0co`001c?o00030000oooooooo083oool00ol0VOoo
ooooo`0Yoooo001Woooo00<0000co`0co`001c?o00030000oooooooo083oool00ol0VOooooooo`0Y
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo083oool00ol0VOooooooo`0Yoooo001W
oooo00<0000co`0co`001c?o00030000oooooooo083oool00ol0VOooooooo`0Yoooo001Qoooo0`00
00?oool00`0003?o03?o0007<ol000<0003oooooool0P?ooo`03o`2Ioooooooo02Woool006;oool0
0`000?ooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo083oool00ol0VOooooooo`0Y
oooo001Ooooo1@0000?oool2000023?o00030000oooooooo083oool00ol0VOooooooo`0Yoooo001O
oooo00@0003oooooool00004oooo2S?o0:ooool0063oool00`000?ooo`000004oooo2S?o0:ooool0
067oool200001?ooo`Xco`2_oooo001Woooo2C?o0;3oool006Ooool9<ol0/?ooo`00Ioooo`Tco`09
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006Ooool9<ol02?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Goool010000?oooooooooo
o`<00004oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02Oooo`050000oooooooo
oooo000000;oool01@000?ooooooooooo`00001joooo001Woooo2C?o00Ooool00`000?ooooooo`02
oooo00<0003oooooool03oooo`030000oooooooo00Woool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo07Ooool006Ooool9<ol02?ooo`030000oooooooo00D0000>
oooo00<0003oooooool02_ooo`030000oooooooo00<00004oooo00<0003oooooool0N?ooo`00Iooo
o`Tco`08oooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003ooooo
ool04Oooo`800009oooo100000?oool300000_ooo`030000oooooooo07Woool006Ooool9<ol0/?oo
o`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.87754 .12361 L
.88797 .12361 L
.89307 .12361 L
.89771 .12361 L
.90008 .12361 L
.90265 .12361 L
.90383 .12361 L
.90508 .12361 L
.90615 .12361 L
s
.90615 .12361 m
.90663 .61803 L
s
0 .4 1 r
.02381 .06223 m
.04262 .06295 L
.06244 .06399 L
.10458 .06697 L
.14264 .07024 L
.18314 .07404 L
.22214 .07782 L
.26358 .08183 L
.30351 .08557 L
.32179 .08723 L
.33219 .08815 L
.34193 .089 L
.35148 .0897 L
.35685 .08999 L
.36176 .0902 L
.36692 .09037 L
.36964 .09044 L
.37255 .0905 L
.37533 .09055 L
.37786 .09058 L
.37908 .09059 L
.3804 .0906 L
.38165 .09061 L
.38279 .09061 L
.38406 .09061 L
.38525 .09061 L
.38632 .09061 L
.38749 .09061 L
.38876 .0906 L
.39011 .09059 L
.39253 .09057 L
.39476 .09055 L
.39685 .09052 L
.40162 .09044 L
.40681 .09031 L
.41156 .09018 L
.42228 .08979 L
.44121 .08888 L
.46191 .08759 L
.50247 .08434 L
.54151 .08049 L
.58301 .07577 L
.62299 .0707 L
.66146 .06541 L
.70238 .0594 L
.74178 .05335 L
.77967 .0474 L
.82001 .04112 L
.85883 .03536 L
.87858 .03264 L
Mistroke
.88901 .03129 L
.89473 .03058 L
.90011 .02993 L
.90264 .02964 L
.90402 .02947 L
.90531 .02933 L
.90599 .02925 L
.90671 .12361 L
.90751 .12361 L
.90824 .12361 L
.91093 .12361 L
.92074 .12361 L
.93987 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo08coool00`1Vooooooooo`0Woooo001Woooo00<0003ooooo
ool0Poooo`X0I_lYoooo001Woooo00<0003oooooool0O?ooo`L0I_l9oooo00<0I_ooooooool09ooo
o`00Ioooo`030000oooooooo07Coool806Ko4?ooo`0306Kooooooooo02Ooool006Ooool00`000?oo
ooooo`1_oooo1@1VoaSoool00`1Vooooooooo`0Woooo001Woooo00<0003oooooool0J_ooo`D0I_lM
oooo00<0I_ooooooool09oooo`00Ioooo`80001Voooo1@1Vob;oool00`1Vooooooooo`0Woooo001W
oooo00<0003oooooool0G_ooo`L0I_lWoooo00<0I_ooooooool09oooo`00Ioooo`030000oooooooo
05Koool806Ko;_ooo`0306Kooooooooo02Ooool001Koool@06Ko@Oooo`030000oooooooo057oool5
06Ko=_ooo`0306Kooooooooo02Ooool002Koool:06Ko=oooo`030000oooooooo04[oool706Ko>ooo
o`0306Kooooooooo02Ooool0033oool:06Ko;Oooo`030000oooooooo043oool:06Ko@_ooo`0306Ko
oooooooo02Ooool003[oool:06Ko8oooo`80000foooo2`1Vodcoool00`1Vooooooooo`0Woooo000G
oooo1@0001koool200001?ooo`800002oooo0P1Vo`80000606Ko6Oooo`030000oooooooo01koool2
00001?ooo`800004oooo0P0000T0I_lFoooo1@0001goool500000_ooo`800004oooo0P00013oool0
0`1Vooooooooo`0=oooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool00005oooo2P1Vo`ooool00`000?ooooooo`0Moooo00@0003oooooool00008
06Ko00@00000I_ooool0000Poooo00<0003oooooool07oooo`030000oooooooo00Ooool010000?oo
ooooo`0000ooool00`1Vooooooooo`0=oooo00<0003oooooool05oooo`006Oooo`030000oooooooo
01goool010000?ooooooo`0000_oool00`000?ooooooo`0=oooo3P1Vo`03oooo0000oooo01[oool4
06Ko00@00000I_l0I_l0000;oooo00<0003oooooool07_ooo`030000oooooooo01ooool00`000?oo
ooooo`0:oooo00<0003oooooool03Oooo`0306Kooooooooo00koool00`000?ooooooo`0Foooo000A
oooo100000Coool00`000?ooooooo`0Goooo100000;oool010000?ooooooo`0000Woool200007_oo
o`0306Ko000006Ko01X0I_l4oooo00@0003oooooool00009oooo0P00027oool00`000?ooooooo`0O
oooo00<0003oooooool02?ooo`80000@oooo00<0I_ooooooool03oooo`030000oooooooo01Goool0
01Woool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool07_ooo`030000
oooooooo01goool010000?ooooooo`0000Woool00`000?ooooooo`0Poooo00<0003oooooool07ooo
o`030000oooooooo00Soool00`000?ooooooo`0?oooo00<0I_ooooooool03Oooo`040000oooooooo
00005_ooo`006?ooo`80000Poooo0P0000[oool300007_ooo`80000Ooooo0P0000[oool300007ooo
o`80000Poooo0P0000[oool300003oooo`0306Kooooooooo00koool200005oooo`00Ioooo`030000
oooooooo08coool00`1Vooooooooo`0Woooo001Woooo00<0003oooooool0S?ooo`0306Kooooooooo
02Ooool006Ooool00`000?ooooooo`2<oooo00<0I_ooooooool09oooo`00Ioooo`030000oooooooo
08coool00`1Vooooooooo`0Woooo001Woooo00<0003oooooool0S?ooo`0306Kooooooooo02Ooool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000@co`0X00000_ooo`030000oooooooo00?oool00ol0VOooo`000007oooo00<0003ooooo
ool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0Uoooo00<0003oooooool09_oo
o`030000<ol0<ol002Dco`000`0003?o03?o000T<ol0400001Woool00`000?ooooooo`0Doooo00?o
09Woooooool03oooo`030000oooooooo01Goool006Ooool00`0003?o03?o0017<ol01@00043oool0
0ol0VOooooooo`0Woooo001Woooo00<0000co`0co`00@S?o00D00015oooo00?o09Woooooool09ooo
o`00Ioooo`030000<ol0<ol003dco`050000B_ooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o
03?o000i<ol0100004ooool00ol0VOooooooo`0Woooo001Woooo0P0003Pco`020000Doooo`03o`2I
oooooooo02Ooool006Ooool00`0003?o03?o000e<ol00P0005Goool00ol0VOooooooo`0Woooo001W
oooo00<0000co`0co`00<c?o0080001Goooo00?o09Woooooool09oooo`00Ioooo`030000<ol0<ol0
034co`020000FOooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000`<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000^<ol00P0005coool00ol0VOoo
ooooo`0Woooo001Woooo0P0002dco`020000G_ooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o
03?o000[<ol000<0003oooooool0G_ooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000Z
<ol000<0003oooooool0Goooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000Y<ol000<0
003oooooool0H?ooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000X<ol000<0003ooooo
ool0HOooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000X<ol000<0003oooooool0HOoo
o`03o`2Ioooooooo02Ooool006Ooool20000:3?o00030000oooooooo06;oool00ol0VOooooooo`0W
oooo001Woooo00<0000co`0co`009S?o00030000oooooooo06?oool00ol0VOooooooo`0Woooo001W
oooo00<0000co`0co`009C?o00030000oooooooo06Coool00ol0VOooooooo`0Woooo001Woooo00<0
000co`0co`0093?o00030000oooooooo06Goool00ol0VOooooooo`0Woooo001Woooo00<0000co`0c
o`008c?o00030000oooooooo06Koool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`008c?o
00030000oooooooo06Koool00ol0VOooooooo`0Woooo001Woooo0P0002<co`000`000?ooooooo`1W
oooo00?o09Woooooool09oooo`00Ioooo`030000<ol0<ol0024co`000`000?ooooooo`1Xoooo00?o
09Woooooool09oooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`1Yoooo00?o09Wooooo
ool09oooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`1Yoooo00?o09Woooooool09ooo
o`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`1Zoooo00?o09Woooooool09oooo`00Gooo
o`D00003oooo00<0000co`0co`007c?o00030000oooooooo06[oool00ol0VOooooooo`0Woooo001Q
oooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?ooooooo`1[oooo00?o09Wooooo
ool09oooo`00HOooo`030000oooooooo00?oool200007c?o00030000oooooooo06_oool00ol0VOoo
ooooo`0Woooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`1/
oooo00?o09Woooooool09oooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0
003oooooool0K?ooo`03o`2Ioooooooo02Ooool0063oool200001Oooo`030000<ol0<ol001`co`00
0`000?ooooooo`1]oooo00?o09Woooooool09oooo`00Ioooo`030000<ol0<ol001`co`000`000?oo
ooooo`1]oooo00?o09Woooooool09oooo`00Ioooo`030000<ol0<ol001/co`000`000?ooooooo`1^
oooo00?o09Woooooool09oooo`00Ioooo`80000L<ol000<0003oooooool0K_ooo`03o`2Ioooooooo
02Ooool006Ooool00`0003?o03?o000J<ol000<0003oooooool0Koooo`03o`2Ioooooooo02Ooool0
06Ooool00`0003?o03?o000J<ol000<0003oooooool0Koooo`03o`2Ioooooooo02Ooool006Ooool0
0`0003?o03?o000I<ol000<0003oooooool0L?ooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o
03?o000I<ol000<0003oooooool0L?ooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000H
<ol000<0003oooooool0LOooo`03o`2Ioooooooo02Ooool006Ooool200006C?o00030000oooooooo
077oool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`005c?o00030000oooooooo07;oool0
0ol0VOooooooo`0Woooo001Woooo00<0000co`0co`005c?o00030000oooooooo07;oool00ol0VOoo
ooooo`0Woooo001Woooo00<0000co`0co`005S?o00030000oooooooo07?oool00ol0VOooooooo`0W
oooo001Woooo00<0000co`0co`005S?o00030000oooooooo07?oool00ol0VOooooooo`0Woooo001W
oooo00<0000co`0co`005S?o00030000oooooooo07?oool00ol0VOooooooo`0Woooo001Woooo00<0
000co`0co`005C?o00030000oooooooo07Coool00ol0VOooooooo`0Woooo001Woooo0P0001Hco`00
0`000?ooooooo`1doooo00?o09Woooooool09oooo`00Ioooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1doooo00?o09Woooooool09oooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1d
oooo00?o09Woooooool09oooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1eoooo00?o
09Woooooool09oooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1eoooo00?o09Wooooo
ool09oooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1eoooo00?o09Woooooool09ooo
o`00Ioooo`80000E<ol000<0003oooooool0MOooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o
03?o000C<ol000<0003oooooool0M_ooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000C
<ol000<0003oooooool0M_ooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000C<ol000<0
003oooooool0M_ooo`03o`2Ioooooooo02Ooool005ooool400001?ooo`030000<ol0<ol001<co`00
0`000?ooooooo`1foooo00?o09Woooooool09oooo`00Goooo`030000oooooooo00Goool00`0003?o
03?o000B<ol000<0003oooooool0Moooo`03o`2Ioooooooo02Ooool0063oool00`000?ooooooo`04
oooo0P0001<co`000`000?ooooooo`1goooo00?o09Woooooool09oooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000B<ol000<0003oooooool0Moooo`03o`2Ioooooooo02Ooool005ooool0
10000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003oooooool0N?ooo`03o`2Ioooooooo
02Ooool0063oool200001Oooo`030000<ol0<ol0014co`000`000?ooooooo`1hoooo00?o09Wooooo
ool09oooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1hoooo00?o09Woooooool09ooo
o`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1hoooo00?o09Woooooool09oooo`00Iooo
o`80000A<ol000<0003oooooool0NOooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000@
<ol000<0003oooooool0NOooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000@<ol000<0
003oooooool0NOooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000@<ol000<0003ooooo
ool0NOooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000?<ol000<0003oooooool0N_oo
o`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000?<ol000<0003oooooool0N_ooo`03o`2I
oooooooo02Ooool006Ooool00`0003?o03?o000?<ol000<0003oooooool0N_ooo`03o`2Ioooooooo
02Ooool006Ooool2000043?o00030000oooooooo07[oool00ol0VOooooooo`0Woooo001Woooo00<0
000co`0co`003S?o00030000oooooooo07_oool00ol0VOooooooo`0Woooo001Woooo00<0000co`0c
o`003S?o00030000oooooooo07_oool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`003S?o
00030000oooooooo07_oool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`003S?o00030000
oooooooo07_oool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`003C?o00030000oooooooo
07coool00ol0VOooooooo`0Woooo001Woooo0P0000hco`000`000?ooooooo`1loooo00?o09Wooooo
ool09oooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1loooo00?o09Woooooool09ooo
o`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`1loooo00?o09Woooooool09oooo`00Iooo
o`030000<ol0<ol000`co`000`000?ooooooo`1moooo00?o09Woooooool09oooo`00Ioooo`030000
<ol0<ol000`co`000`000?ooooooo`1moooo00?o09Woooooool09oooo`00Ioooo`030000<ol0<ol0
00`co`000`000?ooooooo`1moooo00?o09Woooooool09oooo`00Ioooo`80000=<ol000<0003ooooo
ool0OOooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000<<ol000<0003oooooool0OOoo
o`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o000<<ol000<0003oooooool0OOooo`03o`2I
oooooooo02Ooool006Ooool00`0003?o03?o000;<ol000<0003oooooool0O_ooo`03o`2Ioooooooo
02Ooool0063oool200001Oooo`030000<ol0<ol000/co`000`000?ooooooo`1noooo00?o09Wooooo
ool09oooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`1n
oooo00?o09Woooooool09oooo`00HOooo`030000oooooooo00?oool2000033?o00030000oooooooo
07koool00ol0VOooooooo`0Woooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000/co`00
0`000?ooooooo`1noooo00?o09Woooooool09oooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol000/co`000`000?ooooooo`1noooo00?o09Woooooool09oooo`00H?ooo`800005oooo00<0
000co`0co`002S?o00030000oooooooo07ooool00ol0VOooooooo`0Woooo001Woooo00<0000co`0c
o`002S?o00030000oooooooo07ooool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`002S?o
00030000oooooooo07ooool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`002S?o00030000
oooooooo07ooool00ol0VOooooooo`0Woooo001Woooo0P0000/co`000`000?ooooooo`1ooooo00?o
09Woooooool09oooo`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`1ooooo00?o09Wooooo
ool09oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`20oooo00?o09Woooooool09ooo
o`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`20oooo00?o09Woooooool09oooo`00Iooo
o`030000<ol0<ol000Tco`000`000?ooooooo`20oooo00?o09Woooooool09oooo`00Ioooo`030000
<ol0<ol000Tco`000`000?ooooooo`20oooo00?o09Woooooool09oooo`00Ioooo`80000:<ol000<0
003oooooool0P?ooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0P?ooo`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0P?oo
o`03o`2Ioooooooo02Ooool006Ooool00`0003?o03?o0008<ol000<0003oooooool0POooo`03o`2I
oooooooo02Ooool006Ooool00`0003?o03?o0008<ol000<0003oooooool0POooo`03o`2Ioooooooo
02Ooool006Ooool00`0003?o03?o0008<ol000<0003oooooool0POooo`03o`2Ioooooooo02Ooool0
06Ooool200002C?o00030000oooooooo087oool00ol0VOooooooo`0Woooo001Woooo00<0000co`0c
o`0023?o00030000oooooooo087oool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`0023?o
00030000oooooooo087oool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`001c?o00030000
oooooooo08;oool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`001c?o00030000oooooooo
08;oool00ol0VOooooooo`0Woooo001Woooo00<0000co`0co`001c?o00030000oooooooo08;oool0
0ol0VOooooooo`0Woooo001Woooo0P0000Pco`000`000?ooooooo`22oooo00?o09Woooooool09ooo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`22oooo00?o09Woooooool09oooo`00Iooo
o`030000<ol0<ol000Lco`000`000?ooooooo`22oooo00?o09Woooooool09oooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`22oooo00?o09Woooooool09oooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`22oooo00?o09Woooooool09oooo`00HOooo`<00003oooo00<0000co`0c
o`001c?o00030000oooooooo08;oool00ol0VOooooooo`0Woooo001Roooo00<0003oooooool00_oo
o`030000<ol0<ol000Lco`000`000?ooooooo`22oooo00?o09Woooooool09oooo`00Goooo`D00003
oooo0P0000Pco`000`000?ooooooo`22oooo00?o09Woooooool09oooo`00Goooo`040000oooooooo
00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_oooo001Qoooo0P0000Coool:
<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9<ol02Oooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool500000_ooo`800005oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`07oooo00<0003oooooool02Oooo`050000oooooooooooo000000;oool0
1@000?ooooooooooo`00001joooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Woool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo07Ooool006Ooool9<ol02?ooo`030000oooooooo00D0000>oooo00<0003ooooo
ool02_ooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool0
1@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000oooooooo00000_ooo`040000
oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000oooooooo017oool2
00002Oooo`@00003oooo0P0000?oool00`000?ooooooo`1ioooo001Woooo2C?o0;3oool006Ooool8
<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.87754 .12361 L
.88797 .12361 L
.89771 .12361 L
.90265 .12361 L
.90733 .12361 L
.90992 .12361 L
.91063 .12361 L
.91138 .12361 L
.91202 .12361 L
s
.91202 .12361 m
.9123 .61803 L
s
0 .4 1 r
.02381 .06244 m
.04262 .06325 L
.06244 .06438 L
.10458 .06749 L
.14264 .07082 L
.18314 .07465 L
.22214 .07844 L
.26358 .08243 L
.30351 .08615 L
.32179 .08779 L
.33219 .08871 L
.34193 .08955 L
.35148 .09024 L
.35685 .09053 L
.36176 .09074 L
.36692 .09091 L
.36964 .09098 L
.37255 .09104 L
.37533 .09109 L
.37786 .09112 L
.37908 .09113 L
.3804 .09114 L
.38165 .09115 L
.38279 .09115 L
.38406 .09115 L
.38525 .09116 L
.38632 .09115 L
.38749 .09115 L
.38876 .09115 L
.3894 .09114 L
.39011 .09114 L
.39253 .09112 L
.39479 .0911 L
.39722 .09106 L
.40162 .09099 L
.40687 .09087 L
.4124 .09071 L
.42228 .09036 L
.44202 .08942 L
.46039 .0883 L
.49943 .08527 L
.54093 .08127 L
.58091 .07681 L
.61938 .07202 L
.6603 .06648 L
.6997 .06076 L
.73759 .05499 L
.77793 .04867 L
.81675 .04259 L
.85803 .03638 L
Mistroke
.87866 .03348 L
.8887 .03214 L
.89779 .03098 L
.90238 .03042 L
.90734 .02983 L
.90961 .02956 L
.91086 .02942 L
.91202 .02928 L
.91301 .12361 L
.91407 .12361 L
.91632 .12361 L
.93604 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo08goool00`1Vooooooooo`0Voooo001Woooo00<0003ooooo
ool0Qoooo`L0I_lXoooo001Woooo00<0003oooooool0O_ooo`T0I_l6oooo00<0I_ooooooool09_oo
o`00Ioooo`030000oooooooo07Soool606Ko3oooo`0306Kooooooooo02Koool006Ooool00`000?oo
ooooo`1aoooo1`1VoaGoool00`1Vooooooooo`0Voooo001Woooo00<0003oooooool0JOooo`P0I_lL
oooo00<0I_ooooooool09_ooo`00Ioooo`80001Uoooo1@1VobCoool00`1Vooooooooo`0Voooo001W
oooo00<0003oooooool0GOooo`L0I_lYoooo00<0I_ooooooool09_ooo`00Ioooo`030000oooooooo
05Koool706Ko<?ooo`0306Kooooooooo02Koool001Koool@06Ko@Oooo`030000oooooooo057oool5
06Ko=oooo`0306Kooooooooo02Koool002Koool:06Ko=oooo`030000oooooooo04Woool806Ko??oo
o`0306Kooooooooo02Koool0033oool:06Ko;Oooo`030000oooooooo047oool806KoA?ooo`0306Ko
oooooooo02Koool003[oool:06Ko8oooo`80000moooo1@1Vodcoool00`1Vooooooooo`0Voooo000G
oooo1@0001koool200001?ooo`800002oooo0P1Vo`80000606Ko6Oooo`030000oooooooo01koool2
00001?ooo`800004oooo0P0000Woool706Ko3oooo`D0000Moooo1@0000;oool200001?ooo`80000B
oooo00<0I_ooooooool02oooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00001Oooo`X0I_l?oooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooo06Ko0000201VoaSoool00`000?ooooooo`0Ooooo00<0003oooooool01ooo
o`040000oooooooo00004Oooo`0306Kooooooooo00_oool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo00goool;06Ko1?ooo`030000
oooooooo01Woool406Ko00@00000I_l0I_l0000:06Ko00?oool0003oool07oooo`030000oooooooo
01ooool00`000?ooooooo`0:oooo00<0003oooooool03oooo`0306Kooooooooo00coool00`000?oo
ooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool010000?ooooooo`00
00Woool200006oooo`@0I_l00`00001Vo`1Vo`0I06Ko1?ooo`040000oooooooo00002Oooo`80000Q
oooo00<0003oooooool07oooo`030000oooooooo00Soool200004_ooo`0306Kooooooooo00goool0
0`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000
oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?oo
o`030000oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool04Oooo`0306Kooooooooo
00_oool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`0001koool200007ooo
o`80000:oooo0`0001ooool200008?ooo`80000:oooo0`00017oool00`1Vooooooooo`0<oooo0P00
01Ooool006Ooool00`000?ooooooo`2>oooo00<0I_ooooooool09Oooo`00Ioooo`030000oooooooo
08koool00`1Vooooooooo`0Uoooo001Woooo00<0003oooooool0S_ooo`0306Kooooooooo02Goool0
06Ooool00`000?ooooooo`2>oooo00<0I_ooooooool09Oooo`00Ioooo`030000oooooooo08koool0
0`1Vooooooooo`0Uoooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`04oooo00?o09T0003o
ool01_ooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o0100000Ioooo00<0
003oooooool05Oooo`03o`2Ioooooooo00koool00`000?ooooooo`0Eoooo001Woooo00<0000co`0c
o`00Ac?o00D00011oooo00?o09Woooooool09_ooo`00Ioooo`030000<ol0<ol0048co`050000A_oo
o`03o`2Ioooooooo02Koool006Ooool00`0003?o03?o000m<ol01@0004_oool00ol0VOooooooo`0V
oooo001Woooo00<0000co`0co`00>C?o00@0001@oooo00?o09Woooooool09_ooo`00Ioooo`80000h
<ol00P0005Coool00ol0VOooooooo`0Voooo001Woooo00<0000co`0co`00=C?o0080001Foooo00?o
09Woooooool09_ooo`00Ioooo`030000<ol0<ol003<co`020000F?ooo`03o`2Ioooooooo02Koool0
06Ooool00`0003?o03?o000a<ol00P0005[oool00ol0VOooooooo`0Voooo001Woooo00<0000co`0c
o`00<3?o00030000oooooooo05[oool00ol0VOooooooo`0Voooo001Woooo00<0000co`0co`00;S?o
0080001Moooo00?o09Woooooool09_ooo`00Ioooo`80000]<ol00P0005ooool00ol0VOooooooo`0V
oooo001Woooo00<0000co`0co`00:c?o00030000oooooooo05ooool00ol0VOooooooo`0Voooo001W
oooo00<0000co`0co`00:S?o00030000oooooooo063oool00ol0VOooooooo`0Voooo001Woooo00<0
000co`0co`00:C?o00030000oooooooo067oool00ol0VOooooooo`0Voooo001Woooo00<0000co`0c
o`00:3?o00030000oooooooo06;oool00ol0VOooooooo`0Voooo001Woooo00<0000co`0co`00:3?o
00030000oooooooo06;oool00ol0VOooooooo`0Voooo001Woooo0P0002Pco`000`000?ooooooo`1S
oooo00?o09Woooooool09_ooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`1Toooo00?o
09Woooooool09_ooo`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`1Uoooo00?o09Wooooo
ool09_ooo`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`1Voooo00?o09Woooooool09_oo
o`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`1Woooo00?o09Woooooool09_ooo`00Iooo
o`030000<ol0<ol002<co`000`000?ooooooo`1Woooo00?o09Woooooool09_ooo`00Ioooo`80000S
<ol000<0003oooooool0J?ooo`03o`2Ioooooooo02Koool006Ooool00`0003?o03?o000Q<ol000<0
003oooooool0JOooo`03o`2Ioooooooo02Koool006Ooool00`0003?o03?o000P<ol000<0003ooooo
ool0J_ooo`03o`2Ioooooooo02Koool006Ooool00`0003?o03?o000P<ol000<0003oooooool0J_oo
o`03o`2Ioooooooo02Koool006Ooool00`0003?o03?o000O<ol000<0003oooooool0Joooo`03o`2I
oooooooo02Koool005ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`1[oooo00?o
09Woooooool09_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003ooooo
ool0K?ooo`03o`2Ioooooooo02Koool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?oo
ooooo`1/oooo00?o09Woooooool09_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M
<ol000<0003oooooool0KOooo`03o`2Ioooooooo02Koool0067oool00`000?ooooooo`03oooo00<0
000co`0co`007C?o00030000oooooooo06goool00ol0VOooooooo`0Voooo001Poooo0P0000Goool0
0`0003?o03?o000L<ol000<0003oooooool0K_ooo`03o`2Ioooooooo02Koool006Ooool00`0003?o
03?o000L<ol000<0003oooooool0K_ooo`03o`2Ioooooooo02Koool006Ooool00`0003?o03?o000K
<ol000<0003oooooool0Koooo`03o`2Ioooooooo02Koool006Ooool2000073?o00030000oooooooo
06ooool00ol0VOooooooo`0Voooo001Woooo00<0000co`0co`006S?o00030000oooooooo073oool0
0ol0VOooooooo`0Voooo001Woooo00<0000co`0co`006S?o00030000oooooooo073oool00ol0VOoo
ooooo`0Voooo001Woooo00<0000co`0co`006C?o00030000oooooooo077oool00ol0VOooooooo`0V
oooo001Woooo00<0000co`0co`006C?o00030000oooooooo077oool00ol0VOooooooo`0Voooo001W
oooo00<0000co`0co`0063?o00030000oooooooo07;oool00ol0VOooooooo`0Voooo001Woooo0P00
01Tco`000`000?ooooooo`1boooo00?o09Woooooool09_ooo`00Ioooo`030000<ol0<ol001Lco`00
0`000?ooooooo`1coooo00?o09Woooooool09_ooo`00Ioooo`030000<ol0<ol001Lco`000`000?oo
ooooo`1coooo00?o09Woooooool09_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1d
oooo00?o09Woooooool09_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1doooo00?o
09Woooooool09_ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1doooo00?o09Wooooo
ool09_ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1eoooo00?o09Woooooool09_oo
o`00Ioooo`80000F<ol000<0003oooooool0MOooo`03o`2Ioooooooo02Koool006Ooool00`0003?o
03?o000E<ol000<0003oooooool0MOooo`03o`2Ioooooooo02Koool006Ooool00`0003?o03?o000E
<ol000<0003oooooool0MOooo`03o`2Ioooooooo02Koool006Ooool00`0003?o03?o000D<ol000<0
003oooooool0M_ooo`03o`2Ioooooooo02Koool006Ooool00`0003?o03?o000D<ol000<0003ooooo
ool0M_ooo`03o`2Ioooooooo02Koool006Ooool00`0003?o03?o000D<ol000<0003oooooool0M_oo
o`03o`2Ioooooooo02Koool006Ooool200005C?o00030000oooooooo07Koool00ol0VOooooooo`0V
oooo001Woooo00<0000co`0co`004c?o00030000oooooooo07Ooool00ol0VOooooooo`0Voooo001W
oooo00<0000co`0co`004c?o00030000oooooooo07Ooool00ol0VOooooooo`0Voooo001Woooo00<0
000co`0co`004c?o00030000oooooooo07Ooool00ol0VOooooooo`0Voooo001Ooooo100000Coool0
0`0003?o03?o000C<ol000<0003oooooool0Moooo`03o`2Ioooooooo02Koool005ooool00`000?oo
ooooo`05oooo00<0000co`0co`004S?o00030000oooooooo07Soool00ol0VOooooooo`0Voooo001P
oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0N?ooo`03o`2Ioooooooo02Koool0
067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo07Woool00ol0VOoo
ooooo`0Uoooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo
07[oool00ol0VOooooooo`0Uoooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`03o`2Ioooooooo02Goool006Ooool00`0003?o03?o000A<ol000<0003oooooool0N_oo
o`03o`2Ioooooooo02Goool006Ooool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`03o`2I
oooooooo02Goool006Ooool200004C?o00030000oooooooo07_oool00ol0VOooooooo`0Uoooo001W
oooo00<0000co`0co`0043?o00030000oooooooo07_oool00ol0VOooooooo`0Uoooo001Woooo00<0
000co`0co`0043?o00030000oooooooo07_oool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo07_oool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0co`003c?o
00030000oooooooo07coool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0co`003c?o00030000
oooooooo07coool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0co`003c?o00030000oooooooo
07coool00ol0VOooooooo`0Uoooo001Woooo0P00010co`000`000?ooooooo`1loooo00?o09Wooooo
ool09Oooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo00?o09Woooooool09Ooo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo00?o09Woooooool09Oooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo00?o09Woooooool09Oooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`1moooo00?o09Woooooool09Oooo`00Ioooo`030000<ol0<ol0
00dco`000`000?ooooooo`1noooo00?o09Woooooool09Oooo`00Ioooo`80000><ol000<0003ooooo
ool0O_ooo`03o`2Ioooooooo02Goool006Ooool00`0003?o03?o000=<ol000<0003oooooool0O_oo
o`03o`2Ioooooooo02Goool006Ooool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`03o`2I
oooooooo02Goool006Ooool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`03o`2Ioooooooo
02Goool006Ooool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Goool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Goool006Ooool2
00003C?o00030000oooooooo07ooool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0co`0033?o
00030000oooooooo07ooool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0co`0033?o00030000
oooooooo07ooool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0co`002c?o00030000oooooooo
083oool00ol0VOooooooo`0Uoooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`03o`2Ioooooooo02Goool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`03o`2Ioooooooo02Goool0067oool00`000?ooooooo`03oooo0P00
00`co`000`000?ooooooo`20oooo00?o09Woooooool09Oooo`00H_ooo`030000oooooooo00;oool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`03o`2Ioooooooo02Goool005ooool010000?oo
ooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`03o`2Ioooooooo02Goool0
063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo00?o09Woooooool09Ooo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo00?o09Woooooool09Oooo`00Iooo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo00?o09Woooooool09Oooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`21oooo00?o09Woooooool09Oooo`00Ioooo`80000;<ol000<0
003oooooool0POooo`03o`2Ioooooooo02Goool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`03o`2Ioooooooo02Goool006Ooool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`03o`2Ioooooooo02Goool006Ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`03o`2I
oooooooo02Goool006Ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`03o`2Ioooooooo
02Goool006Ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`03o`2Ioooooooo02Goool0
06Ooool200002S?o00030000oooooooo08;oool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo08;oool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0co`002C?o
00030000oooooooo08;oool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0co`0023?o00030000
oooooooo08?oool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0co`0023?o00030000oooooooo
08?oool00ol0VOooooooo`0Uoooo001Woooo00<0000co`0co`0023?o00030000oooooooo08?oool0
0ol0VOooooooo`0Uoooo001Woooo0P0000Tco`000`000?ooooooo`23oooo00?o09Woooooool09Ooo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo00?o09Woooooool09Oooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo00?o09Woooooool09Oooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`24oooo00?o09Woooooool09Oooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`24oooo00?o09Woooooool09Oooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`24oooo00?o09Woooooool09Oooo`00Ioooo`800008<ol000<0003oooooool0Q?oo
o`03o`2Ioooooooo02Goool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`03o`2I
oooooooo02Goool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo
02Goool006Ooool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo02Goool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo02Goool0067oool3
00000oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo00?o09Woooooool09Oooo`00H_oo
o`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo
02Goool005ooool500000oooo`800008<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo02Goool0
05ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[ooo
o`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o
00coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Ioooo`Tco`0;oooo00<0003ooooo
ool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001Woooo2C?o00_oool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001?ooo`800004oooo00<0
003oooooool0Noooo`00Ioooo`Tco`0;oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07_oool006Ooool9<ol02_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo07[oool006Ooool9<ol02ooo
o`030000oooooooo00D0000>oooo00<0003oooooool02?ooo`800004oooo00<0003oooooool0Nooo
o`00Ioooo`Tco`0;oooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001Woooo2C?o00coool00`000?ooooooo`0Aoooo0P00
00[oool200000oooo`030000oooooooo07coool006Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.90802 .12361 L
.91306 .12361 L
.91526 .12361 L
.91765 .12361 L
.91894 .12361 L
s
.91894 .12361 m
.91942 .61803 L
s
0 .4 1 r
.02381 .06268 m
.06244 .0648 L
.10458 .06801 L
.14415 .07155 L
.18221 .07518 L
.22272 .07911 L
.26171 .08286 L
.30316 .08669 L
.32392 .08854 L
.33304 .08934 L
.34309 .09019 L
.34772 .09054 L
.35271 .09085 L
.35702 .09107 L
.36173 .09127 L
.36702 .09144 L
.36946 .09151 L
.37205 .09156 L
.37462 .09161 L
.37695 .09164 L
.37808 .09165 L
.37929 .09167 L
.38043 .09167 L
.3815 .09168 L
.38274 .09169 L
.38387 .09169 L
.38509 .09169 L
.38578 .09169 L
.38641 .09169 L
.38747 .09169 L
.38864 .09168 L
.38986 .09168 L
.391 .09167 L
.39362 .09165 L
.39603 .09162 L
.40144 .09153 L
.40634 .09143 L
.4117 .09128 L
.4225 .09091 L
.44211 .08999 L
.46306 .08872 L
.50456 .08547 L
.54454 .08161 L
.58301 .07733 L
.62393 .07227 L
.66333 .06694 L
.70122 .06147 L
.74156 .05535 L
.78038 .04928 L
.82166 .04281 L
Mistroke
.86142 .0368 L
.88149 .03396 L
.89966 .03155 L
.90455 .03093 L
.90982 .03029 L
.91224 .02999 L
.9148 .02969 L
.91698 .02944 L
.91822 .0293 L
.91938 .12361 L
.92068 .12361 L
.9221 .12361 L
.92468 .12361 L
.92951 .12361 L
.94036 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo08ooool00`1Vooooooooo`0Toooo001Woooo00<0003ooooo
ool0ROooo`L0I_lVoooo001Woooo00<0003oooooool0Ooooo`X0I_l6oooo00<0I_ooooooool09?oo
o`00Ioooo`030000oooooooo07[oool506Ko4?ooo`0306Kooooooooo02Coool006Ooool00`000?oo
ooooo`1eoooo1@1VoaGoool00`1Vooooooooo`0Toooo001Woooo00<0003oooooool0Koooo`H0I_lJ
oooo00<0I_ooooooool09?ooo`00Ioooo`80001Yoooo1`1Vob3oool00`1Vooooooooo`0Toooo001W
oooo00<0003oooooool0H?ooo`P0I_lWoooo00<0I_ooooooool09?ooo`00Ioooo`030000oooooooo
05_oool506Ko;oooo`0306Kooooooooo02Coool001Koool@06Ko@Oooo`030000oooooooo05Coool7
06Ko=?ooo`0306Kooooooooo02Coool002Koool:06Ko=oooo`030000oooooooo04[oool:06Ko>ooo
o`0306Kooooooooo02Coool0033oool:06Ko;Oooo`030000oooooooo04;oool806KoAOooo`0306Ko
oooooooo02Coool003[oool:06Ko8oooo`80000noooo1@1Vodgoool00`1Vooooooooo`0Toooo000G
oooo1@0001koool200001?ooo`800002oooo0P1Vo`80000606Ko6Oooo`030000oooooooo01koool2
00001?ooo`800004oooo0P0000[oool706Ko3_ooo`D0000Moooo1@0000;oool200001?ooo`80000C
oooo00<0I_ooooooool02_ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00001Oooo`X0I_l?oooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00002@1VoaOoool00`000?ooooooo`0Ooooo00<0003oooooool01ooo
o`040000oooooooo00004_ooo`0306Kooooooooo00[oool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo00goool806Ko1oooo`030000
oooooooo01goool01@000?ooooooo`000?ooo`0:06Ko00<0003oooooool07_ooo`030000oooooooo
01ooool00`000?ooooooo`0:oooo00<0003oooooool04?ooo`0306Kooooooooo00_oool00`000?oo
ooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool010000?ooooooo`00
00Woool200006?ooo`L0I_l00`00001Vo`1Vo`0M06Ko00D00000I_l0I_l00000I_l02?ooo`80000Q
oooo00<0003oooooool07oooo`030000oooooooo00Soool200004oooo`0306Kooooooooo00coool0
0`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000
oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?oo
o`030000oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool04_ooo`0306Kooooooooo
00[oool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`0001koool200007ooo
o`80000:oooo0`0001ooool200008?ooo`80000:oooo0`0001;oool00`1Vooooooooo`0;oooo0P00
01Ooool006Ooool00`000?ooooooo`2?oooo00<0I_ooooooool09?ooo`00Ioooo`030000oooooooo
08ooool00`1Vooooooooo`0Toooo001Woooo00<0003oooooool0Soooo`0306Kooooooooo02Coool0
06Ooool00`000?ooooooo`2?oooo00<0I_ooooooool09?ooo`00Ioooo`030000oooooooo08ooool0
0`1Vooooooooo`0Toooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05oooo00<0003o09Wo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o0100000Ioooo00<0
003oooooool05oooo`03o`2Ioooooooo00coool00`000?ooooooo`0Eoooo001Woooo00<0000co`0c
o`00Ac?o00D00013oooo00?o09Woooooool09?ooo`00Ioooo`030000<ol0<ol0048co`050000B?oo
o`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000m<ol01@0004goool00ol0VOooooooo`0T
oooo001Woooo00<0000co`0co`00>C?o00@0001Boooo00?o09Woooooool09?ooo`00Ioooo`80000h
<ol00P0005Koool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`00=C?o0080001Hoooo00?o
09Woooooool09?ooo`00Ioooo`030000<ol0<ol003<co`020000F_ooo`03o`2Ioooooooo02Coool0
06Ooool00`0003?o03?o000a<ol00P0005coool00ol0VOooooooo`0Toooo001Woooo00<0000co`0c
o`00<3?o00030000oooooooo05coool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`00;S?o
0080001Ooooo00?o09Woooooool09?ooo`00Ioooo`80000]<ol00P00067oool00ol0VOooooooo`0T
oooo001Woooo00<0000co`0co`00:c?o00030000oooooooo067oool00ol0VOooooooo`0Toooo001W
oooo00<0000co`0co`00:S?o00030000oooooooo06;oool00ol0VOooooooo`0Toooo001Woooo00<0
000co`0co`00:C?o00030000oooooooo06?oool00ol0VOooooooo`0Toooo001Woooo00<0000co`0c
o`00:3?o00030000oooooooo06Coool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`00:3?o
00030000oooooooo06Coool00ol0VOooooooo`0Toooo001Woooo0P0002Pco`000`000?ooooooo`1U
oooo00?o09Woooooool09?ooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`1Voooo00?o
09Woooooool09?ooo`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`1Woooo00?o09Wooooo
ool09?ooo`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`1Xoooo00?o09Woooooool09?oo
o`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`1Yoooo00?o09Woooooool09?ooo`00Iooo
o`030000<ol0<ol002<co`000`000?ooooooo`1Yoooo00?o09Woooooool09?ooo`00Ioooo`80000S
<ol000<0003oooooool0J_ooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000Q<ol000<0
003oooooool0Joooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000P<ol000<0003ooooo
ool0K?ooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000P<ol000<0003oooooool0K?oo
o`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000O<ol000<0003oooooool0KOooo`03o`2I
oooooooo02Coool005ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`1]oooo00?o
09Woooooool09?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003ooooo
ool0K_ooo`03o`2Ioooooooo02Coool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?oo
ooooo`1^oooo00?o09Woooooool09?ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M
<ol000<0003oooooool0Koooo`03o`2Ioooooooo02Coool0067oool00`000?ooooooo`03oooo00<0
000co`0co`007C?o00030000oooooooo06ooool00ol0VOooooooo`0Toooo001Poooo0P0000Goool0
0`0003?o03?o000L<ol000<0003oooooool0L?ooo`03o`2Ioooooooo02Coool006Ooool00`0003?o
03?o000L<ol000<0003oooooool0L?ooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000K
<ol000<0003oooooool0LOooo`03o`2Ioooooooo02Coool006Ooool2000073?o00030000oooooooo
077oool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`006S?o00030000oooooooo07;oool0
0ol0VOooooooo`0Toooo001Woooo00<0000co`0co`006S?o00030000oooooooo07;oool00ol0VOoo
ooooo`0Toooo001Woooo00<0000co`0co`006C?o00030000oooooooo07?oool00ol0VOooooooo`0T
oooo001Woooo00<0000co`0co`006C?o00030000oooooooo07?oool00ol0VOooooooo`0Toooo001W
oooo00<0000co`0co`0063?o00030000oooooooo07Coool00ol0VOooooooo`0Toooo001Woooo0P00
01Tco`000`000?ooooooo`1doooo00?o09Woooooool09?ooo`00Ioooo`030000<ol0<ol001Lco`00
0`000?ooooooo`1eoooo00?o09Woooooool09?ooo`00Ioooo`030000<ol0<ol001Lco`000`000?oo
ooooo`1eoooo00?o09Woooooool09?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1f
oooo00?o09Woooooool09?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1foooo00?o
09Woooooool09?ooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1foooo00?o09Wooooo
ool09?ooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1goooo00?o09Woooooool09?oo
o`00Ioooo`80000F<ol000<0003oooooool0Moooo`03o`2Ioooooooo02Coool006Ooool00`0003?o
03?o000E<ol000<0003oooooool0Moooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000E
<ol000<0003oooooool0Moooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000D<ol000<0
003oooooool0N?ooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000D<ol000<0003ooooo
ool0N?ooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000D<ol000<0003oooooool0N?oo
o`03o`2Ioooooooo02Coool006Ooool200005C?o00030000oooooooo07Soool00ol0VOooooooo`0T
oooo001Woooo00<0000co`0co`004c?o00030000oooooooo07Woool00ol0VOooooooo`0Toooo001W
oooo00<0000co`0co`004c?o00030000oooooooo07Woool00ol0VOooooooo`0Toooo001Woooo00<0
000co`0co`004c?o00030000oooooooo07Woool00ol0VOooooooo`0Toooo001Ooooo100000Coool0
0`0003?o03?o000C<ol000<0003oooooool0NOooo`03o`2Ioooooooo02Coool005ooool00`000?oo
ooooo`05oooo00<0000co`0co`004S?o00030000oooooooo07[oool00ol0VOooooooo`0Toooo001P
oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02Coool0
067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo07[oool00ol0VOoo
ooooo`0Toooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo
07_oool00ol0VOooooooo`0Toooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003ooooo
ool0Noooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000A<ol000<0003oooooool0Nooo
o`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000A<ol000<0003oooooool0Noooo`03o`2I
oooooooo02Coool006Ooool200004C?o00030000oooooooo07coool00ol0VOooooooo`0Toooo001W
oooo00<0000co`0co`0043?o00030000oooooooo07coool00ol0VOooooooo`0Toooo001Woooo00<0
000co`0co`0043?o00030000oooooooo07coool00ol0VOooooooo`0Toooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo07coool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`003c?o
00030000oooooooo07goool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`003c?o00030000
oooooooo07goool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`003c?o00030000oooooooo
07goool00ol0VOooooooo`0Toooo001Woooo0P00010co`000`000?ooooooo`1moooo00?o09Wooooo
ool09?ooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1noooo00?o09Woooooool09?oo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`1noooo00?o09Woooooool09?ooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`1noooo00?o09Woooooool09?ooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`1noooo00?o09Woooooool09?ooo`00Ioooo`030000<ol0<ol0
00dco`000`000?ooooooo`1ooooo00?o09Woooooool09?ooo`00Ioooo`80000><ol000<0003ooooo
ool0Ooooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000=<ol000<0003oooooool0Oooo
o`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000=<ol000<0003oooooool0Ooooo`03o`2I
oooooooo02Coool006Ooool00`0003?o03?o000<<ol000<0003oooooool0P?ooo`03o`2Ioooooooo
02Coool006Ooool00`0003?o03?o000<<ol000<0003oooooool0P?ooo`03o`2Ioooooooo02Coool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0P?ooo`03o`2Ioooooooo02Coool006Ooool2
00003C?o00030000oooooooo083oool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`0033?o
00030000oooooooo083oool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`0033?o00030000
oooooooo083oool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`002c?o00030000oooooooo
087oool00ol0VOooooooo`0Toooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003ooooo
ool0POooo`03o`2Ioooooooo02Coool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;
<ol000<0003oooooool0POooo`03o`2Ioooooooo02Coool0067oool00`000?ooooooo`03oooo0P00
00`co`000`000?ooooooo`21oooo00?o09Woooooool09?ooo`00H_ooo`030000oooooooo00;oool0
0`0003?o03?o000;<ol000<0003oooooool0POooo`03o`2Ioooooooo02Coool005ooool010000?oo
ooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0POooo`03o`2Ioooooooo02Coool0
063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`22oooo00?o09Woooooool09?oo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`22oooo00?o09Woooooool09?ooo`00Iooo
o`030000<ol0<ol000Xco`000`000?ooooooo`22oooo00?o09Woooooool09?ooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`22oooo00?o09Woooooool09?ooo`00Ioooo`80000;<ol000<0
003oooooool0P_ooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0P_ooo`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Pooo
o`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Poooo`03o`2I
oooooooo02Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Poooo`03o`2Ioooooooo
02Coool006Ooool00`0003?o03?o0009<ol000<0003oooooool0Poooo`03o`2Ioooooooo02Coool0
06Ooool200002S?o00030000oooooooo08?oool00ol0VOooooooo`0Toooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo08?oool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`002C?o
00030000oooooooo08?oool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`0023?o00030000
oooooooo08Coool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`0023?o00030000oooooooo
08Coool00ol0VOooooooo`0Toooo001Woooo00<0000co`0co`0023?o00030000oooooooo08Coool0
0ol0VOooooooo`0Toooo001Woooo0P0000Tco`000`000?ooooooo`24oooo00?o09Woooooool09?oo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`24oooo00?o09Woooooool09?ooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`24oooo00?o09Woooooool09?ooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`25oooo00?o09Woooooool09?ooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`25oooo00?o09Woooooool09?ooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`25oooo00?o09Woooooool09?ooo`00Ioooo`800008<ol000<0003oooooool0QOoo
o`03o`2Ioooooooo02Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0QOooo`03o`2I
oooooooo02Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0QOooo`03o`2Ioooooooo
02Coool006Ooool00`0003?o03?o0007<ol000<0003oooooool0QOooo`03o`2Ioooooooo02Coool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0QOooo`03o`2Ioooooooo02Coool0067oool3
00000oooo`030000<ol0<ol000Lco`000`000?ooooooo`25oooo00?o09Woooooool09?ooo`00H_oo
o`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0QOooo`03o`2Ioooooooo
02Coool005ooool500000oooo`800008<ol000<0003oooooool0QOooo`03o`2Ioooooooo02Coool0
05ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[ooo
o`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o
00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001?ooo`800003oooo1000
00?oool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00002
oooo00<0003oooooool01?ooo`030000oooooooo07Soool006Ooool9<ol01oooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo00Coool00`000?ooooooo`1goooo001Woooo2C?o00Soool00`000?ooooooo`0500003_oo
o`030000oooooooo00Soool200001Oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001W
oooo2C?o00Soool01@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool006Ooool9<ol02Oooo`030000
oooooooo017oool200002_ooo`800004oooo0P0000?oool00`000?ooooooo`1ioooo001Woooo2C?o
0;3oool006Ooool8<ol0/Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.90802 .12361 L
.91765 .12361 L
.9225 .12361 L
.92389 .12361 L
.92521 .12361 L
s
.92521 .12361 m
.92569 .61803 L
s
0 .4 1 r
.02381 .06296 m
.06244 .06523 L
.10458 .06856 L
.14415 .07214 L
.18221 .07579 L
.22272 .07973 L
.26171 .08346 L
.30316 .08726 L
.32392 .08909 L
.33304 .08988 L
.34309 .09073 L
.34772 .09107 L
.35271 .09138 L
.35702 .0916 L
.36173 .0918 L
.36702 .09197 L
.36946 .09203 L
.37205 .09209 L
.37462 .09214 L
.37695 .09217 L
.37808 .09218 L
.37929 .09219 L
.38043 .0922 L
.3815 .09221 L
.38274 .09221 L
.38387 .09222 L
.38509 .09222 L
.38578 .09222 L
.38641 .09222 L
.38747 .09222 L
.38864 .09221 L
.38986 .09221 L
.391 .0922 L
.39362 .09218 L
.39603 .09215 L
.40144 .09207 L
.40634 .09197 L
.4117 .09183 L
.4225 .09146 L
.44211 .09056 L
.46306 .08931 L
.50456 .08612 L
.54454 .08232 L
.58301 .0781 L
.62393 .0731 L
.66333 .06783 L
.70122 .06241 L
.74156 .05633 L
.78038 .05028 L
.82166 .0438 L
Mistroke
.86142 .03773 L
.89966 .03237 L
.90982 .03106 L
.91938 .0299 L
.92195 .0296 L
.92336 .02943 L
.92467 .02928 L
.92536 .02921 L
.92609 .12361 L
.92691 .12361 L
.92765 .12361 L
.93039 .12361 L
.94036 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo097oool00`1Vooooooooo`0Roooo001Woooo00<0003ooooo
ool0R?ooo`X0I_lToooo001Woooo00<0003oooooool0Q?ooo`@0I_l9oooo00<0I_ooooooool08_oo
o`00Ioooo`030000oooooooo07goool706Ko3Oooo`0306Kooooooooo02;oool006Ooool00`000?oo
ooooo`1eoooo201VoaCoool00`1Vooooooooo`0Roooo001Woooo00<0003oooooool0Koooo`H0I_lL
oooo00<0I_ooooooool08_ooo`00Ioooo`80001Yoooo1`1Vob;oool00`1Vooooooooo`0Roooo001W
oooo00<0003oooooool0H?ooo`P0I_lYoooo00<0I_ooooooool08_ooo`00Ioooo`030000oooooooo
05_oool506Ko<Oooo`0306Kooooooooo02;oool001Koool506KoC?ooo`030000oooooooo05Coool7
06Ko=_ooo`0306Kooooooooo02;oool001_ooolE06Ko=oooo`030000oooooooo04coool806Ko?Ooo
o`0306Kooooooooo02;oool0033oool:06Ko;Oooo`030000oooooooo04Ooool506KoAOooo`0306Ko
oooooooo02;oool003[oool:06Ko8oooo`800011oooo1`1Vod[oool00`1Vooooooooo`0Roooo000G
oooo1@0001koool200001?ooo`800002oooo0P1Vo`80000606Ko6Oooo`030000oooooooo01koool2
00001?ooo`800004oooo0P0000[oool:06Ko2oooo`D0000Moooo1@0000;oool200001?ooo`80000E
oooo00<0I_ooooooool02?ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00001Oooo`X0I_l?oooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00002@1VoaOoool00`000?ooooooo`0Ooooo00<0003oooooool01ooo
o`040000oooooooo00005?ooo`0306Kooooooooo00Soool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo00goool806Ko1oooo`030000
oooooooo01goool01@000?ooooooo`000?ooo`0:06Ko00<0003oooooool07_ooo`030000oooooooo
01ooool00`000?ooooooo`0:oooo00<0003oooooool04_ooo`0306Kooooooooo00Woool00`000?oo
ooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Goooo100000;oool010000?ooooooo`00
00Woool200006?ooo`L0I_l00`00001Vo`1Vo`0M06Ko00D00000I_l0I_l00000I_l02?ooo`80000Q
oooo00<0003oooooool07oooo`030000oooooooo00Soool200005Oooo`0306Kooooooooo00[oool0
0`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000
oooooooo01koool00`000?ooooooo`0Moooo00@0003oooooool00009oooo00<0003oooooool08?oo
o`030000oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool05?ooo`0306Kooooooooo
00Soool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`0001koool200007ooo
o`80000:oooo0`0001ooool200008?ooo`80000:oooo0`0001Coool00`1Vooooooooo`09oooo0P00
01Ooool006Ooool00`000?ooooooo`2Aoooo00<0I_ooooooool08_ooo`00Ioooo`030000oooooooo
097oool00`1Vooooooooo`0Roooo001Woooo00<0003oooooool0TOooo`0306Kooooooooo02;oool0
06Ooool00`000?ooooooo`2Aoooo00<0I_ooooooool08_ooo`00Ioooo`030000oooooooo097oool0
0`1Vooooooooo`0Roooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05oooo00@0003ooooo
oooo09T4oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0U
oooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol0400001Woool0
0`000?ooooooo`0Ioooo00?o09Woooooool02_ooo`030000oooooooo01Goool006Ooool00`0003?o
03?o0017<ol01@0004Goool00ol0VOooooooo`0Roooo001Woooo00<0000co`0co`00@S?o00D0001:
oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol003dco`050000Coooo`03o`2Ioooooooo
02;oool006Ooool00`0003?o03?o000i<ol0100005Coool00ol0VOooooooo`0Roooo001Woooo0P00
03Pco`020000F?ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000e<ol00P0005[oool0
0ol0VOooooooo`0Roooo001Woooo00<0000co`0co`00<c?o0080001Loooo00?o09Woooooool08_oo
o`00Ioooo`030000<ol0<ol0034co`020000G_ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o
03?o000`<ol000<0003oooooool0G_ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000^
<ol00P00067oool00ol0VOooooooo`0Roooo001Woooo0P0002dco`020000Hoooo`03o`2Ioooooooo
02;oool006Ooool00`0003?o03?o000[<ol000<0003oooooool0Hoooo`03o`2Ioooooooo02;oool0
06Ooool00`0003?o03?o000Z<ol000<0003oooooool0I?ooo`03o`2Ioooooooo02;oool006Ooool0
0`0003?o03?o000Y<ol000<0003oooooool0IOooo`03o`2Ioooooooo02;oool006Ooool00`0003?o
03?o000X<ol000<0003oooooool0I_ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000X
<ol000<0003oooooool0I_ooo`03o`2Ioooooooo02;oool006Ooool20000:3?o00030000oooooooo
06Ooool00ol0VOooooooo`0Roooo001Woooo00<0000co`0co`009S?o00030000oooooooo06Soool0
0ol0VOooooooo`0Roooo001Woooo00<0000co`0co`009C?o00030000oooooooo06Woool00ol0VOoo
ooooo`0Roooo001Woooo00<0000co`0co`0093?o00030000oooooooo06[oool00ol0VOooooooo`0R
oooo001Woooo00<0000co`0co`008c?o00030000oooooooo06_oool00ol0VOooooooo`0Roooo001W
oooo00<0000co`0co`008c?o00030000oooooooo06_oool00ol0VOooooooo`0Roooo001Woooo0P00
02<co`000`000?ooooooo`1/oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol0024co`00
0`000?ooooooo`1]oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol0020co`000`000?oo
ooooo`1^oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol0020co`000`000?ooooooo`1^
oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`1_oooo00?o
09Woooooool08_ooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo06ooool0
0ol0VOooooooo`0Roooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`000`000?oo
ooooo`1`oooo00?o09Woooooool08_ooo`00HOooo`030000oooooooo00?oool200007c?o00030000
oooooooo073oool00ol0VOooooooo`0Roooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`000`000?ooooooo`1aoooo00?o09Woooooool08_ooo`00HOooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0LOooo`03o`2Ioooooooo02;oool0063oool200001Ooo
o`030000<ol0<ol001`co`000`000?ooooooo`1boooo00?o09Woooooool08_ooo`00Ioooo`030000
<ol0<ol001`co`000`000?ooooooo`1boooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol0
01/co`000`000?ooooooo`1coooo00?o09Woooooool08_ooo`00Ioooo`80000L<ol000<0003ooooo
ool0Loooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000J<ol000<0003oooooool0M?oo
o`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000J<ol000<0003oooooool0M?ooo`03o`2I
oooooooo02;oool006Ooool00`0003?o03?o000I<ol000<0003oooooool0MOooo`03o`2Ioooooooo
02;oool006Ooool00`0003?o03?o000I<ol000<0003oooooool0MOooo`03o`2Ioooooooo02;oool0
06Ooool00`0003?o03?o000H<ol000<0003oooooool0M_ooo`03o`2Ioooooooo02;oool006Ooool2
00006C?o00030000oooooooo07Koool00ol0VOooooooo`0Roooo001Woooo00<0000co`0co`005c?o
00030000oooooooo07Ooool00ol0VOooooooo`0Roooo001Woooo00<0000co`0co`005c?o00030000
oooooooo07Ooool00ol0VOooooooo`0Roooo001Woooo00<0000co`0co`005S?o00030000oooooooo
07Soool00ol0VOooooooo`0Roooo001Woooo00<0000co`0co`005S?o00030000oooooooo07Soool0
0ol0VOooooooo`0Roooo001Woooo00<0000co`0co`005S?o00030000oooooooo07Soool00ol0VOoo
ooooo`0Roooo001Woooo00<0000co`0co`005C?o00030000oooooooo07Woool00ol0VOooooooo`0R
oooo001Woooo0P0001Hco`000`000?ooooooo`1ioooo00?o09Woooooool08_ooo`00Ioooo`030000
<ol0<ol001Dco`000`000?ooooooo`1ioooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1ioooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooooooo`1joooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol001@co`000`000?oo
ooooo`1joooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol001@co`000`000?ooooooo`1j
oooo00?o09Woooooool08_ooo`00Ioooo`80000E<ol000<0003oooooool0N_ooo`03o`2Ioooooooo
02;oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0Noooo`03o`2Ioooooooo02;oool0
06Ooool00`0003?o03?o000C<ol000<0003oooooool0Noooo`03o`2Ioooooooo02;oool006Ooool0
0`0003?o03?o000C<ol000<0003oooooool0Noooo`03o`2Ioooooooo02;oool005ooool400001?oo
o`030000<ol0<ol001<co`000`000?ooooooo`1koooo00?o09Woooooool08_ooo`00Goooo`030000
oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0O?ooo`03o`2Ioooooooo02;oool0
063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`1loooo00?o09Woooooool08_oo
o`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0O?ooo`03o`2I
oooooooo02;oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0003ooooo
ool0OOooo`03o`2Ioooooooo02;oool0063oool200001Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`1moooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1m
oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`1moooo00?o
09Woooooool08_ooo`00Ioooo`80000A<ol000<0003oooooool0O_ooo`03o`2Ioooooooo02;oool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool0O_ooo`03o`2Ioooooooo02;oool006Ooool0
0`0003?o03?o000@<ol000<0003oooooool0O_ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o
03?o000@<ol000<0003oooooool0O_ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000?
<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000?<ol000<0
003oooooool0Ooooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000?<ol000<0003ooooo
ool0Ooooo`03o`2Ioooooooo02;oool006Ooool2000043?o00030000oooooooo07ooool00ol0VOoo
ooooo`0Roooo001Woooo00<0000co`0co`003S?o00030000oooooooo083oool00ol0VOooooooo`0R
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo083oool00ol0VOooooooo`0Roooo001W
oooo00<0000co`0co`003S?o00030000oooooooo083oool00ol0VOooooooo`0Roooo001Woooo00<0
000co`0co`003S?o00030000oooooooo083oool00ol0VOooooooo`0Roooo001Woooo00<0000co`0c
o`003C?o00030000oooooooo087oool00ol0VOooooooo`0Roooo001Woooo0P0000hco`000`000?oo
ooooo`21oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`21
oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`21oooo00?o
09Woooooool08_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`22oooo00?o09Wooooo
ool08_ooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`22oooo00?o09Woooooool08_oo
o`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`22oooo00?o09Woooooool08_ooo`00Iooo
o`80000=<ol000<0003oooooool0P_ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000<
<ol000<0003oooooool0P_ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000<<ol000<0
003oooooool0P_ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o000;<ol000<0003ooooo
ool0Poooo`03o`2Ioooooooo02;oool0063oool200001Oooo`030000<ol0<ol000/co`000`000?oo
ooooo`23oooo00?o09Woooooool08_ooo`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol0
00/co`000`000?ooooooo`23oooo00?o09Woooooool08_ooo`00HOooo`030000oooooooo00?oool2
000033?o00030000oooooooo08?oool00ol0VOooooooo`0Roooo001Roooo00<0003oooooool00_oo
o`030000<ol0<ol000/co`000`000?ooooooo`23oooo00?o09Woooooool08_ooo`00Goooo`040000
oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`23oooo00?o09Woooooool08_oo
o`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo08Coool00ol0VOooooooo`0R
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo08Coool00ol0VOooooooo`0Roooo001W
oooo00<0000co`0co`002S?o00030000oooooooo08Coool00ol0VOooooooo`0Roooo001Woooo00<0
000co`0co`002S?o00030000oooooooo08Coool00ol0VOooooooo`0Roooo001Woooo0P0000/co`00
0`000?ooooooo`24oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol000Xco`000`000?oo
ooooo`24oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`25
oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`25oooo00?o
09Woooooool08_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`25oooo00?o09Wooooo
ool08_ooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`25oooo00?o09Woooooool08_oo
o`00Ioooo`80000:<ol000<0003oooooool0QOooo`03o`2Ioooooooo02;oool006Ooool00`0003?o
03?o0009<ol000<0003oooooool0QOooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o0009
<ol000<0003oooooool0QOooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0Q_ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool0Q_ooo`03o`2Ioooooooo02;oool006Ooool00`0003?o03?o0008<ol000<0003oooooool0Q_oo
o`03o`2Ioooooooo02;oool006Ooool200002C?o00030000oooooooo08Koool00ol0VOooooooo`0R
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo08Koool00ol0VOooooooo`0Roooo001W
oooo00<0000co`0co`0023?o00030000oooooooo08Koool00ol0VOooooooo`0Roooo001Woooo00<0
000co`0co`001c?o00030000oooooooo08Ooool00ol0VOooooooo`0Roooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo08Ooool00ol0VOooooooo`0Roooo001Woooo00<0000co`0co`001c?o
00030000oooooooo08Ooool00ol0VOooooooo`0Roooo001Woooo0P0000Pco`000`000?ooooooo`27
oooo00?o09Woooooool08_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`27oooo00?o
09Woooooool08_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`27oooo00?o09Wooooo
ool08_ooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`27oooo00?o09Woooooool08_oo
o`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`27oooo00?o09Woooooool08_ooo`00HOoo
o`<00003oooo00<0000co`0co`001c?o00030000oooooooo08Ooool00ol0VOooooooo`0Roooo001R
oooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`27oooo00?o09Wooooo
ool08_ooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`27oooo00?o09Woooooool08_oo
o`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?ooo`Xco`2_
oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool006Ooool9
<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o00Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9<ol02?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004oooo0P0000Goool3
00000_ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool010000?ooooooo`00
00Goool01@000?ooooooooooo`00001joooo001Woooo2C?o00Ooool00`000?ooooooo`02oooo00<0
003oooooool03oooo`030000oooooooo00Ooool010000?ooooooo`0000;oool500000oooo`030000
oooooooo07Ooool006Ooool9<ol02?ooo`030000oooooooo00D0000>oooo00<0003oooooool02?oo
o`800003oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`08oooo00D0
003oooooooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
o`000003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003oooooool04Oooo`80000:
oooo0P0000Goool200000_ooo`030000oooooooo07Woool006Ooool9<ol0/?ooo`00Ioooo`Pco`2a
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91765 .12361 L
.9225 .12361 L
.92769 .12361 L
.92922 .12361 L
.92998 .12361 L
.93067 .12361 L
s
.93067 .12361 m
.93119 .61803 L
s
0 .4 1 r
.02381 .06326 m
.06244 .06569 L
.10458 .06911 L
.14415 .07274 L
.18221 .07641 L
.22272 .08034 L
.26171 .08405 L
.30316 .08783 L
.32392 .08964 L
.33304 .09042 L
.34309 .09126 L
.34772 .0916 L
.35271 .0919 L
.36173 .09232 L
.36702 .09249 L
.36963 .09256 L
.37205 .09261 L
.37442 .09265 L
.37657 .09269 L
.37896 .09271 L
.38027 .09272 L
.3815 .09273 L
.38266 .09274 L
.38391 .09274 L
.38508 .09274 L
.38615 .09274 L
.38741 .09274 L
.38812 .09274 L
.38878 .09274 L
.38998 .09273 L
.39126 .09273 L
.39379 .09271 L
.39617 .09268 L
.40158 .0926 L
.40621 .0925 L
.41047 .0924 L
.42005 .0921 L
.43897 .09129 L
.45967 .09011 L
.50023 .08712 L
.53928 .08354 L
.58078 .07911 L
.62076 .07432 L
.65923 .06928 L
.70014 .0635 L
.73955 .05761 L
.77744 .05174 L
.81778 .0454 L
.8566 .0394 L
.87635 .03648 L
Mistroke
.89788 .03345 L
.90787 .03212 L
.91851 .03077 L
.92368 .03014 L
.92622 .02984 L
.92855 .02957 L
.93067 .02932 L
.93174 .0292 L
.93292 .12361 L
.9341 .12361 L
.93536 .12361 L
.93764 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo09;oool00`1Vooooooooo`0Qoooo001Woooo00<0003ooooo
ool0S?ooo`L0I_lSoooo001Woooo00<0003oooooool0P_ooo`X0I_l6oooo00<0I_ooooooool08Ooo
o`00Ioooo`030000oooooooo07goool506Ko4?ooo`0306Kooooooooo027oool006Ooool00`000?oo
ooooo`1ioooo101VoaGoool00`1Vooooooooo`0Qoooo001Woooo00<0003oooooool0LOooo`P0I_lI
oooo00<0I_ooooooool08Oooo`00Ioooo`80001Zoooo201Vob7oool00`1Vooooooooo`0Qoooo001W
oooo00<0003oooooool0IOooo`@0I_lYoooo00<0I_ooooooool08Oooo`00Ioooo`030000oooooooo
05koool706Ko;Oooo`0306Kooooooooo027oool001Koool506KoC?ooo`030000oooooooo05Koool8
06Ko=?ooo`0306Kooooooooo027oool001_oool;06Ko@Oooo`030000oooooooo053oool606Ko??oo
o`0306Kooooooooo027oool002Koool:06Ko=oooo`030000oooooooo04Woool706Ko@_ooo`0306Ko
oooooooo027oool0033ooolD06Ko8oooo`800010oooo2P1VodWoool00`1Vooooooooo`0Qoooo000G
oooo1@0001koool200001?ooo`800002oooo0P1Vo`80000606Ko6Oooo`030000oooooooo01koool2
00001?ooo`800004oooo0P0000Woool:06Ko3?ooo`D0000Moooo1@0000;oool200001?ooo`80000G
oooo00<0I_ooooooool01_ooo`@0000Foooo000Ioooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooooooo00001Oooo`X0I_l?oooo00<0003oooooool07Oooo`040000oooooooo
00002?ooo`040000oooo06Ko0000201VoaSoool00`000?ooooooo`0Ooooo00<0003oooooool01ooo
o`040000oooooooo00005_ooo`0306Kooooooooo00Koool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo00goool806Ko1oooo`030000
oooooooo01goool010000?ooooooo`0000X0I_l00oooo`000?ooo`0Ooooo00<0003oooooool07ooo
o`030000oooooooo00[oool00`000?ooooooo`0Doooo00<0I_ooooooool01oooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01Ooool400000_ooo`040000oooooooo00002Ooo
o`80000Hoooo1`1Vo`03000006Ko06Ko00<0I_l;oooo3`1Vo`04000006Ko06Ko00002Oooo`80000Q
oooo00<0003oooooool07oooo`030000oooooooo00Soool200005oooo`0306Kooooooooo00Soool0
0`000?ooooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000
oooooooo01koool00`000?ooooooo`03oooo2`1Vo`ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0Poooo00<0003oooooool07oooo`030000oooooooo00Soool00`000?ooooooo`0Foooo00<0
I_ooooooool01_ooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool300007_oo
o`80000Ooooo0P0000[oool300007oooo`80000Poooo0P0000[oool300005_ooo`0306Kooooooooo
00Ooool200005oooo`00Ioooo`030000oooooooo09?oool00`1Vooooooooo`0Poooo001Woooo00<0
003oooooool0Toooo`0306Kooooooooo023oool006Ooool00`000?ooooooo`2Coooo00<0I_oooooo
ool08?ooo`00Ioooo`030000oooooooo09?oool00`1Vooooooooo`0Poooo001Woooo00<0003ooooo
ool0Toooo`0306Kooooooooo023oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool0
1@000?ooooooooooool0V@03oooo00<0003oooooool01Oooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T
<ol0400001Woool00`000?ooooooo`0Joooo00?o09Woooooool02Oooo`030000oooooooo01Goool0
06Ooool00`0003?o03?o0017<ol01@0004Koool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0c
o`00@S?o00D0001;oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol003dco`050000D?oo
o`03o`2Ioooooooo027oool006Ooool00`0003?o03?o000i<ol0100005Goool00ol0VOooooooo`0Q
oooo001Woooo0P0003Pco`020000FOooo`03o`2Ioooooooo027oool006Ooool00`0003?o03?o000e
<ol00P0005_oool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`00<c?o0080001Moooo00?o
09Woooooool08Oooo`00Ioooo`030000<ol0<ol0034co`020000Goooo`03o`2Ioooooooo027oool0
06Ooool00`0003?o03?o000`<ol000<0003oooooool0Goooo`03o`2Ioooooooo027oool006Ooool0
0`0003?o03?o000^<ol00P0006;oool00ol0VOooooooo`0Qoooo001Woooo0P0002dco`020000I?oo
o`03o`2Ioooooooo027oool006Ooool00`0003?o03?o000[<ol000<0003oooooool0I?ooo`03o`2I
oooooooo027oool006Ooool00`0003?o03?o000Z<ol000<0003oooooool0IOooo`03o`2Ioooooooo
027oool006Ooool00`0003?o03?o000Y<ol000<0003oooooool0I_ooo`03o`2Ioooooooo027oool0
06Ooool00`0003?o03?o000X<ol000<0003oooooool0Ioooo`03o`2Ioooooooo027oool006Ooool0
0`0003?o03?o000X<ol000<0003oooooool0Ioooo`03o`2Ioooooooo027oool006Ooool20000:3?o
00030000oooooooo06Soool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`009S?o00030000
oooooooo06Woool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`009C?o00030000oooooooo
06[oool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`0093?o00030000oooooooo06_oool0
0ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`008c?o00030000oooooooo06coool00ol0VOoo
ooooo`0Qoooo001Woooo00<0000co`0co`008c?o00030000oooooooo06coool00ol0VOooooooo`0Q
oooo001Woooo0P0002<co`000`000?ooooooo`1]oooo00?o09Woooooool08Oooo`00Ioooo`030000
<ol0<ol0024co`000`000?ooooooo`1^oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol0
020co`000`000?ooooooo`1_oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol0020co`00
0`000?ooooooo`1_oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol001lco`000`000?oo
ooooo`1`oooo00?o09Woooooool08Oooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000
oooooooo073oool00ol0VOooooooo`0Qoooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`1aoooo00?o09Woooooool08Oooo`00HOooo`030000oooooooo00?oool2
00007c?o00030000oooooooo077oool00ol0VOooooooo`0Qoooo001Qoooo00<0003oooooool00ooo
o`030000<ol0<ol001dco`000`000?ooooooo`1boooo00?o09Woooooool08Oooo`00HOooo`030000
oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool0L_ooo`03o`2Ioooooooo027oool0
063oool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`1coooo00?o09Woooooool08Ooo
o`00Ioooo`030000<ol0<ol001`co`000`000?ooooooo`1coooo00?o09Woooooool08Oooo`00Iooo
o`030000<ol0<ol001/co`000`000?ooooooo`1doooo00?o09Woooooool08Oooo`00Ioooo`80000L
<ol000<0003oooooool0M?ooo`03o`2Ioooooooo027oool006Ooool00`0003?o03?o000J<ol000<0
003oooooool0MOooo`03o`2Ioooooooo027oool006Ooool00`0003?o03?o000J<ol000<0003ooooo
ool0MOooo`03o`2Ioooooooo027oool006Ooool00`0003?o03?o000I<ol000<0003oooooool0M_oo
o`03o`2Ioooooooo027oool006Ooool00`0003?o03?o000I<ol000<0003oooooool0M_ooo`03o`2I
oooooooo027oool006Ooool00`0003?o03?o000H<ol000<0003oooooool0Moooo`03o`2Ioooooooo
027oool006Ooool200006C?o00030000oooooooo07Ooool00ol0VOooooooo`0Qoooo001Woooo00<0
000co`0co`005c?o00030000oooooooo07Soool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0c
o`005c?o00030000oooooooo07Soool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`005S?o
00030000oooooooo07Woool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`005S?o00030000
oooooooo07Woool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`005S?o00030000oooooooo
07Woool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`005C?o00030000oooooooo07[oool0
0ol0VOooooooo`0Qoooo001Woooo0P0001Hco`000`000?ooooooo`1joooo00?o09Woooooool08Ooo
o`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1joooo00?o09Woooooool08Oooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`1joooo00?o09Woooooool08Oooo`00Ioooo`030000
<ol0<ol001@co`000`000?ooooooo`1koooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`1koooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooooooo`1koooo00?o09Woooooool08Oooo`00Ioooo`80000E<ol000<0003oooooool0Nooo
o`03o`2Ioooooooo027oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0O?ooo`03o`2I
oooooooo027oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0O?ooo`03o`2Ioooooooo
027oool006Ooool00`0003?o03?o000C<ol000<0003oooooool0O?ooo`03o`2Ioooooooo027oool0
05ooool400001?ooo`030000<ol0<ol001<co`000`000?ooooooo`1loooo00?o09Woooooool08Ooo
o`00Goooo`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0OOooo`03o`2I
oooooooo027oool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`1moooo00?o
09Woooooool08Oooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0OOooo`03o`2Ioooooooo027oool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A
<ol000<0003oooooool0O_ooo`03o`2Ioooooooo027oool0063oool200001Oooo`030000<ol0<ol0
014co`000`000?ooooooo`1noooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol0014co`00
0`000?ooooooo`1noooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol0014co`000`000?oo
ooooo`1noooo00?o09Woooooool08Oooo`00Ioooo`80000A<ol000<0003oooooool0Ooooo`03o`2I
oooooooo027oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0Ooooo`03o`2Ioooooooo
027oool006Ooool00`0003?o03?o000@<ol000<0003oooooool0Ooooo`03o`2Ioooooooo027oool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool0Ooooo`03o`2Ioooooooo027oool006Ooool0
0`0003?o03?o000?<ol000<0003oooooool0P?ooo`03o`2Ioooooooo027oool006Ooool00`0003?o
03?o000?<ol000<0003oooooool0P?ooo`03o`2Ioooooooo027oool006Ooool00`0003?o03?o000?
<ol000<0003oooooool0P?ooo`03o`2Ioooooooo027oool006Ooool2000043?o00030000oooooooo
083oool00ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`003S?o00030000oooooooo087oool0
0ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`003S?o00030000oooooooo087oool00ol0VOoo
ooooo`0Qoooo001Woooo00<0000co`0co`003S?o00030000oooooooo087oool00ol0VOooooooo`0Q
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo087oool00ol0VOooooooo`0Qoooo001W
oooo00<0000co`0co`003C?o00030000oooooooo08;oool00ol0VOooooooo`0Qoooo001Woooo0P00
00hco`000`000?ooooooo`22oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000dco`00
0`000?ooooooo`22oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`22oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`23
oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`23oooo00?o
09Woooooool08Oooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`23oooo00?o09Wooooo
ool08Oooo`00Ioooo`80000=<ol000<0003oooooool0Poooo`03o`2Ioooooooo027oool006Ooool0
0`0003?o03?o000<<ol000<0003oooooool0Poooo`03o`2Ioooooooo027oool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0Poooo`03o`2Ioooooooo027oool006Ooool00`0003?o03?o000;
<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo027oool0063oool200001Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`24oooo00?o09Woooooool08Oooo`00Goooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000`000?ooooooo`24oooo00?o09Woooooool08Oooo`00HOooo`030000
oooooooo00?oool2000033?o00030000oooooooo08Coool00ol0VOooooooo`0Qoooo001Roooo00<0
003oooooool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`24oooo00?o09Woooooool08Ooo
o`00Goooo`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`24oooo00?o
09Woooooool08Oooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo08Goool0
0ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`002S?o00030000oooooooo08Goool00ol0VOoo
ooooo`0Qoooo001Woooo00<0000co`0co`002S?o00030000oooooooo08Goool00ol0VOooooooo`0Q
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo08Goool00ol0VOooooooo`0Qoooo001W
oooo0P0000/co`000`000?ooooooo`25oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol0
00Xco`000`000?ooooooo`25oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000Tco`00
0`000?ooooooo`26oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`26oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`26
oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`26oooo00?o
09Woooooool08Oooo`00Ioooo`80000:<ol000<0003oooooool0Q_ooo`03o`2Ioooooooo027oool0
06Ooool00`0003?o03?o0009<ol000<0003oooooool0Q_ooo`03o`2Ioooooooo027oool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0Q_ooo`03o`2Ioooooooo027oool006Ooool00`0003?o
03?o0008<ol000<0003oooooool0Qoooo`03o`2Ioooooooo027oool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0Qoooo`03o`2Ioooooooo027oool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0Qoooo`03o`2Ioooooooo027oool006Ooool200002C?o00030000oooooooo08Ooool0
0ol0VOooooooo`0Qoooo001Woooo00<0000co`0co`0023?o00030000oooooooo08Ooool00ol0VOoo
ooooo`0Qoooo001Woooo00<0000co`0co`0023?o00030000oooooooo08Ooool00ol0VOooooooo`0Q
oooo001Woooo00<0000co`0co`001c?o00030000oooooooo08Soool00ol0VOooooooo`0Qoooo001W
oooo00<0000co`0co`001c?o00030000oooooooo08Soool00ol0VOooooooo`0Qoooo001Woooo00<0
000co`0co`001c?o00030000oooooooo08Soool00ol0VOooooooo`0Qoooo001Woooo0P0000Pco`00
0`000?ooooooo`28oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?oo
ooooo`28oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`28
oooo00?o09Woooooool08Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`28oooo00?o
09Woooooool08Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`28oooo00?o09Wooooo
ool08Oooo`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo08Soool00ol0VOoo
ooooo`0Qoooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`28
oooo00?o09Woooooool08Oooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`28oooo00?o
09Woooooool08Oooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool0
00001?ooo`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o
0;3oool006Ooool9<ol02Oooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Woooo2C?o
00Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool006Ooool9
<ol02?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004
oooo0P0000?oool300001?ooo`030000oooooooo07Soool006Ooool9<ol02?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001Woooo2C?o
00Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Ooool010000?oo
ooooo`0000;oool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001Woooo2C?o00Soool0
0`000?ooooooo`0500003_ooo`030000oooooooo00Soool200000oooo`<00004oooo00<0003ooooo
ool0N?ooo`00Ioooo`Tco`08oooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09
oooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool0
06Ooool9<ol0/?ooo`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91765 .12361 L
.92769 .12361 L
.93044 .12361 L
.93339 .12361 L
.93482 .12361 L
.93618 .12361 L
.93739 .12361 L
s
.93739 .12361 m
.93792 .61803 L
s
0 .4 1 r
.02381 .0636 m
.06244 .06616 L
.10458 .06967 L
.14415 .07335 L
.18221 .07703 L
.22272 .08095 L
.26171 .08464 L
.30316 .08839 L
.32392 .09019 L
.33304 .09096 L
.34309 .09179 L
.34772 .09212 L
.35271 .09242 L
.36173 .09284 L
.36702 .09301 L
.36963 .09307 L
.37205 .09313 L
.37442 .09317 L
.37657 .0932 L
.37896 .09323 L
.38027 .09324 L
.3815 .09325 L
.38266 .09325 L
.38391 .09326 L
.38508 .09326 L
.38615 .09326 L
.38741 .09326 L
.38812 .09326 L
.38878 .09326 L
.38998 .09325 L
.39126 .09324 L
.39379 .09322 L
.39617 .0932 L
.40158 .09312 L
.40621 .09303 L
.41047 .09293 L
.42005 .09263 L
.43897 .09184 L
.45967 .09069 L
.50023 .08775 L
.53928 .08422 L
.58078 .07986 L
.62076 .07513 L
.65923 .07014 L
.70014 .06442 L
.73955 .05858 L
.77744 .05273 L
.81778 .04639 L
.8566 .04036 L
.89788 .03432 L
Mistroke
.91851 .03157 L
.92855 .03032 L
.93328 .02975 L
.93536 .02951 L
.93654 .02938 L
.93764 .02925 L
.93871 .12361 L
.93987 .12361 L
.94222 .12361 L
.94718 .12361 L
.95616 .12361 L
.97588 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo09Coool00`1Vooooooooo`0Ooooo001Woooo00<0003ooooo
ool0SOooo`P0I_lQoooo001Woooo00<0003oooooool0QOooo`P0I_l7oooo00<0I_ooooooool07ooo
o`00Ioooo`030000oooooooo07goool806Ko3oooo`0306Kooooooooo01ooool006Ooool00`000?oo
ooooo`1ioooo101VoaOoool00`1Vooooooooo`0Ooooo001Woooo00<0003oooooool0LOooo`P0I_lK
oooo00<0I_ooooooool07oooo`00Ioooo`80001Zoooo201Vob?oool00`1Vooooooooo`0Ooooo001W
oooo00<0003oooooool0IOooo`@0I_l[oooo00<0I_ooooooool07oooo`00Ioooo`030000oooooooo
05koool706Ko;oooo`0306Kooooooooo01ooool001Koool506KoC?ooo`030000oooooooo05Koool8
06Ko=_ooo`0306Kooooooooo01ooool001_oool;06Ko@Oooo`030000oooooooo053oool606Ko?_oo
o`0306Kooooooooo01ooool002Koool:06Ko=oooo`030000oooooooo04Woool706KoA?ooo`0306Ko
oooooooo01ooool0033oool:06Ko;Oooo`800010oooo2P1Vod_oool00`1Vooooooooo`0Ooooo000G
oooo1@0001koool20000101Vo`80000206Ko0_ooo`80000Ooooo00<0003oooooool07_ooo`800004
oooo0P0000Coool200002Oooo`X0I_l<oooo1@0001goool500000_ooo`800004oooo0P0001Soool0
0`1Vooooooooo`05oooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00007
oooo00D0I_l00000I_l0I_l000001@1VoaWoool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oool0I_l0000806Ko6?ooo`030000oooooooo01ooool00`000?ooooooo`07oooo00@0
003oooooool0000Goooo00<0I_ooooooool01Oooo`030000oooooooo01Ooool001Woool00`000?oo
ooooo`0Moooo00@0003oooooool0000;oooo00<0003oooooool00ooooa80I_l7oooo00<0003ooooo
ool07Oooo`040000oooooooo00002P1Vo`03oooo0000oooo01ooool00`000?ooooooo`0Ooooo00<0
003oooooool02_ooo`030000oooooooo01Goool00`1Vooooooooo`06oooo00<0003oooooool05_oo
o`004Oooo`@00004oooo00<0003oooooool05oooo`@00002oooo00@0003oooooool00009oooo0P00
01Soool706Ko00@00000I_l0I_l0I_lCoooo2@1Vo`04000006Ko06Ko00002Oooo`80000Qoooo00<0
003oooooool07oooo`030000oooooooo00Soool200006?ooo`0306Kooooooooo00Ooool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo
01koool010000?oooooooooooa<0I_l9oooo00@0003oooooool00009oooo00<0003oooooool08?oo
o`030000oooooooo01ooool00`000?ooooooo`08oooo00<0003oooooool05oooo`0306Kooooooooo
00Goool010000?ooooooo`0001Koool001Soool200008?ooo`80000:oooo0`0001koool200007ooo
o`80000:oooo0`0001ooool200008?ooo`80000:oooo0`0001Ooool00`1Vooooooooo`06oooo0P00
01Ooool006Ooool00`000?ooooooo`2Doooo00<0I_ooooooool07oooo`00Ioooo`030000oooooooo
09Coool00`1Vooooooooo`0Ooooo001Woooo00<0003oooooool0U?ooo`0306Kooooooooo01ooool0
06Ooool00`000?ooooooo`2Doooo00<0I_ooooooool07oooo`00Ioooo`030000oooooooo09Coool0
0`1Vooooooooo`0Ooooo000@ooooo`00017oool001Koool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000
oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0c
o`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0004<ol0:00000;oool00`000?ooooooo`05oooo00<0003ooooo
ool00oooo`03o`2Ioooo000000Ooool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool09Ooo
o`030000oooooooo02Koool00`0003?o03?o000U<ol000<0000co`0co`0093?o0100000Ioooo00<0
003oooooool07?ooo`03o`2Ioooooooo00Ooool00`000?ooooooo`0Eoooo001Woooo00<0000co`0c
o`00Ac?o00D00018oooo00?o09Woooooool07oooo`00Ioooo`030000<ol0<ol0048co`050000COoo
o`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000m<ol01@0005;oool00ol0VOooooooo`0O
oooo001Woooo00<0000co`0co`00>C?o00@0001Goooo00?o09Woooooool07oooo`00Ioooo`80000h
<ol00P0005_oool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`00=C?o0080001Moooo00?o
09Woooooool07oooo`00Ioooo`030000<ol0<ol003<co`020000Goooo`03o`2Ioooooooo01ooool0
06Ooool00`0003?o03?o000a<ol00P00067oool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0c
o`00<3?o00030000oooooooo067oool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`00;S?o
0080001Toooo00?o09Woooooool07oooo`00Ioooo`80000]<ol00P0006Koool00ol0VOooooooo`0O
oooo001Woooo00<0000co`0co`00:c?o00030000oooooooo06Koool00ol0VOooooooo`0Ooooo001W
oooo00<0000co`0co`00:S?o00030000oooooooo06Ooool00ol0VOooooooo`0Ooooo001Woooo00<0
000co`0co`00:C?o00030000oooooooo06Soool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0c
o`00:3?o00030000oooooooo06Woool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`00:3?o
00030000oooooooo06Woool00ol0VOooooooo`0Ooooo001Woooo0P0002Pco`000`000?ooooooo`1Z
oooo00?o09Woooooool07oooo`00Ioooo`030000<ol0<ol002Hco`000`000?ooooooo`1[oooo00?o
09Woooooool07oooo`00Ioooo`030000<ol0<ol002Dco`000`000?ooooooo`1/oooo00?o09Wooooo
ool07oooo`00Ioooo`030000<ol0<ol002@co`000`000?ooooooo`1]oooo00?o09Woooooool07ooo
o`00Ioooo`030000<ol0<ol002<co`000`000?ooooooo`1^oooo00?o09Woooooool07oooo`00Iooo
o`030000<ol0<ol002<co`000`000?ooooooo`1^oooo00?o09Woooooool07oooo`00Ioooo`80000S
<ol000<0003oooooool0Koooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000Q<ol000<0
003oooooool0L?ooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000P<ol000<0003ooooo
ool0LOooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000P<ol000<0003oooooool0LOoo
o`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000O<ol000<0003oooooool0L_ooo`03o`2I
oooooooo01ooool005ooool500000oooo`030000<ol0<ol001lco`000`000?ooooooo`1boooo00?o
09Woooooool07oooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000N<ol000<0003ooooo
ool0Loooo`03o`2Ioooooooo01ooool0067oool00`000?ooooooo`03oooo0P0001lco`000`000?oo
ooooo`1coooo00?o09Woooooool07oooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000M
<ol000<0003oooooool0M?ooo`03o`2Ioooooooo01ooool0067oool00`000?ooooooo`03oooo00<0
000co`0co`007C?o00030000oooooooo07Coool00ol0VOooooooo`0Ooooo001Poooo0P0000Goool0
0`0003?o03?o000L<ol000<0003oooooool0MOooo`03o`2Ioooooooo01ooool006Ooool00`0003?o
03?o000L<ol000<0003oooooool0MOooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000K
<ol000<0003oooooool0M_ooo`03o`2Ioooooooo01ooool006Ooool2000073?o00030000oooooooo
07Koool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`006S?o00030000oooooooo07Ooool0
0ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`006S?o00030000oooooooo07Ooool00ol0VOoo
ooooo`0Ooooo001Woooo00<0000co`0co`006C?o00030000oooooooo07Soool00ol0VOooooooo`0O
oooo001Woooo00<0000co`0co`006C?o00030000oooooooo07Soool00ol0VOooooooo`0Ooooo001W
oooo00<0000co`0co`0063?o00030000oooooooo07Woool00ol0VOooooooo`0Ooooo001Woooo0P00
01Tco`000`000?ooooooo`1ioooo00?o09Woooooool07oooo`00Ioooo`030000<ol0<ol001Lco`00
0`000?ooooooo`1joooo00?o09Woooooool07oooo`00Ioooo`030000<ol0<ol001Lco`000`000?oo
ooooo`1joooo00?o09Woooooool07oooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1k
oooo00?o09Woooooool07oooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1koooo00?o
09Woooooool07oooo`00Ioooo`030000<ol0<ol001Hco`000`000?ooooooo`1koooo00?o09Wooooo
ool07oooo`00Ioooo`030000<ol0<ol001Dco`000`000?ooooooo`1loooo00?o09Woooooool07ooo
o`00Ioooo`80000F<ol000<0003oooooool0O?ooo`03o`2Ioooooooo01ooool006Ooool00`0003?o
03?o000E<ol000<0003oooooool0O?ooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000E
<ol000<0003oooooool0O?ooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000D<ol000<0
003oooooool0OOooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000D<ol000<0003ooooo
ool0OOooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000D<ol000<0003oooooool0OOoo
o`03o`2Ioooooooo01ooool006Ooool200005C?o00030000oooooooo07goool00ol0VOooooooo`0O
oooo001Woooo00<0000co`0co`004c?o00030000oooooooo07koool00ol0VOooooooo`0Ooooo001W
oooo00<0000co`0co`004c?o00030000oooooooo07koool00ol0VOooooooo`0Ooooo001Woooo00<0
000co`0co`004c?o00030000oooooooo07koool00ol0VOooooooo`0Ooooo001Ooooo100000Coool0
0`0003?o03?o000C<ol000<0003oooooool0O_ooo`03o`2Ioooooooo01ooool005ooool00`000?oo
ooooo`05oooo00<0000co`0co`004S?o00030000oooooooo07ooool00ol0VOooooooo`0Ooooo001P
oooo00<0003oooooool01?ooo`80000C<ol000<0003oooooool0Ooooo`03o`2Ioooooooo01ooool0
067oool00`000?ooooooo`03oooo00<0000co`0co`004S?o00030000oooooooo07ooool00ol0VOoo
ooooo`0Ooooo001Ooooo00@0003oooooool00004oooo00<0000co`0co`004C?o00030000oooooooo
083oool00ol0VOooooooo`0Ooooo001Poooo0P0000Goool00`0003?o03?o000A<ol000<0003ooooo
ool0P?ooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000A<ol000<0003oooooool0P?oo
o`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000A<ol000<0003oooooool0P?ooo`03o`2I
oooooooo01ooool006Ooool200004C?o00030000oooooooo087oool00ol0VOooooooo`0Ooooo001W
oooo00<0000co`0co`0043?o00030000oooooooo087oool00ol0VOooooooo`0Ooooo001Woooo00<0
000co`0co`0043?o00030000oooooooo087oool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0c
o`0043?o00030000oooooooo087oool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`003c?o
00030000oooooooo08;oool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`003c?o00030000
oooooooo08;oool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`003c?o00030000oooooooo
08;oool00ol0VOooooooo`0Ooooo001Woooo0P00010co`000`000?ooooooo`22oooo00?o09Wooooo
ool07oooo`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`23oooo00?o09Woooooool07ooo
o`00Ioooo`030000<ol0<ol000hco`000`000?ooooooo`23oooo00?o09Woooooool07oooo`00Iooo
o`030000<ol0<ol000hco`000`000?ooooooo`23oooo00?o09Woooooool07oooo`00Ioooo`030000
<ol0<ol000hco`000`000?ooooooo`23oooo00?o09Woooooool07oooo`00Ioooo`030000<ol0<ol0
00dco`000`000?ooooooo`24oooo00?o09Woooooool07oooo`00Ioooo`80000><ol000<0003ooooo
ool0Q?ooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000=<ol000<0003oooooool0Q?oo
o`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000=<ol000<0003oooooool0Q?ooo`03o`2I
oooooooo01ooool006Ooool00`0003?o03?o000<<ol000<0003oooooool0QOooo`03o`2Ioooooooo
01ooool006Ooool00`0003?o03?o000<<ol000<0003oooooool0QOooo`03o`2Ioooooooo01ooool0
06Ooool00`0003?o03?o000<<ol000<0003oooooool0QOooo`03o`2Ioooooooo01ooool006Ooool2
00003C?o00030000oooooooo08Goool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`0033?o
00030000oooooooo08Goool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`0033?o00030000
oooooooo08Goool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`002c?o00030000oooooooo
08Koool00ol0VOooooooo`0Ooooo001Poooo0P0000Goool00`0003?o03?o000;<ol000<0003ooooo
ool0Q_ooo`03o`2Ioooooooo01ooool005ooool010000?ooooooo`0000Coool00`0003?o03?o000;
<ol000<0003oooooool0Q_ooo`03o`2Ioooooooo01ooool0067oool00`000?ooooooo`03oooo0P00
00`co`000`000?ooooooo`26oooo00?o09Woooooool07oooo`00H_ooo`030000oooooooo00;oool0
0`0003?o03?o000;<ol000<0003oooooool0Q_ooo`03o`2Ioooooooo01ooool005ooool010000?oo
ooooo`0000Coool00`0003?o03?o000;<ol000<0003oooooool0Q_ooo`03o`2Ioooooooo01ooool0
063oool200001Oooo`030000<ol0<ol000Xco`000`000?ooooooo`27oooo00?o09Woooooool07ooo
o`00Ioooo`030000<ol0<ol000Xco`000`000?ooooooo`27oooo00?o09Woooooool07oooo`00Iooo
o`030000<ol0<ol000Xco`000`000?ooooooo`27oooo00?o09Woooooool07oooo`00Ioooo`030000
<ol0<ol000Xco`000`000?ooooooo`27oooo00?o09Woooooool07oooo`00Ioooo`80000;<ol000<0
003oooooool0Qoooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0Qoooo`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0R?oo
o`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0R?ooo`03o`2I
oooooooo01ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0R?ooo`03o`2Ioooooooo
01ooool006Ooool00`0003?o03?o0009<ol000<0003oooooool0R?ooo`03o`2Ioooooooo01ooool0
06Ooool200002S?o00030000oooooooo08Soool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0c
o`002C?o00030000oooooooo08Soool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`002C?o
00030000oooooooo08Soool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`0023?o00030000
oooooooo08Woool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`0023?o00030000oooooooo
08Woool00ol0VOooooooo`0Ooooo001Woooo00<0000co`0co`0023?o00030000oooooooo08Woool0
0ol0VOooooooo`0Ooooo001Woooo0P0000Tco`000`000?ooooooo`29oooo00?o09Woooooool07ooo
o`00Ioooo`030000<ol0<ol000Pco`000`000?ooooooo`29oooo00?o09Woooooool07oooo`00Iooo
o`030000<ol0<ol000Pco`000`000?ooooooo`29oooo00?o09Woooooool07oooo`00Ioooo`030000
<ol0<ol000Lco`000`000?ooooooo`2:oooo00?o09Woooooool07oooo`00Ioooo`030000<ol0<ol0
00Lco`000`000?ooooooo`2:oooo00?o09Woooooool07oooo`00Ioooo`030000<ol0<ol000Lco`00
0`000?ooooooo`2:oooo00?o09Woooooool07oooo`00Ioooo`800008<ol000<0003oooooool0R_oo
o`03o`2Ioooooooo01ooool006Ooool00`0003?o03?o0007<ol000<0003oooooool0R_ooo`03o`2I
oooooooo01ooool006Ooool00`0003?o03?o0007<ol000<0003oooooool0R_ooo`03o`2Ioooooooo
01ooool006Ooool00`0003?o03?o0007<ol000<0003oooooool0R_ooo`03o`2Ioooooooo01ooool0
06Ooool00`0003?o03?o0007<ol000<0003oooooool0R_ooo`03o`2Ioooooooo01ooool0067oool3
00000oooo`030000<ol0<ol000Lco`000`000?ooooooo`2:oooo00?o09Woooooool07oooo`00H_oo
o`030000oooooooo00;oool00`0003?o03?o0007<ol000<0003oooooool0R_ooo`03o`2Ioooooooo
01ooool005ooool500000oooo`800008<ol000<0003oooooool0R_ooo`03o`2Ioooooooo01ooool0
05ooool010000?ooooooo`0000Coool:<ol0[oooo`00H?ooo`030000oooo000000Coool:<ol0[ooo
o`00HOooo`800004oooo2S?o0:ooool006Ooool9<ol0/?ooo`00Ioooo`Tco`2`oooo001Woooo2C?o
00Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00Ioooo`Tco`08oooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001Woooo2C?o00Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001?ooo`800004oooo0P00
00Coool00`000?ooooooo`1hoooo001Woooo2C?o00Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`07oooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo00@0003oooooool00002oooo00@0
003oooooool00004oooo00<0003oooooool0Moooo`00Ioooo`Tco`08oooo00<0003oooooool01@00
00koool00`000?ooooooo`08oooo0P0000Coool200001?ooo`030000oooooooo07Soool006Ooool9
<ol02?ooo`050000oooooooooooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Ioooo`Tco`09oooo00<0003ooooo
ool04Oooo`80000:oooo0P0000Coool200000oooo`030000oooooooo07Woool006Ooool9<ol0/?oo
o`00Ioooo`Pco`2aoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 1.10126 L
.34309 1.07923 L
.36276 .79311 L
.37376 .67763 L
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34132 .61803 L
s
.38073 .61803 m
.38373 .59243 L
.40298 .46673 L
.41382 .41276 L
.4238 .37124 L
.44262 .3094 L
.46328 .25997 L
.48279 .22587 L
.50371 .19899 L
.52495 .17907 L
.54507 .16515 L
.56498 .15486 L
.5834 .14765 L
.60206 .14205 L
.62267 .13738 L
.64201 .13408 L
.66287 .1314 L
.68291 .12948 L
.70401 .12797 L
.72375 .12691 L
.74212 .12615 L
.76257 .12552 L
.78116 .12508 L
.80035 .12473 L
.82114 .12444 L
.84102 .12424 L
.86206 .12408 L
.88164 .12396 L
.89995 .12388 L
.92024 .12381 L
.93877 .12377 L
.95668 .12373 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91726 .12361 L
.92761 .12361 L
.93331 .12361 L
.93871 .12361 L
.94107 .12361 L
.94236 .12361 L
.94357 .12361 L
s
.94357 .12361 m
.94409 .61803 L
s
0 .4 1 r
.02381 .06396 m
.06244 .06665 L
.10458 .07024 L
.14415 .07395 L
.18221 .07765 L
.22272 .08156 L
.26171 .08523 L
.30316 .08895 L
.32392 .09072 L
.33304 .09148 L
.34309 .09231 L
.34772 .09264 L
.35271 .09294 L
.36173 .09335 L
.36702 .09352 L
.36963 .09358 L
.37205 .09363 L
.37442 .09368 L
.37657 .09371 L
.37896 .09374 L
.38027 .09375 L
.3815 .09376 L
.38266 .09376 L
.38391 .09377 L
.38508 .09377 L
.38615 .09377 L
.38741 .09377 L
.38812 .09377 L
.38878 .09377 L
.38998 .09376 L
.39126 .09376 L
.39248 .09375 L
.39379 .09374 L
.39617 .09371 L
.40158 .09364 L
.40627 .09355 L
.41121 .09343 L
.42005 .09316 L
.43979 .09234 L
.45816 .09135 L
.4972 .08861 L
.5387 .08495 L
.57868 .08083 L
.61715 .07637 L
.65807 .07115 L
.69747 .06572 L
.73536 .06017 L
.7757 .05399 L
.81452 .0479 L
.8558 .04145 L
Mistroke
.89556 .03554 L
.91563 .03277 L
.9338 .03045 L
.93869 .02986 L
.94125 .02956 L
.94265 .0294 L
.94396 .02925 L
.94511 .12361 L
.94634 .12361 L
.94894 .12361 L
.95352 .12361 L
.9745 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.18254 .11111 -12 -9 ]
[.18254 .11111 12 0 ]
[.5 .11111 -9 -9 ]
[.5 .11111 9 0 ]
[.65873 .11111 -3 -9 ]
[.65873 .11111 3 0 ]
[.81746 .11111 -9 -9 ]
[.81746 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .24721 -6 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -6 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -6 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.18254 .12361 m
.18254 .12986 L
s
[(-0.5)] .18254 .11111 0 1 Mshowa
.5 .12361 m
.5 .12986 L
s
[(0.5)] .5 .11111 0 1 Mshowa
.65873 .12361 m
.65873 .12986 L
s
[(1)] .65873 .11111 0 1 Mshowa
.81746 .12361 m
.81746 .12986 L
s
[(1.5)] .81746 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.05556 .12361 m
.05556 .12736 L
s
.0873 .12361 m
.0873 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.15079 .12361 m
.15079 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.24603 .12361 m
.24603 .12736 L
s
.27778 .12361 m
.27778 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.37302 .12361 m
.37302 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.43651 .12361 m
.43651 .12736 L
s
.46825 .12361 m
.46825 .12736 L
s
.53175 .12361 m
.53175 .12736 L
s
.56349 .12361 m
.56349 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.62698 .12361 m
.62698 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.72222 .12361 m
.72222 .12736 L
s
.75397 .12361 m
.75397 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.84921 .12361 m
.84921 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.9127 .12361 m
.9127 .12736 L
s
.94444 .12361 m
.94444 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.34127 0 m
.34752 0 L
s
[(-1)] .32877 0 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(1)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(2)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(3)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(4)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .02472 m
.34502 .02472 L
s
.34127 .04944 m
.34502 .04944 L
s
.34127 .07416 m
.34502 .07416 L
s
.34127 .09889 m
.34502 .09889 L
s
.34127 .14833 m
.34502 .14833 L
s
.34127 .17305 m
.34502 .17305 L
s
.34127 .19777 m
.34502 .19777 L
s
.34127 .22249 m
.34502 .22249 L
s
.34127 .27193 m
.34502 .27193 L
s
.34127 .29666 m
.34502 .29666 L
s
.34127 .32138 m
.34502 .32138 L
s
.34127 .3461 m
.34502 .3461 L
s
.34127 .39554 m
.34502 .39554 L
s
.34127 .42026 m
.34502 .42026 L
s
.34127 .44498 m
.34502 .44498 L
s
.34127 .46971 m
.34502 .46971 L
s
.34127 .51915 m
.34502 .51915 L
s
.34127 .54387 m
.34502 .54387 L
s
.34127 .56859 m
.34502 .56859 L
s
.34127 .59331 m
.34502 .59331 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001Ooooo1@000;coool0067oool00`000?ooooooo`2loooo001Qoooo00<0003ooooo
ool00oooo`80002goooo001Ioooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0]_oo
o`00HOooo`030000oooooooo00?oool00`000?ooooooo`2foooo001Poooo0P0000Goool00`000?oo
ooooo`2foooo001Woooo00<0003oooooool0]_ooo`00Ioooo`030000oooooooo0;Koool006Ooool2
0000]oooo`00Ioooo`030000oooooooo09Koool00`1Vooooooooo`0Moooo001Woooo00<0003ooooo
ool0S?ooo`/0I_lOoooo001Woooo00<0003oooooool0Qoooo`D0I_l:oooo00<0I_ooooooool07Ooo
o`00Ioooo`030000oooooooo08;oool506Ko3oooo`0306Kooooooooo01goool006Ooool00`000?oo
ooooo`1koooo1`1VoaCoool00`1Vooooooooo`0Moooo001Woooo00<0003oooooool0Loooo`P0I_lK
oooo00<0I_ooooooool07Oooo`00Ioooo`80001_oooo1@1Vob?oool00`1Vooooooooo`0Moooo001W
oooo00<0003oooooool0Ioooo`L0I_lXoooo00<0I_ooooooool07Oooo`00Ioooo`030000oooooooo
05ooool806Ko;oooo`0306Kooooooooo01goool001Koool506KoC?ooo`030000oooooooo05[oool5
06Ko=oooo`0306Kooooooooo01goool001_oool;06Ko@Oooo`030000oooooooo05?oool706Ko??oo
o`0306Kooooooooo01goool002Koool:06Ko=oooo`030000oooooooo04Woool:06Ko@oooo`0306Ko
oooooooo01goool0033oool:06Ko;Oooo`800012oooo201Vodgoool00`1Vooooooooo`0Moooo000G
oooo1@0001koool20000101Vo`80000206Ko0_ooo`80000Ooooo00<0003oooooool07_ooo`800004
oooo0P0000Coool200004?ooo`D0I_l:oooo1@0001goool500000_ooo`800004oooo0P0001[oool0
0`1Vooooooooo`03oooo100001Koool001Woool00`000?ooooooo`0Moooo00@0003oooooool00007
oooo00D0I_l00000I_l0I_l000001@1VoaWoool00`000?ooooooo`0Moooo00@0003oooooool00008
oooo00@0003oooooool00008oooo1`1Voa7oool00`000?ooooooo`0Ooooo00<0003oooooool01ooo
o`040000oooooooo00006Oooo`0306Kooooooooo00?oool00`000?ooooooo`0Goooo000Ioooo00<0
003oooooool07Oooo`040000oooooooo00002oooo`030000oooooooo00?oool:06Ko3oooo`030000
oooooooo01goool010000?ooooooo`0000Woool206Ko00<00000I_l0I_l01P1VoaSoool00`000?oo
ooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo01Ooool00`1Vooooooooo`04oooo00<0
003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool05oooo`@00002oooo00@0003ooooo
ool00009oooo0P00013oool?06Ko00<0003oooooool05?ooo`T0I_l01000001Vo`1Vo`0000T0I_l2
00008Oooo`030000oooooooo01ooool00`000?ooooooo`08oooo0P0001[oool00`1Vooooooooo`05
oooo00<0003oooooool05Oooo`006Oooo`030000oooooooo01goool010000?ooooooo`0000Woool0
0`000?ooooooo`0Noooo00<00000I_l0I_l0501Vo`Woool010000?ooooooo`0000Woool00`000?oo
ooooo`0Poooo00<0003oooooool07oooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0
I_ooooooool00oooo`040000oooooooo00005_ooo`006?ooo`80000Poooo0P0000[oool300007_oo
o`80000Ooooo0P0000[oool300007oooo`80000Poooo0P0000[oool300006Oooo`0306Kooooooooo
00Coool200005oooo`00Ioooo`030000oooooooo09Koool00`1Vooooooooo`0Moooo001Woooo00<0
003oooooool0U_ooo`0306Kooooooooo01goool006Ooool00`000?ooooooo`2Foooo00<0I_oooooo
ool07Oooo`00Ioooo`030000oooooooo09Koool00`1Vooooooooo`0Moooo001Woooo00<0003ooooo
ool0U_ooo`0306Kooooooooo01goool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05
oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`0003?o03?o0005<ol000<0000co`0co`001C?o00030000
<ol0<ol000Dco`000`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`00
0`0003?o03?o0005<ol000<0000co`0co`001C?o00030000<ol0<ol000Dco`000`0003?o03?o0005
<ol000<0000co`0co`001C?o00030000<ol0<ol000@co`0X00000_ooo`030000oooooooo00Goool0
0`000?ooooooo`04oooo00?o09T0003oool01_ooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0Uoooo00<0003oooooool09_ooo`030000<ol0<ol002Dco`000`0003?o03?o000T<ol04000
01Woool00`000?ooooooo`0Moooo00?o09Woooooool01_ooo`030000oooooooo01Goool006Ooool0
0`0003?o03?o0017<ol01@0004Woool00ol0VOooooooo`0Noooo001Woooo00<0000co`0co`00@S?o
00D0001>oooo00?o09Woooooool07_ooo`00Ioooo`030000<ol0<ol003dco`050000Doooo`03o`2I
oooooooo01koool006Ooool00`0003?o03?o000i<ol0100005Soool00ol0VOooooooo`0Noooo001W
oooo0P0003Pco`020000G?ooo`03o`2Ioooooooo01koool006Ooool00`0003?o03?o000e<ol00P00
05koool00ol0VOooooooo`0Noooo001Woooo00<0000co`0co`00<c?o0080001Poooo00?o09Wooooo
ool07_ooo`00Ioooo`030000<ol0<ol0034co`020000H_ooo`03o`2Ioooooooo01koool006Ooool0
0`0003?o03?o000`<ol000<0003oooooool0H_ooo`03o`2Ioooooooo01koool006Ooool00`0003?o
03?o000^<ol00P0006Goool00ol0VOooooooo`0Noooo001Woooo0P0002dco`020000Ioooo`03o`2I
oooooooo01koool006Ooool00`0003?o03?o000[<ol000<0003oooooool0Ioooo`03o`2Ioooooooo
01koool006Ooool00`0003?o03?o000Z<ol000<0003oooooool0J?ooo`03o`2Ioooooooo01koool0
06Ooool00`0003?o03?o000Y<ol000<0003oooooool0JOooo`03o`2Ioooooooo01koool006Ooool0
0`0003?o03?o000X<ol000<0003oooooool0J_ooo`03o`2Ioooooooo01koool006Ooool00`0003?o
03?o000X<ol000<0003oooooool0J_ooo`03o`2Ioooooooo01koool006Ooool20000:3?o00030000
oooooooo06_oool00ol0VOooooooo`0Noooo001Woooo00<0000co`0co`009S?o00030000oooooooo
06coool00ol0VOooooooo`0Noooo001Woooo00<0000co`0co`009C?o00030000oooooooo06goool0
0ol0VOooooooo`0Noooo001Woooo00<0000co`0co`0093?o00030000oooooooo06koool00ol0VOoo
ooooo`0Noooo001Woooo00<0000co`0co`008c?o00030000oooooooo06ooool00ol0VOooooooo`0N
oooo001Woooo00<0000co`0co`008c?o00030000oooooooo06ooool00ol0VOooooooo`0Noooo001W
oooo0P0002<co`000`000?ooooooo`1`oooo00?o09Woooooool07_ooo`00Ioooo`030000<ol0<ol0
024co`000`000?ooooooo`1aoooo00?o09Woooooool07_ooo`00Ioooo`030000<ol0<ol0020co`00
0`000?ooooooo`1boooo00?o09Woooooool07_ooo`00Ioooo`030000<ol0<ol0020co`000`000?oo
ooooo`1boooo00?o09Woooooool07_ooo`00Ioooo`030000<ol0<ol001lco`000`000?ooooooo`1c
oooo00?o09Woooooool07_ooo`00Goooo`D00003oooo00<0000co`0co`007c?o00030000oooooooo
07?oool00ol0VOooooooo`0Noooo001Qoooo00<0003oooooool00oooo`030000<ol0<ol001hco`00
0`000?ooooooo`1doooo00?o09Woooooool07_ooo`00HOooo`030000oooooooo00?oool200007c?o
00030000oooooooo07Coool00ol0VOooooooo`0Noooo001Qoooo00<0003oooooool00oooo`030000
<ol0<ol001dco`000`000?ooooooo`1eoooo00?o09Woooooool07_ooo`00HOooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003oooooool0MOooo`03o`2Ioooooooo01koool0063oool2
00001Oooo`030000<ol0<ol001`co`000`000?ooooooo`1foooo00?o09Woooooool07_ooo`00Iooo
o`030000<ol0<ol001`co`000`000?ooooooo`1foooo00?o09Woooooool07_ooo`00Ioooo`030000
<ol0<ol001/co`000`000?ooooooo`1goooo00?o09Woooooool07_ooo`00Ioooo`80000L<ol000<0
003oooooool0Moooo`03o`2Ioooooooo01koool006Ooool00`0003?o03?o000J<ol000<0003ooooo
ool0N?ooo`03o`2Ioooooooo01koool006Ooool00`0003?o03?o000J<ol000<0003oooooool0N?oo
o`03o`2Ioooooooo01koool006Ooool00`0003?o03?o000I<ol000<0003oooooool0NOooo`03o`2I
oooooooo01koool006Ooool00`0003?o03?o000I<ol000<0003oooooool0NOooo`03o`2Ioooooooo
01koool006Ooool00`0003?o03?o000H<ol000<0003oooooool0N_ooo`03o`2Ioooooooo01koool0
06Ooool200006C?o00030000oooooooo07[oool00ol0VOooooooo`0Noooo001Woooo00<0000co`0c
o`005c?o00030000oooooooo07_oool00ol0VOooooooo`0Noooo001Woooo00<0000co`0co`005c?o
00030000oooooooo07_oool00ol0VOooooooo`0Noooo001Woooo00<0000co`0co`005S?o00030000
oooooooo07coool00ol0VOooooooo`0Noooo001Woooo00<0000co`0co`005S?o00030000oooooooo
07coool00ol0VOooooooo`0Noooo001Woooo00<0000co`0co`005S?o00030000oooooooo07coool0
0ol0VOooooooo`0Noooo001Woooo00<0000co`0co`005C?o00030000oooooooo07goool00ol0VOoo
ooooo`0Noooo001Woooo0P0001Hco`000`000?ooooooo`1moooo00?o09Woooooool07_ooo`00Iooo
o`030000<ol0<ol001Dco`000`000?ooooooo`1moooo00?o09Woooooool07_ooo`00Ioooo`030000
<ol0<ol001Dco`000`000?ooooooo`1moooo00?o09Woooooool07_ooo`00Ioooo`030000<ol0<ol0
01@co`000`000?ooooooo`1noooo00?o09Woooooool07_ooo`00Ioooo`030000<ol0<ol001@co`00
0`000?ooooooo`1noooo00?o09Woooooool07_ooo`00Ioooo`030000<ol0<ol001@co`000`000?oo
ooooo`1noooo00?o09Woooooool07_ooo`00Ioooo`80000E<ol000<0003oooooool0O_ooo`03o`2I
oooooooo01koool006Ooool00`0003?o03?o000C<ol000<0003oooooool0Ooooo`03o`2Ioooooooo
01koool006Ooool00`0003?o03?o000C<ol000<0003oooooool0Ooooo`03o`2Ioooooooo01koool0
06Ooool00`0003?o03?o000C<ol000<0003oooooool0Ooooo`03o`2Ioooooooo01koool005ooool4
00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`1ooooo00?o09Woooooool07_ooo`00Gooo
o`030000oooooooo00Goool00`0003?o03?o000B<ol000<0003oooooool0P?ooo`03o`2Ioooooooo
01koool0063oool00`000?ooooooo`04oooo0P0001<co`000`000?ooooooo`20oooo00?o09Wooooo
ool07_ooo`00HOooo`030000oooooooo00?oool00`0003?o03?o000B<ol000<0003oooooool0POoo
o`03o`2Ioooooooo01goool005ooool010000?ooooooo`0000Coool00`0003?o03?o000A<ol000<0
003oooooool0P_ooo`03o`2Ioooooooo01goool0063oool200001Oooo`030000<ol0<ol0014co`00
0`000?ooooooo`22oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol0014co`000`000?oo
ooooo`22oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol0014co`000`000?ooooooo`22
oooo00?o09Woooooool07Oooo`00Ioooo`80000A<ol000<0003oooooool0Poooo`03o`2Ioooooooo
01goool006Ooool00`0003?o03?o000@<ol000<0003oooooool0Poooo`03o`2Ioooooooo01goool0
06Ooool00`0003?o03?o000@<ol000<0003oooooool0Poooo`03o`2Ioooooooo01goool006Ooool0
0`0003?o03?o000@<ol000<0003oooooool0Poooo`03o`2Ioooooooo01goool006Ooool00`0003?o
03?o000?<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01goool006Ooool00`0003?o03?o000?
<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01goool006Ooool00`0003?o03?o000?<ol000<0
003oooooool0Q?ooo`03o`2Ioooooooo01goool006Ooool2000043?o00030000oooooooo08Coool0
0ol0VOooooooo`0Moooo001Woooo00<0000co`0co`003S?o00030000oooooooo08Goool00ol0VOoo
ooooo`0Moooo001Woooo00<0000co`0co`003S?o00030000oooooooo08Goool00ol0VOooooooo`0M
oooo001Woooo00<0000co`0co`003S?o00030000oooooooo08Goool00ol0VOooooooo`0Moooo001W
oooo00<0000co`0co`003S?o00030000oooooooo08Goool00ol0VOooooooo`0Moooo001Woooo00<0
000co`0co`003C?o00030000oooooooo08Koool00ol0VOooooooo`0Moooo001Woooo0P0000hco`00
0`000?ooooooo`26oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol000dco`000`000?oo
ooooo`26oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol000dco`000`000?ooooooo`26
oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`27oooo00?o
09Woooooool07Oooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`27oooo00?o09Wooooo
ool07Oooo`00Ioooo`030000<ol0<ol000`co`000`000?ooooooo`27oooo00?o09Woooooool07Ooo
o`00Ioooo`80000=<ol000<0003oooooool0Qoooo`03o`2Ioooooooo01goool006Ooool00`0003?o
03?o000<<ol000<0003oooooool0Qoooo`03o`2Ioooooooo01goool006Ooool00`0003?o03?o000<
<ol000<0003oooooool0Qoooo`03o`2Ioooooooo01goool006Ooool00`0003?o03?o000;<ol000<0
003oooooool0R?ooo`03o`2Ioooooooo01goool0063oool200001Oooo`030000<ol0<ol000/co`00
0`000?ooooooo`28oooo00?o09Woooooool07Oooo`00Goooo`040000oooooooo00001?ooo`030000
<ol0<ol000/co`000`000?ooooooo`28oooo00?o09Woooooool07Oooo`00HOooo`030000oooooooo
00?oool2000033?o00030000oooooooo08Soool00ol0VOooooooo`0Moooo001Roooo00<0003ooooo
ool00_ooo`030000<ol0<ol000/co`000`000?ooooooo`28oooo00?o09Woooooool07Oooo`00Gooo
o`040000oooooooo00001?ooo`030000<ol0<ol000/co`000`000?ooooooo`28oooo00?o09Wooooo
ool07Oooo`00H?ooo`800005oooo00<0000co`0co`002S?o00030000oooooooo08Woool00ol0VOoo
ooooo`0Moooo001Woooo00<0000co`0co`002S?o00030000oooooooo08Woool00ol0VOooooooo`0M
oooo001Woooo00<0000co`0co`002S?o00030000oooooooo08Woool00ol0VOooooooo`0Moooo001W
oooo00<0000co`0co`002S?o00030000oooooooo08Woool00ol0VOooooooo`0Moooo001Woooo0P00
00/co`000`000?ooooooo`29oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol000Xco`00
0`000?ooooooo`29oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?oo
ooooo`2:oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`2:
oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`2:oooo00?o
09Woooooool07Oooo`00Ioooo`030000<ol0<ol000Tco`000`000?ooooooo`2:oooo00?o09Wooooo
ool07Oooo`00Ioooo`80000:<ol000<0003oooooool0R_ooo`03o`2Ioooooooo01goool006Ooool0
0`0003?o03?o0009<ol000<0003oooooool0R_ooo`03o`2Ioooooooo01goool006Ooool00`0003?o
03?o0009<ol000<0003oooooool0R_ooo`03o`2Ioooooooo01goool006Ooool00`0003?o03?o0008
<ol000<0003oooooool0Roooo`03o`2Ioooooooo01goool006Ooool00`0003?o03?o0008<ol000<0
003oooooool0Roooo`03o`2Ioooooooo01goool006Ooool00`0003?o03?o0008<ol000<0003ooooo
ool0Roooo`03o`2Ioooooooo01goool006Ooool200002C?o00030000oooooooo08_oool00ol0VOoo
ooooo`0Moooo001Woooo00<0000co`0co`0023?o00030000oooooooo08_oool00ol0VOooooooo`0M
oooo001Woooo00<0000co`0co`0023?o00030000oooooooo08_oool00ol0VOooooooo`0Moooo001W
oooo00<0000co`0co`001c?o00030000oooooooo08coool00ol0VOooooooo`0Moooo001Woooo00<0
000co`0co`001c?o00030000oooooooo08coool00ol0VOooooooo`0Moooo001Woooo00<0000co`0c
o`001c?o00030000oooooooo08coool00ol0VOooooooo`0Moooo001Woooo0P0000Pco`000`000?oo
ooooo`2<oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`2<
oooo00?o09Woooooool07Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`2<oooo00?o
09Woooooool07Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`2<oooo00?o09Wooooo
ool07Oooo`00Ioooo`030000<ol0<ol000Lco`000`000?ooooooo`2<oooo00?o09Woooooool07Ooo
o`00HOooo`<00003oooo00<0000co`0co`001c?o00030000oooooooo08coool00ol0VOooooooo`0M
oooo001Roooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`2<oooo00?o
09Woooooool07Oooo`00Goooo`D00003oooo0P0000Pco`000`000?ooooooo`2<oooo00?o09Wooooo
ool07Oooo`00Goooo`040000oooooooo00001?ooo`Xco`2_oooo001Poooo00<0003oool000001?oo
o`Xco`2_oooo001Qoooo0P0000Coool:<ol0[oooo`00Ioooo`Tco`2`oooo001Woooo2C?o0;3oool0
06Ooool9<ol03?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001Woooo2C?o00_oool0
0`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool006Ooool9<ol02ooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800003oooo0`00
00Coool00`000?ooooooo`1koooo001Woooo2C?o00_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`09oooo00<0003oooooool00_oo
o`030000oooooooo07_oool006Ooool9<ol02_ooo`030000oooooooo00;oool00`000?ooooooo`0?
oooo00<0003oooooool02?ooo`<00004oooo00<0003oooooool0N_ooo`00Ioooo`Tco`0;oooo00<0
003oooooool01@0000koool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00Ioooo`Tco`0;oooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001Woooo2C?o00coool00`000?ooooooo`0A
oooo0P0000[oool300000_ooo`030000oooooooo07coool006Ooool9<ol0/?ooo`00Ioooo`Pco`2a
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.28237, \
-1.14361, 0.0124234, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.28237, -1.14361, 0.0124234, 0.031907}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-1\), \ 
              1}, \ PlotRange -> {\(-1\), 4}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-1\), \ 1}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(-1\), 
                1}], \[IndentingNewLine]\ \ \ \ \ \ \ Plot[{g[x, 
                t]}, {x, \ \(-1\), \ 1}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(-1\), 
                1}]}, \[IndentingNewLine]\ {t, \ \(-0.15\), \ 0.5,  .01}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.41696 .12361 L
.42237 .12361 L
.42482 .12361 L
.42617 .12361 L
.42744 .12361 L
.42816 .12361 L
s
.42816 .12361 m
.42847 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00?o09Wooooo
ool00oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0Woooo00?o
09Woooooool03oooo`030000<ol0<ol003Tco`000`0003?o03?o000f<ol01@0001Ooool007goool0
0ol0VOooooooo`0?oooo00<0000co`0co`00JS?o00P0000Loooo001moooo00?o09Woooooool03ooo
o`030000<ol0<ol006@co`0600009?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o001O
<ol01@0002[oool007goool00ol0VOooooooo`0?oooo00<0000co`0co`00FS?o00D0000_oooo001m
oooo00?o09Woooooool03oooo`80001F<ol01@0003Coool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`00DC?o00@0000ioooo001moooo00?o09Woooooool03oooo`030000<ol0<ol004lco`02
0000?Oooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o001<<ol00`0003ooool007goool0
0ol0VOooooooo`0?oooo00<0000co`0co`00BS?o00800012oooo001moooo00?o09Woooooool03ooo
o`030000<ol0<ol004Pco`020000A?ooo`00OOooo`03o`2Ioooooooo00ooool20000Ac?o00800016
oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol004@co`020000B?ooo`00OOooo`03o`2I
oooooooo00ooool00`0003?o03?o0013<ol000<0003oooooool0B?ooo`00OOooo`03o`2Ioooooooo
00ooool00`0003?o03?o0011<ol00P0004_oool007goool00ol0VOooooooo`0?oooo00<0000co`0c
o`00?c?o0080001=oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol003hco`000`000?oo
ooooo`1=oooo001moooo00?o09Woooooool03oooo`80000m<ol00P00053oool007goool00ol0VOoo
ooooo`0?oooo00<0000co`0co`00>S?o0080001Boooo001moooo00?o09Woooooool03oooo`030000
<ol0<ol003Tco`000`000?ooooooo`1Boooo001moooo00?o09Woooooool03oooo`030000<ol0<ol0
03Pco`000`000?ooooooo`1Coooo001moooo00?o09Woooooool03oooo`030000<ol0<ol003Hco`02
0000E_ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000e<ol000<0003oooooool0E_oo
o`00OOooo`03o`2Ioooooooo00ooool20000=C?o00030000oooooooo05Ooool007goool00ol0VOoo
ooooo`0?oooo00<0000co`0co`00<c?o00030000oooooooo05Soool007goool00ol0VOooooooo`0?
oooo00<0000co`0co`00<S?o00030000oooooooo05Woool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`00<C?o00030000oooooooo05[oool007goool00ol0VOooooooo`0?oooo00<0000co`0c
o`00<C?o00030000oooooooo05[oool007goool00ol0VOooooooo`07oooo1@0000?oool00`0003?o
03?o000`<ol000<0003oooooool0Foooo`00OOooo`03o`2Ioooooooo00Woool00`000?ooooooo`03
oooo00<0000co`0co`00;c?o00030000oooooooo05coool007goool00ol0VOooooooo`09oooo00<0
003oooooool00oooo`<0000^<ol000<0003oooooool0GOooo`00OOooo`03o`2Ioooooooo00Woool0
0`000?ooooooo`03oooo00<0000co`0co`00;S?o00030000oooooooo05goool007goool00ol0VOoo
ooooo`09oooo00<0003oooooool00oooo`030000<ol0<ol002dco`000`000?ooooooo`1Noooo001m
oooo00?o09Woooooool02?ooo`800005oooo00<0000co`0co`00;3?o00030000oooooooo05ooool0
07goool00ol0VOooooooo`0?oooo00<0000co`0co`00:c?o00030000oooooooo063oool007goool0
0ol0VOooooooo`0?oooo00<0000co`0co`00:c?o00030000oooooooo063oool007goool00ol0VOoo
ooooo`0?oooo0P0002/co`000`000?ooooooo`1Qoooo001moooo00?o09Woooooool03oooo`030000
<ol0<ol002Tco`000`000?ooooooo`1Roooo001moooo00?o09Woooooool03oooo`030000<ol0<ol0
02Tco`000`000?ooooooo`1Roooo001moooo00?o09Woooooool03oooo`030000<ol0<ol002Pco`00
0`000?ooooooo`1Soooo001moooo00?o09Woooooool03oooo`030000<ol0<ol002Lco`000`000?oo
ooooo`1Toooo001moooo00?o09Woooooool03oooo`030000<ol0<ol002Hco`000`000?ooooooo`1U
oooo001moooo00?o09Woooooool03oooo`80000W<ol000<0003oooooool0IOooo`00OOooo`03o`2I
oooooooo00ooool00`0003?o03?o000U<ol000<0003oooooool0I_ooo`00OOooo`03o`2Ioooooooo
00ooool00`0003?o03?o000T<ol000<0003oooooool0Ioooo`00OOooo`03o`2Ioooooooo00ooool0
0`0003?o03?o000T<ol000<0003oooooool0Ioooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o
03?o000S<ol000<0003oooooool0J?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000S
<ol000<0003oooooool0J?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000R<ol000<0
003oooooool0JOooo`00OOooo`03o`2Ioooooooo00ooool200008c?o00030000oooooooo06Woool0
07goool00ol0VOooooooo`0?oooo00<0000co`0co`008C?o00030000oooooooo06[oool007goool0
0ol0VOooooooo`0?oooo00<0000co`0co`008C?o00030000oooooooo06[oool007goool00ol0VOoo
ooooo`0?oooo00<0000co`0co`0083?o00030000oooooooo06_oool007goool00ol0VOooooooo`0?
oooo00<0000co`0co`0083?o00030000oooooooo06_oool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`0083?o00030000oooooooo06_oool007goool00ol0VOooooooo`0?oooo0P00020co`00
0`000?ooooooo`1/oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol001lco`000`000?oo
ooooo`1/oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol001hco`000`000?ooooooo`1]
oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol001hco`000`000?ooooooo`1]oooo001m
oooo00?o09Woooooool01oooo`@00004oooo00<0000co`0co`007S?o00030000oooooooo06goool0
07goool00ol0VOooooooo`07oooo00<0003oooooool01Oooo`030000<ol0<ol001dco`000`000?oo
ooooo`1^oooo001moooo00?o09Woooooool02?ooo`030000oooooooo00Coool300007C?o00030000
oooooooo06koool007goool00ol0VOooooooo`09oooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`000`000?ooooooo`1^oooo001moooo00?o09Woooooool01oooo`040000oooooooo00001?oo
o`030000<ol0<ol001`co`000`000?ooooooo`1_oooo001moooo00?o09Woooooool02?ooo`800005
oooo00<0000co`0co`0073?o00030000oooooooo06ooool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`006c?o00030000oooooooo073oool007goool00ol0VOooooooo`0?oooo00<0000co`0c
o`006c?o00030000oooooooo073oool007goool00ol0VOooooooo`0?oooo0P0001`co`000`000?oo
ooooo`1`oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol001Xco`000`000?ooooooo`1a
oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001m
oooo00?o09Woooooool03oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001moooo00?o
09Woooooool03oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001moooo00?o09Wooooo
ool03oooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001moooo00?o09Woooooool03ooo
o`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001moooo00?o09Woooooool03oooo`80000J
<ol000<0003oooooool0L_ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000H<ol000<0
003oooooool0Loooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000H<ol000<0003ooooo
ool0Loooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000H<ol000<0003oooooool0Looo
o`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00OOoo
o`03o`2Ioooooooo00ooool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00OOooo`03o`2I
oooooooo00ooool2000063?o00030000oooooooo07Coool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`005c?o00030000oooooooo07Coool007goool00ol0VOooooooo`0?oooo00<0000co`0c
o`005S?o00030000oooooooo07Goool007goool00ol0VOooooooo`0?oooo00<0000co`0co`005S?o
00030000oooooooo07Goool007goool00ol0VOooooooo`0?oooo00<0000co`0co`005S?o00030000
oooooooo07Goool007goool00ol0VOooooooo`0?oooo00<0000co`0co`005C?o00030000oooooooo
07Koool007goool00ol0VOooooooo`0?oooo0P0001Hco`000`000?ooooooo`1foooo001moooo00?o
09Woooooool03oooo`030000<ol0<ol001Dco`000`000?ooooooo`1foooo001moooo00?o09Wooooo
ool03oooo`030000<ol0<ol001Dco`000`000?ooooooo`1foooo001moooo00?o09Woooooool03ooo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo001moooo00?o09Woooooool02?ooo`800005
oooo00<0000co`0co`0053?o00030000oooooooo07Ooool007goool00ol0VOooooooo`07oooo00@0
003oooooool00004oooo00<0000co`0co`0053?o00030000oooooooo07Ooool007goool00ol0VOoo
ooooo`09oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool0N?ooo`00OOooo`03o`2I
oooooooo00[oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo07Soool0
07goool00ol0VOooooooo`07oooo00@0003oooooool00004oooo00<0000co`0co`004c?o00030000
oooooooo07Soool007goool00ol0VOooooooo`08oooo0P0000Goool00`0003?o03?o000B<ol000<0
003oooooool0NOooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000B<ol000<0003ooooo
ool0NOooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000B<ol000<0003oooooool0NOoo
o`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00OOoo
o`03o`2Ioooooooo00ooool200004S?o00030000oooooooo07[oool007goool00ol0VOooooooo`0?
oooo00<0000co`0co`004C?o00030000oooooooo07[oool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`004C?o00030000oooooooo07[oool007goool00ol0VOooooooo`0?oooo00<0000co`0c
o`004C?o00030000oooooooo07[oool007goool00ol0VOooooooo`0?oooo00<0000co`0co`0043?o
00030000oooooooo07_oool007goool00ol0VOooooooo`0?oooo00<0000co`0co`0043?o00030000
oooooooo07_oool007goool00ol0VOooooooo`0?oooo0P00014co`000`000?ooooooo`1koooo001m
oooo00?o09Woooooool03oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001moooo00?o
09Woooooool03oooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo001moooo00?o09Wooooo
ool03oooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo001moooo00?o09Woooooool03ooo
o`030000<ol0<ol000lco`000`000?ooooooo`1loooo001moooo00?o09Woooooool03oooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo001moooo00?o09Woooooool03oooo`80000@<ol000<0
003oooooool0O?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000><ol000<0003ooooo
ool0OOooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000><ol000<0003oooooool0OOoo
o`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000><ol000<0003oooooool0OOooo`00OOoo
o`03o`2Ioooooooo00ooool00`0003?o03?o000><ol000<0003oooooool0OOooo`00OOooo`03o`2I
oooooooo00ooool00`0003?o03?o000><ol000<0003oooooool0OOooo`00OOooo`03o`2Ioooooooo
00ooool200003S?o00030000oooooooo07koool007goool00ol0VOooooooo`0?oooo00<0000co`0c
o`003C?o00030000oooooooo07koool007goool00ol0VOooooooo`0?oooo00<0000co`0co`003C?o
00030000oooooooo07koool007goool00ol0VOooooooo`0?oooo00<0000co`0co`003C?o00030000
oooooooo07koool007goool00ol0VOooooooo`0?oooo00<0000co`0co`0033?o00030000oooooooo
07ooool007goool00ol0VOooooooo`09oooo0`0000?oool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00OOooo`03o`2Ioooooooo00[oool00`000?ooooooo`02oooo00<0000co`0co`0033?o
00030000oooooooo07ooool007goool00ol0VOooooooo`07oooo1@0000?oool3000033?o00030000
oooooooo07ooool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo0000
00Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22
oooo001foooo00<0003oooooool05_ooo`hco`0:oooo00<0003oooooool0M_ooo`00MOooo`030000
oooooooo00Soool00`000?ooooooo`0<oooo3S?o00_oool00`000?ooooooo`1eoooo001eoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`03<ol00000000000@co`0200000c?o
00D00002oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool0100003?o03?o000000Xco`00
1@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0000co`0co`00000:<ol000<0003oooooool01?ooo`030000
oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool0100003?o
03?o000000Xco`000`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005Oooo`040000<ol0<ol000002C?o0003oooo0000oooo00?oool00`000?oo
ooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Koool00c?o00000000000:
<ol00P0000Coool300000_ooo`030000oooooooo07Koool008ooool=<ol0Q?ooo`00Soooo`dco`24
oooo0000\
\>"],
  ImageRangeCache->{{{79.5625, 308.938}, {438.813, 297.5}} -> {-0.349561, \
2.10527, 0.00349883, 0.00566123}, {{79.875, 308.563}, {438.813, 297.5}} -> \
{-2.01445, 10.7436, 0.00829766, 0.0319664}, {{79.875, 308.563}, {438.813, \
297.5}} -> {-2.01445, 10.7436, 0.00829766, 0.0319664}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.42237 .12361 L
.42781 .12361 L
.43049 .12361 L
.43179 .12361 L
.43298 .12361 L
s
.43298 .12361 m
.43344 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`04oooo00?o09Wooooo
ool00_ooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0Xoooo00?o
09Woooooool03_ooo`030000<ol0<ol003Tco`000`0003?o03?o000f<ol01@0001Ooool007koool0
0ol0VOooooooo`0>oooo00<0000co`0co`00JS?o00P0000Loooo001noooo00?o09Woooooool03_oo
o`030000<ol0<ol006@co`0600009?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o001O
<ol01@0002[oool007koool00ol0VOooooooo`0>oooo00<0000co`0co`00FS?o00D0000_oooo001n
oooo00?o09Woooooool03_ooo`80001F<ol01@0003Coool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`00DC?o00@0000ioooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol004lco`02
0000?Oooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o001<<ol00`0003ooool007koool0
0ol0VOooooooo`0>oooo00<0000co`0co`00BS?o00800012oooo001noooo00?o09Woooooool03_oo
o`030000<ol0<ol004Pco`020000A?ooo`00O_ooo`03o`2Ioooooooo00koool20000Ac?o00800016
oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol004@co`020000B?ooo`00O_ooo`03o`2I
oooooooo00koool00`0003?o03?o0013<ol000<0003oooooool0B?ooo`00O_ooo`03o`2Ioooooooo
00koool00`0003?o03?o0011<ol00P0004_oool007koool00ol0VOooooooo`0>oooo00<0000co`0c
o`00?c?o0080001=oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol003hco`000`000?oo
ooooo`1=oooo001noooo00?o09Woooooool03_ooo`80000m<ol00P00053oool007koool00ol0VOoo
ooooo`0>oooo00<0000co`0co`00>S?o0080001Boooo001noooo00?o09Woooooool03_ooo`030000
<ol0<ol003Tco`000`000?ooooooo`1Boooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol0
03Pco`000`000?ooooooo`1Coooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol003Hco`02
0000E_ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000e<ol000<0003oooooool0E_oo
o`00O_ooo`03o`2Ioooooooo00koool20000=C?o00030000oooooooo05Ooool007koool00ol0VOoo
ooooo`0>oooo00<0000co`0co`00<c?o00030000oooooooo05Soool007koool00ol0VOooooooo`0>
oooo00<0000co`0co`00<S?o00030000oooooooo05Woool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`00<C?o00030000oooooooo05[oool007koool00ol0VOooooooo`0>oooo00<0000co`0c
o`00<C?o00030000oooooooo05[oool007koool00ol0VOooooooo`06oooo1@0000?oool00`0003?o
03?o000`<ol000<0003oooooool0Foooo`00O_ooo`03o`2Ioooooooo00Soool00`000?ooooooo`03
oooo00<0000co`0co`00;c?o00030000oooooooo05coool007koool00ol0VOooooooo`08oooo00<0
003oooooool00oooo`<0000^<ol000<0003oooooool0GOooo`00O_ooo`03o`2Ioooooooo00Soool0
0`000?ooooooo`03oooo00<0000co`0co`00;S?o00030000oooooooo05goool007koool00ol0VOoo
ooooo`08oooo00<0003oooooool00oooo`030000<ol0<ol002dco`000`000?ooooooo`1Noooo001n
oooo00?o09Woooooool01oooo`800005oooo00<0000co`0co`00;3?o00030000oooooooo05ooool0
07koool00ol0VOooooooo`0>oooo00<0000co`0co`00:c?o00030000oooooooo063oool007koool0
0ol0VOooooooo`0>oooo00<0000co`0co`00:c?o00030000oooooooo063oool007koool00ol0VOoo
ooooo`0>oooo0P0002/co`000`000?ooooooo`1Qoooo001noooo00?o09Woooooool03_ooo`030000
<ol0<ol002Tco`000`000?ooooooo`1Roooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol0
02Tco`000`000?ooooooo`1Roooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol002Pco`00
0`000?ooooooo`1Soooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol002Lco`000`000?oo
ooooo`1Toooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol002Hco`000`000?ooooooo`1U
oooo001noooo00?o09Woooooool03_ooo`80000W<ol000<0003oooooool0IOooo`00O_ooo`03o`2I
oooooooo00koool00`0003?o03?o000U<ol000<0003oooooool0I_ooo`00O_ooo`03o`2Ioooooooo
00koool00`0003?o03?o000T<ol000<0003oooooool0Ioooo`00O_ooo`03o`2Ioooooooo00koool0
0`0003?o03?o000T<ol000<0003oooooool0Ioooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o
03?o000S<ol000<0003oooooool0J?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000S
<ol000<0003oooooool0J?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000R<ol000<0
003oooooool0JOooo`00O_ooo`03o`2Ioooooooo00koool200008c?o00030000oooooooo06Woool0
07koool00ol0VOooooooo`0>oooo00<0000co`0co`008C?o00030000oooooooo06[oool007koool0
0ol0VOooooooo`0>oooo00<0000co`0co`008C?o00030000oooooooo06[oool007koool00ol0VOoo
ooooo`0>oooo00<0000co`0co`0083?o00030000oooooooo06_oool007koool00ol0VOooooooo`0>
oooo00<0000co`0co`0083?o00030000oooooooo06_oool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`0083?o00030000oooooooo06_oool007koool00ol0VOooooooo`0>oooo0P00020co`00
0`000?ooooooo`1/oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol001lco`000`000?oo
ooooo`1/oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol001hco`000`000?ooooooo`1]
oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol001hco`000`000?ooooooo`1]oooo001n
oooo00?o09Woooooool01_ooo`@00004oooo00<0000co`0co`007S?o00030000oooooooo06goool0
07koool00ol0VOooooooo`06oooo00<0003oooooool01Oooo`030000<ol0<ol001dco`000`000?oo
ooooo`1^oooo001noooo00?o09Woooooool01oooo`030000oooooooo00Coool300007C?o00030000
oooooooo06koool007koool00ol0VOooooooo`08oooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`000`000?ooooooo`1^oooo001noooo00?o09Woooooool01_ooo`040000oooooooo00001?oo
o`030000<ol0<ol001`co`000`000?ooooooo`1_oooo001noooo00?o09Woooooool01oooo`800005
oooo00<0000co`0co`0073?o00030000oooooooo06ooool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`006c?o00030000oooooooo073oool007koool00ol0VOooooooo`0>oooo00<0000co`0c
o`006c?o00030000oooooooo073oool007koool00ol0VOooooooo`0>oooo0P0001`co`000`000?oo
ooooo`1`oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1a
oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001n
oooo00?o09Woooooool03_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001noooo00?o
09Woooooool03_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001noooo00?o09Wooooo
ool03_ooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001noooo00?o09Woooooool03_oo
o`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001noooo00?o09Woooooool03_ooo`80000J
<ol000<0003oooooool0L_ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000H<ol000<0
003oooooool0Loooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000H<ol000<0003ooooo
ool0Loooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000H<ol000<0003oooooool0Looo
o`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00O_oo
o`03o`2Ioooooooo00koool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00O_ooo`03o`2I
oooooooo00koool2000063?o00030000oooooooo07Coool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`005c?o00030000oooooooo07Coool007koool00ol0VOooooooo`0>oooo00<0000co`0c
o`005S?o00030000oooooooo07Goool007koool00ol0VOooooooo`0>oooo00<0000co`0co`005S?o
00030000oooooooo07Goool007koool00ol0VOooooooo`0>oooo00<0000co`0co`005S?o00030000
oooooooo07Goool007koool00ol0VOooooooo`0>oooo00<0000co`0co`005C?o00030000oooooooo
07Koool007koool00ol0VOooooooo`0>oooo0P0001Hco`000`000?ooooooo`1foooo001noooo00?o
09Woooooool03_ooo`030000<ol0<ol001Dco`000`000?ooooooo`1foooo001noooo00?o09Wooooo
ool03_ooo`030000<ol0<ol001Dco`000`000?ooooooo`1foooo001noooo00?o09Woooooool03_oo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo001noooo00?o09Woooooool01oooo`800005
oooo00<0000co`0co`0053?o00030000oooooooo07Ooool007koool00ol0VOooooooo`06oooo00@0
003oooooool00004oooo00<0000co`0co`0053?o00030000oooooooo07Ooool007koool00ol0VOoo
ooooo`08oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool0N?ooo`00O_ooo`03o`2I
oooooooo00Woool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo07Soool0
07koool00ol0VOooooooo`06oooo00@0003oooooool00004oooo00<0000co`0co`004c?o00030000
oooooooo07Soool007koool00ol0VOooooooo`07oooo0P0000Goool00`0003?o03?o000B<ol000<0
003oooooool0NOooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000B<ol000<0003ooooo
ool0NOooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000B<ol000<0003oooooool0NOoo
o`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00O_oo
o`03o`2Ioooooooo00koool200004S?o00030000oooooooo07[oool007koool00ol0VOooooooo`0>
oooo00<0000co`0co`004C?o00030000oooooooo07[oool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`004C?o00030000oooooooo07[oool007koool00ol0VOooooooo`0>oooo00<0000co`0c
o`004C?o00030000oooooooo07[oool007koool00ol0VOooooooo`0>oooo00<0000co`0co`0043?o
00030000oooooooo07_oool007koool00ol0VOooooooo`0>oooo00<0000co`0co`0043?o00030000
oooooooo07_oool007koool00ol0VOooooooo`0>oooo0P00014co`000`000?ooooooo`1koooo001n
oooo00?o09Woooooool03_ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001noooo00?o
09Woooooool03_ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo001noooo00?o09Wooooo
ool03_ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo001noooo00?o09Woooooool03_oo
o`030000<ol0<ol000lco`000`000?ooooooo`1loooo001noooo00?o09Woooooool03_ooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo001noooo00?o09Woooooool03_ooo`80000@<ol000<0
003oooooool0O?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000><ol000<0003ooooo
ool0OOooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000><ol000<0003oooooool0OOoo
o`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000><ol000<0003oooooool0OOooo`00O_oo
o`03o`2Ioooooooo00koool00`0003?o03?o000><ol000<0003oooooool0OOooo`00O_ooo`03o`2I
oooooooo00koool00`0003?o03?o000><ol000<0003oooooool0OOooo`00O_ooo`03o`2Ioooooooo
00koool200003S?o00030000oooooooo07koool007koool00ol0VOooooooo`0>oooo00<0000co`0c
o`003C?o00030000oooooooo07koool007koool00ol0VOooooooo`0>oooo00<0000co`0co`003C?o
00030000oooooooo07koool007koool00ol0VOooooooo`0>oooo00<0000co`0co`003C?o00030000
oooooooo07koool007koool00ol0VOooooooo`0>oooo00<0000co`0co`0033?o00030000oooooooo
07ooool007koool00ol0VOooooooo`08oooo0`0000?oool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00O_ooo`03o`2Ioooooooo00Woool00`000?ooooooo`02oooo00<0000co`0co`0033?o
00030000oooooooo07ooool007koool00ol0VOooooooo`06oooo1@0000?oool3000033?o00030000
oooooooo07ooool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo0000
00Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22
oooo001foooo00<0003oooooool05_ooo`hco`0:oooo00<0003oooooool0M_ooo`00MOooo`030000
oooooooo00Soool00`000?ooooooo`0<oooo3S?o00_oool00`000?ooooooo`1eoooo001eoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`03<ol00000000000@co`0200000c?o
00D00003oooo0`0000;oool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool0100003?o03?o000000Xco`00
0`000?ooooooo`04oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo00;oool0
0`000?ooooooo`0Coooo00@0000co`0co`00000:<ol000@0003oooooooooool500000oooo`030000
oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000<ol0<ol000002S?o00050000
oooooooooooo000000;oool01@000?ooooooooooo`00001goooo001eoooo00D0003oooooooooool0
00005Oooo`040000<ol0<ol000002C?o0003oooo0000oooo00?oool00`000?ooo`000003oooo00<0
003oooooool0MOooo`00M_ooo`030000oooooooo01Koool00c?o00000000000:<ol00P0000Goool2
00000_ooo`030000oooooooo07Koool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.42237 .12361 L
.42781 .12361 L
.43298 .12361 L
.43522 .12361 L
.43646 .12361 L
.43762 .12361 L
s
.43762 .12361 m
.43788 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`05oooo00Go09Wooooo
ooooool000002oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo02Woool00ol0VOooooooo`0=
oooo00<0000co`0co`00>C?o00030000<ol0<ol003Hco`0500005oooo`00Ooooo`03o`2Ioooooooo
00goool00`0003?o03?o001Z<ol0200001coool007ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`00I3?o00H0000Toooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol005lco`050000:_oo
o`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o001J<ol01@0002ooool007ooool00ol0VOoo
ooooo`0=oooo0P0005Hco`050000=?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o001A
<ol0100003Woool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`00Cc?o0080000moooo001o
oooo00?o09Woooooool03Oooo`030000<ol0<ol004`co`030000?oooo`00Ooooo`03o`2Ioooooooo
00goool00`0003?o03?o001:<ol00P0004;oool007ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`00B3?o00800014oooo001ooooo00?o09Woooooool03Oooo`800017<ol00P0004Koool007ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`00A3?o00800018oooo001ooooo00?o09Woooooool03Ooo
o`030000<ol0<ol004<co`000`000?ooooooo`18oooo001ooooo00?o09Woooooool03Oooo`030000
<ol0<ol0044co`020000Boooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000o<ol00P00
04goool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`00?S?o00030000oooooooo04goool0
07ooool00ol0VOooooooo`0=oooo0P0003dco`020000D?ooo`00Ooooo`03o`2Ioooooooo00goool0
0`0003?o03?o000j<ol00P0005;oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`00>C?o
00030000oooooooo05;oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`00>3?o00030000
oooooooo05?oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`00=S?o0080001Foooo001o
oooo00?o09Woooooool03Oooo`030000<ol0<ol003Dco`000`000?ooooooo`1Foooo001ooooo00?o
09Woooooool03Oooo`80000e<ol000<0003oooooool0Eoooo`00Ooooo`03o`2Ioooooooo00goool0
0`0003?o03?o000c<ol000<0003oooooool0F?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o
03?o000b<ol000<0003oooooool0FOooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000a
<ol000<0003oooooool0F_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000a<ol000<0
003oooooool0F_ooo`00Ooooo`03o`2Ioooooooo00Goool500000oooo`030000<ol0<ol0030co`00
0`000?ooooooo`1Koooo001ooooo00?o09Woooooool01oooo`030000oooooooo00?oool00`0003?o
03?o000_<ol000<0003oooooool0G?ooo`00Ooooo`03o`2Ioooooooo00Ooool00`000?ooooooo`03
oooo0`0002hco`000`000?ooooooo`1Moooo001ooooo00?o09Woooooool01oooo`030000oooooooo
00?oool00`0003?o03?o000^<ol000<0003oooooool0GOooo`00Ooooo`03o`2Ioooooooo00Ooool0
0`000?ooooooo`03oooo00<0000co`0co`00;C?o00030000oooooooo05koool007ooool00ol0VOoo
ooooo`06oooo0P0000Goool00`0003?o03?o000/<ol000<0003oooooool0Goooo`00Ooooo`03o`2I
oooooooo00goool00`0003?o03?o000[<ol000<0003oooooool0H?ooo`00Ooooo`03o`2Ioooooooo
00goool00`0003?o03?o000[<ol000<0003oooooool0H?ooo`00Ooooo`03o`2Ioooooooo00goool2
0000:c?o00030000oooooooo067oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`00:C?o
00030000oooooooo06;oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`00:C?o00030000
oooooooo06;oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`00:3?o00030000oooooooo
06?oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`009c?o00030000oooooooo06Coool0
07ooool00ol0VOooooooo`0=oooo00<0000co`0co`009S?o00030000oooooooo06Goool007ooool0
0ol0VOooooooo`0=oooo0P0002Lco`000`000?ooooooo`1Uoooo001ooooo00?o09Woooooool03Ooo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001ooooo00?o09Woooooool03Oooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol0
02@co`000`000?ooooooo`1Woooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol002<co`00
0`000?ooooooo`1Xoooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol002<co`000`000?oo
ooooo`1Xoooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol0028co`000`000?ooooooo`1Y
oooo001ooooo00?o09Woooooool03Oooo`80000S<ol000<0003oooooool0JOooo`00Ooooo`03o`2I
oooooooo00goool00`0003?o03?o000Q<ol000<0003oooooool0J_ooo`00Ooooo`03o`2Ioooooooo
00goool00`0003?o03?o000Q<ol000<0003oooooool0J_ooo`00Ooooo`03o`2Ioooooooo00goool0
0`0003?o03?o000P<ol000<0003oooooool0Joooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o
03?o000P<ol000<0003oooooool0Joooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000P
<ol000<0003oooooool0Joooo`00Ooooo`03o`2Ioooooooo00goool2000083?o00030000oooooooo
06coool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`007c?o00030000oooooooo06coool0
07ooool00ol0VOooooooo`0=oooo00<0000co`0co`007S?o00030000oooooooo06goool007ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`007S?o00030000oooooooo06goool007ooool00ol0VOoo
ooooo`05oooo100000Coool00`0003?o03?o000N<ol000<0003oooooool0KOooo`00Ooooo`03o`2I
oooooooo00Goool00`000?ooooooo`05oooo00<0000co`0co`007C?o00030000oooooooo06koool0
07ooool00ol0VOooooooo`06oooo00<0003oooooool01?ooo`<0000M<ol000<0003oooooool0K_oo
o`00Ooooo`03o`2Ioooooooo00Ooool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000
oooooooo06koool007ooool00ol0VOooooooo`05oooo00@0003oooooool00004oooo00<0000co`0c
o`0073?o00030000oooooooo06ooool007ooool00ol0VOooooooo`06oooo0P0000Goool00`0003?o
03?o000L<ol000<0003oooooool0Koooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000K
<ol000<0003oooooool0L?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000K<ol000<0
003oooooool0L?ooo`00Ooooo`03o`2Ioooooooo00goool2000073?o00030000oooooooo073oool0
07ooool00ol0VOooooooo`0=oooo00<0000co`0co`006S?o00030000oooooooo077oool007ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`006S?o00030000oooooooo077oool007ooool00ol0VOoo
ooooo`0=oooo00<0000co`0co`006S?o00030000oooooooo077oool007ooool00ol0VOooooooo`0=
oooo00<0000co`0co`006S?o00030000oooooooo077oool007ooool00ol0VOooooooo`0=oooo00<0
000co`0co`006C?o00030000oooooooo07;oool007ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`006C?o00030000oooooooo07;oool007ooool00ol0VOooooooo`0=oooo0P0001Xco`000`000?oo
ooooo`1boooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo001o
oooo00?o09Woooooool03Oooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo001ooooo00?o
09Woooooool03Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001ooooo00?o09Wooooo
ool03Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001ooooo00?o09Woooooool03Ooo
o`80000H<ol000<0003oooooool0M?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000G
<ol000<0003oooooool0M?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000F<ol000<0
003oooooool0MOooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000F<ol000<0003ooooo
ool0MOooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000F<ol000<0003oooooool0MOoo
o`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000E<ol000<0003oooooool0M_ooo`00Oooo
o`03o`2Ioooooooo00goool200005S?o00030000oooooooo07Koool007ooool00ol0VOooooooo`0=
oooo00<0000co`0co`005C?o00030000oooooooo07Koool007ooool00ol0VOooooooo`0=oooo00<0
000co`0co`005C?o00030000oooooooo07Koool007ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool007ooool00ol0VOooooooo`06oooo0P0000Goool00`0003?o
03?o000D<ol000<0003oooooool0Moooo`00Ooooo`03o`2Ioooooooo00Goool010000?ooooooo`00
00Coool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00Ooooo`03o`2Ioooooooo00Ooool0
0`000?ooooooo`03oooo0`0001<co`000`000?ooooooo`1hoooo001ooooo00?o09Woooooool02?oo
o`030000oooooooo00;oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Ooooo`03o`2I
oooooooo00Goool010000?ooooooo`0000Coool00`0003?o03?o000C<ol000<0003oooooool0N?oo
o`00Ooooo`03o`2Ioooooooo00Koool200001Oooo`030000<ol0<ol0018co`000`000?ooooooo`1i
oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001o
oooo00?o09Woooooool03Oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001ooooo00?o
09Woooooool03Oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001ooooo00?o09Wooooo
ool03Oooo`80000B<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o
03?o000A<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000@<ol000<0003ooooo
ool0Noooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00Ooooo`03o`2Ioooooooo00goool200004C?o00030000oooooooo07_oool007ooool00ol0VOoo
ooooo`0=oooo00<0000co`0co`0043?o00030000oooooooo07_oool007ooool00ol0VOooooooo`0=
oooo00<0000co`0co`003c?o00030000oooooooo07coool007ooool00ol0VOooooooo`0=oooo00<0
000co`0co`003c?o00030000oooooooo07coool007ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`003c?o00030000oooooooo07coool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`003c?o
00030000oooooooo07coool007ooool00ol0VOooooooo`0=oooo0P00010co`000`000?ooooooo`1l
oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001o
oooo00?o09Woooooool03Oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001ooooo00?o
09Woooooool03Oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001ooooo00?o09Wooooo
ool03Oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001ooooo00?o09Woooooool03Ooo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo001ooooo00?o09Woooooool03Oooo`80000>
<ol000<0003oooooool0O_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000=<ol000<0
003oooooool0O_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000=<ol000<0003ooooo
ool0O_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000=<ol000<0003oooooool0O_oo
o`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Oooo
o`03o`2Ioooooooo00Ooool300000oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001o
oooo00?o09Woooooool02?ooo`030000oooooooo00;oool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00Ooooo`03o`2Ioooooooo00Goool500000oooo`<0000<<ol000<0003oooooool0Oooo
o`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?ooo`lco`22
oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool007Koool0
0`000?ooooooo`0Foooo3S?o00[oool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?oo
o`030000oooooooo00coool><ol02oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`0<oooo00<co`000000000013?o00800003<ol01@0000;oool2
00001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400000oooo`040000<ol0<ol000002S?o00050000oooooooo
oooo000000;oool01@000?ooooooooooo`00001goooo001doooo00<0003oooooool00_ooo`030000
oooooooo01?oool0100003?o03?o000000Xco`000`000?ooooooo`03oooo00<0003oooooool00ooo
o`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000<ol0<ol000002S?o
00030000oooooooo00Coool01@000?ooooooooooo`00001goooo001eoooo00D0003oooooooooool0
00005Oooo`040000<ol0<ol000002C?o0003oooo0000oooo00;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1eoooo001foooo00<0003oooooool05_ooo`03<ol00000000000Xco`0200001?oo
o`800003oooo00<0003oooooool0M_ooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44021 .12361 L
.44151 .12361 L
.44268 .12361 L
s
.44268 .12361 m
.44316 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`06oooo00Co09Wooooo
ool0000;oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Xco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000oooooooo
01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0:_ooo`03o`2Ioooooooo00coool0
0`0003?o03?o000i<ol000<0000co`0co`00=S?o00D0000Goooo0020oooo00?o09Woooooool03?oo
o`030000<ol0<ol006Xco`0800007?ooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o001T
<ol01P0002Coool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`00Gc?o00D0000Zoooo0020
oooo00?o09Woooooool03?ooo`030000<ol0<ol005Xco`050000;oooo`00P?ooo`03o`2Ioooooooo
00coool20000ES?o00D0000doooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol0054co`04
0000>Oooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o001?<ol00P0003goool0083oool0
0ol0VOooooooo`0<oooo00<0000co`0co`00C3?o00<0000ooooo0020oooo00?o09Woooooool03?oo
o`030000<ol0<ol004Xco`020000@_ooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o0018
<ol00P0004Coool0083oool00ol0VOooooooo`0<oooo0P0004Lco`020000A_ooo`00P?ooo`03o`2I
oooooooo00coool00`0003?o03?o0014<ol00P0004Soool0083oool00ol0VOooooooo`0<oooo00<0
000co`0co`00@c?o00030000oooooooo04Soool0083oool00ol0VOooooooo`0<oooo00<0000co`0c
o`00@C?o0080001;oooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol003lco`020000COoo
o`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000n<ol000<0003oooooool0COooo`00P?oo
o`03o`2Ioooooooo00coool20000?C?o0080001@oooo0020oooo00?o09Woooooool03?ooo`030000
<ol0<ol003Xco`020000D_ooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000i<ol000<0
003oooooool0D_ooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000h<ol000<0003ooooo
ool0Doooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000f<ol00P0005Koool0083oool0
0ol0VOooooooo`0<oooo00<0000co`0co`00=C?o00030000oooooooo05Koool0083oool00ol0VOoo
ooooo`0<oooo0P0003Dco`000`000?ooooooo`1Goooo0020oooo00?o09Woooooool03?ooo`030000
<ol0<ol003<co`000`000?ooooooo`1Hoooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol0
038co`000`000?ooooooo`1Ioooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol0034co`00
0`000?ooooooo`1Joooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol0034co`000`000?oo
ooooo`1Joooo0020oooo00?o09Woooooool01?ooo`D00003oooo00<0000co`0co`00<3?o00030000
oooooooo05_oool0083oool00ol0VOooooooo`06oooo00<0003oooooool00oooo`030000<ol0<ol0
02lco`000`000?ooooooo`1Loooo0020oooo00?o09Woooooool01_ooo`030000oooooooo00?oool3
0000;S?o00030000oooooooo05goool0083oool00ol0VOooooooo`06oooo00<0003oooooool00ooo
o`030000<ol0<ol002hco`000`000?ooooooo`1Moooo0020oooo00?o09Woooooool01_ooo`030000
oooooooo00?oool00`0003?o03?o000]<ol000<0003oooooool0G_ooo`00P?ooo`03o`2Ioooooooo
00Goool200001Oooo`030000<ol0<ol002`co`000`000?ooooooo`1Ooooo0020oooo00?o09Wooooo
ool03?ooo`030000<ol0<ol002/co`000`000?ooooooo`1Poooo0020oooo00?o09Woooooool03?oo
o`030000<ol0<ol002/co`000`000?ooooooo`1Poooo0020oooo00?o09Woooooool03?ooo`80000[
<ol000<0003oooooool0HOooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000Y<ol000<0
003oooooool0H_ooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000Y<ol000<0003ooooo
ool0H_ooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000X<ol000<0003oooooool0Hooo
o`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000W<ol000<0003oooooool0I?ooo`00P?oo
o`03o`2Ioooooooo00coool00`0003?o03?o000V<ol000<0003oooooool0IOooo`00P?ooo`03o`2I
oooooooo00coool200009c?o00030000oooooooo06Goool0083oool00ol0VOooooooo`0<oooo00<0
000co`0co`009C?o00030000oooooooo06Koool0083oool00ol0VOooooooo`0<oooo00<0000co`0c
o`0093?o00030000oooooooo06Ooool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`0093?o
00030000oooooooo06Ooool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`008c?o00030000
oooooooo06Soool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`008c?o00030000oooooooo
06Soool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`008S?o00030000oooooooo06Woool0
083oool00ol0VOooooooo`0<oooo0P0002<co`000`000?ooooooo`1Yoooo0020oooo00?o09Wooooo
ool03?ooo`030000<ol0<ol0024co`000`000?ooooooo`1Zoooo0020oooo00?o09Woooooool03?oo
o`030000<ol0<ol0024co`000`000?ooooooo`1Zoooo0020oooo00?o09Woooooool03?ooo`030000
<ol0<ol0020co`000`000?ooooooo`1[oooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol0
020co`000`000?ooooooo`1[oooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol0020co`00
0`000?ooooooo`1[oooo0020oooo00?o09Woooooool03?ooo`80000P<ol000<0003oooooool0K?oo
o`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000O<ol000<0003oooooool0K?ooo`00P?oo
o`03o`2Ioooooooo00coool00`0003?o03?o000N<ol000<0003oooooool0KOooo`00P?ooo`03o`2I
oooooooo00coool00`0003?o03?o000N<ol000<0003oooooool0KOooo`00P?ooo`03o`2Ioooooooo
00Coool400001?ooo`030000<ol0<ol001hco`000`000?ooooooo`1]oooo0020oooo00?o09Wooooo
ool01?ooo`030000oooooooo00Goool00`0003?o03?o000M<ol000<0003oooooool0K_ooo`00P?oo
o`03o`2Ioooooooo00Goool00`000?ooooooo`04oooo0`0001dco`000`000?ooooooo`1^oooo0021
oooo00?o09Woooooool01Oooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003ooooo
ool0K_ooo`00POooo`03o`2Ioooooooo00?oool010000?ooooooo`0000Coool00`0003?o03?o000L
<ol000<0003oooooool0Koooo`00POooo`03o`2Ioooooooo00Coool200001Oooo`030000<ol0<ol0
01`co`000`000?ooooooo`1_oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol001/co`00
0`000?ooooooo`1`oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo0021oooo00?o09Woooooool02oooo`80000L<ol000<0003oooooool0L?ooo`00POoo
o`03o`2Ioooooooo00_oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00POooo`03o`2I
oooooooo00_oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00POooo`03o`2Ioooooooo
00_oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00POooo`03o`2Ioooooooo00_oool0
0`0003?o03?o000J<ol000<0003oooooool0LOooo`00POooo`03o`2Ioooooooo00_oool00`0003?o
03?o000I<ol000<0003oooooool0L_ooo`00POooo`03o`2Ioooooooo00_oool00`0003?o03?o000I
<ol000<0003oooooool0L_ooo`00POooo`03o`2Ioooooooo00_oool200006S?o00030000oooooooo
07;oool0087oool00ol0VOooooooo`0;oooo00<0000co`0co`0063?o00030000oooooooo07?oool0
087oool00ol0VOooooooo`0;oooo00<0000co`0co`0063?o00030000oooooooo07?oool0087oool0
0ol0VOooooooo`0;oooo00<0000co`0co`0063?o00030000oooooooo07?oool0087oool00ol0VOoo
ooooo`0;oooo00<0000co`0co`005c?o00030000oooooooo07Coool0087oool00ol0VOooooooo`0;
oooo00<0000co`0co`005c?o00030000oooooooo07Coool0087oool00ol0VOooooooo`0;oooo0P00
01Pco`000`000?ooooooo`1doooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol001Lco`00
0`000?ooooooo`1doooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol001Hco`000`000?ooooooo`1eoooo0021
oooo00?o09Woooooool02oooo`030000<ol0<ol001Dco`000`000?ooooooo`1foooo0021oooo00?o
09Woooooool02oooo`80000F<ol000<0003oooooool0M_ooo`00POooo`03o`2Ioooooooo00_oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00POooo`03o`2Ioooooooo00_oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00POooo`03o`2Ioooooooo00_oool00`0003?o03?o000D
<ol000<0003oooooool0Moooo`00POooo`03o`2Ioooooooo00Coool200001Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo0021oooo00?o09Woooooool00oooo`040000oooooooo00001?oo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo0021oooo00?o09Woooooool01Oooo`030000
oooooooo00?oool300004c?o00030000oooooooo07Soool0087oool00ol0VOooooooo`06oooo00<0
003oooooool00_ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo0021oooo00?o09Wooooo
ool00oooo`040000oooooooo00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo0021
oooo00?o09Woooooool01?ooo`800005oooo00<0000co`0co`004S?o00030000oooooooo07Woool0
087oool00ol0VOooooooo`0;oooo00<0000co`0co`004S?o00030000oooooooo07Woool0087oool0
0ol0VOooooooo`0;oooo00<0000co`0co`004S?o00030000oooooooo07Woool0087oool00ol0VOoo
ooooo`0;oooo00<0000co`0co`004S?o00030000oooooooo07Woool0087oool00ol0VOooooooo`0;
oooo0P00018co`000`000?ooooooo`1joooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol0014co`00
0`000?ooooooo`1joooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol0014co`000`000?oo
ooooo`1joooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo0021
oooo00?o09Woooooool02oooo`80000A<ol000<0003oooooool0Noooo`00POooo`03o`2Ioooooooo
00_oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00POooo`03o`2Ioooooooo00_oool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00POooo`03o`2Ioooooooo00_oool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00POooo`03o`2Ioooooooo00_oool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00POooo`03o`2Ioooooooo00_oool00`0003?o03?o000?<ol000<0
003oooooool0O?ooo`00POooo`03o`2Ioooooooo00_oool2000043?o00030000oooooooo07coool0
087oool00ol0VOooooooo`0;oooo00<0000co`0co`003S?o00030000oooooooo07goool0087oool0
0ol0VOooooooo`0;oooo00<0000co`0co`003S?o00030000oooooooo07goool0087oool00ol0VOoo
ooooo`0;oooo00<0000co`0co`003S?o00030000oooooooo07goool0087oool00ol0VOooooooo`0;
oooo00<0000co`0co`003S?o00030000oooooooo07goool0087oool00ol0VOooooooo`0;oooo00<0
000co`0co`003S?o00030000oooooooo07goool0087oool00ol0VOooooooo`0;oooo0P0000hco`00
0`000?ooooooo`1noooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1noooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000dco`000`000?ooooooo`1n
oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo0021
oooo00?o09Woooooool02oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0021oooo00?o
09Woooooool01Oooo`<00003oooo00<0000co`0co`0033?o00030000oooooooo07ooool0087oool0
0ol0VOooooooo`06oooo00<0003oooooool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo0021oooo00?o09Woooooool00oooo`D00003oooo0`0000`co`000`000?ooooooo`1ooooo0027
oooo00@0003oooooool00004oooo3c?o08;oool008Soool00`000?ooo`000004oooo3c?o08;oool0
08Woool200001?ooo`lco`22oooo002?oooo3c?o08;oool008ooool?<ol0P_ooo`00M_ooo`030000
oooooooo01Koool><ol02_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0
003oooooool03?ooo`hco`0;oooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00coool00c?o000000000004<ol00P0000<co`05000000?oool00000
00000P0000?oool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool0100003?o03?o000000Xco`001@000?oo
ooooooooo`000006oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo00;oool00`000?oo
ooooo`0Coooo00@0000co`0co`00000:<ol000<0003oooooool00_ooo`030000oooooooo00Coool0
0`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool0100003?o03?o000000Xco`00
0`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo07Goool007Goool01@000?oo
ooooooooo`00000Eoooo00@0000co`0co`000009<ol000?oool0003oool00_ooo`040000oooooooo
00000oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Foooo00<co`00000000002S?o
00800004oooo0P0000?oool00`000?ooooooo`1foooo002?oooo3C?o08Coool008ooool=<ol0Q?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44268 .12361 L
.44498 .12361 L
.44625 .12361 L
.44744 .12361 L
s
.44744 .12361 m
.44771 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`08oooo00?o09T0003o
ool02_ooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo02coool00ol0VOooooooo`0:oooo00<0
000co`0co`00>C?o00030000<ol0<ol003Hco`0500005oooo`00P_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o001Z<ol0200001coool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`00I3?o
00H0000Toooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol005lco`050000:_ooo`00P_oo
o`03o`2Ioooooooo00[oool00`0003?o03?o001J<ol01@0002ooool008;oool00ol0VOooooooo`0:
oooo0P0005Hco`050000=?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o001A<ol01000
03Woool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`00Cc?o0080000moooo0022oooo00?o
09Woooooool02_ooo`030000<ol0<ol004`co`030000?oooo`00P_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o001:<ol00P0004;oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`00B3?o
00800014oooo0022oooo00?o09Woooooool02_ooo`800017<ol00P0004Koool008;oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`00A3?o00800018oooo0022oooo00?o09Woooooool02_ooo`030000
<ol0<ol004<co`000`000?ooooooo`18oooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol0
044co`020000Boooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000o<ol00P0004goool0
08;oool00ol0VOooooooo`0:oooo00<0000co`0co`00?S?o00030000oooooooo04goool008;oool0
0ol0VOooooooo`0:oooo0P0003dco`020000D?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o
03?o000j<ol00P0005;oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`00>C?o00030000
oooooooo05;oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`00>3?o00030000oooooooo
05?oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`00=S?o0080001Foooo0022oooo00?o
09Woooooool02_ooo`030000<ol0<ol003Dco`000`000?ooooooo`1Foooo0022oooo00?o09Wooooo
ool02_ooo`80000e<ol000<0003oooooool0Eoooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o
03?o000c<ol000<0003oooooool0F?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000b
<ol000<0003oooooool0FOooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000a<ol000<0
003oooooool0F_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000a<ol000<0003ooooo
ool0F_ooo`00P_ooo`03o`2Ioooooooo00;oool500000oooo`030000<ol0<ol0030co`000`000?oo
ooooo`1Koooo0022oooo00?o09Woooooool01?ooo`030000oooooooo00?oool00`0003?o03?o000_
<ol000<0003oooooool0G?ooo`00P_ooo`03o`2Ioooooooo00Coool00`000?ooooooo`03oooo0`00
02hco`000`000?ooooooo`1Moooo0022oooo00?o09Woooooool01?ooo`030000oooooooo00?oool0
0`0003?o03?o000^<ol000<0003oooooool0GOooo`00P_ooo`03o`2Ioooooooo00Coool00`000?oo
ooooo`03oooo00<0000co`0co`00;C?o00030000oooooooo05koool008;oool00ol0VOooooooo`03
oooo0P0000Goool00`0003?o03?o000/<ol000<0003oooooool0Goooo`00P_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o000[<ol000<0003oooooool0H?ooo`00P_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o000[<ol000<0003oooooool0H?ooo`00P_ooo`03o`2Ioooooooo00[oool20000:c?o
00030000oooooooo067oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`00:C?o00030000
oooooooo06;oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`00:C?o00030000oooooooo
06;oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`00:3?o00030000oooooooo06?oool0
08;oool00ol0VOooooooo`0:oooo00<0000co`0co`009c?o00030000oooooooo06Coool008;oool0
0ol0VOooooooo`0:oooo00<0000co`0co`009S?o00030000oooooooo06Goool008;oool00ol0VOoo
ooooo`0:oooo0P0002Lco`000`000?ooooooo`1Uoooo0022oooo00?o09Woooooool02_ooo`030000
<ol0<ol002Dco`000`000?ooooooo`1Voooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol0
02@co`000`000?ooooooo`1Woooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol002@co`00
0`000?ooooooo`1Woooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol002<co`000`000?oo
ooooo`1Xoooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol002<co`000`000?ooooooo`1X
oooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol0028co`000`000?ooooooo`1Yoooo0022
oooo00?o09Woooooool02_ooo`80000S<ol000<0003oooooool0JOooo`00P_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o000Q<ol000<0003oooooool0J_ooo`00P_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o000Q<ol000<0003oooooool0J_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o
03?o000P<ol000<0003oooooool0Joooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000P
<ol000<0003oooooool0Joooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000P<ol000<0
003oooooool0Joooo`00P_ooo`03o`2Ioooooooo00[oool2000083?o00030000oooooooo06coool0
08;oool00ol0VOooooooo`0:oooo00<0000co`0co`007c?o00030000oooooooo06coool008;oool0
0ol0VOooooooo`0:oooo00<0000co`0co`007S?o00030000oooooooo06goool008;oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`007S?o00030000oooooooo06goool008;oool00ol0VOooooooo`02
oooo100000Coool00`0003?o03?o000N<ol000<0003oooooool0KOooo`00P_ooo`03o`2Ioooooooo
00;oool00`000?ooooooo`05oooo00<0000co`0co`007C?o00030000oooooooo06koool008;oool0
0ol0VOooooooo`03oooo00<0003oooooool01?ooo`<0000M<ol000<0003oooooool0K_ooo`00P_oo
o`03o`2Ioooooooo00Coool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo
06koool008;oool00ol0VOooooooo`02oooo00@0003oooooool00004oooo00<0000co`0co`0073?o
00030000oooooooo06ooool008;oool00ol0VOooooooo`03oooo0P0000Goool00`0003?o03?o000L
<ol000<0003oooooool0Koooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000K<ol000<0
003oooooool0L?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000K<ol000<0003ooooo
ool0L?ooo`00P_ooo`03o`2Ioooooooo00[oool2000073?o00030000oooooooo073oool008;oool0
0ol0VOooooooo`0:oooo00<0000co`0co`006S?o00030000oooooooo077oool008;oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`006S?o00030000oooooooo077oool008;oool00ol0VOooooooo`0:
oooo00<0000co`0co`006S?o00030000oooooooo077oool008;oool00ol0VOooooooo`0:oooo00<0
000co`0co`006S?o00030000oooooooo077oool008;oool00ol0VOooooooo`0:oooo00<0000co`0c
o`006C?o00030000oooooooo07;oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`006C?o
00030000oooooooo07;oool008;oool00ol0VOooooooo`0:oooo0P0001Xco`000`000?ooooooo`1b
oooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo0022
oooo00?o09Woooooool02_ooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo0022oooo00?o
09Woooooool02_ooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo0022oooo00?o09Wooooo
ool02_ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0022oooo00?o09Woooooool02_oo
o`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0022oooo00?o09Woooooool02_ooo`80000H
<ol000<0003oooooool0M?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000F<ol000<0003ooooo
ool0MOooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000F<ol000<0003oooooool0MOoo
o`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00P_oo
o`03o`2Ioooooooo00[oool00`0003?o03?o000E<ol000<0003oooooool0M_ooo`00P_ooo`03o`2I
oooooooo00[oool200005S?o00030000oooooooo07Koool008;oool00ol0VOooooooo`0:oooo00<0
000co`0co`005C?o00030000oooooooo07Koool008;oool00ol0VOooooooo`0:oooo00<0000co`0c
o`005C?o00030000oooooooo07Koool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`0053?o
00030000oooooooo07Ooool008;oool00ol0VOooooooo`03oooo0P0000Goool00`0003?o03?o000D
<ol000<0003oooooool0Moooo`00P_ooo`03o`2Ioooooooo00;oool010000?ooooooo`0000Coool0
0`0003?o03?o000D<ol000<0003oooooool0Moooo`00P_ooo`03o`2Ioooooooo00Coool00`000?oo
ooooo`03oooo0`0001<co`000`000?ooooooo`1hoooo0022oooo00?o09Woooooool01Oooo`030000
oooooooo00;oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00P_ooo`03o`2Ioooooooo
00;oool010000?ooooooo`0000Coool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00P_oo
o`03o`2Ioooooooo00?oool200001Oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0022
oooo00?o09Woooooool02_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0022oooo00?o
09Woooooool02_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0022oooo00?o09Wooooo
ool02_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0022oooo00?o09Woooooool02_oo
o`80000B<ol000<0003oooooool0N_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00P_oo
o`03o`2Ioooooooo00[oool200004C?o00030000oooooooo07_oool008;oool00ol0VOooooooo`0:
oooo00<0000co`0co`0043?o00030000oooooooo07_oool008;oool00ol0VOooooooo`0:oooo00<0
000co`0co`003c?o00030000oooooooo07coool008;oool00ol0VOooooooo`0:oooo00<0000co`0c
o`003c?o00030000oooooooo07coool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`003c?o
00030000oooooooo07coool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`003c?o00030000
oooooooo07coool008;oool00ol0VOooooooo`0:oooo0P00010co`000`000?ooooooo`1loooo0022
oooo00?o09Woooooool02_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0022oooo00?o
09Woooooool02_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0022oooo00?o09Wooooo
ool02_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0022oooo00?o09Woooooool02_oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo0022oooo00?o09Woooooool02_ooo`030000
<ol0<ol000hco`000`000?ooooooo`1moooo0022oooo00?o09Woooooool02_ooo`80000><ol000<0
003oooooool0O_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000=<ol000<0003ooooo
ool0O_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000=<ol000<0003oooooool0O_oo
o`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00P_oo
o`03o`2Ioooooooo00[oool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00P_ooo`03o`2I
oooooooo00Coool300000oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0022oooo00?o
09Woooooool01Oooo`030000oooooooo00;oool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00P_ooo`03o`2Ioooooooo00;oool500000oooo`<0000<<ol000<0003oooooool0Ooooo`00Qooo
o`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?ooo`lco`22oooo0029
oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool007Koool00`000?oo
ooooo`0Foooo3S?o00[oool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000
oooooooo00coool><ol02oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0<oooo00<co`000000000013?o00800003<ol01@000003oooo00000000
00<00002oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0000co`0co`00000:<ol000<0003ooooo
ool00oooo`030000oooooooo00;oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_oo
o`030000oooooooo01?oool0100003?o03?o000000Xco`000`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000<ol0<ol0
00002S?o00030000oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool0MOooo`00MOoo
o`050000oooooooooooo000001Goool0100003?o03?o000000Tco`000oooo`000?ooo`04oooo00<0
003oooooool00_ooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Foooo00<co`000000
00002S?o00800004oooo0P0000?oool00`000?ooooooo`1foooo002?oooo3C?o08Coool008ooool=
<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44268 .12361 L
.44744 .12361 L
.44874 .12361 L
.45013 .12361 L
.45143 .12361 L
s
.45143 .12361 m
.45191 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo02goool00ol0VOooooooo`09oooo00<0
000co`0co`00>C?o00030000<ol0<ol003Hco`0500005oooo`00Poooo`03o`2Ioooooooo00Woool0
0`0003?o03?o001Z<ol0200001coool008?oool00ol0VOooooooo`09oooo00<0000co`0co`00I3?o
00H0000Toooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol005lco`050000:_ooo`00Pooo
o`03o`2Ioooooooo00Woool00`0003?o03?o001J<ol01@0002ooool008?oool00ol0VOooooooo`09
oooo0P0005Hco`050000=?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o001A<ol01000
03Woool008?oool00ol0VOooooooo`09oooo00<0000co`0co`00Cc?o0080000moooo0023oooo00?o
09Woooooool02Oooo`030000<ol0<ol004`co`030000?oooo`00Poooo`03o`2Ioooooooo00Woool0
0`0003?o03?o001:<ol00P0004;oool008?oool00ol0VOooooooo`09oooo00<0000co`0co`00B3?o
00800014oooo0023oooo00?o09Woooooool02Oooo`800017<ol00P0004Koool008?oool00ol0VOoo
ooooo`09oooo00<0000co`0co`00A3?o00800018oooo0023oooo00?o09Woooooool02Oooo`030000
<ol0<ol004<co`000`000?ooooooo`18oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol0
044co`020000Boooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000o<ol00P0004goool0
08?oool00ol0VOooooooo`09oooo00<0000co`0co`00?S?o00030000oooooooo04goool008?oool0
0ol0VOooooooo`09oooo0P0003dco`020000D?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o
03?o000j<ol00P0005;oool008?oool00ol0VOooooooo`09oooo00<0000co`0co`00>C?o00030000
oooooooo05;oool008?oool00ol0VOooooooo`09oooo00<0000co`0co`00>3?o00030000oooooooo
05?oool008?oool00ol0VOooooooo`09oooo00<0000co`0co`00=S?o0080001Foooo0023oooo00?o
09Woooooool02Oooo`030000<ol0<ol003Dco`000`000?ooooooo`1Foooo0023oooo00?o09Wooooo
ool02Oooo`80000e<ol000<0003oooooool0Eoooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o
03?o000c<ol000<0003oooooool0F?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000b
<ol000<0003oooooool0FOooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000a<ol000<0
003oooooool0F_ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000a<ol000<0003ooooo
ool0F_ooo`00Poooo`04o`2Ioooooooooooo1@0000?oool00`0003?o03?o000`<ol000<0003ooooo
ool0Foooo`00Poooo`03o`2Ioooooooo00?oool00`000?ooooooo`03oooo00<0000co`0co`00;c?o
00030000oooooooo05coool008?oool00ol0VOooooooo`03oooo00<0003oooooool00oooo`<0000^
<ol000<0003oooooool0GOooo`00Poooo`03o`2Ioooooooo00?oool00`000?ooooooo`03oooo00<0
000co`0co`00;S?o00030000oooooooo05goool008?oool00ol0VOooooooo`03oooo00<0003ooooo
ool00oooo`030000<ol0<ol002dco`000`000?ooooooo`1Noooo0023oooo00?o09Woooooool00_oo
o`800005oooo00<0000co`0co`00;3?o00030000oooooooo05ooool008?oool00ol0VOooooooo`09
oooo00<0000co`0co`00:c?o00030000oooooooo063oool008?oool00ol0VOooooooo`09oooo00<0
000co`0co`00:c?o00030000oooooooo063oool008?oool00ol0VOooooooo`09oooo0P0002/co`00
0`000?ooooooo`1Qoooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol002Tco`000`000?oo
ooooo`1Roooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol002Tco`000`000?ooooooo`1R
oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol002Pco`000`000?ooooooo`1Soooo0023
oooo00?o09Woooooool02Oooo`030000<ol0<ol002Lco`000`000?ooooooo`1Toooo0023oooo00?o
09Woooooool02Oooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo0023oooo00?o09Wooooo
ool02Oooo`80000W<ol000<0003oooooool0IOooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o
03?o000U<ol000<0003oooooool0I_ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000T
<ol000<0003oooooool0Ioooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000S<ol000<0003ooooo
ool0J?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000S<ol000<0003oooooool0J?oo
o`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000R<ol000<0003oooooool0JOooo`00Pooo
o`03o`2Ioooooooo00Woool200008c?o00030000oooooooo06Woool008?oool00ol0VOooooooo`09
oooo00<0000co`0co`008C?o00030000oooooooo06[oool008?oool00ol0VOooooooo`09oooo00<0
000co`0co`008C?o00030000oooooooo06[oool008?oool00ol0VOooooooo`09oooo00<0000co`0c
o`0083?o00030000oooooooo06_oool008?oool00ol0VOooooooo`09oooo00<0000co`0co`0083?o
00030000oooooooo06_oool008?oool00ol0VOooooooo`09oooo00<0000co`0co`0083?o00030000
oooooooo06_oool008?oool00ol0VOooooooo`09oooo0P00020co`000`000?ooooooo`1/oooo0023
oooo00?o09Woooooool02Oooo`030000<ol0<ol001lco`000`000?ooooooo`1/oooo0023oooo00?o
09Woooooool02Oooo`030000<ol0<ol001hco`000`000?ooooooo`1]oooo0023oooo00?o09Wooooo
ool02Oooo`030000<ol0<ol001hco`000`000?ooooooo`1]oooo0023oooo00Co09Woooooooooool4
00001?ooo`030000<ol0<ol001hco`000`000?ooooooo`1]oooo0023oooo00Go09Woooooooooool0
00001oooo`030000<ol0<ol001dco`000`000?ooooooo`1^oooo0023oooo00?o09Woooooool00_oo
o`030000oooooooo00Coool300007C?o00030000oooooooo06koool008?oool00ol0VOooooooo`03
oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`1^oooo0023oooo00Go
09Woooooooooool000000_ooo`030000oooooooo00;oool00`0003?o03?o000L<ol000<0003ooooo
ool0Koooo`00Poooo`03o`2Ioooooooo00;oool200001Oooo`030000<ol0<ol001`co`000`000?oo
ooooo`1_oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol001/co`000`000?ooooooo`1`oooo0023
oooo00?o09Woooooool02Oooo`80000L<ol000<0003oooooool0L?ooo`00Poooo`03o`2Ioooooooo
00Woool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00Poooo`03o`2Ioooooooo00Woool0
0`0003?o03?o000J<ol000<0003oooooool0LOooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o
03?o000J<ol000<0003oooooool0LOooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000J
<ol000<0003oooooool0LOooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000I<ol000<0
003oooooool0L_ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000I<ol000<0003ooooo
ool0L_ooo`00Poooo`03o`2Ioooooooo00Woool200006S?o00030000oooooooo07;oool008?oool0
0ol0VOooooooo`09oooo00<0000co`0co`0063?o00030000oooooooo07?oool008?oool00ol0VOoo
ooooo`09oooo00<0000co`0co`0063?o00030000oooooooo07?oool008?oool00ol0VOooooooo`09
oooo00<0000co`0co`0063?o00030000oooooooo07?oool008?oool00ol0VOooooooo`09oooo00<0
000co`0co`005c?o00030000oooooooo07Coool008?oool00ol0VOooooooo`09oooo00<0000co`0c
o`005c?o00030000oooooooo07Coool008?oool00ol0VOooooooo`09oooo0P0001Pco`000`000?oo
ooooo`1doooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1d
oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol001Hco`000`000?ooooooo`1eoooo0023
oooo00?o09Woooooool02Oooo`030000<ol0<ol001Hco`000`000?ooooooo`1eoooo0023oooo00?o
09Woooooool02Oooo`030000<ol0<ol001Hco`000`000?ooooooo`1eoooo0023oooo00?o09Wooooo
ool02Oooo`030000<ol0<ol001Dco`000`000?ooooooo`1foooo0023oooo00?o09Woooooool02Ooo
o`80000F<ol000<0003oooooool0M_ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000E
<ol000<0003oooooool0M_ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000E<ol000<0
003oooooool0M_ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000D<ol000<0003ooooo
ool0Moooo`00Poooo`03o`2Ioooooooo00;oool200001Oooo`030000<ol0<ol001@co`000`000?oo
ooooo`1goooo0023oooo00Go09Woooooooooool000000_ooo`030000oooooooo00;oool00`0003?o
03?o000D<ol000<0003oooooool0Moooo`00Poooo`03o`2Ioooooooo00?oool00`000?ooooooo`03
oooo0`0001<co`000`000?ooooooo`1hoooo0023oooo00?o09Woooooool01?ooo`030000oooooooo
00;oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Poooo`05o`2Ioooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo07Soool008?oool0
0ol0VOooooooo`02oooo0P0000Goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Pooo
o`03o`2Ioooooooo00Woool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Poooo`03o`2I
oooooooo00Woool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Poooo`03o`2Ioooooooo
00Woool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Poooo`03o`2Ioooooooo00Woool2
00004S?o00030000oooooooo07[oool008?oool00ol0VOooooooo`09oooo00<0000co`0co`004C?o
00030000oooooooo07[oool008?oool00ol0VOooooooo`09oooo00<0000co`0co`004C?o00030000
oooooooo07[oool008?oool00ol0VOooooooo`09oooo00<0000co`0co`004C?o00030000oooooooo
07[oool008?oool00ol0VOooooooo`09oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
08?oool00ol0VOooooooo`09oooo00<0000co`0co`0043?o00030000oooooooo07_oool008?oool0
0ol0VOooooooo`09oooo0P00014co`000`000?ooooooo`1koooo0023oooo00?o09Woooooool02Ooo
o`030000<ol0<ol0010co`000`000?ooooooo`1koooo0023oooo00?o09Woooooool02Oooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo0023oooo00?o09Woooooool02Oooo`80000@<ol000<0003oooooool0O?ooo`00Pooo
o`03o`2Ioooooooo00Woool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Poooo`03o`2I
oooooooo00Woool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Poooo`03o`2Ioooooooo
00Woool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Poooo`03o`2Ioooooooo00Woool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o
03?o000><ol000<0003oooooool0OOooo`00Poooo`03o`2Ioooooooo00Woool200003S?o00030000
oooooooo07koool008?oool00ol0VOooooooo`09oooo00<0000co`0co`003C?o00030000oooooooo
07koool008?oool00ol0VOooooooo`09oooo00<0000co`0co`003C?o00030000oooooooo07koool0
08?oool00ol0VOooooooo`09oooo00<0000co`0co`003C?o00030000oooooooo07koool008?oool0
0ol0VOooooooo`09oooo00<0000co`0co`0033?o00030000oooooooo07ooool008?oool00ol0VOoo
ooooo`03oooo0`0000?oool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Poooo`03o`2I
oooooooo00Coool00`000?ooooooo`02oooo00<0000co`0co`0033?o00030000oooooooo07ooool0
08?oool01?l0VOooooooooooo`D00003oooo0`0000`co`000`000?ooooooo`1ooooo0027oooo00@0
003oooooool00004oooo3c?o08;oool008Soool00`000?ooo`000004oooo3c?o08;oool008Woool2
00001?ooo`lco`22oooo002?oooo3c?o08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo
01?oool><ol01oooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`hco`08oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Woool4<ol00P0000@co`0200000S?o0003oooo0000000000<00002oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01?ooo`@00003<ol000@0000co`0co`000007<ol00oooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo013oool3<ol000@0
000co`0co`000007<ol00oooo`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000ooool3<ol000@0000co`0co`000007<ol00oooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000004_ooo`<co`00100003?o03?o0000
00Hco`04oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Woool00`000?ooooooo`0C
oooo13?o00800007<ol00oooo`800003oooo00<0003oooooool0NOooo`00Soooo`dco`24oooo002?
oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.44268 .12361 L
.44778 .12361 L
.45262 .12361 L
.45473 .12361 L
.45588 .12361 L
.45697 .12361 L
s
.45697 .12361 m
.45749 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003o09Wo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo02koool00ol0VOooooooo`08oooo00<0
000co`0co`00>C?o00030000<ol0<ol003Hco`0500005oooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o001Z<ol0200001coool008Coool00ol0VOooooooo`08oooo00<0000co`0co`00I3?o
00H0000Toooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol005lco`050000:_ooo`00Q?oo
o`03o`2Ioooooooo00Soool00`0003?o03?o001J<ol01@0002ooool008Coool00ol0VOooooooo`08
oooo0P0005Hco`050000=?ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o001A<ol01000
03Woool008Coool00ol0VOooooooo`08oooo00<0000co`0co`00Cc?o0080000moooo0024oooo00?o
09Woooooool02?ooo`030000<ol0<ol004`co`030000?oooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o001:<ol00P0004;oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`00B3?o
00800014oooo0024oooo00?o09Woooooool02?ooo`800017<ol00P0004Koool008Coool00ol0VOoo
ooooo`08oooo00<0000co`0co`00A3?o00800018oooo0024oooo00?o09Woooooool02?ooo`030000
<ol0<ol004<co`000`000?ooooooo`18oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol0
044co`020000Boooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000o<ol00P0004goool0
08Coool00ol0VOooooooo`08oooo00<0000co`0co`00?S?o00030000oooooooo04goool008Coool0
0ol0VOooooooo`08oooo0P0003dco`020000D?ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o
03?o000j<ol00P0005;oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`00>C?o00030000
oooooooo05;oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`00>3?o00030000oooooooo
05?oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`00=S?o0080001Foooo0024oooo00?o
09Woooooool02?ooo`030000<ol0<ol003Dco`000`000?ooooooo`1Foooo0024oooo00?o09Wooooo
ool02?ooo`80000e<ol000<0003oooooool0Eoooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o
03?o000c<ol000<0003oooooool0F?ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000b
<ol000<0003oooooool0FOooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000a<ol000<0
003oooooool0F_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000a<ol000<0003ooooo
ool0F_ooo`00Q?ooo`03o`2Ioooooooo00D00003oooo00<0000co`0co`00<3?o00030000oooooooo
05_oool008Coool00ol0VOooooooo`02oooo00<0003oooooool00oooo`030000<ol0<ol002lco`00
0`000?ooooooo`1Loooo0024oooo00?o09Woooooool00_ooo`030000oooooooo00?oool30000;S?o
00030000oooooooo05goool008Coool00ol0VOooooooo`02oooo00<0003oooooool00oooo`030000
<ol0<ol002hco`000`000?ooooooo`1Moooo0024oooo00?o09Woooooool00_ooo`030000oooooooo
00?oool00`0003?o03?o000]<ol000<0003oooooool0G_ooo`00Q?ooo`04o`2Ioooooooooooo0P00
00Goool00`0003?o03?o000/<ol000<0003oooooool0Goooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o000[<ol000<0003oooooool0H?ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o
03?o000[<ol000<0003oooooool0H?ooo`00Q?ooo`03o`2Ioooooooo00Soool20000:c?o00030000
oooooooo067oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`00:C?o00030000oooooooo
06;oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`00:C?o00030000oooooooo06;oool0
08Coool00ol0VOooooooo`08oooo00<0000co`0co`00:3?o00030000oooooooo06?oool008Coool0
0ol0VOooooooo`08oooo00<0000co`0co`009c?o00030000oooooooo06Coool008Coool00ol0VOoo
ooooo`08oooo00<0000co`0co`009S?o00030000oooooooo06Goool008Coool00ol0VOooooooo`08
oooo0P0002Lco`000`000?ooooooo`1Uoooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol0
02Dco`000`000?ooooooo`1Voooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol002@co`00
0`000?ooooooo`1Woooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol002@co`000`000?oo
ooooo`1Woooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol002<co`000`000?ooooooo`1X
oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol002<co`000`000?ooooooo`1Xoooo0024
oooo00?o09Woooooool02?ooo`030000<ol0<ol0028co`000`000?ooooooo`1Yoooo0024oooo00?o
09Woooooool02?ooo`80000S<ol000<0003oooooool0JOooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o000Q<ol000<0003oooooool0J_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o
03?o000Q<ol000<0003oooooool0J_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000P
<ol000<0003oooooool0Joooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000P<ol000<0
003oooooool0Joooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000P<ol000<0003ooooo
ool0Joooo`00Q?ooo`03o`2Ioooooooo00Soool2000083?o00030000oooooooo06coool008Coool0
0ol0VOooooooo`08oooo00<0000co`0co`007c?o00030000oooooooo06coool008Coool00ol0VOoo
ooooo`08oooo00<0000co`0co`007S?o00030000oooooooo06goool008Coool00ol0VOooooooo`08
oooo00<0000co`0co`007S?o00030000oooooooo06goool008Coool00ol0VOooooooo`0400001?oo
o`030000<ol0<ol001hco`000`000?ooooooo`1]oooo0024oooo00Co09Woooooool00007oooo00<0
000co`0co`007C?o00030000oooooooo06koool008Coool01Ol0VOooooooooooo`000006oooo0`00
01dco`000`000?ooooooo`1^oooo0024oooo00?o09Woooooool00_ooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool0K_ooo`00Q?ooo`04o`2Ioooooooo00000_ooo`030000
oooooooo00;oool00`0003?o03?o000L<ol000<0003oooooool0Koooo`00Q?ooo`04o`2Ioooooooo
oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool0Koooo`00Q?ooo`03o`2Ioooooooo
00Soool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Q?ooo`03o`2Ioooooooo00Soool2000073?o
00030000oooooooo073oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`006S?o00030000
oooooooo077oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`006S?o00030000oooooooo
077oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`006S?o00030000oooooooo077oool0
08Coool00ol0VOooooooo`08oooo00<0000co`0co`006S?o00030000oooooooo077oool008Coool0
0ol0VOooooooo`08oooo00<0000co`0co`006C?o00030000oooooooo07;oool008Coool00ol0VOoo
ooooo`08oooo00<0000co`0co`006C?o00030000oooooooo07;oool008Coool00ol0VOooooooo`08
oooo0P0001Xco`000`000?ooooooo`1boooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol0
01Pco`000`000?ooooooo`1coooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1coooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1d
oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0024
oooo00?o09Woooooool02?ooo`80000H<ol000<0003oooooool0M?ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o000F<ol000<0003oooooool0MOooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o
03?o000F<ol000<0003oooooool0MOooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000E<ol000<0
003oooooool0M_ooo`00Q?ooo`03o`2Ioooooooo00Soool200005S?o00030000oooooooo07Koool0
08Coool00ol0VOooooooo`08oooo00<0000co`0co`005C?o00030000oooooooo07Koool008Coool0
0ol0VOooooooo`08oooo00<0000co`0co`005C?o00030000oooooooo07Koool008Coool00ol0VOoo
ooooo`08oooo00<0000co`0co`0053?o00030000oooooooo07Ooool008Coool01?l0VOoooooooooo
o`800005oooo00<0000co`0co`0053?o00030000oooooooo07Ooool008Coool01?l0VOooooooo`00
00;oool00`000?ooooooo`02oooo00<0000co`0co`0053?o00030000oooooooo07Ooool008Coool0
0ol0VOooooooo`02oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool0N?ooo`00Q?oo
o`03o`2Ioooooooo00?oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo
07Soool008Coool01?l0VOooooooo`0000;oool00`000?ooooooo`02oooo00<0000co`0co`004c?o
00030000oooooooo07Soool008Coool01?l0VOooooooooooo`800005oooo00<0000co`0co`004S?o
00030000oooooooo07Woool008Coool00ol0VOooooooo`08oooo00<0000co`0co`004S?o00030000
oooooooo07Woool008Coool00ol0VOooooooo`08oooo00<0000co`0co`004S?o00030000oooooooo
07Woool008Coool00ol0VOooooooo`08oooo00<0000co`0co`004S?o00030000oooooooo07Woool0
08Coool00ol0VOooooooo`08oooo0P00018co`000`000?ooooooo`1joooo0024oooo00?o09Wooooo
ool02?ooo`030000<ol0<ol0014co`000`000?ooooooo`1joooo0024oooo00?o09Woooooool02?oo
o`030000<ol0<ol0014co`000`000?ooooooo`1joooo0024oooo00?o09Woooooool02?ooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol0
010co`000`000?ooooooo`1koooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo0024oooo00?o09Woooooool02?ooo`80000A<ol000<0003oooooool0Nooo
o`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Q?oo
o`03o`2Ioooooooo00Soool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Q?ooo`03o`2I
oooooooo00Soool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Q?ooo`03o`2Ioooooooo00Soool2000043?o
00030000oooooooo07coool008Coool00ol0VOooooooo`08oooo00<0000co`0co`003S?o00030000
oooooooo07goool008Coool00ol0VOooooooo`08oooo00<0000co`0co`003S?o00030000oooooooo
07goool008Coool00ol0VOooooooo`08oooo00<0000co`0co`003S?o00030000oooooooo07goool0
08Coool00ol0VOooooooo`08oooo00<0000co`0co`003S?o00030000oooooooo07goool008Coool0
0ol0VOooooooo`08oooo00<0000co`0co`003S?o00030000oooooooo07goool008Coool00ol0VOoo
ooooo`08oooo0P0000hco`000`000?ooooooo`1noooo0024oooo00?o09Woooooool02?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol0
00dco`000`000?ooooooo`1noooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000dco`00
0`000?ooooooo`1noooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo0024oooo00?o09Woooooool00_ooo`<00003oooo00<0000co`0co`0033?o00030000
oooooooo07ooool008Coool00ol0VOooooooo`03oooo00<0003oooooool00_ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1ooooo0024oooo00?o09Woooooool01@0000?oool3000033?o00030000
oooooooo07ooool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo0000
00Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22
oooo001foooo00<0003oooooool05_ooo`hco`0:oooo00<0003oooooool0M_ooo`00MOooo`030000
oooooooo00Soool00`000?ooooooo`0<oooo3S?o00_oool00`000?ooooooo`1eoooo001eoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`03<ol00000000000@co`02000013?o
00800003oooo0`0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool0100003?o03?o000000Pco`00
100003?o0?ooo`0000Coool00`000?ooooooo`02oooo00<0003oooooool0MOooo`00M?ooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0000co`0co`000008<ol000@0000co`3oool00003
oooo0`0000Coool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool0100003?o
03?o000000Pco`00100003?o0?ooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1e
oooo001eoooo00D0003oooooooooool000005Oooo`040000<ol0<ol0000023?o00040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0F
oooo00<co`00000000002S?o00800004oooo0`0000;oool00`000?ooooooo`1foooo002?oooo3C?o
08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.45734 .12361 L
.45963 .12361 L
.46063 .12361 L
.46172 .12361 L
s
.46172 .12361 m
.46216 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
09T02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo02ooool00ol0VOooooooo`07oooo00<0
000co`0co`00>C?o00030000<ol0<ol003Hco`0500005oooo`00QOooo`03o`2Ioooooooo00Ooool0
0`0003?o03?o001Z<ol0200001coool008Goool00ol0VOooooooo`07oooo00<0000co`0co`00I3?o
00H0000Toooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol005lco`050000:_ooo`00QOoo
o`03o`2Ioooooooo00Ooool00`0003?o03?o001J<ol01@0002ooool008Goool00ol0VOooooooo`07
oooo0P0005Hco`050000=?ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o001A<ol01000
03Woool008Goool00ol0VOooooooo`07oooo00<0000co`0co`00Cc?o0080000moooo0025oooo00?o
09Woooooool01oooo`030000<ol0<ol004`co`030000?oooo`00QOooo`03o`2Ioooooooo00Ooool0
0`0003?o03?o001:<ol00P0004;oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`00B3?o
00800014oooo0025oooo00?o09Woooooool01oooo`800017<ol00P0004Koool008Goool00ol0VOoo
ooooo`07oooo00<0000co`0co`00A3?o00800018oooo0025oooo00?o09Woooooool01oooo`030000
<ol0<ol004<co`000`000?ooooooo`18oooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol0
044co`020000Boooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000o<ol00P0004goool0
08Goool00ol0VOooooooo`07oooo00<0000co`0co`00?S?o00030000oooooooo04goool008Goool0
0ol0VOooooooo`07oooo0P0003dco`020000D?ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o
03?o000j<ol00P0005;oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`00>C?o00030000
oooooooo05;oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`00>3?o00030000oooooooo
05?oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`00=S?o0080001Foooo0025oooo00?o
09Woooooool01oooo`030000<ol0<ol003Dco`000`000?ooooooo`1Foooo0025oooo00?o09Wooooo
ool01oooo`80000e<ol000<0003oooooool0Eoooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o
03?o000c<ol000<0003oooooool0F?ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000b
<ol000<0003oooooool0FOooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000a<ol000<0
003oooooool0F_ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000a<ol000<0003ooooo
ool0F_ooo`00QOooo`03o`2Ioooo000000@00003oooo00<0000co`0co`00<3?o00030000oooooooo
05_oool008Goool01Ol0VOooooooooooo`000005oooo00<0000co`0co`00;c?o00030000oooooooo
05coool008Goool01Ol0VOooooooooooo`000005oooo0`0002hco`000`000?ooooooo`1Moooo0025
oooo00Go09Woooooooooool000001Oooo`030000<ol0<ol002hco`000`000?ooooooo`1Moooo0025
oooo00Go09Woooooooooool000001Oooo`030000<ol0<ol002dco`000`000?ooooooo`1Noooo0025
oooo00?o09Woooooool00P0000Goool00`0003?o03?o000/<ol000<0003oooooool0Goooo`00QOoo
o`03o`2Ioooooooo00Ooool00`0003?o03?o000[<ol000<0003oooooool0H?ooo`00QOooo`03o`2I
oooooooo00Ooool00`0003?o03?o000[<ol000<0003oooooool0H?ooo`00QOooo`03o`2Ioooooooo
00Ooool20000:c?o00030000oooooooo067oool008Goool00ol0VOooooooo`07oooo00<0000co`0c
o`00:C?o00030000oooooooo06;oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`00:C?o
00030000oooooooo06;oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`00:3?o00030000
oooooooo06?oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`009c?o00030000oooooooo
06Coool008Goool00ol0VOooooooo`07oooo00<0000co`0co`009S?o00030000oooooooo06Goool0
08Goool00ol0VOooooooo`07oooo0P0002Lco`000`000?ooooooo`1Uoooo0025oooo00?o09Wooooo
ool01oooo`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo0025oooo00?o09Woooooool01ooo
o`030000<ol0<ol002@co`000`000?ooooooo`1Woooo0025oooo00?o09Woooooool01oooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol0
02<co`000`000?ooooooo`1Xoooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol002<co`00
0`000?ooooooo`1Xoooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol0028co`000`000?oo
ooooo`1Yoooo0025oooo00?o09Woooooool01oooo`80000S<ol000<0003oooooool0JOooo`00QOoo
o`03o`2Ioooooooo00Ooool00`0003?o03?o000Q<ol000<0003oooooool0J_ooo`00QOooo`03o`2I
oooooooo00Ooool00`0003?o03?o000Q<ol000<0003oooooool0J_ooo`00QOooo`03o`2Ioooooooo
00Ooool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00QOooo`03o`2Ioooooooo00Ooool0
0`0003?o03?o000P<ol000<0003oooooool0Joooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o
03?o000P<ol000<0003oooooool0Joooo`00QOooo`03o`2Ioooooooo00Ooool2000083?o00030000
oooooooo06coool008Goool00ol0VOooooooo`07oooo00<0000co`0co`007c?o00030000oooooooo
06coool008Goool00ol0VOooooooo`07oooo00<0000co`0co`007S?o00030000oooooooo06goool0
08Goool00ol0VOooooooo`07oooo00<0000co`0co`007S?o00030000oooooooo06goool008Goool0
0ol0VOooo`00000300001?ooo`030000<ol0<ol001hco`000`000?ooooooo`1]oooo0025oooo00?o
09Woool000001oooo`030000<ol0<ol001dco`000`000?ooooooo`1^oooo0025oooo00Co09Wooooo
ool00006oooo0`0001dco`000`000?ooooooo`1^oooo0025oooo00Go09Woooooooooool000001Ooo
o`030000<ol0<ol001dco`000`000?ooooooo`1^oooo0025oooo00?o09Woool000000_ooo`030000
oooooooo00;oool00`0003?o03?o000L<ol000<0003oooooool0Koooo`00QOooo`03o`2Ioooooooo
00800005oooo00<0000co`0co`0073?o00030000oooooooo06ooool008Goool00ol0VOooooooo`07
oooo00<0000co`0co`006c?o00030000oooooooo073oool008Goool00ol0VOooooooo`07oooo00<0
000co`0co`006c?o00030000oooooooo073oool008Goool00ol0VOooooooo`07oooo0P0001`co`00
0`000?ooooooo`1`oooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol001Xco`000`000?oo
ooooo`1aoooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol001Xco`000`000?ooooooo`1a
oooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0025
oooo00?o09Woooooool01oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0025oooo00?o
09Woooooool01oooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo0025oooo00?o09Wooooo
ool01oooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo0025oooo00?o09Woooooool01ooo
o`80000J<ol000<0003oooooool0L_ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000H<ol000<0
003oooooool0Loooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000H<ol000<0003ooooo
ool0Loooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000G<ol000<0003oooooool0M?oo
o`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00QOoo
o`03o`2Ioooooooo00Ooool2000063?o00030000oooooooo07Coool008Goool00ol0VOooooooo`07
oooo00<0000co`0co`005c?o00030000oooooooo07Coool008Goool00ol0VOooooooo`07oooo00<0
000co`0co`005S?o00030000oooooooo07Goool008Goool00ol0VOooooooo`07oooo00<0000co`0c
o`005S?o00030000oooooooo07Goool008Goool00ol0VOooooooo`07oooo00<0000co`0co`005S?o
00030000oooooooo07Goool008Goool00ol0VOooooooo`07oooo00<0000co`0co`005C?o00030000
oooooooo07Koool008Goool00ol0VOooooooo`07oooo0P0001Hco`000`000?ooooooo`1foooo0025
oooo00?o09Woooooool01oooo`030000<ol0<ol001Dco`000`000?ooooooo`1foooo0025oooo00?o
09Woooooool01oooo`030000<ol0<ol001Dco`000`000?ooooooo`1foooo0025oooo00?o09Wooooo
ool01oooo`030000<ol0<ol001@co`000`000?ooooooo`1goooo0025oooo00?o09Woooooool00P00
00Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00QOooo`03o`2Ioooo000000;oool0
0`000?ooooooo`02oooo00<0000co`0co`0053?o00030000oooooooo07Ooool008Goool01Ol0VOoo
ooooooooo`000005oooo0`0001<co`000`000?ooooooo`1hoooo0025oooo00?o09Woooooool00_oo
o`030000oooooooo00;oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00QOooo`03o`2I
oooo000000;oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo07Soool0
08Goool00ol0VOooooooo`0200001Oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0025
oooo00?o09Woooooool01oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0025oooo00?o
09Woooooool01oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0025oooo00?o09Wooooo
ool01oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0025oooo00?o09Woooooool01ooo
o`80000B<ol000<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00QOoo
o`03o`2Ioooooooo00Ooool200004C?o00030000oooooooo07_oool008Goool00ol0VOooooooo`07
oooo00<0000co`0co`0043?o00030000oooooooo07_oool008Goool00ol0VOooooooo`07oooo00<0
000co`0co`003c?o00030000oooooooo07coool008Goool00ol0VOooooooo`07oooo00<0000co`0c
o`003c?o00030000oooooooo07coool008Goool00ol0VOooooooo`07oooo00<0000co`0co`003c?o
00030000oooooooo07coool008Goool00ol0VOooooooo`07oooo00<0000co`0co`003c?o00030000
oooooooo07coool008Goool00ol0VOooooooo`07oooo0P00010co`000`000?ooooooo`1loooo0025
oooo00?o09Woooooool01oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0025oooo00?o
09Woooooool01oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0025oooo00?o09Wooooo
ool01oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0025oooo00?o09Woooooool01ooo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo0025oooo00?o09Woooooool01oooo`030000
<ol0<ol000hco`000`000?ooooooo`1moooo0025oooo00?o09Woooooool01oooo`80000><ol000<0
003oooooool0O_ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000=<ol000<0003ooooo
ool0O_ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000=<ol000<0003oooooool0O_oo
o`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00QOoo
o`03o`2Ioooooooo00Ooool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00QOooo`04o`2I
oooooooooooo0`0000?oool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00QOooo`03o`2I
oooooooo00;oool00`000?ooooooo`02oooo00<0000co`0co`0033?o00030000oooooooo07ooool0
08Goool00ol0VOooo`00000400000oooo`<0000<<ol000<0003oooooool0Ooooo`00Qoooo`040000
oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?ooo`lco`22oooo0029oooo0P00
00Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool007Koool00`000?ooooooo`0F
oooo3S?o00[oool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000oooooooo
00coool><ol02oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`0<oooo00<co`000000000013?o00800004<ol00P0000Coool200001?ooo`030000
oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool400000oooo`040000<ol0<ol0000023?o00040000<ol0oooo00000_ooo`040000
oooooooo00000oooo`030000oooooooo07Goool007Coool00`000?ooooooo`02oooo00<0003ooooo
ool04oooo`040000<ol0<ol0000023?o00040000<ol0oooo00000_ooo`040000oooooooo00001?oo
o`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000<ol0<ol0000023?o
00040000<ol0oooo00000oooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooo
oooo000001Goool0100003?o03?o000000Pco`0010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05_ooo`03<ol00000000000Xco`02
00001?ooo`800003oooo00<0003oooooool0M_ooo`00Soooo`dco`24oooo002?oooo3C?o08Coool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46388 .12361 L
.46507 .12361 L
.46618 .12361 L
s
.46618 .12361 m
.46644 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00@0003ooooo
oooo09T8oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Xco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000oooooooo
01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0<?ooo`03o`2Ioooooooo00Koool0
0`0003?o03?o000i<ol000<0000co`0co`00=S?o00D0000Goooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol006Xco`0800007?ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o001T
<ol01P0002Coool008Koool00ol0VOooooooo`06oooo00<0000co`0co`00Gc?o00D0000Zoooo0026
oooo00?o09Woooooool01_ooo`030000<ol0<ol005Xco`050000;oooo`00Q_ooo`03o`2Ioooooooo
00Koool20000ES?o00D0000doooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0054co`04
0000>Oooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o001?<ol00P0003goool008Koool0
0ol0VOooooooo`06oooo00<0000co`0co`00C3?o00<0000ooooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol004Xco`020000@_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o0018
<ol00P0004Coool008Koool00ol0VOooooooo`06oooo0P0004Lco`020000A_ooo`00Q_ooo`03o`2I
oooooooo00Koool00`0003?o03?o0014<ol00P0004Soool008Koool00ol0VOooooooo`06oooo00<0
000co`0co`00@c?o00030000oooooooo04Soool008Koool00ol0VOooooooo`06oooo00<0000co`0c
o`00@C?o0080001;oooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol003lco`020000COoo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000n<ol000<0003oooooool0COooo`00Q_oo
o`03o`2Ioooooooo00Koool20000?C?o0080001@oooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol003Xco`020000D_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000i<ol000<0
003oooooool0D_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000h<ol000<0003ooooo
ool0Doooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000f<ol00P0005Koool008Koool0
0ol0VOooooooo`06oooo00<0000co`0co`00=C?o00030000oooooooo05Koool008Koool00ol0VOoo
ooooo`06oooo0P0003Dco`000`000?ooooooo`1Goooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol003<co`000`000?ooooooo`1Hoooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0
038co`000`000?ooooooo`1Ioooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0034co`00
0`000?ooooooo`1Joooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0034co`000`000?oo
ooooo`1Joooo0026oooo00?o09T0000000000`0000?oool00`0003?o03?o000`<ol000<0003ooooo
ool0Foooo`00Q_ooo`04o`2Ioooooooo00001Oooo`030000<ol0<ol002lco`000`000?ooooooo`1L
oooo0026oooo00Co09Woooooool00005oooo0`0002hco`000`000?ooooooo`1Moooo0026oooo00Co
09Woooooool00005oooo00<0000co`0co`00;S?o00030000oooooooo05goool008Koool01?l0VOoo
ooooo`0000Goool00`0003?o03?o000]<ol000<0003oooooool0G_ooo`00Q_ooo`04o`2Ioooo0000
00001Oooo`030000<ol0<ol002`co`000`000?ooooooo`1Ooooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol002/co`000`000?ooooooo`1Poooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol002/co`000`000?ooooooo`1Poooo0026oooo00?o09Woooooool01_ooo`80000[<ol000<0
003oooooool0HOooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000Y<ol000<0003ooooo
ool0H_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000Y<ol000<0003oooooool0H_oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000X<ol000<0003oooooool0Hoooo`00Q_oo
o`03o`2Ioooooooo00Koool00`0003?o03?o000W<ol000<0003oooooool0I?ooo`00Q_ooo`03o`2I
oooooooo00Koool00`0003?o03?o000V<ol000<0003oooooool0IOooo`00Q_ooo`03o`2Ioooooooo
00Koool200009c?o00030000oooooooo06Goool008Koool00ol0VOooooooo`06oooo00<0000co`0c
o`009C?o00030000oooooooo06Koool008Koool00ol0VOooooooo`06oooo00<0000co`0co`0093?o
00030000oooooooo06Ooool008Koool00ol0VOooooooo`06oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool008Koool00ol0VOooooooo`06oooo00<0000co`0co`008c?o00030000oooooooo
06Soool008Koool00ol0VOooooooo`06oooo00<0000co`0co`008c?o00030000oooooooo06Soool0
08Koool00ol0VOooooooo`06oooo00<0000co`0co`008S?o00030000oooooooo06Woool008Koool0
0ol0VOooooooo`06oooo0P0002<co`000`000?ooooooo`1Yoooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol0024co`000`000?ooooooo`1Zoooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol0024co`000`000?ooooooo`1Zoooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0
020co`000`000?ooooooo`1[oooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0020co`00
0`000?ooooooo`1[oooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0020co`000`000?oo
ooooo`1[oooo0026oooo00?o09Woooooool01_ooo`80000P<ol000<0003oooooool0K?ooo`00Q_oo
o`03o`2Ioooooooo00Koool00`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Q_ooo`03o`2I
oooooooo00Koool00`0003?o03?o000N<ol000<0003oooooool0KOooo`00Q_ooo`03o`2Ioooooooo
00Koool00`0003?o03?o000N<ol000<0003oooooool0KOooo`00Q_ooo`03o`2I0000000000800004
oooo00<0000co`0co`007S?o00030000oooooooo06goool008Koool00ol0V@000?ooo`06oooo00<0
000co`0co`007C?o00030000oooooooo06koool008Koool00ol0VOooo`000006oooo0`0001dco`00
0`000?ooooooo`1^oooo0026oooo00Co09Woooooool00005oooo00<0000co`0co`007C?o00030000
oooooooo06koool008Koool01Ol0V@000?ooooooo`000004oooo00<0000co`0co`0073?o00030000
oooooooo06ooool008Koool01?l0VOooo`00000000Goool00`0003?o03?o000L<ol000<0003ooooo
ool0Koooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000K<ol000<0003oooooool0L?oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Q_oo
o`03o`2Ioooooooo00Koool2000073?o00030000oooooooo073oool008Koool00ol0VOooooooo`06
oooo00<0000co`0co`006S?o00030000oooooooo077oool008Koool00ol0VOooooooo`06oooo00<0
000co`0co`006S?o00030000oooooooo077oool008Koool00ol0VOooooooo`06oooo00<0000co`0c
o`006S?o00030000oooooooo077oool008Koool00ol0VOooooooo`06oooo00<0000co`0co`006S?o
00030000oooooooo077oool008Koool00ol0VOooooooo`06oooo00<0000co`0co`006C?o00030000
oooooooo07;oool008Koool00ol0VOooooooo`06oooo00<0000co`0co`006C?o00030000oooooooo
07;oool008Koool00ol0VOooooooo`06oooo0P0001Xco`000`000?ooooooo`1boooo0026oooo00?o
09Woooooool01_ooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo0026oooo00?o09Wooooo
ool01_ooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol001Pco`000`000?ooooooo`1coooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol001Lco`000`000?ooooooo`1doooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`1doooo0026oooo00?o09Woooooool01_ooo`80000H<ol000<0003ooooo
ool0M?ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000G<ol000<0003oooooool0M?oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00Q_oo
o`03o`2Ioooooooo00Koool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00Q_ooo`03o`2I
oooooooo00Koool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00Q_ooo`03o`2Ioooooooo
00Koool00`0003?o03?o000E<ol000<0003oooooool0M_ooo`00Q_ooo`03o`2Ioooooooo00Koool2
00005S?o00030000oooooooo07Koool008Koool00ol0VOooooooo`06oooo00<0000co`0co`005C?o
00030000oooooooo07Koool008Koool00ol0VOooooooo`06oooo00<0000co`0co`005C?o00030000
oooooooo07Koool008Koool00ol0VOooooooo`06oooo00<0000co`0co`0053?o00030000oooooooo
07Ooool008Koool01?l0VOooo`00000000Goool00`0003?o03?o000D<ol000<0003oooooool0Mooo
o`00Q_ooo`05o`2I0000oooooooo000000Coool00`0003?o03?o000D<ol000<0003oooooool0Mooo
o`00Q_ooo`04o`2Ioooooooo00001Oooo`<0000C<ol000<0003oooooool0N?ooo`00Q_ooo`05o`2I
oooooooooooo000000Coool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Q_ooo`05o`2I
0000oooooooo000000Coool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Q_ooo`04o`2I
oooo000000001Oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0026oooo00?o09Wooooo
ool01_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol0018co`000`000?ooooooo`1ioooo0026oooo00?o09Woooooool01_ooo`80000B<ol000<0
003oooooool0N_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000A<ol000<0003oooooool0N_oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Q_oo
o`03o`2Ioooooooo00Koool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Q_ooo`03o`2I
oooooooo00Koool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Q_ooo`03o`2Ioooooooo
00Koool200004C?o00030000oooooooo07_oool008Koool00ol0VOooooooo`06oooo00<0000co`0c
o`0043?o00030000oooooooo07_oool008Koool00ol0VOooooooo`06oooo00<0000co`0co`003c?o
00030000oooooooo07coool008Koool00ol0VOooooooo`06oooo00<0000co`0co`003c?o00030000
oooooooo07coool008Koool00ol0VOooooooo`06oooo00<0000co`0co`003c?o00030000oooooooo
07coool008Koool00ol0VOooooooo`06oooo00<0000co`0co`003c?o00030000oooooooo07coool0
08Koool00ol0VOooooooo`06oooo0P00010co`000`000?ooooooo`1loooo0026oooo00?o09Wooooo
ool01_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol000hco`000`000?ooooooo`1moooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0
00hco`000`000?ooooooo`1moooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol000hco`00
0`000?ooooooo`1moooo0026oooo00?o09Woooooool01_ooo`80000><ol000<0003oooooool0O_oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Q_oo
o`03o`2Ioooooooo00Koool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Q_ooo`03o`2I
oooooooo00Koool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Q_ooo`03o`2Ioooooooo
00Koool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Q_ooo`03o`2Ioooooooo00<00003
oooo00<0000co`0co`0033?o00030000oooooooo07ooool008Koool01Ol0VOooooooooooo`000004
oooo00<0000co`0co`0033?o00030000oooooooo07ooool008Koool00ol0V@000000000300000ooo
o`<0000<<ol000<0003oooooool0Ooooo`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028
oooo00<0003oool000001?ooo`lco`22oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22
oooo002?oooo3c?o08;oool007Koool00`000?ooooooo`0Foooo3S?o00[oool00`000?ooooooo`1f
oooo001eoooo00<0003oooooool02?ooo`030000oooooooo00coool><ol02oooo`030000oooooooo
07Goool007Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo00<co`000000
000013?o00800004<ol00P0000Goool00`000?ooooooo`02oooo00<0003oooooool0MOooo`00MOoo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003
oooo00@0000co`0co`000008<ol000@0000co`3oool00004oooo00<0003oooooool00_ooo`030000
oooooooo07Goool007Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000<ol0<ol0
000023?o00040000<ol0oooo00001?ooo`030000oooooooo00?oool00`000?ooooooo`1doooo001e
oooo00<0003oooooool01@0001;oool0100003?o03?o000000Pco`00100003?o0?ooo`0000Goool0
1@000?ooooooooooo`00001goooo001eoooo00D0003oooooooooool000005Oooo`040000<ol0<ol0
000023?o00040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool0
07Koool00`000?ooooooo`0Foooo00<co`00000000002S?o00800003oooo100000;oool00`000?oo
ooooo`1foooo002?oooo3C?o08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46618 .12361 L
.46854 .12361 L
.46984 .12361 L
.47106 .12361 L
s
.47106 .12361 m
.47153 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool00_ooo`03o`2Ioooooooo00Coool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0boooo00?o
09Woooooool01?ooo`030000<ol0<ol003Tco`000`0003?o03?o000f<ol01@0001Ooool008Soool0
0ol0VOooooooo`04oooo00<0000co`0co`00JS?o00P0000Loooo0028oooo00?o09Woooooool01?oo
o`030000<ol0<ol006@co`0600009?ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o001O
<ol01@0002[oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`00FS?o00D0000_oooo0028
oooo00?o09Woooooool01?ooo`80001F<ol01@0003Coool008Soool00ol0VOooooooo`04oooo00<0
000co`0co`00DC?o00@0000ioooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol004lco`02
0000?Oooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o001<<ol00`0003ooool008Soool0
0ol0VOooooooo`04oooo00<0000co`0co`00BS?o00800012oooo0028oooo00?o09Woooooool01?oo
o`030000<ol0<ol004Pco`020000A?ooo`00R?ooo`03o`2Ioooooooo00Coool20000Ac?o00800016
oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol004@co`020000B?ooo`00R?ooo`03o`2I
oooooooo00Coool00`0003?o03?o0013<ol000<0003oooooool0B?ooo`00R?ooo`03o`2Ioooooooo
00Coool00`0003?o03?o0011<ol00P0004_oool008Soool00ol0VOooooooo`04oooo00<0000co`0c
o`00?c?o0080001=oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol003hco`000`000?oo
ooooo`1=oooo0028oooo00?o09Woooooool01?ooo`80000m<ol00P00053oool008Soool00ol0VOoo
ooooo`04oooo00<0000co`0co`00>S?o0080001Boooo0028oooo00?o09Woooooool01?ooo`030000
<ol0<ol003Tco`000`000?ooooooo`1Boooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol0
03Pco`000`000?ooooooo`1Coooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol003Hco`02
0000E_ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000e<ol000<0003oooooool0E_oo
o`00R?ooo`03o`2Ioooooooo00Coool20000=C?o00030000oooooooo05Ooool008Soool00ol0VOoo
ooooo`04oooo00<0000co`0co`00<c?o00030000oooooooo05Soool008Soool00ol0VOooooooo`04
oooo00<0000co`0co`00<S?o00030000oooooooo05Woool008Soool00ol0VOooooooo`04oooo00<0
000co`0co`00<C?o00030000oooooooo05[oool008Soool00ol0VOooooooo`04oooo00<0000co`0c
o`00<C?o00030000oooooooo05[oool008Ooool500000oooo`030000<ol0<ol0030co`000`000?oo
ooooo`1Koooo0028oooo00?o09T0003oool01?ooo`030000<ol0<ol002lco`000`000?ooooooo`1L
oooo0028oooo00?o09T0003oool01?ooo`<0000^<ol000<0003oooooool0GOooo`00R?ooo`03o`2I
0000oooo00Coool00`0003?o03?o000^<ol000<0003oooooool0GOooo`00R?ooo`03o`2I0000oooo
00Coool00`0003?o03?o000]<ol000<0003oooooool0G_ooo`00R?ooo`800005oooo00<0000co`0c
o`00;3?o00030000oooooooo05ooool008Soool00ol0VOooooooo`04oooo00<0000co`0co`00:c?o
00030000oooooooo063oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`00:c?o00030000
oooooooo063oool008Soool00ol0VOooooooo`04oooo0P0002/co`000`000?ooooooo`1Qoooo0028
oooo00?o09Woooooool01?ooo`030000<ol0<ol002Tco`000`000?ooooooo`1Roooo0028oooo00?o
09Woooooool01?ooo`030000<ol0<ol002Tco`000`000?ooooooo`1Roooo0028oooo00?o09Wooooo
ool01?ooo`030000<ol0<ol002Pco`000`000?ooooooo`1Soooo0028oooo00?o09Woooooool01?oo
o`030000<ol0<ol002Lco`000`000?ooooooo`1Toooo0028oooo00?o09Woooooool01?ooo`030000
<ol0<ol002Hco`000`000?ooooooo`1Uoooo0028oooo00?o09Woooooool01?ooo`80000W<ol000<0
003oooooool0IOooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000U<ol000<0003ooooo
ool0I_ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000T<ol000<0003oooooool0Iooo
o`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000T<ol000<0003oooooool0Ioooo`00R?oo
o`03o`2Ioooooooo00Coool00`0003?o03?o000S<ol000<0003oooooool0J?ooo`00R?ooo`03o`2I
oooooooo00Coool00`0003?o03?o000S<ol000<0003oooooool0J?ooo`00R?ooo`03o`2Ioooooooo
00Coool00`0003?o03?o000R<ol000<0003oooooool0JOooo`00R?ooo`03o`2Ioooooooo00Coool2
00008c?o00030000oooooooo06Woool008Soool00ol0VOooooooo`04oooo00<0000co`0co`008C?o
00030000oooooooo06[oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`008C?o00030000
oooooooo06[oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`0083?o00030000oooooooo
06_oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`0083?o00030000oooooooo06_oool0
08Soool00ol0VOooooooo`04oooo00<0000co`0co`0083?o00030000oooooooo06_oool008Soool0
0ol0VOooooooo`04oooo0P00020co`000`000?ooooooo`1/oooo0028oooo00?o09Woooooool01?oo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo0028oooo00?o09Woooooool01?ooo`030000
<ol0<ol001hco`000`000?ooooooo`1]oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo0027oooo100000Coool00`0003?o03?o000N<ol000<0003ooooo
ool0KOooo`00Qoooo`030000o`2Ioooo00Goool00`0003?o03?o000M<ol000<0003oooooool0K_oo
o`00R?ooo`030000oooooooo00Coool300007C?o00030000oooooooo06koool008Soool00ol0V@00
0?ooo`04oooo00<0000co`0co`007C?o00030000oooooooo06koool008Ooool010000?l0VOooo`00
00Coool00`0003?o03?o000L<ol000<0003oooooool0Koooo`00R?ooo`800005oooo00<0000co`0c
o`0073?o00030000oooooooo06ooool008Soool00ol0VOooooooo`04oooo00<0000co`0co`006c?o
00030000oooooooo073oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`006c?o00030000
oooooooo073oool008Soool00ol0VOooooooo`04oooo0P0001`co`000`000?ooooooo`1`oooo0028
oooo00?o09Woooooool01?ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0028oooo00?o
09Woooooool01?ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0028oooo00?o09Wooooo
ool01?ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0028oooo00?o09Woooooool01?oo
o`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0028oooo00?o09Woooooool01?ooo`030000
<ol0<ol001Tco`000`000?ooooooo`1boooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol0
01Tco`000`000?ooooooo`1boooo0028oooo00?o09Woooooool01?ooo`80000J<ol000<0003ooooo
ool0L_ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000H<ol000<0003oooooool0Looo
o`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000H<ol000<0003oooooool0Loooo`00R?oo
o`03o`2Ioooooooo00Coool00`0003?o03?o000H<ol000<0003oooooool0Loooo`00R?ooo`03o`2I
oooooooo00Coool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00R?ooo`03o`2Ioooooooo
00Coool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00R?ooo`03o`2Ioooooooo00Coool2
000063?o00030000oooooooo07Coool008Soool00ol0VOooooooo`04oooo00<0000co`0co`005c?o
00030000oooooooo07Coool008Soool00ol0VOooooooo`04oooo00<0000co`0co`005S?o00030000
oooooooo07Goool008Soool00ol0VOooooooo`04oooo00<0000co`0co`005S?o00030000oooooooo
07Goool008Soool00ol0VOooooooo`04oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
08Soool00ol0VOooooooo`04oooo00<0000co`0co`005C?o00030000oooooooo07Koool008Soool0
0ol0VOooooooo`04oooo0P0001Hco`000`000?ooooooo`1foooo0028oooo00?o09Woooooool01?oo
o`030000<ol0<ol001Dco`000`000?ooooooo`1foooo0028oooo00?o09Woooooool01?ooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003ooooo
ool0Moooo`00Qoooo`040000o`2Ioooo00001?ooo`030000<ol0<ol001@co`000`000?ooooooo`1g
oooo0028oooo00?o09T0003oool01?ooo`<0000C<ol000<0003oooooool0N?ooo`00R?ooo`03o`2I
oooo000000Coool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Qoooo`040000o`2Ioooo
00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo0028oooo0P0000Goool00`0003?o
03?o000B<ol000<0003oooooool0NOooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000B
<ol000<0003oooooool0NOooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000B<ol000<0
003oooooool0NOooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000B<ol000<0003ooooo
ool0NOooo`00R?ooo`03o`2Ioooooooo00Coool200004S?o00030000oooooooo07[oool008Soool0
0ol0VOooooooo`04oooo00<0000co`0co`004C?o00030000oooooooo07[oool008Soool00ol0VOoo
ooooo`04oooo00<0000co`0co`004C?o00030000oooooooo07[oool008Soool00ol0VOooooooo`04
oooo00<0000co`0co`004C?o00030000oooooooo07[oool008Soool00ol0VOooooooo`04oooo00<0
000co`0co`0043?o00030000oooooooo07_oool008Soool00ol0VOooooooo`04oooo00<0000co`0c
o`0043?o00030000oooooooo07_oool008Soool00ol0VOooooooo`04oooo0P00014co`000`000?oo
ooooo`1koooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo0028
oooo00?o09Woooooool01?ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo0028oooo00?o
09Woooooool01?ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo0028oooo00?o09Wooooo
ool01?ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo0028oooo00?o09Woooooool01?oo
o`80000@<ol000<0003oooooool0O?ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000>
<ol000<0003oooooool0OOooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000><ol000<0003ooooo
ool0OOooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000><ol000<0003oooooool0OOoo
o`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000><ol000<0003oooooool0OOooo`00R?oo
o`03o`2Ioooooooo00Coool200003S?o00030000oooooooo07koool008Soool00ol0VOooooooo`04
oooo00<0000co`0co`003C?o00030000oooooooo07koool008Soool00ol0VOooooooo`04oooo00<0
000co`0co`003C?o00030000oooooooo07koool008Soool00ol0VOooooooo`04oooo00<0000co`0c
o`003C?o00030000oooooooo07koool008Soool00ol0VOooooooo`04oooo00<0000co`0co`0033?o
00030000oooooooo07ooool008Soool01?l0V@000000000000?oool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00R?ooo`03o`2Ioooo000000Coool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00Qoooo`D00003oooo0`0000`co`000`000?ooooooo`1ooooo0027oooo00@0003ooooo
ool00004oooo3c?o08;oool008Soool00`000?ooo`000004oooo3c?o08;oool008Woool200001?oo
o`lco`22oooo002?oooo3c?o08;oool008ooool?<ol0P_ooo`00M_ooo`030000oooooooo01Koool>
<ol02_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool03?oo
o`hco`0;oooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00coool00c?o000000000004<ol00P0000@co`0200000oooo`<00004oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00003oooo00@0000co`0co`000008<ol000@0000co`3oool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0000co`0co`000008<ol000@0000co`3oool00002oooo00@0003oooooool00004oooo00<0
003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0000co`0co`000008<ol000@0
000co`3oool00002oooo0`0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool0
00005Oooo`040000<ol0<ol0000023?o00040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1eoooo001foooo00<0003oooooool05_ooo`03<ol00000000000Xco`0200001?oo
o`<00002oooo00<0003oooooool0M_ooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46618 .12361 L
.47106 .12361 L
.47329 .12361 L
.47451 .12361 L
.47567 .12361 L
s
.47567 .12361 m
.4761 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo00?oool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0coooo00?o
09Woooooool00oooo`030000<ol0<ol003Tco`000`0003?o03?o000f<ol01@0001Ooool008Woool0
0ol0VOooooooo`03oooo00<0000co`0co`00JS?o00P0000Loooo0029oooo00?o09Woooooool00ooo
o`030000<ol0<ol006@co`0600009?ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o001O
<ol01@0002[oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`00FS?o00D0000_oooo0029
oooo00?o09Woooooool00oooo`80001F<ol01@0003Coool008Woool00ol0VOooooooo`03oooo00<0
000co`0co`00DC?o00@0000ioooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol004lco`02
0000?Oooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o001<<ol00`0003ooool008Woool0
0ol0VOooooooo`03oooo00<0000co`0co`00BS?o00800012oooo0029oooo00?o09Woooooool00ooo
o`030000<ol0<ol004Pco`020000A?ooo`00ROooo`03o`2Ioooooooo00?oool20000Ac?o00800016
oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol004@co`020000B?ooo`00ROooo`03o`2I
oooooooo00?oool00`0003?o03?o0013<ol000<0003oooooool0B?ooo`00ROooo`03o`2Ioooooooo
00?oool00`0003?o03?o0011<ol00P0004_oool008Woool00ol0VOooooooo`03oooo00<0000co`0c
o`00?c?o0080001=oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol003hco`000`000?oo
ooooo`1=oooo0029oooo00?o09Woooooool00oooo`80000m<ol00P00053oool008Woool00ol0VOoo
ooooo`03oooo00<0000co`0co`00>S?o0080001Boooo0029oooo00?o09Woooooool00oooo`030000
<ol0<ol003Tco`000`000?ooooooo`1Boooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol0
03Pco`000`000?ooooooo`1Coooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol003Hco`02
0000E_ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000e<ol000<0003oooooool0E_oo
o`00ROooo`03o`2Ioooooooo00?oool20000=C?o00030000oooooooo05Ooool008Woool00ol0VOoo
ooooo`03oooo00<0000co`0co`00<c?o00030000oooooooo05Soool008Woool00ol0VOooooooo`03
oooo00<0000co`0co`00<S?o00030000oooooooo05Woool008Woool00ol0VOooooooo`03oooo00<0
000co`0co`00<C?o00030000oooooooo05[oool008Woool00ol0VOooooooo`03oooo00<0000co`0c
o`00<C?o00030000oooooooo05[oool008Ooool500000oooo`030000<ol0<ol0030co`000`000?oo
ooooo`1Koooo0029oooo00<0003oooooool00oooo`030000<ol0<ol002lco`000`000?ooooooo`1L
oooo0029oooo00<0003oooooool00oooo`<0000^<ol000<0003oooooool0GOooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000^<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000]<ol000<0003oooooool0G_ooo`00R?ooo`800005oooo00<0000co`0c
o`00;3?o00030000oooooooo05ooool008Woool00ol0VOooooooo`03oooo00<0000co`0co`00:c?o
00030000oooooooo063oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`00:c?o00030000
oooooooo063oool008Woool00ol0VOooooooo`03oooo0P0002/co`000`000?ooooooo`1Qoooo0029
oooo00?o09Woooooool00oooo`030000<ol0<ol002Tco`000`000?ooooooo`1Roooo0029oooo00?o
09Woooooool00oooo`030000<ol0<ol002Tco`000`000?ooooooo`1Roooo0029oooo00?o09Wooooo
ool00oooo`030000<ol0<ol002Pco`000`000?ooooooo`1Soooo0029oooo00?o09Woooooool00ooo
o`030000<ol0<ol002Lco`000`000?ooooooo`1Toooo0029oooo00?o09Woooooool00oooo`030000
<ol0<ol002Hco`000`000?ooooooo`1Uoooo0029oooo00?o09Woooooool00oooo`80000W<ol000<0
003oooooool0IOooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000U<ol000<0003ooooo
ool0I_ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000T<ol000<0003oooooool0Iooo
o`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000T<ol000<0003oooooool0Ioooo`00ROoo
o`03o`2Ioooooooo00?oool00`0003?o03?o000S<ol000<0003oooooool0J?ooo`00ROooo`03o`2I
oooooooo00?oool00`0003?o03?o000S<ol000<0003oooooool0J?ooo`00ROooo`03o`2Ioooooooo
00?oool00`0003?o03?o000R<ol000<0003oooooool0JOooo`00ROooo`03o`2Ioooooooo00?oool2
00008c?o00030000oooooooo06Woool008Woool00ol0VOooooooo`03oooo00<0000co`0co`008C?o
00030000oooooooo06[oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`008C?o00030000
oooooooo06[oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`0083?o00030000oooooooo
06_oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`0083?o00030000oooooooo06_oool0
08Woool00ol0VOooooooo`03oooo00<0000co`0co`0083?o00030000oooooooo06_oool008Woool0
0ol0VOooooooo`03oooo0P00020co`000`000?ooooooo`1/oooo0029oooo00?o09Woooooool00ooo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo0029oooo00?o09Woooooool00oooo`030000
<ol0<ol001hco`000`000?ooooooo`1]oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo0027oooo100000Coool00`0003?o03?o000N<ol000<0003ooooo
ool0KOooo`00Qoooo`030000ooooo`2I00Goool00`0003?o03?o000M<ol000<0003oooooool0K_oo
o`00R?ooo`030000o`2Ioooo00Coool300007C?o00030000oooooooo06koool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo06koool008Ooool010000?ooool0V@00
00Coool00`0003?o03?o000L<ol000<0003oooooool0Koooo`00R?ooo`800005oooo00<0000co`0c
o`0073?o00030000oooooooo06ooool008Woool00ol0VOooooooo`03oooo00<0000co`0co`006c?o
00030000oooooooo073oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`006c?o00030000
oooooooo073oool008Woool00ol0VOooooooo`03oooo0P0001`co`000`000?ooooooo`1`oooo0029
oooo00?o09Woooooool00oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0029oooo00?o
09Woooooool00oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0029oooo00?o09Wooooo
ool00oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0029oooo00?o09Woooooool00ooo
o`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0029oooo00?o09Woooooool00oooo`030000
<ol0<ol001Tco`000`000?ooooooo`1boooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol0
01Tco`000`000?ooooooo`1boooo0029oooo00?o09Woooooool00oooo`80000J<ol000<0003ooooo
ool0L_ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000H<ol000<0003oooooool0Looo
o`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000H<ol000<0003oooooool0Loooo`00ROoo
o`03o`2Ioooooooo00?oool00`0003?o03?o000H<ol000<0003oooooool0Loooo`00ROooo`03o`2I
oooooooo00?oool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00ROooo`03o`2Ioooooooo
00?oool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00ROooo`03o`2Ioooooooo00?oool2
000063?o00030000oooooooo07Coool008Woool00ol0VOooooooo`03oooo00<0000co`0co`005c?o
00030000oooooooo07Coool008Woool00ol0VOooooooo`03oooo00<0000co`0co`005S?o00030000
oooooooo07Goool008Woool00ol0VOooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo
07Goool008Woool00ol0VOooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
08Woool00ol0VOooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool008Woool0
0ol0VOooooooo`03oooo0P0001Hco`000`000?ooooooo`1foooo0029oooo00?o09Woooooool00ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`1foooo0029oooo00?o09Woooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003ooooo
ool0Moooo`00Qoooo`040000ooooo`2I00001?ooo`030000<ol0<ol001@co`000`000?ooooooo`1g
oooo0029oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool0N?ooo`00ROooo`03o`2I
0000oooo00?oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Qoooo`040000ooooo`2I
00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo0028oooo0P0000Goool00`0003?o
03?o000B<ol000<0003oooooool0NOooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000B
<ol000<0003oooooool0NOooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000B<ol000<0
003oooooool0NOooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000B<ol000<0003ooooo
ool0NOooo`00ROooo`03o`2Ioooooooo00?oool200004S?o00030000oooooooo07[oool008Woool0
0ol0VOooooooo`03oooo00<0000co`0co`004C?o00030000oooooooo07[oool008Woool00ol0VOoo
ooooo`03oooo00<0000co`0co`004C?o00030000oooooooo07[oool008Woool00ol0VOooooooo`03
oooo00<0000co`0co`004C?o00030000oooooooo07[oool008Woool00ol0VOooooooo`03oooo00<0
000co`0co`0043?o00030000oooooooo07_oool008Woool00ol0VOooooooo`03oooo00<0000co`0c
o`0043?o00030000oooooooo07_oool008Woool00ol0VOooooooo`03oooo0P00014co`000`000?oo
ooooo`1koooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo0029
oooo00?o09Woooooool00oooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo0029oooo00?o
09Woooooool00oooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo0029oooo00?o09Wooooo
ool00oooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo0029oooo00?o09Woooooool00ooo
o`80000@<ol000<0003oooooool0O?ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000>
<ol000<0003oooooool0OOooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000><ol000<0003ooooo
ool0OOooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000><ol000<0003oooooool0OOoo
o`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00ROoo
o`03o`2Ioooooooo00?oool200003S?o00030000oooooooo07koool008Woool00ol0VOooooooo`03
oooo00<0000co`0co`003C?o00030000oooooooo07koool008Woool00ol0VOooooooo`03oooo00<0
000co`0co`003C?o00030000oooooooo07koool008Woool00ol0VOooooooo`03oooo00<0000co`0c
o`003C?o00030000oooooooo07koool008Woool00ol0VOooooooo`03oooo00<0000co`0co`0033?o
00030000oooooooo07ooool008Woool300000oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo0029oooo00?o09T0003oool00oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0027
oooo1@0000?oool3000033?o00030000oooooooo07ooool008Ooool010000?ooooooo`0000Coool?
<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool0
08ooool?<ol0P_ooo`00Soooo`lco`22oooo001foooo00<0003oooooool05_ooo`hco`0:oooo00<0
003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0<oooo3S?o00_oool0
0`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?oo
o`03<ol00000000000@co`02000013?o00800004oooo0P0000Coool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00?oool0100003?o03?o000000Pco`00100003?o0?ooo`0000;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool0100003?o
03?o000000Pco`00100003?o0?ooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0M?oo
o`00MOooo`030000oooooooo00D0000Boooo00@0000co`0co`000008<ol000@0000co`3oool00003
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000
<ol0<ol0000023?o00040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1e
oooo001foooo00<0003oooooool05_ooo`03<ol00000000000Xco`0200001?ooo`<00002oooo00<0
003oooooool0M_ooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47567 .12361 L
.47791 .12361 L
.47889 .12361 L
.47994 .12361 L
s
.47994 .12361 m
.48043 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo00;oool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0doooo00?o
09Woooooool00_ooo`030000<ol0<ol003Tco`000`0003?o03?o000f<ol01@0001Ooool008[oool0
0ol0VOooooooo`02oooo00<0000co`0co`00JS?o00P0000Loooo002:oooo00?o09Woooooool00_oo
o`030000<ol0<ol006@co`0600009?ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o001O
<ol01@0002[oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`00FS?o00D0000_oooo002:
oooo00?o09Woooooool00_ooo`80001F<ol01@0003Coool008[oool00ol0VOooooooo`02oooo00<0
000co`0co`00DC?o00@0000ioooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol004lco`02
0000?Oooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o001<<ol00`0003ooool008[oool0
0ol0VOooooooo`02oooo00<0000co`0co`00BS?o00800012oooo002:oooo00?o09Woooooool00_oo
o`030000<ol0<ol004Pco`020000A?ooo`00R_ooo`03o`2Ioooooooo00;oool20000Ac?o00800016
oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol004@co`020000B?ooo`00R_ooo`03o`2I
oooooooo00;oool00`0003?o03?o0013<ol000<0003oooooool0B?ooo`00R_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o0011<ol00P0004_oool008[oool00ol0VOooooooo`02oooo00<0000co`0c
o`00?c?o0080001=oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol003hco`000`000?oo
ooooo`1=oooo002:oooo00?o09Woooooool00_ooo`80000m<ol00P00053oool008[oool00ol0VOoo
ooooo`02oooo00<0000co`0co`00>S?o0080001Boooo002:oooo00?o09Woooooool00_ooo`030000
<ol0<ol003Tco`000`000?ooooooo`1Boooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0
03Pco`000`000?ooooooo`1Coooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol003Hco`02
0000E_ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000e<ol000<0003oooooool0E_oo
o`00R_ooo`03o`2Ioooooooo00;oool20000=C?o00030000oooooooo05Ooool008[oool00ol0VOoo
ooooo`02oooo00<0000co`0co`00<c?o00030000oooooooo05Soool008[oool00ol0VOooooooo`02
oooo00<0000co`0co`00<S?o00030000oooooooo05Woool008[oool00ol0VOooooooo`02oooo00<0
000co`0co`00<C?o00030000oooooooo05[oool008[oool00ol0VOooooooo`02oooo00<0000co`0c
o`00<C?o00030000oooooooo05[oool008Ooool500000oooo`030000<ol0<ol0030co`000`000?oo
ooooo`1Koooo0029oooo00<0003o09Woool00oooo`030000<ol0<ol002lco`000`000?ooooooo`1L
oooo0029oooo00<0003o09Woool00oooo`<0000^<ol000<0003oooooool0GOooo`00ROooo`030000
o`2Ioooo00?oool00`0003?o03?o000^<ol000<0003oooooool0GOooo`00ROooo`030000o`2Ioooo
00?oool00`0003?o03?o000]<ol000<0003oooooool0G_ooo`00R?ooo`8000000ol0VOooooooo`02
oooo00<0000co`0co`00;3?o00030000oooooooo05ooool008[oool00ol0VOooooooo`02oooo00<0
000co`0co`00:c?o00030000oooooooo063oool008[oool00ol0VOooooooo`02oooo00<0000co`0c
o`00:c?o00030000oooooooo063oool008[oool00ol0VOooooooo`02oooo0P0002/co`000`000?oo
ooooo`1Qoooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol002Tco`000`000?ooooooo`1R
oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol002Tco`000`000?ooooooo`1Roooo002:
oooo00?o09Woooooool00_ooo`030000<ol0<ol002Pco`000`000?ooooooo`1Soooo002:oooo00?o
09Woooooool00_ooo`030000<ol0<ol002Lco`000`000?ooooooo`1Toooo002:oooo00?o09Wooooo
ool00_ooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo002:oooo00?o09Woooooool00_oo
o`80000W<ol000<0003oooooool0IOooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000U
<ol000<0003oooooool0I_ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000T<ol000<0003ooooo
ool0Ioooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000S<ol000<0003oooooool0J?oo
o`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000S<ol000<0003oooooool0J?ooo`00R_oo
o`03o`2Ioooooooo00;oool00`0003?o03?o000R<ol000<0003oooooool0JOooo`00R_ooo`03o`2I
oooooooo00;oool200008c?o00030000oooooooo06Woool008[oool00ol0VOooooooo`02oooo00<0
000co`0co`008C?o00030000oooooooo06[oool008[oool00ol0VOooooooo`02oooo00<0000co`0c
o`008C?o00030000oooooooo06[oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`0083?o
00030000oooooooo06_oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`0083?o00030000
oooooooo06_oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`0083?o00030000oooooooo
06_oool008[oool00ol0VOooooooo`02oooo0P00020co`000`000?ooooooo`1/oooo002:oooo00?o
09Woooooool00_ooo`030000<ol0<ol001lco`000`000?ooooooo`1/oooo002:oooo00?o09Wooooo
ool00_ooo`030000<ol0<ol001hco`000`000?ooooooo`1]oooo002:oooo00?o09Woooooool00_oo
o`030000<ol0<ol001hco`000`000?ooooooo`1]oooo0027oooo100000Coool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00Qoooo`040000ooooooooo`2I1?ooo`030000<ol0<ol001dco`00
0`000?ooooooo`1^oooo0028oooo00<0003ooooo09T01?ooo`<0000M<ol000<0003oooooool0K_oo
o`00ROooo`030000o`2Ioooo00?oool00`0003?o03?o000M<ol000<0003oooooool0K_ooo`00Qooo
o`040000oooooooo00001?ooo`030000<ol0<ol001`co`000`000?ooooooo`1_oooo0028oooo0P00
0003o`2Ioooooooo00;oool00`0003?o03?o000L<ol000<0003oooooool0Koooo`00R_ooo`03o`2I
oooooooo00;oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00R_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00R_ooo`03o`2Ioooooooo00;oool2
000073?o00030000oooooooo073oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`006S?o
00030000oooooooo077oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`006S?o00030000
oooooooo077oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`006S?o00030000oooooooo
077oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`006S?o00030000oooooooo077oool0
08[oool00ol0VOooooooo`02oooo00<0000co`0co`006C?o00030000oooooooo07;oool008[oool0
0ol0VOooooooo`02oooo00<0000co`0co`006C?o00030000oooooooo07;oool008[oool00ol0VOoo
ooooo`02oooo0P0001Xco`000`000?ooooooo`1boooo002:oooo00?o09Woooooool00_ooo`030000
<ol0<ol001Pco`000`000?ooooooo`1coooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0
01Pco`000`000?ooooooo`1coooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1coooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol001Lco`000`000?oo
ooooo`1doooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol001Lco`000`000?ooooooo`1d
oooo002:oooo00?o09Woooooool00_ooo`80000H<ol000<0003oooooool0M?ooo`00R_ooo`03o`2I
oooooooo00;oool00`0003?o03?o000G<ol000<0003oooooool0M?ooo`00R_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00R_ooo`03o`2Ioooooooo00;oool0
0`0003?o03?o000F<ol000<0003oooooool0MOooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o
03?o000F<ol000<0003oooooool0MOooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000E
<ol000<0003oooooool0M_ooo`00R_ooo`03o`2Ioooooooo00;oool200005S?o00030000oooooooo
07Koool008[oool00ol0VOooooooo`02oooo00<0000co`0co`005C?o00030000oooooooo07Koool0
08[oool00ol0VOooooooo`02oooo00<0000co`0co`005C?o00030000oooooooo07Koool008[oool0
0ol0VOooooooo`02oooo00<0000co`0co`0053?o00030000oooooooo07Ooool008Soool2000000?o
09Woooooool00_ooo`030000<ol0<ol001@co`000`000?ooooooo`1goooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`0053?o00030000oooooooo07Ooool008Woool00`000?l0VOooo`03
oooo0`0001<co`000`000?ooooooo`1hoooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol0
01<co`000`000?ooooooo`1hoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`004c?o
00030000oooooooo07Soool008Soool2000000?o09Woooooool00_ooo`030000<ol0<ol0018co`00
0`000?ooooooo`1ioooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0018co`000`000?oo
ooooo`1ioooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0018co`000`000?ooooooo`1i
oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo002:
oooo00?o09Woooooool00_ooo`80000B<ol000<0003oooooool0N_ooo`00R_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00R_ooo`03o`2Ioooooooo00;oool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o
03?o000A<ol000<0003oooooool0N_ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000@
<ol000<0003oooooool0Noooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000@<ol000<0
003oooooool0Noooo`00R_ooo`03o`2Ioooooooo00;oool200004C?o00030000oooooooo07_oool0
08[oool00ol0VOooooooo`02oooo00<0000co`0co`0043?o00030000oooooooo07_oool008[oool0
0ol0VOooooooo`02oooo00<0000co`0co`003c?o00030000oooooooo07coool008[oool00ol0VOoo
ooooo`02oooo00<0000co`0co`003c?o00030000oooooooo07coool008[oool00ol0VOooooooo`02
oooo00<0000co`0co`003c?o00030000oooooooo07coool008[oool00ol0VOooooooo`02oooo00<0
000co`0co`003c?o00030000oooooooo07coool008[oool00ol0VOooooooo`02oooo0P00010co`00
0`000?ooooooo`1loooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000hco`000`000?oo
ooooo`1moooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000hco`000`000?ooooooo`1m
oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo002:
oooo00?o09Woooooool00_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo002:oooo00?o
09Woooooool00_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo002:oooo00?o09Wooooo
ool00_ooo`80000><ol000<0003oooooool0O_ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000=
<ol000<0003oooooool0O_ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000=<ol000<0
003oooooool0O_ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00ROooo`<00003oooo00<0000co`0co`0033?o00030000oooooooo07ooool008[oool0
0`000?ooooooo`02oooo00<0000co`0co`0033?o00030000oooooooo07ooool008Ooool500000ooo
o`<0000<<ol000<0003oooooool0Ooooo`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028
oooo00<0003oool000001?ooo`lco`22oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22
oooo002?oooo3c?o08;oool007Koool00`000?ooooooo`0Foooo3S?o00[oool00`000?ooooooo`1f
oooo001eoooo00<0003oooooool02?ooo`030000oooooooo00coool><ol02oooo`030000oooooooo
07Goool007Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo00<co`000000
000013?o00800004<ol00P0000Goool300000_ooo`030000oooooooo07Goool007Goool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000
<ol0<ol0000023?o00040000<ol0oooo00001Oooo`050000oooooooooooo000007Ooool007Coool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000<ol0<ol0000023?o00040000<ol0oooo
00000_ooo`D00003oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0
000co`0co`000008<ol000@0000co`3oool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000001Goool0100003?o03?o000000Pco`0010000?oo
ooooo`0000?oool00`000?ooo`000003oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo
01Koool00c?o00000000000:<ol00P0000Goool200000_ooo`030000oooooooo07Koool008ooool=
<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47994 .12361 L
.48231 .12361 L
.48361 .12361 L
.48484 .12361 L
.48554 .12361 L
s
.48554 .12361 m
.48584 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool01Oooo`05o`2Ioooooooooooo000000/co`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Goool01Ol0VOoooooooooo
o`00000k<ol000<0000co`0co`00=S?o00D0000Goooo002;oooo00Go09Woooooooooool00000K3?o
00P0000Loooo002;oooo00Go09Woooooooooool00000IS?o00H0000Toooo002;oooo00Go09Wooooo
ooooool00000HC?o00D0000Zoooo002;oooo00Go09Woooooooooool00000G3?o00D0000_oooo002;
oooo00Co09Woooooooooool20000ES?o00D0000doooo002;oooo00Go09Woooooooooool00000Dc?o
00@0000ioooo002;oooo00Go09Woooooooooool00000DC?o0080000moooo002;oooo00Go09Wooooo
ooooool00000CS?o00<0000ooooo002;oooo00Go09Woooooooooool00000C3?o00800012oooo002;
oooo00Go09Woooooooooool00000BS?o00800014oooo002;oooo00Co09Woooooooooool20000Ac?o
00800016oooo002;oooo00Go09Woooooooooool00000AS?o00800018oooo002;oooo00Go09Wooooo
ooooool00000AC?o00030000oooooooo04Soool008_oool01Ol0VOooooooooooo`000013<ol00P00
04_oool008_oool01Ol0VOooooooooooo`000011<ol00P0004goool008_oool01Ol0VOoooooooooo
o`000010<ol000<0003oooooool0COooo`00Roooo`04o`2Ioooooooooooo0P0003dco`020000D?oo
o`00Roooo`05o`2Ioooooooooooo000003`co`020000D_ooo`00Roooo`05o`2Ioooooooooooo0000
03/co`000`000?ooooooo`1Boooo002;oooo00Go09Woooooooooool00000>S?o00030000oooooooo
05?oool008_oool01Ol0VOooooooooooo`00000h<ol00P0005Koool008_oool01Ol0VOoooooooooo
o`00000g<ol000<0003oooooool0E_ooo`00Roooo`04o`2Ioooooooooooo0P0003Dco`000`000?oo
ooooo`1Goooo002;oooo00Go09Woooooooooool00000=C?o00030000oooooooo05Soool008_oool0
1Ol0VOooooooooooo`00000d<ol000<0003oooooool0FOooo`00Roooo`05o`2Ioooooooooooo0000
03<co`000`000?ooooooo`1Joooo002;oooo00Go09Woooooooooool00000<c?o00030000oooooooo
05[oool008Ooool500000oooo`030000<ol0<ol0030co`000`000?ooooooo`1Koooo0029oooo00<0
003ooooo09T00oooo`030000<ol0<ol002lco`000`000?ooooooo`1Loooo0029oooo00<0003ooooo
09T00oooo`<0000^<ol000<0003oooooool0GOooo`00ROooo`030000ooooo`2I00?oool00`0003?o
03?o000^<ol000<0003oooooool0GOooo`00ROooo`030000ooooo`2I00?oool00`0003?o03?o000]
<ol000<0003oooooool0G_ooo`00R?ooo`8000000oooool0VOooo`02oooo00<0000co`0co`00;3?o
00030000oooooooo05ooool008_oool01Ol0VOooooooooooo`00000]<ol000<0003oooooool0H?oo
o`00Roooo`05o`2Ioooooooooooo000002dco`000`000?ooooooo`1Poooo002;oooo00Co09Wooooo
ooooool20000:c?o00030000oooooooo067oool008_oool01Ol0VOooooooooooo`00000[<ol000<0
003oooooool0H_ooo`00Roooo`05o`2Ioooooooooooo000002/co`000`000?ooooooo`1Roooo002;
oooo00Go09Woooooooooool00000:S?o00030000oooooooo06?oool008_oool01Ol0VOoooooooooo
o`00000Y<ol000<0003oooooool0I?ooo`00Roooo`05o`2Ioooooooooooo000002Pco`000`000?oo
ooooo`1Uoooo002;oooo00Co09Woooooooooool200009c?o00030000oooooooo06Goool008_oool0
1Ol0VOooooooooooo`00000W<ol000<0003oooooool0I_ooo`00Roooo`05o`2Ioooooooooooo0000
02Hco`000`000?ooooooo`1Woooo002;oooo00Go09Woooooooooool000009S?o00030000oooooooo
06Ooool008_oool01Ol0VOooooooooooo`00000U<ol000<0003oooooool0J?ooo`00Roooo`05o`2I
oooooooooooo000002Dco`000`000?ooooooo`1Xoooo002;oooo00Go09Woooooooooool0000093?o
00030000oooooooo06Woool008_oool01?l0VOooooooooooo`80000S<ol000<0003oooooool0JOoo
o`00Roooo`05o`2Ioooooooooooo000002<co`000`000?ooooooo`1Zoooo002;oooo00Go09Wooooo
ooooool000008c?o00030000oooooooo06[oool008_oool01Ol0VOooooooooooo`00000R<ol000<0
003oooooool0Joooo`00Roooo`05o`2Ioooooooooooo0000028co`000`000?ooooooo`1[oooo002;
oooo00Go09Woooooooooool000008S?o00030000oooooooo06_oool008_oool01?l0VOoooooooooo
o`80000P<ol000<0003oooooool0K?ooo`00Roooo`05o`2Ioooooooooooo0000024co`000`000?oo
ooooo`1/oooo002;oooo00Go09Woooooooooool0000083?o00030000oooooooo06goool008_oool0
1Ol0VOooooooooooo`00000P<ol000<0003oooooool0KOooo`00Qoooo`@000001Ol0VOoooooooooo
o`00000P<ol000<0003oooooool0KOooo`00Qoooo`050000ooooooooooooo`2I00?oool00`0003?o
03?o000M<ol000<0003oooooool0K_ooo`00R?ooo`040000ooooooooo`2I0oooo`<0000M<ol000<0
003oooooool0K_ooo`00ROooo`030000ooooo`2I00?oool00`0003?o03?o000M<ol000<0003ooooo
ool0K_ooo`00Qoooo`050000oooooooo0000o`2I00?oool00`0003?o03?o000L<ol000<0003ooooo
ool0Koooo`00R?ooo`8000000oooool0VOooo`02oooo00<0000co`0co`0073?o00030000oooooooo
06ooool008_oool01Ol0VOooooooooooo`00000M<ol000<0003oooooool0L?ooo`00Roooo`05o`2I
oooooooooooo000001dco`000`000?ooooooo`1`oooo002;oooo00Co09Woooooooooool2000073?o
00030000oooooooo073oool008_oool01Ol0VOooooooooooo`00000L<ol000<0003oooooool0LOoo
o`00Roooo`05o`2Ioooooooooooo000001`co`000`000?ooooooo`1aoooo002;oooo00Go09Wooooo
ooooool0000073?o00030000oooooooo077oool008_oool01Ol0VOooooooooooo`00000L<ol000<0
003oooooool0LOooo`00Roooo`05o`2Ioooooooooooo000001/co`000`000?ooooooo`1boooo002;
oooo00Go09Woooooooooool000006c?o00030000oooooooo07;oool008_oool01?l0VOoooooooooo
o`80000J<ol000<0003oooooool0L_ooo`00Roooo`05o`2Ioooooooooooo000001Xco`000`000?oo
ooooo`1coooo002;oooo00Go09Woooooooooool000006S?o00030000oooooooo07?oool008_oool0
1Ol0VOooooooooooo`00000J<ol000<0003oooooool0Loooo`00Roooo`05o`2Ioooooooooooo0000
01Tco`000`000?ooooooo`1doooo002;oooo00Go09Woooooooooool000006C?o00030000oooooooo
07Coool008_oool01?l0VOooooooooooo`80000H<ol000<0003oooooool0M?ooo`00Roooo`05o`2I
oooooooooooo000001Tco`000`000?ooooooo`1doooo002;oooo00Go09Woooooooooool0000063?o
00030000oooooooo07Goool008_oool01Ol0VOooooooooooo`00000H<ol000<0003oooooool0MOoo
o`00Roooo`05o`2Ioooooooooooo000001Pco`000`000?ooooooo`1eoooo002;oooo00Go09Wooooo
ooooool000005c?o00030000oooooooo07Koool008_oool01?l0VOooooooooooo`80000F<ol000<0
003oooooool0M_ooo`00Roooo`05o`2Ioooooooooooo000001Lco`000`000?ooooooo`1foooo002;
oooo00Go09Woooooooooool000005c?o00030000oooooooo07Koool008_oool01Ol0VOoooooooooo
o`00000F<ol000<0003oooooool0Moooo`00R?ooo`8000000oooool0VOooo`02oooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool008Ooool01@000?ooooooo`000?l0V@03oooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool008Woool00`000?ooool0V@03oooo0`0001<co`000`000?oo
ooooo`1hoooo002:oooo00<0003o09Woool00_ooo`030000<ol0<ol001<co`000`000?ooooooo`1h
oooo0027oooo00D0003oooooool0003o09T00oooo`030000<ol0<ol001<co`000`000?ooooooo`1h
oooo0028oooo0P000003ooooo`2Ioooo00;oool00`0003?o03?o000B<ol000<0003oooooool0NOoo
o`00Roooo`05o`2Ioooooooooooo000001@co`000`000?ooooooo`1ioooo002;oooo00Go09Wooooo
ooooool0000053?o00030000oooooooo07Woool008_oool01Ol0VOooooooooooo`00000D<ol000<0
003oooooool0NOooo`00Roooo`04o`2Ioooooooooooo0P00018co`000`000?ooooooo`1joooo002;
oooo00Go09Woooooooooool000004c?o00030000oooooooo07[oool008_oool01Ol0VOoooooooooo
o`00000C<ol000<0003oooooool0N_ooo`00Roooo`05o`2Ioooooooooooo000001<co`000`000?oo
ooooo`1joooo002;oooo00Go09Woooooooooool000004S?o00030000oooooooo07_oool008_oool0
1Ol0VOooooooooooo`00000B<ol000<0003oooooool0Noooo`00Roooo`04o`2Ioooooooooooo0P00
014co`000`000?ooooooo`1koooo002;oooo00Go09Woooooooooool000004S?o00030000oooooooo
07_oool008_oool01Ol0VOooooooooooo`00000A<ol000<0003oooooool0O?ooo`00Roooo`05o`2I
oooooooooooo0000014co`000`000?ooooooo`1loooo002;oooo00Go09Woooooooooool000004C?o
00030000oooooooo07coool008_oool01Ol0VOooooooooooo`00000A<ol000<0003oooooool0O?oo
o`00Roooo`04o`2Ioooooooooooo0P00010co`000`000?ooooooo`1loooo002;oooo00Go09Wooooo
ooooool0000043?o00030000oooooooo07goool008_oool01Ol0VOooooooooooo`00000@<ol000<0
003oooooool0OOooo`00Roooo`05o`2Ioooooooooooo0000010co`000`000?ooooooo`1moooo002;
oooo00Go09Woooooooooool0000043?o00030000oooooooo07goool008_oool01Ol0VOoooooooooo
o`00000@<ol000<0003oooooool0OOooo`00Roooo`04o`2Ioooooooooooo0P0000hco`000`000?oo
ooooo`1noooo002;oooo00Go09Woooooooooool000003c?o00030000oooooooo07koool008_oool0
1Ol0VOooooooooooo`00000?<ol000<0003oooooool0O_ooo`00Roooo`05o`2Ioooooooooooo0000
00lco`000`000?ooooooo`1noooo002;oooo00Go09Woooooooooool000003S?o00030000oooooooo
07ooool008Woool300000oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo002:oooo00<0
003o09Woool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0027oooo1@0000?oool3
000033?o00030000oooooooo07ooool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?oo
o`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_oo
o`00Soooo`lco`22oooo001foooo00<0003oooooool05_ooo`hco`0:oooo00<0003oooooool0M_oo
o`00MOooo`030000oooooooo00Soool00`000?ooooooo`0<oooo3S?o00_oool00`000?ooooooo`1e
oooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`03<ol000000000
00@co`02000013?o00800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool0100003?o
03?o000000Pco`00100003?o0?ooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1e
oooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool0100003?o03?o000000Pco`00
100003?o0?ooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0M?ooo`00MOooo`030000
oooooooo00D0000Boooo00@0000co`0co`000008<ol000@0000co`3oool00005oooo00D0003ooooo
ooooool00000Moooo`00MOooo`050000oooooooooooo000001Goool0100003?o03?o000000Pco`00
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001foooo00<0
003oooooool05_ooo`03<ol00000000000Xco`0200001?ooo`800003oooo00<0003oooooool0M_oo
o`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47994 .12361 L
.48519 .12361 L
.48778 .12361 L
.48904 .12361 L
.49018 .12361 L
s
.49018 .12361 m
.49063 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool01_ooo`04o`2Ioooooooo00002c?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Xco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000oooooooo
01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0=_ooo`04o`2Ioooooooo0000>c?o
00030000<ol0<ol003Hco`0500005oooo`00S?ooo`04o`2Ioooooooo0000K3?o00P0000Loooo002<
oooo00Co09Woooooool0001V<ol01P0002Coool008coool01?l0VOooooooo`00064co`050000:_oo
o`00S?ooo`04o`2Ioooooooo0000G3?o00D0000_oooo002<oooo00?o09Woooooool00P0005Hco`05
0000=?ooo`00S?ooo`04o`2Ioooooooo0000Dc?o00@0000ioooo002<oooo00Co09Woooooool0001A
<ol00P0003goool008coool01?l0VOooooooo`0004hco`030000?oooo`00S?ooo`04o`2Ioooooooo
0000C3?o00800012oooo002<oooo00Co09Woooooool0001:<ol00P0004Coool008coool00ol0VOoo
ooooo`020000Ac?o00800016oooo002<oooo00Co09Woooooool00016<ol00P0004Soool008coool0
1?l0VOooooooo`0004Dco`000`000?ooooooo`18oooo002<oooo00Co09Woooooool00013<ol00P00
04_oool008coool01?l0VOooooooo`00044co`020000COooo`00S?ooo`04o`2Ioooooooo0000@3?o
00030000oooooooo04goool008coool00ol0VOooooooo`020000?C?o0080001@oooo002<oooo00Co
09Woooooool0000l<ol00P0005;oool008coool01?l0VOooooooo`0003/co`000`000?ooooooo`1B
oooo002<oooo00Co09Woooooool0000j<ol000<0003oooooool0Doooo`00S?ooo`04o`2Ioooooooo
0000>3?o0080001Foooo002<oooo00Co09Woooooool0000g<ol000<0003oooooool0E_ooo`00S?oo
o`03o`2Ioooooooo0080000e<ol000<0003oooooool0Eoooo`00S?ooo`04o`2Ioooooooo0000=C?o
00030000oooooooo05Soool008coool01?l0VOooooooo`0003@co`000`000?ooooooo`1Ioooo002<
oooo00Co09Woooooool0000c<ol000<0003oooooool0F_ooo`00S?ooo`04o`2Ioooooooo0000<c?o
00030000oooooooo05[oool008Ooool5000000Co09Woooooool0000b<ol000<0003oooooool0Fooo
o`00ROooo`040000ooooooooo`2I0_ooo`030000<ol0<ol002lco`000`000?ooooooo`1Loooo0029
oooo00@0003ooooooooo09T2oooo0`0002hco`000`000?ooooooo`1Moooo0029oooo00@0003ooooo
oooo09T2oooo00<0000co`0co`00;S?o00030000oooooooo05goool008Woool010000?ooooooool0
V@;oool00`0003?o03?o000]<ol000<0003oooooool0G_ooo`00R?ooo`800002oooo00Co09Wooooo
ool0000^<ol000<0003oooooool0Goooo`00S?ooo`04o`2Ioooooooo0000;C?o00030000oooooooo
063oool008coool01?l0VOooooooo`0002dco`000`000?ooooooo`1Poooo002<oooo00?o09Wooooo
ool00P0002/co`000`000?ooooooo`1Qoooo002<oooo00Co09Woooooool0000[<ol000<0003ooooo
ool0H_ooo`00S?ooo`04o`2Ioooooooo0000:c?o00030000oooooooo06;oool008coool01?l0VOoo
ooooo`0002Xco`000`000?ooooooo`1Soooo002<oooo00Co09Woooooool0000Y<ol000<0003ooooo
ool0I?ooo`00S?ooo`04o`2Ioooooooo0000:3?o00030000oooooooo06Goool008coool00ol0VOoo
ooooo`0200009c?o00030000oooooooo06Goool008coool01?l0VOooooooo`0002Lco`000`000?oo
ooooo`1Voooo002<oooo00Co09Woooooool0000V<ol000<0003oooooool0Ioooo`00S?ooo`04o`2I
oooooooo00009S?o00030000oooooooo06Ooool008coool01?l0VOooooooo`0002Dco`000`000?oo
ooooo`1Xoooo002<oooo00Co09Woooooool0000U<ol000<0003oooooool0J?ooo`00S?ooo`04o`2I
oooooooo000093?o00030000oooooooo06Woool008coool00ol0VOooooooo`0200008c?o00030000
oooooooo06Woool008coool01?l0VOooooooo`0002<co`000`000?ooooooo`1Zoooo002<oooo00Co
09Woooooool0000S<ol000<0003oooooool0J_ooo`00S?ooo`04o`2Ioooooooo00008S?o00030000
oooooooo06_oool008coool01?l0VOooooooo`00028co`000`000?ooooooo`1[oooo002<oooo00Co
09Woooooool0000R<ol000<0003oooooool0Joooo`00S?ooo`03o`2Ioooooooo0080000P<ol000<0
003oooooool0K?ooo`00S?ooo`04o`2Ioooooooo00008C?o00030000oooooooo06coool008coool0
1?l0VOooooooo`00020co`000`000?ooooooo`1]oooo002<oooo00Co09Woooooool0000P<ol000<0
003oooooool0KOooo`00Qoooo`@000001Oooool0VOooooooo`00000P<ol000<0003oooooool0KOoo
o`00Qoooo`030000oooooooo00;oool01?l0VOooooooo`0001lco`000`000?ooooooo`1^oooo0028
oooo00D0003ooooooooooooo09T00_ooo`<0000M<ol000<0003oooooool0K_ooo`00ROooo`070000
ooooooooooooo`2Ioooo000001lco`000`000?ooooooo`1^oooo0027oooo00@0003oooooool00002
oooo00?o09Woool000007S?o00030000oooooooo06ooool008Soool200000oooo`03o`2Ioooo0000
01hco`000`000?ooooooo`1_oooo002=oooo00?o09Woool000007C?o00030000oooooooo073oool0
08goool00ol0VOooo`00000M<ol000<0003oooooool0L?ooo`00SOooo`04o`2Ioooo0000000073?o
00030000oooooooo073oool008goool00ol0VOooo`00000L<ol000<0003oooooool0LOooo`00SOoo
o`03o`2Ioooo000001`co`000`000?ooooooo`1aoooo002=oooo00?o09Woool0000073?o00030000
oooooooo077oool008goool00ol0VOooo`00000L<ol000<0003oooooool0LOooo`00SOooo`03o`2I
oooo000001/co`000`000?ooooooo`1boooo002=oooo00?o09Woool000006c?o00030000oooooooo
07;oool008goool01?l0VOooo`00000001Xco`000`000?ooooooo`1boooo002=oooo00?o09Woool0
00006S?o00030000oooooooo07?oool008goool00ol0VOooo`00000J<ol000<0003oooooool0Looo
o`00SOooo`03o`2Ioooo000001Xco`000`000?ooooooo`1coooo002=oooo00?o09Woool000006C?o
00030000oooooooo07Coool008goool00ol0VOooo`00000I<ol000<0003oooooool0M?ooo`00SOoo
o`04o`2Ioooo0000000063?o00030000oooooooo07Coool008goool00ol0VOooo`00000I<ol000<0
003oooooool0M?ooo`00SOooo`03o`2Ioooo000001Pco`000`000?ooooooo`1eoooo002=oooo00?o
09Woool0000063?o00030000oooooooo07Goool008goool00ol0VOooo`00000H<ol000<0003ooooo
ool0MOooo`00SOooo`03o`2Ioooo000001Lco`000`000?ooooooo`1foooo002=oooo00Co09Woool0
0000000F<ol000<0003oooooool0M_ooo`00SOooo`03o`2Ioooo000001Lco`000`000?ooooooo`1f
oooo002=oooo00?o09Woool000005c?o00030000oooooooo07Koool008goool00ol0VOooo`00000F
<ol000<0003oooooool0Moooo`00R?ooo`800003oooo00?o09Woool000005S?o00030000oooooooo
07Ooool008Ooool010000?ooooooo`0000;oool00ol0VOooo`00000F<ol000<0003oooooool0Mooo
o`00ROooo`060000ooooooooooooo`2Ioooo0`0001<co`000`000?ooooooo`1hoooo002:oooo00H0
003ooooooooo09Woool0000E<ol000<0003oooooool0N?ooo`00Qoooo`040000oooooooo00000_oo
o`03o`2Ioooo000001Dco`000`000?ooooooo`1hoooo0028oooo0P0000?oool00ol0VOooo`00000D
<ol000<0003oooooool0NOooo`00SOooo`03o`2Ioooo000001@co`000`000?ooooooo`1ioooo002=
oooo00?o09Woool0000053?o00030000oooooooo07Woool008goool00ol0VOooo`00000D<ol000<0
003oooooool0NOooo`00SOooo`04o`2Ioooo000000004S?o00030000oooooooo07[oool008goool0
0ol0VOooo`00000C<ol000<0003oooooool0N_ooo`00SOooo`03o`2Ioooo000001<co`000`000?oo
ooooo`1joooo002=oooo00?o09Woool000004c?o00030000oooooooo07[oool008goool00ol0VOoo
o`00000B<ol000<0003oooooool0Noooo`00SOooo`03o`2Ioooo0000018co`000`000?ooooooo`1k
oooo002=oooo00Co09Woool00000000A<ol000<0003oooooool0Noooo`00SOooo`03o`2Ioooo0000
018co`000`000?ooooooo`1koooo002=oooo00?o09Woool000004C?o00030000oooooooo07coool0
08goool00ol0VOooo`00000A<ol000<0003oooooool0O?ooo`00SOooo`03o`2Ioooo0000014co`00
0`000?ooooooo`1loooo002=oooo00?o09Woool000004C?o00030000oooooooo07coool008goool0
1?l0VOooo`000000010co`000`000?ooooooo`1loooo002=oooo00?o09Woool0000043?o00030000
oooooooo07goool008goool00ol0VOooo`00000@<ol000<0003oooooool0OOooo`00SOooo`03o`2I
oooo0000010co`000`000?ooooooo`1moooo002=oooo00?o09Woool0000043?o00030000oooooooo
07goool008goool00ol0VOooo`00000@<ol000<0003oooooool0OOooo`00SOooo`04o`2Ioooo0000
00003S?o00030000oooooooo07koool008goool00ol0VOooo`00000?<ol000<0003oooooool0O_oo
o`00SOooo`03o`2Ioooo000000lco`000`000?ooooooo`1noooo002=oooo00?o09Woool000003c?o
00030000oooooooo07koool008goool00ol0VOooo`00000><ol000<0003oooooool0Ooooo`00ROoo
o`<000001?ooool0VOooo`0000hco`000`000?ooooooo`1ooooo002:oooo00H0003ooooooooo09Wo
ool0000><ol000<0003oooooool0Ooooo`00Qoooo`D000000oooool0VOooo`03000033?o00030000
oooooooo07ooool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo0000
00Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22
oooo001foooo00<0003oooooool05_ooo`hco`0:oooo00<0003oooooool0M_ooo`00MOooo`030000
oooooooo00Soool00`000?ooooooo`0<oooo3S?o00_oool00`000?ooooooo`1eoooo001eoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`03<ol00000000000@co`02000013?o
00800003oooo100000?oool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool0100003?o03?o000000Pco`00
100003?o0?ooo`0000;oool00`000?ooooooo`04oooo00<0003oooooool0MOooo`00M?ooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0000co`0co`000008<ol000@0000co`3oool00003
oooo00<0003oooooool01?ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_oo
o`040000<ol0<ol0000023?o00040000<ol0oooo00001?ooo`030000oooooooo00;oool00`000?oo
ooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000<ol0<ol0000023?o00040000
oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool007Koool00`000?oo
ooooo`0Foooo00<co`00000000002S?o00800004oooo0P0000?oool00`000?ooooooo`1foooo002?
oooo3C?o08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47994 .12361 L
.48519 .12361 L
.49018 .12361 L
.49235 .12361 L
.49354 .12361 L
.49466 .12361 L
s
.49466 .12361 m
.49492 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02?ooo`03o`2I0000<ol000Xco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Soool00ol0V@0003?o000j<ol000<0
000co`0co`00=S?o00D0000Goooo002>oooo00?o09T0000co`00Jc?o00P0000Loooo002>oooo00?o
09T0000co`00IC?o00H0000Toooo002>oooo00?o09T0000co`00H3?o00D0000Zoooo002>oooo00?o
09T0000co`00Fc?o00D0000_oooo002>oooo00?o09T000000000ES?o00D0000doooo002>oooo00?o
09T0000co`00DS?o00@0000ioooo002>oooo00?o09T0000co`00D3?o0080000moooo002>oooo00?o
09T0000co`00CC?o00<0000ooooo002>oooo00?o09T0000co`00Bc?o00800012oooo002>oooo00?o
09T0000co`00BC?o00800014oooo002>oooo00?o09T000000000Ac?o00800016oooo002>oooo00?o
09T0000co`00AC?o00800018oooo002>oooo00?o09T0000co`00A3?o00030000oooooooo04Soool0
08koool00ol0V@0003?o0012<ol00P0004_oool008koool00ol0V@0003?o0010<ol00P0004goool0
08koool00ol0V@0003?o000o<ol000<0003oooooool0COooo`00S_ooo`03o`2I0000000003dco`02
0000D?ooo`00S_ooo`03o`2I0000<ol003/co`020000D_ooo`00S_ooo`03o`2I0000<ol003Xco`00
0`000?ooooooo`1Boooo002>oooo00?o09T0000co`00>C?o00030000oooooooo05?oool008koool0
0ol0V@0003?o000g<ol00P0005Koool008koool00ol0V@0003?o000f<ol000<0003oooooool0E_oo
o`00S_ooo`03o`2I0000000003Dco`000`000?ooooooo`1Goooo002>oooo00?o09T0000co`00=3?o
00030000oooooooo05Soool008koool00ol0V@0003?o000c<ol000<0003oooooool0FOooo`00S_oo
o`03o`2I0000<ol0038co`000`000?ooooooo`1Joooo002>oooo00?o09T0000co`00<S?o00030000
oooooooo05[oool008Ooool500000_ooo`03o`2I0000<ol0034co`000`000?ooooooo`1Koooo0029
oooo00<0003oooooool00_ooo`03o`2I0000<ol0030co`000`000?ooooooo`1Loooo0029oooo00<0
003oooooool00_ooo`04o`2I000000000000;S?o00030000oooooooo05goool008Woool00`000?oo
ooooo`02oooo00?o09T0000co`00;c?o00030000oooooooo05goool008Woool00`000?ooooooo`02
oooo00?o09T0000co`00;S?o00030000oooooooo05koool008Soool200001?ooo`03o`2I0000<ol0
02dco`000`000?ooooooo`1Ooooo002>oooo00?o09T0000co`00;3?o00030000oooooooo063oool0
08koool00ol0V@0003?o000/<ol000<0003oooooool0H?ooo`00S_ooo`03o`2I0000000002/co`00
0`000?ooooooo`1Qoooo002>oooo00?o09T0000co`00:S?o00030000oooooooo06;oool008koool0
0ol0V@0003?o000Z<ol000<0003oooooool0H_ooo`00S_ooo`03o`2I0000<ol002Tco`000`000?oo
ooooo`1Soooo002>oooo00?o09T0000co`00:3?o00030000oooooooo06Coool008koool00ol0V@00
03?o000W<ol000<0003oooooool0IOooo`00S_ooo`03o`2I0000000002Lco`000`000?ooooooo`1U
oooo002>oooo00?o09T0000co`009S?o00030000oooooooo06Koool008koool00ol0V@0003?o000U
<ol000<0003oooooool0Ioooo`00S_ooo`03o`2I0000<ol002Dco`000`000?ooooooo`1Woooo002>
oooo00?o09T0000co`0093?o00030000oooooooo06Soool008koool00ol0V@0003?o000T<ol000<0
003oooooool0J?ooo`00S_ooo`03o`2I0000<ol002<co`000`000?ooooooo`1Yoooo002>oooo00?o
09T0000000008c?o00030000oooooooo06Woool008koool00ol0V@0003?o000R<ol000<0003ooooo
ool0J_ooo`00S_ooo`03o`2I0000<ol0028co`000`000?ooooooo`1Zoooo002>oooo00?o09T0000c
o`008C?o00030000oooooooo06_oool008koool00ol0V@0003?o000Q<ol000<0003oooooool0Jooo
o`00S_ooo`03o`2I0000<ol0024co`000`000?ooooooo`1[oooo002>oooo00?o09T00000000083?o
00030000oooooooo06coool008koool00ol0V@0003?o000P<ol000<0003oooooool0K?ooo`00S_oo
o`03o`2I0000<ol001lco`000`000?ooooooo`1]oooo002>oooo00?o09T0000co`007c?o00030000
oooooooo06goool008Ooool400000oooo`03o`2I0000<ol001lco`000`000?ooooooo`1]oooo0027
oooo00<0003oooooool01?ooo`03o`2I0000<ol001hco`000`000?ooooooo`1^oooo0028oooo00<0
003oooooool00oooo`04o`2I0000000000007C?o00030000oooooooo06koool008Woool00`000?oo
ooooo`02oooo00?o09T0000co`007S?o00030000oooooooo06koool008Ooool010000?ooooooo`00
00?oool00ol0V@0003?o000M<ol000<0003oooooool0Koooo`00R?ooo`800004oooo00?o09T0000c
o`007C?o00030000oooooooo06ooool008koool00ol0V@0003?o000L<ol000<0003oooooool0L?oo
o`00S_ooo`03o`2I0000<ol001`co`000`000?ooooooo`1`oooo002>oooo00?o09T00000000073?o
00030000oooooooo073oool008koool00ol0V@0003?o000K<ol000<0003oooooool0LOooo`00S_oo
o`03o`2I0000<ol001/co`000`000?ooooooo`1aoooo002>oooo00?o09T0000co`006c?o00030000
oooooooo077oool008koool00ol0V@0003?o000K<ol000<0003oooooool0LOooo`00S_ooo`03o`2I
0000<ol001Xco`000`000?ooooooo`1boooo002>oooo00?o09T0000co`006S?o00030000oooooooo
07;oool008koool00ol0V@000000000J<ol000<0003oooooool0L_ooo`00S_ooo`03o`2I0000<ol0
01Tco`000`000?ooooooo`1coooo002>oooo00?o09T0000co`006C?o00030000oooooooo07?oool0
08koool00ol0V@0003?o000I<ol000<0003oooooool0Loooo`00S_ooo`03o`2I0000<ol001Pco`00
0`000?ooooooo`1doooo002>oooo00?o09T0000co`0063?o00030000oooooooo07Coool008koool0
0ol0V@000000000H<ol000<0003oooooool0M?ooo`00S_ooo`03o`2I0000<ol001Pco`000`000?oo
ooooo`1doooo002>oooo00?o09T0000co`005c?o00030000oooooooo07Goool008koool00ol0V@00
03?o000G<ol000<0003oooooool0MOooo`00S_ooo`03o`2I0000<ol001Lco`000`000?ooooooo`1e
oooo002>oooo00?o09T0000co`005S?o00030000oooooooo07Koool008koool00ol0V@000000000F
<ol000<0003oooooool0M_ooo`00S_ooo`03o`2I0000<ol001Hco`000`000?ooooooo`1foooo002>
oooo00?o09T0000co`005S?o00030000oooooooo07Koool008koool00ol0V@0003?o000E<ol000<0
003oooooool0Moooo`00R?ooo`800004oooo00?o09T0000co`005C?o00030000oooooooo07Ooool0
08Ooool010000?ooooooo`0000?oool00ol0V@0003?o000E<ol000<0003oooooool0Moooo`00ROoo
o`030000oooooooo00;oool01?l0V@000000000001<co`000`000?ooooooo`1hoooo002:oooo00H0
003ooooooooooooo09T0000E<ol000<0003oooooool0N?ooo`00Qoooo`040000oooooooo00000ooo
o`03o`2I0000<ol001@co`000`000?ooooooo`1hoooo0028oooo0P0000Coool00ol0V@0003?o000C
<ol000<0003oooooool0NOooo`00S_ooo`03o`2I0000<ol001<co`000`000?ooooooo`1ioooo002>
oooo00?o09T0000co`004c?o00030000oooooooo07Woool008koool00ol0V@0003?o000C<ol000<0
003oooooool0NOooo`00S_ooo`03o`2I00000000018co`000`000?ooooooo`1joooo002>oooo00?o
09T0000co`004S?o00030000oooooooo07[oool008koool00ol0V@0003?o000B<ol000<0003ooooo
ool0N_ooo`00S_ooo`03o`2I0000<ol0018co`000`000?ooooooo`1joooo002>oooo00?o09T0000c
o`004C?o00030000oooooooo07_oool008koool00ol0V@0003?o000A<ol000<0003oooooool0Nooo
o`00S_ooo`03o`2I00000000014co`000`000?ooooooo`1koooo002>oooo00?o09T0000co`004C?o
00030000oooooooo07_oool008koool00ol0V@0003?o000@<ol000<0003oooooool0O?ooo`00S_oo
o`03o`2I0000<ol0010co`000`000?ooooooo`1loooo002>oooo00?o09T0000co`0043?o00030000
oooooooo07coool008koool00ol0V@0003?o000@<ol000<0003oooooool0O?ooo`00S_ooo`03o`2I
00000000010co`000`000?ooooooo`1loooo002>oooo00?o09T0000co`003c?o00030000oooooooo
07goool008koool00ol0V@0003?o000?<ol000<0003oooooool0OOooo`00S_ooo`03o`2I0000<ol0
00lco`000`000?ooooooo`1moooo002>oooo00?o09T0000co`003c?o00030000oooooooo07goool0
08koool00ol0V@0003?o000?<ol000<0003oooooool0OOooo`00S_ooo`03o`2I0000000000hco`00
0`000?ooooooo`1noooo002>oooo00?o09T0000co`003S?o00030000oooooooo07koool008koool0
0ol0V@0003?o000><ol000<0003oooooool0O_ooo`00S_ooo`03o`2I0000<ol000hco`000`000?oo
ooooo`1noooo002>oooo00?o09T0000co`003C?o00030000oooooooo07ooool008Woool300000_oo
o`03o`2I0000<ol000dco`000`000?ooooooo`1ooooo002:oooo00H0003ooooooooooooo09T0000>
<ol000<0003oooooool0Ooooo`00Qoooo`D00002oooo00Co09T000000000000<<ol000<0003ooooo
ool0Ooooo`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?oo
o`lco`22oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool0
07Koool00`000?ooooooo`0Foooo3S?o00[oool00`000?ooooooo`1foooo001eoooo00<0003ooooo
ool02?ooo`030000oooooooo00coool><ol02oooo`030000oooooooo07Goool007Goool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo00<co`000000000013?o00800004<ol00P00
00?oool500000_ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000<ol0<ol0000023?o00040000
<ol0oooo00001?ooo`030000oooooooo00;oool00`000?ooooooo`1eoooo001doooo00<0003ooooo
ool00_ooo`030000oooooooo01?oool0100003?o03?o000000Pco`00100003?o0?ooo`0000Coool0
0`000?ooooooo`03oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0
000co`0co`000008<ol000@0000co`3oool00004oooo00<0003oooooool00_ooo`030000oooooooo
07Goool007Goool01@000?ooooooooooo`00000Eoooo00@0000co`0co`000008<ol000@0003ooooo
ool00004oooo00<0003oooooool00_ooo`030000oooooooo07Goool007Koool00`000?ooooooo`0F
oooo00<co`00000000002S?o00800004oooo0P0000?oool00`000?ooooooo`1foooo002?oooo3C?o
08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50007 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000i<ol000<0
000co`0co`00=S?o00D0000Goooo002?oooo00<0000co`0co`00JS?o00P0000Loooo002?oooo00<0
000co`0co`00I3?o00H0000Toooo002?oooo00<0000co`0co`00Gc?o00D0000Zoooo002?oooo00<0
000co`0co`00FS?o00D0000_oooo002?oooo0P0005Hco`050000=?ooo`00Soooo`030000<ol0<ol0
054co`040000>Oooo`00Soooo`030000<ol0<ol004lco`020000?Oooo`00Soooo`030000<ol0<ol0
04`co`030000?oooo`00Soooo`030000<ol0<ol004Xco`020000@_ooo`00Soooo`030000<ol0<ol0
04Pco`020000A?ooo`00Soooo`800017<ol00P0004Koool008ooool00`0003?o03?o0014<ol00P00
04Soool008ooool00`0003?o03?o0013<ol000<0003oooooool0B?ooo`00Soooo`030000<ol0<ol0
044co`020000Boooo`00Soooo`030000<ol0<ol003lco`020000COooo`00Soooo`030000<ol0<ol0
03hco`000`000?ooooooo`1=oooo002?oooo0P0003dco`020000D?ooo`00Soooo`030000<ol0<ol0
03Xco`020000D_ooo`00Soooo`030000<ol0<ol003Tco`000`000?ooooooo`1Boooo002?oooo00<0
000co`0co`00>3?o00030000oooooooo05?oool008ooool00`0003?o03?o000f<ol00P0005Koool0
08ooool00`0003?o03?o000e<ol000<0003oooooool0E_ooo`00Soooo`80000e<ol000<0003ooooo
ool0Eoooo`00Soooo`030000<ol0<ol003<co`000`000?ooooooo`1Hoooo002?oooo00<0000co`0c
o`00<S?o00030000oooooooo05Woool008ooool00`0003?o03?o000a<ol000<0003oooooool0F_oo
o`00Soooo`030000<ol0<ol0034co`000`000?ooooooo`1Joooo0027oooo1@0000?oool00`0003?o
03?o000`<ol000<0003oooooool0Foooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000_
<ol000<0003oooooool0G?ooo`00ROooo`030000oooooooo00?oool30000;S?o00030000oooooooo
05goool008Woool00`000?ooooooo`03oooo00<0000co`0co`00;S?o00030000oooooooo05goool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`00;C?o00030000oooooooo05koool008Soool2
00001Oooo`030000<ol0<ol002`co`000`000?ooooooo`1Ooooo002?oooo00<0000co`0co`00:c?o
00030000oooooooo063oool008ooool00`0003?o03?o000[<ol000<0003oooooool0H?ooo`00Sooo
o`80000[<ol000<0003oooooool0HOooo`00Soooo`030000<ol0<ol002Tco`000`000?ooooooo`1R
oooo002?oooo00<0000co`0co`00:C?o00030000oooooooo06;oool008ooool00`0003?o03?o000X
<ol000<0003oooooool0Hoooo`00Soooo`030000<ol0<ol002Lco`000`000?ooooooo`1Toooo002?
oooo00<0000co`0co`009S?o00030000oooooooo06Goool008ooool200009c?o00030000oooooooo
06Goool008ooool00`0003?o03?o000U<ol000<0003oooooool0I_ooo`00Soooo`030000<ol0<ol0
02@co`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`0093?o00030000oooooooo06Ooool0
08ooool00`0003?o03?o000S<ol000<0003oooooool0J?ooo`00Soooo`030000<ol0<ol002<co`00
0`000?ooooooo`1Xoooo002?oooo00<0000co`0co`008S?o00030000oooooooo06Woool008ooool2
00008c?o00030000oooooooo06Woool008ooool00`0003?o03?o000Q<ol000<0003oooooool0J_oo
o`00Soooo`030000<ol0<ol0024co`000`000?ooooooo`1Zoooo002?oooo00<0000co`0co`0083?o
00030000oooooooo06_oool008ooool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Sooo
o`030000<ol0<ol0020co`000`000?ooooooo`1[oooo002?oooo0P00020co`000`000?ooooooo`1/
oooo002?oooo00<0000co`0co`007c?o00030000oooooooo06coool008ooool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`1]oooo0027
oooo100000Coool00`0003?o03?o000N<ol000<0003oooooool0KOooo`00Qoooo`030000oooooooo
00Goool00`0003?o03?o000M<ol000<0003oooooool0K_ooo`00R?ooo`030000oooooooo00Coool3
00007C?o00030000oooooooo06koool008Woool00`000?ooooooo`03oooo00<0000co`0co`007C?o
00030000oooooooo06koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000L<ol000<0
003oooooool0Koooo`00R?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo06ooool0
08ooool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol001/co`00
0`000?ooooooo`1`oooo002?oooo0P0001`co`000`000?ooooooo`1`oooo002?oooo00<0000co`0c
o`006S?o00030000oooooooo077oool008ooool00`0003?o03?o000J<ol000<0003oooooool0LOoo
o`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`006S?o
00030000oooooooo077oool008ooool00`0003?o03?o000I<ol000<0003oooooool0L_ooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`1boooo002?oooo0P0001Xco`000`000?ooooooo`1b
oooo002?oooo00<0000co`0co`0063?o00030000oooooooo07?oool008ooool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo002?
oooo00<0000co`0co`005c?o00030000oooooooo07Coool008ooool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00Soooo`80000H<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol0
01Lco`000`000?ooooooo`1doooo002?oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
08ooool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00Soooo`030000<ol0<ol001Hco`00
0`000?ooooooo`1eoooo002?oooo00<0000co`0co`005C?o00030000oooooooo07Koool008ooool2
00005S?o00030000oooooooo07Koool008ooool00`0003?o03?o000E<ol000<0003oooooool0M_oo
o`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`1foooo002?oooo00<0000co`0co`0053?o
00030000oooooooo07Ooool008Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`1g
oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0053?o00030000oooooooo07Ooool0
08Woool00`000?ooooooo`03oooo0`0001<co`000`000?ooooooo`1hoooo002:oooo00<0003ooooo
ool00_ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`004c?o00030000oooooooo07Soool008Soool200001Oooo`030000<ol0<ol0
018co`000`000?ooooooo`1ioooo002?oooo00<0000co`0co`004S?o00030000oooooooo07Woool0
08ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`1ioooo002?oooo0P00018co`000`000?ooooooo`1joooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo07[oool008ooool00`0003?o03?o000A<ol000<0003oooooool0N_oo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1joooo002?oooo00<0000co`0co`0043?o
00030000oooooooo07_oool008ooool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Sooo
o`80000A<ol000<0003oooooool0Noooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo07coool008ooool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo002?
oooo00<0000co`0co`003c?o00030000oooooooo07coool008ooool2000043?o00030000oooooooo
07coool008ooool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`1moooo002?oooo00<0000co`0co`003S?o00030000oooooooo07goool0
08ooool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`1moooo002?oooo0P0000hco`000`000?ooooooo`1noooo002?oooo00<0000co`0c
o`003C?o00030000oooooooo07koool008ooool00`0003?o03?o000=<ol000<0003oooooool0O_oo
o`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo002?oooo00<0000co`0co`0033?o
00030000oooooooo07ooool008Woool300000oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0027
oooo1@0000?oool3000033?o00030000oooooooo07ooool008Ooool010000?ooooooo`0000Coool?
<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool0
08ooool?<ol0P_ooo`00Soooo`lco`22oooo001ooooo00<0003oooooool03Oooo`hco`000oooo`00
0?ooo`20oooo001noooo00<0003oooooool02?ooo`030000oooooooo00?oool><ol00_ooo`030000
oooooooo07koool007koool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`03oooo13?o
00800004<ol00P00008co`02oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`<co`00100003?o03?o000000Lco`02
oooo00<0003oooooool0O_ooo`00OOooo`030000oooooooo00;oool00`000?ooooooo`0:oooo0c?o
00040000<ol0<ol000001c?o00?oool00`000?ooooooo`1moooo001noooo00<0003oooooool01@00
00Woool3<ol000@0000co`0co`000007<ol00_ooo`030000oooooooo07koool007koool01@000?oo
ooooooooo`00000<oooo0c?o00040000<ol0<ol000001S?o00?oool00`000?ooooooo`1noooo001o
oooo00<0003oooooool03Oooo`@co`0200001c?o00;oool00`000?ooooooo`1ooooo002?oooo3C?o
08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49955 .12361 L
.50205 .12361 L
.50342 .12361 L
.50471 .12361 L
s
.50471 .12361 m
.50519 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47994 .12361 L
.48519 .12361 L
.49018 .12361 L
.49235 .12361 L
.49354 .12361 L
.49466 .12361 L
.4953 .12357 L
.49599 .12322 L
.4972 .1226 L
.49955 .1214 L
.50192 .12021 L
.50323 .11956 L
.50447 .11895 L
.50562 .12361 L
.50687 .12361 L
.50906 .12361 L
.51949 .12361 L
.54055 .12361 L
.58134 .12361 L
.6206 .12361 L
.65835 .12361 L
.69856 .12361 L
.73724 .12361 L
.77838 .12361 L
.81801 .12361 L
.85612 .12361 L
.89668 .12361 L
.93572 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<00000I_oo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000o`2I<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`000?l0VC?o000i<ol000<0
000co`0co`00=S?o00D0000Goooo002?oooo00<0003o09Tco`00JS?o00P0000Loooo002?oooo00<0
003o09Tco`00I3?o00H0000Toooo002?oooo00<0003o09Tco`00Gc?o00D0000Zoooo002?oooo00<0
003o09Tco`00FS?o00D0000_oooo002?oooo0P0005Hco`050000=?ooo`00Soooo`030000o`2I<ol0
054co`040000>Oooo`00Soooo`030000o`2I<ol004lco`020000?Oooo`00Soooo`030000o`2I<ol0
04`co`030000?oooo`00Soooo`030000o`2I<ol004Xco`020000@_ooo`00Soooo`030000o`2I<ol0
04Pco`020000A?ooo`00Soooo`800017<ol00P0004Koool008ooool00`000?l0VC?o0014<ol00P00
04Soool008ooool00`000?l0VC?o0013<ol000<0003oooooool0B?ooo`00Soooo`030000o`2I<ol0
044co`020000Boooo`00Soooo`030000o`2I<ol003lco`020000COooo`00Soooo`030000o`2I<ol0
03hco`000`000?ooooooo`1=oooo002?oooo0P0003dco`020000D?ooo`00Soooo`030000o`2I<ol0
03Xco`020000D_ooo`00Soooo`030000o`2I<ol003Tco`000`000?ooooooo`1Boooo002?oooo00<0
003o09Tco`00>3?o00030000oooooooo05?oool008ooool00`000?l0VC?o000f<ol00P0005Koool0
08ooool00`000?l0VC?o000e<ol000<0003oooooool0E_ooo`00Soooo`80000e<ol000<0003ooooo
ool0Eoooo`00Soooo`030000o`2I<ol003<co`000`000?ooooooo`1Hoooo002?oooo00<0003o09Tc
o`00<S?o00030000oooooooo05Woool008ooool00`000?l0VC?o000a<ol000<0003oooooool0F_oo
o`00Soooo`030000o`2I<ol0034co`000`000?ooooooo`1Joooo0027oooo1@0000?oool00`000?l0
VC?o000`<ol000<0003oooooool0Foooo`00ROooo`030000oooooooo00?oool00`000?l0VC?o000_
<ol000<0003oooooool0G?ooo`00ROooo`030000oooooooo00?oool30000;S?o00030000oooooooo
05goool008Woool00`000?ooooooo`03oooo00<0003o09Tco`00;S?o00030000oooooooo05goool0
08Woool00`000?ooooooo`03oooo00<0003o09Tco`00;C?o00030000oooooooo05koool008Soool2
00001Oooo`030000o`2I<ol002`co`000`000?ooooooo`1Ooooo002?oooo00<0003o09Tco`00:c?o
00030000oooooooo063oool008ooool00`000?l0VC?o000[<ol000<0003oooooool0H?ooo`00Sooo
o`80000[<ol000<0003oooooool0HOooo`00Soooo`030000o`2I<ol002Tco`000`000?ooooooo`1R
oooo002?oooo00<0003o09Tco`00:C?o00030000oooooooo06;oool008ooool00`000?l0VC?o000X
<ol000<0003oooooool0Hoooo`00Soooo`030000o`2I<ol002Lco`000`000?ooooooo`1Toooo002?
oooo00<0003o09Tco`009S?o00030000oooooooo06Goool008ooool200009c?o00030000oooooooo
06Goool008ooool00`000?l0VC?o000U<ol000<0003oooooool0I_ooo`00Soooo`030000o`2I<ol0
02@co`000`000?ooooooo`1Woooo002?oooo00<0003o09Tco`0093?o00030000oooooooo06Ooool0
08ooool00`000?l0VC?o000S<ol000<0003oooooool0J?ooo`00Soooo`030000o`2I<ol002<co`00
0`000?ooooooo`1Xoooo002?oooo00<0003o09Tco`008S?o00030000oooooooo06Woool008ooool2
00008c?o00030000oooooooo06Woool008ooool00`000?l0VC?o000Q<ol000<0003oooooool0J_oo
o`00Soooo`030000o`2I<ol0024co`000`000?ooooooo`1Zoooo002?oooo00<0003o09Tco`0083?o
00030000oooooooo06_oool008ooool00`000?l0VC?o000P<ol000<0003oooooool0Joooo`00Sooo
o`030000o`2I<ol0020co`000`000?ooooooo`1[oooo002?oooo0P00020co`000`000?ooooooo`1/
oooo002?oooo00<0003o09Tco`007c?o00030000oooooooo06coool008ooool00`000?l0VC?o000N
<ol000<0003oooooool0KOooo`00Soooo`030000o`2I<ol001hco`000`000?ooooooo`1]oooo0027
oooo100000Coool00`000?l0VC?o000N<ol000<0003oooooool0KOooo`00Qoooo`030000oooooooo
00Goool00`000?l0VC?o000M<ol000<0003oooooool0K_ooo`00R?ooo`030000oooooooo00Coool3
00007C?o00030000oooooooo06koool008Woool00`000?ooooooo`03oooo00<0003o09Tco`007C?o
00030000oooooooo06koool008Ooool010000?ooooooo`0000Coool00`000?l0VC?o000L<ol000<0
003oooooool0Koooo`00R?ooo`800005oooo00<0003o09Tco`0073?o00030000oooooooo06ooool0
08ooool00`000?l0VC?o000K<ol000<0003oooooool0L?ooo`00Soooo`030000o`2I<ol001/co`00
0`000?ooooooo`1`oooo002?oooo0P0001`co`000`000?ooooooo`1`oooo002?oooo00<0003o09Tc
o`006S?o00030000oooooooo077oool008ooool00`000?l0VC?o000J<ol000<0003oooooool0LOoo
o`00Soooo`030000o`2I<ol001Xco`000`000?ooooooo`1aoooo002?oooo00<0003o09Tco`006S?o
00030000oooooooo077oool008ooool00`000?l0VC?o000I<ol000<0003oooooool0L_ooo`00Sooo
o`030000o`2I<ol001Tco`000`000?ooooooo`1boooo002?oooo0P0001Xco`000`000?ooooooo`1b
oooo002?oooo00<0003o09Tco`0063?o00030000oooooooo07?oool008ooool00`000?l0VC?o000H
<ol000<0003oooooool0Loooo`00Soooo`030000o`2I<ol001Pco`000`000?ooooooo`1coooo002?
oooo00<0003o09Tco`005c?o00030000oooooooo07Coool008ooool00`000?l0VC?o000G<ol000<0
003oooooool0M?ooo`00Soooo`80000H<ol000<0003oooooool0M?ooo`00Soooo`030000o`2I<ol0
01Lco`000`000?ooooooo`1doooo002?oooo00<0003o09Tco`005S?o00030000oooooooo07Goool0
08ooool00`000?l0VC?o000F<ol000<0003oooooool0MOooo`00Soooo`030000o`2I<ol001Hco`00
0`000?ooooooo`1eoooo002?oooo00<0003o09Tco`005C?o00030000oooooooo07Koool008ooool2
00005S?o00030000oooooooo07Koool008ooool00`000?l0VC?o000E<ol000<0003oooooool0M_oo
o`00Soooo`030000o`2I<ol001Dco`000`000?ooooooo`1foooo002?oooo00<0003o09Tco`0053?o
00030000oooooooo07Ooool008Soool200001Oooo`030000o`2I<ol001@co`000`000?ooooooo`1g
oooo0027oooo00@0003oooooool00004oooo00<0003o09Tco`0053?o00030000oooooooo07Ooool0
08Woool00`000?ooooooo`03oooo0`0001<co`000`000?ooooooo`1hoooo002:oooo00<0003ooooo
ool00_ooo`030000o`2I<ol001<co`000`000?ooooooo`1hoooo0027oooo00@0003oooooool00004
oooo00<0003o09Tco`004c?o00030000oooooooo07Soool008Soool200001Oooo`030000o`2I<ol0
018co`000`000?ooooooo`1ioooo002?oooo00<0003o09Tco`004S?o00030000oooooooo07Woool0
08ooool00`000?l0VC?o000B<ol000<0003oooooool0NOooo`00Soooo`030000o`2I<ol0018co`00
0`000?ooooooo`1ioooo002?oooo0P00018co`000`000?ooooooo`1joooo002?oooo00<0003o09Tc
o`004C?o00030000oooooooo07[oool008ooool00`000?l0VC?o000A<ol000<0003oooooool0N_oo
o`00Soooo`030000o`2I<ol0014co`000`000?ooooooo`1joooo002?oooo00<0003o09Tco`0043?o
00030000oooooooo07_oool008ooool00`000?l0VC?o000@<ol000<0003oooooool0Noooo`00Sooo
o`80000A<ol000<0003oooooool0Noooo`00Soooo`030000o`2I<ol0010co`000`000?ooooooo`1k
oooo002?oooo00<0003o09Tco`003c?o00030000oooooooo07coool008ooool00`000?l0VC?o000?
<ol000<0003oooooool0O?ooo`00Soooo`030000o`2I<ol000lco`000`000?ooooooo`1loooo002?
oooo00<0003o09Tco`003c?o00030000oooooooo07coool008ooool2000043?o00030000oooooooo
07coool008ooool00`000?l0VC?o000><ol000<0003oooooool0OOooo`00Soooo`030000o`2I<ol0
00hco`000`000?ooooooo`1moooo002?oooo00<0003o09Tco`003S?o00030000oooooooo07goool0
08ooool00`000?l0VC?o000><ol000<0003oooooool0OOooo`00Soooo`030000o`2I<ol000hco`00
0`000?ooooooo`1moooo002?oooo0P0000hco`000`000?ooooooo`1noooo002?oooo00<0003o09Tc
o`003C?o00030000oooooooo07koool008ooool00`000?l0VC?o000=<ol000<0003oooooool0O_oo
o`00Soooo`030000o`2I<ol000dco`000`000?ooooooo`1noooo002?oooo00<0003o09Tco`0033?o
00030000oooooooo07ooool008Woool300000oooo`030000o`2I<ol000`co`000`000?ooooooo`1o
oooo002:oooo00<0003oooooool00_ooo`030000o`2I<ol000`co`000`000?ooooooo`1ooooo0027
oooo1@0000?oool3000033?o00030000oooooooo07ooool008Ooool010000?ooooooo`0000Coool?
<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool0
08ooool?<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07oooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o00Soool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004<ol00P0000@co`0200000S?o0003oooo0000000000<00002oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo000023?o00050000<ol0<ol00000<ol000?oool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003ooooo
ool00008<ol000D0000co`0co`00000co`000oooo`030000oooooooo00?oool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Pco`001@0003?o03?o0000
03?o0003oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000?oooo00@0003oooooool00008<ol000@0000co`0co`000004oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Xco`02000000@co`3ooooo
ooooool200000oooo`030000oooooooo07Woool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49955 .12361 L
.50431 .12361 L
.50682 .12361 L
.5082 .12361 L
.5095 .12361 L
s
.5095 .12361 m
.51 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47994 .12361 L
.48519 .12361 L
.48778 .12361 L
.48904 .12361 L
.49018 .12361 L
.4913 .12318 L
.49235 .12264 L
.49466 .12146 L
.49955 .11903 L
.5046 .11659 L
.50707 .11543 L
.50814 .11492 L
.50931 .11438 L
.51053 .12361 L
.51169 .12361 L
.51423 .12361 L
.51963 .12361 L
.5381 .12361 L
.57888 .12361 L
.61815 .12361 L
.6559 .12361 L
.6961 .12361 L
.73479 .12361 L
.77593 .12361 L
.81556 .12361 L
.85366 .12361 L
.89423 .12361 L
.93327 .12361 L
.97477 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooo`1Vo`2>oooo002?oooo00<00000I_l0
I_l0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0o`2I00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o0?l0V@0i<ol000<0
000co`0co`00=S?o00D0000Goooo002?oooo00<0000co`3o09T0JS?o00P0000Loooo002?oooo00<0
000co`3o09T0I3?o00H0000Toooo002?oooo00<0000co`3o09T0Gc?o00D0000Zoooo002?oooo00<0
000co`3o09T0FS?o00D0000_oooo002?oooo0P000003o`2I<ol0<ol005<co`050000=?ooo`00Sooo
o`030000<ol0o`2I054co`040000>Oooo`00Soooo`030000<ol0o`2I04lco`020000?Oooo`00Sooo
o`030000<ol0o`2I04`co`030000?oooo`00Soooo`030000<ol0o`2I04Xco`020000@_ooo`00Sooo
o`030000<ol0o`2I04Pco`020000A?ooo`00Soooo`8000000ol0VC?o03?o0014<ol00P0004Koool0
08ooool00`0003?o0?l0V@14<ol00P0004Soool008ooool00`0003?o0?l0V@13<ol000<0003ooooo
ool0B?ooo`00Soooo`030000<ol0o`2I044co`020000Boooo`00Soooo`030000<ol0o`2I03lco`02
0000COooo`00Soooo`030000<ol0o`2I03hco`000`000?ooooooo`1=oooo002?oooo0P000003o`2I
<ol0<ol003Xco`020000D?ooo`00Soooo`030000<ol0o`2I03Xco`020000D_ooo`00Soooo`030000
<ol0o`2I03Tco`000`000?ooooooo`1Boooo002?oooo00<0000co`3o09T0>3?o00030000oooooooo
05?oool008ooool00`0003?o0?l0V@0f<ol00P0005Koool008ooool00`0003?o0?l0V@0e<ol000<0
003oooooool0E_ooo`00Soooo`8000000ol0VC?o03?o000b<ol000<0003oooooool0Eoooo`00Sooo
o`030000<ol0o`2I03<co`000`000?ooooooo`1Hoooo002?oooo00<0000co`3o09T0<S?o00030000
oooooooo05Woool008ooool00`0003?o0?l0V@0a<ol000<0003oooooool0F_ooo`00Soooo`030000
<ol0o`2I034co`000`000?ooooooo`1Joooo0027oooo1@0000?oool00`0003?o0?l0V@0`<ol000<0
003oooooool0Foooo`00ROooo`030000oooooooo00?oool00`0003?o0?l0V@0_<ol000<0003ooooo
ool0G?ooo`00ROooo`030000oooooooo00?oool30000;S?o00030000oooooooo05goool008Woool0
0`000?ooooooo`03oooo00<0000co`3o09T0;S?o00030000oooooooo05goool008Woool00`000?oo
ooooo`03oooo00<0000co`3o09T0;C?o00030000oooooooo05koool008Soool200001Oooo`030000
<ol0o`2I02`co`000`000?ooooooo`1Ooooo002?oooo00<0000co`3o09T0:c?o00030000oooooooo
063oool008ooool00`0003?o0?l0V@0[<ol000<0003oooooool0H?ooo`00Soooo`8000000ol0VC?o
03?o000X<ol000<0003oooooool0HOooo`00Soooo`030000<ol0o`2I02Tco`000`000?ooooooo`1R
oooo002?oooo00<0000co`3o09T0:C?o00030000oooooooo06;oool008ooool00`0003?o0?l0V@0X
<ol000<0003oooooool0Hoooo`00Soooo`030000<ol0o`2I02Lco`000`000?ooooooo`1Toooo002?
oooo00<0000co`3o09T09S?o00030000oooooooo06Goool008ooool2000000?o09Tco`0co`0093?o
00030000oooooooo06Goool008ooool00`0003?o0?l0V@0U<ol000<0003oooooool0I_ooo`00Sooo
o`030000<ol0o`2I02@co`000`000?ooooooo`1Woooo002?oooo00<0000co`3o09T093?o00030000
oooooooo06Ooool008ooool00`0003?o0?l0V@0S<ol000<0003oooooool0J?ooo`00Soooo`030000
<ol0o`2I02<co`000`000?ooooooo`1Xoooo002?oooo00<0000co`3o09T08S?o00030000oooooooo
06Woool008ooool2000000?o09Tco`0co`0083?o00030000oooooooo06Woool008ooool00`0003?o
0?l0V@0Q<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0o`2I024co`000`000?ooooooo`1Z
oooo002?oooo00<0000co`3o09T083?o00030000oooooooo06_oool008ooool00`0003?o0?l0V@0P
<ol000<0003oooooool0Joooo`00Soooo`030000<ol0o`2I020co`000`000?ooooooo`1[oooo002?
oooo0P000003o`2I<ol0<ol001dco`000`000?ooooooo`1/oooo002?oooo00<0000co`3o09T07c?o
00030000oooooooo06coool008ooool00`0003?o0?l0V@0N<ol000<0003oooooool0KOooo`00Sooo
o`030000<ol0o`2I01hco`000`000?ooooooo`1]oooo0027oooo100000Coool00`0003?o0?l0V@0N
<ol000<0003oooooool0KOooo`00Qoooo`030000oooooooo00Goool00`0003?o0?l0V@0M<ol000<0
003oooooool0K_ooo`00R?ooo`030000oooooooo00Coool300007C?o00030000oooooooo06koool0
08Woool00`000?ooooooo`03oooo00@0000co`0co`3o09TL<ol000<0003oooooool0K_ooo`00Qooo
o`040000oooooooo00001?ooo`040000<ol0<ol0o`2I6c?o00030000oooooooo06ooool008Soool2
00001Oooo`040000<ol0<ol0o`2I6c?o00030000oooooooo06ooool008ooool0100003?o03?o0?l0
VAXco`000`000?ooooooo`1`oooo002?oooo00@0000co`0co`3o09TJ<ol000<0003oooooool0L?oo
o`00Soooo`8000000c?o0?l0VC?o000I<ol000<0003oooooool0L?ooo`00Soooo`040000<ol0<ol0
o`2I6C?o00030000oooooooo077oool008ooool0100003?o03?o0?l0VATco`000`000?ooooooo`1a
oooo002?oooo00@0000co`0co`3o09TI<ol000<0003oooooool0LOooo`00Soooo`040000<ol0<ol0
o`2I6C?o00030000oooooooo077oool008ooool0100003?o03?o0?l0VAPco`000`000?ooooooo`1b
oooo002?oooo00@0000co`0co`3o09TH<ol000<0003oooooool0L_ooo`00Soooo`8000000c?o0?l0
VC?o000G<ol000<0003oooooool0L_ooo`00Soooo`040000<ol0<ol0o`2I5c?o00030000oooooooo
07?oool008ooool0100003?o03?o0?l0VALco`000`000?ooooooo`1coooo002?oooo00@0000co`0c
o`3o09TG<ol000<0003oooooool0Loooo`00Soooo`040000<ol0<ol0o`2I5S?o00030000oooooooo
07Coool008ooool0100003?o03?o0?l0VAHco`000`000?ooooooo`1doooo002?oooo0P000003<ol0
o`2I<ol001Dco`000`000?ooooooo`1doooo002?oooo00@0000co`0co`3o09TF<ol000<0003ooooo
ool0M?ooo`00Soooo`040000<ol0<ol0o`2I5C?o00030000oooooooo07Goool008ooool0100003?o
03?o0?l0VADco`000`000?ooooooo`1eoooo002?oooo00@0000co`0co`3o09TE<ol000<0003ooooo
ool0MOooo`00Soooo`040000<ol0<ol0o`2I53?o00030000oooooooo07Koool008ooool2000000<c
o`3o09Tco`004c?o00030000oooooooo07Koool008ooool0100003?o03?o0?l0VA@co`000`000?oo
ooooo`1foooo002?oooo00@0000co`0co`3o09TD<ol000<0003oooooool0M_ooo`00Soooo`040000
<ol0<ol0o`2I4c?o00030000oooooooo07Ooool008Soool200001Oooo`040000<ol0<ol0o`2I4c?o
00030000oooooooo07Ooool008Ooool010000?ooooooo`0000Coool0100003?o03?o0?l0VA<co`00
0`000?ooooooo`1goooo0029oooo00<0003oooooool00oooo`<000000ol0VC?o03?o000@<ol000<0
003oooooool0N?ooo`00R_ooo`030000oooooooo00;oool0100003?o03?o0?l0VA8co`000`000?oo
ooooo`1hoooo0027oooo00@0003oooooool00004oooo00@0000co`0co`3o09TB<ol000<0003ooooo
ool0N?ooo`00R?ooo`800005oooo00@0000co`0co`3o09TA<ol000<0003oooooool0NOooo`00Sooo
o`040000<ol0<ol0o`2I4C?o00030000oooooooo07Woool008ooool0100003?o03?o0?l0VA4co`00
0`000?ooooooo`1ioooo002?oooo00@0000co`0co`3o09TA<ol000<0003oooooool0NOooo`00Sooo
o`8000000c?o0?l0VC?o000?<ol000<0003oooooool0N_ooo`00Soooo`040000<ol0<ol0o`2I43?o
00030000oooooooo07[oool008ooool0100003?o03?o0?l0VA0co`000`000?ooooooo`1joooo002?
oooo00@0000co`0co`3o09T@<ol000<0003oooooool0N_ooo`00Soooo`040000<ol0<ol0o`2I3c?o
00030000oooooooo07_oool008ooool0100003?o03?o0?l0V@lco`000`000?ooooooo`1koooo002?
oooo0P000003<ol0o`2I<ol000hco`000`000?ooooooo`1koooo002?oooo00@0000co`0co`3o09T?
<ol000<0003oooooool0Noooo`00Soooo`040000<ol0<ol0o`2I3S?o00030000oooooooo07coool0
08ooool0100003?o03?o0?l0V@hco`000`000?ooooooo`1loooo002?oooo00@0000co`0co`3o09T>
<ol000<0003oooooool0O?ooo`00Soooo`040000<ol0<ol0o`2I3S?o00030000oooooooo07coool0
08ooool2000000<co`3o09Tco`003C?o00030000oooooooo07coool008ooool0100003?o03?o0?l0
V@dco`000`000?ooooooo`1moooo002?oooo00@0000co`0co`3o09T=<ol000<0003oooooool0OOoo
o`00Soooo`040000<ol0<ol0o`2I3C?o00030000oooooooo07goool008ooool0100003?o03?o0?l0
V@dco`000`000?ooooooo`1moooo002?oooo00@0000co`0co`3o09T=<ol000<0003oooooool0OOoo
o`00Soooo`8000000c?o0?l0VC?o000;<ol000<0003oooooool0O_ooo`00Soooo`040000<ol0<ol0
o`2I33?o00030000oooooooo07koool008ooool0100003?o03?o0?l0V@`co`000`000?ooooooo`1n
oooo002?oooo00@0000co`0co`3o09T<<ol000<0003oooooool0O_ooo`00Soooo`040000<ol0<ol0
o`2I2c?o00030000oooooooo07ooool008Woool300000oooo`040000<ol0<ol0o`2I2c?o00030000
oooooooo07ooool008[oool00`000?ooooooo`02oooo00@0000co`0co`3o09T;<ol000<0003ooooo
ool0Ooooo`00Qoooo`D00003oooo0`000003o`2I<ol0<ol000Tco`000`000?ooooooo`1ooooo0027
oooo00@0003oooooool00004oooo3c?o08;oool008Soool00`000?ooo`000004oooo3c?o08;oool0
08Woool200001?ooo`lco`22oooo002?oooo3c?o08;oool008ooool?<ol0P_ooo`00NOooo`030000
oooooooo01?oool><ol01oooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0
003oooooool02Oooo`hco`08oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Ooool2000013?o00800004<ol00P00008co`000oooo`0000000002
00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Pco`001`0003?o03?o000003?o0?oo
o`000006oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo00@0003oooooool00008<ol000D0000co`0co`00000co`000_ooo`030000oooooooo00Coool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Pco`00
1@0003?o03?o000003?o0003oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00008<ol000@0000co`0co`000002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002S?o
0080000013?o0?ooooooooooo`800003oooo00<0003oooooool0NOooo`00Soooo`dco`24oooo002?
oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49955 .12361 L
.50431 .12361 L
.50682 .12361 L
.5095 .12361 L
.51083 .12361 L
.51207 .12361 L
.51319 .12361 L
s
.51319 .12361 m
.51368 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47994 .12361 L
.48231 .12361 L
.48361 .12361 L
.48484 .12361 L
.48554 .12361 L
.48629 .12331 L
.48761 .12263 L
.49018 .12132 L
.49955 .11673 L
.50414 .11458 L
.50906 .11233 L
.51051 .11169 L
.51188 .11108 L
.51311 .11053 L
.51381 .11023 L
.51445 .12361 L
.51561 .12361 L
.5169 .12361 L
.51949 .12361 L
.54055 .12361 L
.58076 .12361 L
.61945 .12361 L
.66059 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`040000oooooooo06KoSOooo`00Soooo`04000006Ko06Ko06KoSOooo`00S_ooo`0306Ko
0000oooo00;oool00`1Vooooooooo`2:oooo000@ooooo`00017oool001Koool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00@0000co`0co`3o09T8<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002S?o00030000<ol0<ol000Tco`000`0003?o
03?o0009<ol000<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0i
oooo00@0000co`0co`3o09Th<ol000<0000co`0co`00=S?o00D0000Goooo002?oooo00@0000co`0c
o`3o09UY<ol0200001coool008ooool0100003?o03?o0?l0VF<co`0600009?ooo`00Soooo`040000
<ol0<ol0o`2IGS?o00D0000Zoooo002?oooo00@0000co`0co`3o09UI<ol01@0002ooool008ooool2
000000<co`3o09Tco`00Dc?o00D0000doooo002?oooo00@0000co`0co`3o09U@<ol0100003Woool0
08ooool0100003?o03?o0?l0VDhco`020000?Oooo`00Soooo`040000<ol0<ol0o`2IBc?o00<0000o
oooo002?oooo00@0000co`0co`3o09U9<ol00P0004;oool008ooool0100003?o03?o0?l0VDLco`02
0000A?ooo`00Soooo`8000000c?o0?l0VC?o0014<ol00P0004Koool008ooool0100003?o03?o0?l0
VD<co`020000B?ooo`00Soooo`040000<ol0<ol0o`2I@S?o00030000oooooooo04Soool008ooool0
100003?o03?o0?l0VD0co`020000Boooo`00Soooo`040000<ol0<ol0o`2I?S?o0080001=oooo002?
oooo00@0000co`0co`3o09Tm<ol000<0003oooooool0COooo`00Soooo`8000000c?o0?l0VC?o000j
<ol00P00053oool008ooool0100003?o03?o0?l0VCTco`020000D_ooo`00Soooo`040000<ol0<ol0
o`2I>3?o00030000oooooooo05;oool008ooool0100003?o03?o0?l0VCLco`000`000?ooooooo`1C
oooo002?oooo00@0000co`0co`3o09Te<ol00P0005Koool008ooool0100003?o03?o0?l0VC@co`00
0`000?ooooooo`1Foooo002?oooo0P000003<ol0o`2I<ol0038co`000`000?ooooooo`1Goooo002?
oooo00@0000co`0co`3o09Tb<ol000<0003oooooool0F?ooo`00Soooo`040000<ol0<ol0o`2I<C?o
00030000oooooooo05Woool008ooool0100003?o03?o0?l0VC0co`000`000?ooooooo`1Joooo002?
oooo00@0000co`0co`3o09T`<ol000<0003oooooool0F_ooo`00Qoooo`D00003oooo00@0000co`0c
o`3o09T_<ol000<0003oooooool0Foooo`00ROooo`030000oooooooo00?oool0100003?o03?o0?l0
VBhco`000`000?ooooooo`1Loooo0029oooo00<0003oooooool00oooo`<000000ol0VC?o03?o000[
<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo00?oool0100003?o03?o0?l0VBdco`00
0`000?ooooooo`1Moooo0029oooo00<0003oooooool00oooo`040000<ol0<ol0o`2I;3?o00030000
oooooooo05koool008Soool200001Oooo`040000<ol0<ol0o`2I:c?o00030000oooooooo05ooool0
08ooool0100003?o03?o0?l0VBXco`000`000?ooooooo`1Poooo002?oooo00@0000co`0co`3o09TZ
<ol000<0003oooooool0H?ooo`00Soooo`8000000c?o0?l0VC?o000X<ol000<0003oooooool0HOoo
o`00Soooo`040000<ol0<ol0o`2I:3?o00030000oooooooo06;oool008ooool0100003?o03?o0?l0
VBPco`000`000?ooooooo`1Roooo002?oooo00@0000co`0co`3o09TW<ol000<0003oooooool0Hooo
o`00Soooo`040000<ol0<ol0o`2I9S?o00030000oooooooo06Coool008ooool0100003?o03?o0?l0
VBDco`000`000?ooooooo`1Uoooo002?oooo0P000003<ol0o`2I<ol002@co`000`000?ooooooo`1U
oooo002?oooo00@0000co`0co`3o09TT<ol000<0003oooooool0I_ooo`00Soooo`040000<ol0<ol0
o`2I8c?o00030000oooooooo06Ooool008ooool0100003?o03?o0?l0VB<co`000`000?ooooooo`1W
oooo002?oooo00@0000co`0co`3o09TR<ol000<0003oooooool0J?ooo`00Soooo`040000<ol0<ol0
o`2I8S?o00030000oooooooo06Soool008ooool0100003?o03?o0?l0VB4co`000`000?ooooooo`1Y
oooo002?oooo0P000003<ol0o`2I<ol0020co`000`000?ooooooo`1Yoooo002?oooo00@0000co`0c
o`3o09TP<ol000<0003oooooool0J_ooo`00Soooo`040000<ol0<ol0o`2I83?o00030000oooooooo
06[oool008ooool0100003?o03?o0?l0VAlco`000`000?ooooooo`1[oooo002?oooo00@0000co`0c
o`3o09TO<ol000<0003oooooool0Joooo`00Soooo`040000<ol0<ol0o`2I7c?o00030000oooooooo
06_oool008ooool2000000<co`3o09Tco`007C?o00030000oooooooo06coool008ooool0100003?o
03?o0?l0VAhco`000`000?ooooooo`1/oooo002?oooo00@0000co`0co`3o09TM<ol000<0003ooooo
ool0KOooo`00Soooo`040000<ol0<ol0o`2I7C?o00030000oooooooo06goool008Ooool400001?oo
o`040000<ol0<ol0o`2I7C?o00030000oooooooo06goool008Ooool00`000?ooooooo`05oooo00@0
000co`0co`3o09TL<ol000<0003oooooool0K_ooo`00R?ooo`030000oooooooo00Coool3000000?o
09Tco`0co`006S?o00030000oooooooo06koool008Woool00`000?ooooooo`03oooo00@0000co`0c
o`3o09TL<ol000<0003oooooool0K_ooo`00Qoooo`040000oooooooo00001?ooo`040000<ol0<ol0
o`2I6c?o00030000oooooooo06ooool008Soool200001Oooo`040000<ol0<ol0o`2I6c?o00030000
oooooooo06ooool008ooool0100003?o03?o0?l0VAXco`000`000?ooooooo`1`oooo002?oooo00@0
000co`0co`3o09TJ<ol000<0003oooooool0L?ooo`00Soooo`8000000c?o0?l0VC?o000I<ol000<0
003oooooool0L?ooo`00Soooo`040000<ol0<ol0o`2I6C?o00030000oooooooo077oool008ooool0
100003?o03?o0?l0VATco`000`000?ooooooo`1aoooo002?oooo00@0000co`0co`3o09TI<ol000<0
003oooooool0LOooo`00Soooo`040000<ol0<ol0o`2I6C?o00030000oooooooo077oool008ooool0
100003?o03?o0?l0VAPco`000`000?ooooooo`1boooo002?oooo00@0000co`0co`3o09TH<ol000<0
003oooooool0L_ooo`00Soooo`8000000c?o0?l0VC?o000G<ol000<0003oooooool0L_ooo`00Sooo
o`040000<ol0<ol0o`2I5c?o00030000oooooooo07?oool008ooool0100003?o03?o0?l0VALco`00
0`000?ooooooo`1coooo002?oooo00@0000co`0co`3o09TG<ol000<0003oooooool0Loooo`00Sooo
o`040000<ol0<ol0o`2I5S?o00030000oooooooo07Coool008ooool0100003?o03?o0?l0VAHco`00
0`000?ooooooo`1doooo002?oooo0P000003<ol0o`2I<ol001Dco`000`000?ooooooo`1doooo002?
oooo00@0000co`0co`3o09TF<ol000<0003oooooool0M?ooo`00Soooo`040000<ol0<ol0o`2I5C?o
00030000oooooooo07Goool008ooool0100003?o03?o0?l0VADco`000`000?ooooooo`1eoooo002?
oooo00@0000co`0co`3o09TE<ol000<0003oooooool0MOooo`00Soooo`040000<ol0<ol0o`2I53?o
00030000oooooooo07Koool008ooool2000000<co`3o09Tco`004c?o00030000oooooooo07Koool0
08ooool0100003?o03?o0?l0VA@co`000`000?ooooooo`1foooo002?oooo00@0000co`0co`3o09TD
<ol000<0003oooooool0M_ooo`00Soooo`040000<ol0<ol0o`2I4c?o00030000oooooooo07Ooool0
08Soool200001Oooo`040000<ol0<ol0o`2I4c?o00030000oooooooo07Ooool008Ooool010000?oo
ooooo`0000Coool0100003?o03?o0?l0VA<co`000`000?ooooooo`1goooo0029oooo00<0003ooooo
ool00oooo`<000000ol0VC?o03?o000@<ol000<0003oooooool0N?ooo`00R_ooo`030000oooooooo
00;oool0100003?o03?o0?l0VA8co`000`000?ooooooo`1hoooo0027oooo00@0003oooooool00004
oooo00@0000co`0co`3o09TB<ol000<0003oooooool0N?ooo`00R?ooo`800005oooo00@0000co`0c
o`3o09TA<ol000<0003oooooool0NOooo`00Soooo`040000<ol0<ol0o`2I4C?o00030000oooooooo
07Woool008ooool0100003?o03?o0?l0VA4co`000`000?ooooooo`1ioooo002?oooo00@0000co`0c
o`3o09TA<ol000<0003oooooool0NOooo`00Soooo`8000000c?o0?l0VC?o000?<ol000<0003ooooo
ool0N_ooo`00Soooo`040000<ol0<ol0o`2I43?o00030000oooooooo07[oool008ooool0100003?o
03?o0?l0VA0co`000`000?ooooooo`1joooo002?oooo00@0000co`0co`3o09T@<ol000<0003ooooo
ool0N_ooo`00Soooo`040000<ol0<ol0o`2I3c?o00030000oooooooo07_oool008ooool0100003?o
03?o0?l0V@lco`000`000?ooooooo`1koooo002?oooo0P000003<ol0o`2I<ol000hco`000`000?oo
ooooo`1koooo002?oooo00@0000co`0co`3o09T?<ol000<0003oooooool0Noooo`00Soooo`040000
<ol0<ol0o`2I3S?o00030000oooooooo07coool008ooool0100003?o03?o0?l0V@hco`000`000?oo
ooooo`1loooo002?oooo00@0000co`0co`3o09T><ol000<0003oooooool0O?ooo`00Soooo`040000
<ol0<ol0o`2I3S?o00030000oooooooo07coool008ooool2000000<co`3o09Tco`003C?o00030000
oooooooo07coool008ooool0100003?o03?o0?l0V@dco`000`000?ooooooo`1moooo002?oooo00@0
000co`0co`3o09T=<ol000<0003oooooool0OOooo`00Soooo`040000<ol0<ol0o`2I3C?o00030000
oooooooo07goool008ooool0100003?o03?o0?l0V@dco`000`000?ooooooo`1moooo002?oooo00@0
000co`0co`3o09T=<ol000<0003oooooool0OOooo`00Soooo`8000000c?o0?l0VC?o000;<ol000<0
003oooooool0O_ooo`00Soooo`040000<ol0<ol0o`2I33?o00030000oooooooo07koool008ooool0
100003?o03?o0?l0V@`co`000`000?ooooooo`1noooo002?oooo00@0000co`0co`3o09T<<ol000<0
003oooooool0O_ooo`00Soooo`040000<ol0<ol0o`2I2c?o00030000oooooooo07ooool008Woool3
00000oooo`040000<ol0<ol0o`2I2c?o00030000oooooooo07ooool008[oool00`000?ooooooo`02
oooo00@0000co`0co`3o09T;<ol000<0003oooooool0Ooooo`00Qoooo`D00003oooo0`000003o`2I
<ol0<ol000Tco`000`000?ooooooo`1ooooo0027oooo00@0003oooooool00004oooo3c?o08;oool0
08Soool00`000?ooo`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o
08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o
00800004<ol00P00008co`02oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008
<ol000L0000co`0co`00000co`3oool000000_ooo`050000oooooooooooo000007[oool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo000023?o00050000<ol0<ol0
0000<ol000?oool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000<oooo00@0003oooooool00008<ol000D0000co`0co`00000co`001?ooo`050000oooooooo
oooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008<ol000@0
000co`0co`000002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo017oool200002S?o0080000013?o0?ooooooooooo`800003oooo00<0003oooooool0NOoo
o`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.5095 .12361 L
.51441 .12361 L
.5168 .12361 L
.51784 .12361 L
.51896 .12361 L
s
.51896 .12361 m
.51948 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47567 .12361 L
.47791 .12361 L
.47889 .12361 L
.47994 .12361 L
.48116 .1235 L
.48231 .1229 L
.48484 .12161 L
.49018 .11895 L
.49955 .1145 L
.50906 .11024 L
.51166 .10911 L
.51445 .10791 L
.51581 .10734 L
.51709 .10681 L
.51824 .10633 L
.51949 .12361 L
.52079 .12361 L
.52201 .12361 L
.5248 .12361 L
.53043 .12361 L
.54055 .12361 L
.57924 .12361 L
.62038 .12361 L
.66001 .12361 L
.69811 .12361 L
.73868 .12361 L
.77772 .12361 L
.81922 .12361 L
.8592 .12361 L
.89767 .12361 L
.93859 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`2>oooo002?oooo00@0003oooooooooool2
06KoRoooo`00Soooo`060000oooo06Ko06Kooooo06KoRoooo`00S_ooo`0306Ko000006Ko00?oool0
0`1Vooooooooo`29oooo002<oooo0P1Vo`03oooo0000oooo00?oool00`1Vooooooooo`29oooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
000co`0co`000S?o0003o`2I<ol0<ol000@co`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o0002
<ol000?o09Tco`0co`00=3?o00030000<ol0<ol003Hco`0500005oooo`00Soooo`030000<ol0<ol0
008co`000ol0VC?o03?o001U<ol0200001coool008ooool00`0003?o03?o0002<ol000?o09Tco`0c
o`00Gc?o00H0000Toooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol005Xco`050000:_oo
o`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o001E<ol01@0002ooool008ooool200000c?o
0003o`2I<ol0<ol0050co`050000=?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o001<
<ol0100003Woool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`00BS?o0080000moooo002?
oooo00<0000co`0co`000S?o0003o`2I<ol0<ol004Lco`030000?oooo`00Soooo`030000<ol0<ol0
008co`000ol0VC?o03?o0015<ol00P0004;oool008ooool00`0003?o03?o0002<ol000?o09Tco`0c
o`00@c?o00800014oooo002?oooo0P0000<co`000ol0VC?o03?o0011<ol00P0004Koool008ooool0
0`0003?o03?o0002<ol000?o09Tco`0co`00?c?o00800018oooo002?oooo00<0000co`0co`000S?o
0003o`2I<ol0<ol003hco`000`000?ooooooo`18oooo002?oooo00<0000co`0co`000S?o0003o`2I
<ol0<ol003`co`020000Boooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000j<ol00P00
04goool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`00>C?o00030000oooooooo04goool0
08ooool200000c?o0003o`2I<ol0<ol003Lco`020000D?ooo`00Soooo`030000<ol0<ol0008co`00
0ol0VC?o03?o000e<ol00P0005;oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`00=3?o
00030000oooooooo05;oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`00<c?o00030000
oooooooo05?oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`00<C?o0080001Foooo002?
oooo00<0000co`0co`000S?o0003o`2I<ol0<ol0030co`000`000?ooooooo`1Foooo002?oooo0P00
00<co`000ol0VC?o03?o000_<ol000<0003oooooool0Eoooo`00Soooo`030000<ol0<ol0008co`00
0ol0VC?o03?o000^<ol000<0003oooooool0F?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o
03?o000]<ol000<0003oooooool0FOooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000/
<ol000<0003oooooool0F_ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000/<ol000<0
003oooooool0F_ooo`00Qoooo`D00003oooo00<0000co`0co`000S?o0003o`2I<ol0<ol002/co`00
0`000?ooooooo`1Koooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0008co`000ol0VC?o
03?o000Z<ol000<0003oooooool0G?ooo`00ROooo`030000oooooooo00?oool300000S?o0003o`2I
<ol0<ol002Tco`000`000?ooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
008co`000ol0VC?o03?o000Y<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o0002<ol000?o09Tco`0co`00:3?o00030000oooooooo05koool008Soool200001Ooo
o`030000<ol0<ol0008co`000ol0VC?o03?o000W<ol000<0003oooooool0Goooo`00Soooo`030000
<ol0<ol0008co`000ol0VC?o03?o000V<ol000<0003oooooool0H?ooo`00Soooo`030000<ol0<ol0
008co`000ol0VC?o03?o000V<ol000<0003oooooool0H?ooo`00Soooo`800003<ol000?o09Tco`0c
o`009C?o00030000oooooooo067oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`0093?o
00030000oooooooo06;oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`0093?o00030000
oooooooo06;oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`008c?o00030000oooooooo
06?oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`008S?o00030000oooooooo06Coool0
08ooool00`0003?o03?o0002<ol000?o09Tco`0co`008C?o00030000oooooooo06Goool008ooool2
00000c?o0003o`2I<ol0<ol0024co`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`000S?o
0003o`2I<ol0<ol0020co`000`000?ooooooo`1Voooo002?oooo00<0000co`0co`000S?o0003o`2I
<ol0<ol001lco`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol0
01lco`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001hco`00
0`000?ooooooo`1Xoooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001hco`000`000?oo
ooooo`1Xoooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001dco`000`000?ooooooo`1Y
oooo002?oooo0P0000<co`000ol0VC?o03?o000M<ol000<0003oooooool0JOooo`00Soooo`030000
<ol0<ol0008co`000ol0VC?o03?o000L<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol0
008co`000ol0VC?o03?o000L<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol0008co`00
0ol0VC?o03?o000K<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o
03?o000K<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000K
<ol000<0003oooooool0Joooo`00Soooo`800003<ol000?o09Tco`0co`006S?o00030000oooooooo
06coool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`006S?o00030000oooooooo06coool0
08ooool00`0003?o03?o0002<ol000?o09Tco`0co`006C?o00030000oooooooo06goool008ooool0
0`0003?o03?o0002<ol000?o09Tco`0co`006C?o00030000oooooooo06goool008Ooool400001?oo
o`030000<ol0<ol0008co`000ol0VC?o03?o000I<ol000<0003oooooool0KOooo`00Qoooo`030000
oooooooo00Goool00`0003?o03?o0002<ol000?o09Tco`0co`0063?o00030000oooooooo06koool0
08Soool00`000?ooooooo`04oooo0`00008co`000ol0VC?o03?o000H<ol000<0003oooooool0K_oo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o0002<ol000?o09Tco`0co`0063?o00030000
oooooooo06koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0002<ol000?o09Tco`0c
o`005c?o00030000oooooooo06ooool008Soool200001Oooo`030000<ol0<ol0008co`000ol0VC?o
03?o000G<ol000<0003oooooool0Koooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000F
<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000F<ol000<0
003oooooool0L?ooo`00Soooo`800003<ol000?o09Tco`0co`005S?o00030000oooooooo073oool0
08ooool00`0003?o03?o0002<ol000?o09Tco`0co`005C?o00030000oooooooo077oool008ooool0
0`0003?o03?o0002<ol000?o09Tco`0co`005C?o00030000oooooooo077oool008ooool00`0003?o
03?o0002<ol000?o09Tco`0co`005C?o00030000oooooooo077oool008ooool00`0003?o03?o0002
<ol000?o09Tco`0co`005C?o00030000oooooooo077oool008ooool00`0003?o03?o0002<ol000?o
09Tco`0co`0053?o00030000oooooooo07;oool008ooool00`0003?o03?o0002<ol000?o09Tco`0c
o`0053?o00030000oooooooo07;oool008ooool200000c?o0003o`2I<ol0<ol001@co`000`000?oo
ooooo`1boooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001<co`000`000?ooooooo`1c
oooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001<co`000`000?ooooooo`1coooo002?
oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001<co`000`000?ooooooo`1coooo002?oooo00<0
000co`0co`000S?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1doooo002?oooo00<0000co`0c
o`000S?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1doooo002?oooo0P0000<co`000ol0VC?o
03?o000B<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000B
<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000A<ol000<0
003oooooool0MOooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000A<ol000<0003ooooo
ool0MOooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000A<ol000<0003oooooool0MOoo
o`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000@<ol000<0003oooooool0M_ooo`00Sooo
o`800003<ol000?o09Tco`0co`0043?o00030000oooooooo07Koool008ooool00`0003?o03?o0002
<ol000?o09Tco`0co`0043?o00030000oooooooo07Koool008ooool00`0003?o03?o0002<ol000?o
09Tco`0co`0043?o00030000oooooooo07Koool008ooool00`0003?o03?o0002<ol000?o09Tco`0c
o`003c?o00030000oooooooo07Ooool008Soool200001Oooo`030000<ol0<ol0008co`000ol0VC?o
03?o000?<ol000<0003oooooool0Moooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
008co`000ol0VC?o03?o000?<ol000<0003oooooool0Moooo`00ROooo`030000oooooooo00?oool3
00000S?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1hoooo002:oooo00<0003oooooool00_oo
o`030000<ol0<ol0008co`000ol0VC?o03?o000><ol000<0003oooooool0N?ooo`00Qoooo`040000
oooooooo00001?ooo`030000<ol0<ol0008co`000ol0VC?o03?o000><ol000<0003oooooool0N?oo
o`00R?ooo`800005oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1i
oooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1ioooo002?
oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1ioooo002?oooo00<0
000co`0co`000S?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1ioooo002?oooo0P0000<co`00
0ol0VC?o03?o000<<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o
03?o000<<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000<
<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000<<ol000<0
003oooooool0N_ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000;<ol000<0003ooooo
ool0Noooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000;<ol000<0003oooooool0Nooo
o`00Soooo`800003<ol000?o09Tco`0co`002c?o00030000oooooooo07_oool008ooool00`0003?o
03?o0002<ol000?o09Tco`0co`002c?o00030000oooooooo07_oool008ooool00`0003?o03?o0002
<ol000?o09Tco`0co`002S?o00030000oooooooo07coool008ooool00`0003?o03?o0002<ol000?o
09Tco`0co`002S?o00030000oooooooo07coool008ooool00`0003?o03?o0002<ol000?o09Tco`0c
o`002S?o00030000oooooooo07coool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`002S?o
00030000oooooooo07coool008ooool200000c?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1l
oooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1moooo002?
oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1moooo002?oooo00<0
000co`0co`000S?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1moooo002?oooo00<0000co`0c
o`000S?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1moooo002?oooo00<0000co`0co`000S?o
0003o`2I<ol0<ol000Tco`000`000?ooooooo`1moooo002?oooo0P0000<co`000ol0VC?o03?o0008
<ol000<0003oooooool0O_ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0008<ol000<0
003oooooool0O_ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0008<ol000<0003ooooo
ool0O_ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0008<ol000<0003oooooool0O_oo
o`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0007<ol000<0003oooooool0Ooooo`00ROoo
o`<00003oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1ooooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol0008co`000ol0VC?o03?o0007<ol000<0003ooooo
ool0Ooooo`00Qoooo`D00003oooo0`00008co`000ol0VC?o03?o0007<ol000<0003oooooool0Oooo
o`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?ooo`lco`22
oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool007Woool0
0`000?ooooooo`0Coooo3S?o00Ooool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo00Woool><ol02?ooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000@co`02000013?o00800002<ol00oooo`<00002
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo000023?o00050000<ol0<ol00000<ol000Coool0
1@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool0
10000?ooooooo`0000Pco`001P0003?o03?o000003?o0?ooo`D00003oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008<ol000L0000co`0co`00000c
o`3oool000000_ooo`050000oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00008<ol000@0000co`0co`000003oooo00<0003oool000000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Xco`02000000<co`3oooooool00_oo
o`800002oooo00<0003oooooool0NOooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.5095 .12361 L
.51441 .12361 L
.51896 .12361 L
.52148 .12361 L
.52221 .12361 L
.52289 .12361 L
s
.52289 .12361 m
.52341 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46618 .12361 L
.47106 .12361 L
.47329 .12361 L
.47451 .12361 L
.47567 .12361 L
.47674 .12332 L
.47791 .12272 L
.47994 .12168 L
.49955 .11234 L
.50986 .10786 L
.5149 .10576 L
.51949 .1039 L
.52068 .10342 L
.52198 .10291 L
.5232 .10243 L
.52434 .12361 L
.52553 .12361 L
.52686 .12361 L
.52953 .12361 L
.54055 .12361 L
.58076 .12361 L
.61945 .12361 L
.66059 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0003?oool200002_oo
o`<0000doooo0P0001Ooool008ooool00`000?ooooooo`02oooo0P1Voh[oool008ooool00`000?oo
o`1Vo`0206Ko00?oool0I_ooool0ROooo`00Soooo`03000006Kooooo00?oool00`1Vooooooooo`28
oooo002>oooo00<0I_l0003oool01?ooo`0306Kooooooooo08Soool008coool206Ko00?oool0003o
ool01?ooo`0306Kooooooooo08Soool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`0003?o03?o0003<ol000?o09Tco`0co`000c?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Xco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0
003oooooool0>Oooo`030000<ol0<ol000<co`000ol0VC?o03?o000c<ol000<0000co`0co`00=S?o
00D0000Goooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol006@co`0800007?ooo`00Sooo
o`030000<ol0<ol000<co`000ol0VC?o03?o001N<ol01P0002Coool008ooool00`0003?o03?o0003
<ol000?o09Tco`0co`00FC?o00D0000Zoooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol0
05@co`050000;oooo`00Soooo`800004<ol000?o09Tco`0co`00Cc?o00D0000doooo002?oooo00<0
000co`0co`000c?o0003o`2I<ol0<ol004/co`040000>Oooo`00Soooo`030000<ol0<ol000<co`00
0ol0VC?o03?o0019<ol00P0003goool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`00AS?o
00<0000ooooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol004@co`020000@_ooo`00Sooo
o`030000<ol0<ol000<co`000ol0VC?o03?o0012<ol00P0004Coool008ooool2000013?o0003o`2I
<ol0<ol0040co`020000A_ooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000n<ol00P00
04Soool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`00?C?o00030000oooooooo04Soool0
08ooool00`0003?o03?o0003<ol000?o09Tco`0co`00>c?o0080001;oooo002?oooo00<0000co`0c
o`000c?o0003o`2I<ol0<ol003Tco`020000COooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o
03?o000h<ol000<0003oooooool0COooo`00Soooo`800004<ol000?o09Tco`0co`00=S?o0080001@
oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol003@co`020000D_ooo`00Soooo`030000
<ol0<ol000<co`000ol0VC?o03?o000c<ol000<0003oooooool0D_ooo`00Soooo`030000<ol0<ol0
00<co`000ol0VC?o03?o000b<ol000<0003oooooool0Doooo`00Soooo`030000<ol0<ol000<co`00
0ol0VC?o03?o000`<ol00P0005Koool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`00;c?o
00030000oooooooo05Koool008ooool2000013?o0003o`2I<ol0<ol002hco`000`000?ooooooo`1G
oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol002dco`000`000?ooooooo`1Hoooo002?
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol002`co`000`000?ooooooo`1Ioooo002?oooo00<0
000co`0co`000c?o0003o`2I<ol0<ol002/co`000`000?ooooooo`1Joooo002?oooo00<0000co`0c
o`000c?o0003o`2I<ol0<ol002/co`000`000?ooooooo`1Joooo0027oooo1@0000?oool00`0003?o
03?o0003<ol000?o09Tco`0co`00:S?o00030000oooooooo05_oool008Woool00`000?ooooooo`03
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol002Tco`000`000?ooooooo`1Loooo0029oooo00<0
003oooooool00oooo`<00003<ol000?o09Tco`0co`00:3?o00030000oooooooo05goool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`000c?o0003o`2I<ol0<ol002Pco`000`000?ooooooo`1M
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000<co`000ol0VC?o03?o000W<ol000<0
003oooooool0G_ooo`00R?ooo`800005oooo00<0000co`0co`000c?o0003o`2I<ol0<ol002Hco`00
0`000?ooooooo`1Ooooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol002Dco`000`000?oo
ooooo`1Poooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol002Dco`000`000?ooooooo`1P
oooo002?oooo0P0000@co`000ol0VC?o03?o000T<ol000<0003oooooool0HOooo`00Soooo`030000
<ol0<ol000<co`000ol0VC?o03?o000S<ol000<0003oooooool0H_ooo`00Soooo`030000<ol0<ol0
00<co`000ol0VC?o03?o000S<ol000<0003oooooool0H_ooo`00Soooo`030000<ol0<ol000<co`00
0ol0VC?o03?o000R<ol000<0003oooooool0Hoooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o
03?o000Q<ol000<0003oooooool0I?ooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000P
<ol000<0003oooooool0IOooo`00Soooo`800004<ol000?o09Tco`0co`0083?o00030000oooooooo
06Goool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`007c?o00030000oooooooo06Koool0
08ooool00`0003?o03?o0003<ol000?o09Tco`0co`007S?o00030000oooooooo06Ooool008ooool0
0`0003?o03?o0003<ol000?o09Tco`0co`007S?o00030000oooooooo06Ooool008ooool00`0003?o
03?o0003<ol000?o09Tco`0co`007C?o00030000oooooooo06Soool008ooool00`0003?o03?o0003
<ol000?o09Tco`0co`007C?o00030000oooooooo06Soool008ooool00`0003?o03?o0003<ol000?o
09Tco`0co`0073?o00030000oooooooo06Woool008ooool2000013?o0003o`2I<ol0<ol001`co`00
0`000?ooooooo`1Yoooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol001/co`000`000?oo
ooooo`1Zoooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol001/co`000`000?ooooooo`1Z
oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol001Xco`000`000?ooooooo`1[oooo002?
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol001Xco`000`000?ooooooo`1[oooo002?oooo00<0
000co`0co`000c?o0003o`2I<ol0<ol001Xco`000`000?ooooooo`1[oooo002?oooo0P0000@co`00
0ol0VC?o03?o000I<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o
03?o000I<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000H
<ol000<0003oooooool0KOooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000H<ol000<0
003oooooool0KOooo`00Qoooo`@00004oooo00<0000co`0co`000c?o0003o`2I<ol0<ol001Pco`00
0`000?ooooooo`1]oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000<co`000ol0VC?o
03?o000G<ol000<0003oooooool0K_ooo`00R?ooo`030000oooooooo00Coool300000c?o0003o`2I
<ol0<ol001Lco`000`000?ooooooo`1^oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00<co`000ol0VC?o03?o000G<ol000<0003oooooool0K_ooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000<co`000ol0VC?o03?o000F<ol000<0003oooooool0Koooo`00R?ooo`800005
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol001Hco`000`000?ooooooo`1_oooo002?oooo00<0
000co`0co`000c?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`1`oooo002?oooo00<0000co`0c
o`000c?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`1`oooo002?oooo0P0000@co`000ol0VC?o
03?o000E<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000D
<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000D<ol000<0
003oooooool0LOooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000D<ol000<0003ooooo
ool0LOooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000D<ol000<0003oooooool0LOoo
o`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000C<ol000<0003oooooool0L_ooo`00Sooo
o`030000<ol0<ol000<co`000ol0VC?o03?o000C<ol000<0003oooooool0L_ooo`00Soooo`800004
<ol000?o09Tco`0co`004c?o00030000oooooooo07;oool008ooool00`0003?o03?o0003<ol000?o
09Tco`0co`004S?o00030000oooooooo07?oool008ooool00`0003?o03?o0003<ol000?o09Tco`0c
o`004S?o00030000oooooooo07?oool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`004S?o
00030000oooooooo07?oool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`004C?o00030000
oooooooo07Coool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`004C?o00030000oooooooo
07Coool008ooool2000013?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1doooo002?oooo00<0
000co`0co`000c?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1doooo002?oooo00<0000co`0c
o`000c?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`000c?o
0003o`2I<ol0<ol0010co`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`000c?o0003o`2I
<ol0<ol0010co`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol0
00lco`000`000?ooooooo`1foooo002?oooo0P0000@co`000ol0VC?o03?o000?<ol000<0003ooooo
ool0M_ooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000?<ol000<0003oooooool0M_oo
o`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000?<ol000<0003oooooool0M_ooo`00Sooo
o`030000<ol0<ol000<co`000ol0VC?o03?o000><ol000<0003oooooool0Moooo`00R?ooo`800005
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1goooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1g
oooo0029oooo00<0003oooooool00oooo`<00003<ol000?o09Tco`0co`003C?o00030000oooooooo
07Soool008[oool00`000?ooooooo`02oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000dco`00
0`000?ooooooo`1hoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`000c?o0003o`2I
<ol0<ol000dco`000`000?ooooooo`1hoooo0028oooo0P0000Goool00`0003?o03?o0003<ol000?o
09Tco`0co`0033?o00030000oooooooo07Woool008ooool00`0003?o03?o0003<ol000?o09Tco`0c
o`0033?o00030000oooooooo07Woool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`0033?o
00030000oooooooo07Woool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`0033?o00030000
oooooooo07Woool008ooool2000013?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1joooo002?
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1joooo002?oooo00<0
000co`0co`000c?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1joooo002?oooo00<0000co`0c
o`000c?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1joooo002?oooo00<0000co`0co`000c?o
0003o`2I<ol0<ol000Xco`000`000?ooooooo`1koooo002?oooo00<0000co`0co`000c?o0003o`2I
<ol0<ol000Xco`000`000?ooooooo`1koooo002?oooo0P0000@co`000ol0VC?o03?o000:<ol000<0
003oooooool0Noooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000:<ol000<0003ooooo
ool0Noooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o0009<ol000<0003oooooool0O?oo
o`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o0009<ol000<0003oooooool0O?ooo`00Sooo
o`030000<ol0<ol000<co`000ol0VC?o03?o0009<ol000<0003oooooool0O?ooo`00Soooo`030000
<ol0<ol000<co`000ol0VC?o03?o0009<ol000<0003oooooool0O?ooo`00Soooo`800004<ol000?o
09Tco`0co`002C?o00030000oooooooo07coool008ooool00`0003?o03?o0003<ol000?o09Tco`0c
o`0023?o00030000oooooooo07goool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`0023?o
00030000oooooooo07goool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`0023?o00030000
oooooooo07goool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`0023?o00030000oooooooo
07goool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`0023?o00030000oooooooo07goool0
08ooool2000013?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1noooo002?oooo00<0000co`0c
o`000c?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1noooo002?oooo00<0000co`0co`000c?o
0003o`2I<ol0<ol000Lco`000`000?ooooooo`1noooo002?oooo00<0000co`0co`000c?o0003o`2I
<ol0<ol000Lco`000`000?ooooooo`1noooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol0
00Hco`000`000?ooooooo`1ooooo0029oooo0`0000?oool00`0003?o03?o0003<ol000?o09Tco`0c
o`001S?o00030000oooooooo07ooool008[oool00`000?ooooooo`02oooo00<0000co`0co`000c?o
0003o`2I<ol0<ol000Hco`000`000?ooooooo`1ooooo0027oooo1@0000?oool300000c?o0003o`2I
<ol0<ol000Hco`000`000?ooooooo`1ooooo0027oooo00@0003oooooool00004oooo3c?o08;oool0
08Soool00`000?ooo`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o
08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o
00800004<ol00P00008co`02oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008
<ol000L0000co`0co`00000co`3oool000000_ooo`050000oooooooooooo000007[oool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo000023?o00050000<ol0<ol0
0000<ol000Coool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000<oooo00@0003oooooool00008<ol000D0000co`0co`00000co`000_ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Pco`00
100003?o03?o000000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo017oool200002S?o0080000013?o0?ooooooooooo`<00002oooo00<0003oooooool0NOoo
o`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.5095 .12361 L
.51896 .12361 L
.52417 .12361 L
.5256 .12361 L
.52712 .12361 L
.52786 .12361 L
.52856 .12361 L
s
.52856 .12361 m
.52908 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46618 .12361 L
.46854 .12361 L
.46984 .12361 L
.47106 .12361 L
.47222 .1232 L
.47348 .12255 L
.47567 .12144 L
.47994 .1193 L
.49955 .11024 L
.50986 .1059 L
.51949 .10205 L
.52434 .10019 L
.52573 .09966 L
.52705 .09916 L
.52824 .09872 L
.52953 .12361 L
.53085 .12361 L
.53231 .12361 L
.53526 .12361 L
.54055 .12361 L
.58076 .12361 L
.61945 .12361 L
.66059 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool0
0`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000aoooo0P0000Coool206Ko;Ooo
o`80000:oooo0`0003Coool200005oooo`00Soooo`040000oooooooooooo0P1Vo`03oooo06Kooooo
08Soool008ooool010000?ooo`1Vo`1Vo`?oool00`1Vooooooooo`27oooo002>oooo00<0I_l00000
I_l01Oooo`0306Kooooooooo08Ooool008coool206Ko00?oool0003oool01Oooo`0306Kooooooooo
08Ooool008[oool206Ko0oooo`030000oooooooo00Coool00`1Vooooooooo`27oooo000@ooooo`00
017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0c
o`0013?o0003o`2I<ol0<ol0008co`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o0004<ol000?o
09Tco`0co`00<S?o00030000<ol0<ol003Hco`0500005oooo`00Soooo`030000<ol0<ol000@co`00
0ol0VC?o03?o001S<ol0200001coool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`00GC?o
00H0000Toooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol005Pco`050000:_ooo`00Sooo
o`030000<ol0<ol000@co`000ol0VC?o03?o001C<ol01@0002ooool008ooool200001C?o0003o`2I
<ol0<ol004hco`050000=?ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o001:<ol01000
03Woool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`00B3?o0080000moooo002?oooo00<0
000co`0co`0013?o0003o`2I<ol0<ol004Dco`030000?oooo`00Soooo`030000<ol0<ol000@co`00
0ol0VC?o03?o0013<ol00P0004;oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`00@C?o
00800014oooo002?oooo0P0000Dco`000ol0VC?o03?o000o<ol00P0004Koool008ooool00`0003?o
03?o0004<ol000?o09Tco`0co`00?C?o00800018oooo002?oooo00<0000co`0co`0013?o0003o`2I
<ol0<ol003`co`000`000?ooooooo`18oooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol0
03Xco`020000Boooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000h<ol00P0004goool0
08ooool00`0003?o03?o0004<ol000?o09Tco`0co`00=c?o00030000oooooooo04goool008ooool2
00001C?o0003o`2I<ol0<ol003Dco`020000D?ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o
03?o000c<ol00P0005;oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`00<S?o00030000
oooooooo05;oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`00<C?o00030000oooooooo
05?oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`00;c?o0080001Foooo002?oooo00<0
000co`0co`0013?o0003o`2I<ol0<ol002hco`000`000?ooooooo`1Foooo002?oooo0P0000Dco`00
0ol0VC?o03?o000]<ol000<0003oooooool0Eoooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o
03?o000/<ol000<0003oooooool0F?ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000[
<ol000<0003oooooool0FOooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000Z<ol000<0
003oooooool0F_ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000Z<ol000<0003ooooo
ool0F_ooo`00Qoooo`D00003oooo00<0000co`0co`0013?o0003o`2I<ol0<ol002Tco`000`000?oo
ooooo`1Koooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000@co`000ol0VC?o03?o000X
<ol000<0003oooooool0G?ooo`00ROooo`030000oooooooo00?oool3000013?o0003o`2I<ol0<ol0
02Lco`000`000?ooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000@co`00
0ol0VC?o03?o000W<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o0004<ol000?o09Tco`0co`009S?o00030000oooooooo05koool008Soool200001Oooo`030000
<ol0<ol000@co`000ol0VC?o03?o000U<ol000<0003oooooool0Goooo`00Soooo`030000<ol0<ol0
00@co`000ol0VC?o03?o000T<ol000<0003oooooool0H?ooo`00Soooo`030000<ol0<ol000@co`00
0ol0VC?o03?o000T<ol000<0003oooooool0H?ooo`00Soooo`800005<ol000?o09Tco`0co`008c?o
00030000oooooooo067oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`008S?o00030000
oooooooo06;oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`008S?o00030000oooooooo
06;oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`008C?o00030000oooooooo06?oool0
08ooool00`0003?o03?o0004<ol000?o09Tco`0co`0083?o00030000oooooooo06Coool008ooool0
0`0003?o03?o0004<ol000?o09Tco`0co`007c?o00030000oooooooo06Goool008ooool200001C?o
0003o`2I<ol0<ol001lco`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`0013?o0003o`2I
<ol0<ol001hco`000`000?ooooooo`1Voooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol0
01dco`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol001dco`00
0`000?ooooooo`1Woooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol001`co`000`000?oo
ooooo`1Xoooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol001`co`000`000?ooooooo`1X
oooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol001/co`000`000?ooooooo`1Yoooo002?
oooo0P0000Dco`000ol0VC?o03?o000K<ol000<0003oooooool0JOooo`00Soooo`030000<ol0<ol0
00@co`000ol0VC?o03?o000J<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol000@co`00
0ol0VC?o03?o000J<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o
03?o000I<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000I
<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000I<ol000<0
003oooooool0Joooo`00Soooo`800005<ol000?o09Tco`0co`0063?o00030000oooooooo06coool0
08ooool00`0003?o03?o0004<ol000?o09Tco`0co`0063?o00030000oooooooo06coool008ooool0
0`0003?o03?o0004<ol000?o09Tco`0co`005c?o00030000oooooooo06goool008ooool00`0003?o
03?o0004<ol000?o09Tco`0co`005c?o00030000oooooooo06goool008Ooool400001?ooo`030000
<ol0<ol000@co`000ol0VC?o03?o000G<ol000<0003oooooool0KOooo`00Qoooo`030000oooooooo
00Goool00`0003?o03?o0004<ol000?o09Tco`0co`005S?o00030000oooooooo06koool008Soool0
0`000?ooooooo`04oooo0`0000@co`000ol0VC?o03?o000F<ol000<0003oooooool0K_ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o0004<ol000?o09Tco`0co`005S?o00030000oooooooo
06koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0004<ol000?o09Tco`0co`005C?o
00030000oooooooo06ooool008Soool200001Oooo`030000<ol0<ol000@co`000ol0VC?o03?o000E
<ol000<0003oooooool0Koooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000D<ol000<0
003oooooool0L?ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000D<ol000<0003ooooo
ool0L?ooo`00Soooo`800005<ol000?o09Tco`0co`0053?o00030000oooooooo073oool008ooool0
0`0003?o03?o0004<ol000?o09Tco`0co`004c?o00030000oooooooo077oool008ooool00`0003?o
03?o0004<ol000?o09Tco`0co`004c?o00030000oooooooo077oool008ooool00`0003?o03?o0004
<ol000?o09Tco`0co`004c?o00030000oooooooo077oool008ooool00`0003?o03?o0004<ol000?o
09Tco`0co`004c?o00030000oooooooo077oool008ooool00`0003?o03?o0004<ol000?o09Tco`0c
o`004S?o00030000oooooooo07;oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`004S?o
00030000oooooooo07;oool008ooool200001C?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1b
oooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1coooo002?
oooo00<0000co`0co`0013?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1coooo002?oooo00<0
000co`0co`0013?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1coooo002?oooo00<0000co`0c
o`0013?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1doooo002?oooo00<0000co`0co`0013?o
0003o`2I<ol0<ol0010co`000`000?ooooooo`1doooo002?oooo0P0000Dco`000ol0VC?o03?o000@
<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000@<ol000<0
003oooooool0M?ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000?<ol000<0003ooooo
ool0MOooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000?<ol000<0003oooooool0MOoo
o`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000?<ol000<0003oooooool0MOooo`00Sooo
o`030000<ol0<ol000@co`000ol0VC?o03?o000><ol000<0003oooooool0M_ooo`00Soooo`800005
<ol000?o09Tco`0co`003S?o00030000oooooooo07Koool008ooool00`0003?o03?o0004<ol000?o
09Tco`0co`003S?o00030000oooooooo07Koool008ooool00`0003?o03?o0004<ol000?o09Tco`0c
o`003S?o00030000oooooooo07Koool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`003C?o
00030000oooooooo07Ooool008Soool200001Oooo`030000<ol0<ol000@co`000ol0VC?o03?o000=
<ol000<0003oooooool0Moooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000@co`00
0ol0VC?o03?o000=<ol000<0003oooooool0Moooo`00ROooo`030000oooooooo00?oool3000013?o
0003o`2I<ol0<ol000`co`000`000?ooooooo`1hoooo002:oooo00<0003oooooool00_ooo`030000
<ol0<ol000@co`000ol0VC?o03?o000<<ol000<0003oooooool0N?ooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol000@co`000ol0VC?o03?o000<<ol000<0003oooooool0N?ooo`00R?oo
o`800005oooo00<0000co`0co`0013?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1ioooo002?
oooo00<0000co`0co`0013?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1ioooo002?oooo00<0
000co`0co`0013?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1ioooo002?oooo00<0000co`0c
o`0013?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1ioooo002?oooo0P0000Dco`000ol0VC?o
03?o000:<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000:
<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000:<ol000<0
003oooooool0N_ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000:<ol000<0003ooooo
ool0N_ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o0009<ol000<0003oooooool0Nooo
o`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o0009<ol000<0003oooooool0Noooo`00Sooo
o`800005<ol000?o09Tco`0co`002C?o00030000oooooooo07_oool008ooool00`0003?o03?o0004
<ol000?o09Tco`0co`002C?o00030000oooooooo07_oool008ooool00`0003?o03?o0004<ol000?o
09Tco`0co`0023?o00030000oooooooo07coool008ooool00`0003?o03?o0004<ol000?o09Tco`0c
o`0023?o00030000oooooooo07coool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`0023?o
00030000oooooooo07coool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`0023?o00030000
oooooooo07coool008ooool200001C?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1loooo002?
oooo00<0000co`0co`0013?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1moooo002?oooo00<0
000co`0co`0013?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1moooo002?oooo00<0000co`0c
o`0013?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1moooo002?oooo00<0000co`0co`0013?o
0003o`2I<ol0<ol000Lco`000`000?ooooooo`1moooo002?oooo00<0000co`0co`0013?o0003o`2I
<ol0<ol000Lco`000`000?ooooooo`1moooo002?oooo0P0000Dco`000ol0VC?o03?o0006<ol000<0
003oooooool0O_ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o0006<ol000<0003ooooo
ool0O_ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o0006<ol000<0003oooooool0O_oo
o`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o0006<ol000<0003oooooool0O_ooo`00Sooo
o`030000<ol0<ol000@co`000ol0VC?o03?o0005<ol000<0003oooooool0Ooooo`00ROooo`<00003
oooo00<0000co`0co`0013?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1ooooo002:oooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000ol0VC?o03?o0005<ol000<0003oooooool0Oooo
o`00Qoooo`D00003oooo0`0000@co`000ol0VC?o03?o0005<ol000<0003oooooool0Ooooo`00Qooo
o`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?ooo`lco`22oooo0029
oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool007Woool00`000?oo
ooooo`0Coooo3S?o00Ooool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool><ol02?ooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000@co`02000013?o00800002<ol000Coool0000000000004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo000023?o00070000<ol0<ol00000<ol0oooo0000
00;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000Pco`001`0003?o03?o000003?o0?ooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo
000023?o00060000<ol0<ol00000<ol0oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000003oooo`040000oooooooo000023?o00040000<ol0<ol000000oooo`030000
oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:<ol00P00
0004<ol0oooooooooooo0`0000;oool00`000?ooooooo`1ioooo002?oooo3C?o08Coool008ooool=
<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.51896 .12361 L
.52455 .12361 L
.52731 .12361 L
.52986 .12361 L
.53105 .12361 L
.53217 .12361 L
s
.53217 .12361 m
.53269 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46388 .12361 L
.46507 .12361 L
.46618 .12361 L
.46682 .12353 L
.46751 .12317 L
.46871 .12255 L
.47106 .12136 L
.47994 .117 L
.49955 .10821 L
.51949 .10026 L
.52434 .09845 L
.52953 .09655 L
.53106 .096 L
.53182 .09573 L
.53251 .09549 L
.53382 .12361 L
.5345 .12361 L
.53523 .12361 L
.54055 .12361 L
.57831 .12361 L
.61851 .12361 L
.6572 .12361 L
.69834 .12361 L
.73796 .12361 L
.77607 .12361 L
.81663 .12361 L
.85567 .12361 L
.89717 .12361 L
.93715 .12361 L
.97562 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0aoooo00<0003oooooool01Oooo`0306Kooooooooo02Woool010000?ooooooo`0000Woool0
0`000?ooooooo`0eoooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P0000[oool30000<Ooo
o`800002oooo1@1Vobcoool200002_ooo`<0000doooo0P0001Ooool008ooool010000?ooo`1Vo`1V
o`Coool00`1Vooooooooo`26oooo002?oooo00<00000I_ooool01Oooo`0306Kooooooooo08Koool0
08goool206Ko00<0003oooooool01_ooo`0306Kooooooooo08Goool008_oool206Ko0_ooo`030000
oooooooo00Koool00`1Vooooooooo`25oooo002:oooo00<0I_ooooooool00_ooo`030000oooooooo
00Koool00`1Vooooooooo`25oooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0000co`0co`001C?o0005o`2I<ol0<ol0<ol0000000/co`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Xco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Ooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o000a<ol000<0000co`0co`00=S?o00D0000Goooo002?
oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0068co`0800007?ooo`00Soooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o001L<ol01P0002Coool008ooool00`0003?o03?o0005<ol000?o09Tco`0c
o`00Ec?o00D0000Zoooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0058co`050000;ooo
o`00Soooo`800006<ol000?o09Tco`0co`00CC?o00D0000doooo002?oooo00<0000co`0co`001C?o
0003o`2I<ol0<ol004Tco`040000>Oooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o0017
<ol00P0003goool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`00A3?o00<0000ooooo002?
oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0048co`020000@_ooo`00Soooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o0010<ol00P0004Coool008ooool200001S?o0003o`2I<ol0<ol003hco`02
0000A_ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000l<ol00P0004Soool008ooool0
0`0003?o03?o0005<ol000?o09Tco`0co`00>c?o00030000oooooooo04Soool008ooool00`0003?o
03?o0005<ol000?o09Tco`0co`00>C?o0080001;oooo002?oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol003Lco`020000COooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000f<ol000<0
003oooooool0COooo`00Soooo`800006<ol000?o09Tco`0co`00=3?o0080001@oooo002?oooo00<0
000co`0co`001C?o0003o`2I<ol0<ol0038co`020000D_ooo`00Soooo`030000<ol0<ol000Dco`00
0ol0VC?o03?o000a<ol000<0003oooooool0D_ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o
03?o000`<ol000<0003oooooool0Doooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000^
<ol00P0005Koool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`00;C?o00030000oooooooo
05Koool008ooool200001S?o0003o`2I<ol0<ol002`co`000`000?ooooooo`1Goooo002?oooo00<0
000co`0co`001C?o0003o`2I<ol0<ol002/co`000`000?ooooooo`1Hoooo002?oooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol002Xco`000`000?ooooooo`1Ioooo002?oooo00<0000co`0co`001C?o
0003o`2I<ol0<ol002Tco`000`000?ooooooo`1Joooo002?oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol002Tco`000`000?ooooooo`1Joooo0027oooo1@0000?oool00`0003?o03?o0005<ol000?o
09Tco`0co`00:3?o00030000oooooooo05_oool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol002Lco`000`000?ooooooo`1Loooo0029oooo00<0003oooooool00ooo
o`<00005<ol000?o09Tco`0co`009S?o00030000oooooooo05goool008Woool00`000?ooooooo`03
oooo00<0000co`0co`001C?o0003o`2I<ol0<ol002Hco`000`000?ooooooo`1Moooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000Dco`000ol0VC?o03?o000U<ol000<0003oooooool0G_oo
o`00R?ooo`800005oooo00<0000co`0co`001C?o0003o`2I<ol0<ol002@co`000`000?ooooooo`1O
oooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol002<co`000`000?ooooooo`1Poooo002?
oooo00<0000co`0co`001C?o0003o`2I<ol0<ol002<co`000`000?ooooooo`1Poooo002?oooo0P00
00Hco`000ol0VC?o03?o000R<ol000<0003oooooool0HOooo`00Soooo`030000<ol0<ol000Dco`00
0ol0VC?o03?o000Q<ol000<0003oooooool0H_ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o
03?o000Q<ol000<0003oooooool0H_ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000P
<ol000<0003oooooool0Hoooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000O<ol000<0
003oooooool0I?ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000N<ol000<0003ooooo
ool0IOooo`00Soooo`800006<ol000?o09Tco`0co`007S?o00030000oooooooo06Goool008ooool0
0`0003?o03?o0005<ol000?o09Tco`0co`007C?o00030000oooooooo06Koool008ooool00`0003?o
03?o0005<ol000?o09Tco`0co`0073?o00030000oooooooo06Ooool008ooool00`0003?o03?o0005
<ol000?o09Tco`0co`0073?o00030000oooooooo06Ooool008ooool00`0003?o03?o0005<ol000?o
09Tco`0co`006c?o00030000oooooooo06Soool008ooool00`0003?o03?o0005<ol000?o09Tco`0c
o`006c?o00030000oooooooo06Soool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`006S?o
00030000oooooooo06Woool008ooool200001S?o0003o`2I<ol0<ol001Xco`000`000?ooooooo`1Y
oooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol001Tco`000`000?ooooooo`1Zoooo002?
oooo00<0000co`0co`001C?o0003o`2I<ol0<ol001Tco`000`000?ooooooo`1Zoooo002?oooo00<0
000co`0co`001C?o0003o`2I<ol0<ol001Pco`000`000?ooooooo`1[oooo002?oooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol001Pco`000`000?ooooooo`1[oooo002?oooo00<0000co`0co`001C?o
0003o`2I<ol0<ol001Pco`000`000?ooooooo`1[oooo002?oooo0P0000Hco`000ol0VC?o03?o000G
<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000G<ol000<0
003oooooool0K?ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000F<ol000<0003ooooo
ool0KOooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000F<ol000<0003oooooool0KOoo
o`00Qoooo`@00004oooo00<0000co`0co`001C?o0003o`2I<ol0<ol001Hco`000`000?ooooooo`1]
oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000Dco`000ol0VC?o03?o000E<ol000<0
003oooooool0K_ooo`00R?ooo`030000oooooooo00Coool300001C?o0003o`2I<ol0<ol001Dco`00
0`000?ooooooo`1^oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000Dco`000ol0VC?o
03?o000E<ol000<0003oooooool0K_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o000D<ol000<0003oooooool0Koooo`00R?ooo`800005oooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol001@co`000`000?ooooooo`1_oooo002?oooo00<0000co`0co`001C?o
0003o`2I<ol0<ol001<co`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol001<co`000`000?ooooooo`1`oooo002?oooo0P0000Hco`000ol0VC?o03?o000C<ol000<0
003oooooool0L?ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000B<ol000<0003ooooo
ool0LOooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000B<ol000<0003oooooool0LOoo
o`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000B<ol000<0003oooooool0LOooo`00Sooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o000B<ol000<0003oooooool0LOooo`00Soooo`030000
<ol0<ol000Dco`000ol0VC?o03?o000A<ol000<0003oooooool0L_ooo`00Soooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o000A<ol000<0003oooooool0L_ooo`00Soooo`800006<ol000?o09Tco`0c
o`004C?o00030000oooooooo07;oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`0043?o
00030000oooooooo07?oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`0043?o00030000
oooooooo07?oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`0043?o00030000oooooooo
07?oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`003c?o00030000oooooooo07Coool0
08ooool00`0003?o03?o0005<ol000?o09Tco`0co`003c?o00030000oooooooo07Coool008ooool2
00001S?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1doooo002?oooo00<0000co`0co`001C?o
0003o`2I<ol0<ol000lco`000`000?ooooooo`1doooo002?oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol000hco`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
00hco`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000hco`00
0`000?ooooooo`1eoooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000dco`000`000?oo
ooooo`1foooo002?oooo0P0000Hco`000ol0VC?o03?o000=<ol000<0003oooooool0M_ooo`00Sooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o000=<ol000<0003oooooool0M_ooo`00Soooo`030000
<ol0<ol000Dco`000ol0VC?o03?o000=<ol000<0003oooooool0M_ooo`00Soooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o000<<ol000<0003oooooool0Moooo`00R?ooo`800005oooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1goooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1goooo0029oooo00<0
003oooooool00oooo`<00005<ol000?o09Tco`0co`002c?o00030000oooooooo07Soool008[oool0
0`000?ooooooo`02oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1h
oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000/co`00
0`000?ooooooo`1hoooo0028oooo0P0000Goool00`0003?o03?o0005<ol000?o09Tco`0co`002S?o
00030000oooooooo07Woool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`002S?o00030000
oooooooo07Woool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`002S?o00030000oooooooo
07Woool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`002S?o00030000oooooooo07Woool0
08ooool200001S?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1joooo002?oooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1joooo002?oooo00<0000co`0co`001C?o
0003o`2I<ol0<ol000Tco`000`000?ooooooo`1joooo002?oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol000Tco`000`000?ooooooo`1joooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
00Pco`000`000?ooooooo`1koooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000Pco`00
0`000?ooooooo`1koooo002?oooo0P0000Hco`000ol0VC?o03?o0008<ol000<0003oooooool0Nooo
o`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o0008<ol000<0003oooooool0Noooo`00Sooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o0007<ol000<0003oooooool0O?ooo`00Soooo`030000
<ol0<ol000Dco`000ol0VC?o03?o0007<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o0007<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol000Dco`00
0ol0VC?o03?o0007<ol000<0003oooooool0O?ooo`00Soooo`800006<ol000?o09Tco`0co`001c?o
00030000oooooooo07coool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`001S?o00030000
oooooooo07goool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`001S?o00030000oooooooo
07goool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`001S?o00030000oooooooo07goool0
08ooool00`0003?o03?o0005<ol000?o09Tco`0co`001S?o00030000oooooooo07goool008ooool0
0`0003?o03?o0005<ol000?o09Tco`0co`001S?o00030000oooooooo07goool008ooool200001S?o
0003o`2I<ol0<ol000Dco`000`000?ooooooo`1noooo002?oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`1noooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
00Dco`000`000?ooooooo`1noooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000Dco`00
0`000?ooooooo`1noooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000@co`000`000?oo
ooooo`1ooooo0029oooo0`0000?oool00`0003?o03?o0005<ol000?o09Tco`0co`0013?o00030000
oooooooo07ooool008[oool00`000?ooooooo`02oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
00@co`000`000?ooooooo`1ooooo0027oooo1@0000?oool300001C?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`1ooooo0027oooo00@0003oooooool00004oooo3c?o08;oool008Soool00`000?oo
o`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o08;oool008ooool?
<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o00800004<ol00P00
008co`03oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Pco`00
1@0003?o03?o000003?o0003oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo000023?o00050000<ol0<ol0
0000<ol000?oool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000<oooo00@0003oooooool00008<ol000D0000co`0co`00000co`001?ooo`050000oooooooo
oooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008<ol000@0
000co`0co`000002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo017oool200002S?o008000000c?o0?ooooooo`0400000_ooo`030000oooooooo07Woool0
08ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.51896 .12361 L
.52455 .12361 L
.52986 .12361 L
.53463 .12361 L
.53594 .12361 L
.53666 .12361 L
.53733 .12361 L
s
.53733 .12361 m
.53786 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.45734 .12361 L
.45963 .12361 L
.46063 .12361 L
.46172 .12361 L
.46283 .12313 L
.46388 .12259 L
.46618 .12141 L
.47106 .11899 L
.47994 .11476 L
.49955 .10624 L
.51949 .09853 L
.52953 .09492 L
.53228 .09396 L
.53523 .09295 L
.53666 .09246 L
.53737 .09223 L
.53802 .09201 L
.53923 .12361 L
.54055 .12361 L
.57982 .12361 L
.61757 .12361 L
.65777 .12361 L
.69646 .12361 L
.7376 .12361 L
.77723 .12361 L
.81533 .12361 L
.8559 .12361 L
.89494 .12361 L
.93644 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool01_ooo`80I_lYoooo00@0003oooooool00009oooo0P00
03Koool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002Ooo
o`030000oooooooo037oool00`000?ooooooo`04oooo101VobWoool010000?ooooooo`0000Woool0
0`000?ooooooo`0eoooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P0000[oool30000<Ooo
o`800002oooo0`1Vo`?oool00`1Vooooooooo`0Xoooo0P0000[oool30000=?ooo`80000Goooo002?
oooo00@0003oool0I_l0I_l6oooo00<0I_ooooooool0Q?ooo`00S_ooo`0306Ko000006Ko00Soool0
0`1Vooooooooo`24oooo002<oooo0P1Vo`03oooo0000oooo00Soool00`1Vooooooooo`24oooo002:
oooo0P1Vo`?oool00`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00R?ooo`80I_l5oooo00<0
003oooooool01oooo`0306Kooooooooo08Coool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0006<ol000Co09Tco`0co`00000;
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`0003?o03?o0006<ol000?o09Tco`0co`00<3?o00030000<ol0<ol003Hco`0500005ooo
o`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o001Q<ol0200001coool008ooool00`0003?o
03?o0006<ol000?o09Tco`0co`00Fc?o00H0000Toooo002?oooo00<0000co`0co`001S?o0003o`2I
<ol0<ol005Hco`050000:_ooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o001A<ol01@00
02ooool008ooool200001c?o0003o`2I<ol0<ol004`co`050000=?ooo`00Soooo`030000<ol0<ol0
00Hco`000ol0VC?o03?o0018<ol0100003Woool008ooool00`0003?o03?o0006<ol000?o09Tco`0c
o`00AS?o0080000moooo002?oooo00<0000co`0co`001S?o0003o`2I<ol0<ol004<co`030000?ooo
o`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o0011<ol00P0004;oool008ooool00`0003?o
03?o0006<ol000?o09Tco`0co`00?c?o00800014oooo002?oooo0P0000Lco`000ol0VC?o03?o000m
<ol00P0004Koool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`00>c?o00800018oooo002?
oooo00<0000co`0co`001S?o0003o`2I<ol0<ol003Xco`000`000?ooooooo`18oooo002?oooo00<0
000co`0co`001S?o0003o`2I<ol0<ol003Pco`020000Boooo`00Soooo`030000<ol0<ol000Hco`00
0ol0VC?o03?o000f<ol00P0004goool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`00=C?o
00030000oooooooo04goool008ooool200001c?o0003o`2I<ol0<ol003<co`020000D?ooo`00Sooo
o`030000<ol0<ol000Hco`000ol0VC?o03?o000a<ol00P0005;oool008ooool00`0003?o03?o0006
<ol000?o09Tco`0co`00<3?o00030000oooooooo05;oool008ooool00`0003?o03?o0006<ol000?o
09Tco`0co`00;c?o00030000oooooooo05?oool008ooool00`0003?o03?o0006<ol000?o09Tco`0c
o`00;C?o0080001Foooo002?oooo00<0000co`0co`001S?o0003o`2I<ol0<ol002`co`000`000?oo
ooooo`1Foooo002?oooo0P0000Lco`000ol0VC?o03?o000[<ol000<0003oooooool0Eoooo`00Sooo
o`030000<ol0<ol000Hco`000ol0VC?o03?o000Z<ol000<0003oooooool0F?ooo`00Soooo`030000
<ol0<ol000Hco`000ol0VC?o03?o000Y<ol000<0003oooooool0FOooo`00Soooo`030000<ol0<ol0
00Hco`000ol0VC?o03?o000X<ol000<0003oooooool0F_ooo`00Soooo`030000<ol0<ol000Hco`00
0ol0VC?o03?o000X<ol000<0003oooooool0F_ooo`00Qoooo`D00003oooo00<0000co`0co`001S?o
0003o`2I<ol0<ol002Lco`000`000?ooooooo`1Koooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol000Hco`000ol0VC?o03?o000V<ol000<0003oooooool0G?ooo`00ROooo`030000oooooooo
00?oool300001S?o0003o`2I<ol0<ol002Dco`000`000?ooooooo`1Moooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol000Hco`000ol0VC?o03?o000U<ol000<0003oooooool0GOooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o0006<ol000?o09Tco`0co`0093?o00030000oooooooo
05koool008Soool200001Oooo`030000<ol0<ol000Hco`000ol0VC?o03?o000S<ol000<0003ooooo
ool0Goooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o000R<ol000<0003oooooool0H?oo
o`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o000R<ol000<0003oooooool0H?ooo`00Sooo
o`800007<ol000?o09Tco`0co`008C?o00030000oooooooo067oool008ooool00`0003?o03?o0006
<ol000?o09Tco`0co`0083?o00030000oooooooo06;oool008ooool00`0003?o03?o0006<ol000?o
09Tco`0co`0083?o00030000oooooooo06;oool008ooool00`0003?o03?o0006<ol000?o09Tco`0c
o`007c?o00030000oooooooo06?oool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`007S?o
00030000oooooooo06Coool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`007C?o00030000
oooooooo06Goool008ooool200001c?o0003o`2I<ol0<ol001dco`000`000?ooooooo`1Uoooo002?
oooo00<0000co`0co`001S?o0003o`2I<ol0<ol001`co`000`000?ooooooo`1Voooo002?oooo00<0
000co`0co`001S?o0003o`2I<ol0<ol001/co`000`000?ooooooo`1Woooo002?oooo00<0000co`0c
o`001S?o0003o`2I<ol0<ol001/co`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`001S?o
0003o`2I<ol0<ol001Xco`000`000?ooooooo`1Xoooo002?oooo00<0000co`0co`001S?o0003o`2I
<ol0<ol001Xco`000`000?ooooooo`1Xoooo002?oooo00<0000co`0co`001S?o0003o`2I<ol0<ol0
01Tco`000`000?ooooooo`1Yoooo002?oooo0P0000Lco`000ol0VC?o03?o000I<ol000<0003ooooo
ool0JOooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o000H<ol000<0003oooooool0J_oo
o`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o000H<ol000<0003oooooool0J_ooo`00Sooo
o`030000<ol0<ol000Hco`000ol0VC?o03?o000G<ol000<0003oooooool0Joooo`00Soooo`030000
<ol0<ol000Hco`000ol0VC?o03?o000G<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol0
00Hco`000ol0VC?o03?o000G<ol000<0003oooooool0Joooo`00Soooo`800007<ol000?o09Tco`0c
o`005S?o00030000oooooooo06coool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`005S?o
00030000oooooooo06coool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`005C?o00030000
oooooooo06goool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`005C?o00030000oooooooo
06goool008Ooool400001?ooo`030000<ol0<ol000Hco`000ol0VC?o03?o000E<ol000<0003ooooo
ool0KOooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o0006<ol000?o09Tco`0co`0053?o
00030000oooooooo06koool008Soool00`000?ooooooo`04oooo0`0000Hco`000ol0VC?o03?o000D
<ol000<0003oooooool0K_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o0007<ol000?o
09Tco`0co`004c?o00030000oooooooo06koool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o0007<ol000?o09Tco`0co`004S?o00030000oooooooo06ooool008Soool200001Oooo`030000
<ol0<ol000Lco`000ol0VC?o03?o000B<ol000<0003oooooool0Koooo`00Soooo`030000<ol0<ol0
00Lco`000ol0VC?o03?o000A<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol000Lco`00
0ol0VC?o03?o000A<ol000<0003oooooool0L?ooo`00Soooo`800008<ol000?o09Tco`0co`004C?o
00030000oooooooo073oool008ooool00`0003?o03?o0007<ol000?o09Tco`0co`0043?o00030000
oooooooo077oool008ooool00`0003?o03?o0007<ol000?o09Tco`0co`0043?o00030000oooooooo
077oool008ooool00`0003?o03?o0007<ol000?o09Tco`0co`0043?o00030000oooooooo077oool0
08ooool00`0003?o03?o0007<ol000?o09Tco`0co`0043?o00030000oooooooo077oool008ooool0
0`0003?o03?o0007<ol000?o09Tco`0co`003c?o00030000oooooooo07;oool008ooool00`0003?o
03?o0007<ol000?o09Tco`0co`003c?o00030000oooooooo07;oool008ooool2000023?o0003o`2I
<ol0<ol000lco`000`000?ooooooo`1boooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol0
00hco`000`000?ooooooo`1coooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000hco`00
0`000?ooooooo`1coooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000hco`000`000?oo
ooooo`1coooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1d
oooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1doooo002?
oooo0P0000Pco`000ol0VC?o03?o000=<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol0
00Lco`000ol0VC?o03?o000=<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol000Lco`00
0ol0VC?o03?o000<<ol000<0003oooooool0MOooo`00Soooo`030000<ol0<ol000Lco`000ol0VC?o
03?o000<<ol000<0003oooooool0MOooo`00Soooo`030000<ol0<ol000Lco`000ol0VC?o03?o000<
<ol000<0003oooooool0MOooo`00Soooo`030000<ol0<ol000Lco`000ol0VC?o03?o000;<ol000<0
003oooooool0M_ooo`00Soooo`800008<ol000?o09Tco`0co`002c?o00030000oooooooo07Koool0
08ooool00`0003?o03?o0007<ol000?o09Tco`0co`002c?o00030000oooooooo07Koool008ooool0
0`0003?o03?o0007<ol000?o09Tco`0co`002c?o00030000oooooooo07Koool008ooool00`0003?o
03?o0007<ol000?o09Tco`0co`002S?o00030000oooooooo07Ooool008Soool200001Oooo`030000
<ol0<ol000Lco`000ol0VC?o03?o000:<ol000<0003oooooool0Moooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol000Lco`000ol0VC?o03?o000:<ol000<0003oooooool0Moooo`00ROoo
o`030000oooooooo00?oool300001c?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1hoooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000ol0VC?o03?o0009<ol000<0003ooooo
ool0N?ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Lco`000ol0VC?o03?o0009
<ol000<0003oooooool0N?ooo`00R?ooo`800005oooo00<0000co`0co`001c?o0003o`2I<ol0<ol0
00Pco`000`000?ooooooo`1ioooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000Pco`00
0`000?ooooooo`1ioooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000Pco`000`000?oo
ooooo`1ioooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1i
oooo002?oooo0P0000Pco`000ol0VC?o03?o0007<ol000<0003oooooool0N_ooo`00Soooo`030000
<ol0<ol000Lco`000ol0VC?o03?o0007<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol0
00Lco`000ol0VC?o03?o0007<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol000Lco`00
0ol0VC?o03?o0007<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol000Lco`000ol0VC?o
03?o0006<ol000<0003oooooool0Noooo`00Soooo`030000<ol0<ol000Lco`000ol0VC?o03?o0006
<ol000<0003oooooool0Noooo`00Soooo`800008<ol000?o09Tco`0co`001S?o00030000oooooooo
07_oool008ooool00`0003?o03?o0007<ol000?o09Tco`0co`001S?o00030000oooooooo07_oool0
08ooool00`0003?o03?o0007<ol000?o09Tco`0co`001C?o00030000oooooooo07coool008ooool0
0`0003?o03?o0007<ol000?o09Tco`0co`001C?o00030000oooooooo07coool008ooool00`0003?o
03?o0007<ol000?o09Tco`0co`001C?o00030000oooooooo07coool008ooool00`0003?o03?o0007
<ol000?o09Tco`0co`001C?o00030000oooooooo07coool008ooool2000023?o0003o`2I<ol0<ol0
00Dco`000`000?ooooooo`1loooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`1moooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000@co`000`000?oo
ooooo`1moooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1m
oooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1moooo002?
oooo00<0000co`0co`001c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1moooo002?oooo0P00
00Pco`000ol0VC?o03?o0003<ol000<0003oooooool0O_ooo`00Soooo`030000<ol0<ol000Lco`00
0ol0VC?o03?o0003<ol000<0003oooooool0O_ooo`00Soooo`030000<ol0<ol000Lco`000ol0VC?o
03?o0003<ol000<0003oooooool0O_ooo`00Soooo`030000<ol0<ol000Lco`000ol0VC?o03?o0003
<ol000<0003oooooool0O_ooo`00Soooo`030000<ol0<ol000Lco`000ol0VC?o03?o0002<ol000<0
003oooooool0Ooooo`00ROooo`<00003oooo00<0000co`0co`001c?o0003o`2I<ol0<ol0008co`00
0`000?ooooooo`1ooooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000Lco`000ol0VC?o
03?o0002<ol000<0003oooooool0Ooooo`00Qoooo`D00003oooo0`0000Lco`000ol0VC?o03?o0002
<ol000<0003oooooool0Ooooo`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0
003oool000001?ooo`lco`22oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?
oooo3c?o08;oool007Woool00`000?ooooooo`0Coooo3S?o00Ooool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo00Woool><ol02?ooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000@co`02000013?o
00800002<ol00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo000023?o00070000
<ol0<ol00000<ol0oooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00goool010000?ooooooo`0000Pco`001`0003?o03?o000003?o0?oo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003?ooo`040000oooooooo000023?o00050000<ol0<ol00000<ol000;oool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008<ol000@0
000co`0co`000002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo017oool200002S?o0080000013?o0?ooooooooooo`800003oooo00<0003oooooool0NOoo
o`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53057 .12361 L
.53543 .12361 L
.53984 .12361 L
.54098 .12361 L
.54221 .12361 L
s
.54221 .12361 m
.54267 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.44268 .12361 L
.44778 .12361 L
.45262 .12361 L
.45473 .12361 L
.45588 .12361 L
.45697 .12361 L
.45826 .12303 L
.45943 .12243 L
.46172 .12127 L
.50027 .10406 L
.51981 .09674 L
.53017 .09313 L
.53587 .09122 L
.53868 .09029 L
.53991 .08989 L
.54127 .08945 L
.54255 .08903 L
.54375 .12361 L
.54502 .12361 L
.54639 .12361 L
.55195 .12361 L
.56169 .12361 L
.58076 .12361 L
.6219 .12361 L
.66152 .12361 L
.69963 .12361 L
.74019 .12361 L
.77924 .12361 L
.82073 .12361 L
.86072 .12361 L
.89918 .12361 L
.9401 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`0aoooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000boooo00<0003oooooool01_ooo`<0I_lXoooo00@0003oooooool00009oooo0P00
03Koool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002Ooo
o`030000oooooooo037oool00`000?ooooooo`04oooo0P1Vo`;oool00`1Vooooooooo`0Voooo00@0
003oooooool00009oooo00<0003oooooool0=Oooo`030000oooooooo01Goool001Soool20000=Ooo
o`80000:oooo0`00037oool2000000?oool0I_l0I_l00P1Vo`Coool00`1Vooooooooo`0Woooo0P00
00[oool30000=?ooo`80000Goooo002?oooo00<00000I_l0I_l02?ooo`0306Kooooooooo08?oool0
08goool206Ko00<0003oooooool02?ooo`0306Kooooooooo08?oool008_oool206Ko0_ooo`030000
oooooooo00Soool00`1Vooooooooo`23oooo0029oooo0P1Vo`Coool00`000?ooooooo`08oooo00<0
I_ooooooool0Poooo`00Qoooo`80I_l6oooo00<0003oooooool02?ooo`0306Kooooooooo08?oool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`0003?o03?o0008<ol000?o09T0000co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0003oooooool05Oooo`005_oo
o`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`0023?o0003o`2I<ol0<ol0
02hco`000`0003?o03?o000f<ol01@0001Ooool008ooool00`0003?o03?o0008<ol000?o09Tco`0c
o`00Gc?o00P0000Loooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol005Tco`0600009?oo
o`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o001D<ol01@0002[oool008ooool00`0003?o
03?o0008<ol000?o09Tco`0co`00Cc?o00D0000_oooo002?oooo0P0000Tco`000ol0VC?o03?o001:
<ol01@0003Coool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`00AS?o00@0000ioooo002?
oooo00<0000co`0co`0023?o0003o`2I<ol0<ol004@co`020000?Oooo`00Soooo`030000<ol0<ol0
00Pco`000ol0VC?o03?o0011<ol00`0003ooool008ooool00`0003?o03?o0008<ol000?o09Tco`0c
o`00?c?o00800012oooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol003dco`020000A?oo
o`00Soooo`800009<ol000?o09Tco`0co`00>c?o00800016oooo002?oooo00<0000co`0co`0023?o
0003o`2I<ol0<ol003Tco`020000B?ooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o000h
<ol000<0003oooooool0B?ooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o000f<ol00P00
04_oool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`00=3?o0080001=oooo002?oooo00<0
000co`0co`0023?o0003o`2I<ol0<ol003<co`000`000?ooooooo`1=oooo002?oooo0P0000Tco`00
0ol0VC?o03?o000a<ol00P00053oool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`00;c?o
0080001Boooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol002hco`000`000?ooooooo`1B
oooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol002dco`000`000?ooooooo`1Coooo002?
oooo00<0000co`0co`0023?o0003o`2I<ol0<ol002/co`020000E_ooo`00Soooo`030000<ol0<ol0
00Pco`000ol0VC?o03?o000Z<ol000<0003oooooool0E_ooo`00Soooo`800009<ol000?o09Tco`0c
o`00:C?o00030000oooooooo05Ooool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`00:3?o
00030000oooooooo05Soool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`009c?o00030000
oooooooo05Woool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`009S?o00030000oooooooo
05[oool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`009S?o00030000oooooooo05[oool0
08Ooool500000oooo`030000<ol0<ol000Pco`000ol0VC?o03?o000U<ol000<0003oooooool0Fooo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o0008<ol000?o09Tco`0co`0093?o00030000
oooooooo05coool008Woool00`000?ooooooo`03oooo0`0000Pco`000ol0VC?o03?o000S<ol000<0
003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o0008<ol000?o09Tco`0c
o`008c?o00030000oooooooo05goool008Woool00`000?ooooooo`03oooo00<0000co`0co`0023?o
0003o`2I<ol0<ol0028co`000`000?ooooooo`1Noooo0028oooo0P0000Goool00`0003?o03?o0008
<ol000?o09Tco`0co`008C?o00030000oooooooo05ooool008ooool00`0003?o03?o0008<ol000?o
09Tco`0co`0083?o00030000oooooooo063oool008ooool00`0003?o03?o0008<ol000?o09Tco`0c
o`0083?o00030000oooooooo063oool008ooool200002C?o0003o`2I<ol0<ol001lco`000`000?oo
ooooo`1Qoooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol001hco`000`000?ooooooo`1R
oooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol001hco`000`000?ooooooo`1Roooo002?
oooo00<0000co`0co`0023?o0003o`2I<ol0<ol001dco`000`000?ooooooo`1Soooo002?oooo00<0
000co`0co`0023?o0003o`2I<ol0<ol001`co`000`000?ooooooo`1Toooo002?oooo00<0000co`0c
o`0023?o0003o`2I<ol0<ol001/co`000`000?ooooooo`1Uoooo002?oooo0P0000Tco`000ol0VC?o
03?o000K<ol000<0003oooooool0IOooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o000J
<ol000<0003oooooool0I_ooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o000I<ol000<0
003oooooool0Ioooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o000I<ol000<0003ooooo
ool0Ioooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o000H<ol000<0003oooooool0J?oo
o`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o000H<ol000<0003oooooool0J?ooo`00Sooo
o`030000<ol0<ol000Pco`000ol0VC?o03?o000G<ol000<0003oooooool0JOooo`00Soooo`800009
<ol000?o09Tco`0co`005c?o00030000oooooooo06Woool008ooool00`0003?o03?o0008<ol000?o
09Tco`0co`005S?o00030000oooooooo06[oool008ooool00`0003?o03?o0008<ol000?o09Tco`0c
o`005S?o00030000oooooooo06[oool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`005C?o
00030000oooooooo06_oool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`005C?o00030000
oooooooo06_oool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`005C?o00030000oooooooo
06_oool008ooool200002C?o0003o`2I<ol0<ol001@co`000`000?ooooooo`1/oooo002?oooo00<0
000co`0co`0023?o0003o`2I<ol0<ol001@co`000`000?ooooooo`1/oooo002?oooo00<0000co`0c
o`0023?o0003o`2I<ol0<ol001<co`000`000?ooooooo`1]oooo002?oooo00<0000co`0co`0023?o
0003o`2I<ol0<ol001<co`000`000?ooooooo`1]oooo0027oooo100000Coool00`0003?o03?o0008
<ol000?o09Tco`0co`004c?o00030000oooooooo06goool008Ooool00`000?ooooooo`05oooo00<0
000co`0co`0023?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1^oooo0028oooo00<0003ooooo
ool01?ooo`<00008<ol000?o09Tco`0co`004S?o00030000oooooooo06koool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`0023?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1^oooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`0023?o0003o`2I<ol0<ol0014co`000`000?oo
ooooo`1_oooo0028oooo0P0000Goool00`0003?o03?o0008<ol000?o09Tco`0co`004C?o00030000
oooooooo06ooool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`0043?o00030000oooooooo
073oool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`0043?o00030000oooooooo073oool0
08ooool200002C?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1`oooo002?oooo00<0000co`0c
o`0023?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`0023?o
0003o`2I<ol0<ol000lco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`0023?o0003o`2I
<ol0<ol000lco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol0
00lco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000hco`00
0`000?ooooooo`1boooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000hco`000`000?oo
ooooo`1boooo002?oooo0P0000Tco`000ol0VC?o03?o000><ol000<0003oooooool0L_ooo`00Sooo
o`030000<ol0<ol000Pco`000ol0VC?o03?o000=<ol000<0003oooooool0Loooo`00Soooo`030000
<ol0<ol000Pco`000ol0VC?o03?o000=<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0
00Pco`000ol0VC?o03?o000=<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol000Pco`00
0ol0VC?o03?o000<<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o
03?o000<<ol000<0003oooooool0M?ooo`00Soooo`800009<ol000?o09Tco`0co`0033?o00030000
oooooooo07Coool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`0033?o00030000oooooooo
07Coool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`002c?o00030000oooooooo07Goool0
08ooool00`0003?o03?o0008<ol000?o09Tco`0co`002c?o00030000oooooooo07Goool008ooool0
0`0003?o03?o0008<ol000?o09Tco`0co`002c?o00030000oooooooo07Goool008ooool00`0003?o
03?o0008<ol000?o09Tco`0co`002S?o00030000oooooooo07Koool008ooool200002C?o0003o`2I
<ol0<ol000Xco`000`000?ooooooo`1foooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol0
00Xco`000`000?ooooooo`1foooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Xco`00
0`000?ooooooo`1foooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Tco`000`000?oo
ooooo`1goooo0028oooo0P0000Goool00`0003?o03?o0008<ol000?o09Tco`0co`002C?o00030000
oooooooo07Ooool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000?o09Tco`0c
o`002C?o00030000oooooooo07Ooool008Woool00`000?ooooooo`03oooo0`0000Pco`000ol0VC?o
03?o0008<ol000<0003oooooool0N?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008
<ol000?o09Tco`0co`0023?o00030000oooooooo07Soool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000?o09Tco`0co`0023?o00030000oooooooo07Soool008Soool200001Ooo
o`030000<ol0<ol000Pco`000ol0VC?o03?o0007<ol000<0003oooooool0NOooo`00Soooo`030000
<ol0<ol000Pco`000ol0VC?o03?o0007<ol000<0003oooooool0NOooo`00Soooo`030000<ol0<ol0
00Pco`000ol0VC?o03?o0007<ol000<0003oooooool0NOooo`00Soooo`030000<ol0<ol000Pco`00
0ol0VC?o03?o0007<ol000<0003oooooool0NOooo`00Soooo`800009<ol000?o09Tco`0co`001S?o
00030000oooooooo07[oool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`001S?o00030000
oooooooo07[oool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`001S?o00030000oooooooo
07[oool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`001S?o00030000oooooooo07[oool0
08ooool00`0003?o03?o0008<ol000?o09Tco`0co`001C?o00030000oooooooo07_oool008ooool0
0`0003?o03?o0008<ol000?o09Tco`0co`001C?o00030000oooooooo07_oool008ooool200002C?o
0003o`2I<ol0<ol000Dco`000`000?ooooooo`1koooo002?oooo00<0000co`0co`0023?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`1koooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol0
00@co`000`000?ooooooo`1loooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`1loooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000@co`000`000?oo
ooooo`1loooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1l
oooo002?oooo0P0000Tco`000ol0VC?o03?o0004<ol000<0003oooooool0O?ooo`00Soooo`030000
<ol0<ol000Pco`000ol0VC?o03?o0003<ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol0
00Pco`000ol0VC?o03?o0003<ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol000Pco`00
0ol0VC?o03?o0003<ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o
03?o0003<ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o0003
<ol000<0003oooooool0OOooo`00Soooo`800009<ol000?o09Tco`0co`000S?o00030000oooooooo
07koool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`000S?o00030000oooooooo07koool0
08ooool00`0003?o03?o0008<ol000?o09Tco`0co`000S?o00030000oooooooo07koool008ooool0
0`0003?o03?o0008<ol000?o09Tco`0co`000S?o00030000oooooooo07koool008ooool00`0003?o
03?o0008<ol000Go09Tco`0co`0co`000000POooo`00ROooo`<00003oooo00<0000co`0co`0023?o
0005o`2I<ol0<ol0<ol00000087oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o
0005o`2I<ol0<ol0<ol00000087oool008Ooool500000oooo`<00008<ol000Go09Tco`0co`0co`00
0000POooo`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?oo
o`lco`22oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool0
07Woool00`000?ooooooo`0Coooo3S?o00Ooool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo00Woool><ol02?ooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000@co`02000013?o00800002<ol000Co
ool0000000000004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo000023?o00050000<ol0<ol0
0000<ol000?oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0=oooo00@0003oooooool00008<ol000D0000co`0co`00000co`000_oo
o`<00004oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003ooooo
ool00008<ol000L0000co`0co`00000co`3oool000000_ooo`050000oooooooooooo000007[oool0
07Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008<ol000@0000co`0co`000002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00002S?o0080000013?o0?ooooooooooo`<00002oooo00<0003oooooool0NOooo`00Soooo`dco`24
oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53057 .12361 L
.53984 .12361 L
.54444 .12361 L
.54576 .12361 L
.54701 .12361 L
s
.54701 .12361 m
.54746 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44268 .12361 L
.44744 .12361 L
.44874 .12361 L
.45013 .12361 L
.45143 .12361 L
.45262 .12348 L
.45379 .12288 L
.45487 .12232 L
.45731 .12109 L
.46172 .1189 L
.5012 .10186 L
.52107 .09469 L
.52974 .09176 L
.53918 .08869 L
.5417 .08789 L
.54438 .08705 L
.54548 .08671 L
.54667 .08635 L
.54797 .12361 L
.54919 .12361 L
.55869 .12361 L
.5796 .12361 L
.62074 .12361 L
.66036 .12361 L
.69847 .12361 L
.73903 .12361 L
.77808 .12361 L
.81958 .12361 L
.85956 .12361 L
.89802 .12361 L
.93894 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02ooool00`000?ooooooo`08oooo0P1VobOoool010000?ooooooo`0000_oool00`000?ooooooo`0c
oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?ooo`@00002oooo00@0
003oooooool00009oooo0P0003;oool00`000?ooooooo`04oooo101Vo`03oooo06Kooooo02Koool0
10000?ooooooo`0000Woool20000=_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`0b
oooo00@0003oooooool00009oooo00<0003oooooool0<Oooo`040000oooooooooooo0`1Vo`Goool0
0`1Vooooooooo`0Uoooo00@0003oooooool00009oooo00<0003oooooool0=Oooo`030000oooooooo
01Goool001Soool20000=Oooo`80000:oooo0`00037oool200000P1Vo`Soool00`1Vooooooooo`0V
oooo0P0000[oool30000=?ooo`80000Goooo002>oooo00<0I_l00000I_l02_ooo`0306Kooooooooo
08;oool008coool206Ko00?oool0003oool02_ooo`0306Kooooooooo08;oool008Woool306Ko0ooo
o`030000oooooooo00Woool00`1Vooooooooo`22oooo0027oooo0P1Vo`Koool00`000?ooooooo`09
oooo00<0I_ooooooool0P_ooo`00QOooo`80I_l8oooo00<0003oooooool02Oooo`0306Kooooooooo
08;oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0
000co`0co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`002C?o0003o`2I
<ol0<ol002dco`000`0003?o03?o000f<ol01@0001Ooool008ooool00`0003?o03?o0009<ol000?o
09Tco`0co`00GS?o00P0000Loooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol005Pco`06
00009?ooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o001C<ol01@0002[oool008ooool0
0`0003?o03?o0009<ol000?o09Tco`0co`00CS?o00D0000_oooo002?oooo0P0000Xco`000ol0VC?o
03?o0019<ol01@0003Coool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`00AC?o00@0000i
oooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol004<co`020000?Oooo`00Soooo`030000
<ol0<ol000Tco`000ol0VC?o03?o0010<ol00`0003ooool008ooool00`0003?o03?o0009<ol000?o
09Tco`0co`00?S?o00800012oooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol003`co`02
0000A?ooo`00Soooo`80000:<ol000?o09Tco`0co`00>S?o00800016oooo002?oooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol003Pco`020000B?ooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o
03?o000g<ol000<0003oooooool0B?ooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o000e
<ol00P0004_oool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`00<c?o0080001=oooo002?
oooo00<0000co`0co`002C?o0003o`2I<ol0<ol0038co`000`000?ooooooo`1=oooo002?oooo0P00
00Xco`000ol0VC?o03?o000`<ol00P00053oool008ooool00`0003?o03?o0009<ol000?o09Tco`0c
o`00;S?o0080001Boooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol002dco`000`000?oo
ooooo`1Boooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol002`co`000`000?ooooooo`1C
oooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol002Xco`020000E_ooo`00Soooo`030000
<ol0<ol000Tco`000ol0VC?o03?o000Y<ol000<0003oooooool0E_ooo`00Soooo`80000:<ol000?o
09Tco`0co`00:3?o00030000oooooooo05Ooool008ooool00`0003?o03?o0009<ol000?o09Tco`0c
o`009c?o00030000oooooooo05Soool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`009S?o
00030000oooooooo05Woool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`009C?o00030000
oooooooo05[oool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`009C?o00030000oooooooo
05[oool008Ooool500000oooo`030000<ol0<ol000Tco`000ol0VC?o03?o000T<ol000<0003ooooo
ool0Foooo`00ROooo`030000oooooooo00?oool00`0003?o03?o0009<ol000?o09Tco`0co`008c?o
00030000oooooooo05coool008Woool00`000?ooooooo`03oooo0`0000Tco`000ol0VC?o03?o000R
<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o0009<ol000?o
09Tco`0co`008S?o00030000oooooooo05goool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol0024co`000`000?ooooooo`1Noooo0028oooo0P0000Goool00`0003?o
03?o0009<ol000?o09Tco`0co`0083?o00030000oooooooo05ooool008ooool00`0003?o03?o0009
<ol000?o09Tco`0co`007c?o00030000oooooooo063oool008ooool00`0003?o03?o0009<ol000?o
09Tco`0co`007c?o00030000oooooooo063oool008ooool200002S?o0003o`2I<ol0<ol001hco`00
0`000?ooooooo`1Qoooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol001dco`000`000?oo
ooooo`1Roooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol001dco`000`000?ooooooo`1R
oooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol001`co`000`000?ooooooo`1Soooo002?
oooo00<0000co`0co`002C?o0003o`2I<ol0<ol001/co`000`000?ooooooo`1Toooo002?oooo00<0
000co`0co`002C?o0003o`2I<ol0<ol001Xco`000`000?ooooooo`1Uoooo002?oooo0P0000Xco`00
0ol0VC?o03?o000J<ol000<0003oooooool0IOooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o
03?o000I<ol000<0003oooooool0I_ooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o000H
<ol000<0003oooooool0Ioooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o000H<ol000<0
003oooooool0Ioooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o000G<ol000<0003ooooo
ool0J?ooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o000G<ol000<0003oooooool0J?oo
o`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o000F<ol000<0003oooooool0JOooo`00Sooo
o`80000:<ol000?o09Tco`0co`005S?o00030000oooooooo06Woool008ooool00`0003?o03?o0009
<ol000?o09Tco`0co`005C?o00030000oooooooo06[oool008ooool00`0003?o03?o0009<ol000?o
09Tco`0co`005C?o00030000oooooooo06[oool008ooool00`0003?o03?o0009<ol000?o09Tco`0c
o`0053?o00030000oooooooo06_oool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`0053?o
00030000oooooooo06_oool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`0053?o00030000
oooooooo06_oool008ooool200002S?o0003o`2I<ol0<ol001<co`000`000?ooooooo`1/oooo002?
oooo00<0000co`0co`002C?o0003o`2I<ol0<ol001<co`000`000?ooooooo`1/oooo002?oooo00<0
000co`0co`002C?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1]oooo002?oooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1]oooo0027oooo100000Coool00`0003?o
03?o0009<ol000?o09Tco`0co`004S?o00030000oooooooo06goool008Ooool00`000?ooooooo`05
oooo00<0000co`0co`002C?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1^oooo0028oooo00<0
003oooooool01?ooo`<00009<ol000?o09Tco`0co`004C?o00030000oooooooo06koool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`002C?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1^
oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`002C?o0003o`2I<ol0<ol0010co`00
0`000?ooooooo`1_oooo0028oooo0P0000Goool00`0003?o03?o0009<ol000?o09Tco`0co`0043?o
00030000oooooooo06ooool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`003c?o00030000
oooooooo073oool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`003c?o00030000oooooooo
073oool008ooool200002S?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1`oooo002?oooo00<0
000co`0co`002C?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`002C?o
0003o`2I<ol0<ol000hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`002C?o0003o`2I
<ol0<ol000hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol0
00dco`000`000?ooooooo`1boooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000dco`00
0`000?ooooooo`1boooo002?oooo0P0000Xco`000ol0VC?o03?o000=<ol000<0003oooooool0L_oo
o`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o000<<ol000<0003oooooool0Loooo`00Sooo
o`030000<ol0<ol000Tco`000ol0VC?o03?o000<<ol000<0003oooooool0Loooo`00Soooo`030000
<ol0<ol000Tco`000ol0VC?o03?o000<<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0
00Tco`000ol0VC?o03?o000;<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol000Tco`00
0ol0VC?o03?o000;<ol000<0003oooooool0M?ooo`00Soooo`80000:<ol000?o09Tco`0co`002c?o
00030000oooooooo07Coool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`002c?o00030000
oooooooo07Coool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`002S?o00030000oooooooo
07Goool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`002S?o00030000oooooooo07Goool0
08ooool00`0003?o03?o0009<ol000?o09Tco`0co`002S?o00030000oooooooo07Goool008ooool0
0`0003?o03?o0009<ol000?o09Tco`0co`002C?o00030000oooooooo07Koool008ooool200002S?o
0003o`2I<ol0<ol000Tco`000`000?ooooooo`1foooo002?oooo00<0000co`0co`002C?o0003o`2I
<ol0<ol000Tco`000`000?ooooooo`1foooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol0
00Tco`000`000?ooooooo`1foooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000Pco`00
0`000?ooooooo`1goooo0028oooo0P0000Goool00`0003?o03?o0009<ol000?o09Tco`0co`0023?o
00030000oooooooo07Ooool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0009<ol000?o
09Tco`0co`0023?o00030000oooooooo07Ooool008Woool00`000?ooooooo`03oooo0`0000Tco`00
0ol0VC?o03?o0007<ol000<0003oooooool0N?ooo`00R_ooo`030000oooooooo00;oool00`0003?o
03?o0009<ol000?o09Tco`0co`001c?o00030000oooooooo07Soool008Ooool010000?ooooooo`00
00Coool00`0003?o03?o0009<ol000?o09Tco`0co`001c?o00030000oooooooo07Soool008Soool2
00001Oooo`030000<ol0<ol000Tco`000ol0VC?o03?o0006<ol000<0003oooooool0NOooo`00Sooo
o`030000<ol0<ol000Tco`000ol0VC?o03?o0006<ol000<0003oooooool0NOooo`00Soooo`030000
<ol0<ol000Tco`000ol0VC?o03?o0006<ol000<0003oooooool0NOooo`00Soooo`030000<ol0<ol0
00Tco`000ol0VC?o03?o0006<ol000<0003oooooool0NOooo`00Soooo`80000:<ol000?o09Tco`0c
o`001C?o00030000oooooooo07[oool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`001C?o
00030000oooooooo07[oool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`001C?o00030000
oooooooo07[oool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`001C?o00030000oooooooo
07[oool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`0013?o00030000oooooooo07_oool0
08ooool00`0003?o03?o0009<ol000?o09Tco`0co`0013?o00030000oooooooo07_oool008ooool2
00002S?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1koooo002?oooo00<0000co`0co`002C?o
0003o`2I<ol0<ol000@co`000`000?ooooooo`1koooo002?oooo00<0000co`0co`002C?o0003o`2I
<ol0<ol000<co`000`000?ooooooo`1loooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol0
00<co`000`000?ooooooo`1loooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000<co`00
0`000?ooooooo`1loooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000<co`000`000?oo
ooooo`1loooo002?oooo0P0000Xco`000ol0VC?o03?o0003<ol000<0003oooooool0O?ooo`00Sooo
o`030000<ol0<ol000Tco`000ol0VC?o03?o0002<ol000<0003oooooool0OOooo`00Soooo`030000
<ol0<ol000Tco`000ol0VC?o03?o0002<ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol0
00Tco`000ol0VC?o03?o0002<ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol000Tco`00
0ol0VC?o03?o0002<ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o
03?o0002<ol000<0003oooooool0OOooo`00Soooo`80000:<ol000Go09Tco`0co`0co`000000P?oo
o`00Soooo`030000<ol0<ol000Tco`001Ol0VC?o03?o03?o00000020oooo002?oooo00<0000co`0c
o`002C?o0005o`2I<ol0<ol0<ol00000083oool008ooool00`0003?o03?o0009<ol000Go09Tco`0c
o`0co`000000P?ooo`00Soooo`030000<ol0<ol000Tco`001?l0VC?o03?o0000087oool008Woool3
00000oooo`030000<ol0<ol000Tco`001?l0VC?o03?o0000087oool008[oool00`000?ooooooo`02
oooo00<0000co`0co`002C?o0004o`2I<ol0<ol00000POooo`00Qoooo`D00003oooo0`0000Tco`00
1?l0VC?o03?o0000087oool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000
oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Sooo
o`lco`22oooo001loooo00<0003oooooool04?ooo`hco`04oooo00<0003oooooool0O?ooo`00Nooo
o`030000oooooooo00Soool00`000?ooooooo`06oooo3S?o00Goool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`03<ol00000000000@co`02
00000c?o00D00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000<ol0<ol000002S?o00030000oooooooo
00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool0
100003?o03?o000000Xco`000`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000
oooooooo00D0000<oooo00@0000co`0co`00000:<ol000<0003oooooool00_ooo`030000oooooooo
07_oool007_oool01@000?ooooooooooo`00000?oooo00@0000co`0co`000009<ol000?oool0003o
ool00oooo`030000oooooooo07_oool007coool00`000?ooooooo`0@oooo00<co`00000000002S?o
00800003oooo00<0003oooooool0O?ooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54444 .12361 L
.54934 .12361 L
.5508 .12361 L
.55151 .12361 L
.55216 .12361 L
s
.55216 .12361 m
.55266 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44268 .12361 L
.44498 .12361 L
.44625 .12361 L
.44744 .12361 L
.44811 .12335 L
.44885 .12297 L
.45013 .12232 L
.45262 .12105 L
.46172 .11661 L
.50272 .09954 L
.52314 .09245 L
.53311 .08921 L
.54221 .08637 L
.54671 .085 L
.54909 .08429 L
.5504 .08391 L
.55162 .08355 L
.55268 .12361 L
.55382 .12361 L
.55625 .12361 L
.56053 .12361 L
.58018 .12361 L
.62132 .12361 L
.66094 .12361 L
.69905 .12361 L
.73961 .12361 L
.77866 .12361 L
.82016 .12361 L
.86014 .12361 L
.8986 .12361 L
.93952 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo00Woool206Ko9_ooo`040000oooooooo00002?ooo`040000oooooooo0000=Ooo
o`030000oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0
003oooooool0;oooo`030000oooooooo00Ooool406Ko9_ooo`040000oooooooo00002oooo`030000
oooooooo03?oool00`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0/oooo1000
00;oool010000?ooooooo`0000Woool20000<_ooo`030000oooooooo00Goool206Ko0oooo`0306Ko
oooooooo02Coool010000?ooooooo`0000Woool20000=_ooo`030000oooooooo01Goool001Woool0
0`000?ooooooo`0boooo00@0003oooooool00009oooo00<0003oooooool0<Oooo`040000oooooooo
oooo101Vo`Goool00`1Vooooooooo`0Toooo00@0003oooooool00009oooo00<0003oooooool0=Ooo
o`030000oooooooo01Goool001Soool20000=Oooo`80000:oooo0`00037oool200000P1Vo`Woool0
0`1Vooooooooo`0Uoooo0P0000[oool30000=?ooo`80000Goooo002=oooo0P1Vo`030000oooooooo
00[oool00`1Vooooooooo`21oooo002;oooo0P1Vo`;oool00`000?ooooooo`0:oooo00<0I_oooooo
ool0POooo`00ROooo`80I_l4oooo00<0003oooooool02_ooo`0306Kooooooooo087oool008Ooool2
06Ko1_ooo`030000oooooooo00[oool00`1Vooooooooo`21oooo0025oooo0P1Vo`Soool00`000?oo
ooooo`0:oooo00<0I_ooooooool0POooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`000?l0VC?o0009<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool0
0`0003?o03?o000:<ol000?o09Tco`0co`00;3?o00030000<ol0<ol003Hco`0500005oooo`00Sooo
o`030000<ol0<ol000Xco`000ol0VC?o03?o001M<ol0200001coool008ooool00`0003?o03?o000:
<ol000?o09Tco`0co`00Ec?o00H0000Toooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol0
058co`050000:_ooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o001=<ol01@0002ooool0
08ooool200002c?o0003o`2I<ol0<ol004Pco`050000=?ooo`00Soooo`030000<ol0<ol000Xco`00
0ol0VC?o03?o0014<ol0100003Woool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`00@S?o
0080000moooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol003lco`030000?oooo`00Sooo
o`030000<ol0<ol000Xco`000ol0VC?o03?o000m<ol00P0004;oool008ooool00`0003?o03?o000:
<ol000?o09Tco`0co`00>c?o00800014oooo002?oooo0P0000/co`000ol0VC?o03?o000i<ol00P00
04Koool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`00=c?o00800018oooo002?oooo00<0
000co`0co`002S?o0003o`2I<ol0<ol003Hco`000`000?ooooooo`18oooo002?oooo00<0000co`0c
o`002S?o0003o`2I<ol0<ol003@co`020000Boooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o
03?o000b<ol00P0004goool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`00<C?o00030000
oooooooo04goool008ooool200002c?o0003o`2I<ol0<ol002lco`020000D?ooo`00Soooo`030000
<ol0<ol000Xco`000ol0VC?o03?o000]<ol00P0005;oool008ooool00`0003?o03?o000:<ol000?o
09Tco`0co`00;3?o00030000oooooooo05;oool008ooool00`0003?o03?o000:<ol000?o09Tco`0c
o`00:c?o00030000oooooooo05?oool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`00:C?o
0080001Foooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol002Pco`000`000?ooooooo`1F
oooo002?oooo0P0000/co`000ol0VC?o03?o000W<ol000<0003oooooool0Eoooo`00Soooo`030000
<ol0<ol000Xco`000ol0VC?o03?o000V<ol000<0003oooooool0F?ooo`00Soooo`030000<ol0<ol0
00Xco`000ol0VC?o03?o000U<ol000<0003oooooool0FOooo`00Soooo`030000<ol0<ol000Xco`00
0ol0VC?o03?o000T<ol000<0003oooooool0F_ooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o
03?o000T<ol000<0003oooooool0F_ooo`00Qoooo`D00003oooo00<0000co`0co`002S?o0003o`2I
<ol0<ol002<co`000`000?ooooooo`1Koooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00Xco`000ol0VC?o03?o000R<ol000<0003oooooool0G?ooo`00ROooo`030000oooooooo00?oool3
00002S?o0003o`2I<ol0<ol0024co`000`000?ooooooo`1Moooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol000Xco`000ol0VC?o03?o000Q<ol000<0003oooooool0GOooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000:<ol000?o09Tco`0co`0083?o00030000oooooooo05koool0
08Soool200001Oooo`030000<ol0<ol000Xco`000ol0VC?o03?o000O<ol000<0003oooooool0Gooo
o`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o000N<ol000<0003oooooool0H?ooo`00Sooo
o`030000<ol0<ol000Xco`000ol0VC?o03?o000N<ol000<0003oooooool0H?ooo`00Soooo`80000;
<ol000?o09Tco`0co`007C?o00030000oooooooo067oool008ooool00`0003?o03?o000:<ol000?o
09Tco`0co`0073?o00030000oooooooo06;oool008ooool00`0003?o03?o000:<ol000?o09Tco`0c
o`0073?o00030000oooooooo06;oool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`006c?o
00030000oooooooo06?oool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`006S?o00030000
oooooooo06Coool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`006C?o00030000oooooooo
06Goool008ooool200002c?o0003o`2I<ol0<ol001Tco`000`000?ooooooo`1Uoooo002?oooo00<0
000co`0co`002S?o0003o`2I<ol0<ol001Pco`000`000?ooooooo`1Voooo002?oooo00<0000co`0c
o`002S?o0003o`2I<ol0<ol001Lco`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`002S?o
0003o`2I<ol0<ol001Lco`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`002S?o0003o`2I
<ol0<ol001Hco`000`000?ooooooo`1Xoooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol0
01Hco`000`000?ooooooo`1Xoooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol001Dco`00
0`000?ooooooo`1Yoooo002?oooo0P0000/co`000ol0VC?o03?o000E<ol000<0003oooooool0JOoo
o`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o000D<ol000<0003oooooool0J_ooo`00Sooo
o`030000<ol0<ol000Xco`000ol0VC?o03?o000D<ol000<0003oooooool0J_ooo`00Soooo`030000
<ol0<ol000Xco`000ol0VC?o03?o000C<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol0
00Xco`000ol0VC?o03?o000C<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol000Xco`00
0ol0VC?o03?o000C<ol000<0003oooooool0Joooo`00Soooo`80000;<ol000?o09Tco`0co`004S?o
00030000oooooooo06coool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`004S?o00030000
oooooooo06coool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`004C?o00030000oooooooo
06goool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`004C?o00030000oooooooo06goool0
08Ooool400001?ooo`030000<ol0<ol000Xco`000ol0VC?o03?o000A<ol000<0003oooooool0KOoo
o`00Qoooo`030000oooooooo00Goool00`0003?o03?o000:<ol000?o09Tco`0co`0043?o00030000
oooooooo06koool008Soool00`000?ooooooo`04oooo0`0000Xco`000ol0VC?o03?o000@<ol000<0
003oooooool0K_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000:<ol000?o09Tco`0c
o`0043?o00030000oooooooo06koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000:
<ol000?o09Tco`0co`003c?o00030000oooooooo06ooool008Soool200001Oooo`030000<ol0<ol0
00Xco`000ol0VC?o03?o000?<ol000<0003oooooool0Koooo`00Soooo`030000<ol0<ol000Xco`00
0ol0VC?o03?o000><ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o
03?o000><ol000<0003oooooool0L?ooo`00Soooo`80000;<ol000?o09Tco`0co`003S?o00030000
oooooooo073oool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`003C?o00030000oooooooo
077oool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`003C?o00030000oooooooo077oool0
08ooool00`0003?o03?o000:<ol000?o09Tco`0co`003C?o00030000oooooooo077oool008ooool0
0`0003?o03?o000:<ol000?o09Tco`0co`003C?o00030000oooooooo077oool008ooool00`0003?o
03?o000:<ol000?o09Tco`0co`0033?o00030000oooooooo07;oool008ooool00`0003?o03?o000:
<ol000?o09Tco`0co`0033?o00030000oooooooo07;oool008ooool200002c?o0003o`2I<ol0<ol0
00`co`000`000?ooooooo`1boooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol000/co`00
0`000?ooooooo`1coooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol000/co`000`000?oo
ooooo`1coooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1c
oooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1doooo002?
oooo00<0000co`0co`002S?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1doooo002?oooo0P00
00/co`000ol0VC?o03?o000:<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol000Xco`00
0ol0VC?o03?o000:<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o
03?o0009<ol000<0003oooooool0MOooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o0009
<ol000<0003oooooool0MOooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o0009<ol000<0
003oooooool0MOooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o0008<ol000<0003ooooo
ool0M_ooo`00Soooo`80000;<ol000?o09Tco`0co`0023?o00030000oooooooo07Koool008ooool0
0`0003?o03?o000:<ol000?o09Tco`0co`0023?o00030000oooooooo07Koool008ooool00`0003?o
03?o000:<ol000?o09Tco`0co`0023?o00030000oooooooo07Koool008ooool00`0003?o03?o000:
<ol000?o09Tco`0co`001c?o00030000oooooooo07Ooool008Soool200001Oooo`030000<ol0<ol0
00Xco`000ol0VC?o03?o0007<ol000<0003oooooool0Moooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000Xco`000ol0VC?o03?o0007<ol000<0003oooooool0Moooo`00ROooo`030000
oooooooo00?oool300002S?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1hoooo002:oooo00<0
003oooooool00_ooo`030000<ol0<ol000Xco`000ol0VC?o03?o0006<ol000<0003oooooool0N?oo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Xco`000ol0VC?o03?o0006<ol000<0
003oooooool0N?ooo`00R?ooo`800005oooo00<0000co`0co`002S?o0003o`2I<ol0<ol000Dco`00
0`000?ooooooo`1ioooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol000Dco`000`000?oo
ooooo`1ioooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1i
oooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1ioooo002?
oooo0P0000/co`000ol0VC?o03?o0004<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol0
00Xco`000ol0VC?o03?o0004<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol000Xco`00
0ol0VC?o03?o0004<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o
03?o0004<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o0003
<ol000<0003oooooool0Noooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o0003<ol000<0
003oooooool0Noooo`00Soooo`80000;<ol000?o09Tco`0co`000c?o00030000oooooooo07_oool0
08ooool00`0003?o03?o000:<ol000?o09Tco`0co`000c?o00030000oooooooo07_oool008ooool0
0`0003?o03?o000:<ol000?o09Tco`0co`000S?o00030000oooooooo07coool008ooool00`0003?o
03?o000:<ol000?o09Tco`0co`000S?o00030000oooooooo07coool008ooool00`0003?o03?o000:
<ol000?o09Tco`0co`000S?o00030000oooooooo07coool008ooool00`0003?o03?o000:<ol000?o
09Tco`0co`000S?o00030000oooooooo07coool008ooool200002c?o0003o`2I<ol0<ol0008co`00
0`000?ooooooo`1loooo002?oooo00<0000co`0co`002S?o0005o`2I<ol0<ol0<ol0000007ooool0
08ooool00`0003?o03?o000:<ol000Go09Tco`0co`0co`000000Ooooo`00Soooo`030000<ol0<ol0
00Xco`001Ol0VC?o03?o03?o0000001ooooo002?oooo00<0000co`0co`002S?o0005o`2I<ol0<ol0
<ol0000007ooool008ooool00`0003?o03?o000:<ol000Go09Tco`0co`0co`000000Ooooo`00Sooo
o`80000;<ol000Co09Tco`0co`000020oooo002?oooo00<0000co`0co`002S?o0004o`2I<ol0<ol0
0000P?ooo`00Soooo`030000<ol0<ol000Xco`001?l0VC?o03?o0000083oool008ooool00`0003?o
03?o000:<ol000Co09Tco`0co`000020oooo002?oooo00<0000co`0co`002S?o0003o`2I<ol00000
087oool008Woool300000oooo`030000<ol0<ol000Xco`000ol0VC?o00000021oooo002:oooo00<0
003oooooool00_ooo`030000<ol0<ol000Xco`000ol0VC?o00000021oooo0027oooo1@0000?oool3
00002S?o0003o`2I<ol00000087oool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?oo
o`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_oo
o`00Soooo`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07oooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o00Soool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004<ol00P00
00<co`05000000?oool0000000000`0000;oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000:
<ol000<0000co`0co`000oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0
003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Xco`000`0003?o03?o0003
oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?oo
o`040000oooooooo00002S?o00030000<ol0<ol000?oool00`000?ooooooo`02oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Xco`000`0003?o
0?ooo`03oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Woool00`000?ooooooo`0A
oooo0P0000Xco`02000000@co`3oooooooooool200000oooo`030000oooooooo07Woool008ooool=
<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55195 .12361 L
.55338 .12361 L
.55472 .12361 L
.55598 .12361 L
.55669 .12361 L
s
.55669 .12361 m
.55695 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44021 .12361 L
.44151 .12361 L
.44268 .12361 L
.44387 .12308 L
.44498 .12251 L
.44744 .12126 L
.45262 .11869 L
.46172 .11438 L
.50027 .09872 L
.51981 .09205 L
.53017 .08873 L
.54127 .08533 L
.54676 .08371 L
.55195 .0822 L
.55421 .08156 L
.55545 .08121 L
.55662 .08088 L
.55787 .12361 L
.55854 .12361 L
.55925 .12361 L
.56169 .12361 L
.58076 .12361 L
.6219 .12361 L
.66152 .12361 L
.69963 .12361 L
.74019 .12361 L
.77924 .12361 L
.82073 .12361 L
.86072 .12361 L
.89918 .12361 L
.9401 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool0<_ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Ooo
o`030000oooooooo00Woool306Ko9Oooo`040000oooooooo00002?ooo`040000oooooooo0000=Ooo
o`030000oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0
003oooooool0;oooo`030000oooooooo00Ooool206Ko0_ooo`0306Kooooooooo02?oool010000?oo
ooooo`0000_oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0
003oooooool0;?ooo`@00002oooo00@0003oooooool00009oooo0P0003;oool010000?oooooooooo
o`H0I_l4oooo00<0I_ooooooool08oooo`040000oooooooo00002Oooo`80000foooo00<0003ooooo
ool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?ooooooo`0a
oooo00@0003oool0I_l0I_l:oooo00<0I_ooooooool08oooo`040000oooooooo00002Oooo`030000
oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000`oooo00<0
I_l0000000003?ooo`0306Kooooooooo02Coool200002_ooo`<0000doooo0P0001Ooool008coool2
06Ko00?oool0003oool03?ooo`0306Kooooooooo083oool008Woool306Ko0oooo`030000oooooooo
00coool00`1Vooooooooo`1ooooo0027oooo0P1Vo`Koool00`000?ooooooo`0<oooo00<0I_oooooo
ool0Ooooo`00QOooo`80I_l8oooo00<0003oooooool03?ooo`0306Kooooooooo07ooool008?oool2
06Ko2_ooo`030000oooooooo00coool00`1Vooooooooo`1ooooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000
<ol0o`2I00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Xco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0
003oooooool0>Oooo`030000<ol0<ol000/co`000ol0VC?o03?o000[<ol000<0000co`0co`00=S?o
00D0000Goooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol005`co`0800007?ooo`00Sooo
o`030000<ol0<ol000/co`000ol0VC?o03?o001F<ol01P0002Coool008ooool00`0003?o03?o000;
<ol000?o09Tco`0co`00DC?o00D0000Zoooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0
04`co`050000;oooo`00Soooo`80000<<ol000?o09Tco`0co`00Ac?o00D0000doooo002?oooo00<0
000co`0co`002c?o0003o`2I<ol0<ol004<co`040000>Oooo`00Soooo`030000<ol0<ol000/co`00
0ol0VC?o03?o0011<ol00P0003goool008ooool00`0003?o03?o000;<ol000?o09Tco`0co`00?S?o
00<0000ooooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol003`co`020000@_ooo`00Sooo
o`030000<ol0<ol000/co`000ol0VC?o03?o000j<ol00P0004Coool008ooool2000033?o0003o`2I
<ol0<ol003Pco`020000A_ooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000f<ol00P00
04Soool008ooool00`0003?o03?o000;<ol000?o09Tco`0co`00=C?o00030000oooooooo04Soool0
08ooool00`0003?o03?o000;<ol000?o09Tco`0co`00<c?o0080001;oooo002?oooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol0034co`020000COooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o
03?o000`<ol000<0003oooooool0COooo`00Soooo`80000<<ol000?o09Tco`0co`00;S?o0080001@
oooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol002`co`020000D_ooo`00Soooo`030000
<ol0<ol000/co`000ol0VC?o03?o000[<ol000<0003oooooool0D_ooo`00Soooo`030000<ol0<ol0
00/co`000ol0VC?o03?o000Z<ol000<0003oooooool0Doooo`00Soooo`030000<ol0<ol000/co`00
0ol0VC?o03?o000X<ol00P0005Koool008ooool00`0003?o03?o000;<ol000?o09Tco`0co`009c?o
00030000oooooooo05Koool008ooool2000033?o0003o`2I<ol0<ol002Hco`000`000?ooooooo`1G
oooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol002Dco`000`000?ooooooo`1Hoooo002?
oooo00<0000co`0co`002c?o0003o`2I<ol0<ol002@co`000`000?ooooooo`1Ioooo002?oooo00<0
000co`0co`002c?o0003o`2I<ol0<ol002<co`000`000?ooooooo`1Joooo002?oooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol002<co`000`000?ooooooo`1Joooo0027oooo1@0000?oool00`0003?o
03?o000;<ol000?o09Tco`0co`008S?o00030000oooooooo05_oool008Woool00`000?ooooooo`03
oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0024co`000`000?ooooooo`1Loooo0029oooo00<0
003oooooool00oooo`<0000;<ol000?o09Tco`0co`0083?o00030000oooooooo05goool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0020co`000`000?ooooooo`1M
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000/co`000ol0VC?o03?o000O<ol000<0
003oooooool0G_ooo`00R?ooo`800005oooo00<0000co`0co`002c?o0003o`2I<ol0<ol001hco`00
0`000?ooooooo`1Ooooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol001dco`000`000?oo
ooooo`1Poooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol001dco`000`000?ooooooo`1P
oooo002?oooo0P0000`co`000ol0VC?o03?o000L<ol000<0003oooooool0HOooo`00Soooo`030000
<ol0<ol000/co`000ol0VC?o03?o000K<ol000<0003oooooool0H_ooo`00Soooo`030000<ol0<ol0
00/co`000ol0VC?o03?o000K<ol000<0003oooooool0H_ooo`00Soooo`030000<ol0<ol000/co`00
0ol0VC?o03?o000J<ol000<0003oooooool0Hoooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o
03?o000I<ol000<0003oooooool0I?ooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000H
<ol000<0003oooooool0IOooo`00Soooo`80000<<ol000?o09Tco`0co`0063?o00030000oooooooo
06Goool008ooool00`0003?o03?o000;<ol000?o09Tco`0co`005c?o00030000oooooooo06Koool0
08ooool00`0003?o03?o000;<ol000?o09Tco`0co`005S?o00030000oooooooo06Ooool008ooool0
0`0003?o03?o000;<ol000?o09Tco`0co`005S?o00030000oooooooo06Ooool008ooool00`0003?o
03?o000;<ol000?o09Tco`0co`005C?o00030000oooooooo06Soool008ooool00`0003?o03?o000;
<ol000?o09Tco`0co`005C?o00030000oooooooo06Soool008ooool00`0003?o03?o000;<ol000?o
09Tco`0co`0053?o00030000oooooooo06Woool008ooool2000033?o0003o`2I<ol0<ol001@co`00
0`000?ooooooo`1Yoooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol001<co`000`000?oo
ooooo`1Zoooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol001<co`000`000?ooooooo`1Z
oooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1[oooo002?
oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1[oooo002?oooo00<0
000co`0co`002c?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1[oooo002?oooo0P0000`co`00
0ol0VC?o03?o000A<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o
03?o000A<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000@
<ol000<0003oooooool0KOooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000@<ol000<0
003oooooool0KOooo`00Qoooo`@00004oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0010co`00
0`000?ooooooo`1]oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000/co`000ol0VC?o
03?o000?<ol000<0003oooooool0K_ooo`00R?ooo`030000oooooooo00Coool300002c?o0003o`2I
<ol0<ol000lco`000`000?ooooooo`1^oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00/co`000ol0VC?o03?o000?<ol000<0003oooooool0K_ooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000/co`000ol0VC?o03?o000><ol000<0003oooooool0Koooo`00R?ooo`800005
oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1_oooo002?oooo00<0
000co`0co`002c?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1`oooo002?oooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1`oooo002?oooo0P0000`co`000ol0VC?o
03?o000=<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000<
<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000<<ol000<0
003oooooool0LOooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000<<ol000<0003ooooo
ool0LOooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000<<ol000<0003oooooool0LOoo
o`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000;<ol000<0003oooooool0L_ooo`00Sooo
o`030000<ol0<ol000/co`000ol0VC?o03?o000;<ol000<0003oooooool0L_ooo`00Soooo`80000<
<ol000?o09Tco`0co`002c?o00030000oooooooo07;oool008ooool00`0003?o03?o000;<ol000?o
09Tco`0co`002S?o00030000oooooooo07?oool008ooool00`0003?o03?o000;<ol000?o09Tco`0c
o`002S?o00030000oooooooo07?oool008ooool00`0003?o03?o000;<ol000?o09Tco`0co`002S?o
00030000oooooooo07?oool008ooool00`0003?o03?o000;<ol000?o09Tco`0co`002C?o00030000
oooooooo07Coool008ooool00`0003?o03?o000;<ol000?o09Tco`0co`002C?o00030000oooooooo
07Coool008ooool2000033?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1doooo002?oooo00<0
000co`0co`002c?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1doooo002?oooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`002c?o
0003o`2I<ol0<ol000Pco`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`002c?o0003o`2I
<ol0<ol000Pco`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0
00Lco`000`000?ooooooo`1foooo002?oooo0P0000`co`000ol0VC?o03?o0007<ol000<0003ooooo
ool0M_ooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o0007<ol000<0003oooooool0M_oo
o`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o0007<ol000<0003oooooool0M_ooo`00Sooo
o`030000<ol0<ol000/co`000ol0VC?o03?o0006<ol000<0003oooooool0Moooo`00R?ooo`800005
oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1goooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1g
oooo0029oooo00<0003oooooool00oooo`<0000;<ol000?o09Tco`0co`001C?o00030000oooooooo
07Soool008[oool00`000?ooooooo`02oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000Dco`00
0`000?ooooooo`1hoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`002c?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`1hoooo0028oooo0P0000Goool00`0003?o03?o000;<ol000?o
09Tco`0co`0013?o00030000oooooooo07Woool008ooool00`0003?o03?o000;<ol000?o09Tco`0c
o`0013?o00030000oooooooo07Woool008ooool00`0003?o03?o000;<ol000?o09Tco`0co`0013?o
00030000oooooooo07Woool008ooool00`0003?o03?o000;<ol000?o09Tco`0co`0013?o00030000
oooooooo07Woool008ooool2000033?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1joooo002?
oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1joooo002?oooo00<0
000co`0co`002c?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1joooo002?oooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1joooo002?oooo00<0000co`0co`002c?o
0003o`2I<ol0<ol0008co`000`000?ooooooo`1koooo002?oooo00<0000co`0co`002c?o0003o`2I
<ol0<ol0008co`000`000?ooooooo`1koooo002?oooo0P0000`co`000ol0VC?o03?o0002<ol000<0
003oooooool0Noooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o0002<ol000<0003ooooo
ool0Noooo`00Soooo`030000<ol0<ol000/co`001Ol0VC?o03?o03?o0000001noooo002?oooo00<0
000co`0co`002c?o0005o`2I<ol0<ol0<ol0000007koool008ooool00`0003?o03?o000;<ol000Go
09Tco`0co`0co`000000O_ooo`00Soooo`030000<ol0<ol000/co`001Ol0VC?o03?o03?o0000001n
oooo002?oooo0P0000`co`001Ol0VC?o03?o03?o0000001noooo002?oooo00<0000co`0co`002c?o
0004o`2I<ol0<ol00000Ooooo`00Soooo`030000<ol0<ol000/co`001?l0VC?o03?o000007ooool0
08ooool00`0003?o03?o000;<ol000Co09Tco`0co`00001ooooo002?oooo00<0000co`0co`002c?o
0004o`2I<ol0<ol00000Ooooo`00Soooo`030000<ol0<ol000/co`001?l0VC?o03?o000007ooool0
08ooool2000033?o0003o`2I<ol00000083oool008ooool00`0003?o03?o000;<ol000?o09Tco`00
0000P?ooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o00000020oooo002?oooo00<0000co`0c
o`002c?o0003o`2I<ol00000083oool008ooool00`0003?o03?o000;<ol000?o09T0003oool0P?oo
o`00ROooo`<00003oooo00<0000co`0co`002c?o0003o`2I0000oooo083oool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`002c?o0003o`2I0000oooo083oool008Ooool500000oooo`<0000;
<ol000?o09T0003oool0P?ooo`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0
003oool000001?ooo`lco`22oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?
oooo3c?o08;oool007Woool00`000?ooooooo`0Coooo3S?o00Ooool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo00Woool><ol02?ooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000@co`0200000c?o
00D000000oooo`000000000200000oooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Xco`00
1@0003?o03?o0?ooo`000006oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0003oooooool0000:<ol000<0000co`0co`000_ooo`030000oooooooo
00Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`00
00Xco`000`0003?o03?o0003oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000?oooo00@0003oooooool0000:<ol000D0000co`3oooooool000000_oo
o`050000oooooooooooo000007[oool007Woool00`000?ooooooo`0Aoooo0P0000Xco`02000000@c
o`3oooooooooool200000oooo`030000oooooooo07Woool008ooool=<ol0Q?ooo`00Soooo`dco`24
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55436 .12361 L
.55712 .12361 L
.55847 .12361 L
.55972 .12361 L
.56092 .12361 L
s
.56092 .12361 m
.56142 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.42237 .12361 L
.42781 .12361 L
.43298 .12361 L
.43522 .12361 L
.43646 .12361 L
.43762 .12361 L
.43828 .12351 L
.43899 .12314 L
.44024 .1225 L
.44268 .12126 L
.46172 .11222 L
.50272 .09621 L
.52314 .08954 L
.54221 .08378 L
.55162 .0811 L
.55625 .07981 L
.55829 .07926 L
.56053 .07865 L
.56176 .07832 L
.56292 .12361 L
.56414 .12361 L
.56546 .12361 L
.57081 .12361 L
.58018 .12361 L
.62132 .12361 L
.66094 .12361 L
.69905 .12361 L
.73961 .12361 L
.77866 .12361 L
.82016 .12361 L
.86014 .12361 L
.8986 .12361 L
.93952 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`D0000coooo0P0000Coool2
00001?ooo`80000boooo00<0003oooooool02oooo`<0I_lToooo0P0000Coool200001?ooo`80000d
oooo1@0001Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00008oooo00@0003ooooo
ool0000aoooo00<0003oooooool01oooo`@0I_l2oooo00<0I_ooooooool08Oooo`040000oooooooo
00002?ooo`040000oooooooo0000=Oooo`030000oooooooo01Goool001Woool00`000?ooooooo`0b
oooo00@0003oooooool0000;oooo00<0003oooooool0;oooo`030000oooooooo00Goool206Ko1_oo
o`0306Kooooooooo027oool010000?ooooooo`0000_oool00`000?ooooooo`0coooo00<0003ooooo
ool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?ooo`@00002oooo00@0003oooooool00009
oooo0P0003;oool010000?ooooooooooo`@0I_l8oooo00<0I_ooooooool08Oooo`040000oooooooo
00002Oooo`80000foooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?oo
ooooo`0000Woool00`000?ooooooo`0aoooo00@00000I_l0I_l0I_l<oooo00<0I_ooooooool08Ooo
o`040000oooooooo00002Oooo`030000oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P00
03Goool200002_ooo`<0000_oooo0P1Vo`80000>oooo00<0I_ooooooool08_ooo`80000:oooo0`00
03Coool200005oooo`00Roooo`80I_l2oooo00<0003oooooool03Oooo`0306Kooooooooo07koool0
08Woool206Ko1?ooo`030000oooooooo00goool00`1Vooooooooo`1noooo0027oooo0P1Vo`Koool0
0`000?ooooooo`0=oooo00<0I_ooooooool0O_ooo`00Q?ooo`<0I_l8oooo00<0003oooooool03Ooo
o`0306Kooooooooo07koool008;oool206Ko2oooo`030000oooooooo00goool00`1Vooooooooo`1n
oooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0000co`0co`002C?o00040000<ol0<ol0o`2I23?o00030000<ol0<ol000Tco`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0
000co`0co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`0033?o0003o`2I
<ol0<ol002Xco`000`0003?o03?o000f<ol01@0001Ooool008ooool00`0003?o03?o000<<ol000?o
09Tco`0co`00Fc?o00P0000Loooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol005Dco`06
00009?ooo`00Soooo`030000<ol0<ol000`co`000ol0VC?o03?o001@<ol01@0002[oool008ooool0
0`0003?o03?o000<<ol000?o09Tco`0co`00Bc?o00D0000_oooo002?oooo0P0000dco`000ol0VC?o
03?o0016<ol01@0003Coool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`00@S?o00@0000i
oooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol0040co`020000?Oooo`00Soooo`030000
<ol0<ol000`co`000ol0VC?o03?o000m<ol00`0003ooool008ooool00`0003?o03?o000<<ol000?o
09Tco`0co`00>c?o00800012oooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol003Tco`02
0000A?ooo`00Soooo`80000=<ol000?o09Tco`0co`00=c?o00800016oooo002?oooo00<0000co`0c
o`0033?o0003o`2I<ol0<ol003Dco`020000B?ooo`00Soooo`030000<ol0<ol000`co`000ol0VC?o
03?o000d<ol000<0003oooooool0B?ooo`00Soooo`030000<ol0<ol000`co`000ol0VC?o03?o000b
<ol00P0004_oool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`00<3?o0080001=oooo002?
oooo00<0000co`0co`0033?o0003o`2I<ol0<ol002lco`000`000?ooooooo`1=oooo002?oooo0P00
00dco`000ol0VC?o03?o000]<ol00P00053oool008ooool00`0003?o03?o000<<ol000?o09Tco`0c
o`00:c?o0080001Boooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol002Xco`000`000?oo
ooooo`1Boooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol002Tco`000`000?ooooooo`1C
oooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol002Lco`020000E_ooo`00Soooo`030000
<ol0<ol000`co`000ol0VC?o03?o000V<ol000<0003oooooool0E_ooo`00Soooo`80000=<ol000?o
09Tco`0co`009C?o00030000oooooooo05Ooool008ooool00`0003?o03?o000<<ol000?o09Tco`0c
o`0093?o00030000oooooooo05Soool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`008c?o
00030000oooooooo05Woool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`008S?o00030000
oooooooo05[oool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`008S?o00030000oooooooo
05[oool008Ooool500000oooo`030000<ol0<ol000`co`000ol0VC?o03?o000Q<ol000<0003ooooo
ool0Foooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000<<ol000?o09Tco`0co`0083?o
00030000oooooooo05coool008Woool00`000?ooooooo`03oooo0`0000`co`000ol0VC?o03?o000O
<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000<<ol000?o
09Tco`0co`007c?o00030000oooooooo05goool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`0033?o0003o`2I<ol0<ol001hco`000`000?ooooooo`1Noooo0028oooo0P0000Goool00`0003?o
03?o000<<ol000?o09Tco`0co`007C?o00030000oooooooo05ooool008ooool00`0003?o03?o000<
<ol000?o09Tco`0co`0073?o00030000oooooooo063oool008ooool00`0003?o03?o000<<ol000?o
09Tco`0co`0073?o00030000oooooooo063oool008ooool200003C?o0003o`2I<ol0<ol001/co`00
0`000?ooooooo`1Qoooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol001Xco`000`000?oo
ooooo`1Roooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol001Xco`000`000?ooooooo`1R
oooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol001Tco`000`000?ooooooo`1Soooo002?
oooo00<0000co`0co`0033?o0003o`2I<ol0<ol001Pco`000`000?ooooooo`1Toooo002?oooo00<0
000co`0co`0033?o0003o`2I<ol0<ol001Lco`000`000?ooooooo`1Uoooo002?oooo0P0000dco`00
0ol0VC?o03?o000G<ol000<0003oooooool0IOooo`00Soooo`030000<ol0<ol000`co`000ol0VC?o
03?o000F<ol000<0003oooooool0I_ooo`00Soooo`030000<ol0<ol000`co`000ol0VC?o03?o000E
<ol000<0003oooooool0Ioooo`00Soooo`030000<ol0<ol000`co`000ol0VC?o03?o000E<ol000<0
003oooooool0Ioooo`00Soooo`030000<ol0<ol000`co`000ol0VC?o03?o000D<ol000<0003ooooo
ool0J?ooo`00Soooo`030000<ol0<ol000`co`000ol0VC?o03?o000D<ol000<0003oooooool0J?oo
o`00Soooo`030000<ol0<ol000`co`000ol0VC?o03?o000C<ol000<0003oooooool0JOooo`00Sooo
o`80000=<ol000?o09Tco`0co`004c?o00030000oooooooo06Woool008ooool00`0003?o03?o000<
<ol000?o09Tco`0co`004S?o00030000oooooooo06[oool008ooool00`0003?o03?o000<<ol000?o
09Tco`0co`004S?o00030000oooooooo06[oool008ooool00`0003?o03?o000<<ol000?o09Tco`0c
o`004C?o00030000oooooooo06_oool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`004C?o
00030000oooooooo06_oool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`004C?o00030000
oooooooo06_oool008ooool200003C?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1/oooo002?
oooo00<0000co`0co`0033?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1/oooo002?oooo00<0
000co`0co`0033?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1]oooo002?oooo00<0000co`0c
o`0033?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1]oooo0027oooo100000Coool00`0003?o
03?o000<<ol000?o09Tco`0co`003c?o00030000oooooooo06goool008Ooool00`000?ooooooo`05
oooo00<0000co`0co`0033?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1^oooo0028oooo00<0
003oooooool01?ooo`<0000<<ol000?o09Tco`0co`003S?o00030000oooooooo06koool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`003C?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1^
oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`003C?o0003o`2I<ol0<ol000`co`00
0`000?ooooooo`1_oooo0028oooo0P0000Goool00`0003?o03?o000=<ol000?o09Tco`0co`0033?o
00030000oooooooo06ooool008ooool00`0003?o03?o000=<ol000?o09Tco`0co`002c?o00030000
oooooooo073oool008ooool00`0003?o03?o000=<ol000?o09Tco`0co`002c?o00030000oooooooo
073oool008ooool200003S?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1`oooo002?oooo00<0
000co`0co`003C?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1aoooo002?oooo00<0000co`0c
o`003C?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`003C?o
0003o`2I<ol0<ol000Xco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`003C?o0003o`2I
<ol0<ol000Xco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`003C?o0003o`2I<ol0<ol0
00Tco`000`000?ooooooo`1boooo002?oooo00<0000co`0co`003C?o0003o`2I<ol0<ol000Tco`00
0`000?ooooooo`1boooo002?oooo0P0000hco`000ol0VC?o03?o0009<ol000<0003oooooool0L_oo
o`00Soooo`030000<ol0<ol000dco`000ol0VC?o03?o0008<ol000<0003oooooool0Loooo`00Sooo
o`030000<ol0<ol000dco`000ol0VC?o03?o0008<ol000<0003oooooool0Loooo`00Soooo`030000
<ol0<ol000dco`000ol0VC?o03?o0008<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0
00dco`000ol0VC?o03?o0007<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol000dco`00
0ol0VC?o03?o0007<ol000<0003oooooool0M?ooo`00Soooo`80000><ol000?o09Tco`0co`001c?o
00030000oooooooo07Coool008ooool00`0003?o03?o000=<ol000?o09Tco`0co`001c?o00030000
oooooooo07Coool008ooool00`0003?o03?o000=<ol000?o09Tco`0co`001S?o00030000oooooooo
07Goool008ooool00`0003?o03?o000=<ol000?o09Tco`0co`001S?o00030000oooooooo07Goool0
08ooool00`0003?o03?o000=<ol000?o09Tco`0co`001S?o00030000oooooooo07Goool008ooool0
0`0003?o03?o000=<ol000?o09Tco`0co`001C?o00030000oooooooo07Koool008ooool200003S?o
0003o`2I<ol0<ol000Dco`000`000?ooooooo`1foooo002?oooo00<0000co`0co`003C?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`1foooo002?oooo00<0000co`0co`003C?o0003o`2I<ol0<ol0
00Dco`000`000?ooooooo`1foooo002?oooo00<0000co`0co`003C?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`1goooo0028oooo0P0000Goool00`0003?o03?o000=<ol000?o09Tco`0co`0013?o
00030000oooooooo07Ooool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000=<ol000?o
09Tco`0co`0013?o00030000oooooooo07Ooool008Woool00`000?ooooooo`03oooo0`0000dco`00
0ol0VC?o03?o0003<ol000<0003oooooool0N?ooo`00R_ooo`030000oooooooo00;oool00`0003?o
03?o000=<ol000?o09Tco`0co`000c?o00030000oooooooo07Soool008Ooool010000?ooooooo`00
00Coool00`0003?o03?o000=<ol000?o09Tco`0co`000c?o00030000oooooooo07Soool008Soool2
00001Oooo`030000<ol0<ol000dco`000ol0VC?o03?o0002<ol000<0003oooooool0NOooo`00Sooo
o`030000<ol0<ol000dco`000ol0VC?o03?o0002<ol000<0003oooooool0NOooo`00Soooo`030000
<ol0<ol000dco`000ol0VC?o03?o0002<ol000<0003oooooool0NOooo`00Soooo`030000<ol0<ol0
00dco`000ol0VC?o03?o0002<ol000<0003oooooool0NOooo`00Soooo`80000><ol000Go09Tco`0c
o`0co`000000O?ooo`00Soooo`030000<ol0<ol000dco`001Ol0VC?o03?o03?o0000001loooo002?
oooo00<0000co`0co`003C?o0005o`2I<ol0<ol0<ol0000007coool008ooool00`0003?o03?o000=
<ol000Go09Tco`0co`0co`000000O?ooo`00Soooo`030000<ol0<ol000dco`001?l0VC?o03?o0000
07goool008ooool00`0003?o03?o000=<ol000Co09Tco`0co`00001moooo002?oooo0P0000hco`00
1?l0VC?o03?o000007goool008ooool00`0003?o03?o000=<ol000Co09Tco`0co`00001moooo002?
oooo00<0000co`0co`003C?o0003o`2I<ol0000007koool008ooool00`0003?o03?o000=<ol000?o
09Tco`000000O_ooo`00Soooo`030000<ol0<ol000dco`000ol0VC?o0000001noooo002?oooo00<0
000co`0co`003C?o0003o`2I<ol0000007koool008ooool200003S?o0003o`2I<ol0000007koool0
08ooool00`0003?o03?o000=<ol000?o09T0003oool0O_ooo`00Soooo`030000<ol0<ol000dco`00
0ol0V@000?ooo`1noooo002?oooo00<0000co`0co`003C?o0003o`2I0000oooo07koool008ooool0
0`0003?o03?o000=<ol000?o09T0003oool0O_ooo`00Soooo`030000<ol0<ol000dco`000ol0V@00
0?ooo`1noooo002?oooo0P0000hco`000ol0VOooooooo`1noooo002?oooo00<0000co`0co`003C?o
0003o`2Ioooooooo07koool008ooool00`0003?o03?o000=<ol000?o09Woooooool0O_ooo`00Sooo
o`030000<ol0<ol000dco`000ol0VOooooooo`1noooo002?oooo00<0000co`0co`0033?o00030000
o`2Ioooo07ooool008Woool300000oooo`030000<ol0<ol000`co`000`000?l0VOooo`1ooooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000`co`000`000?l0VOooo`1ooooo0027oooo1@00
00?oool3000033?o00030000o`2Ioooo07ooool008Ooool010000?ooooooo`0000Coool?<ol0P_oo
o`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?
<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07oooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o00Soool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004
<ol00P0000<co`0500000_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002S?o
00050000<ol0<ol0oooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00goool010000?ooooooo`0000Xco`000`0003?o03?o0003oooo00<0
003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000
oooooooo00002S?o00030000<ol0<ol000Coool01@000?ooooooooooo`00001joooo001hoooo00D0
003oooooooooool000003oooo`040000oooooooo00002S?o00050000<ol0oooooooo000000;oool0
1@000?ooooooooooo`00001joooo001ioooo00<0003oooooool04Oooo`80000:<ol00P000004<ol0
oooooooooooo0P0000?oool00`000?ooooooo`1ioooo002?oooo3C?o08Coool008ooool=<ol0Q?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55436 .12361 L
.55972 .12361 L
.56236 .12361 L
.56366 .12361 L
.56486 .12361 L
.56594 .12361 L
s
.56594 .12361 m
.5664 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.42237 .12361 L
.42781 .12361 L
.43049 .12361 L
.43179 .12361 L
.43298 .12361 L
.43413 .12319 L
.43522 .12263 L
.43762 .12141 L
.44268 .11889 L
.46172 .11013 L
.50027 .09544 L
.51981 .08918 L
.54127 .08282 L
.55113 .08008 L
.55655 .07861 L
.56169 .07724 L
.56401 .07664 L
.56528 .07631 L
.56647 .076 L
.56775 .12361 L
.56843 .12361 L
.56917 .12361 L
.57167 .12361 L
.58076 .12361 L
.6219 .12361 L
.66152 .12361 L
.69963 .12361 L
.74019 .12361 L
.77924 .12361 L
.82073 .12361 L
.86072 .12361 L
.89918 .12361 L
.9401 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool200003_ooo`80I_mooooo000Goooo1@0003?oool2
00001?ooo`800004oooo0P0003;oool00`000?ooooooo`09oooo1P1Vob?oool200001?ooo`800004
oooo0P0003Coool500005Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Soool0
10000?ooooooo`00037oool00`000?ooooooo`06oooo0`1Vo`Goool00`1Vooooooooo`0Poooo00@0
003oooooool00008oooo00@0003oooooool0000eoooo00<0003oooooool05Oooo`006Oooo`030000
oooooooo03;oool010000?ooooooo`0000_oool00`000?ooooooo`0_oooo00<0003oooooool01?oo
o`80I_l8oooo00<0I_ooooooool08?ooo`040000oooooooo00002oooo`030000oooooooo03?oool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0/oooo100000;oool010000?oo
ooooo`0000Woool20000<_ooo`030000oooooooo00@0I_l:oooo00<0I_ooooooool08?ooo`040000
oooooooo00002Oooo`80000foooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool0
10000?ooooooo`0000Woool00`000?ooooooo`0`oooo00@0I_l00000I_l0I_l>oooo00<0I_oooooo
ool08?ooo`040000oooooooo00002Oooo`030000oooooooo03Goool00`000?ooooooo`0Eoooo000H
oooo0P0003Goool200002_ooo`<0000^oooo0P1Vo`03oooo0000000000ooool00`1Vooooooooo`0Q
oooo0P0000[oool30000=?ooo`80000Goooo0029oooo0`1Vo`?oool00`000?ooooooo`0>oooo00<0
I_ooooooool0OOooo`00Qoooo`80I_l6oooo00<0003oooooool03_ooo`0306Kooooooooo07goool0
08Coool306Ko2?ooo`030000oooooooo00koool00`1Vooooooooo`1moooo0022oooo0P1Vo`_oool0
0`000?ooooooo`0>oooo00<0I_ooooooool0OOooo`00P?ooo`80I_l=oooo00<0003oooooool03_oo
o`0306Kooooooooo07goool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`000S?o0003o`2I<ol0<ol0
00@co`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Xco`000`0003?o03?o0009<ol000<0
000co`0co`002C?o00030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0>Oooo`030000<ol0<ol000hco`000ol0VC?o03?o000X<ol000<0000co`0co`00=S?o00D0000G
oooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol005Tco`0800007?ooo`00Soooo`030000
<ol0<ol000hco`000ol0VC?o03?o001C<ol01P0002Coool008ooool00`0003?o03?o000><ol000?o
09Tco`0co`00CS?o00D0000Zoooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol004Tco`05
0000;oooo`00Soooo`80000?<ol000?o09Tco`0co`00A3?o00D0000doooo002?oooo00<0000co`0c
o`003S?o0003o`2I<ol0<ol0040co`040000>Oooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o
03?o000n<ol00P0003goool008ooool00`0003?o03?o000><ol000?o09Tco`0co`00>c?o00<0000o
oooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol003Tco`020000@_ooo`00Soooo`030000
<ol0<ol000hco`000ol0VC?o03?o000g<ol00P0004Coool008ooool200003c?o0003o`2I<ol0<ol0
03Dco`020000A_ooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o000c<ol00P0004Soool0
08ooool00`0003?o03?o000><ol000?o09Tco`0co`00<S?o00030000oooooooo04Soool008ooool0
0`0003?o03?o000><ol000?o09Tco`0co`00<3?o0080001;oooo002?oooo00<0000co`0co`003S?o
0003o`2I<ol0<ol002hco`020000COooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o000]
<ol000<0003oooooool0COooo`00Soooo`80000?<ol000?o09Tco`0co`00:c?o0080001@oooo002?
oooo00<0000co`0co`003S?o0003o`2I<ol0<ol002Tco`020000D_ooo`00Soooo`030000<ol0<ol0
00hco`000ol0VC?o03?o000X<ol000<0003oooooool0D_ooo`00Soooo`030000<ol0<ol000hco`00
0ol0VC?o03?o000W<ol000<0003oooooool0Doooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o
03?o000U<ol00P0005Koool008ooool00`0003?o03?o000><ol000?o09Tco`0co`0093?o00030000
oooooooo05Koool008ooool200003c?o0003o`2I<ol0<ol002<co`000`000?ooooooo`1Goooo002?
oooo00<0000co`0co`003S?o0003o`2I<ol0<ol0028co`000`000?ooooooo`1Hoooo002?oooo00<0
000co`0co`003S?o0003o`2I<ol0<ol0024co`000`000?ooooooo`1Ioooo002?oooo00<0000co`0c
o`003S?o0003o`2I<ol0<ol0020co`000`000?ooooooo`1Joooo002?oooo00<0000co`0co`003S?o
0003o`2I<ol0<ol0020co`000`000?ooooooo`1Joooo0027oooo1@0000?oool00`0003?o03?o000>
<ol000?o09Tco`0co`007c?o00030000oooooooo05_oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`003S?o0003o`2I<ol0<ol001hco`000`000?ooooooo`1Loooo0029oooo00<0003ooooo
ool00oooo`<0000><ol000?o09Tco`0co`007C?o00030000oooooooo05goool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`003S?o0003o`2I<ol0<ol001dco`000`000?ooooooo`1Moooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol000hco`000ol0VC?o03?o000L<ol000<0003ooooo
ool0G_ooo`00R?ooo`800005oooo00<0000co`0co`003S?o0003o`2I<ol0<ol001/co`000`000?oo
ooooo`1Ooooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol001Xco`000`000?ooooooo`1P
oooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol001Xco`000`000?ooooooo`1Poooo002?
oooo0P0000lco`000ol0VC?o03?o000I<ol000<0003oooooool0HOooo`00Soooo`030000<ol0<ol0
00hco`000ol0VC?o03?o000H<ol000<0003oooooool0H_ooo`00Soooo`030000<ol0<ol000hco`00
0ol0VC?o03?o000H<ol000<0003oooooool0H_ooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o
03?o000G<ol000<0003oooooool0Hoooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o000F
<ol000<0003oooooool0I?ooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o000E<ol000<0
003oooooool0IOooo`00Soooo`80000?<ol000?o09Tco`0co`005C?o00030000oooooooo06Goool0
08ooool00`0003?o03?o000><ol000?o09Tco`0co`0053?o00030000oooooooo06Koool008ooool0
0`0003?o03?o000><ol000?o09Tco`0co`004c?o00030000oooooooo06Ooool008ooool00`0003?o
03?o000><ol000?o09Tco`0co`004c?o00030000oooooooo06Ooool008ooool00`0003?o03?o000>
<ol000?o09Tco`0co`004S?o00030000oooooooo06Soool008ooool00`0003?o03?o000><ol000?o
09Tco`0co`004S?o00030000oooooooo06Soool008ooool00`0003?o03?o000><ol000?o09Tco`0c
o`004C?o00030000oooooooo06Woool008ooool200003c?o0003o`2I<ol0<ol0014co`000`000?oo
ooooo`1Yoooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1Z
oooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1Zoooo002?
oooo00<0000co`0co`003S?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1[oooo002?oooo00<0
000co`0co`003S?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1[oooo002?oooo00<0000co`0c
o`003S?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1[oooo002?oooo0P0000lco`000ol0VC?o
03?o000><ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o000>
<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o000=<ol000<0
003oooooool0KOooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o000=<ol000<0003ooooo
ool0KOooo`00Qoooo`@00004oooo00<0000co`0co`003S?o0003o`2I<ol0<ol000dco`000`000?oo
ooooo`1]oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000hco`000ol0VC?o03?o000<
<ol000<0003oooooool0K_ooo`00R?ooo`030000oooooooo00Coool300003S?o0003o`2I<ol0<ol0
00`co`000`000?ooooooo`1^oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000hco`00
0ol0VC?o03?o000<<ol000<0003oooooool0K_ooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000hco`000ol0VC?o03?o000;<ol000<0003oooooool0Koooo`00R?ooo`800005oooo00<0
000co`0co`003S?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1_oooo002?oooo00<0000co`0c
o`003S?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`003S?o
0003o`2I<ol0<ol000Xco`000`000?ooooooo`1`oooo002?oooo0P0000lco`000ol0VC?o03?o000:
<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o0009<ol000<0
003oooooool0LOooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o0009<ol000<0003ooooo
ool0LOooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o0009<ol000<0003oooooool0LOoo
o`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o0009<ol000<0003oooooool0LOooo`00Sooo
o`030000<ol0<ol000hco`000ol0VC?o03?o0008<ol000<0003oooooool0L_ooo`00Soooo`030000
<ol0<ol000hco`000ol0VC?o03?o0008<ol000<0003oooooool0L_ooo`00Soooo`80000?<ol000?o
09Tco`0co`0023?o00030000oooooooo07;oool008ooool00`0003?o03?o000><ol000?o09Tco`0c
o`001c?o00030000oooooooo07?oool008ooool00`0003?o03?o000><ol000?o09Tco`0co`001c?o
00030000oooooooo07?oool008ooool00`0003?o03?o000><ol000?o09Tco`0co`001c?o00030000
oooooooo07?oool008ooool00`0003?o03?o000><ol000?o09Tco`0co`001S?o00030000oooooooo
07Coool008ooool00`0003?o03?o000><ol000?o09Tco`0co`001S?o00030000oooooooo07Coool0
08ooool200003c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1doooo002?oooo00<0000co`0c
o`003S?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1doooo002?oooo00<0000co`0co`003S?o
0003o`2I<ol0<ol000Dco`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`003S?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol0
00Dco`000`000?ooooooo`1eoooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`1foooo002?oooo0P0000lco`000ol0VC?o03?o0004<ol000<0003oooooool0M_oo
o`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o0004<ol000<0003oooooool0M_ooo`00Sooo
o`030000<ol0<ol000hco`000ol0VC?o03?o0004<ol000<0003oooooool0M_ooo`00Soooo`030000
<ol0<ol000hco`000ol0VC?o03?o0003<ol000<0003oooooool0Moooo`00R?ooo`800005oooo00<0
000co`0co`003S?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1goooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`003S?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1goooo0029
oooo00<0003oooooool00oooo`<0000><ol000?o09Tco`0co`000S?o00030000oooooooo07Soool0
08[oool00`000?ooooooo`02oooo00<0000co`0co`003S?o0003o`2I<ol0<ol0008co`000`000?oo
ooooo`1hoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`003S?o0003o`2I<ol0<ol0
008co`000`000?ooooooo`1hoooo0028oooo0P0000Goool00`0003?o03?o000><ol000Go09Tco`0c
o`0co`000000Noooo`00Soooo`030000<ol0<ol000hco`001Ol0VC?o03?o03?o0000001koooo002?
oooo00<0000co`0co`003S?o0005o`2I<ol0<ol0<ol0000007_oool008ooool00`0003?o03?o000>
<ol000Go09Tco`0co`0co`000000Noooo`00Soooo`80000?<ol000Co09Tco`0co`00001loooo002?
oooo00<0000co`0co`003S?o0004o`2I<ol0<ol00000O?ooo`00Soooo`030000<ol0<ol000hco`00
1?l0VC?o03?o000007coool008ooool00`0003?o03?o000><ol000Co09Tco`0co`00001loooo002?
oooo00<0000co`0co`003S?o0003o`2I<ol0000007goool008ooool00`0003?o03?o000><ol000?o
09Tco`000000OOooo`00Soooo`80000?<ol000?o09Tco`000000OOooo`00Soooo`030000<ol0<ol0
00hco`000ol0VC?o0000001moooo002?oooo00<0000co`0co`003S?o0003o`2I0000oooo07goool0
08ooool00`0003?o03?o000><ol000?o09T0003oool0OOooo`00Soooo`030000<ol0<ol000hco`00
0ol0V@000?ooo`1moooo002?oooo00<0000co`0co`003S?o0003o`2I0000oooo07goool008ooool2
00003c?o0003o`2I0000oooo07goool008ooool00`0003?o03?o000><ol000?o09Woooooool0OOoo
o`00Soooo`030000<ol0<ol000hco`000ol0VOooooooo`1moooo002?oooo00<0000co`0co`003S?o
0003o`2Ioooooooo07goool008ooool00`0003?o03?o000><ol000?o09Woooooool0OOooo`00Sooo
o`030000<ol0<ol000hco`000ol0VOooooooo`1moooo002?oooo0P0000hco`000`000?l0VOooo`1n
oooo002?oooo00<0000co`0co`003C?o00030000o`2Ioooo07koool008ooool00`0003?o03?o000=
<ol000<0003o09Woool0O_ooo`00Soooo`030000<ol0<ol000dco`000`000?l0VOooo`1noooo002?
oooo00<0000co`0co`0033?o00030000ooooo`2I07ooool008Woool300000oooo`030000<ol0<ol0
00`co`000`000?ooool0V@1ooooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000`co`00
0`000?ooool0V@1ooooo0027oooo1@0000?oool3000033?o00030000ooooo`2I07ooool008Ooool0
10000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROoo
o`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0003ooooo
ool04oooo`hco`07oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`09oooo3S?o00Soool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01oooo`800004<ol00P0000<co`0500000oooo`<00002oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`040000oooooooo00002S?o00030000<ol0<ol000Coool01@000?ooooooooooo`00001j
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Xco`00
100003?o03?o0?ooo`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<
oooo00@0003oooooool0000:<ol000D0000co`0co`3oool000000_ooo`050000oooooooooooo0000
07[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool0000:<ol000<0000co`3o
ool00_ooo`030000oooo000000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Ooo
o`80000:<ol00P000003<ol0oooooooo00;oool200000_ooo`030000oooooooo07Woool008ooool=
<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55972 .12361 L
.56446 .12361 L
.56706 .12361 L
.56834 .12361 L
.56951 .12361 L
.57063 .12361 L
s
.57063 .12361 m
.5711 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.41696 .12361 L
.42237 .12361 L
.42482 .12361 L
.42617 .12361 L
.42744 .12361 L
.42816 .12361 L
.42894 .12341 L
.42966 .12305 L
.43031 .12271 L
.43298 .12135 L
.44268 .1166 L
.46172 .1081 L
.5012 .09358 L
.53918 .08222 L
.55869 .07697 L
.5643 .07553 L
.56707 .07483 L
.56828 .07452 L
.56963 .07419 L
.57082 .07389 L
.57194 .12361 L
.57313 .12361 L
.5744 .12361 L
.5796 .12361 L
.62074 .12361 L
.66036 .12361 L
.69847 .12361 L
.73903 .12361 L
.77808 .12361 L
.81958 .12361 L
.85956 .12361 L
.89802 .12361 L
.93894 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool200003_ooo`<0I_mnoooo000Goooo1@0003?oool2
00001?ooo`800004oooo0P0003;oool00`000?ooooooo`0:oooo0`1Vo`;oool00`1Vooooooooo`0P
oooo0P0000Coool200001?ooo`80000doooo1@0001Goool001Woool00`000?ooooooo`0boooo00@0
003oooooool00008oooo00@0003oooooool0000aoooo00<0003oooooool01_ooo`@0I_l5oooo00<0
I_ooooooool07oooo`040000oooooooo00002?ooo`040000oooooooo0000=Oooo`030000oooooooo
01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0003oooooool0;ooo
o`030000oooooooo00?oool306Ko2Oooo`0306Kooooooooo01ooool010000?ooooooo`0000_oool0
0`000?ooooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?oo
o`@00002oooo00@0003oooooool00009oooo0P0003;oool00`000?ooo`1Vo`0306Ko3?ooo`0306Ko
oooooooo01ooool010000?ooooooo`0000Woool20000=_ooo`030000oooooooo01Goool001Woool0
0`000?ooooooo`0boooo00@0003oooooool00009oooo00<0003oooooool0<?ooo`0306Ko000006Ko
013oool00`1Vooooooooo`0Ooooo00@0003oooooool00009oooo00<0003oooooool0=Oooo`030000
oooooooo01Goool001Soool20000=Oooo`80000:oooo0`0002goool306Ko00?oool0000000004?oo
o`0306Kooooooooo023oool200002_ooo`<0000doooo0P0001Ooool008Ooool406Ko1?ooo`030000
oooooooo00ooool00`1Vooooooooo`1loooo0025oooo0P1Vo`Soool00`000?ooooooo`0?oooo00<0
I_ooooooool0O?ooo`00Poooo`80I_l:oooo00<0003oooooool03oooo`0306Kooooooooo07coool0
087oool206Ko3?ooo`030000oooooooo00ooool00`1Vooooooooo`1loooo0020oooo00<0I_oooooo
ool03?ooo`030000oooooooo00ooool00`1Vooooooooo`1loooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000
<ol0<ol000<co`000ol0VC?o03?o0003<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0
003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000?<ol000?o09Tco`0co`009c?o
00030000<ol0<ol003Hco`0500005oooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o001H
<ol0200001coool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`00DS?o00H0000Toooo002?
oooo00<0000co`0co`003c?o0003o`2I<ol0<ol004dco`050000:_ooo`00Soooo`030000<ol0<ol0
00lco`000ol0VC?o03?o0018<ol01@0002ooool008ooool2000043?o0003o`2I<ol0<ol004<co`05
0000=?ooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000o<ol0100003Woool008ooool0
0`0003?o03?o000?<ol000?o09Tco`0co`00?C?o0080000moooo002?oooo00<0000co`0co`003c?o
0003o`2I<ol0<ol003Xco`030000?oooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000h
<ol00P0004;oool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`00=S?o00800014oooo002?
oooo0P00010co`000ol0VC?o03?o000d<ol00P0004Koool008ooool00`0003?o03?o000?<ol000?o
09Tco`0co`00<S?o00800018oooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol0034co`00
0`000?ooooooo`18oooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol002lco`020000Booo
o`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000]<ol00P0004goool008ooool00`0003?o
03?o000?<ol000?o09Tco`0co`00;3?o00030000oooooooo04goool008ooool2000043?o0003o`2I
<ol0<ol002Xco`020000D?ooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000X<ol00P00
05;oool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`009c?o00030000oooooooo05;oool0
08ooool00`0003?o03?o000?<ol000?o09Tco`0co`009S?o00030000oooooooo05?oool008ooool0
0`0003?o03?o000?<ol000?o09Tco`0co`0093?o0080001Foooo002?oooo00<0000co`0co`003c?o
0003o`2I<ol0<ol002<co`000`000?ooooooo`1Foooo002?oooo0P00010co`000ol0VC?o03?o000R
<ol000<0003oooooool0Eoooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000Q<ol000<0
003oooooool0F?ooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000P<ol000<0003ooooo
ool0FOooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000O<ol000<0003oooooool0F_oo
o`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000O<ol000<0003oooooool0F_ooo`00Qooo
o`D00003oooo00<0000co`0co`003c?o0003o`2I<ol0<ol001hco`000`000?ooooooo`1Koooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol000lco`000ol0VC?o03?o000M<ol000<0003ooooo
ool0G?ooo`00ROooo`030000oooooooo00?oool300003c?o0003o`2I<ol0<ol001`co`000`000?oo
ooooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000lco`000ol0VC?o03?o000L
<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000?<ol000?o
09Tco`0co`006c?o00030000oooooooo05koool008Soool200001Oooo`030000<ol0<ol000lco`00
0ol0VC?o03?o000J<ol000<0003oooooool0Goooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o
03?o000I<ol000<0003oooooool0H?ooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000I
<ol000<0003oooooool0H?ooo`00Soooo`80000@<ol000?o09Tco`0co`0063?o00030000oooooooo
067oool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`005c?o00030000oooooooo06;oool0
08ooool00`0003?o03?o000?<ol000?o09Tco`0co`005c?o00030000oooooooo06;oool008ooool0
0`0003?o03?o000?<ol000?o09Tco`0co`005S?o00030000oooooooo06?oool008ooool00`0003?o
03?o000?<ol000?o09Tco`0co`005C?o00030000oooooooo06Coool008ooool00`0003?o03?o000?
<ol000?o09Tco`0co`0053?o00030000oooooooo06Goool008ooool2000043?o0003o`2I<ol0<ol0
01@co`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol001<co`00
0`000?ooooooo`1Voooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol0018co`000`000?oo
ooooo`1Woooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1W
oooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1Xoooo002?
oooo00<0000co`0co`003c?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1Xoooo002?oooo00<0
000co`0co`003c?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1Yoooo002?oooo0P00010co`00
0ol0VC?o03?o000@<ol000<0003oooooool0JOooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o
03?o000?<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000?
<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000><ol000<0
003oooooool0Joooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000><ol000<0003ooooo
ool0Joooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000><ol000<0003oooooool0Jooo
o`00Soooo`80000@<ol000?o09Tco`0co`003C?o00030000oooooooo06coool008ooool00`0003?o
03?o000?<ol000?o09Tco`0co`003C?o00030000oooooooo06coool008ooool00`0003?o03?o000?
<ol000?o09Tco`0co`0033?o00030000oooooooo06goool008ooool00`0003?o03?o000?<ol000?o
09Tco`0co`0033?o00030000oooooooo06goool008Ooool400001?ooo`030000<ol0<ol000lco`00
0ol0VC?o03?o000<<ol000<0003oooooool0KOooo`00Qoooo`030000oooooooo00Goool00`0003?o
03?o000?<ol000?o09Tco`0co`002c?o00030000oooooooo06koool008Soool00`000?ooooooo`04
oooo0`0000lco`000ol0VC?o03?o000;<ol000<0003oooooool0K_ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000?<ol000?o09Tco`0co`002c?o00030000oooooooo06koool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o000?<ol000?o09Tco`0co`002S?o00030000oooooooo
06ooool008Soool200001Oooo`030000<ol0<ol000lco`000ol0VC?o03?o000:<ol000<0003ooooo
ool0Koooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o0009<ol000<0003oooooool0L?oo
o`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o0009<ol000<0003oooooool0L?ooo`00Sooo
o`80000@<ol000?o09Tco`0co`002C?o00030000oooooooo073oool008ooool00`0003?o03?o000?
<ol000?o09Tco`0co`0023?o00030000oooooooo077oool008ooool00`0003?o03?o000?<ol000?o
09Tco`0co`0023?o00030000oooooooo077oool008ooool00`0003?o03?o000?<ol000?o09Tco`0c
o`0023?o00030000oooooooo077oool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`0023?o
00030000oooooooo077oool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`001c?o00030000
oooooooo07;oool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`001c?o00030000oooooooo
07;oool008ooool2000043?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1boooo002?oooo00<0
000co`0co`003c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1coooo002?oooo00<0000co`0c
o`003c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1coooo002?oooo00<0000co`0co`003c?o
0003o`2I<ol0<ol000Hco`000`000?ooooooo`1coooo002?oooo00<0000co`0co`003c?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`1doooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol0
00Dco`000`000?ooooooo`1doooo002?oooo0P00010co`000ol0VC?o03?o0005<ol000<0003ooooo
ool0M?ooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o0005<ol000<0003oooooool0M?oo
o`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o0004<ol000<0003oooooool0MOooo`00Sooo
o`030000<ol0<ol000lco`000ol0VC?o03?o0004<ol000<0003oooooool0MOooo`00Soooo`030000
<ol0<ol000lco`000ol0VC?o03?o0004<ol000<0003oooooool0MOooo`00Soooo`030000<ol0<ol0
00lco`000ol0VC?o03?o0003<ol000<0003oooooool0M_ooo`00Soooo`80000@<ol000?o09Tco`0c
o`000c?o00030000oooooooo07Koool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`000c?o
00030000oooooooo07Koool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`000c?o00030000
oooooooo07Koool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`000S?o00030000oooooooo
07Ooool008Soool200001Oooo`030000<ol0<ol000lco`000ol0VC?o03?o0002<ol000<0003ooooo
ool0Moooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000lco`000ol0VC?o03?o0002
<ol000<0003oooooool0Moooo`00ROooo`030000oooooooo00?oool300003c?o0005o`2I<ol0<ol0
<ol0000007[oool008[oool00`000?ooooooo`02oooo00<0000co`0co`003c?o0005o`2I<ol0<ol0
<ol0000007[oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000?<ol000Go09Tco`0c
o`0co`000000N_ooo`00R?ooo`800005oooo00<0000co`0co`003c?o0004o`2I<ol0<ol00000Nooo
o`00Soooo`030000<ol0<ol000lco`001?l0VC?o03?o000007_oool008ooool00`0003?o03?o000?
<ol000Co09Tco`0co`00001koooo002?oooo00<0000co`0co`003c?o0004o`2I<ol0<ol00000Nooo
o`00Soooo`80000@<ol000?o09Tco`000000O?ooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o
0000001loooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0000007coool008ooool00`0003?o
03?o000?<ol000?o09Tco`000000O?ooo`00Soooo`030000<ol0<ol000lco`000ol0V@000?ooo`1l
oooo002?oooo00<0000co`0co`003c?o0003o`2I0000oooo07coool008ooool2000043?o0003o`2I
0000oooo07coool008ooool00`0003?o03?o000?<ol000?o09T0003oool0O?ooo`00Soooo`030000
<ol0<ol000lco`000ol0VOooooooo`1loooo002?oooo00<0000co`0co`003c?o0003o`2Ioooooooo
07coool008ooool00`0003?o03?o000?<ol000?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol0
00lco`000ol0VOooooooo`1loooo002?oooo0P00010co`000ol0VOooooooo`1loooo002?oooo00<0
000co`0co`003S?o00030000o`2Ioooo07goool008ooool00`0003?o03?o000><ol000<0003o09Wo
ool0OOooo`00Soooo`030000<ol0<ol000hco`000`000?l0VOooo`1moooo002?oooo00<0000co`0c
o`003S?o00030000o`2Ioooo07goool008ooool00`0003?o03?o000><ol000<0003o09Woool0OOoo
o`00Soooo`80000><ol000<0003ooooo09T0O_ooo`00Soooo`030000<ol0<ol000dco`000`000?oo
ool0V@1noooo002?oooo00<0000co`0co`003C?o00030000ooooo`2I07koool008ooool00`0003?o
03?o000=<ol000<0003ooooo09T0O_ooo`00Soooo`030000<ol0<ol000`co`0010000?ooooooool0
VGkoool008Woool300000oooo`030000<ol0<ol000`co`0010000?ooooooool0VGkoool008[oool0
0`000?ooooooo`02oooo00<0000co`0co`0033?o00040000ooooooooo`2IO_ooo`00Qoooo`D00003
oooo0`0000`co`0010000?ooooooool0VGkoool008Ooool010000?ooooooo`0000Coool?<ol0P_oo
o`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?
<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07oooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o00Soool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004
<ol00P0000<co`0500000_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002S?o
00050000<ol0<ol0oooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00goool010000?ooooooo`0000Xco`000`0003?o03?o0004oooo00<0
003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000
oooooooo00002S?o00030000<ol0<ol000;oool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000?oooo00@0003oooooool0000:<ol000<0000co`3oool00_ooo`030000
oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:<ol00P00
0004<ol0oooooooooooo0`0000;oool00`000?ooooooo`1ioooo002?oooo3C?o08Coool008ooool=
<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55972 .12361 L
.56446 .12361 L
.56951 .12361 L
.57197 .12361 L
.57318 .12361 L
.57429 .12361 L
.5753 .12361 L
s
.5753 .12361 m
.57572 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.41696 .12361 L
.41976 .12361 L
.42113 .12361 L
.42237 .12361 L
.42363 .12361 L
.42482 .12308 L
.42744 .12174 L
.43298 .11898 L
.44268 .11437 L
.46172 .10614 L
.50027 .09238 L
.51981 .0865 L
.54127 .08049 L
.55113 .07788 L
.56169 .07518 L
.56681 .07391 L
.57167 .07273 L
.57378 .07222 L
.57493 .07194 L
.57602 .07168 L
.57719 .12361 L
.57848 .12361 L
.58076 .12361 L
.61945 .12361 L
.66059 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo013oool00`1Vooooooooo`1koooo002?oooo0P0000goool506KoOOoo
o`005oooo`D0000coooo0P0000Coool200001?ooo`80000boooo00<0003oooooool01_ooo`H0I_l4
oooo00<0I_ooooooool07oooo`800004oooo0P0000Coool20000=?ooo`D0000Eoooo000Ioooo00<0
003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo0000<Oooo`030000oooooooo
00Coool206Ko2_ooo`0306Kooooooooo01koool010000?ooooooo`0000Soool010000?ooooooo`00
03Goool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002ooo
o`030000oooooooo02ooool00`000?ooooooo`0406Ko3?ooo`0306Kooooooooo01koool010000?oo
ooooo`0000_oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0
003oooooool0;?ooo`@00002oooo00@0003oooooool00009oooo0P00037oool0101Vo`00001Vo`1V
oa3oool00`1Vooooooooo`0Noooo00@0003oooooool00009oooo0P0003Koool00`000?ooooooo`0E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002Oooo`030000oooooooo02koool2
06Ko00?oool0003oool04Oooo`0306Kooooooooo01koool010000?ooooooo`0000Woool00`000?oo
ooooo`0eoooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P0000[oool30000:oooo`<0I_l3
oooo0P0001;oool00`1Vooooooooo`0Noooo0P0000[oool30000=?ooo`80000Goooo0027oooo0P1V
o`Koool00`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`00Q?ooo`<0I_l8oooo00<0003ooooo
ool04Oooo`0306Kooooooooo07[oool008;oool206Ko2oooo`030000oooooooo017oool00`1Voooo
ooooo`1joooo0020oooo0P1Vo`goool00`000?ooooooo`0Aoooo00<0I_ooooooool0N_ooo`00O_oo
o`80I_l?oooo00<0003oooooool04Oooo`0306Kooooooooo07[oool0013ooooo00004Oooo`005_oo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0
000co`0co`0013?o0003o`2I<ol0<ol0008co`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Xco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0010co`000ol0VC?o03?o000V
<ol000<0000co`0co`00=S?o00D0000Goooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0
05Lco`0800007?ooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o001A<ol01P0002Coool0
08ooool00`0003?o03?o000@<ol000?o09Tco`0co`00C3?o00D0000Zoooo002?oooo00<0000co`0c
o`0043?o0003o`2I<ol0<ol004Lco`050000;oooo`00Soooo`80000A<ol000?o09Tco`0co`00@S?o
00D0000doooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol003hco`040000>Oooo`00Sooo
o`030000<ol0<ol0010co`000ol0VC?o03?o000l<ol00P0003goool008ooool00`0003?o03?o000@
<ol000?o09Tco`0co`00>C?o00<0000ooooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0
03Lco`020000@_ooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o000e<ol00P0004Coool0
08ooool200004C?o0003o`2I<ol0<ol003<co`020000A_ooo`00Soooo`030000<ol0<ol0010co`00
0ol0VC?o03?o000a<ol00P0004Soool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`00<3?o
00030000oooooooo04Soool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`00;S?o0080001;
oooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol002`co`020000COooo`00Soooo`030000
<ol0<ol0010co`000ol0VC?o03?o000[<ol000<0003oooooool0COooo`00Soooo`80000A<ol000?o
09Tco`0co`00:C?o0080001@oooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol002Lco`02
0000D_ooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o000V<ol000<0003oooooool0D_oo
o`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o000U<ol000<0003oooooool0Doooo`00Sooo
o`030000<ol0<ol0010co`000ol0VC?o03?o000S<ol00P0005Koool008ooool00`0003?o03?o000@
<ol000?o09Tco`0co`008S?o00030000oooooooo05Koool008ooool200004C?o0003o`2I<ol0<ol0
024co`000`000?ooooooo`1Goooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0020co`00
0`000?ooooooo`1Hoooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol001lco`000`000?oo
ooooo`1Ioooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol001hco`000`000?ooooooo`1J
oooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol001hco`000`000?ooooooo`1Joooo0027
oooo1@0000?oool00`0003?o03?o000@<ol000?o09Tco`0co`007C?o00030000oooooooo05_oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`0043?o0003o`2I<ol0<ol001`co`000`000?oo
ooooo`1Loooo0029oooo00<0003oooooool00oooo`<0000@<ol000?o09Tco`0co`006c?o00030000
oooooooo05goool008Woool00`000?ooooooo`03oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0
01/co`000`000?ooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0010co`00
0ol0VC?o03?o000J<ol000<0003oooooool0G_ooo`00R?ooo`800005oooo00<0000co`0co`0043?o
0003o`2I<ol0<ol001Tco`000`000?ooooooo`1Ooooo002?oooo00<0000co`0co`0043?o0003o`2I
<ol0<ol001Pco`000`000?ooooooo`1Poooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0
01Pco`000`000?ooooooo`1Poooo002?oooo0P00014co`000ol0VC?o03?o000G<ol000<0003ooooo
ool0HOooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o000F<ol000<0003oooooool0H_oo
o`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o000F<ol000<0003oooooool0H_ooo`00Sooo
o`030000<ol0<ol0010co`000ol0VC?o03?o000E<ol000<0003oooooool0Hoooo`00Soooo`030000
<ol0<ol0010co`000ol0VC?o03?o000D<ol000<0003oooooool0I?ooo`00Soooo`030000<ol0<ol0
010co`000ol0VC?o03?o000C<ol000<0003oooooool0IOooo`00Soooo`80000A<ol000?o09Tco`0c
o`004c?o00030000oooooooo06Goool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`004S?o
00030000oooooooo06Koool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`004C?o00030000
oooooooo06Ooool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`004C?o00030000oooooooo
06Ooool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`0043?o00030000oooooooo06Soool0
08ooool00`0003?o03?o000@<ol000?o09Tco`0co`0043?o00030000oooooooo06Soool008ooool0
0`0003?o03?o000@<ol000?o09Tco`0co`003c?o00030000oooooooo06Woool008ooool200004C?o
0003o`2I<ol0<ol000lco`000`000?ooooooo`1Yoooo002?oooo00<0000co`0co`0043?o0003o`2I
<ol0<ol000hco`000`000?ooooooo`1Zoooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0
00hco`000`000?ooooooo`1Zoooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000dco`00
0`000?ooooooo`1[oooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000dco`000`000?oo
ooooo`1[oooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1[
oooo002?oooo0P00014co`000ol0VC?o03?o000<<ol000<0003oooooool0K?ooo`00Soooo`030000
<ol0<ol0010co`000ol0VC?o03?o000<<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol0
010co`000ol0VC?o03?o000;<ol000<0003oooooool0KOooo`00Soooo`030000<ol0<ol0010co`00
0ol0VC?o03?o000;<ol000<0003oooooool0KOooo`00Qoooo`@00004oooo00<0000co`0co`0043?o
0003o`2I<ol0<ol000/co`000`000?ooooooo`1]oooo0027oooo00<0003oooooool01Oooo`030000
<ol0<ol0010co`000ol0VC?o03?o000:<ol000<0003oooooool0K_ooo`00R?ooo`030000oooooooo
00Coool3000043?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1^oooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol0010co`000ol0VC?o03?o000:<ol000<0003oooooool0K_ooo`00Qooo
o`040000oooooooo00001?ooo`030000<ol0<ol0010co`000ol0VC?o03?o0009<ol000<0003ooooo
ool0Koooo`00R?ooo`800005oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000Tco`000`000?oo
ooooo`1_oooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1`
oooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1`oooo002?
oooo0P00014co`000ol0VC?o03?o0008<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol0
010co`000ol0VC?o03?o0007<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol0010co`00
0ol0VC?o03?o0007<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o
03?o0007<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o0007
<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o0006<ol000<0
003oooooool0L_ooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o0006<ol000<0003ooooo
ool0L_ooo`00Soooo`80000A<ol000?o09Tco`0co`001S?o00030000oooooooo07;oool008ooool0
0`0003?o03?o000@<ol000?o09Tco`0co`001C?o00030000oooooooo07?oool008ooool00`0003?o
03?o000@<ol000?o09Tco`0co`001C?o00030000oooooooo07?oool008ooool00`0003?o03?o000@
<ol000?o09Tco`0co`001C?o00030000oooooooo07?oool008ooool00`0003?o03?o000@<ol000?o
09Tco`0co`0013?o00030000oooooooo07Coool008ooool00`0003?o03?o000@<ol000?o09Tco`0c
o`0013?o00030000oooooooo07Coool008ooool200004C?o0003o`2I<ol0<ol000@co`000`000?oo
ooooo`1doooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1d
oooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1eoooo002?
oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1eoooo002?oooo00<0
000co`0co`0043?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1eoooo002?oooo00<0000co`0c
o`0043?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1foooo002?oooo0P00014co`000ol0VC?o
03?o0002<ol000<0003oooooool0M_ooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o0002
<ol000<0003oooooool0M_ooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o0002<ol000<0
003oooooool0M_ooo`00Soooo`030000<ol0<ol0010co`001Ol0VC?o03?o03?o0000001ioooo0028
oooo0P0000Goool00`0003?o03?o000@<ol000Go09Tco`0co`0co`000000NOooo`00Qoooo`040000
oooooooo00001?ooo`030000<ol0<ol0010co`001Ol0VC?o03?o03?o0000001ioooo0029oooo00<0
003oooooool00oooo`<0000@<ol000Co09Tco`0co`00001joooo002:oooo00<0003oooooool00_oo
o`030000<ol0<ol0010co`001?l0VC?o03?o000007[oool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o000@<ol000Co09Tco`0co`00001joooo0028oooo0P0000Goool00`0003?o03?o000@
<ol000?o09Tco`000000Noooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o0000001koooo002?
oooo00<0000co`0co`0043?o0003o`2I<ol0000007_oool008ooool00`0003?o03?o000@<ol000?o
09Tco`000000Noooo`00Soooo`80000A<ol000?o09T0003oool0Noooo`00Soooo`030000<ol0<ol0
010co`000ol0V@000?ooo`1koooo002?oooo00<0000co`0co`0043?o0003o`2I0000oooo07_oool0
08ooool00`0003?o03?o000@<ol000?o09T0003oool0Noooo`00Soooo`030000<ol0<ol0010co`00
0ol0VOooooooo`1koooo002?oooo00<0000co`0co`0043?o0003o`2Ioooooooo07_oool008ooool2
00004C?o0003o`2Ioooooooo07_oool008ooool00`0003?o03?o000@<ol000?o09Woooooool0Nooo
o`00Soooo`030000<ol0<ol000lco`000`000?l0VOooo`1loooo002?oooo00<0000co`0co`003c?o
00030000o`2Ioooo07coool008ooool00`0003?o03?o000?<ol000<0003o09Woool0O?ooo`00Sooo
o`030000<ol0<ol000lco`000`000?l0VOooo`1loooo002?oooo0P00010co`000`000?l0VOooo`1l
oooo002?oooo00<0000co`0co`003S?o00030000ooooo`2I07goool008ooool00`0003?o03?o000>
<ol000<0003ooooo09T0OOooo`00Soooo`030000<ol0<ol000hco`000`000?ooool0V@1moooo002?
oooo00<0000co`0co`003S?o00030000ooooo`2I07goool008ooool00`0003?o03?o000><ol000<0
003ooooo09T0OOooo`00Soooo`80000><ol000@0003ooooooooo09Umoooo002?oooo00<0000co`0c
o`003C?o00040000ooooooooo`2IOOooo`00Soooo`030000<ol0<ol000dco`0010000?ooooooool0
VGgoool008ooool00`0003?o03?o000=<ol000@0003ooooooooo09Umoooo002?oooo00<0000co`0c
o`0033?o00050000ooooooooooooo`2I07goool008Woool300000oooo`030000<ol0<ol000`co`00
1@000?ooooooooooool0V@1moooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000`co`00
1@000?ooooooooooool0V@1moooo0027oooo1@0000?oool3000033?o00050000ooooooooooooo`2I
07goool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo000000Coool?
<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22oooo001i
oooo00<0003oooooool04oooo`hco`07oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`09oooo3S?o00Soool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01oooo`800004<ol00P0000<co`05000000Coool00000
00000004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002S?o00050000<ol0<ol0oooo0000
00;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000Xco`001@0003?o03?o0?ooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002S?o
00040000<ol0<ol0oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00003oooo`040000oooooooo00002S?o00030000<ol0oooo00;oool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002S?o0080000013?o0?oooooooooo
o`<00002oooo00<0003oooooool0NOooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.56817 .12361 L
.57355 .12361 L
.57618 .12361 L
.57861 .12361 L
.57995 .12361 L
.58063 .12361 L
s
.58063 .12361 m
.58093 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40134 .12361 L
.41134 .12361 L
.41408 .12361 L
.4156 .12361 L
.41703 .12361 L
.41768 .12361 L
.41837 .12361 L
.41912 .12357 L
.41982 .12321 L
.42237 .1219 L
.46395 .10336 L
.50401 .0898 L
.54257 .07905 L
.5625 .07401 L
.57255 .0716 L
.5753 .07095 L
.57681 .0706 L
.57825 .07027 L
.57958 .06996 L
.58033 .06979 L
.58103 .12361 L
.58226 .12361 L
.58357 .12361 L
.62132 .12361 L
.66152 .12361 L
.70021 .12361 L
.74135 .12361 L
.78097 .12361 L
.81908 .12361 L
.85964 .12361 L
.89869 .12361 L
.94019 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo00ooool306KoO?ooo`00Soooo`80000<oooo101Vo`;oool00`1Voooo
ooooo`1joooo000Goooo1@0003?oool200001?ooo`800004oooo0P0003;oool00`000?ooooooo`07
oooo101Vo`Koool00`1Vooooooooo`0Noooo0P0000Coool200001?ooo`80000doooo1@0001Goool0
01Woool00`000?ooooooo`0boooo00@0003oooooool00008oooo00@0003oooooool0000aoooo00<0
003oooooool01?ooo`<0I_l:oooo00<0I_ooooooool07Oooo`040000oooooooo00002?ooo`040000
oooooooo0000=Oooo`030000oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003ooooo
ool0000;oooo00<0003oooooool0;oooo`030000oooooooo00@0I_l=oooo00<0I_ooooooool07Ooo
o`040000oooooooo00002oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo000Aoooo1000
00Coool00`000?ooooooo`0/oooo100000;oool010000?ooooooo`0000Woool20000<_ooo`030000
06Ko06Ko017oool00`1Vooooooooo`0Moooo00@0003oooooool00009oooo0P0003Koool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002Oooo`030000oooooooo
02koool306Ko00<0003oooooool04Oooo`0306Kooooooooo01goool010000?ooooooo`0000Woool0
0`000?ooooooo`0eoooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P0000[oool30000:_oo
o`@0I_l3oooo0P0001?oool00`1Vooooooooo`0Moooo0P0000[oool30000=?ooo`80000Goooo0025
oooo0`1Vo`Ooool00`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00Poooo`80I_l:oooo00<0
003oooooool04_ooo`0306Kooooooooo07Woool0087oool206Ko3?ooo`030000oooooooo01;oool0
0`1Vooooooooo`1ioooo001ooooo0P1Vo`koool00`000?ooooooo`0Boooo00<0I_ooooooool0NOoo
o`00OOooo`80I_l@oooo00<0003oooooool04_ooo`0306Kooooooooo07Woool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`001C?o0005o`2I<ol0<ol0<ol0000000/co`000`0003?o03?o0009<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002S?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0003oooooool05Oooo`005_ooo`030000
oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`004C?o0003o`2I<ol0<ol002Dco`00
0`0003?o03?o000f<ol01@0001Ooool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`00ES?o
00P0000Loooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol0050co`0600009?ooo`00Sooo
o`030000<ol0<ol0014co`000ol0VC?o03?o001;<ol01@0002[oool008ooool00`0003?o03?o000A
<ol000?o09Tco`0co`00AS?o00D0000_oooo002?oooo0P00018co`000ol0VC?o03?o0011<ol01@00
03Coool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`00?C?o00@0000ioooo002?oooo00<0
000co`0co`004C?o0003o`2I<ol0<ol003/co`020000?Oooo`00Soooo`030000<ol0<ol0014co`00
0ol0VC?o03?o000h<ol00`0003ooool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`00=S?o
00800012oooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol003@co`020000A?ooo`00Sooo
o`80000B<ol000?o09Tco`0co`00<S?o00800016oooo002?oooo00<0000co`0co`004C?o0003o`2I
<ol0<ol0030co`020000B?ooo`00Soooo`030000<ol0<ol0014co`000ol0VC?o03?o000_<ol000<0
003oooooool0B?ooo`00Soooo`030000<ol0<ol0014co`000ol0VC?o03?o000]<ol00P0004_oool0
08ooool00`0003?o03?o000A<ol000?o09Tco`0co`00:c?o0080001=oooo002?oooo00<0000co`0c
o`004C?o0003o`2I<ol0<ol002Xco`000`000?ooooooo`1=oooo002?oooo0P00018co`000ol0VC?o
03?o000X<ol00P00053oool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`009S?o0080001B
oooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol002Dco`000`000?ooooooo`1Boooo002?
oooo00<0000co`0co`004C?o0003o`2I<ol0<ol002@co`000`000?ooooooo`1Coooo002?oooo00<0
000co`0co`004C?o0003o`2I<ol0<ol0028co`020000E_ooo`00Soooo`030000<ol0<ol0014co`00
0ol0VC?o03?o000Q<ol000<0003oooooool0E_ooo`00Soooo`80000B<ol000?o09Tco`0co`0083?o
00030000oooooooo05Ooool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`007c?o00030000
oooooooo05Soool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`007S?o00030000oooooooo
05Woool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`007C?o00030000oooooooo05[oool0
08ooool00`0003?o03?o000A<ol000?o09Tco`0co`007C?o00030000oooooooo05[oool008Ooool5
00000oooo`030000<ol0<ol0014co`000ol0VC?o03?o000L<ol000<0003oooooool0Foooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000A<ol000?o09Tco`0co`006c?o00030000oooooooo
05coool008Woool00`000?ooooooo`03oooo0`00014co`000ol0VC?o03?o000J<ol000<0003ooooo
ool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000A<ol000?o09Tco`0co`006S?o
00030000oooooooo05goool008Woool00`000?ooooooo`03oooo00<0000co`0co`004C?o0003o`2I
<ol0<ol001Tco`000`000?ooooooo`1Noooo0028oooo0P0000Goool00`0003?o03?o000A<ol000?o
09Tco`0co`0063?o00030000oooooooo05ooool008ooool00`0003?o03?o000A<ol000?o09Tco`0c
o`005c?o00030000oooooooo063oool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`005c?o
00030000oooooooo063oool008ooool200004S?o0003o`2I<ol0<ol001Hco`000`000?ooooooo`1Q
oooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`1Roooo002?
oooo00<0000co`0co`004C?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`1Roooo002?oooo00<0
000co`0co`004C?o0003o`2I<ol0<ol001@co`000`000?ooooooo`1Soooo002?oooo00<0000co`0c
o`004C?o0003o`2I<ol0<ol001<co`000`000?ooooooo`1Toooo002?oooo00<0000co`0co`004C?o
0003o`2I<ol0<ol0018co`000`000?ooooooo`1Uoooo002?oooo0P00018co`000ol0VC?o03?o000B
<ol000<0003oooooool0IOooo`00Soooo`030000<ol0<ol0014co`000ol0VC?o03?o000A<ol000<0
003oooooool0I_ooo`00Soooo`030000<ol0<ol0014co`000ol0VC?o03?o000@<ol000<0003ooooo
ool0Ioooo`00Soooo`030000<ol0<ol0014co`000ol0VC?o03?o000@<ol000<0003oooooool0Iooo
o`00Soooo`030000<ol0<ol0014co`000ol0VC?o03?o000?<ol000<0003oooooool0J?ooo`00Sooo
o`030000<ol0<ol0014co`000ol0VC?o03?o000?<ol000<0003oooooool0J?ooo`00Soooo`030000
<ol0<ol0014co`000ol0VC?o03?o000><ol000<0003oooooool0JOooo`00Soooo`80000B<ol000?o
09Tco`0co`003S?o00030000oooooooo06Woool008ooool00`0003?o03?o000A<ol000?o09Tco`0c
o`003C?o00030000oooooooo06[oool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`003C?o
00030000oooooooo06[oool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`0033?o00030000
oooooooo06_oool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`0033?o00030000oooooooo
06_oool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`0033?o00030000oooooooo06_oool0
08ooool200004S?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1/oooo002?oooo00<0000co`0c
o`004C?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`004C?o
0003o`2I<ol0<ol000Xco`000`000?ooooooo`1]oooo002?oooo00<0000co`0co`004C?o0003o`2I
<ol0<ol000Xco`000`000?ooooooo`1]oooo0027oooo100000Coool00`0003?o03?o000A<ol000?o
09Tco`0co`002S?o00030000oooooooo06goool008Ooool00`000?ooooooo`05oooo00<0000co`0c
o`004C?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1^oooo0028oooo00<0003oooooool01?oo
o`<0000A<ol000?o09Tco`0co`002C?o00030000oooooooo06koool008Woool00`000?ooooooo`03
oooo00<0000co`0co`004C?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1^oooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`004C?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1_
oooo0028oooo0P0000Goool00`0003?o03?o000A<ol000?o09Tco`0co`0023?o00030000oooooooo
06ooool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`001c?o00030000oooooooo073oool0
08ooool00`0003?o03?o000A<ol000?o09Tco`0co`001c?o00030000oooooooo073oool008ooool2
00004S?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`004C?o
0003o`2I<ol0<ol000Hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`004C?o0003o`2I
<ol0<ol000Hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol0
00Hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol000Hco`00
0`000?ooooooo`1aoooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol000Dco`000`000?oo
ooooo`1boooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1b
oooo002?oooo0P00018co`000ol0VC?o03?o0005<ol000<0003oooooool0L_ooo`00Soooo`030000
<ol0<ol0014co`000ol0VC?o03?o0004<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0
014co`000ol0VC?o03?o0004<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0014co`00
0ol0VC?o03?o0004<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0014co`000ol0VC?o
03?o0003<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol0014co`000ol0VC?o03?o0003
<ol000<0003oooooool0M?ooo`00Soooo`80000B<ol000?o09Tco`0co`000c?o00030000oooooooo
07Coool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`000c?o00030000oooooooo07Coool0
08ooool00`0003?o03?o000A<ol000?o09Tco`0co`000S?o00030000oooooooo07Goool008ooool0
0`0003?o03?o000A<ol000?o09Tco`0co`000S?o00030000oooooooo07Goool008ooool00`0003?o
03?o000A<ol000?o09Tco`0co`000S?o00030000oooooooo07Goool008ooool00`0003?o03?o000A
<ol000Go09Tco`0co`0co`000000N?ooo`00Soooo`80000B<ol000Go09Tco`0co`0co`000000N?oo
o`00Soooo`030000<ol0<ol0014co`001Ol0VC?o03?o03?o0000001hoooo002?oooo00<0000co`0c
o`004C?o0005o`2I<ol0<ol0<ol0000007Soool008ooool00`0003?o03?o000A<ol000Co09Tco`0c
o`00001ioooo0028oooo0P0000Goool00`0003?o03?o000A<ol000Co09Tco`0co`00001ioooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`004C?o0004o`2I<ol0<ol00000NOooo`00ROoo
o`030000oooooooo00?oool300004C?o0003o`2I<ol0000007[oool008[oool00`000?ooooooo`02
oooo00<0000co`0co`004C?o0003o`2I<ol0000007[oool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o000A<ol000?o09Tco`000000N_ooo`00R?ooo`800005oooo00<0000co`0co`004C?o
0003o`2I0000oooo07[oool008ooool00`0003?o03?o000A<ol000?o09T0003oool0N_ooo`00Sooo
o`030000<ol0<ol0014co`000ol0V@000?ooo`1joooo002?oooo00<0000co`0co`004C?o0003o`2I
0000oooo07[oool008ooool200004S?o0003o`2Ioooooooo07[oool008ooool00`0003?o03?o000A
<ol000?o09Woooooool0N_ooo`00Soooo`030000<ol0<ol0014co`000ol0VOooooooo`1joooo002?
oooo00<0000co`0co`004C?o0003o`2Ioooooooo07[oool008ooool00`0003?o03?o000@<ol000<0
003o09Woool0Noooo`00Soooo`030000<ol0<ol0010co`000`000?l0VOooo`1koooo002?oooo0P00
014co`000`000?l0VOooo`1koooo002?oooo00<0000co`0co`0043?o00030000o`2Ioooo07_oool0
08ooool00`0003?o03?o000?<ol000<0003ooooo09T0O?ooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooool0V@1loooo002?oooo00<0000co`0co`003c?o00030000ooooo`2I07coool008ooool0
0`0003?o03?o000?<ol000<0003ooooo09T0O?ooo`00Soooo`80000@<ol000<0003ooooo09T0O?oo
o`00Soooo`030000<ol0<ol000hco`0010000?ooooooool0VGcoool008ooool00`0003?o03?o000>
<ol000@0003ooooooooo09Uloooo002?oooo00<0000co`0co`003S?o00040000ooooooooo`2IO?oo
o`00Soooo`030000<ol0<ol000hco`0010000?ooooooool0VGcoool008ooool00`0003?o03?o000>
<ol000@0003ooooooooo09Uloooo002?oooo0P0000hco`001@000?ooooooooooool0V@1loooo002?
oooo00<0000co`0co`003C?o00050000ooooooooooooo`2I07coool008ooool00`0003?o03?o000=
<ol000D0003ooooooooooooo09T0O?ooo`00Soooo`030000<ol0<ol000dco`001@000?oooooooooo
ool0V@1loooo002?oooo00<0000co`0co`0033?o00030000oooooooo00;oool00ol0VOooooooo`1j
oooo0029oooo0`0000?oool00`0003?o03?o000<<ol000<0003oooooool00_ooo`03o`2Ioooooooo
07[oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0033?o00030000oooooooo00;oool0
0ol0VOooooooo`1joooo0027oooo1@0000?oool3000033?o00030000oooooooo00;oool00ol0VOoo
ooooo`1joooo0027oooo00@0003oooooool00004oooo3c?o08;oool008Soool00`000?ooo`000004
oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o08;oool008ooool?<ol0P_oo
o`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o00800003<ol01@0000?oool0
0`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002S?o00030000<ol0<ol0
00?oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0003oooooool0000:<ol000<0000co`0co`000oooo`030000oooooooo
00?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`00
00Xco`000`0003?o03?o0004oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Xco`001@0003?o0?ooooooo`000002oooo00D0003ooooo
ooooool00000N_ooo`00NOooo`030000oooooooo017oool200002S?o008000000c?o0?ooooooo`04
00000_ooo`030000oooooooo07Woool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.56817 .12361 L
.57861 .12361 L
.58157 .12361 L
.58302 .12361 L
.58436 .12361 L
.58558 .12361 L
s
.58558 .12361 m
.58609 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40134 .12361 L
.40616 .12361 L
.40882 .12361 L
.41134 .12361 L
.41276 .12361 L
.41357 .12361 L
.41432 .12359 L
.41563 .12291 L
.41703 .12219 L
.42237 .11952 L
.46395 .10155 L
.50401 .08843 L
.54257 .078 L
.56211 .07318 L
.57247 .07074 L
.57817 .06944 L
.58097 .06881 L
.58221 .06853 L
.58357 .06823 L
.58485 .06795 L
.58605 .12361 L
.58732 .12361 L
.58868 .12361 L
.59425 .12361 L
.60399 .12361 L
.62306 .12361 L
.6642 .12361 L
.70382 .12361 L
.74193 .12361 L
.78249 .12361 L
.82153 .12361 L
.86303 .12361 L
.90301 .12361 L
.94148 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool04_oo
o`0306Kooooooooo07Woool008ooool00`000?ooooooo`0?oooo101Vog_oool008ooool200003?oo
o`@0I_l3oooo00<0I_ooooooool0NOooo`005oooo`D0000coooo0P0000Coool200001?ooo`80000b
oooo00<0003oooooool01_ooo`D0I_l7oooo00<0I_ooooooool07Oooo`800004oooo0P0000Coool2
0000=?ooo`D0000Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000
oooooooo0000<Oooo`040000oooooooooooo1@1Vo`coool00`1Vooooooooo`0Loooo00@0003ooooo
ool00008oooo00@0003oooooool0000eoooo00<0003oooooool05Oooo`006Oooo`030000oooooooo
03;oool010000?ooooooo`0000_oool00`000?ooooooo`0_oooo00@00000I_l0I_l0I_lAoooo00<0
I_ooooooool07?ooo`040000oooooooo00002oooo`030000oooooooo03?oool00`000?ooooooo`0E
oooo000Aoooo100000Coool00`000?ooooooo`0/oooo100000;oool010000?ooooooo`0000Woool2
0000<?ooo`80I_l00`000?ooooooo`0Boooo00<0I_ooooooool07?ooo`040000oooooooo00002Ooo
o`80000foooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`00
00Woool00`000?ooooooo`0/oooo0`1Vo`;oool00`000?ooooooo`0Boooo00<0I_ooooooool07?oo
o`040000oooooooo00002Oooo`030000oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P00
03Goool200002_ooo`<0000Zoooo0P1Vo`Goool200005?ooo`0306Kooooooooo01coool200002_oo
o`<0000doooo0P0001Ooool008Goool306Ko1oooo`030000oooooooo01?oool00`1Vooooooooo`1h
oooo0022oooo0`1Vo`[oool00`000?ooooooo`0Coooo00<0I_ooooooool0N?ooo`00P?ooo`80I_l=
oooo00<0003oooooool04oooo`0306Kooooooooo07Soool007goool306Ko3oooo`030000oooooooo
01?oool00`1Vooooooooo`1hoooo001koooo0P1Voa;oool00`000?ooooooo`0Coooo00<0I_oooooo
ool0N?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0007<ol000?o09Tco`0000002c?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000C<ol000?o
09Tco`0co`008c?o00030000<ol0<ol003Hco`0500005oooo`00Soooo`030000<ol0<ol001<co`00
0ol0VC?o03?o001D<ol0200001coool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`00CS?o
00H0000Toooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol004Tco`050000:_ooo`00Sooo
o`030000<ol0<ol001<co`000ol0VC?o03?o0014<ol01@0002ooool008ooool2000053?o0003o`2I
<ol0<ol003lco`050000=?ooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o000k<ol01000
03Woool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`00>C?o0080000moooo002?oooo00<0
000co`0co`004c?o0003o`2I<ol0<ol003Hco`030000?oooo`00Soooo`030000<ol0<ol001<co`00
0ol0VC?o03?o000d<ol00P0004;oool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`00<S?o
00800014oooo002?oooo0P0001@co`000ol0VC?o03?o000`<ol00P0004Koool008ooool00`0003?o
03?o000C<ol000?o09Tco`0co`00;S?o00800018oooo002?oooo00<0000co`0co`004c?o0003o`2I
<ol0<ol002dco`000`000?ooooooo`18oooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0
02/co`020000Boooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o000Y<ol00P0004goool0
08ooool00`0003?o03?o000C<ol000?o09Tco`0co`00:3?o00030000oooooooo04goool008ooool2
000053?o0003o`2I<ol0<ol002Hco`020000D?ooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o
03?o000T<ol00P0005;oool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`008c?o00030000
oooooooo05;oool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`008S?o00030000oooooooo
05?oool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`0083?o0080001Foooo002?oooo00<0
000co`0co`004c?o0003o`2I<ol0<ol001lco`000`000?ooooooo`1Foooo002?oooo0P0001@co`00
0ol0VC?o03?o000N<ol000<0003oooooool0Eoooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o
03?o000M<ol000<0003oooooool0F?ooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o000L
<ol000<0003oooooool0FOooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o000K<ol000<0
003oooooool0F_ooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o000K<ol000<0003ooooo
ool0F_ooo`00Qoooo`D00003oooo00<0000co`0co`004c?o0003o`2I<ol0<ol001Xco`000`000?oo
ooooo`1Koooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001<co`000ol0VC?o03?o000I
<ol000<0003oooooool0G?ooo`00ROooo`030000oooooooo00?oool300004c?o0003o`2I<ol0<ol0
01Pco`000`000?ooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001<co`00
0ol0VC?o03?o000H<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000C<ol000?o09Tco`0co`005c?o00030000oooooooo05koool008Soool200001Oooo`030000
<ol0<ol001<co`000ol0VC?o03?o000F<ol000<0003oooooool0Goooo`00Soooo`030000<ol0<ol0
01<co`000ol0VC?o03?o000E<ol000<0003oooooool0H?ooo`00Soooo`030000<ol0<ol001<co`00
0ol0VC?o03?o000E<ol000<0003oooooool0H?ooo`00Soooo`80000D<ol000?o09Tco`0co`0053?o
00030000oooooooo067oool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`004c?o00030000
oooooooo06;oool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`004c?o00030000oooooooo
06;oool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`004S?o00030000oooooooo06?oool0
08ooool00`0003?o03?o000C<ol000?o09Tco`0co`004C?o00030000oooooooo06Coool008ooool0
0`0003?o03?o000C<ol000?o09Tco`0co`0043?o00030000oooooooo06Goool008ooool2000053?o
0003o`2I<ol0<ol0010co`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`004c?o0003o`2I
<ol0<ol000lco`000`000?ooooooo`1Voooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0
00hco`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol000hco`00
0`000?ooooooo`1Woooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol000dco`000`000?oo
ooooo`1Xoooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1X
oooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1Yoooo002?
oooo0P0001@co`000ol0VC?o03?o000<<ol000<0003oooooool0JOooo`00Soooo`030000<ol0<ol0
01<co`000ol0VC?o03?o000;<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol001<co`00
0ol0VC?o03?o000;<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o
03?o000:<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o000:
<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o000:<ol000<0
003oooooool0Joooo`00Soooo`80000D<ol000?o09Tco`0co`002C?o00030000oooooooo06coool0
08ooool00`0003?o03?o000C<ol000?o09Tco`0co`002C?o00030000oooooooo06coool008ooool0
0`0003?o03?o000C<ol000?o09Tco`0co`0023?o00030000oooooooo06goool008ooool00`0003?o
03?o000C<ol000?o09Tco`0co`0023?o00030000oooooooo06goool008Ooool400001?ooo`030000
<ol0<ol001<co`000ol0VC?o03?o0008<ol000<0003oooooool0KOooo`00Qoooo`030000oooooooo
00Goool00`0003?o03?o000C<ol000?o09Tco`0co`001c?o00030000oooooooo06koool008Soool0
0`000?ooooooo`04oooo0`0001<co`000ol0VC?o03?o0007<ol000<0003oooooool0K_ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000C<ol000?o09Tco`0co`001c?o00030000oooooooo
06koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000C<ol000?o09Tco`0co`001S?o
00030000oooooooo06ooool008Soool200001Oooo`030000<ol0<ol001<co`000ol0VC?o03?o0006
<ol000<0003oooooool0Koooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o0005<ol000<0
003oooooool0L?ooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o0005<ol000<0003ooooo
ool0L?ooo`00Soooo`80000D<ol000?o09Tco`0co`001C?o00030000oooooooo073oool008ooool0
0`0003?o03?o000C<ol000?o09Tco`0co`0013?o00030000oooooooo077oool008ooool00`0003?o
03?o000C<ol000?o09Tco`0co`0013?o00030000oooooooo077oool008ooool00`0003?o03?o000C
<ol000?o09Tco`0co`0013?o00030000oooooooo077oool008ooool00`0003?o03?o000C<ol000?o
09Tco`0co`0013?o00030000oooooooo077oool008ooool00`0003?o03?o000C<ol000?o09Tco`0c
o`000c?o00030000oooooooo07;oool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`000c?o
00030000oooooooo07;oool008ooool2000053?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1b
oooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1coooo002?
oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1coooo002?oooo00<0
000co`0co`004c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1coooo002?oooo00<0000co`0c
o`004c?o0005o`2I<ol0<ol0<ol0000007Koool008ooool00`0003?o03?o000C<ol000Go09Tco`0c
o`0co`000000M_ooo`00Soooo`80000D<ol000Go09Tco`0co`0co`000000M_ooo`00Soooo`030000
<ol0<ol001<co`001Ol0VC?o03?o03?o0000001foooo002?oooo00<0000co`0co`004c?o0004o`2I
<ol0<ol00000Moooo`00Soooo`030000<ol0<ol001<co`001?l0VC?o03?o000007Ooool008ooool0
0`0003?o03?o000C<ol000Co09Tco`0co`00001goooo002?oooo00<0000co`0co`004c?o0003o`2I
<ol0000007Soool008ooool2000053?o0003o`2I<ol0000007Soool008ooool00`0003?o03?o000C
<ol000?o09Tco`000000N?ooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o0000001hoooo002?
oooo00<0000co`0co`004c?o0003o`2I0000oooo07Soool008Soool200001Oooo`030000<ol0<ol0
01<co`000ol0V@000?ooo`1hoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`004c?o
0003o`2I0000oooo07Soool008Woool00`000?ooooooo`03oooo0`0001<co`000ol0VOooooooo`1h
oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol001<co`000ol0VOooooooo`1hoooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`004c?o0003o`2Ioooooooo07Soool008Soool2
00001Oooo`030000<ol0<ol0018co`000`000?l0VOooo`1ioooo002?oooo00<0000co`0co`004S?o
00030000o`2Ioooo07Woool008ooool00`0003?o03?o000B<ol000<0003o09Woool0NOooo`00Sooo
o`030000<ol0<ol0018co`000`000?l0VOooo`1ioooo002?oooo0P00018co`000`000?ooool0V@1j
oooo002?oooo00<0000co`0co`004C?o00030000ooooo`2I07[oool008ooool00`0003?o03?o000A
<ol000<0003ooooo09T0N_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooool0V@1joooo002?
oooo00<0000co`0co`0043?o00040000ooooooooo`2IN_ooo`00Soooo`030000<ol0<ol0010co`00
10000?ooooooool0VG[oool008ooool200004C?o00040000ooooooooo`2IN_ooo`00Soooo`030000
<ol0<ol0010co`0010000?ooooooool0VG[oool008ooool00`0003?o03?o000?<ol000D0003ooooo
oooooooo09T0N_ooo`00Soooo`030000<ol0<ol000lco`001@000?ooooooooooool0V@1joooo002?
oooo00<0000co`0co`003c?o00050000ooooooooooooo`2I07[oool008ooool00`0003?o03?o000?
<ol000D0003ooooooooooooo09T0N_ooo`00Soooo`80000@<ol000D0003ooooooooooooo09T0N_oo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`02oooo00?o09Woooooool0N?ooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`02oooo00?o09Woooooool0N?ooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`02oooo00?o09Woooooool0N?ooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`02oooo00?o09Woooooool0N?ooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`02oooo00?o09Woooooool0N?ooo`00Soooo`80000><ol000<0003oooooool00ooo
o`03o`2Ioooooooo07Soool008ooool00`0003?o03?o000=<ol000<0003oooooool00oooo`03o`2I
oooooooo07Soool008ooool00`0003?o03?o000=<ol000<0003oooooool00oooo`03o`2Ioooooooo
07Soool008ooool00`0003?o03?o000=<ol000<0003oooooool00oooo`03o`2Ioooooooo07Soool0
08ooool00`0003?o03?o000<<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Soool008Woool3
00000oooo`030000<ol0<ol000`co`000`000?ooooooo`04oooo00?o09Woooooool0N?ooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o000<<ol000<0003oooooool01?ooo`03o`2Ioooooooo
07Soool008Ooool500000oooo`<0000<<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Soool0
08Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_oo
o`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0
003oooooool04oooo`hco`07oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`09oooo3S?o00Soool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01oooo`800004<ol00P0000<co`0500000_ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00002S?o00050000<ol0<ol0oooo000000;oool01@000?oo
ooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000Xco`001@0003?o03?o0?ooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002S?o00030000<ol0<ol0
00;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool0000:<ol000D0000co`3oooooool000000_ooo`050000oooooooooooo000007[oool0
07Woool00`000?ooooooo`0Aoooo0P0000Xco`02000000@co`3oooooooooool200000oooo`030000
oooooooo07Woool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.57861 .12361 L
.58392 .12361 L
.58683 .12361 L
.58826 .12361 L
.58957 .12361 L
s
.58957 .12361 m
.59007 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.39174 .12361 L
.40134 .12361 L
.40616 .12361 L
.40755 .12361 L
.40887 .12361 L
.41005 .12333 L
.41134 .12267 L
.42237 .1172 L
.46301 .10013 L
.50214 .08763 L
.54372 .07671 L
.56459 .07171 L
.57374 .06962 L
.57859 .06853 L
.58379 .06739 L
.58639 .06683 L
.58768 .06655 L
.58886 .0663 L
.58993 .06607 L
.59108 .12361 L
.59222 .12361 L
.59348 .12361 L
.60254 .12361 L
.62234 .12361 L
.66254 .12361 L
.70123 .12361 L
.74237 .12361 L
.78199 .12361 L
.8201 .12361 L
.86066 .12361 L
.89971 .12361 L
.94121 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool04Ooo
o`@0I_mioooo002?oooo00<0003oooooool03?ooo`D0I_l3oooo00<0I_ooooooool0Moooo`00Sooo
o`80000;oooo0P1Vo`Soool00`1Vooooooooo`1goooo000Goooo1@0003?oool200001?ooo`800004
oooo0P0003;oool00`000?ooooooo`06oooo101Vo`[oool00`1Vooooooooo`0Koooo0P0000Coool2
00001?ooo`80000doooo1@0001Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00008
oooo00@0003oooooool0000aoooo00@0003oooooooooool506Ko3_ooo`0306Kooooooooo01[oool0
10000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?ooooooo`0Eoooo000Ioooo00<0
003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo02ooool01000001Vo`1Vo`1V
oa?oool00`1Vooooooooo`0Joooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000_oooo0`1Vo`030000oooooooo01Coool00`1Vooooooooo`0Joooo00@0003ooooo
ool00009oooo0P0003Koool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000
oooooooo00002Oooo`030000oooooooo02[oool406Ko0oooo`030000oooooooo01Coool00`1Voooo
ooooo`0Joooo00@0003oooooool00009oooo00<0003oooooool0=Oooo`030000oooooooo01Goool0
01Soool20000=Oooo`80000:oooo0`0002Ooool306Ko1oooo`80000Eoooo00<0I_ooooooool06ooo
o`80000:oooo0`0003Coool200005oooo`00Poooo`80I_l:oooo00<0003oooooool05?ooo`0306Ko
oooooooo07Ooool0087oool206Ko3?ooo`030000oooooooo01Coool00`1Vooooooooo`1goooo001o
oooo0P1Vo`koool00`000?ooooooo`0Doooo00<0I_ooooooool0Moooo`00OOooo`80I_l@oooo00<0
003oooooool05?ooo`0306Kooooooooo07Ooool007[oool306Ko4_ooo`030000oooooooo01Coool0
0`1Vooooooooo`1goooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Pco`000ol0V@0003?o000:
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Xco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
01@co`000ol0VC?o03?o000R<ol000<0000co`0co`00=S?o00D0000Goooo002?oooo00<0000co`0c
o`0053?o0003o`2I<ol0<ol005<co`0800007?ooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o
03?o001=<ol01P0002Coool008ooool00`0003?o03?o000D<ol000?o09Tco`0co`00B3?o00D0000Z
oooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol004<co`050000;oooo`00Soooo`80000E
<ol000?o09Tco`0co`00?S?o00D0000doooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol0
03Xco`040000>Oooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000h<ol00P0003goool0
08ooool00`0003?o03?o000D<ol000?o09Tco`0co`00=C?o00<0000ooooo002?oooo00<0000co`0c
o`0053?o0003o`2I<ol0<ol003<co`020000@_ooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o
03?o000a<ol00P0004Coool008ooool200005C?o0003o`2I<ol0<ol002lco`020000A_ooo`00Sooo
o`030000<ol0<ol001@co`000ol0VC?o03?o000]<ol00P0004Soool008ooool00`0003?o03?o000D
<ol000?o09Tco`0co`00;3?o00030000oooooooo04Soool008ooool00`0003?o03?o000D<ol000?o
09Tco`0co`00:S?o0080001;oooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol002Pco`02
0000COooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000W<ol000<0003oooooool0COoo
o`00Soooo`80000E<ol000?o09Tco`0co`009C?o0080001@oooo002?oooo00<0000co`0co`0053?o
0003o`2I<ol0<ol002<co`020000D_ooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000R
<ol000<0003oooooool0D_ooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000Q<ol000<0
003oooooool0Doooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000O<ol00P0005Koool0
08ooool00`0003?o03?o000D<ol000?o09Tco`0co`007S?o00030000oooooooo05Koool008ooool2
00005C?o0003o`2I<ol0<ol001dco`000`000?ooooooo`1Goooo002?oooo00<0000co`0co`0053?o
0003o`2I<ol0<ol001`co`000`000?ooooooo`1Hoooo002?oooo00<0000co`0co`0053?o0003o`2I
<ol0<ol001/co`000`000?ooooooo`1Ioooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol0
01Xco`000`000?ooooooo`1Joooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol001Xco`00
0`000?ooooooo`1Joooo0027oooo1@0000?oool00`0003?o03?o000D<ol000?o09Tco`0co`006C?o
00030000oooooooo05_oool008Woool00`000?ooooooo`03oooo00<0000co`0co`0053?o0003o`2I
<ol0<ol001Pco`000`000?ooooooo`1Loooo0029oooo00<0003oooooool00oooo`<0000D<ol000?o
09Tco`0co`005c?o00030000oooooooo05goool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`0053?o0003o`2I<ol0<ol001Lco`000`000?ooooooo`1Moooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol001@co`000ol0VC?o03?o000F<ol000<0003oooooool0G_ooo`00R?ooo`800005
oooo00<0000co`0co`0053?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`1Ooooo002?oooo00<0
000co`0co`0053?o0003o`2I<ol0<ol001@co`000`000?ooooooo`1Poooo002?oooo00<0000co`0c
o`0053?o0003o`2I<ol0<ol001@co`000`000?ooooooo`1Poooo002?oooo0P0001Dco`000ol0VC?o
03?o000C<ol000<0003oooooool0HOooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000B
<ol000<0003oooooool0H_ooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000B<ol000<0
003oooooool0H_ooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000A<ol000<0003ooooo
ool0Hoooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000@<ol000<0003oooooool0I?oo
o`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000?<ol000<0003oooooool0IOooo`00Sooo
o`80000E<ol000?o09Tco`0co`003c?o00030000oooooooo06Goool008ooool00`0003?o03?o000D
<ol000?o09Tco`0co`003S?o00030000oooooooo06Koool008ooool00`0003?o03?o000D<ol000?o
09Tco`0co`003C?o00030000oooooooo06Ooool008ooool00`0003?o03?o000D<ol000?o09Tco`0c
o`003C?o00030000oooooooo06Ooool008ooool00`0003?o03?o000D<ol000?o09Tco`0co`0033?o
00030000oooooooo06Soool008ooool00`0003?o03?o000D<ol000?o09Tco`0co`0033?o00030000
oooooooo06Soool008ooool00`0003?o03?o000D<ol000?o09Tco`0co`002c?o00030000oooooooo
06Woool008ooool200005C?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1Yoooo002?oooo00<0
000co`0co`0053?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1Zoooo002?oooo00<0000co`0c
o`0053?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1Zoooo002?oooo00<0000co`0co`0053?o
0003o`2I<ol0<ol000Tco`000`000?ooooooo`1[oooo002?oooo00<0000co`0co`0053?o0003o`2I
<ol0<ol000Tco`000`000?ooooooo`1[oooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol0
00Tco`000`000?ooooooo`1[oooo002?oooo0P0001Dco`000ol0VC?o03?o0008<ol000<0003ooooo
ool0K?ooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o0008<ol000<0003oooooool0K?oo
o`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o0007<ol000<0003oooooool0KOooo`00Sooo
o`030000<ol0<ol001@co`000ol0VC?o03?o0007<ol000<0003oooooool0KOooo`00Qoooo`@00004
oooo00<0000co`0co`0053?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1]oooo0027oooo00<0
003oooooool01Oooo`030000<ol0<ol001@co`000ol0VC?o03?o0006<ol000<0003oooooool0K_oo
o`00R?ooo`030000oooooooo00Coool3000053?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1^
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001@co`000ol0VC?o03?o0006<ol000<0
003oooooool0K_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001@co`000ol0VC?o
03?o0005<ol000<0003oooooool0Koooo`00R?ooo`800005oooo00<0000co`0co`0053?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`1_oooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol0
00@co`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`1`oooo002?oooo0P0001Dco`000ol0VC?o03?o0004<ol000<0003oooooool0L?oo
o`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o0003<ol000<0003oooooool0LOooo`00Sooo
o`030000<ol0<ol001@co`000ol0VC?o03?o0003<ol000<0003oooooool0LOooo`00Soooo`030000
<ol0<ol001@co`000ol0VC?o03?o0003<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol0
01@co`000ol0VC?o03?o0003<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol001@co`00
0ol0VC?o03?o0002<ol000<0003oooooool0L_ooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o
03?o0002<ol000<0003oooooool0L_ooo`00Soooo`80000E<ol000?o09Tco`0co`000S?o00030000
oooooooo07;oool008ooool00`0003?o03?o000D<ol000Go09Tco`0co`0co`000000MOooo`00Sooo
o`030000<ol0<ol001@co`001Ol0VC?o03?o03?o0000001eoooo002?oooo00<0000co`0co`0053?o
0005o`2I<ol0<ol0<ol0000007Goool008ooool00`0003?o03?o000D<ol000Co09Tco`0co`00001f
oooo002?oooo00<0000co`0co`0053?o0004o`2I<ol0<ol00000M_ooo`00Soooo`80000E<ol000Co
09Tco`0co`00001foooo002?oooo00<0000co`0co`0053?o0004o`2I<ol0<ol00000M_ooo`00Sooo
o`030000<ol0<ol001@co`000ol0VC?o0000001goooo002?oooo00<0000co`0co`0053?o0003o`2I
<ol0000007Ooool008ooool00`0003?o03?o000D<ol000?o09Tco`000000Moooo`00Soooo`030000
<ol0<ol001@co`000ol0V@000?ooo`1goooo002?oooo0P0001Dco`000ol0V@000?ooo`1goooo002?
oooo00<0000co`0co`0053?o0003o`2I0000oooo07Ooool008ooool00`0003?o03?o000D<ol000?o
09T0003oool0Moooo`00Soooo`030000<ol0<ol001@co`000ol0VOooooooo`1goooo0028oooo0P00
00Goool00`0003?o03?o000D<ol000?o09Woooooool0Moooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol001@co`000ol0VOooooooo`1goooo0029oooo00<0003oooooool00oooo`<0000C
<ol000<0003o09Woool0N?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000C<ol000<0
003o09Woool0N?ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001<co`000`000?l0
VOooo`1hoooo0028oooo0P0000Goool00`0003?o03?o000B<ol000<0003ooooo09T0NOooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooool0V@1ioooo002?oooo00<0000co`0co`004S?o00030000
ooooo`2I07Woool008ooool00`0003?o03?o000B<ol000<0003ooooo09T0NOooo`00Soooo`80000B
<ol000@0003ooooooooo09Uioooo002?oooo00<0000co`0co`004C?o00040000ooooooooo`2INOoo
o`00Soooo`030000<ol0<ol0014co`0010000?ooooooool0VGWoool008ooool00`0003?o03?o000A
<ol000@0003ooooooooo09Uioooo002?oooo00<0000co`0co`0043?o00050000ooooooooooooo`2I
07Woool008ooool00`0003?o03?o000@<ol000D0003ooooooooooooo09T0NOooo`00Soooo`80000A
<ol000D0003ooooooooooooo09T0NOooo`00Soooo`030000<ol0<ol0010co`001@000?oooooooooo
ool0V@1ioooo002?oooo00<0000co`0co`003c?o00030000oooooooo00;oool00ol0VOooooooo`1g
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo00;oool00ol0VOooooooo`1goooo002?
oooo00<0000co`0co`003c?o00030000oooooooo00;oool00ol0VOooooooo`1goooo002?oooo00<0
000co`0co`003c?o00030000oooooooo00;oool00ol0VOooooooo`1goooo002?oooo0P00010co`00
0`000?ooooooo`02oooo00?o09Woooooool0Moooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`03oooo00?o09Woooooool0Moooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`03
oooo00?o09Woooooool0Moooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`03oooo00?o
09Woooooool0Moooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`03oooo00?o09Wooooo
ool0Moooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`03oooo00?o09Woooooool0Mooo
o`00Soooo`80000><ol000<0003oooooool01?ooo`03o`2Ioooooooo07Ooool008ooool00`0003?o
03?o000=<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o000=
<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o000=<ol000<0
003oooooool01?ooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o000<<ol000<0003ooooo
ool01Oooo`03o`2Ioooooooo07Ooool008Woool300000oooo`030000<ol0<ol000`co`000`000?oo
ooooo`05oooo00?o09Woooooool0Moooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000<
<ol000<0003oooooool01Oooo`03o`2Ioooooooo07Ooool008Ooool500000oooo`<0000<<ol000<0
003oooooool01Oooo`03o`2Ioooooooo07Ooool008Ooool010000?ooooooo`0000Coool?<ol0P_oo
o`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?
<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07oooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o00Soool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004
<ol00P0000<co`05000000Coool0000000000004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002S?o00030000<ol0<ol000?oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000:<ol000<0000co`0c
o`000_ooo`<00004oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0
003oooooool0000:<ol000D0000co`0co`3oool000000_ooo`050000oooooooooooo000007[oool0
07Soool01@000?ooooooooooo`00000?oooo00@0003oooooool0000:<ol000D0000co`3oooooool0
00000_ooo`050000oooooooooooo000007[oool007Woool00`000?ooooooo`0Aoooo0P0000Xco`02
000000@co`3oooooooooool300000_ooo`030000oooooooo07Woool008ooool=<ol0Q?ooo`00Sooo
o`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.57861 .12361 L
.58392 .12361 L
.58957 .12361 L
.59232 .12361 L
.59367 .12361 L
.59491 .12361 L
s
.59491 .12361 m
.59536 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.39174 .12361 L
.39675 .12361 L
.40134 .12361 L
.40252 .12361 L
.40381 .12361 L
.40503 .12347 L
.40616 .12289 L
.41134 .12026 L
.42237 .11496 L
.4615 .09896 L
.50308 .08609 L
.54314 .07588 L
.56152 .07156 L
.57195 .06921 L
.58169 .06709 L
.58664 .06603 L
.59132 .06505 L
.59257 .06479 L
.5939 .06452 L
.5946 .06438 L
.59536 .12361 L
.59606 .12361 L
.59671 .12361 L
.60163 .12361 L
.6227 .12361 L
.66139 .12361 L
.70253 .12361 L
.74215 .12361 L
.78026 .12361 L
.82082 .12361 L
.85986 .12361 L
.90136 .12361 L
.94134 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`0Doooo0P1VogSoool008ooool00`000?oo
ooooo`0Aoooo1@1VogSoool008ooool00`000?ooooooo`0;oooo1P1Vo`Coool00`1Vooooooooo`1f
oooo002?oooo0P0000Soool406Ko2_ooo`0306Kooooooooo07Koool001Ooool50000<oooo`800004
oooo0P0000Coool20000<_ooo`030000oooooooo00Coool306Ko3_ooo`0306Kooooooooo01[oool2
00001?ooo`800004oooo0P0003Coool500005Oooo`006Oooo`030000oooooooo03;oool010000?oo
ooooo`0000Soool010000?ooooooo`00037oool00`000?ooooooo`0406Ko4Oooo`0306Kooooooooo
01Woool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?ooooooo`0Eoooo000I
oooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo02ooool00`00001V
o`1Vo`0Eoooo00<0I_ooooooool06Oooo`040000oooooooo00002oooo`030000oooooooo03?oool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0/oooo100000;oool010000?oo
ooooo`0000Woool20000;_ooo`@0I_l00`000?ooooooo`0Eoooo00<0I_ooooooool06Oooo`040000
oooooooo00002Oooo`80000foooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool0
10000?ooooooo`0000Woool00`000?ooooooo`0Yoooo101Vo`Coool00`000?ooooooo`0Eoooo00<0
I_ooooooool06Oooo`040000oooooooo00002Oooo`030000oooooooo03Goool00`000?ooooooo`0E
oooo000Hoooo0P0003Goool200002_ooo`<0000Voooo0`1Vo`Soool200005_ooo`0306Kooooooooo
01[oool200002_ooo`<0000doooo0P0001Ooool008;oool206Ko2oooo`030000oooooooo01Goool0
0`1Vooooooooo`1foooo001ooooo0`1Vo`goool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_oo
o`00OOooo`80I_l@oooo00<0003oooooool05Oooo`0306Kooooooooo07Koool007_oool206Ko4_oo
o`030000oooooooo01Goool00`1Vooooooooo`1foooo001ioooo0P1VoaCoool00`000?ooooooo`0E
oooo00<0I_ooooooool0M_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o
03?o000E<ol000?o09Tco`0co`008C?o00030000<ol0<ol003Hco`0500005oooo`00Soooo`030000
<ol0<ol001Dco`000ol0VC?o03?o001B<ol0200001coool008ooool00`0003?o03?o000E<ol000?o
09Tco`0co`00C3?o00H0000Toooo002?oooo00<0000co`0co`005C?o0003o`2I<ol0<ol004Lco`05
0000:_ooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o03?o0012<ol01@0002ooool008ooool2
00005S?o0003o`2I<ol0<ol003dco`050000=?ooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o
03?o000i<ol0100003Woool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`00=c?o0080000m
oooo002?oooo00<0000co`0co`005C?o0003o`2I<ol0<ol003@co`030000?oooo`00Soooo`030000
<ol0<ol001Dco`000ol0VC?o03?o000b<ol00P0004;oool008ooool00`0003?o03?o000E<ol000?o
09Tco`0co`00<3?o00800014oooo002?oooo0P0001Hco`000ol0VC?o03?o000^<ol00P0004Koool0
08ooool00`0003?o03?o000E<ol000?o09Tco`0co`00;3?o00800018oooo002?oooo00<0000co`0c
o`005C?o0003o`2I<ol0<ol002/co`000`000?ooooooo`18oooo002?oooo00<0000co`0co`005C?o
0003o`2I<ol0<ol002Tco`020000Boooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o03?o000W
<ol00P0004goool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`009S?o00030000oooooooo
04goool008ooool200005S?o0003o`2I<ol0<ol002@co`020000D?ooo`00Soooo`030000<ol0<ol0
01Dco`000ol0VC?o03?o000R<ol00P0005;oool008ooool00`0003?o03?o000E<ol000?o09Tco`0c
o`008C?o00030000oooooooo05;oool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`0083?o
00030000oooooooo05?oool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`007S?o0080001F
oooo002?oooo00<0000co`0co`005C?o0003o`2I<ol0<ol001dco`000`000?ooooooo`1Foooo002?
oooo0P0001Hco`000ol0VC?o03?o000L<ol000<0003oooooool0Eoooo`00Soooo`030000<ol0<ol0
01Dco`000ol0VC?o03?o000K<ol000<0003oooooool0F?ooo`00Soooo`030000<ol0<ol001Dco`00
0ol0VC?o03?o000J<ol000<0003oooooool0FOooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o
03?o000I<ol000<0003oooooool0F_ooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o03?o000I
<ol000<0003oooooool0F_ooo`00Qoooo`D00003oooo00<0000co`0co`005C?o0003o`2I<ol0<ol0
01Pco`000`000?ooooooo`1Koooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0ol0VC?o03?o000G<ol000<0003oooooool0G?ooo`00ROooo`030000oooooooo00?oool300005C?o
0003o`2I<ol0<ol001Hco`000`000?ooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000ol0VC?o03?o000F<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000E<ol000?o09Tco`0co`005C?o00030000oooooooo05koool008Soool2
00001Oooo`030000<ol0<ol001Dco`000ol0VC?o03?o000D<ol000<0003oooooool0Goooo`00Sooo
o`030000<ol0<ol001Dco`000ol0VC?o03?o000C<ol000<0003oooooool0H?ooo`00Soooo`030000
<ol0<ol001Dco`000ol0VC?o03?o000C<ol000<0003oooooool0H?ooo`00Soooo`80000F<ol000?o
09Tco`0co`004S?o00030000oooooooo067oool008ooool00`0003?o03?o000E<ol000?o09Tco`0c
o`004C?o00030000oooooooo06;oool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`004C?o
00030000oooooooo06;oool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`0043?o00030000
oooooooo06?oool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`003c?o00030000oooooooo
06Coool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`003S?o00030000oooooooo06Goool0
08ooool200005S?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1Uoooo002?oooo00<0000co`0c
o`005C?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1Voooo002?oooo00<0000co`0co`005C?o
0003o`2I<ol0<ol000`co`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`005C?o0003o`2I
<ol0<ol000`co`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`005C?o0003o`2I<ol0<ol0
00/co`000`000?ooooooo`1Xoooo002?oooo00<0000co`0co`005C?o0003o`2I<ol0<ol000/co`00
0`000?ooooooo`1Xoooo002?oooo00<0000co`0co`005C?o0003o`2I<ol0<ol000Xco`000`000?oo
ooooo`1Yoooo002?oooo0P0001Hco`000ol0VC?o03?o000:<ol000<0003oooooool0JOooo`00Sooo
o`030000<ol0<ol001Dco`000ol0VC?o03?o0009<ol000<0003oooooool0J_ooo`00Soooo`030000
<ol0<ol001Dco`000ol0VC?o03?o0009<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol0
01Dco`000ol0VC?o03?o0008<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol001Dco`00
0ol0VC?o03?o0008<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o
03?o0008<ol000<0003oooooool0Joooo`00Soooo`80000F<ol000?o09Tco`0co`001c?o00030000
oooooooo06coool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`001c?o00030000oooooooo
06coool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`001S?o00030000oooooooo06goool0
08ooool00`0003?o03?o000E<ol000?o09Tco`0co`001S?o00030000oooooooo06goool008Ooool4
00001?ooo`030000<ol0<ol001Dco`000ol0VC?o03?o0006<ol000<0003oooooool0KOooo`00Qooo
o`030000oooooooo00Goool00`0003?o03?o000E<ol000?o09Tco`0co`001C?o00030000oooooooo
06koool008Soool00`000?ooooooo`04oooo0`0001Dco`000ol0VC?o03?o0005<ol000<0003ooooo
ool0K_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000?o09Tco`0co`001C?o
00030000oooooooo06koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000E<ol000?o
09Tco`0co`0013?o00030000oooooooo06ooool008Soool200001Oooo`030000<ol0<ol001Dco`00
0ol0VC?o03?o0004<ol000<0003oooooool0Koooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o
03?o0003<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o03?o0003
<ol000<0003oooooool0L?ooo`00Soooo`80000F<ol000?o09Tco`0co`000c?o00030000oooooooo
073oool008ooool00`0003?o03?o000E<ol000?o09Tco`0co`000S?o00030000oooooooo077oool0
08ooool00`0003?o03?o000E<ol000?o09Tco`0co`000S?o00030000oooooooo077oool008ooool0
0`0003?o03?o000E<ol000?o09Tco`0co`000S?o00030000oooooooo077oool008ooool00`0003?o
03?o000E<ol000?o09Tco`0co`000S?o00030000oooooooo077oool008ooool00`0003?o03?o000E
<ol000Go09Tco`0co`0co`000000M?ooo`00Soooo`030000<ol0<ol001Dco`001Ol0VC?o03?o03?o
0000001doooo002?oooo0P0001Hco`001Ol0VC?o03?o03?o0000001doooo002?oooo00<0000co`0c
o`005C?o0004o`2I<ol0<ol00000MOooo`00Soooo`030000<ol0<ol001Dco`001?l0VC?o03?o0000
07Goool008ooool00`0003?o03?o000E<ol000Co09Tco`0co`00001eoooo002?oooo00<0000co`0c
o`005C?o0003o`2I<ol0000007Koool008ooool00`0003?o03?o000E<ol000?o09Tco`000000M_oo
o`00Soooo`80000F<ol000?o09Tco`000000M_ooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o
0000001foooo002?oooo00<0000co`0co`005C?o0003o`2I0000oooo07Koool008ooool00`0003?o
03?o000E<ol000?o09T0003oool0M_ooo`00Soooo`030000<ol0<ol001Dco`000ol0V@000?ooo`1f
oooo002?oooo00<0000co`0co`005C?o0003o`2Ioooooooo07Koool008ooool200005S?o0003o`2I
oooooooo07Koool008ooool00`0003?o03?o000E<ol000?o09Woooooool0M_ooo`00Soooo`030000
<ol0<ol001Dco`000ol0VOooooooo`1foooo002?oooo00<0000co`0co`0053?o00030000o`2Ioooo
07Ooool008Soool200001Oooo`030000<ol0<ol001@co`000`000?l0VOooo`1goooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0053?o00030000o`2Ioooo07Ooool008Woool00`000?oo
ooooo`03oooo0`0001<co`000`000?ooool0V@1hoooo002:oooo00<0003oooooool00_ooo`030000
<ol0<ol001<co`000`000?ooool0V@1hoooo0027oooo00@0003oooooool00004oooo00<0000co`0c
o`004c?o00030000ooooo`2I07Soool008Soool200001Oooo`030000<ol0<ol0018co`0010000?oo
ooooool0VGSoool008ooool00`0003?o03?o000B<ol000@0003ooooooooo09Uhoooo002?oooo00<0
000co`0co`004S?o00040000ooooooooo`2IN?ooo`00Soooo`030000<ol0<ol0018co`0010000?oo
ooooool0VGSoool008ooool200004S?o00050000ooooooooooooo`2I07Soool008ooool00`0003?o
03?o000A<ol000D0003ooooooooooooo09T0N?ooo`00Soooo`030000<ol0<ol0014co`001@000?oo
ooooooooool0V@1hoooo002?oooo00<0000co`0co`004C?o00050000ooooooooooooo`2I07Soool0
08ooool00`0003?o03?o000@<ol000<0003oooooool00_ooo`03o`2Ioooooooo07Koool008ooool0
0`0003?o03?o000@<ol000<0003oooooool00_ooo`03o`2Ioooooooo07Koool008ooool200004C?o
00030000oooooooo00;oool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`0043?o00030000
oooooooo00;oool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`003c?o00030000oooooooo
00?oool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`003c?o00030000oooooooo00?oool0
0ol0VOooooooo`1foooo002?oooo00<0000co`0co`003c?o00030000oooooooo00?oool00ol0VOoo
ooooo`1foooo002?oooo00<0000co`0co`003c?o00030000oooooooo00?oool00ol0VOooooooo`1f
oooo002?oooo0P00010co`000`000?ooooooo`03oooo00?o09Woooooool0M_ooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`04oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`04oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`04oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`04oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`04
oooo00?o09Woooooool0M_ooo`00Soooo`80000><ol000<0003oooooool01Oooo`03o`2Ioooooooo
07Koool008ooool00`0003?o03?o000=<ol000<0003oooooool01Oooo`03o`2Ioooooooo07Koool0
08ooool00`0003?o03?o000=<ol000<0003oooooool01Oooo`03o`2Ioooooooo07Koool008ooool0
0`0003?o03?o000=<ol000<0003oooooool01Oooo`03o`2Ioooooooo07Koool008ooool00`0003?o
03?o000<<ol000<0003oooooool01_ooo`03o`2Ioooooooo07Koool008Woool300000oooo`030000
<ol0<ol000`co`000`000?ooooooo`06oooo00?o09Woooooool0M_ooo`00R_ooo`030000oooooooo
00;oool00`0003?o03?o000<<ol000<0003oooooool01_ooo`03o`2Ioooooooo07Koool008Ooool5
00000oooo`<0000<<ol000<0003oooooool01_ooo`03o`2Ioooooooo07Koool008Ooool010000?oo
ooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004
oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22oooo001loooo00<0003oooooool04?oo
o`hco`04oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`06
oooo3S?o00Goool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`03<ol00000000000@co`0200000c?o00@00003oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000<ol0<ol0000023?o00030000<ol0oooo00Coool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00goool0100003?o03?o000000Tco`000`000?ooooooo`04
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0000co`0co`00000:
<ol000<0003oooooool00_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?
oooo00@0000co`0co`000008<ol000@0003oooooool00003oooo00<0003oooooool0Noooo`00O?oo
o`030000oooooooo013oool00c?o00000000000:<ol00P0000?oool00`000?ooooooo`1loooo002?
oooo3C?o08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59405 .12361 L
.59698 .12361 L
.59842 .12361 L
.59905 .12361 L
.59975 .12361 L
s
.59975 .12361 m
.60026 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.3815 .12361 L
.39106 .12361 L
.39381 .12361 L
.39642 .12361 L
.39756 .12361 L
.39877 .12361 L
.39947 .12361 L
.4001 .12355 L
.40134 .12292 L
.42237 .11278 L
.46243 .09696 L
.50098 .08539 L
.54199 .07522 L
.56241 .07054 L
.58147 .06641 L
.59088 .06445 L
.59552 .06351 L
.59755 .06311 L
.59863 .06289 L
.5998 .06266 L
.60103 .12361 L
.60219 .12361 L
.60472 .12361 L
.61008 .12361 L
.61945 .12361 L
.66059 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`0Doooo0`1VogOoool008ooool00`000?oo
ooooo`0@oooo101Vo`;oool00`1Vooooooooo`1eoooo002?oooo00<0003oooooool02oooo`D0I_l6
oooo00<0I_ooooooool0MOooo`00Soooo`800008oooo101Vo`_oool00`1Vooooooooo`1eoooo000G
oooo1@0003?oool200001?ooo`800004oooo0P0003;oool00`000?ooooooo`03oooo101Vo`ooool0
0`1Vooooooooo`0Ioooo0P0000Coool200001?ooo`80000doooo1@0001Goool001Woool00`000?oo
ooooo`0boooo00@0003oooooool00008oooo00@0003oooooool0000aoooo00<0003oool0I_l00`1V
oa?oool00`1Vooooooooo`0Hoooo00@0003oooooool00008oooo00@0003oooooool0000eoooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000_oool00`000?oo
ooooo`0^oooo00<0I_l00000I_l05oooo`0306Kooooooooo01Soool010000?ooooooo`0000_oool0
0`000?ooooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?oo
o`@00002oooo00@0003oooooool00009oooo0P0002koool306Ko00?oool0003oool05oooo`0306Ko
oooooooo01Soool010000?ooooooo`0000Woool20000=_ooo`030000oooooooo01Goool001Woool0
0`000?ooooooo`0boooo00@0003oooooool00009oooo00<0003oooooool0:Oooo`@0I_l4oooo00<0
003oooooool05oooo`0306Kooooooooo01Ooool010000?ooooooo`0000Woool00`000?ooooooo`0e
oooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P0000[oool300009_ooo`<0I_l8oooo0P00
01Soool00`1Vooooooooo`0Hoooo0P0000[oool30000=?ooo`80000Goooo0022oooo0P1Vo`_oool0
0`000?ooooooo`0Goooo00<0I_ooooooool0M?ooo`00Ooooo`<0I_l=oooo00<0003oooooool05ooo
o`0306Kooooooooo07Coool007goool206Ko4?ooo`030000oooooooo01Ooool00`1Vooooooooo`1d
oooo001joooo0`1Voa;oool00`000?ooooooo`0Goooo00<0I_ooooooool0M?ooo`00N?ooo`80I_lE
oooo00<0003oooooool05oooo`0306Kooooooooo07Coool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000o`2I<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002S?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?oo
ooooo`0ioooo00<0000co`0co`005S?o0003o`2I<ol0<ol0020co`000`0003?o03?o000f<ol01@00
01Ooool008ooool00`0003?o03?o000F<ol000?o09Tco`0co`00DC?o00P0000Loooo002?oooo00<0
000co`0co`005S?o0003o`2I<ol0<ol004/co`0600009?ooo`00Soooo`030000<ol0<ol001Hco`00
0ol0VC?o03?o0016<ol01@0002[oool008ooool00`0003?o03?o000F<ol000?o09Tco`0co`00@C?o
00D0000_oooo002?oooo0P0001Lco`000ol0VC?o03?o000l<ol01@0003Coool008ooool00`0003?o
03?o000F<ol000?o09Tco`0co`00>3?o00@0000ioooo002?oooo00<0000co`0co`005S?o0003o`2I
<ol0<ol003Hco`020000?Oooo`00Soooo`030000<ol0<ol001Hco`000ol0VC?o03?o000c<ol00`00
03ooool008ooool00`0003?o03?o000F<ol000?o09Tco`0co`00<C?o00800012oooo002?oooo00<0
000co`0co`005S?o0003o`2I<ol0<ol002lco`020000A?ooo`00Soooo`80000G<ol000?o09Tco`0c
o`00;C?o00800016oooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol002/co`020000B?oo
o`00Soooo`030000<ol0<ol001Hco`000ol0VC?o03?o000Z<ol000<0003oooooool0B?ooo`00Sooo
o`030000<ol0<ol001Hco`000ol0VC?o03?o000X<ol00P0004_oool008ooool00`0003?o03?o000F
<ol000?o09Tco`0co`009S?o0080001=oooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol0
02Dco`000`000?ooooooo`1=oooo002?oooo0P0001Lco`000ol0VC?o03?o000S<ol00P00053oool0
08ooool00`0003?o03?o000F<ol000?o09Tco`0co`008C?o0080001Boooo002?oooo00<0000co`0c
o`005S?o0003o`2I<ol0<ol0020co`000`000?ooooooo`1Boooo002?oooo00<0000co`0co`005S?o
0003o`2I<ol0<ol001lco`000`000?ooooooo`1Coooo002?oooo00<0000co`0co`005S?o0003o`2I
<ol0<ol001dco`020000E_ooo`00Soooo`030000<ol0<ol001Hco`000ol0VC?o03?o000L<ol000<0
003oooooool0E_ooo`00Soooo`80000G<ol000?o09Tco`0co`006c?o00030000oooooooo05Ooool0
08ooool00`0003?o03?o000F<ol000?o09Tco`0co`006S?o00030000oooooooo05Soool008ooool0
0`0003?o03?o000F<ol000?o09Tco`0co`006C?o00030000oooooooo05Woool008ooool00`0003?o
03?o000F<ol000?o09Tco`0co`0063?o00030000oooooooo05[oool008ooool00`0003?o03?o000F
<ol000?o09Tco`0co`0063?o00030000oooooooo05[oool008Ooool500000oooo`030000<ol0<ol0
01Hco`000ol0VC?o03?o000G<ol000<0003oooooool0Foooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000F<ol000?o09Tco`0co`005S?o00030000oooooooo05coool008Woool00`000?oo
ooooo`03oooo0`0001Hco`000ol0VC?o03?o000E<ol000<0003oooooool0GOooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000F<ol000?o09Tco`0co`005C?o00030000oooooooo05goool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o0003o`2I<ol0<ol001@co`000`000?oo
ooooo`1Noooo0028oooo0P0000Goool00`0003?o03?o000F<ol000?o09Tco`0co`004c?o00030000
oooooooo05ooool008ooool00`0003?o03?o000F<ol000?o09Tco`0co`004S?o00030000oooooooo
063oool008ooool00`0003?o03?o000F<ol000?o09Tco`0co`004S?o00030000oooooooo063oool0
08ooool200005c?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1Qoooo002?oooo00<0000co`0c
o`005S?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1Roooo002?oooo00<0000co`0co`005S?o
0003o`2I<ol0<ol0010co`000`000?ooooooo`1Roooo002?oooo00<0000co`0co`005S?o0003o`2I
<ol0<ol000lco`000`000?ooooooo`1Soooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol0
00hco`000`000?ooooooo`1Toooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol000dco`00
0`000?ooooooo`1Uoooo002?oooo0P0001Lco`000ol0VC?o03?o000=<ol000<0003oooooool0IOoo
o`00Soooo`030000<ol0<ol001Hco`000ol0VC?o03?o000<<ol000<0003oooooool0I_ooo`00Sooo
o`030000<ol0<ol001Hco`000ol0VC?o03?o000;<ol000<0003oooooool0Ioooo`00Soooo`030000
<ol0<ol001Hco`000ol0VC?o03?o000;<ol000<0003oooooool0Ioooo`00Soooo`030000<ol0<ol0
01Hco`000ol0VC?o03?o000:<ol000<0003oooooool0J?ooo`00Soooo`030000<ol0<ol001Hco`00
0ol0VC?o03?o000:<ol000<0003oooooool0J?ooo`00Soooo`030000<ol0<ol001Hco`000ol0VC?o
03?o0009<ol000<0003oooooool0JOooo`00Soooo`80000G<ol000?o09Tco`0co`002C?o00030000
oooooooo06Woool008ooool00`0003?o03?o000F<ol000?o09Tco`0co`0023?o00030000oooooooo
06[oool008ooool00`0003?o03?o000F<ol000?o09Tco`0co`0023?o00030000oooooooo06[oool0
08ooool00`0003?o03?o000F<ol000?o09Tco`0co`001c?o00030000oooooooo06_oool008ooool0
0`0003?o03?o000F<ol000?o09Tco`0co`001c?o00030000oooooooo06_oool008ooool00`0003?o
03?o000F<ol000?o09Tco`0co`001c?o00030000oooooooo06_oool008ooool200005c?o0003o`2I
<ol0<ol000Hco`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol0
00Hco`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol000Dco`00
0`000?ooooooo`1]oooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol000Dco`000`000?oo
ooooo`1]oooo0027oooo100000Coool00`0003?o03?o000F<ol000?o09Tco`0co`001C?o00030000
oooooooo06goool008Ooool00`000?ooooooo`05oooo00<0000co`0co`005S?o0003o`2I<ol0<ol0
00@co`000`000?ooooooo`1^oooo0028oooo00<0003oooooool01?ooo`<0000F<ol000?o09Tco`0c
o`0013?o00030000oooooooo06koool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o
0003o`2I<ol0<ol000@co`000`000?ooooooo`1^oooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`005S?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1_oooo0028oooo0P0000Goool0
0`0003?o03?o000F<ol000?o09Tco`0co`000c?o00030000oooooooo06ooool008ooool00`0003?o
03?o000F<ol000?o09Tco`0co`000S?o00030000oooooooo073oool008ooool00`0003?o03?o000F
<ol000?o09Tco`0co`000S?o00030000oooooooo073oool008ooool200005c?o0003o`2I<ol0<ol0
008co`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`005S?o0005o`2I<ol0<ol0<ol00000
07?oool008ooool00`0003?o03?o000F<ol000Go09Tco`0co`0co`000000Loooo`00Soooo`030000
<ol0<ol001Hco`001Ol0VC?o03?o03?o0000001coooo002?oooo00<0000co`0co`005S?o0005o`2I
<ol0<ol0<ol0000007?oool008ooool00`0003?o03?o000F<ol000Co09Tco`0co`00001doooo002?
oooo00<0000co`0co`005S?o0004o`2I<ol0<ol00000M?ooo`00Soooo`80000G<ol000Co09Tco`0c
o`00001doooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0000007Goool008ooool00`0003?o
03?o000F<ol000?o09Tco`000000MOooo`00Soooo`030000<ol0<ol001Hco`000ol0VC?o0000001e
oooo002?oooo00<0000co`0co`005S?o0003o`2I0000oooo07Goool008ooool00`0003?o03?o000F
<ol000?o09T0003oool0MOooo`00Soooo`80000G<ol000?o09T0003oool0MOooo`00Soooo`030000
<ol0<ol001Hco`000ol0V@000?ooo`1eoooo002?oooo00<0000co`0co`005S?o0003o`2Ioooooooo
07Goool008ooool00`0003?o03?o000F<ol000?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0
01Hco`000ol0VOooooooo`1eoooo002?oooo00<0000co`0co`005C?o00030000o`2Ioooo07Koool0
08ooool200005S?o00030000o`2Ioooo07Koool008ooool00`0003?o03?o000E<ol000<0003o09Wo
ool0M_ooo`00Soooo`030000<ol0<ol001Dco`000`000?l0VOooo`1foooo002?oooo00<0000co`0c
o`0053?o00030000ooooo`2I07Ooool008Soool200001Oooo`030000<ol0<ol001@co`000`000?oo
ool0V@1goooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0053?o00030000ooooo`2I
07Ooool008Woool00`000?ooooooo`03oooo0`0001<co`0010000?ooooooool0VGOoool008[oool0
0`000?ooooooo`02oooo00<0000co`0co`004c?o00040000ooooooooo`2IMoooo`00Qoooo`040000
oooooooo00001?ooo`030000<ol0<ol001<co`0010000?ooooooool0VGOoool008Soool200001Ooo
o`030000<ol0<ol0018co`001@000?ooooooooooool0V@1goooo002?oooo00<0000co`0co`004S?o
00050000ooooooooooooo`2I07Ooool008ooool00`0003?o03?o000B<ol000D0003ooooooooooooo
09T0Moooo`00Soooo`030000<ol0<ol0018co`001@000?ooooooooooool0V@1goooo002?oooo0P00
018co`000`000?ooooooo`02oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`02oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`02oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`02
oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`03oooo00?o
09Woooooool0MOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`03oooo00?o09Wooooo
ool0MOooo`00Soooo`80000A<ol000<0003oooooool00oooo`03o`2Ioooooooo07Goool008ooool0
0`0003?o03?o000@<ol000<0003oooooool00oooo`03o`2Ioooooooo07Goool008ooool00`0003?o
03?o000?<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000?
<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000?<ol000<0
003oooooool01?ooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool01?ooo`03o`2Ioooooooo07Goool008ooool2000043?o00030000oooooooo00Coool00ol0VOoo
ooooo`1eoooo002?oooo00<0000co`0co`003S?o00030000oooooooo00Goool00ol0VOooooooo`1e
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo00Goool00ol0VOooooooo`1eoooo002?
oooo00<0000co`0co`003S?o00030000oooooooo00Goool00ol0VOooooooo`1eoooo002?oooo00<0
000co`0co`003S?o00030000oooooooo00Goool00ol0VOooooooo`1eoooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo00Goool00ol0VOooooooo`1eoooo002?oooo0P0000hco`000`000?oo
ooooo`06oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`06
oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`06oooo00?o
09Woooooool0MOooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`06oooo00?o09Wooooo
ool0MOooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`07oooo00?o09Woooooool0MOoo
o`00ROooo`<00003oooo00<0000co`0co`0033?o00030000oooooooo00Ooool00ol0VOooooooo`1e
oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`07oooo00?o
09Woooooool0MOooo`00Qoooo`D00003oooo0`0000`co`000`000?ooooooo`07oooo00?o09Wooooo
ool0MOooo`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?oo
o`lco`22oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool0
07Woool00`000?ooooooo`0Coooo3S?o00Ooool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo00Woool><ol02?ooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000@co`0200000c?o00@000000c?o0?oo
o`00000400000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Pco`000`0003?o03?o0002
<ol00oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo00goool010000?ooooooo`0000Tco`00100003?o03?o03?o00?oool00`000?oo
ooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003ooooo
ool0000:<ol000<0000co`0co`000oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000003oooo`040000oooooooo000023?o00040000<ol0<ol000001?oo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:
<ol00P000004<ol0oooooooooooo0P0000?oool00`000?ooooooo`1ioooo002?oooo3C?o08Coool0
08ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59405 .12361 L
.59698 .12361 L
.59975 .12361 L
.60237 .12361 L
.60309 .12361 L
.60385 .12361 L
.6045 .12361 L
s
.6045 .12361 m
.60478 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.3815 .12361 L
.3864 .12361 L
.39106 .12361 L
.39362 .12361 L
.39433 .12361 L
.39508 .12361 L
.39578 .12332 L
.39642 .12299 L
.40134 .1205 L
.42237 .11068 L
.46243 .09535 L
.50098 .08418 L
.54199 .07432 L
.56241 .06976 L
.58147 .06571 L
.59088 .06379 L
.5998 .06203 L
.60219 .06157 L
.60349 .06131 L
.60472 .06108 L
.60604 .12361 L
.60675 .12361 L
.6075 .12361 L
.61008 .12361 L
.61945 .12361 L
.66059 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`0Doooo1@1VogGoool008ooool00`000?oo
ooooo`0@oooo101Vo`Coool00`1Vooooooooo`1coooo002?oooo00<0003oooooool02oooo`D0I_l8
oooo00<0I_ooooooool0Loooo`00Soooo`800007oooo1@1Vo`goool00`1Vooooooooo`1coooo000G
oooo1@0003?oool200001?ooo`800004oooo0P0003;oool00`000?ooooooo`0606Ko4_ooo`0306Ko
oooooooo01Ooool200001?ooo`800004oooo0P0003Coool500005Oooo`006Oooo`030000oooooooo
03;oool010000?ooooooo`0000Soool010000?ooooooo`00033oool0101Vo`00001Vo`1VoaSoool0
0`1Vooooooooo`0Foooo00@0003oooooool00008oooo00@0003oooooool0000eoooo00<0003ooooo
ool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000_oool00`000?ooooooo`0[
oooo0`1Vo`03oooo0000oooo01Woool00`1Vooooooooo`0Foooo00@0003oooooool0000;oooo00<0
003oooooool0<oooo`030000oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool4
00000_ooo`040000oooooooo00002Oooo`80000Zoooo101Vo`Coool00`000?ooooooo`0Hoooo00<0
I_ooooooool05_ooo`040000oooooooo00002Oooo`80000foooo00<0003oooooool05Oooo`006Ooo
o`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?ooooooo`0Voooo0`1Vo`Soool0
0`000?ooooooo`0Hoooo00<0I_ooooooool05_ooo`040000oooooooo00002Oooo`030000oooooooo
03Goool00`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000Toooo0P1Vo`_oool2
00006Oooo`0306Kooooooooo01Ooool200002_ooo`<0000doooo0P0001Ooool007ooool306Ko3Ooo
o`030000oooooooo01Soool00`1Vooooooooo`1coooo001moooo0P1Voa3oool00`000?ooooooo`0H
oooo00<0I_ooooooool0Loooo`00Noooo`80I_lBoooo00<0003oooooool06?ooo`0306Kooooooooo
07?oool007Woool206Ko5?ooo`030000oooooooo01Soool00`1Vooooooooo`1coooo001goooo0P1V
oaKoool00`000?ooooooo`0Hoooo00<0I_ooooooool0Loooo`004?ooool0000Aoooo000Foooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_oo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o
03?o0009<ol000<0000co`3o09T02C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo03Woool00`0003?o03?o000G<ol000?o09Tco`0co`007c?o00030000<ol0<ol003Hco`05
00005oooo`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o001@<ol0200001coool008ooool0
0`0003?o03?o000G<ol000?o09Tco`0co`00BS?o00H0000Toooo002?oooo00<0000co`0co`005c?o
0003o`2I<ol0<ol004Dco`050000:_ooo`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o0010
<ol01@0002ooool008ooool2000063?o0003o`2I<ol0<ol003/co`050000=?ooo`00Soooo`030000
<ol0<ol001Lco`000ol0VC?o03?o000g<ol0100003Woool008ooool00`0003?o03?o000G<ol000?o
09Tco`0co`00=C?o0080000moooo002?oooo00<0000co`0co`005c?o0003o`2I<ol0<ol0038co`03
0000?oooo`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o000`<ol00P0004;oool008ooool0
0`0003?o03?o000G<ol000?o09Tco`0co`00;S?o00800014oooo002?oooo0P0001Pco`000ol0VC?o
03?o000/<ol00P0004Koool008ooool00`0003?o03?o000G<ol000?o09Tco`0co`00:S?o00800018
oooo002?oooo00<0000co`0co`005c?o0003o`2I<ol0<ol002Tco`000`000?ooooooo`18oooo002?
oooo00<0000co`0co`005c?o0003o`2I<ol0<ol002Lco`020000Boooo`00Soooo`030000<ol0<ol0
01Lco`000ol0VC?o03?o000U<ol00P0004goool008ooool00`0003?o03?o000G<ol000?o09Tco`0c
o`0093?o00030000oooooooo04goool008ooool2000063?o0003o`2I<ol0<ol0028co`020000D?oo
o`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o000P<ol00P0005;oool008ooool00`0003?o
03?o000G<ol000?o09Tco`0co`007c?o00030000oooooooo05;oool008ooool00`0003?o03?o000G
<ol000?o09Tco`0co`007S?o00030000oooooooo05?oool008ooool00`0003?o03?o000G<ol000?o
09Tco`0co`0073?o0080001Foooo002?oooo00<0000co`0co`005c?o0003o`2I<ol0<ol001/co`00
0`000?ooooooo`1Foooo002?oooo0P0001Pco`000ol0VC?o03?o000J<ol000<0003oooooool0Eooo
o`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o000I<ol000<0003oooooool0F?ooo`00Sooo
o`030000<ol0<ol001Lco`000ol0VC?o03?o000H<ol000<0003oooooool0FOooo`00Soooo`030000
<ol0<ol001Lco`000ol0VC?o03?o000G<ol000<0003oooooool0F_ooo`00Soooo`030000<ol0<ol0
01Lco`000ol0VC?o03?o000G<ol000<0003oooooool0F_ooo`00Qoooo`D00003oooo00<0000co`0c
o`005c?o0003o`2I<ol0<ol001Hco`000`000?ooooooo`1Koooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol001Lco`000ol0VC?o03?o000E<ol000<0003oooooool0G?ooo`00ROooo`030000
oooooooo00?oool300005c?o0003o`2I<ol0<ol001@co`000`000?ooooooo`1Moooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol001Lco`000ol0VC?o03?o000D<ol000<0003oooooool0GOoo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000G<ol000?o09Tco`0co`004c?o00030000
oooooooo05koool008Soool200001Oooo`030000<ol0<ol001Lco`000ol0VC?o03?o000B<ol000<0
003oooooool0Goooo`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o000A<ol000<0003ooooo
ool0H?ooo`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o000A<ol000<0003oooooool0H?oo
o`00Soooo`80000H<ol000?o09Tco`0co`0043?o00030000oooooooo067oool008ooool00`0003?o
03?o000G<ol000?o09Tco`0co`003c?o00030000oooooooo06;oool008ooool00`0003?o03?o000G
<ol000?o09Tco`0co`003c?o00030000oooooooo06;oool008ooool00`0003?o03?o000G<ol000?o
09Tco`0co`003S?o00030000oooooooo06?oool008ooool00`0003?o03?o000G<ol000?o09Tco`0c
o`003C?o00030000oooooooo06Coool008ooool00`0003?o03?o000G<ol000?o09Tco`0co`0033?o
00030000oooooooo06Goool008ooool2000063?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1U
oooo002?oooo00<0000co`0co`005c?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1Voooo002?
oooo00<0000co`0co`005c?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1Woooo002?oooo00<0
000co`0co`005c?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1Woooo002?oooo00<0000co`0c
o`005c?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1Xoooo002?oooo00<0000co`0co`005c?o
0003o`2I<ol0<ol000Tco`000`000?ooooooo`1Xoooo002?oooo00<0000co`0co`005c?o0003o`2I
<ol0<ol000Pco`000`000?ooooooo`1Yoooo002?oooo0P0001Pco`000ol0VC?o03?o0008<ol000<0
003oooooool0JOooo`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o0007<ol000<0003ooooo
ool0J_ooo`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o0007<ol000<0003oooooool0J_oo
o`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o0006<ol000<0003oooooool0Joooo`00Sooo
o`030000<ol0<ol001Lco`000ol0VC?o03?o0006<ol000<0003oooooool0Joooo`00Soooo`030000
<ol0<ol001Lco`000ol0VC?o03?o0006<ol000<0003oooooool0Joooo`00Soooo`80000H<ol000?o
09Tco`0co`001C?o00030000oooooooo06coool008ooool00`0003?o03?o000G<ol000?o09Tco`0c
o`001C?o00030000oooooooo06coool008ooool00`0003?o03?o000G<ol000?o09Tco`0co`0013?o
00030000oooooooo06goool008ooool00`0003?o03?o000G<ol000?o09Tco`0co`0013?o00030000
oooooooo06goool008Ooool400001?ooo`030000<ol0<ol001Lco`000ol0VC?o03?o0004<ol000<0
003oooooool0KOooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000G<ol000?o09Tco`0c
o`000c?o00030000oooooooo06koool008Soool00`000?ooooooo`04oooo0`0001Lco`000ol0VC?o
03?o0003<ol000<0003oooooool0K_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000H
<ol000?o09Tco`0co`000S?o00030000oooooooo06koool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o000H<ol000Go09Tco`0co`0co`000000LOooo`00R?ooo`800005oooo00<0000co`0c
o`0063?o0005o`2I<ol0<ol0<ol00000077oool008ooool00`0003?o03?o000H<ol000Co09Tco`0c
o`00001boooo002?oooo00<0000co`0co`0063?o0004o`2I<ol0<ol00000L_ooo`00Soooo`80000I
<ol000Co09Tco`0co`00001boooo002?oooo00<0000co`0co`0063?o0003o`2I<ol0000007?oool0
08ooool00`0003?o03?o000H<ol000?o09Tco`000000Loooo`00Soooo`030000<ol0<ol001Pco`00
0ol0VC?o0000001coooo002?oooo00<0000co`0co`0063?o0003o`2I<ol0000007?oool008ooool0
0`0003?o03?o000H<ol000?o09T0003oool0Loooo`00Soooo`030000<ol0<ol001Pco`000ol0V@00
0?ooo`1coooo002?oooo0P0001Tco`000ol0V@000?ooo`1coooo002?oooo00<0000co`0co`0063?o
0003o`2Ioooooooo07?oool008ooool00`0003?o03?o000H<ol000?o09Woooooool0Loooo`00Sooo
o`030000<ol0<ol001Pco`000ol0VOooooooo`1coooo002?oooo00<0000co`0co`005c?o00030000
o`2Ioooo07Coool008ooool00`0003?o03?o000G<ol000<0003o09Woool0M?ooo`00Soooo`80000H
<ol000<0003o09Woool0M?ooo`00Soooo`030000<ol0<ol001Lco`000`000?l0VOooo`1doooo002?
oooo00<0000co`0co`005S?o00030000ooooo`2I07Goool008ooool00`0003?o03?o000F<ol000<0
003ooooo09T0MOooo`00Soooo`030000<ol0<ol001Hco`000`000?ooool0V@1eoooo002?oooo00<0
000co`0co`005C?o00040000ooooooooo`2IMOooo`00Soooo`80000F<ol000@0003ooooooooo09Ue
oooo002?oooo00<0000co`0co`005C?o00040000ooooooooo`2IMOooo`00Soooo`030000<ol0<ol0
01Dco`0010000?ooooooool0VGGoool008ooool00`0003?o03?o000D<ol000D0003ooooooooooooo
09T0MOooo`00R?ooo`800005oooo00<0000co`0co`0053?o00050000ooooooooooooo`2I07Goool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o000D<ol000D0003ooooooooooooo09T0MOoo
o`00ROooo`030000oooooooo00?oool300004c?o00030000oooooooo00;oool00ol0VOooooooo`1c
oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol001<co`000`000?ooooooo`02oooo00?o
09Woooooool0Loooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001<co`000`000?oo
ooooo`02oooo00?o09Woooooool0Loooo`00R?ooo`800005oooo00<0000co`0co`004S?o00030000
oooooooo00?oool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`004S?o00030000oooooooo
00?oool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`004S?o00030000oooooooo00?oool0
0ol0VOooooooo`1coooo002?oooo00<0000co`0co`004S?o00030000oooooooo00?oool00ol0VOoo
ooooo`1coooo002?oooo0P00018co`000`000?ooooooo`04oooo00?o09Woooooool0Loooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`04oooo00?o09Woooooool0Loooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`04oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol0
014co`000`000?ooooooo`04oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`05oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol0010co`000`000?oo
ooooo`05oooo00?o09Woooooool0Loooo`00Soooo`80000A<ol000<0003oooooool01Oooo`03o`2I
oooooooo07?oool008ooool00`0003?o03?o000@<ol000<0003oooooool01Oooo`03o`2Ioooooooo
07?oool008ooool00`0003?o03?o000?<ol000<0003oooooool01_ooo`03o`2Ioooooooo07?oool0
08ooool00`0003?o03?o000?<ol000<0003oooooool01_ooo`03o`2Ioooooooo07?oool008ooool0
0`0003?o03?o000?<ol000<0003oooooool01_ooo`03o`2Ioooooooo07?oool008ooool00`0003?o
03?o000?<ol000<0003oooooool01_ooo`03o`2Ioooooooo07?oool008ooool2000043?o00030000
oooooooo00Koool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`003S?o00030000oooooooo
00Ooool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`003S?o00030000oooooooo00Ooool0
0ol0VOooooooo`1coooo002?oooo00<0000co`0co`003S?o00030000oooooooo00Ooool00ol0VOoo
ooooo`1coooo002?oooo00<0000co`0co`003S?o00030000oooooooo00Ooool00ol0VOooooooo`1c
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo00Ooool00ol0VOooooooo`1coooo002?
oooo0P0000hco`000`000?ooooooo`08oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`08oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol000dco`00
0`000?ooooooo`08oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol000dco`000`000?oo
ooooo`08oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`09
oooo00?o09Woooooool0Loooo`00ROooo`<00003oooo00<0000co`0co`0033?o00030000oooooooo
00Woool00ol0VOooooooo`1coooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000`co`00
0`000?ooooooo`09oooo00?o09Woooooool0Loooo`00Qoooo`D00003oooo0`0000`co`000`000?oo
ooooo`09oooo00?o09Woooooool0Loooo`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028
oooo00<0003oool000001?ooo`lco`22oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22
oooo002?oooo3c?o08;oool007Woool00`000?ooooooo`0Coooo3S?o00Ooool00`000?ooooooo`1i
oooo001hoooo00<0003oooooool02?ooo`030000oooooooo00Woool><ol02?ooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000@co`02
00000c?o00@000000c?o0?ooo`00000300000oooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00Pco`000`0003?o03?o0002<ol000?oool0003oool01Oooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002C?o00040000<ol0<ol0
<ol00_ooo`030000oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00coool010000?ooooooo`0000Xco`000`0003?o03?o0003oooo00<0003oooooool00_ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008<ol000@0
000co`0co`000002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo017oool200002S?o0080000013?o0?ooooooooooo`800003oooo00<0003oooooool0NOoo
o`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59405 .12361 L
.59975 .12361 L
.60256 .12361 L
.60521 .12361 L
.60759 .12361 L
.60824 .12361 L
.60893 .12361 L
s
.60893 .12361 m
.60942 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.37685 .12361 L
.3815 .12361 L
.38384 .12361 L
.3864 .12361 L
.38757 .12361 L
.38881 .12361 L
.38999 .12361 L
.39106 .12331 L
.3917 .12297 L
.39238 .12262 L
.3936 .122 L
.39635 .12061 L
.40134 .11816 L
.42237 .10863 L
.46034 .09448 L
.50076 .08306 L
.53967 .07398 L
.55948 .06963 L
.58103 .06513 L
.59107 .06313 L
.59657 .06206 L
.60173 .06107 L
.60611 .06024 L
.60731 .06001 L
.60857 .05978 L
.60965 .12361 L
.61083 .12361 L
.62088 .12361 L
.66144 .12361 L
.70048 .12361 L
.74198 .12361 L
.78196 .12361 L
.82043 .12361 L
.86135 .12361 L
.90075 .12361 L
.93864 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo01Soool00`1Vooooooooo`1coooo002?oooo00<0003oooooool05?ooo`D0I_me
oooo002?oooo00<0003oooooool04?ooo`@0I_l4oooo00<0I_ooooooool0Loooo`00Soooo`030000
oooooooo00[oool606Ko2?ooo`0306Kooooooooo07?oool008ooool200001_ooo`D0I_l>oooo00<0
I_ooooooool0Loooo`005oooo`D0000coooo0P0000Coool200001?ooo`80000boooo00<0003ooooo
ool01@1Voa?oool00`1Vooooooooo`0Goooo0P0000Coool200001?ooo`80000doooo1@0001Goool0
01Woool00`000?ooooooo`0boooo00@0003oooooool00008oooo00@0003oooooool0000`oooo00@0
I_l00000I_l0I_lHoooo00<0I_ooooooool05_ooo`040000oooooooo00002?ooo`040000oooooooo
0000=Oooo`030000oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool0000;
oooo00<0003oooooool0:oooo`<0I_l00oooo`000?ooo`0Ioooo00<0I_ooooooool05_ooo`040000
oooooooo00002oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo000Aoooo100000Coool0
0`000?ooooooo`0/oooo100000;oool010000?ooooooo`0000Woool20000:_ooo`@0I_l4oooo00<0
003oooooool06?ooo`0306Kooooooooo01Koool010000?ooooooo`0000Woool20000=_ooo`030000
oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00009oooo00<0003ooooo
ool09_ooo`<0I_l8oooo00<0003oooooool06Oooo`0306Kooooooooo01Goool010000?ooooooo`00
00Woool00`000?ooooooo`0eoooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P0000[oool3
00009?ooo`80I_l;oooo0P0001[oool00`1Vooooooooo`0Foooo0P0000[oool30000=?ooo`80000G
oooo001ooooo0`1Vo`goool00`000?ooooooo`0Ioooo00<0I_ooooooool0L_ooo`00OOooo`80I_l@
oooo00<0003oooooool06Oooo`0306Kooooooooo07;oool007[oool306Ko4_ooo`030000oooooooo
01Woool00`1Vooooooooo`1boooo001hoooo0P1VoaGoool00`000?ooooooo`0Ioooo00<0I_oooooo
ool0L_ooo`00M_ooo`80I_lGoooo00<0003oooooool06Oooo`0306Kooooooooo07;oool0013ooooo
00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o
03?o0009<ol000<0000co`0co`002C?o00050000<ol0<ol0<ol0o`2I00Lco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0003oooooool05Oooo`005_oo
o`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`006C?o0003o`2I<ol0<ol0
01dco`000`0003?o03?o000f<ol01@0001Ooool008ooool00`0003?o03?o000I<ol000?o09Tco`0c
o`00CS?o00P0000Loooo002?oooo00<0000co`0co`006C?o0003o`2I<ol0<ol004Pco`0600009?oo
o`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o0013<ol01@0002[oool008ooool00`0003?o
03?o000I<ol000?o09Tco`0co`00?S?o00D0000_oooo002?oooo0P0001Xco`000ol0VC?o03?o000i
<ol01@0003Coool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`00=C?o00@0000ioooo002?
oooo00<0000co`0co`006C?o0003o`2I<ol0<ol003<co`020000?Oooo`00Soooo`030000<ol0<ol0
01Tco`000ol0VC?o03?o000`<ol00`0003ooool008ooool00`0003?o03?o000I<ol000?o09Tco`0c
o`00;S?o00800012oooo002?oooo00<0000co`0co`006C?o0003o`2I<ol0<ol002`co`020000A?oo
o`00Soooo`80000J<ol000?o09Tco`0co`00:S?o00800016oooo002?oooo00<0000co`0co`006C?o
0003o`2I<ol0<ol002Pco`020000B?ooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o000W
<ol000<0003oooooool0B?ooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o000U<ol00P00
04_oool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`008c?o0080001=oooo002?oooo00<0
000co`0co`006C?o0003o`2I<ol0<ol0028co`000`000?ooooooo`1=oooo002?oooo0P0001Xco`00
0ol0VC?o03?o000P<ol00P00053oool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`007S?o
0080001Boooo002?oooo00<0000co`0co`006C?o0003o`2I<ol0<ol001dco`000`000?ooooooo`1B
oooo002?oooo00<0000co`0co`006C?o0003o`2I<ol0<ol001`co`000`000?ooooooo`1Coooo002?
oooo00<0000co`0co`006C?o0003o`2I<ol0<ol001Xco`020000E_ooo`00Soooo`030000<ol0<ol0
01Tco`000ol0VC?o03?o000I<ol000<0003oooooool0E_ooo`00Soooo`80000J<ol000?o09Tco`0c
o`0063?o00030000oooooooo05Ooool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`005c?o
00030000oooooooo05Soool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`005S?o00030000
oooooooo05Woool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`005C?o00030000oooooooo
05[oool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`005C?o00030000oooooooo05[oool0
08Ooool500000oooo`030000<ol0<ol001Tco`000ol0VC?o03?o000D<ol000<0003oooooool0Fooo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000I<ol000?o09Tco`0co`004c?o00030000
oooooooo05coool008Woool00`000?ooooooo`03oooo0`0001Tco`000ol0VC?o03?o000B<ol000<0
003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000I<ol000?o09Tco`0c
o`004S?o00030000oooooooo05goool008Woool00`000?ooooooo`03oooo00<0000co`0co`006C?o
0003o`2I<ol0<ol0014co`000`000?ooooooo`1Noooo0028oooo0P0000Goool00`0003?o03?o000I
<ol000?o09Tco`0co`0043?o00030000oooooooo05ooool008ooool00`0003?o03?o000I<ol000?o
09Tco`0co`003c?o00030000oooooooo063oool008ooool00`0003?o03?o000I<ol000?o09Tco`0c
o`003c?o00030000oooooooo063oool008ooool200006S?o0003o`2I<ol0<ol000hco`000`000?oo
ooooo`1Qoooo002?oooo00<0000co`0co`006C?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1R
oooo002?oooo00<0000co`0co`006C?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1Roooo002?
oooo00<0000co`0co`006C?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1Soooo002?oooo00<0
000co`0co`006C?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1Toooo002?oooo00<0000co`0c
o`006C?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1Uoooo002?oooo0P0001Xco`000ol0VC?o
03?o000:<ol000<0003oooooool0IOooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o0009
<ol000<0003oooooool0I_ooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o0008<ol000<0
003oooooool0Ioooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o0008<ol000<0003ooooo
ool0Ioooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o0007<ol000<0003oooooool0J?oo
o`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o0007<ol000<0003oooooool0J?ooo`00Sooo
o`030000<ol0<ol001Tco`000ol0VC?o03?o0006<ol000<0003oooooool0JOooo`00Soooo`80000J
<ol000?o09Tco`0co`001S?o00030000oooooooo06Woool008ooool00`0003?o03?o000I<ol000?o
09Tco`0co`001C?o00030000oooooooo06[oool008ooool00`0003?o03?o000I<ol000?o09Tco`0c
o`001C?o00030000oooooooo06[oool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`0013?o
00030000oooooooo06_oool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`0013?o00030000
oooooooo06_oool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`0013?o00030000oooooooo
06_oool008ooool200006S?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1/oooo002?oooo00<0
000co`0co`006C?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1/oooo002?oooo00<0000co`0c
o`006C?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1]oooo002?oooo00<0000co`0co`006C?o
0003o`2I<ol0<ol0008co`000`000?ooooooo`1]oooo0027oooo100000Coool00`0003?o03?o000I
<ol000?o09Tco`0co`000S?o00030000oooooooo06goool008Ooool00`000?ooooooo`05oooo00<0
000co`0co`006C?o0005o`2I<ol0<ol0<ol00000073oool008Soool00`000?ooooooo`04oooo0`00
01Tco`001Ol0VC?o03?o03?o0000001`oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Tco`001Ol0VC?o03?o03?o0000001`oooo0027oooo00@0003oooooool00004oooo00<0000co`0c
o`006C?o0004o`2I<ol0<ol00000LOooo`00R?ooo`800005oooo00<0000co`0co`006C?o0004o`2I
<ol0<ol00000LOooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o0000001boooo002?oooo00<0
000co`0co`006C?o0003o`2I<ol0000007;oool008ooool200006S?o0003o`2I<ol0000007;oool0
08ooool00`0003?o03?o000I<ol000?o09T0003oool0L_ooo`00Soooo`030000<ol0<ol001Tco`00
0ol0V@000?ooo`1boooo002?oooo00<0000co`0co`006C?o0003o`2I0000oooo07;oool008ooool0
0`0003?o03?o000I<ol000?o09T0003oool0L_ooo`00Soooo`030000<ol0<ol001Tco`000ol0VOoo
ooooo`1boooo002?oooo00<0000co`0co`006C?o0003o`2Ioooooooo07;oool008ooool200006S?o
0003o`2Ioooooooo07;oool008ooool00`0003?o03?o000H<ol000<0003o09Woool0Loooo`00Sooo
o`030000<ol0<ol001Pco`000`000?l0VOooo`1coooo002?oooo00<0000co`0co`0063?o00030000
o`2Ioooo07?oool008ooool00`0003?o03?o000G<ol000<0003ooooo09T0M?ooo`00Soooo`030000
<ol0<ol001Lco`000`000?ooool0V@1doooo002?oooo0P0001Pco`000`000?ooool0V@1doooo002?
oooo00<0000co`0co`005c?o00030000ooooo`2I07Coool008ooool00`0003?o03?o000F<ol000@0
003ooooooooo09Udoooo002?oooo00<0000co`0co`005S?o00040000ooooooooo`2IM?ooo`00Sooo
o`030000<ol0<ol001Hco`0010000?ooooooool0VGCoool008ooool00`0003?o03?o000E<ol000D0
003ooooooooooooo09T0M?ooo`00Soooo`80000F<ol000D0003ooooooooooooo09T0M?ooo`00Sooo
o`030000<ol0<ol001Dco`001@000?ooooooooooool0V@1doooo002?oooo00<0000co`0co`005C?o
00050000ooooooooooooo`2I07Coool008ooool00`0003?o03?o000D<ol000<0003oooooool00_oo
o`03o`2Ioooooooo07;oool008Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`02
oooo00?o09Woooooool0L_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001@co`00
0`000?ooooooo`02oooo00?o09Woooooool0L_ooo`00ROooo`030000oooooooo00?oool300004c?o
00030000oooooooo00?oool00ol0VOooooooo`1boooo002:oooo00<0003oooooool00_ooo`030000
<ol0<ol001<co`000`000?ooooooo`03oooo00?o09Woooooool0L_ooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`03oooo00?o09Woooooool0L_ooo`00R?oo
o`800005oooo00<0000co`0co`004S?o00030000oooooooo00Coool00ol0VOooooooo`1boooo002?
oooo00<0000co`0co`004S?o00030000oooooooo00Coool00ol0VOooooooo`1boooo002?oooo00<0
000co`0co`004S?o00030000oooooooo00Coool00ol0VOooooooo`1boooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo00Coool00ol0VOooooooo`1boooo002?oooo0P00018co`000`000?oo
ooooo`05oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`05
oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`05oooo00?o
09Woooooool0L_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`05oooo00?o09Wooooo
ool0L_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`06oooo00?o09Woooooool0L_oo
o`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`06oooo00?o09Woooooool0L_ooo`00Sooo
o`80000A<ol000<0003oooooool01_ooo`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000@
<ol000<0003oooooool01_ooo`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000?<ol000<0
003oooooool01oooo`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000?<ol000<0003oooooool01ooo
o`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000?<ol000<0003oooooool01oooo`03o`2I
oooooooo07;oool008ooool2000043?o00030000oooooooo00Ooool00ol0VOooooooo`1boooo002?
oooo00<0000co`0co`003S?o00030000oooooooo00Soool00ol0VOooooooo`1boooo002?oooo00<0
000co`0co`003S?o00030000oooooooo00Soool00ol0VOooooooo`1boooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo00Soool00ol0VOooooooo`1boooo002?oooo00<0000co`0co`003S?o
00030000oooooooo00Soool00ol0VOooooooo`1boooo002?oooo00<0000co`0co`003S?o00030000
oooooooo00Soool00ol0VOooooooo`1boooo002?oooo0P0000hco`000`000?ooooooo`09oooo00?o
09Woooooool0L_ooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`09oooo00?o09Wooooo
ool0L_ooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`09oooo00?o09Woooooool0L_oo
o`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`09oooo00?o09Woooooool0L_ooo`00Sooo
o`030000<ol0<ol000`co`000`000?ooooooo`0:oooo00?o09Woooooool0L_ooo`00ROooo`<00003
oooo00<0000co`0co`0033?o00030000oooooooo00[oool00ol0VOooooooo`1boooo002:oooo00<0
003oooooool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`0:oooo00?o09Woooooool0L_oo
o`00Qoooo`D00003oooo0`0000`co`000`000?ooooooo`0:oooo00?o09Woooooool0L_ooo`00Qooo
o`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?ooo`lco`22oooo0029
oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool007Woool00`000?oo
ooooo`0Coooo3S?o00Ooool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool><ol02?ooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000@co`0200000c?o00@000000c?o0?ooooooo`0200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Pco`000`0003?o03?o0002<ol000Goool0003o
ooooool000000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03Oooo`040000oooooooo00002C?o00040000<ol0<ol0<ol00oooo`030000oooooooo00?oool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Xco`00
0`0003?o03?o0004oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Pco`00100003?o03?o000000;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:<ol00P000004<ol0oooooooo
oooo0P0000?oool00`000?ooooooo`1ioooo002?oooo3C?o08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59975 .12361 L
.60479 .12361 L
.60756 .12361 L
.61016 .12361 L
.6126 .12361 L
.61327 .12361 L
.61397 .12361 L
s
.61397 .12361 m
.61448 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.37685 .12361 L
.3815 .12361 L
.38384 .12361 L
.38448 .12361 L
.38517 .12361 L
.3864 .12325 L
.38766 .1226 L
.38884 .122 L
.39106 .12088 L
.40134 .11589 L
.42237 .10665 L
.46092 .09277 L
.50192 .08166 L
.54141 .07276 L
.57938 .06483 L
.59889 .06104 L
.60451 .05999 L
.60727 .05948 L
.60983 .05901 L
.61215 .05859 L
.61331 .05837 L
.61461 .12361 L
.6159 .12361 L
.61729 .12361 L
.6198 .12361 L
.66094 .12361 L
.70057 .12361 L
.73868 .12361 L
.77924 .12361 L
.81828 .12361 L
.85978 .12361 L
.89976 .12361 L
.93823 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo01Ooool406KoLoooo`00Soooo`030000oooooooo013oool706Ko0oooo`0306Ko
oooooooo077oool008ooool00`000?ooooooo`0=oooo0`1Vo`[oool00`1Vooooooooo`1aoooo002?
oooo00<0003oooooool02Oooo`@0I_l=oooo00<0I_ooooooool0LOooo`00Soooo`800006oooo101V
oa7oool00`1Vooooooooo`1aoooo000Goooo1@0003?oool200001?ooo`800004oooo0P0003;oool0
0`000?ooooooo`0506Ko5Oooo`0306Kooooooooo01Goool200001?ooo`800004oooo0P0003Coool5
00005Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Soool010000?ooooooo`00
033oool0101Vo`00001Vo`1Voa[oool00`1Vooooooooo`0Doooo00@0003oooooool00008oooo00@0
003oooooool0000eoooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?oo
ooooo`0000_oool00`000?ooooooo`0[oooo0`1Vo`03oooo0000oooo01_oool00`1Vooooooooo`0D
oooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000oooooooo01Goool0017oool4
00001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo00002Oooo`80000Zoooo101V
o`Coool00`000?ooooooo`0Joooo00<0I_ooooooool05?ooo`040000oooooooo00002Oooo`80000f
oooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool0
0`000?ooooooo`0Voooo0`1Vo`Soool00`000?ooooooo`0Joooo00<0I_ooooooool05?ooo`040000
oooooooo00002Oooo`030000oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P0003Goool2
00002_ooo`<0000Soooo0`1Vo`_oool200006oooo`0306Kooooooooo01Goool200002_ooo`<0000d
oooo0P0001Ooool007goool406Ko3_ooo`030000oooooooo01[oool00`1Vooooooooo`1aoooo001j
oooo0`1Voa;oool00`000?ooooooo`0Joooo00<0I_ooooooool0LOooo`00N?ooo`80I_lEoooo00<0
003oooooool06_ooo`0306Kooooooooo077oool007Koool206Ko5oooo`030000oooooooo01[oool0
0`1Vooooooooo`1aoooo001doooo0P1VoaWoool00`000?ooooooo`0Joooo00<0I_ooooooool0LOoo
o`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`000S?o0003o`2I<ol0<ol0
00@co`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o
03?o0009<ol000<0000co`0co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0
003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0c
o`006S?o0003o`2I<ol0<ol001`co`000`0003?o03?o000f<ol01@0001Ooool008ooool00`0003?o
03?o000J<ol000?o09Tco`0co`00CC?o00P0000Loooo002?oooo00<0000co`0co`006S?o0003o`2I
<ol0<ol004Lco`0600009?ooo`00Soooo`030000<ol0<ol001Xco`000ol0VC?o03?o0012<ol01@00
02[oool008ooool00`0003?o03?o000J<ol000?o09Tco`0co`00?C?o00D0000_oooo002?oooo0P00
01/co`000ol0VC?o03?o000h<ol01@0003Coool008ooool00`0003?o03?o000J<ol000?o09Tco`0c
o`00=3?o00@0000ioooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol0038co`020000?Ooo
o`00Soooo`030000<ol0<ol001Xco`000ol0VC?o03?o000_<ol00`0003ooool008ooool00`0003?o
03?o000J<ol000?o09Tco`0co`00;C?o00800012oooo002?oooo00<0000co`0co`006S?o0003o`2I
<ol0<ol002/co`020000A?ooo`00Soooo`80000K<ol000?o09Tco`0co`00:C?o00800016oooo002?
oooo00<0000co`0co`006S?o0003o`2I<ol0<ol002Lco`020000B?ooo`00Soooo`030000<ol0<ol0
01Xco`000ol0VC?o03?o000V<ol000<0003oooooool0B?ooo`00Soooo`030000<ol0<ol001Xco`00
0ol0VC?o03?o000T<ol00P0004_oool008ooool00`0003?o03?o000J<ol000?o09Tco`0co`008S?o
0080001=oooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol0024co`000`000?ooooooo`1=
oooo002?oooo0P0001/co`000ol0VC?o03?o000O<ol00P00053oool008ooool00`0003?o03?o000J
<ol000?o09Tco`0co`007C?o0080001Boooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol0
01`co`000`000?ooooooo`1Boooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol001/co`00
0`000?ooooooo`1Coooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol001Tco`020000E_oo
o`00Soooo`030000<ol0<ol001Xco`000ol0VC?o03?o000H<ol000<0003oooooool0E_ooo`00Sooo
o`80000K<ol000?o09Tco`0co`005c?o00030000oooooooo05Ooool008ooool00`0003?o03?o000J
<ol000?o09Tco`0co`005S?o00030000oooooooo05Soool008ooool00`0003?o03?o000J<ol000?o
09Tco`0co`005C?o00030000oooooooo05Woool008ooool00`0003?o03?o000J<ol000?o09Tco`0c
o`0053?o00030000oooooooo05[oool008ooool00`0003?o03?o000J<ol000?o09Tco`0co`0053?o
00030000oooooooo05[oool008Ooool500000oooo`030000<ol0<ol001Xco`000ol0VC?o03?o000C
<ol000<0003oooooool0Foooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000J<ol000?o
09Tco`0co`004S?o00030000oooooooo05coool008Woool00`000?ooooooo`03oooo0`0001Xco`00
0ol0VC?o03?o000A<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000J<ol000?o09Tco`0co`004C?o00030000oooooooo05goool008Woool00`000?ooooooo`03
oooo00<0000co`0co`006S?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1Noooo0028oooo0P00
00Goool00`0003?o03?o000J<ol000?o09Tco`0co`003c?o00030000oooooooo05ooool008ooool0
0`0003?o03?o000J<ol000?o09Tco`0co`003S?o00030000oooooooo063oool008ooool00`0003?o
03?o000J<ol000?o09Tco`0co`003S?o00030000oooooooo063oool008ooool200006c?o0003o`2I
<ol0<ol000dco`000`000?ooooooo`1Qoooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol0
00`co`000`000?ooooooo`1Roooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol000`co`00
0`000?ooooooo`1Roooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol000/co`000`000?oo
ooooo`1Soooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1T
oooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1Uoooo002?
oooo0P0001/co`000ol0VC?o03?o0009<ol000<0003oooooool0IOooo`00Soooo`030000<ol0<ol0
01Xco`000ol0VC?o03?o0008<ol000<0003oooooool0I_ooo`00Soooo`030000<ol0<ol001Xco`00
0ol0VC?o03?o0007<ol000<0003oooooool0Ioooo`00Soooo`030000<ol0<ol001Xco`000ol0VC?o
03?o0007<ol000<0003oooooool0Ioooo`00Soooo`030000<ol0<ol001Xco`000ol0VC?o03?o0006
<ol000<0003oooooool0J?ooo`00Soooo`030000<ol0<ol001Xco`000ol0VC?o03?o0006<ol000<0
003oooooool0J?ooo`00Soooo`030000<ol0<ol001Xco`000ol0VC?o03?o0005<ol000<0003ooooo
ool0JOooo`00Soooo`80000K<ol000?o09Tco`0co`001C?o00030000oooooooo06Woool008ooool0
0`0003?o03?o000J<ol000?o09Tco`0co`0013?o00030000oooooooo06[oool008ooool00`0003?o
03?o000J<ol000?o09Tco`0co`0013?o00030000oooooooo06[oool008ooool00`0003?o03?o000J
<ol000?o09Tco`0co`000c?o00030000oooooooo06_oool008ooool00`0003?o03?o000J<ol000?o
09Tco`0co`000c?o00030000oooooooo06_oool008ooool00`0003?o03?o000J<ol000?o09Tco`0c
o`000c?o00030000oooooooo06_oool008ooool200006c?o0003o`2I<ol0<ol0008co`000`000?oo
ooooo`1/oooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1/
oooo002?oooo00<0000co`0co`006S?o0005o`2I<ol0<ol0<ol0000006ooool008ooool00`0003?o
03?o000J<ol000Go09Tco`0co`0co`000000Koooo`00Qoooo`@00004oooo00<0000co`0co`006S?o
0005o`2I<ol0<ol0<ol0000006ooool008Ooool00`000?ooooooo`05oooo00<0000co`0co`006S?o
0004o`2I<ol0<ol00000L?ooo`00R?ooo`030000oooooooo00Coool300006S?o0004o`2I<ol0<ol0
0000L?ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000J<ol000Co09Tco`0co`00001`
oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`006S?o0003o`2I<ol00000077oool0
08Soool200001Oooo`030000<ol0<ol001Xco`000ol0VC?o0000001aoooo002?oooo00<0000co`0c
o`006S?o0003o`2I0000oooo077oool008ooool00`0003?o03?o000J<ol000?o09T0003oool0LOoo
o`00Soooo`80000K<ol000?o09T0003oool0LOooo`00Soooo`030000<ol0<ol001Xco`000ol0VOoo
ooooo`1aoooo002?oooo00<0000co`0co`006S?o0003o`2Ioooooooo077oool008ooool00`0003?o
03?o000J<ol000?o09Woooooool0LOooo`00Soooo`030000<ol0<ol001Xco`000ol0VOooooooo`1a
oooo002?oooo00<0000co`0co`006C?o00030000o`2Ioooo07;oool008ooool00`0003?o03?o000I
<ol000<0003o09Woool0L_ooo`00Soooo`80000J<ol000<0003o09Woool0L_ooo`00Soooo`030000
<ol0<ol001Pco`000`000?ooool0V@1coooo002?oooo00<0000co`0co`0063?o00030000ooooo`2I
07?oool008ooool00`0003?o03?o000H<ol000<0003ooooo09T0Loooo`00Soooo`030000<ol0<ol0
01Lco`0010000?ooooooool0VG?oool008ooool00`0003?o03?o000G<ol000@0003ooooooooo09Uc
oooo002?oooo0P0001Pco`0010000?ooooooool0VG?oool008ooool00`0003?o03?o000G<ol000@0
003ooooooooo09Ucoooo002?oooo00<0000co`0co`005S?o00050000ooooooooooooo`2I07?oool0
08ooool00`0003?o03?o000F<ol000D0003ooooooooooooo09T0Loooo`00Soooo`030000<ol0<ol0
01Hco`001@000?ooooooooooool0V@1coooo002?oooo00<0000co`0co`005C?o00030000oooooooo
00;oool00ol0VOooooooo`1aoooo002?oooo0P0001Hco`000`000?ooooooo`02oooo00?o09Wooooo
ool0LOooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`02oooo00?o09Woooooool0LOoo
o`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`02oooo00?o09Woooooool0LOooo`00Sooo
o`030000<ol0<ol001@co`000`000?ooooooo`03oooo00?o09Woooooool0LOooo`00R?ooo`800005
oooo00<0000co`0co`0053?o00030000oooooooo00?oool00ol0VOooooooo`1aoooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0053?o00030000oooooooo00?oool00ol0VOooooooo`1a
oooo0029oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool01?ooo`03o`2Ioooooooo
077oool008[oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo00Coool0
0ol0VOooooooo`1aoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`004c?o00030000
oooooooo00Coool00ol0VOooooooo`1aoooo0028oooo0P0000Goool00`0003?o03?o000B<ol000<0
003oooooool01Oooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool01Oooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000B<ol000<0003oooooool01Ooo
o`03o`2Ioooooooo077oool008ooool00`0003?o03?o000B<ol000<0003oooooool01Oooo`03o`2I
oooooooo077oool008ooool200004S?o00030000oooooooo00Koool00ol0VOooooooo`1aoooo002?
oooo00<0000co`0co`004C?o00030000oooooooo00Koool00ol0VOooooooo`1aoooo002?oooo00<0
000co`0co`004C?o00030000oooooooo00Koool00ol0VOooooooo`1aoooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo00Koool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`0043?o
00030000oooooooo00Ooool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`0043?o00030000
oooooooo00Ooool00ol0VOooooooo`1aoooo002?oooo0P00014co`000`000?ooooooo`07oooo00?o
09Woooooool0LOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`07oooo00?o09Wooooo
ool0LOooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`08oooo00?o09Woooooool0LOoo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`08oooo00?o09Woooooool0LOooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`08oooo00?o09Woooooool0LOooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`08oooo00?o09Woooooool0LOooo`00Soooo`80000@<ol000<0
003oooooool02?ooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000><ol000<0003ooooo
ool02Oooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000><ol000<0003oooooool02Ooo
o`03o`2Ioooooooo077oool008ooool00`0003?o03?o000><ol000<0003oooooool02Oooo`03o`2I
oooooooo077oool008ooool00`0003?o03?o000><ol000<0003oooooool02Oooo`03o`2Ioooooooo
077oool008ooool00`0003?o03?o000><ol000<0003oooooool02Oooo`03o`2Ioooooooo077oool0
08ooool200003S?o00030000oooooooo00[oool00ol0VOooooooo`1aoooo002?oooo00<0000co`0c
o`003C?o00030000oooooooo00[oool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`003C?o
00030000oooooooo00[oool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`003C?o00030000
oooooooo00[oool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`0033?o00030000oooooooo
00_oool00ol0VOooooooo`1aoooo0029oooo0`0000?oool00`0003?o03?o000<<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo077oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0033?o
00030000oooooooo00_oool00ol0VOooooooo`1aoooo0027oooo1@0000?oool3000033?o00030000
oooooooo00_oool00ol0VOooooooo`1aoooo0027oooo00@0003oooooool00004oooo3c?o08;oool0
08Soool00`000?ooo`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o
08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o
00800003<ol010000004<ol0oooooooooooo0`0000;oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool00008<ol000<0000co`0co`000S?o00Coool01@000?ooooooooooo`00001joooo001goooo00<0
003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Tco`001@0003?o03?o03?o
0?ooo`0500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000
oooooooo00002S?o00050000<ol0<ol0oooo000000;oool01@000?ooooooooooo`00001joooo001h
oooo00D0003oooooooooool000003oooo`040000oooooooo000023?o00040000<ol0<ol000000ooo
o`030000oooo000000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:
<ol00P000003<ol0oooooooo00;oool200000_ooo`030000oooooooo07Woool008ooool=<ol0Q?oo
o`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59975 .12361 L
.60479 .12361 L
.61016 .12361 L
.61278 .12361 L
.61524 .12361 L
.61745 .12361 L
.61869 .12361 L
s
.61869 .12361 m
.61915 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.37114 .12361 L
.37372 .12361 L
.37649 .12361 L
.37783 .12361 L
.3791 .12361 L
.38025 .12361 L
.3815 .12332 L
.38215 .12299 L
.38283 .12264 L
.38405 .12201 L
.38681 .12062 L
.39182 .11816 L
.40117 .11376 L
.42214 .10482 L
.46012 .09154 L
.50054 .0809 L
.53945 .07237 L
.55926 .06824 L
.58081 .06394 L
.59085 .06201 L
.60151 .06001 L
.61061 .05836 L
.6131 .05791 L
.61579 .05744 L
.61703 .05722 L
.61833 .05699 L
.61944 .12361 L
.62066 .12361 L
.66122 .12361 L
.70026 .12361 L
.74176 .12361 L
.78174 .12361 L
.82021 .12361 L
.86113 .12361 L
.90053 .12361 L
.93842 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo01Koool606KoL_ooo`00Soooo`030000oooooooo00ooool706Ko1Oooo`0306Ko
oooooooo073oool008ooool00`000?ooooooo`0:oooo1@1Vo`coool00`1Vooooooooo`1`oooo002?
oooo00<0003oooooool01_ooo`@0I_lAoooo00<0I_ooooooool0L?ooo`00Soooo`800004oooo0`1V
oaGoool00`1Vooooooooo`1`oooo000Goooo1@0003?oool200001?ooo`800004oooo0P0003;oool0
0`000?ooo`1Vo`0306Ko6?ooo`0306Kooooooooo01Coool200001?ooo`800004oooo0P0003Coool5
00005Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Soool010000?ooooooo`00
02ooool206Ko00<00000I_ooool06oooo`0306Kooooooooo01?oool010000?ooooooo`0000Soool0
10000?ooooooo`0003Goool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000
oooooooo00002oooo`030000oooooooo02Soool506Ko0_ooo`030000oooooooo01_oool00`1Voooo
ooooo`0Coooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000oooooooo01Goool0
017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo00002Oooo`80000W
oooo101Vo`Ooool00`000?ooooooo`0Koooo00<0I_ooooooool04oooo`040000oooooooo00002Ooo
o`80000foooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`00
00Woool00`000?ooooooo`0Toooo0P1Vo`_oool00`000?ooooooo`0Koooo00<0I_ooooooool04ooo
o`040000oooooooo00002Oooo`030000oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P00
03Goool200002_ooo`<0000Qoooo0`1Vo`goool200007?ooo`0306Kooooooooo01Coool200002_oo
o`<0000doooo0P0001Ooool007goool206Ko4?ooo`030000oooooooo01_oool00`1Vooooooooo`1`
oooo001joooo0`1Voa;oool00`000?ooooooo`0Koooo00<0I_ooooooool0L?ooo`00N?ooo`80I_lE
oooo00<0003oooooool06oooo`0306Kooooooooo073oool007Koool206Ko5oooo`030000oooooooo
01_oool00`1Vooooooooo`1`oooo001doooo0P1VoaWoool00`000?ooooooo`0Koooo00<0I_oooooo
ool0L?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`000c?o0003o`2I
<ol0<ol000<co`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0
000co`0co`006c?o0003o`2I<ol0<ol001/co`000`0003?o03?o000f<ol01@0001Ooool008ooool0
0`0003?o03?o000K<ol000?o09Tco`0co`00C3?o00P0000Loooo002?oooo00<0000co`0co`006c?o
0003o`2I<ol0<ol004Hco`0600009?ooo`00Soooo`030000<ol0<ol001/co`000ol0VC?o03?o0011
<ol01@0002[oool008ooool00`0003?o03?o000K<ol000?o09Tco`0co`00?3?o00D0000_oooo002?
oooo0P0001`co`000ol0VC?o03?o000g<ol01@0003Coool008ooool00`0003?o03?o000K<ol000?o
09Tco`0co`00<c?o00@0000ioooo002?oooo00<0000co`0co`006c?o0003o`2I<ol0<ol0034co`02
0000?Oooo`00Soooo`030000<ol0<ol001/co`000ol0VC?o03?o000^<ol00`0003ooool008ooool0
0`0003?o03?o000K<ol000?o09Tco`0co`00;3?o00800012oooo002?oooo00<0000co`0co`006c?o
0003o`2I<ol0<ol002Xco`020000A?ooo`00Soooo`80000L<ol000?o09Tco`0co`00:3?o00800016
oooo002?oooo00<0000co`0co`006c?o0003o`2I<ol0<ol002Hco`020000B?ooo`00Soooo`030000
<ol0<ol001/co`000ol0VC?o03?o000U<ol000<0003oooooool0B?ooo`00Soooo`030000<ol0<ol0
01/co`000ol0VC?o03?o000S<ol00P0004_oool008ooool00`0003?o03?o000K<ol000?o09Tco`0c
o`008C?o0080001=oooo002?oooo00<0000co`0co`006c?o0003o`2I<ol0<ol0020co`000`000?oo
ooooo`1=oooo002?oooo0P0001`co`000ol0VC?o03?o000N<ol00P00053oool008ooool00`0003?o
03?o000K<ol000?o09Tco`0co`0073?o0080001Boooo002?oooo00<0000co`0co`006c?o0003o`2I
<ol0<ol001/co`000`000?ooooooo`1Boooo002?oooo00<0000co`0co`006c?o0003o`2I<ol0<ol0
01Xco`000`000?ooooooo`1Coooo002?oooo00<0000co`0co`006c?o0003o`2I<ol0<ol001Pco`02
0000E_ooo`00Soooo`030000<ol0<ol001/co`000ol0VC?o03?o000G<ol000<0003oooooool0E_oo
o`00Soooo`80000L<ol000?o09Tco`0co`005S?o00030000oooooooo05Ooool008ooool00`0003?o
03?o000K<ol000?o09Tco`0co`005C?o00030000oooooooo05Soool008ooool00`0003?o03?o000K
<ol000?o09Tco`0co`0053?o00030000oooooooo05Woool008ooool00`0003?o03?o000K<ol000?o
09Tco`0co`004c?o00030000oooooooo05[oool008ooool00`0003?o03?o000K<ol000?o09Tco`0c
o`004c?o00030000oooooooo05[oool008Ooool500000oooo`030000<ol0<ol001/co`000ol0VC?o
03?o000B<ol000<0003oooooool0Foooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000K
<ol000?o09Tco`0co`004C?o00030000oooooooo05coool008Woool00`000?ooooooo`03oooo0`00
01/co`000ol0VC?o03?o000@<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000K<ol000?o09Tco`0co`0043?o00030000oooooooo05goool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`006c?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1Noooo0028
oooo0P0000Goool00`0003?o03?o000K<ol000?o09Tco`0co`003S?o00030000oooooooo05ooool0
08ooool00`0003?o03?o000K<ol000?o09Tco`0co`003C?o00030000oooooooo063oool008ooool0
0`0003?o03?o000K<ol000?o09Tco`0co`003C?o00030000oooooooo063oool008ooool2000073?o
0003o`2I<ol0<ol000`co`000`000?ooooooo`1Qoooo002?oooo00<0000co`0co`006c?o0003o`2I
<ol0<ol000/co`000`000?ooooooo`1Roooo002?oooo00<0000co`0co`006c?o0003o`2I<ol0<ol0
00/co`000`000?ooooooo`1Roooo002?oooo00<0000co`0co`006c?o0003o`2I<ol0<ol000Xco`00
0`000?ooooooo`1Soooo002?oooo00<0000co`0co`006c?o0003o`2I<ol0<ol000Tco`000`000?oo
ooooo`1Toooo002?oooo00<0000co`0co`006c?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1U
oooo002?oooo0P0001`co`000ol0VC?o03?o0008<ol000<0003oooooool0IOooo`00Soooo`030000
<ol0<ol001/co`000ol0VC?o03?o0007<ol000<0003oooooool0I_ooo`00Soooo`030000<ol0<ol0
01/co`000ol0VC?o03?o0006<ol000<0003oooooool0Ioooo`00Soooo`030000<ol0<ol001/co`00
0ol0VC?o03?o0006<ol000<0003oooooool0Ioooo`00Soooo`030000<ol0<ol001/co`000ol0VC?o
03?o0005<ol000<0003oooooool0J?ooo`00Soooo`030000<ol0<ol001/co`000ol0VC?o03?o0005
<ol000<0003oooooool0J?ooo`00Soooo`030000<ol0<ol001/co`000ol0VC?o03?o0004<ol000<0
003oooooool0JOooo`00Soooo`80000L<ol000?o09Tco`0co`0013?o00030000oooooooo06Woool0
08ooool00`0003?o03?o000K<ol000?o09Tco`0co`000c?o00030000oooooooo06[oool008ooool0
0`0003?o03?o000K<ol000?o09Tco`0co`000c?o00030000oooooooo06[oool008ooool00`0003?o
03?o000K<ol000?o09Tco`0co`000S?o00030000oooooooo06_oool008ooool00`0003?o03?o000K
<ol000?o09Tco`0co`000S?o00030000oooooooo06_oool008ooool00`0003?o03?o000K<ol000?o
09Tco`0co`000S?o00030000oooooooo06_oool008ooool2000073?o0005o`2I<ol0<ol0<ol00000
06koool008ooool00`0003?o03?o000K<ol000Go09Tco`0co`0co`000000K_ooo`00Soooo`030000
<ol0<ol001/co`001?l0VC?o03?o000006ooool008ooool00`0003?o03?o000K<ol000Co09Tco`0c
o`00001_oooo0027oooo100000Coool00`0003?o03?o000K<ol000Co09Tco`0co`00001_oooo0027
oooo00<0003oooooool01Oooo`030000<ol0<ol001/co`000ol0VC?o0000001`oooo0028oooo00<0
003oooooool01?ooo`<0000K<ol000?o09Tco`000000L?ooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000K<ol000?o09Tco`000000L?ooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol001/co`000ol0V@000?ooo`1`oooo0028oooo0P0000Goool00`0003?o03?o000K<ol000?o
09T0003oool0L?ooo`00Soooo`030000<ol0<ol001/co`000ol0VOooooooo`1`oooo002?oooo00<0
000co`0co`006c?o0003o`2Ioooooooo073oool008ooool2000073?o0003o`2Ioooooooo073oool0
08ooool00`0003?o03?o000J<ol000<0003o09Woool0LOooo`00Soooo`030000<ol0<ol001Xco`00
0`000?l0VOooo`1aoooo002?oooo00<0000co`0co`006S?o00030000o`2Ioooo077oool008ooool0
0`0003?o03?o000J<ol000<0003o09Woool0LOooo`00Soooo`030000<ol0<ol001Tco`000`000?oo
ool0V@1boooo002?oooo00<0000co`0co`006C?o00030000ooooo`2I07;oool008ooool200006S?o
00030000ooooo`2I07;oool008ooool00`0003?o03?o000H<ol000@0003ooooooooo09Uboooo002?
oooo00<0000co`0co`0063?o00040000ooooooooo`2IL_ooo`00Soooo`030000<ol0<ol001Pco`00
10000?ooooooool0VG;oool008ooool00`0003?o03?o000G<ol000D0003ooooooooooooo09T0L_oo
o`00Soooo`030000<ol0<ol001Lco`001@000?ooooooooooool0V@1boooo002?oooo0P0001Pco`00
1@000?ooooooooooool0V@1boooo002?oooo00<0000co`0co`005c?o00050000ooooooooooooo`2I
07;oool008ooool00`0003?o03?o000F<ol000<0003oooooool00_ooo`03o`2Ioooooooo073oool0
08ooool00`0003?o03?o000F<ol000<0003oooooool00_ooo`03o`2Ioooooooo073oool008ooool0
0`0003?o03?o000F<ol000<0003oooooool00_ooo`03o`2Ioooooooo073oool008ooool00`0003?o
03?o000E<ol000<0003oooooool00oooo`03o`2Ioooooooo073oool008ooool200005S?o00030000
oooooooo00?oool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`005C?o00030000oooooooo
00?oool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`005C?o00030000oooooooo00?oool0
0ol0VOooooooo`1`oooo002?oooo00<0000co`0co`0053?o00030000oooooooo00Coool00ol0VOoo
ooooo`1`oooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool01?ooo`03o`2I
oooooooo073oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000D<ol000<0003ooooo
ool01?ooo`03o`2Ioooooooo073oool008Woool00`000?ooooooo`03oooo0`0001<co`000`000?oo
ooooo`05oooo00?o09Woooooool0L?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000C
<ol000<0003oooooool01Oooo`03o`2Ioooooooo073oool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o000C<ol000<0003oooooool01Oooo`03o`2Ioooooooo073oool008Soool200001Ooo
o`030000<ol0<ol0018co`000`000?ooooooo`06oooo00?o09Woooooool0L?ooo`00Soooo`030000
<ol0<ol0018co`000`000?ooooooo`06oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol0
018co`000`000?ooooooo`06oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`06oooo00?o09Woooooool0L?ooo`00Soooo`80000B<ol000<0003oooooool01ooo
o`03o`2Ioooooooo073oool008ooool00`0003?o03?o000A<ol000<0003oooooool01oooo`03o`2I
oooooooo073oool008ooool00`0003?o03?o000A<ol000<0003oooooool01oooo`03o`2Ioooooooo
073oool008ooool00`0003?o03?o000A<ol000<0003oooooool01oooo`03o`2Ioooooooo073oool0
08ooool00`0003?o03?o000@<ol000<0003oooooool02?ooo`03o`2Ioooooooo073oool008ooool0
0`0003?o03?o000@<ol000<0003oooooool02?ooo`03o`2Ioooooooo073oool008ooool200004C?o
00030000oooooooo00Soool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`0043?o00030000
oooooooo00Soool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`003c?o00030000oooooooo
00Woool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`003c?o00030000oooooooo00Woool0
0ol0VOooooooo`1`oooo002?oooo00<0000co`0co`003c?o00030000oooooooo00Woool00ol0VOoo
ooooo`1`oooo002?oooo00<0000co`0co`003c?o00030000oooooooo00Woool00ol0VOooooooo`1`
oooo002?oooo0P00010co`000`000?ooooooo`09oooo00?o09Woooooool0L?ooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`0:oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0:oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`0:oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`0:oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0:
oooo00?o09Woooooool0L?ooo`00Soooo`80000><ol000<0003oooooool02oooo`03o`2Ioooooooo
073oool008ooool00`0003?o03?o000=<ol000<0003oooooool02oooo`03o`2Ioooooooo073oool0
08ooool00`0003?o03?o000=<ol000<0003oooooool02oooo`03o`2Ioooooooo073oool008ooool0
0`0003?o03?o000=<ol000<0003oooooool02oooo`03o`2Ioooooooo073oool008ooool00`0003?o
03?o000<<ol000<0003oooooool03?ooo`03o`2Ioooooooo073oool008Woool300000oooo`030000
<ol0<ol000`co`000`000?ooooooo`0<oooo00?o09Woooooool0L?ooo`00R_ooo`030000oooooooo
00;oool00`0003?o03?o000<<ol000<0003oooooool03?ooo`03o`2Ioooooooo073oool008Ooool5
00000oooo`<0000<<ol000<0003oooooool03?ooo`03o`2Ioooooooo073oool008Ooool010000?oo
ooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004
oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0003oooooool04ooo
o`hco`07oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09
oooo3S?o00Soool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01oooo`800004<ol00P0000<co`04000000<co`3oooooool00P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00008<ol000<0000co`0co`000S?o0005oooo0000oooooooo0000
00?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool0
10000?ooooooo`0000Tco`00100003?o03?o03?o00Coool00`000?ooooooo`02oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000:<ol000<0000co`0c
o`000_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Pco`00100003?o03?o000000?oool00`000?ooooooo`03oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200002S?o0080000013?o0?ooooooooooo`<00002
oooo00<0003oooooool0NOooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61445 .12361 L
.61726 .12361 L
.61984 .12361 L
.62236 .12361 L
.62363 .12361 L
s
.62363 .12361 m
.62392 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.36626 .12361 L
.37114 .12361 L
.37257 .12361 L
.37393 .12361 L
.37515 .12361 L
.37585 .12361 L
.37649 .12345 L
.37776 .1228 L
.37891 .12221 L
.3815 .1209 L
.42157 .10318 L
.46012 .09012 L
.50112 .07972 L
.54061 .07136 L
.57858 .06379 L
.59972 .05983 L
.60974 .05803 L
.619 .05642 L
.6214 .05601 L
.62257 .05581 L
.62364 .05563 L
.62477 .12361 L
.62599 .12361 L
.62857 .12361 L
.63898 .12361 L
.65791 .12361 L
.69754 .12361 L
.73564 .12361 L
.77621 .12361 L
.81525 .12361 L
.85675 .12361 L
.89673 .12361 L
.9352 .12361 L
.97612 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool06oooo`80I_ma
oooo002?oooo00<0003oooooool05?ooo`L0I_l00oooo`1Vooooo`1`oooo002?oooo00<0003ooooo
ool03oooo`D0I_l8oooo00<0I_ooooooool0Koooo`00Soooo`030000oooooooo00[oool506Ko3Ooo
o`0306Kooooooooo06ooool008ooool00`000?ooooooo`05oooo1@1Voa;oool00`1Vooooooooo`1_
oooo002?oooo0P000003oooo06Ko06Ko00<0I_lGoooo00<0I_ooooooool0Koooo`005oooo`D0000c
oooo0P0000Coool200001?ooo`80000aoooo00@0I_l00000I_l0I_lLoooo00<0I_ooooooool04ooo
o`800004oooo0P0000Coool20000=?ooo`D0000Eoooo000Ioooo00<0003oooooool0<_ooo`040000
oooooooo00002?ooo`040000oooooooo0000;Oooo`<0I_l00oooo`000?ooo`0Moooo00<0I_oooooo
ool04_ooo`040000oooooooo00002?ooo`040000oooooooo0000=Oooo`030000oooooooo01Goool0
01Woool00`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0003oooooool09oooo`@0I_l4
oooo00<0003oooooool07?ooo`0306Kooooooooo01;oool010000?ooooooo`0000_oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?ooo`@00002
oooo00@0003oooooool00009oooo0P0002Ooool306Ko2?ooo`030000oooooooo01goool00`1Voooo
ooooo`0Aoooo00@0003oooooool00009oooo0P0003Koool00`000?ooooooo`0Eoooo000Ioooo00<0
003oooooool0<_ooo`040000oooooooo00002Oooo`030000oooooooo02?oool306Ko2oooo`030000
oooooooo01goool00`1Vooooooooo`0Aoooo00@0003oooooool00009oooo00<0003oooooool0=Ooo
o`030000oooooooo01Goool001Soool20000=Oooo`80000:oooo0`0001ooool406Ko3_ooo`80000N
oooo00<0I_ooooooool04_ooo`80000:oooo0`0003Coool200005oooo`00Noooo`80I_lBoooo00<0
003oooooool07Oooo`0306Kooooooooo06koool007Woool206Ko5?ooo`030000oooooooo01goool0
0`1Vooooooooo`1^oooo001goooo0P1VoaKoool00`000?ooooooo`0Moooo00<0I_ooooooool0K_oo
o`00MOooo`80I_lHoooo00<0003oooooool07Oooo`0306Kooooooooo06koool007?oool206Ko6_oo
o`030000oooooooo01goool00`1Vooooooooo`1^oooo000@ooooo`00017oool001Koool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0004<ol000?o09Tco`0co`000S?o00030000<ol0<ol000Tco`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool0>_ooo`030000oooooooo03Woool00`0003?o03?o000L<ol000?o09Tco`0co`006S?o00030000
<ol0<ol003Hco`0500005oooo`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o001;<ol02000
01coool008ooool00`0003?o03?o000L<ol000?o09Tco`0co`00AC?o00H0000Toooo002?oooo00<0
000co`0co`0073?o0003o`2I<ol0<ol0040co`050000:_ooo`00Soooo`030000<ol0<ol001`co`00
0ol0VC?o03?o000k<ol01@0002ooool008ooool200007C?o0003o`2I<ol0<ol003Hco`050000=?oo
o`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o000b<ol0100003Woool008ooool00`0003?o
03?o000L<ol000?o09Tco`0co`00<3?o0080000moooo002?oooo00<0000co`0co`0073?o0003o`2I
<ol0<ol002dco`030000?oooo`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o000[<ol00P00
04;oool008ooool00`0003?o03?o000L<ol000?o09Tco`0co`00:C?o00800014oooo002?oooo0P00
01dco`000ol0VC?o03?o000W<ol00P0004Koool008ooool00`0003?o03?o000L<ol000?o09Tco`0c
o`009C?o00800018oooo002?oooo00<0000co`0co`0073?o0003o`2I<ol0<ol002@co`000`000?oo
ooooo`18oooo002?oooo00<0000co`0co`0073?o0003o`2I<ol0<ol0028co`020000Boooo`00Sooo
o`030000<ol0<ol001`co`000ol0VC?o03?o000P<ol00P0004goool008ooool00`0003?o03?o000L
<ol000?o09Tco`0co`007c?o00030000oooooooo04goool008ooool200007C?o0003o`2I<ol0<ol0
01dco`020000D?ooo`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o000K<ol00P0005;oool0
08ooool00`0003?o03?o000L<ol000?o09Tco`0co`006S?o00030000oooooooo05;oool008ooool0
0`0003?o03?o000L<ol000?o09Tco`0co`006C?o00030000oooooooo05?oool008ooool00`0003?o
03?o000L<ol000?o09Tco`0co`005c?o0080001Foooo002?oooo00<0000co`0co`0073?o0003o`2I
<ol0<ol001Hco`000`000?ooooooo`1Foooo002?oooo0P0001dco`000ol0VC?o03?o000E<ol000<0
003oooooool0Eoooo`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o000D<ol000<0003ooooo
ool0F?ooo`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o000C<ol000<0003oooooool0FOoo
o`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o000B<ol000<0003oooooool0F_ooo`00Sooo
o`030000<ol0<ol001`co`000ol0VC?o03?o000B<ol000<0003oooooool0F_ooo`00Qoooo`D00003
oooo00<0000co`0co`0073?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1Koooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol001`co`000ol0VC?o03?o000@<ol000<0003oooooool0G?oo
o`00ROooo`030000oooooooo00?oool3000073?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1M
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001`co`000ol0VC?o03?o000?<ol000<0
003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000L<ol000?o09Tco`0c
o`003S?o00030000oooooooo05koool008Soool200001Oooo`030000<ol0<ol001`co`000ol0VC?o
03?o000=<ol000<0003oooooool0Goooo`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o000<
<ol000<0003oooooool0H?ooo`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o000<<ol000<0
003oooooool0H?ooo`00Soooo`80000M<ol000?o09Tco`0co`002c?o00030000oooooooo067oool0
08ooool00`0003?o03?o000L<ol000?o09Tco`0co`002S?o00030000oooooooo06;oool008ooool0
0`0003?o03?o000L<ol000?o09Tco`0co`002S?o00030000oooooooo06;oool008ooool00`0003?o
03?o000L<ol000?o09Tco`0co`002C?o00030000oooooooo06?oool008ooool00`0003?o03?o000L
<ol000?o09Tco`0co`0023?o00030000oooooooo06Coool008ooool00`0003?o03?o000L<ol000?o
09Tco`0co`001c?o00030000oooooooo06Goool008ooool200007C?o0003o`2I<ol0<ol000Lco`00
0`000?ooooooo`1Uoooo002?oooo00<0000co`0co`0073?o0003o`2I<ol0<ol000Hco`000`000?oo
ooooo`1Voooo002?oooo00<0000co`0co`0073?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1W
oooo002?oooo00<0000co`0co`0073?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1Woooo002?
oooo00<0000co`0co`0073?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1Xoooo002?oooo00<0
000co`0co`0073?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1Xoooo002?oooo00<0000co`0c
o`0073?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1Yoooo002?oooo0P0001dco`000ol0VC?o
03?o0003<ol000<0003oooooool0JOooo`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o0002
<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o0002<ol000<0
003oooooool0J_ooo`00Soooo`030000<ol0<ol001`co`001Ol0VC?o03?o03?o0000001]oooo002?
oooo00<0000co`0co`0073?o0005o`2I<ol0<ol0<ol0000006goool008ooool00`0003?o03?o000L
<ol000Go09Tco`0co`0co`000000KOooo`00Soooo`80000M<ol000Co09Tco`0co`00001^oooo002?
oooo00<0000co`0co`0073?o0004o`2I<ol0<ol00000K_ooo`00Soooo`030000<ol0<ol001`co`00
0ol0VC?o0000001_oooo002?oooo00<0000co`0co`0073?o0003o`2I<ol0000006ooool008Ooool4
00001?ooo`030000<ol0<ol001`co`000ol0VC?o0000001_oooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol001`co`000ol0V@000?ooo`1_oooo0028oooo00<0003oooooool01?ooo`<0000L
<ol000?o09T0003oool0Koooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000L<ol000?o
09T0003oool0Koooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001`co`000ol0VOoo
ooooo`1_oooo0028oooo0P0000Goool00`0003?o03?o000L<ol000?o09Woooooool0Koooo`00Sooo
o`030000<ol0<ol001/co`000`000?l0VOooo`1`oooo002?oooo00<0000co`0co`006c?o00030000
o`2Ioooo073oool008ooool2000073?o00030000o`2Ioooo073oool008ooool00`0003?o03?o000J
<ol000<0003ooooo09T0LOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooool0V@1aoooo002?
oooo00<0000co`0co`006S?o00030000ooooo`2I077oool008ooool00`0003?o03?o000J<ol000<0
003ooooo09T0LOooo`00Soooo`030000<ol0<ol001Tco`0010000?ooooooool0VG7oool008ooool0
0`0003?o03?o000I<ol000@0003ooooooooo09Uaoooo002?oooo0P0001Xco`0010000?ooooooool0
VG7oool008ooool00`0003?o03?o000H<ol000D0003ooooooooooooo09T0LOooo`00Soooo`030000
<ol0<ol001Pco`001@000?ooooooooooool0V@1aoooo002?oooo00<0000co`0co`0063?o00050000
ooooooooooooo`2I077oool008ooool00`0003?o03?o000G<ol000<0003oooooool00_ooo`03o`2I
oooooooo06ooool008ooool00`0003?o03?o000G<ol000<0003oooooool00_ooo`03o`2Ioooooooo
06ooool008ooool2000063?o00030000oooooooo00;oool00ol0VOooooooo`1_oooo002?oooo00<0
000co`0co`005c?o00030000oooooooo00;oool00ol0VOooooooo`1_oooo002?oooo00<0000co`0c
o`005S?o00030000oooooooo00?oool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`005S?o
00030000oooooooo00?oool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`005S?o00030000
oooooooo00?oool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`005C?o00030000oooooooo
00Coool00ol0VOooooooo`1_oooo002?oooo0P0001Hco`000`000?ooooooo`04oooo00?o09Wooooo
ool0Koooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`04oooo00?o09Woooooool0Kooo
o`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`04oooo00?o09Woooooool0Koooo`00Sooo
o`030000<ol0<ol001@co`000`000?ooooooo`05oooo00?o09Woooooool0Koooo`00R?ooo`800005
oooo00<0000co`0co`0053?o00030000oooooooo00Goool00ol0VOooooooo`1_oooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0053?o00030000oooooooo00Goool00ol0VOooooooo`1_
oooo0029oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool01_ooo`03o`2Ioooooooo
06ooool008[oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo00Koool0
0ol0VOooooooo`1_oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`004c?o00030000
oooooooo00Koool00ol0VOooooooo`1_oooo0028oooo0P0000Goool00`0003?o03?o000B<ol000<0
003oooooool01oooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000B<ol000<0003oooooool01ooo
o`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000B<ol000<0003oooooool01oooo`03o`2I
oooooooo06ooool008ooool200004S?o00030000oooooooo00Soool00ol0VOooooooo`1_oooo002?
oooo00<0000co`0co`004C?o00030000oooooooo00Soool00ol0VOooooooo`1_oooo002?oooo00<0
000co`0co`004C?o00030000oooooooo00Soool00ol0VOooooooo`1_oooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo00Soool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`0043?o
00030000oooooooo00Woool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`0043?o00030000
oooooooo00Woool00ol0VOooooooo`1_oooo002?oooo0P00014co`000`000?ooooooo`09oooo00?o
09Woooooool0Koooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`09oooo00?o09Wooooo
ool0Koooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0:oooo00?o09Woooooool0Kooo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0:oooo00?o09Woooooool0Koooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0:oooo00?o09Woooooool0Koooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0:oooo00?o09Woooooool0Koooo`00Soooo`80000@<ol000<0
003oooooool02_ooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000><ol000<0003ooooo
ool02oooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000><ol000<0003oooooool02ooo
o`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000><ol000<0003oooooool02oooo`03o`2I
oooooooo06ooool008ooool00`0003?o03?o000><ol000<0003oooooool02oooo`03o`2Ioooooooo
06ooool008ooool00`0003?o03?o000><ol000<0003oooooool02oooo`03o`2Ioooooooo06ooool0
08ooool200003S?o00030000oooooooo00coool00ol0VOooooooo`1_oooo002?oooo00<0000co`0c
o`003C?o00030000oooooooo00coool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`003C?o
00030000oooooooo00coool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`003C?o00030000
oooooooo00coool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`0033?o00030000oooooooo
00goool00ol0VOooooooo`1_oooo0029oooo0`0000?oool00`0003?o03?o000<<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo06ooool008[oool00`000?ooooooo`02oooo00<0000co`0co`0033?o
00030000oooooooo00goool00ol0VOooooooo`1_oooo0027oooo1@0000?oool3000033?o00030000
oooooooo00goool00ol0VOooooooo`1_oooo0027oooo00@0003oooooool00004oooo3c?o08;oool0
08Soool00`000?ooo`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o
08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o
00800003<ol010000003<ol0oooo000000800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
000023?o00030000<ol0<ol0008co`001Oooo`000?ooooooo`000003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00009<ol000H0
000co`0co`0co`3oool00002oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002S?o00040000<ol0<ol0oooo0`0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo000023?o
00040000<ol0<ol000000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`80000:<ol00P000004<ol0oooooooooooo0`0000;oool00`000?ooooooo`1i
oooo002?oooo3C?o08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61445 .12361 L
.61984 .12361 L
.62502 .12361 L
.62644 .12361 L
.62722 .12361 L
.62795 .12361 L
s
.62795 .12361 m
.62846 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.36626 .12361 L
.36876 .12361 L
.36999 .12361 L
.37114 .12361 L
.37178 .12342 L
.37247 .12307 L
.37393 .12232 L
.37649 .12102 L
.3815 .11854 L
.42308 .10081 L
.46315 .08788 L
.5017 .0786 L
.5427 .0702 L
.58219 .06256 L
.60205 .05894 L
.61073 .05741 L
.62016 .05579 L
.62268 .05537 L
.62537 .05492 L
.62647 .05474 L
.62765 .05454 L
.62896 .12361 L
.63018 .12361 L
.63967 .12361 L
.66059 .12361 L
.70173 .12361 L
.74135 .12361 L
.77946 .12361 L
.82002 .12361 L
.85906 .12361 L
.90056 .12361 L
.94054 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool06oooo`<0I_m`
oooo002?oooo00<0003oooooool05Oooo`H0I_l2oooo00<0I_ooooooool0K_ooo`00Soooo`030000
oooooooo013oool506Ko2?ooo`0306Kooooooooo06koool008ooool00`000?ooooooo`0;oooo1@1V
o`goool00`1Vooooooooo`1^oooo002?oooo00<0003oooooool01_ooo`D0I_lBoooo00<0I_oooooo
ool0K_ooo`00Soooo`8000000oooo`1Vo`1Vo`0406Ko5oooo`0306Kooooooooo06koool001Ooool5
0000<oooo`800004oooo0P0000Coool20000<?ooo`80I_l00`00001Vo`1Vo`0Moooo00<0I_oooooo
ool04_ooo`800004oooo0P0000Coool20000=?ooo`D0000Eoooo000Ioooo00<0003oooooool0<_oo
o`040000oooooooo00002?ooo`040000oooooooo0000:oooo`@0I_l2oooo00<0003oooooool07Ooo
o`0306Kooooooooo017oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02Goool406Ko1_ooo`030000oooooooo01goool00`1Vooooooooo`0Aoooo00@0003oooooool0000;
oooo00<0003oooooool0<oooo`030000oooooooo01Goool0017oool400001?ooo`030000oooooooo
02coool400000_ooo`040000oooooooo00002Oooo`80000Uoooo0`1Vo`[oool00`000?ooooooo`0N
oooo00<0I_ooooooool04?ooo`040000oooooooo00002Oooo`80000foooo00<0003oooooool05Ooo
o`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?ooooooo`0Roooo0P1V
o`goool00`000?ooooooo`0Noooo00<0I_ooooooool04?ooo`040000oooooooo00002Oooo`030000
oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000Ooooo0`1V
o`ooool200007oooo`0306Kooooooooo017oool200002_ooo`<0000doooo0P0001Ooool007[oool3
06Ko4_ooo`030000oooooooo01koool00`1Vooooooooo`1]oooo001hoooo0P1VoaGoool00`000?oo
ooooo`0Noooo00<0I_ooooooool0KOooo`00MOooo`<0I_lGoooo00<0003oooooool07_ooo`0306Ko
oooooooo06goool007?oool206Ko6_ooo`030000oooooooo01koool00`1Vooooooooo`1]oooo001a
oooo0P1Voacoool00`000?ooooooo`0Noooo00<0I_ooooooool0KOooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`001C?o0005o`2I<ol0<ol0<ol0000000/co`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool0>_ooo`030000oooooooo03Woool00`0003?o03?o000M<ol000?o09Tco`0co`006C?o00030000
<ol0<ol003Hco`0500005oooo`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o001:<ol02000
01coool008ooool00`0003?o03?o000M<ol000?o09Tco`0co`00A3?o00H0000Toooo002?oooo00<0
000co`0co`007C?o0003o`2I<ol0<ol003lco`050000:_ooo`00Soooo`030000<ol0<ol001dco`00
0ol0VC?o03?o000j<ol01@0002ooool008ooool200007S?o0003o`2I<ol0<ol003Dco`050000=?oo
o`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o000a<ol0100003Woool008ooool00`0003?o
03?o000M<ol000?o09Tco`0co`00;c?o0080000moooo002?oooo00<0000co`0co`007C?o0003o`2I
<ol0<ol002`co`030000?oooo`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o000Z<ol00P00
04;oool008ooool00`0003?o03?o000M<ol000?o09Tco`0co`00:3?o00800014oooo002?oooo0P00
01hco`000ol0VC?o03?o000V<ol00P0004Koool008ooool00`0003?o03?o000M<ol000?o09Tco`0c
o`0093?o00800018oooo002?oooo00<0000co`0co`007C?o0003o`2I<ol0<ol002<co`000`000?oo
ooooo`18oooo002?oooo00<0000co`0co`007C?o0003o`2I<ol0<ol0024co`020000Boooo`00Sooo
o`030000<ol0<ol001dco`000ol0VC?o03?o000O<ol00P0004goool008ooool00`0003?o03?o000M
<ol000?o09Tco`0co`007S?o00030000oooooooo04goool008ooool200007S?o0003o`2I<ol0<ol0
01`co`020000D?ooo`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o000J<ol00P0005;oool0
08ooool00`0003?o03?o000M<ol000?o09Tco`0co`006C?o00030000oooooooo05;oool008ooool0
0`0003?o03?o000M<ol000?o09Tco`0co`0063?o00030000oooooooo05?oool008ooool00`0003?o
03?o000M<ol000?o09Tco`0co`005S?o0080001Foooo002?oooo00<0000co`0co`007C?o0003o`2I
<ol0<ol001Dco`000`000?ooooooo`1Foooo002?oooo0P0001hco`000ol0VC?o03?o000D<ol000<0
003oooooool0Eoooo`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o000C<ol000<0003ooooo
ool0F?ooo`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o000B<ol000<0003oooooool0FOoo
o`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o000A<ol000<0003oooooool0F_ooo`00Sooo
o`030000<ol0<ol001dco`000ol0VC?o03?o000A<ol000<0003oooooool0F_ooo`00Qoooo`D00003
oooo00<0000co`0co`007C?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1Koooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol001dco`000ol0VC?o03?o000?<ol000<0003oooooool0G?oo
o`00ROooo`030000oooooooo00?oool300007C?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1M
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000ol0VC?o03?o000><ol000<0
003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000M<ol000?o09Tco`0c
o`003C?o00030000oooooooo05koool008Soool200001Oooo`030000<ol0<ol001dco`000ol0VC?o
03?o000<<ol000<0003oooooool0Goooo`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o000;
<ol000<0003oooooool0H?ooo`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o000;<ol000<0
003oooooool0H?ooo`00Soooo`80000N<ol000?o09Tco`0co`002S?o00030000oooooooo067oool0
08ooool00`0003?o03?o000M<ol000?o09Tco`0co`002C?o00030000oooooooo06;oool008ooool0
0`0003?o03?o000M<ol000?o09Tco`0co`002C?o00030000oooooooo06;oool008ooool00`0003?o
03?o000M<ol000?o09Tco`0co`0023?o00030000oooooooo06?oool008ooool00`0003?o03?o000M
<ol000?o09Tco`0co`001c?o00030000oooooooo06Coool008ooool00`0003?o03?o000M<ol000?o
09Tco`0co`001S?o00030000oooooooo06Goool008ooool200007S?o0003o`2I<ol0<ol000Hco`00
0`000?ooooooo`1Uoooo002?oooo00<0000co`0co`007C?o0003o`2I<ol0<ol000Dco`000`000?oo
ooooo`1Voooo002?oooo00<0000co`0co`007C?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1W
oooo002?oooo00<0000co`0co`007C?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1Woooo002?
oooo00<0000co`0co`007C?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1Xoooo002?oooo00<0
000co`0co`007C?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1Xoooo002?oooo00<0000co`0c
o`007C?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1Yoooo002?oooo0P0001hco`000ol0VC?o
03?o0002<ol000<0003oooooool0JOooo`00Soooo`030000<ol0<ol001dco`001Ol0VC?o03?o03?o
0000001/oooo002?oooo00<0000co`0co`007C?o0005o`2I<ol0<ol0<ol0000006coool008ooool0
0`0003?o03?o000M<ol000Co09Tco`0co`00001]oooo002?oooo00<0000co`0co`007C?o0004o`2I
<ol0<ol00000KOooo`00Soooo`030000<ol0<ol001dco`001?l0VC?o03?o000006goool008ooool2
00007S?o0003o`2I<ol0000006koool008ooool00`0003?o03?o000M<ol000?o09Tco`000000K_oo
o`00Soooo`030000<ol0<ol001dco`000ol0V@000?ooo`1^oooo002?oooo00<0000co`0co`007C?o
0003o`2I0000oooo06koool008Ooool400001?ooo`030000<ol0<ol001dco`000ol0V@000?ooo`1^
oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol001dco`000ol0VOooooooo`1^oooo0028
oooo00<0003oooooool01?ooo`<0000M<ol000?o09Woooooool0K_ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000M<ol000<0003o09Woool0K_ooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol001`co`000`000?ooool0V@1_oooo0028oooo0P0000Goool00`0003?o03?o000L
<ol000<0003ooooo09T0Koooo`00Soooo`030000<ol0<ol001/co`0010000?ooooooool0VFooool0
08ooool00`0003?o03?o000K<ol000@0003ooooooooo09U_oooo002?oooo0P0001`co`0010000?oo
ooooool0VFooool008ooool00`0003?o03?o000J<ol000D0003ooooooooooooo09T0Koooo`00Sooo
o`030000<ol0<ol001Xco`001@000?ooooooooooool0V@1_oooo002?oooo00<0000co`0co`006S?o
00050000ooooooooooooo`2I06ooool008ooool00`0003?o03?o000J<ol000D0003ooooooooooooo
09T0Koooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`02oooo00?o09Woooooool0KOoo
o`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`02oooo00?o09Woooooool0KOooo`00Sooo
o`80000J<ol000<0003oooooool00_ooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o000H
<ol000<0003oooooool00oooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o000H<ol000<0
003oooooool00oooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool00oooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o000G<ol000<0003oooooool01?oo
o`03o`2Ioooooooo06goool008ooool00`0003?o03?o000G<ol000<0003oooooool01?ooo`03o`2I
oooooooo06goool008ooool2000063?o00030000oooooooo00Coool00ol0VOooooooo`1]oooo002?
oooo00<0000co`0co`005c?o00030000oooooooo00Coool00ol0VOooooooo`1]oooo002?oooo00<0
000co`0co`005S?o00030000oooooooo00Goool00ol0VOooooooo`1]oooo002?oooo00<0000co`0c
o`005S?o00030000oooooooo00Goool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`005S?o
00030000oooooooo00Goool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`005C?o00030000
oooooooo00Koool00ol0VOooooooo`1]oooo002?oooo0P0001Hco`000`000?ooooooo`06oooo00?o
09Woooooool0KOooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`06oooo00?o09Wooooo
ool0KOooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`06oooo00?o09Woooooool0KOoo
o`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`07oooo00?o09Woooooool0KOooo`00R?oo
o`800005oooo00<0000co`0co`0053?o00030000oooooooo00Ooool00ol0VOooooooo`1]oooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`0053?o00030000oooooooo00Ooool00ol0VOoo
ooooo`1]oooo0029oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool02?ooo`03o`2I
oooooooo06goool008[oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo
00Soool00ol0VOooooooo`1]oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`004c?o
00030000oooooooo00Soool00ol0VOooooooo`1]oooo0028oooo0P0000Goool00`0003?o03?o000B
<ol000<0003oooooool02Oooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o000B<ol000<0
003oooooool02Oooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool02Oooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o000B<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo06goool008ooool200004S?o00030000oooooooo00[oool00ol0VOooooooo`1]
oooo002?oooo00<0000co`0co`004C?o00030000oooooooo00[oool00ol0VOooooooo`1]oooo002?
oooo00<0000co`0co`004C?o00030000oooooooo00[oool00ol0VOooooooo`1]oooo002?oooo00<0
000co`0co`004C?o00030000oooooooo00[oool00ol0VOooooooo`1]oooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo00_oool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`0043?o
00030000oooooooo00_oool00ol0VOooooooo`1]oooo002?oooo0P00014co`000`000?ooooooo`0;
oooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0;oooo00?o
09Woooooool0KOooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0<oooo00?o09Wooooo
ool0KOooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0<oooo00?o09Woooooool0KOoo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0<oooo00?o09Woooooool0KOooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0<oooo00?o09Woooooool0KOooo`00Soooo`80000@
<ol000<0003oooooool03?ooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o000><ol000<0
003oooooool03Oooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o000><ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o000><ol000<0003oooooool03Ooo
o`03o`2Ioooooooo06goool008ooool00`0003?o03?o000><ol000<0003oooooool03Oooo`03o`2I
oooooooo06goool008ooool00`0003?o03?o000><ol000<0003oooooool03Oooo`03o`2Ioooooooo
06goool008ooool200003S?o00030000oooooooo00koool00ol0VOooooooo`1]oooo002?oooo00<0
000co`0co`003C?o00030000oooooooo00koool00ol0VOooooooo`1]oooo002?oooo00<0000co`0c
o`003C?o00030000oooooooo00koool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`003C?o
00030000oooooooo00koool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`0033?o00030000
oooooooo00ooool00ol0VOooooooo`1]oooo0029oooo0`0000?oool00`0003?o03?o000<<ol000<0
003oooooool03oooo`03o`2Ioooooooo06goool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0033?o00030000oooooooo00ooool00ol0VOooooooo`1]oooo0027oooo1@0000?oool3000033?o
00030000oooooooo00ooool00ol0VOooooooo`1]oooo0027oooo00@0003oooooool00004oooo3c?o
08;oool008Soool00`000?ooo`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?
oooo3c?o08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2
000013?o00800003<ol010000005<ol0oooooooooooo000000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008<ol000<0000co`0co`000S?o00?oool00`000?ooooooo`02oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00009
<ol000@0000co`0co`0co`03oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002S?o00030000<ol0<ol000Coool01@000?oo
ooooooooo`00001joooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo000023?o
00040000<ol0<ol000000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000Xco`02000000<co`3oooooool0100000;oool00`000?ooooooo`1i
oooo002?oooo3C?o08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61984 .12361 L
.6254 .12361 L
.62812 .12361 L
.63064 .12361 L
.63182 .12361 L
.63292 .12361 L
s
.63292 .12361 m
.63338 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.35271 .12361 L
.36173 .12361 L
.36405 .12361 L
.3652 .12361 L
.36626 .12361 L
.36748 .12319 L
.36812 .12285 L
.36881 .1225 L
.37114 .12132 L
.3815 .11626 L
.42308 .09907 L
.46315 .08658 L
.5017 .07764 L
.5427 .06951 L
.58219 .06204 L
.60205 .05849 L
.62016 .05539 L
.62496 .0546 L
.62749 .05418 L
.63018 .05375 L
.63131 .05356 L
.63252 .05337 L
.63322 .05326 L
.63386 .12361 L
.63511 .12361 L
.63967 .12361 L
.66059 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool06_ooo`H0I_m^
oooo002?oooo00<0003oooooool05Oooo`D0I_l5oooo00<0I_ooooooool0K?ooo`00Soooo`030000
oooooooo013oool506Ko2_ooo`0306Kooooooooo06coool008ooool00`000?ooooooo`0;oooo1@1V
o`ooool00`1Vooooooooo`1/oooo002?oooo00<0003oooooool01_ooo`D0I_lDoooo00<0I_oooooo
ool0K?ooo`00Soooo`8000000oooo`1Vo`1Vo`0406Ko6Oooo`0306Kooooooooo06coool001Ooool5
0000<oooo`800004oooo0P0000Coool20000<?ooo`80I_l00`00001Vo`1Vo`0Ooooo00<0I_oooooo
ool04?ooo`800004oooo0P0000Coool20000=?ooo`D0000Eoooo000Ioooo00<0003oooooool0<_oo
o`040000oooooooo00002?ooo`040000oooooooo0000:oooo`@0I_l2oooo00<0003oooooool07ooo
o`0306Kooooooooo00ooool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
02Goool406Ko1_ooo`030000oooooooo01ooool00`1Vooooooooo`0?oooo00@0003oooooool0000;
oooo00<0003oooooool0<oooo`030000oooooooo01Goool0017oool400001?ooo`030000oooooooo
02coool400000_ooo`040000oooooooo00002Oooo`80000Toooo101Vo`[oool00`000?ooooooo`0O
oooo00<0I_ooooooool03oooo`040000oooooooo00002Oooo`80000foooo00<0003oooooool05Ooo
o`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?ooooooo`0Ooooo101V
o`koool00`000?ooooooo`0Ooooo00<0I_ooooooool03oooo`040000oooooooo00002Oooo`030000
oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000Moooo0P1V
oa;oool200008?ooo`0306Kooooooooo013oool200002_ooo`<0000doooo0P0001Ooool007Woool2
06Ko5?ooo`030000oooooooo01ooool00`1Vooooooooo`1/oooo001goooo0P1VoaKoool00`000?oo
ooooo`0Ooooo00<0I_ooooooool0K?ooo`00MOooo`80I_lHoooo00<0003oooooool07oooo`0306Ko
oooooooo06coool007?oool206Ko6_ooo`030000oooooooo01ooool00`1Vooooooooo`1/oooo001`
oooo0`1Voacoool00`000?ooooooo`0Ooooo00<0I_ooooooool0K?ooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`001c?o0003o`2I<ol0000000/co`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000O<ol000?o09Tco`0co`005c?o00030000<ol0<ol0
03Hco`0500005oooo`00Soooo`030000<ol0<ol001lco`000ol0VC?o03?o0018<ol0200001coool0
08ooool00`0003?o03?o000O<ol000?o09Tco`0co`00@S?o00H0000Toooo002?oooo00<0000co`0c
o`007c?o0003o`2I<ol0<ol003dco`050000:_ooo`00Soooo`030000<ol0<ol001lco`000ol0VC?o
03?o000h<ol01@0002ooool008ooool2000083?o0003o`2I<ol0<ol003<co`050000=?ooo`00Sooo
o`030000<ol0<ol001lco`000ol0VC?o03?o000_<ol0100003Woool008ooool00`0003?o03?o000O
<ol000?o09Tco`0co`00;C?o0080000moooo002?oooo00<0000co`0co`007c?o0003o`2I<ol0<ol0
02Xco`030000?oooo`00Soooo`030000<ol0<ol001lco`000ol0VC?o03?o000X<ol00P0004;oool0
08ooool00`0003?o03?o000O<ol000?o09Tco`0co`009S?o00800014oooo002?oooo0P00020co`00
0ol0VC?o03?o000T<ol00P0004Koool008ooool00`0003?o03?o000O<ol000?o09Tco`0co`008S?o
00800018oooo002?oooo00<0000co`0co`007c?o0003o`2I<ol0<ol0024co`000`000?ooooooo`18
oooo002?oooo00<0000co`0co`007c?o0003o`2I<ol0<ol001lco`020000Boooo`00Soooo`030000
<ol0<ol001lco`000ol0VC?o03?o000M<ol00P0004goool008ooool00`0003?o03?o000O<ol000?o
09Tco`0co`0073?o00030000oooooooo04goool008ooool2000083?o0003o`2I<ol0<ol001Xco`02
0000D?ooo`00Soooo`030000<ol0<ol001lco`000ol0VC?o03?o000H<ol00P0005;oool008ooool0
0`0003?o03?o000O<ol000?o09Tco`0co`005c?o00030000oooooooo05;oool008ooool00`0003?o
03?o000O<ol000?o09Tco`0co`005S?o00030000oooooooo05?oool008ooool00`0003?o03?o000O
<ol000?o09Tco`0co`0053?o0080001Foooo002?oooo00<0000co`0co`007c?o0003o`2I<ol0<ol0
01<co`000`000?ooooooo`1Foooo002?oooo0P00020co`000ol0VC?o03?o000B<ol000<0003ooooo
ool0Eoooo`00Soooo`030000<ol0<ol001lco`000ol0VC?o03?o000A<ol000<0003oooooool0F?oo
o`00Soooo`030000<ol0<ol001lco`000ol0VC?o03?o000@<ol000<0003oooooool0FOooo`00Sooo
o`030000<ol0<ol001lco`000ol0VC?o03?o000?<ol000<0003oooooool0F_ooo`00Soooo`030000
<ol0<ol001lco`000ol0VC?o03?o000?<ol000<0003oooooool0F_ooo`00Qoooo`D00003oooo00<0
000co`0co`007c?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1Koooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol001lco`000ol0VC?o03?o000=<ol000<0003oooooool0G?ooo`00ROoo
o`030000oooooooo00?oool300007c?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1Moooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol001lco`000ol0VC?o03?o000<<ol000<0003ooooo
ool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000O<ol000?o09Tco`0co`002c?o
00030000oooooooo05koool008Soool200001Oooo`030000<ol0<ol001lco`000ol0VC?o03?o000:
<ol000<0003oooooool0Goooo`00Soooo`030000<ol0<ol001lco`000ol0VC?o03?o0009<ol000<0
003oooooool0H?ooo`00Soooo`030000<ol0<ol001lco`000ol0VC?o03?o0009<ol000<0003ooooo
ool0H?ooo`00Soooo`80000P<ol000?o09Tco`0co`0023?o00030000oooooooo067oool008ooool0
0`0003?o03?o000O<ol000?o09Tco`0co`001c?o00030000oooooooo06;oool008ooool00`0003?o
03?o000O<ol000?o09Tco`0co`001c?o00030000oooooooo06;oool008ooool00`0003?o03?o000O
<ol000?o09Tco`0co`001S?o00030000oooooooo06?oool008ooool00`0003?o03?o000O<ol000?o
09Tco`0co`001C?o00030000oooooooo06Coool008ooool00`0003?o03?o000O<ol000?o09Tco`0c
o`0013?o00030000oooooooo06Goool008ooool2000083?o0003o`2I<ol0<ol000@co`000`000?oo
ooooo`1Uoooo002?oooo00<0000co`0co`007c?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1V
oooo002?oooo00<0000co`0co`007c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1Woooo002?
oooo00<0000co`0co`007c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1Woooo002?oooo00<0
000co`0co`007c?o0005o`2I<ol0<ol0<ol0000006[oool008ooool00`0003?o03?o000O<ol000Go
09Tco`0co`0co`000000J_ooo`00Soooo`030000<ol0<ol001lco`001?l0VC?o03?o000006_oool0
08ooool2000083?o0004o`2I<ol0<ol00000Joooo`00Soooo`030000<ol0<ol001lco`000ol0VC?o
0000001/oooo002?oooo00<0000co`0co`007c?o0003o`2I<ol0000006coool008ooool00`0003?o
03?o000O<ol000?o09T0003oool0K?ooo`00Soooo`030000<ol0<ol001lco`000ol0V@000?ooo`1/
oooo002?oooo00<0000co`0co`007c?o0003o`2I0000oooo06coool008ooool2000083?o0003o`2I
oooooooo06coool008ooool00`0003?o03?o000O<ol000?o09Woooooool0K?ooo`00Soooo`030000
<ol0<ol001hco`000`000?l0VOooo`1]oooo002?oooo00<0000co`0co`007S?o00030000o`2Ioooo
06goool008Ooool400001?ooo`030000<ol0<ol001hco`000`000?l0VOooo`1]oooo0027oooo00<0
003oooooool01Oooo`030000<ol0<ol001dco`000`000?ooool0V@1^oooo0028oooo00<0003ooooo
ool01?ooo`<0000M<ol000<0003ooooo09T0K_ooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000M<ol000<0003ooooo09T0K_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
01`co`0010000?ooooooool0VFkoool008Soool200001Oooo`030000<ol0<ol001`co`0010000?oo
ooooool0VFkoool008ooool00`0003?o03?o000K<ol000D0003ooooooooooooo09T0K_ooo`00Sooo
o`030000<ol0<ol001/co`001@000?ooooooooooool0V@1^oooo002?oooo0P0001`co`001@000?oo
ooooooooool0V@1^oooo002?oooo00<0000co`0co`006S?o00030000oooooooo00;oool00ol0VOoo
ooooo`1/oooo002?oooo00<0000co`0co`006S?o00030000oooooooo00;oool00ol0VOooooooo`1/
oooo002?oooo00<0000co`0co`006S?o00030000oooooooo00;oool00ol0VOooooooo`1/oooo002?
oooo00<0000co`0co`006S?o00030000oooooooo00;oool00ol0VOooooooo`1/oooo002?oooo00<0
000co`0co`006C?o00030000oooooooo00?oool00ol0VOooooooo`1/oooo002?oooo00<0000co`0c
o`006C?o00030000oooooooo00?oool00ol0VOooooooo`1/oooo002?oooo0P0001Xco`000`000?oo
ooooo`03oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`04
oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`04oooo00?o
09Woooooool0K?ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`04oooo00?o09Wooooo
ool0K?ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`05oooo00?o09Woooooool0K?oo
o`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`05oooo00?o09Woooooool0K?ooo`00Sooo
o`80000H<ol000<0003oooooool01Oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000G
<ol000<0003oooooool01Oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000F<ol000<0
003oooooool01_ooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000F<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000F<ol000<0003oooooool01_oo
o`03o`2Ioooooooo06coool008ooool00`0003?o03?o000E<ol000<0003oooooool01oooo`03o`2I
oooooooo06coool008ooool200005S?o00030000oooooooo00Ooool00ol0VOooooooo`1/oooo002?
oooo00<0000co`0co`005C?o00030000oooooooo00Ooool00ol0VOooooooo`1/oooo002?oooo00<0
000co`0co`005C?o00030000oooooooo00Ooool00ol0VOooooooo`1/oooo002?oooo00<0000co`0c
o`0053?o00030000oooooooo00Soool00ol0VOooooooo`1/oooo0028oooo0P0000Goool00`0003?o
03?o000D<ol000<0003oooooool02?ooo`03o`2Ioooooooo06coool008Ooool010000?ooooooo`00
00Coool00`0003?o03?o000D<ol000<0003oooooool02?ooo`03o`2Ioooooooo06coool008Woool0
0`000?ooooooo`03oooo0`0001<co`000`000?ooooooo`09oooo00?o09Woooooool0K?ooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o000C<ol000<0003oooooool02Oooo`03o`2Ioooooooo
06coool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000C<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo06coool008Soool200001Oooo`030000<ol0<ol0018co`000`000?ooooooo`0:
oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0:oooo00?o
09Woooooool0K?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0:oooo00?o09Wooooo
ool0K?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0:oooo00?o09Woooooool0K?oo
o`00Soooo`80000B<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool008ooool00`0003?o
03?o000A<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000A
<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000A<ol000<0
003oooooool02oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool03?ooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000@<ol000<0003oooooool03?oo
o`03o`2Ioooooooo06coool008ooool200004C?o00030000oooooooo00coool00ol0VOooooooo`1/
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo00coool00ol0VOooooooo`1/oooo002?
oooo00<0000co`0co`003c?o00030000oooooooo00goool00ol0VOooooooo`1/oooo002?oooo00<0
000co`0co`003c?o00030000oooooooo00goool00ol0VOooooooo`1/oooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo00goool00ol0VOooooooo`1/oooo002?oooo00<0000co`0co`003c?o
00030000oooooooo00goool00ol0VOooooooo`1/oooo002?oooo0P00010co`000`000?ooooooo`0=
oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0>oooo00?o
09Woooooool0K?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0>oooo00?o09Wooooo
ool0K?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0>oooo00?o09Woooooool0K?oo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0>oooo00?o09Woooooool0K?ooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`0>oooo00?o09Woooooool0K?ooo`00Soooo`80000>
<ol000<0003oooooool03oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000=<ol000<0
003oooooool03oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000=<ol000<0003ooooo
ool03oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o000=<ol000<0003oooooool03ooo
o`03o`2Ioooooooo06coool008ooool00`0003?o03?o000<<ol000<0003oooooool04?ooo`03o`2I
oooooooo06coool008Woool300000oooo`030000<ol0<ol000`co`000`000?ooooooo`0@oooo00?o
09Woooooool0K?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000<<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo06coool008Ooool500000oooo`<0000<<ol000<0003oooooool04?oo
o`03o`2Ioooooooo06coool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000
oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Sooo
o`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07oooo00<0003oooooool0NOooo`00N?oo
o`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o00Soool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004<ol00P0000<co`04
000000<co`3oooooool00P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008<ol000<0
000co`0co`000S?o0005oooo0000oooooooo000000?oool00`000?ooooooo`1hoooo001goooo00<0
003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Tco`001P0003?o03?o03?o
0?ooo`0000;oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000<oooo00@0003oooooool0000:<ol000<0000co`0co`000_ooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Pco`00100003?o
03?o000000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`80000:<ol00P000004<ol0oooooooooooo0P0000?oool00`000?ooooooo`1ioooo002?
oooo3C?o08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61984 .12361 L
.6254 .12361 L
.63064 .12361 L
.63534 .12361 L
.63663 .12361 L
.63733 .12361 L
.63799 .12361 L
s
.63799 .12361 m
.63845 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.35271 .12361 L
.35742 .12361 L
.35948 .12361 L
.36057 .12361 L
.36173 .12361 L
.36294 .12307 L
.36405 .1225 L
.36626 .12137 L
.37114 .11895 L
.3815 .11404 L
.42308 .0974 L
.46315 .08533 L
.5017 .07671 L
.5427 .06885 L
.58219 .06156 L
.60205 .05806 L
.62016 .05502 L
.62496 .05423 L
.63018 .05339 L
.63257 .05301 L
.63511 .05261 L
.63615 .05245 L
.63728 .05227 L
.63851 .12361 L
.63967 .12361 L
.66059 .12361 L
.70173 .12361 L
.74135 .12361 L
.77946 .12361 L
.82002 .12361 L
.85906 .12361 L
.90056 .12361 L
.94054 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80000Poooo0P1Vofgoool008ooool00`000?ooooooo`0J
oooo1`1Vofgoool008ooool00`000?ooooooo`0Eoooo1@1Vo`Koool00`1Vooooooooo`1[oooo002?
oooo00<0003oooooool04?ooo`D0I_l;oooo00<0I_ooooooool0Joooo`00Soooo`030000oooooooo
00_oool506Ko4?ooo`0306Kooooooooo06_oool008ooool00`000?ooooooo`06oooo1@1VoaGoool0
0`1Vooooooooo`1[oooo002?oooo0P000003oooo06Ko06Ko00@0I_lJoooo00<0I_ooooooool0Jooo
o`005oooo`D0000coooo0P0000Coool200001?ooo`80000`oooo0P1Vo`03000006Ko06Ko023oool0
0`1Vooooooooo`0?oooo0P0000Coool200001?ooo`80000doooo1@0001Goool001Woool00`000?oo
ooooo`0boooo00@0003oooooool00008oooo00@0003oooooool0000[oooo101Vo`;oool00`000?oo
ooooo`0Poooo00<0I_ooooooool03_ooo`040000oooooooo00002?ooo`040000oooooooo0000=Ooo
o`030000oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0
003oooooool09Oooo`@0I_l6oooo00<0003oooooool08?ooo`0306Kooooooooo00koool010000?oo
ooooo`0000_oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0
003oooooool0;?ooo`@00002oooo00@0003oooooool00009oooo0P0002Coool406Ko2_ooo`030000
oooooooo023oool00`1Vooooooooo`0>oooo00@0003oooooool00009oooo0P0003Koool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002Oooo`030000oooooooo
01ooool406Ko3_ooo`030000oooooooo023oool00`1Vooooooooo`0>oooo00@0003oooooool00009
oooo00<0003oooooool0=Oooo`030000oooooooo01Goool001Soool20000=Oooo`80000:oooo0`00
01coool306Ko4_ooo`80000Qoooo00<0I_ooooooool03oooo`80000:oooo0`0003Coool200005ooo
o`00N?ooo`80I_lEoooo00<0003oooooool08?ooo`0306Kooooooooo06_oool007Goool306Ko5ooo
o`030000oooooooo023oool00`1Vooooooooo`1[oooo001coooo0P1Voa[oool00`000?ooooooo`0P
oooo00<0I_ooooooool0Joooo`00L?ooo`<0I_lLoooo00<0003oooooool08?ooo`0306Kooooooooo
06_oool006koool206Ko7oooo`030000oooooooo023oool00`1Vooooooooo`1[oooo000@ooooo`00
017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0008<ol000?o09T0000co`002S?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Xco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000oooooooo01Goool001Koool00`000?oo
ooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0020co`000ol0VC?o03?o000F<ol000<0
000co`0co`00=S?o00D0000Goooo002?oooo00<0000co`0co`0083?o0003o`2I<ol0<ol004Lco`08
00007?ooo`00Soooo`030000<ol0<ol0020co`000ol0VC?o03?o0011<ol01P0002Coool008ooool0
0`0003?o03?o000P<ol000?o09Tco`0co`00?3?o00D0000Zoooo002?oooo00<0000co`0co`0083?o
0003o`2I<ol0<ol003Lco`050000;oooo`00Soooo`80000Q<ol000?o09Tco`0co`00<S?o00D0000d
oooo002?oooo00<0000co`0co`0083?o0003o`2I<ol0<ol002hco`040000>Oooo`00Soooo`030000
<ol0<ol0020co`000ol0VC?o03?o000/<ol00P0003goool008ooool00`0003?o03?o000P<ol000?o
09Tco`0co`00:C?o00<0000ooooo002?oooo00<0000co`0co`0083?o0003o`2I<ol0<ol002Lco`02
0000@_ooo`00Soooo`030000<ol0<ol0020co`000ol0VC?o03?o000U<ol00P0004Coool008ooool2
00008C?o0003o`2I<ol0<ol002<co`020000A_ooo`00Soooo`030000<ol0<ol0020co`000ol0VC?o
03?o000Q<ol00P0004Soool008ooool00`0003?o03?o000P<ol000?o09Tco`0co`0083?o00030000
oooooooo04Soool008ooool00`0003?o03?o000P<ol000?o09Tco`0co`007S?o0080001;oooo002?
oooo00<0000co`0co`0083?o0003o`2I<ol0<ol001`co`020000COooo`00Soooo`030000<ol0<ol0
020co`000ol0VC?o03?o000K<ol000<0003oooooool0COooo`00Soooo`80000Q<ol000?o09Tco`0c
o`006C?o0080001@oooo002?oooo00<0000co`0co`0083?o0003o`2I<ol0<ol001Lco`020000D_oo
o`00Soooo`030000<ol0<ol0020co`000ol0VC?o03?o000F<ol000<0003oooooool0D_ooo`00Sooo
o`030000<ol0<ol0020co`000ol0VC?o03?o000E<ol000<0003oooooool0Doooo`00Soooo`030000
<ol0<ol0020co`000ol0VC?o03?o000C<ol00P0005Koool008ooool00`0003?o03?o000P<ol000?o
09Tco`0co`004S?o00030000oooooooo05Koool008ooool200008C?o0003o`2I<ol0<ol0014co`00
0`000?ooooooo`1Goooo002?oooo00<0000co`0co`0083?o0003o`2I<ol0<ol0010co`000`000?oo
ooooo`1Hoooo002?oooo00<0000co`0co`0083?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1I
oooo002?oooo00<0000co`0co`0083?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1Joooo002?
oooo00<0000co`0co`0083?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1Joooo0027oooo1@00
00?oool00`0003?o03?o000P<ol000?o09Tco`0co`003C?o00030000oooooooo05_oool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`0083?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1L
oooo0029oooo00<0003oooooool00oooo`<0000P<ol000?o09Tco`0co`002c?o00030000oooooooo
05goool008Woool00`000?ooooooo`03oooo00<0000co`0co`0083?o0003o`2I<ol0<ol000/co`00
0`000?ooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0020co`000ol0VC?o
03?o000:<ol000<0003oooooool0G_ooo`00R?ooo`800005oooo00<0000co`0co`0083?o0003o`2I
<ol0<ol000Tco`000`000?ooooooo`1Ooooo002?oooo00<0000co`0co`0083?o0003o`2I<ol0<ol0
00Pco`000`000?ooooooo`1Poooo002?oooo00<0000co`0co`0083?o0003o`2I<ol0<ol000Pco`00
0`000?ooooooo`1Poooo002?oooo0P00024co`000ol0VC?o03?o0007<ol000<0003oooooool0HOoo
o`00Soooo`030000<ol0<ol0020co`000ol0VC?o03?o0006<ol000<0003oooooool0H_ooo`00Sooo
o`030000<ol0<ol0020co`000ol0VC?o03?o0006<ol000<0003oooooool0H_ooo`00Soooo`030000
<ol0<ol0020co`000ol0VC?o03?o0005<ol000<0003oooooool0Hoooo`00Soooo`030000<ol0<ol0
020co`000ol0VC?o03?o0004<ol000<0003oooooool0I?ooo`00Soooo`030000<ol0<ol0020co`00
0ol0VC?o03?o0003<ol000<0003oooooool0IOooo`00Soooo`80000Q<ol000?o09Tco`0co`000c?o
00030000oooooooo06Goool008ooool00`0003?o03?o000P<ol000?o09Tco`0co`000S?o00030000
oooooooo06Koool008ooool00`0003?o03?o000P<ol000Go09Tco`0co`0co`000000JOooo`00Sooo
o`030000<ol0<ol0020co`001Ol0VC?o03?o03?o0000001Yoooo002?oooo00<0000co`0co`0083?o
0004o`2I<ol0<ol00000J_ooo`00Soooo`030000<ol0<ol0020co`001?l0VC?o03?o000006[oool0
08ooool00`0003?o03?o000P<ol000?o09Tco`000000Joooo`00Soooo`80000Q<ol000?o09Tco`00
0000Joooo`00Soooo`030000<ol0<ol0020co`000ol0V@000?ooo`1[oooo002?oooo00<0000co`0c
o`0083?o0003o`2I0000oooo06_oool008ooool00`0003?o03?o000P<ol000?o09Woooooool0Jooo
o`00Soooo`030000<ol0<ol0020co`000ol0VOooooooo`1[oooo002?oooo00<0000co`0co`0083?o
0003o`2Ioooooooo06_oool008ooool2000083?o00030000o`2Ioooo06coool008ooool00`0003?o
03?o000O<ol000<0003o09Woool0K?ooo`00Soooo`030000<ol0<ol001hco`000`000?ooool0V@1]
oooo002?oooo00<0000co`0co`007S?o00030000ooooo`2I06goool008Ooool400001?ooo`030000
<ol0<ol001hco`000`000?ooool0V@1]oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol0
01dco`0010000?ooooooool0VFgoool008Soool00`000?ooooooo`04oooo0`0001dco`0010000?oo
ooooool0VFgoool008Woool00`000?ooooooo`03oooo00<0000co`0co`007C?o00040000oooooooo
o`2IKOooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001`co`001@000?oooooooooo
ool0V@1]oooo0028oooo0P0000Goool00`0003?o03?o000L<ol000D0003ooooooooooooo09T0KOoo
o`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`02oooo00?o09Woooooool0Joooo`00Sooo
o`030000<ol0<ol001/co`000`000?ooooooo`02oooo00?o09Woooooool0Joooo`00Soooo`80000L
<ol000<0003oooooool00_ooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000J<ol000<0
003oooooool00oooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000J<ol000<0003ooooo
ool00oooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000J<ol000<0003oooooool00ooo
o`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000J<ol000<0003oooooool00oooo`03o`2I
oooooooo06_oool008ooool00`0003?o03?o000I<ol000<0003oooooool01?ooo`03o`2Ioooooooo
06_oool008ooool00`0003?o03?o000I<ol000<0003oooooool01?ooo`03o`2Ioooooooo06_oool0
08ooool200006S?o00030000oooooooo00Coool00ol0VOooooooo`1[oooo002?oooo00<0000co`0c
o`0063?o00030000oooooooo00Goool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`0063?o
00030000oooooooo00Goool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`0063?o00030000
oooooooo00Goool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`005c?o00030000oooooooo
00Koool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`005c?o00030000oooooooo00Koool0
0ol0VOooooooo`1[oooo002?oooo0P0001Pco`000`000?ooooooo`06oooo00?o09Woooooool0Jooo
o`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`06oooo00?o09Woooooool0Joooo`00Sooo
o`030000<ol0<ol001Hco`000`000?ooooooo`07oooo00?o09Woooooool0Joooo`00Soooo`030000
<ol0<ol001Hco`000`000?ooooooo`07oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol0
01Hco`000`000?ooooooo`07oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol001Dco`00
0`000?ooooooo`08oooo00?o09Woooooool0Joooo`00Soooo`80000F<ol000<0003oooooool02?oo
o`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000E<ol000<0003oooooool02?ooo`03o`2I
oooooooo06_oool008ooool00`0003?o03?o000E<ol000<0003oooooool02?ooo`03o`2Ioooooooo
06_oool008ooool00`0003?o03?o000D<ol000<0003oooooool02Oooo`03o`2Ioooooooo06_oool0
08Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`09oooo00?o09Woooooool0Jooo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001@co`000`000?ooooooo`09oooo00?o
09Woooooool0Joooo`00ROooo`030000oooooooo00?oool300004c?o00030000oooooooo00[oool0
0ol0VOooooooo`1[oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol001<co`000`000?oo
ooooo`0:oooo00?o09Woooooool0Joooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
01<co`000`000?ooooooo`0:oooo00?o09Woooooool0Joooo`00R?ooo`800005oooo00<0000co`0c
o`004S?o00030000oooooooo00_oool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`004S?o
00030000oooooooo00_oool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`004S?o00030000
oooooooo00_oool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`004S?o00030000oooooooo
00_oool00ol0VOooooooo`1[oooo002?oooo0P00018co`000`000?ooooooo`0<oooo00?o09Wooooo
ool0Joooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0<oooo00?o09Woooooool0Jooo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0<oooo00?o09Woooooool0Joooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`0<oooo00?o09Woooooool0Joooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0=oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0=oooo00?o09Woooooool0Joooo`00Soooo`80000A<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000@<ol000<0003oooooool03Ooo
o`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000?<ol000<0003oooooool03_ooo`03o`2I
oooooooo06_oool008ooool00`0003?o03?o000?<ol000<0003oooooool03_ooo`03o`2Ioooooooo
06_oool008ooool00`0003?o03?o000?<ol000<0003oooooool03_ooo`03o`2Ioooooooo06_oool0
08ooool00`0003?o03?o000?<ol000<0003oooooool03_ooo`03o`2Ioooooooo06_oool008ooool2
000043?o00030000oooooooo00koool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`003S?o
00030000oooooooo00ooool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`003S?o00030000
oooooooo00ooool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`003S?o00030000oooooooo
00ooool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`003S?o00030000oooooooo00ooool0
0ol0VOooooooo`1[oooo002?oooo00<0000co`0co`003S?o00030000oooooooo00ooool00ol0VOoo
ooooo`1[oooo002?oooo0P0000hco`000`000?ooooooo`0@oooo00?o09Woooooool0Joooo`00Sooo
o`030000<ol0<ol000dco`000`000?ooooooo`0@oooo00?o09Woooooool0Joooo`00Soooo`030000
<ol0<ol000dco`000`000?ooooooo`0@oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`0@oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`0Aoooo00?o09Woooooool0Joooo`00ROooo`<00003oooo00<0000co`0co`0033?o
00030000oooooooo017oool00ol0VOooooooo`1[oooo002:oooo00<0003oooooool00_ooo`030000
<ol0<ol000`co`000`000?ooooooo`0Aoooo00?o09Woooooool0Joooo`00Qoooo`D00003oooo0`00
00`co`000`000?ooooooo`0Aoooo00?o09Woooooool0Joooo`00Qoooo`040000oooooooo00001?oo
o`lco`22oooo0028oooo00<0003oool000001?ooo`lco`22oooo0029oooo0P0000Coool?<ol0P_oo
o`00Soooo`lco`22oooo002?oooo3c?o08;oool007Woool00`000?ooooooo`0Coooo3S?o00Ooool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo00Woool><ol02?oo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000@co`0200000c?o00@000000c?o0?ooo`00000200001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Pco`000`0003?o03?o0002<ol00oooo`030000oooooooo00;oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00Tco`00100003?o03?o03?o00;oool300001?ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500003?ooo`040000oooooooo00002S?o00050000<ol0<ol0oooo000000;oool01@000?oo
ooooooooo`00001joooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo000023?o
00040000<ol0<ol000000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000Xco`02000000@co`3oooooooooool300000_ooo`030000oooooooo
07Woool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.63527 .12361 L
.63796 .12361 L
.64043 .12361 L
.64164 .12361 L
.64277 .12361 L
s
.64277 .12361 m
.64324 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.34309 .12361 L
.34772 .12361 L
.35028 .12361 L
.35271 .12361 L
.35496 .12361 L
.35624 .12361 L
.35742 .12346 L
.35852 .1229 L
.35951 .12239 L
.36173 .12126 L
.3815 .11189 L
.42157 .09628 L
.46012 .08488 L
.50112 .07593 L
.54061 .06861 L
.57858 .06173 L
.59972 .05806 L
.619 .05485 L
.62857 .05332 L
.63362 .05252 L
.63639 .05209 L
.63898 .05169 L
.64123 .05135 L
.6425 .05115 L
.64366 .12361 L
.64486 .12361 L
.64617 .12361 L
.64882 .12361 L
.65791 .12361 L
.69847 .12361 L
.73752 .12361 L
.77902 .12361 L
.819 .12361 L
.85746 .12361 L
.89838 .12361 L
.93779 .12361 L
.97567 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80000Poooo0`1Vofcoool008ooool00`000?ooooooo`0I
oooo1P1Vo`;oool00`1Vooooooooo`1Zoooo002?oooo00<0003oooooool05?ooo`D0I_l8oooo00<0
I_ooooooool0J_ooo`00Soooo`030000oooooooo00goool706Ko3Oooo`0306Kooooooooo06[oool0
08ooool00`000?ooooooo`05oooo201VoaCoool00`1Vooooooooo`1Zoooo002?oooo00<0003ooooo
ool01@1Voacoool00`1Vooooooooo`1Zoooo002>oooo00@0I_l000000000I_lQoooo00<0I_oooooo
ool0J_ooo`005oooo`D0000coooo0P0000Coool200001?ooo`80000^oooo0`1Vo`03oooo0000oooo
02;oool00`1Vooooooooo`0>oooo0P0000Coool200001?ooo`80000doooo1@0001Goool001Woool0
0`000?ooooooo`0boooo00@0003oooooool00008oooo00@0003oooooool0000Yoooo101Vo`Coool0
0`000?ooooooo`0Qoooo00<0I_ooooooool03Oooo`040000oooooooo00002?ooo`040000oooooooo
0000=Oooo`030000oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool0000;
oooo00<0003oooooool08oooo`@0I_l8oooo00<0003oooooool08Oooo`0306Kooooooooo00goool0
10000?ooooooo`0000_oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004
oooo00<0003oooooool0;?ooo`@00002oooo00@0003oooooool00009oooo0P00027oool506Ko3?oo
o`030000oooooooo027oool00`1Vooooooooo`0=oooo00@0003oooooool00009oooo0P0003Koool0
0`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002Oooo`030000
oooooooo01coool406Ko4Oooo`030000oooooooo027oool00`1Vooooooooo`0=oooo00@0003ooooo
ool00009oooo00<0003oooooool0=Oooo`030000oooooooo01Goool001Soool20000=Oooo`80000:
oooo0`0001[oool206Ko5Oooo`80000Roooo00<0I_ooooooool03_ooo`80000:oooo0`0003Coool2
00005oooo`00MOooo`<0I_lGoooo00<0003oooooool08Oooo`0306Kooooooooo06[oool007?oool2
06Ko6_ooo`030000oooooooo027oool00`1Vooooooooo`1Zoooo001aoooo0P1Voacoool00`000?oo
ooooo`0Qoooo00<0I_ooooooool0J_ooo`00Koooo`80I_lNoooo00<0003oooooool08Oooo`0306Ko
oooooooo06[oool006goool206Ko8?ooo`030000oooooooo027oool00`1Vooooooooo`1Zoooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Xco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0024co`000ol0VC?o03?o000E
<ol000<0000co`0co`00=S?o00D0000Goooo002?oooo00<0000co`0co`008C?o0003o`2I<ol0<ol0
04Hco`0800007?ooo`00Soooo`030000<ol0<ol0024co`000ol0VC?o03?o0010<ol01P0002Coool0
08ooool00`0003?o03?o000Q<ol000?o09Tco`0co`00>c?o00D0000Zoooo002?oooo00<0000co`0c
o`008C?o0003o`2I<ol0<ol003Hco`050000;oooo`00Soooo`80000R<ol000?o09Tco`0co`00<C?o
00D0000doooo002?oooo00<0000co`0co`008C?o0003o`2I<ol0<ol002dco`040000>Oooo`00Sooo
o`030000<ol0<ol0024co`000ol0VC?o03?o000[<ol00P0003goool008ooool00`0003?o03?o000Q
<ol000?o09Tco`0co`00:3?o00<0000ooooo002?oooo00<0000co`0co`008C?o0003o`2I<ol0<ol0
02Hco`020000@_ooo`00Soooo`030000<ol0<ol0024co`000ol0VC?o03?o000T<ol00P0004Coool0
08ooool200008S?o0003o`2I<ol0<ol0028co`020000A_ooo`00Soooo`030000<ol0<ol0024co`00
0ol0VC?o03?o000P<ol00P0004Soool008ooool00`0003?o03?o000Q<ol000?o09Tco`0co`007c?o
00030000oooooooo04Soool008ooool00`0003?o03?o000Q<ol000?o09Tco`0co`007C?o0080001;
oooo002?oooo00<0000co`0co`008C?o0003o`2I<ol0<ol001/co`020000COooo`00Soooo`030000
<ol0<ol0024co`000ol0VC?o03?o000J<ol000<0003oooooool0COooo`00Soooo`80000R<ol000?o
09Tco`0co`0063?o0080001@oooo002?oooo00<0000co`0co`008C?o0003o`2I<ol0<ol001Hco`02
0000D_ooo`00Soooo`030000<ol0<ol0024co`000ol0VC?o03?o000E<ol000<0003oooooool0D_oo
o`00Soooo`030000<ol0<ol0024co`000ol0VC?o03?o000D<ol000<0003oooooool0Doooo`00Sooo
o`030000<ol0<ol0024co`000ol0VC?o03?o000B<ol00P0005Koool008ooool00`0003?o03?o000Q
<ol000?o09Tco`0co`004C?o00030000oooooooo05Koool008ooool200008S?o0003o`2I<ol0<ol0
010co`000`000?ooooooo`1Goooo002?oooo00<0000co`0co`008C?o0003o`2I<ol0<ol000lco`00
0`000?ooooooo`1Hoooo002?oooo00<0000co`0co`008C?o0003o`2I<ol0<ol000hco`000`000?oo
ooooo`1Ioooo002?oooo00<0000co`0co`008C?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1J
oooo002?oooo00<0000co`0co`008C?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1Joooo0027
oooo1@0000?oool00`0003?o03?o000Q<ol000?o09Tco`0co`0033?o00030000oooooooo05_oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`008C?o0003o`2I<ol0<ol000/co`000`000?oo
ooooo`1Loooo0029oooo00<0003oooooool00oooo`<0000Q<ol000?o09Tco`0co`002S?o00030000
oooooooo05goool008Woool00`000?ooooooo`03oooo00<0000co`0co`008C?o0003o`2I<ol0<ol0
00Xco`000`000?ooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0024co`00
0ol0VC?o03?o0009<ol000<0003oooooool0G_ooo`00R?ooo`800005oooo00<0000co`0co`008C?o
0003o`2I<ol0<ol000Pco`000`000?ooooooo`1Ooooo002?oooo00<0000co`0co`008C?o0003o`2I
<ol0<ol000Lco`000`000?ooooooo`1Poooo002?oooo00<0000co`0co`008C?o0003o`2I<ol0<ol0
00Lco`000`000?ooooooo`1Poooo002?oooo0P00028co`000ol0VC?o03?o0006<ol000<0003ooooo
ool0HOooo`00Soooo`030000<ol0<ol0024co`000ol0VC?o03?o0005<ol000<0003oooooool0H_oo
o`00Soooo`030000<ol0<ol0024co`000ol0VC?o03?o0005<ol000<0003oooooool0H_ooo`00Sooo
o`030000<ol0<ol0024co`000ol0VC?o03?o0004<ol000<0003oooooool0Hoooo`00Soooo`030000
<ol0<ol0024co`000ol0VC?o03?o0003<ol000<0003oooooool0I?ooo`00Soooo`030000<ol0<ol0
024co`000ol0VC?o03?o0002<ol000<0003oooooool0IOooo`00Soooo`80000R<ol000?o09Tco`0c
o`000S?o00030000oooooooo06Goool008ooool00`0003?o03?o000Q<ol000Go09Tco`0co`0co`00
0000J?ooo`00Soooo`030000<ol0<ol0024co`001?l0VC?o03?o000006Woool008ooool00`0003?o
03?o000Q<ol000Co09Tco`0co`00001Yoooo002?oooo00<0000co`0co`008C?o0003o`2I<ol00000
06[oool008ooool00`0003?o03?o000Q<ol000?o09Tco`000000J_ooo`00Soooo`030000<ol0<ol0
024co`000ol0V@000?ooo`1Zoooo002?oooo0P00028co`000ol0V@000?ooo`1Zoooo002?oooo00<0
000co`0co`008C?o0003o`2Ioooooooo06[oool008ooool00`0003?o03?o000Q<ol000?o09Wooooo
ool0J_ooo`00Soooo`030000<ol0<ol0020co`000`000?l0VOooo`1[oooo002?oooo00<0000co`0c
o`0083?o00030000o`2Ioooo06_oool008ooool00`0003?o03?o000P<ol000<0003o09Woool0Jooo
o`00Soooo`80000P<ol000<0003ooooo09T0K?ooo`00Soooo`030000<ol0<ol001lco`000`000?oo
ool0V@1/oooo002?oooo00<0000co`0co`007S?o00040000ooooooooo`2IK?ooo`00Soooo`030000
<ol0<ol001hco`0010000?ooooooool0VFcoool008Ooool400001?ooo`030000<ol0<ol001hco`00
10000?ooooooool0VFcoool008Ooool00`000?ooooooo`05oooo00<0000co`0co`007C?o00050000
ooooooooooooo`2I06coool008Soool00`000?ooooooo`04oooo0`0001dco`001@000?oooooooooo
ool0V@1/oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001dco`001@000?oooooooooo
ool0V@1/oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0073?o00030000oooooooo
00;oool00ol0VOooooooo`1Zoooo0028oooo0P0000Goool00`0003?o03?o000L<ol000<0003ooooo
ool00_ooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000K<ol000<0003oooooool00ooo
o`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000K<ol000<0003oooooool00oooo`03o`2I
oooooooo06[oool008ooool2000073?o00030000oooooooo00?oool00ol0VOooooooo`1Zoooo002?
oooo00<0000co`0co`006S?o00030000oooooooo00Coool00ol0VOooooooo`1Zoooo002?oooo00<0
000co`0co`006S?o00030000oooooooo00Coool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0c
o`006S?o00030000oooooooo00Coool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`006S?o
00030000oooooooo00Coool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`006C?o00030000
oooooooo00Goool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`006C?o00030000oooooooo
00Goool00ol0VOooooooo`1Zoooo002?oooo0P0001Xco`000`000?ooooooo`05oooo00?o09Wooooo
ool0J_ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`06oooo00?o09Woooooool0J_oo
o`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`06oooo00?o09Woooooool0J_ooo`00Sooo
o`030000<ol0<ol001Pco`000`000?ooooooo`06oooo00?o09Woooooool0J_ooo`00Soooo`030000
<ol0<ol001Lco`000`000?ooooooo`07oooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol0
01Lco`000`000?ooooooo`07oooo00?o09Woooooool0J_ooo`00Soooo`80000H<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000G<ol000<0003oooooool01ooo
o`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000F<ol000<0003oooooool02?ooo`03o`2I
oooooooo06[oool008ooool00`0003?o03?o000F<ol000<0003oooooool02?ooo`03o`2Ioooooooo
06[oool008ooool00`0003?o03?o000F<ol000<0003oooooool02?ooo`03o`2Ioooooooo06[oool0
08ooool00`0003?o03?o000E<ol000<0003oooooool02Oooo`03o`2Ioooooooo06[oool008ooool2
00005S?o00030000oooooooo00Woool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`005C?o
00030000oooooooo00Woool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`005C?o00030000
oooooooo00Woool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`0053?o00030000oooooooo
00[oool00ol0VOooooooo`1Zoooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003ooooo
ool02_ooo`03o`2Ioooooooo06[oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000D
<ol000<0003oooooool02_ooo`03o`2Ioooooooo06[oool008Woool00`000?ooooooo`03oooo0`00
01<co`000`000?ooooooo`0;oooo00?o09Woooooool0J_ooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o000C<ol000<0003oooooool02oooo`03o`2Ioooooooo06[oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o000C<ol000<0003oooooool02oooo`03o`2Ioooooooo06[oool0
08Soool200001Oooo`030000<ol0<ol0018co`000`000?ooooooo`0<oooo00?o09Woooooool0J_oo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0<oooo00?o09Woooooool0J_ooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`0<oooo00?o09Woooooool0J_ooo`00Soooo`030000
<ol0<ol0018co`000`000?ooooooo`0<oooo00?o09Woooooool0J_ooo`00Soooo`80000B<ol000<0
003oooooool03Oooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000A<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000A<ol000<0003oooooool03Ooo
o`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000A<ol000<0003oooooool03Oooo`03o`2I
oooooooo06[oool008ooool00`0003?o03?o000@<ol000<0003oooooool03_ooo`03o`2Ioooooooo
06[oool008ooool00`0003?o03?o000@<ol000<0003oooooool03_ooo`03o`2Ioooooooo06[oool0
08ooool200004C?o00030000oooooooo00koool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo00koool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`003c?o
00030000oooooooo00ooool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`003c?o00030000
oooooooo00ooool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`003c?o00030000oooooooo
00ooool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`003c?o00030000oooooooo00ooool0
0ol0VOooooooo`1Zoooo002?oooo0P00010co`000`000?ooooooo`0?oooo00?o09Woooooool0J_oo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0@oooo00?o09Woooooool0J_ooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`0@oooo00?o09Woooooool0J_ooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`0@oooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0@oooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`0@oooo00?o09Woooooool0J_ooo`00Soooo`80000><ol000<0003oooooool04Ooo
o`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000=<ol000<0003oooooool04Oooo`03o`2I
oooooooo06[oool008ooool00`0003?o03?o000=<ol000<0003oooooool04Oooo`03o`2Ioooooooo
06[oool008ooool00`0003?o03?o000=<ol000<0003oooooool04Oooo`03o`2Ioooooooo06[oool0
08ooool00`0003?o03?o000<<ol000<0003oooooool04_ooo`03o`2Ioooooooo06[oool008Woool3
00000oooo`030000<ol0<ol000`co`000`000?ooooooo`0Boooo00?o09Woooooool0J_ooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o000<<ol000<0003oooooool04_ooo`03o`2Ioooooooo
06[oool008Ooool500000oooo`<0000<<ol000<0003oooooool04_ooo`03o`2Ioooooooo06[oool0
08Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_oo
o`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22oooo001loooo00<0
003oooooool04?ooo`hco`04oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool0
0`000?ooooooo`06oooo3S?o00Goool00`000?ooooooo`1koooo001koooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`03<ol00000000000@co`02000013?o00800004oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000<ol0<ol0000023?o00040000<ol0oooo00000oooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000<ol0<ol000002S?o
00030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool0
100003?o03?o000000Xco`000oooo`000?ooo`02oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000ooool0100003?o03?o000000Pco`0010000?ooooooo`0000?oool00`000?oo
ooooo`1koooo001loooo00<0003oooooool04?ooo`03<ol00000000000Xco`0200000oooo`030000
oooooooo07coool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.31) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.63527 .12361 L
.64043 .12361 L
.64277 .12361 L
.64524 .12361 L
.64654 .12361 L
.64727 .12361 L
s
.64727 .12361 m
.64755 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.33788 .12361 L
.34309 .12361 L
.34566 .12361 L
.34811 .12361 L
.35031 .12361 L
.35156 .12361 L
.35271 .12343 L
.35389 .12283 L
.355 .12226 L
.35708 .1212 L
.36173 .11889 L
.3815 .10981 L
.42005 .0952 L
.46105 .08346 L
.50054 .07518 L
.53851 .06837 L
.57894 .06122 L
.61785 .05471 L
.62802 .05309 L
.63338 .05226 L
.63909 .05138 L
.64405 .05063 L
.64541 .05043 L
.64613 .05032 L
.64688 .05021 L
.64754 .05012 L
.64827 .12361 L
.64954 .12361 L
.65921 .12361 L
.69977 .12361 L
.73881 .12361 L
.78031 .12361 L
.82029 .12361 L
.85876 .12361 L
.89968 .12361 L
.93908 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.31) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80000Poooo101Vof_oool008ooool00`000?ooooooo`0I
oooo1P1Vo`?oool00`1Vooooooooo`1Yoooo002?oooo00<0003oooooool05?ooo`D0I_l9oooo00<0
I_ooooooool0JOooo`00Soooo`030000oooooooo00goool706Ko3_ooo`0306Kooooooooo06Woool0
08ooool00`000?ooooooo`05oooo201VoaGoool00`1Vooooooooo`1Yoooo002?oooo00<0003ooooo
ool01@1Voagoool00`1Vooooooooo`1Yoooo002=oooo0P1Vo`8000000`1Vooooooooo`0Poooo00<0
I_ooooooool0JOooo`005oooo`D0000coooo0P0000Coool200001?ooo`80000[oooo1@1Vo`;oool0
0`000?ooooooo`0Roooo00<0I_ooooooool03Oooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo00009_oo
o`@0I_l7oooo00<0003oooooool08_ooo`0306Kooooooooo00coool010000?ooooooo`0000Soool0
10000?ooooooo`0003Goool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000
oooooooo00002oooo`030000oooooooo027oool306Ko2oooo`030000oooooooo02;oool00`1Voooo
ooooo`0<oooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000oooooooo01Goool0
017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo00002Oooo`80000P
oooo101Vo`koool00`000?ooooooo`0Soooo00<0I_ooooooool02oooo`040000oooooooo00002Ooo
o`80000foooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`00
00Woool00`000?ooooooo`0Loooo0`1Voa;oool00`000?ooooooo`0Soooo00<0I_ooooooool02ooo
o`040000oooooooo00002Oooo`030000oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P00
03Goool200002_ooo`<0000Joooo0P1VoaGoool200009?ooo`0306Kooooooooo00coool200002_oo
o`<0000doooo0P0001Ooool007Goool306Ko5oooo`030000oooooooo02?oool00`1Vooooooooo`1X
oooo001coooo0P1Voa[oool00`000?ooooooo`0Soooo00<0I_ooooooool0J?ooo`00L?ooo`<0I_lL
oooo00<0003oooooool08oooo`0306Kooooooooo06Soool006koool206Ko7oooo`030000oooooooo
02?oool00`1Vooooooooo`1Xoooo001/oooo0P1Vob7oool00`000?ooooooo`0Soooo00<0I_oooooo
ool0J?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
o`2I<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000R<ol000?o
09Tco`0co`0053?o00030000<ol0<ol003Hco`0500005oooo`00Soooo`030000<ol0<ol0028co`00
0ol0VC?o03?o0015<ol0200001coool008ooool00`0003?o03?o000R<ol000?o09Tco`0co`00?c?o
00H0000Toooo002?oooo00<0000co`0co`008S?o0003o`2I<ol0<ol003Xco`050000:_ooo`00Sooo
o`030000<ol0<ol0028co`000ol0VC?o03?o000e<ol01@0002ooool008ooool200008c?o0003o`2I
<ol0<ol0030co`050000=?ooo`00Soooo`030000<ol0<ol0028co`000ol0VC?o03?o000/<ol01000
03Woool008ooool00`0003?o03?o000R<ol000?o09Tco`0co`00:S?o0080000moooo002?oooo00<0
000co`0co`008S?o0003o`2I<ol0<ol002Lco`030000?oooo`00Soooo`030000<ol0<ol0028co`00
0ol0VC?o03?o000U<ol00P0004;oool008ooool00`0003?o03?o000R<ol000?o09Tco`0co`008c?o
00800014oooo002?oooo0P0002<co`000ol0VC?o03?o000Q<ol00P0004Koool008ooool00`0003?o
03?o000R<ol000?o09Tco`0co`007c?o00800018oooo002?oooo00<0000co`0co`008S?o0003o`2I
<ol0<ol001hco`000`000?ooooooo`18oooo002?oooo00<0000co`0co`008S?o0003o`2I<ol0<ol0
01`co`020000Boooo`00Soooo`030000<ol0<ol0028co`000ol0VC?o03?o000J<ol00P0004goool0
08ooool00`0003?o03?o000R<ol000?o09Tco`0co`006C?o00030000oooooooo04goool008ooool2
00008c?o0003o`2I<ol0<ol001Lco`020000D?ooo`00Soooo`030000<ol0<ol0028co`000ol0VC?o
03?o000E<ol00P0005;oool008ooool00`0003?o03?o000R<ol000?o09Tco`0co`0053?o00030000
oooooooo05;oool008ooool00`0003?o03?o000R<ol000?o09Tco`0co`004c?o00030000oooooooo
05?oool008ooool00`0003?o03?o000R<ol000?o09Tco`0co`004C?o0080001Foooo002?oooo00<0
000co`0co`008S?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1Foooo002?oooo0P0002<co`00
0ol0VC?o03?o000?<ol000<0003oooooool0Eoooo`00Soooo`030000<ol0<ol0028co`000ol0VC?o
03?o000><ol000<0003oooooool0F?ooo`00Soooo`030000<ol0<ol0028co`000ol0VC?o03?o000=
<ol000<0003oooooool0FOooo`00Soooo`030000<ol0<ol0028co`000ol0VC?o03?o000<<ol000<0
003oooooool0F_ooo`00Soooo`030000<ol0<ol0028co`000ol0VC?o03?o000<<ol000<0003ooooo
ool0F_ooo`00Qoooo`D00003oooo00<0000co`0co`008S?o0003o`2I<ol0<ol000/co`000`000?oo
ooooo`1Koooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0028co`000ol0VC?o03?o000:
<ol000<0003oooooool0G?ooo`00ROooo`030000oooooooo00?oool300008S?o0003o`2I<ol0<ol0
00Tco`000`000?ooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0028co`00
0ol0VC?o03?o0009<ol000<0003oooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000R<ol000?o09Tco`0co`0023?o00030000oooooooo05koool008Soool200001Oooo`030000
<ol0<ol0028co`000ol0VC?o03?o0007<ol000<0003oooooool0Goooo`00Soooo`030000<ol0<ol0
028co`000ol0VC?o03?o0006<ol000<0003oooooool0H?ooo`00Soooo`030000<ol0<ol0028co`00
0ol0VC?o03?o0006<ol000<0003oooooool0H?ooo`00Soooo`80000S<ol000?o09Tco`0co`001C?o
00030000oooooooo067oool008ooool00`0003?o03?o000R<ol000?o09Tco`0co`0013?o00030000
oooooooo06;oool008ooool00`0003?o03?o000R<ol000?o09Tco`0co`0013?o00030000oooooooo
06;oool008ooool00`0003?o03?o000R<ol000?o09Tco`0co`000c?o00030000oooooooo06?oool0
08ooool00`0003?o03?o000R<ol000?o09Tco`0co`000S?o00030000oooooooo06Coool008ooool0
0`0003?o03?o000R<ol000Go09Tco`0co`0co`000000Ioooo`00Soooo`80000S<ol000Go09Tco`0c
o`0co`000000Ioooo`00Soooo`030000<ol0<ol0028co`001?l0VC?o03?o000006Soool008ooool0
0`0003?o03?o000R<ol000?o09Tco`000000JOooo`00Soooo`030000<ol0<ol0028co`000ol0VC?o
0000001Yoooo002?oooo00<0000co`0co`008S?o0003o`2I0000oooo06Woool008ooool00`0003?o
03?o000R<ol000?o09T0003oool0JOooo`00Soooo`030000<ol0<ol0028co`000ol0VOooooooo`1Y
oooo002?oooo0P0002<co`000ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`008C?o00030000
o`2Ioooo06[oool008ooool00`0003?o03?o000Q<ol000<0003o09Woool0J_ooo`00Soooo`030000
<ol0<ol0020co`000`000?ooool0V@1[oooo002?oooo00<0000co`0co`0083?o00030000ooooo`2I
06_oool008ooool00`0003?o03?o000P<ol000<0003ooooo09T0Joooo`00Soooo`80000P<ol000@0
003ooooooooo09U[oooo002?oooo00<0000co`0co`007c?o00040000ooooooooo`2IJoooo`00Sooo
o`030000<ol0<ol001hco`001@000?ooooooooooool0V@1[oooo002?oooo00<0000co`0co`007S?o
00050000ooooooooooooo`2I06_oool008Ooool400001?ooo`030000<ol0<ol001hco`001@000?oo
ooooooooool0V@1[oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol001dco`000`000?oo
ooooo`02oooo00?o09Woooooool0JOooo`00R?ooo`030000oooooooo00Coool300007C?o00030000
oooooooo00;oool00ol0VOooooooo`1Yoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`000`000?ooooooo`02oooo00?o09Woooooool0JOooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol001`co`000`000?ooooooo`03oooo00?o09Woooooool0JOooo`00R?ooo`800005
oooo00<0000co`0co`0073?o00030000oooooooo00?oool00ol0VOooooooo`1Yoooo002?oooo00<0
000co`0co`006c?o00030000oooooooo00Coool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0c
o`006c?o00030000oooooooo00Coool00ol0VOooooooo`1Yoooo002?oooo0P0001`co`000`000?oo
ooooo`04oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`05
oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`05oooo00?o
09Woooooool0JOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`05oooo00?o09Wooooo
ool0JOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`05oooo00?o09Woooooool0JOoo
o`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`06oooo00?o09Woooooool0JOooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`06oooo00?o09Woooooool0JOooo`00Soooo`80000J
<ol000<0003oooooool01_ooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000H<ol000<0
003oooooool01oooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000H<ol000<0003oooooool01ooo
o`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000G<ol000<0003oooooool02?ooo`03o`2I
oooooooo06Woool008ooool00`0003?o03?o000G<ol000<0003oooooool02?ooo`03o`2Ioooooooo
06Woool008ooool2000063?o00030000oooooooo00Soool00ol0VOooooooo`1Yoooo002?oooo00<0
000co`0co`005c?o00030000oooooooo00Soool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0c
o`005S?o00030000oooooooo00Woool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`005S?o
00030000oooooooo00Woool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`005S?o00030000
oooooooo00Woool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`005C?o00030000oooooooo
00[oool00ol0VOooooooo`1Yoooo002?oooo0P0001Hco`000`000?ooooooo`0:oooo00?o09Wooooo
ool0JOooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0:oooo00?o09Woooooool0JOoo
o`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0:oooo00?o09Woooooool0JOooo`00Sooo
o`030000<ol0<ol001@co`000`000?ooooooo`0;oooo00?o09Woooooool0JOooo`00R?ooo`800005
oooo00<0000co`0co`0053?o00030000oooooooo00_oool00ol0VOooooooo`1Yoooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0053?o00030000oooooooo00_oool00ol0VOooooooo`1Y
oooo0029oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool03?ooo`03o`2Ioooooooo
06Woool008[oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo00coool0
0ol0VOooooooo`1Yoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`004c?o00030000
oooooooo00coool00ol0VOooooooo`1Yoooo0028oooo0P0000Goool00`0003?o03?o000B<ol000<0
003oooooool03Oooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000B<ol000<0003oooooool03Ooo
o`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000B<ol000<0003oooooool03Oooo`03o`2I
oooooooo06Woool008ooool200004S?o00030000oooooooo00koool00ol0VOooooooo`1Yoooo002?
oooo00<0000co`0co`004C?o00030000oooooooo00koool00ol0VOooooooo`1Yoooo002?oooo00<0
000co`0co`004C?o00030000oooooooo00koool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo00koool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`0043?o
00030000oooooooo00ooool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`0043?o00030000
oooooooo00ooool00ol0VOooooooo`1Yoooo002?oooo0P00014co`000`000?ooooooo`0?oooo00?o
09Woooooool0JOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0?oooo00?o09Wooooo
ool0JOooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0@oooo00?o09Woooooool0JOoo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0@oooo00?o09Woooooool0JOooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0@oooo00?o09Woooooool0JOooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0@oooo00?o09Woooooool0JOooo`00Soooo`80000@<ol000<0
003oooooool04?ooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000><ol000<0003ooooo
ool04Oooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000><ol000<0003oooooool04Ooo
o`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000><ol000<0003oooooool04Oooo`03o`2I
oooooooo06Woool008ooool00`0003?o03?o000><ol000<0003oooooool04Oooo`03o`2Ioooooooo
06Woool008ooool00`0003?o03?o000><ol000<0003oooooool04Oooo`03o`2Ioooooooo06Woool0
08ooool200003S?o00030000oooooooo01;oool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0c
o`003C?o00030000oooooooo01;oool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`003C?o
00030000oooooooo01;oool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`003C?o00030000
oooooooo01;oool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`0033?o00030000oooooooo
01?oool00ol0VOooooooo`1Yoooo0029oooo0`0000?oool00`0003?o03?o000<<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo06Woool008[oool00`000?ooooooo`02oooo00<0000co`0co`0033?o
00030000oooooooo01?oool00ol0VOooooooo`1Yoooo0027oooo1@0000?oool3000033?o00030000
oooooooo01?oool00ol0VOooooooo`1Yoooo0027oooo00@0003oooooool00004oooo3c?o08;oool0
08Soool00`000?ooo`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o
08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o
00800004<ol00P00008co`000oooo`000000000300000_ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000Pco`001@0003?o03?o000003?o0003oooo00<0003oooooool00_ooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002S?o
00030000<ol0<ol000?oool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000<oooo00@0003oooooool0000;<ol000<0000co`3oool00_ooo`030000oooooooo
00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo
000023?o00040000<ol0<ol000001?ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:<ol00P000004<ol0oooooooooooo0P0000?oool00`000?oo
ooooo`1ioooo002?oooo3C?o08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.64043 .12361 L
.64559 .12361 L
.64812 .12361 L
.64923 .12361 L
.65045 .12361 L
.65155 .12361 L
s
.65155 .12361 m
.65196 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.33788 .12361 L
.34055 .12361 L
.34309 .12361 L
.34549 .12361 L
.34615 .12361 L
.34685 .12361 L
.34811 .12335 L
.34935 .12271 L
.35053 .12211 L
.35271 .121 L
.36173 .1166 L
.3815 .1078 L
.42005 .09365 L
.46105 .08231 L
.50054 .07435 L
.53851 .06778 L
.57894 .06081 L
.61785 .0544 L
.62802 .0528 L
.63909 .05112 L
.64415 .05036 L
.64693 .04995 L
.64954 .04957 L
.65061 .04941 L
.65175 .04925 L
.65299 .12361 L
.65413 .12361 L
.65921 .12361 L
.69731 .12361 L
.73788 .12361 L
.77692 .12361 L
.81842 .12361 L
.8584 .12361 L
.89687 .12361 L
.93779 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80000Noooo1`1Vof[oool008ooool00`000?ooooooo`0G
oooo1P1Vo`Koool00`1Vooooooooo`1Xoooo002?oooo00<0003oooooool03oooo`P0I_l<oooo00<0
I_ooooooool0J?ooo`00Soooo`030000oooooooo00[oool506Ko5?ooo`0306Kooooooooo06Soool0
08ooool00`000?ooooooo`05oooo1@1VoaWoool00`1Vooooooooo`1Xoooo002?oooo00<0003ooooo
ool01@1Voakoool00`1Vooooooooo`1Xoooo002=oooo0P1Vo`8000000`1Vooooooooo`0Qoooo00<0
I_ooooooool0J?ooo`005oooo`D0000coooo0P0000Coool200001?ooo`80000[oooo1@1Vo`;oool0
0`000?ooooooo`0Soooo00<0I_ooooooool03?ooo`800004oooo0P0000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo00009_oo
o`@0I_l7oooo00<0003oooooool08oooo`0306Kooooooooo00_oool010000?ooooooo`0000Soool0
10000?ooooooo`0003Goool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000
oooooooo00002oooo`030000oooooooo027oool306Ko2oooo`030000oooooooo02?oool00`1Voooo
ooooo`0;oooo00@0003oooooool0000;oooo00<0003oooooool0<oooo`030000oooooooo01Goool0
017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo00002Oooo`80000P
oooo101Vo`koool00`000?ooooooo`0Toooo00<0I_ooooooool02_ooo`040000oooooooo00002Ooo
o`80000foooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`00
00Woool00`000?ooooooo`0Loooo0`1Voa;oool00`000?ooooooo`0Toooo00<0I_ooooooool02_oo
o`040000oooooooo00002Oooo`030000oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P00
03Goool200002_ooo`<0000Ioooo0`1VoaGoool200009Oooo`0306Kooooooooo00_oool200002_oo
o`<0000doooo0P0001Ooool007?oool406Ko6?ooo`030000oooooooo02Coool00`1Vooooooooo`1W
oooo001aoooo0P1Voacoool00`000?ooooooo`0Toooo00<0I_ooooooool0Ioooo`00Koooo`80I_lN
oooo00<0003oooooool09?ooo`0306Kooooooooo06Ooool006goool206Ko8?ooo`030000oooooooo
02Coool00`1Vooooooooo`1Woooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo02Coool0
0`1Vooooooooo`1Woooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`3o09T02C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Xco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
02<co`000ol0VC?o03?o000C<ol000<0000co`0co`00=S?o00D0000Goooo002?oooo00<0000co`0c
o`008c?o0003o`2I<ol0<ol004@co`0800007?ooo`00Soooo`030000<ol0<ol002<co`000ol0VC?o
03?o000n<ol01P0002Coool008ooool00`0003?o03?o000S<ol000?o09Tco`0co`00>C?o00D0000Z
oooo002?oooo00<0000co`0co`008c?o0003o`2I<ol0<ol003@co`050000;oooo`00Soooo`80000T
<ol000?o09Tco`0co`00;c?o00D0000doooo002?oooo00<0000co`0co`008c?o0003o`2I<ol0<ol0
02/co`040000>Oooo`00Soooo`030000<ol0<ol002<co`000ol0VC?o03?o000Y<ol00P0003goool0
08ooool00`0003?o03?o000S<ol000?o09Tco`0co`009S?o00<0000ooooo002?oooo00<0000co`0c
o`008c?o0003o`2I<ol0<ol002@co`020000@_ooo`00Soooo`030000<ol0<ol002<co`000ol0VC?o
03?o000R<ol00P0004Coool008ooool2000093?o0003o`2I<ol0<ol0020co`020000A_ooo`00Sooo
o`030000<ol0<ol002<co`000ol0VC?o03?o000N<ol00P0004Soool008ooool00`0003?o03?o000S
<ol000?o09Tco`0co`007C?o00030000oooooooo04Soool008ooool00`0003?o03?o000S<ol000?o
09Tco`0co`006c?o0080001;oooo002?oooo00<0000co`0co`008c?o0003o`2I<ol0<ol001Tco`02
0000COooo`00Soooo`030000<ol0<ol002<co`000ol0VC?o03?o000H<ol000<0003oooooool0COoo
o`00Soooo`80000T<ol000?o09Tco`0co`005S?o0080001@oooo002?oooo00<0000co`0co`008c?o
0003o`2I<ol0<ol001@co`020000D_ooo`00Soooo`030000<ol0<ol002<co`000ol0VC?o03?o000C
<ol000<0003oooooool0D_ooo`00Soooo`030000<ol0<ol002<co`000ol0VC?o03?o000B<ol000<0
003oooooool0Doooo`00Soooo`030000<ol0<ol002<co`000ol0VC?o03?o000@<ol00P0005Koool0
08ooool00`0003?o03?o000S<ol000?o09Tco`0co`003c?o00030000oooooooo05Koool008ooool2
000093?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1Goooo002?oooo00<0000co`0co`008c?o
0003o`2I<ol0<ol000dco`000`000?ooooooo`1Hoooo002?oooo00<0000co`0co`008c?o0003o`2I
<ol0<ol000`co`000`000?ooooooo`1Ioooo002?oooo00<0000co`0co`008c?o0003o`2I<ol0<ol0
00/co`000`000?ooooooo`1Joooo002?oooo00<0000co`0co`008c?o0003o`2I<ol0<ol000/co`00
0`000?ooooooo`1Joooo0027oooo1@0000?oool00`0003?o03?o000S<ol000?o09Tco`0co`002S?o
00030000oooooooo05_oool008Woool00`000?ooooooo`03oooo00<0000co`0co`008c?o0003o`2I
<ol0<ol000Tco`000`000?ooooooo`1Loooo0029oooo00<0003oooooool00oooo`<0000S<ol000?o
09Tco`0co`0023?o00030000oooooooo05goool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`008c?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1Moooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol002<co`000ol0VC?o03?o0007<ol000<0003oooooool0G_ooo`00R?ooo`800005
oooo00<0000co`0co`008c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1Ooooo002?oooo00<0
000co`0co`008c?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1Poooo002?oooo00<0000co`0c
o`008c?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1Poooo002?oooo0P0002@co`000ol0VC?o
03?o0004<ol000<0003oooooool0HOooo`00Soooo`030000<ol0<ol002<co`000ol0VC?o03?o0003
<ol000<0003oooooool0H_ooo`00Soooo`030000<ol0<ol002<co`000ol0VC?o03?o0003<ol000<0
003oooooool0H_ooo`00Soooo`030000<ol0<ol002<co`000ol0VC?o03?o0002<ol000<0003ooooo
ool0Hoooo`00Soooo`030000<ol0<ol002<co`001Ol0VC?o03?o03?o0000001Voooo002?oooo00<0
000co`0co`008c?o0004o`2I<ol0<ol00000Ioooo`00Soooo`80000T<ol000Co09Tco`0co`00001W
oooo002?oooo00<0000co`0co`008c?o0003o`2I<ol0000006Soool008ooool00`0003?o03?o000S
<ol000?o09T0003oool0J?ooo`00Soooo`030000<ol0<ol002<co`000ol0V@000?ooo`1Xoooo002?
oooo00<0000co`0co`008c?o0003o`2Ioooooooo06Soool008ooool00`0003?o03?o000S<ol000?o
09Woooooool0J?ooo`00Soooo`030000<ol0<ol0028co`000`000?l0VOooo`1Yoooo002?oooo0P00
02<co`000`000?l0VOooo`1Yoooo002?oooo00<0000co`0co`008C?o00030000ooooo`2I06[oool0
08ooool00`0003?o03?o000Q<ol000<0003ooooo09T0J_ooo`00Soooo`030000<ol0<ol0020co`00
10000?ooooooool0VF[oool008ooool00`0003?o03?o000P<ol000@0003ooooooooo09UZoooo002?
oooo00<0000co`0co`0083?o00040000ooooooooo`2IJ_ooo`00Soooo`80000P<ol000D0003ooooo
oooooooo09T0J_ooo`00Soooo`030000<ol0<ol001lco`001@000?ooooooooooool0V@1Zoooo002?
oooo00<0000co`0co`007S?o00030000oooooooo00;oool00ol0VOooooooo`1Xoooo002?oooo00<0
000co`0co`007S?o00030000oooooooo00;oool00ol0VOooooooo`1Xoooo0027oooo100000Coool0
0`0003?o03?o000N<ol000<0003oooooool00_ooo`03o`2Ioooooooo06Soool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`007C?o00030000oooooooo00?oool00ol0VOooooooo`1Xoooo0028
oooo00<0003oooooool01?ooo`<0000M<ol000<0003oooooool00oooo`03o`2Ioooooooo06Soool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000oooooooo00Coool00ol0VOoo
ooooo`1Woooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0073?o00030000oooooooo
00Goool00ol0VOooooooo`1Woooo0028oooo0P0000Goool00`0003?o03?o000L<ol000<0003ooooo
ool01Oooo`03o`2Ioooooooo06Ooool008ooool00`0003?o03?o000K<ol000<0003oooooool01_oo
o`03o`2Ioooooooo06Ooool008ooool00`0003?o03?o000K<ol000<0003oooooool01_ooo`03o`2I
oooooooo06Ooool008ooool2000073?o00030000oooooooo00Koool00ol0VOooooooo`1Woooo002?
oooo00<0000co`0co`006S?o00030000oooooooo00Ooool00ol0VOooooooo`1Woooo002?oooo00<0
000co`0co`006S?o00030000oooooooo00Ooool00ol0VOooooooo`1Woooo002?oooo00<0000co`0c
o`006S?o00030000oooooooo00Ooool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`006S?o
00030000oooooooo00Ooool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`006C?o00030000
oooooooo00Soool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`006C?o00030000oooooooo
00Soool00ol0VOooooooo`1Woooo002?oooo0P0001Xco`000`000?ooooooo`08oooo00?o09Wooooo
ool0Ioooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`09oooo00?o09Woooooool0Iooo
o`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`09oooo00?o09Woooooool0Ioooo`00Sooo
o`030000<ol0<ol001Pco`000`000?ooooooo`09oooo00?o09Woooooool0Ioooo`00Soooo`030000
<ol0<ol001Lco`000`000?ooooooo`0:oooo00?o09Woooooool0Ioooo`00Soooo`030000<ol0<ol0
01Lco`000`000?ooooooo`0:oooo00?o09Woooooool0Ioooo`00Soooo`80000H<ol000<0003ooooo
ool02_ooo`03o`2Ioooooooo06Ooool008ooool00`0003?o03?o000G<ol000<0003oooooool02_oo
o`03o`2Ioooooooo06Ooool008ooool00`0003?o03?o000F<ol000<0003oooooool02oooo`03o`2I
oooooooo06Ooool008ooool00`0003?o03?o000F<ol000<0003oooooool02oooo`03o`2Ioooooooo
06Ooool008ooool00`0003?o03?o000F<ol000<0003oooooool02oooo`03o`2Ioooooooo06Ooool0
08ooool00`0003?o03?o000E<ol000<0003oooooool03?ooo`03o`2Ioooooooo06Ooool008ooool2
00005S?o00030000oooooooo00coool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`005C?o
00030000oooooooo00coool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`005C?o00030000
oooooooo00coool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`0053?o00030000oooooooo
00goool00ol0VOooooooo`1Woooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo06Ooool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000D
<ol000<0003oooooool03Oooo`03o`2Ioooooooo06Ooool008Woool00`000?ooooooo`03oooo0`00
01<co`000`000?ooooooo`0>oooo00?o09Woooooool0Ioooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o000C<ol000<0003oooooool03_ooo`03o`2Ioooooooo06Ooool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o000C<ol000<0003oooooool03_ooo`03o`2Ioooooooo06Ooool0
08Soool200001Oooo`030000<ol0<ol0018co`000`000?ooooooo`0?oooo00?o09Woooooool0Iooo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0?oooo00?o09Woooooool0Ioooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`0?oooo00?o09Woooooool0Ioooo`00Soooo`030000
<ol0<ol0018co`000`000?ooooooo`0?oooo00?o09Woooooool0Ioooo`00Soooo`80000B<ol000<0
003oooooool04?ooo`03o`2Ioooooooo06Ooool008ooool00`0003?o03?o000A<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo06Ooool008ooool00`0003?o03?o000A<ol000<0003oooooool04?oo
o`03o`2Ioooooooo06Ooool008ooool00`0003?o03?o000A<ol000<0003oooooool04?ooo`03o`2I
oooooooo06Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool04Oooo`03o`2Ioooooooo
06Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Ooool0
08ooool200004C?o00030000oooooooo017oool00ol0VOooooooo`1Woooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo017oool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`003c?o
00030000oooooooo01;oool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`003c?o00030000
oooooooo01;oool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`003c?o00030000oooooooo
01;oool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`003c?o00030000oooooooo01;oool0
0ol0VOooooooo`1Woooo002?oooo0P00010co`000`000?ooooooo`0Boooo00?o09Woooooool0Iooo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Coooo00?o09Woooooool0Ioooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`0Coooo00?o09Woooooool0Ioooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`0Coooo00?o09Woooooool0Ioooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0Coooo00?o09Woooooool0Ioooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`0Coooo00?o09Woooooool0Ioooo`00Soooo`80000><ol000<0003oooooool05?oo
o`03o`2Ioooooooo06Ooool008ooool00`0003?o03?o000=<ol000<0003oooooool05?ooo`03o`2I
oooooooo06Ooool008ooool00`0003?o03?o000=<ol000<0003oooooool05?ooo`03o`2Ioooooooo
06Ooool008ooool00`0003?o03?o000=<ol000<0003oooooool05?ooo`03o`2Ioooooooo06Ooool0
08ooool00`0003?o03?o000<<ol000<0003oooooool05Oooo`03o`2Ioooooooo06Ooool008Woool3
00000oooo`030000<ol0<ol000`co`000`000?ooooooo`0Eoooo00?o09Woooooool0Ioooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o000<<ol000<0003oooooool05Oooo`03o`2Ioooooooo
06Ooool008Ooool500000oooo`<0000<<ol000<0003oooooool05Oooo`03o`2Ioooooooo06Ooool0
08Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_oo
o`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0
003oooooool04oooo`hco`07oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`09oooo3S?o00Soool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01oooo`800004<ol00P0000@co`0200000S?o0003oooo00000000
00800003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo000023?o00070000<ol0<ol00000<ol0
oooo000000Koool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000Xco`000`0003?o03?o0002oooo00<0003oooooool01?ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002c?o00030000
<ol0oooo00;oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Pco`00100003?o03?o000000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:<ol00P000004<ol0
oooooooooooo0P0000?oool00`000?ooooooo`1ioooo002?oooo3C?o08Coool008ooool=<ol0Q?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.33) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.64043 .12361 L
.64559 .12361 L
.65045 .12361 L
.65258 .12361 L
.65482 .12361 L
.65599 .12361 L
s
.65599 .12361 m
.65651 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 .12361 L
.34309 .12349 L
.34373 .12315 L
.34441 .1228 L
.34564 .12218 L
.3484 .12078 L
.3534 .11831 L
.36276 .1139 L
.38373 .10495 L
.4217 .09164 L
.46213 .08097 L
.50104 .07348 L
.5424 .06656 L
.58224 .05986 L
.62057 .05369 L
.64035 .05068 L
.65033 .04922 L
.65307 .04883 L
.6545 .04863 L
.65529 .04851 L
.65602 .04841 L
.65666 .04832 L
.65735 .12361 L
.65811 .12361 L
.6588 .12361 L
.66135 .12361 L
.70134 .12361 L
.7398 .12361 L
.78072 .12361 L
.82012 .12361 L
.85801 .12361 L
.89835 .12361 L
.93717 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.33) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool09?ooo`80I_mXoooo002?oooo0P00023oool506Ko00?oool0I_ooool0Iooo
o`00Soooo`030000oooooooo01Soool706Ko1_ooo`0306Kooooooooo06Koool008ooool00`000?oo
ooooo`0@oooo201Vo`goool00`1Vooooooooo`1Voooo002?oooo00<0003oooooool02oooo`D0I_lE
oooo00<0I_ooooooool0I_ooo`00Soooo`030000oooooooo00Koool506Ko6_ooo`0306Kooooooooo
06Koool008ooool00`000?ooooooo`0606Ko7oooo`0306Kooooooooo06Koool008goool206Ko0P00
000306Kooooooooo02?oool00`1Vooooooooo`1Voooo000Goooo1@0003?oool200001?ooo`800004
oooo0P0002_oool506Ko0_ooo`030000oooooooo02Goool00`1Vooooooooo`0:oooo0P0000Coool2
00001?ooo`80000doooo1@0001Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00008
oooo00@0003oooooool0000Uoooo1@1Vo`Ooool00`000?ooooooo`0Uoooo00<0I_ooooooool02Ooo
o`040000oooooooo00002?ooo`040000oooooooo0000=Oooo`030000oooooooo01Goool001Woool0
0`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0003oooooool07_ooo`D0I_l<oooo00<0
003oooooool09Oooo`0306Kooooooooo00Woool010000?ooooooo`0000_oool00`000?ooooooo`0c
oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?ooo`@00002oooo00@0
003oooooool00009oooo0P0001goool406Ko4Oooo`030000oooooooo02Goool00`1Vooooooooo`09
oooo00@0003oooooool00009oooo0P0003Koool00`000?ooooooo`0Eoooo000Ioooo00<0003ooooo
ool0<_ooo`040000oooooooo00002Oooo`030000oooooooo01[oool206Ko5Oooo`030000oooooooo
02Goool00`1Vooooooooo`09oooo00@0003oooooool00009oooo00<0003oooooool0=Oooo`030000
oooooooo01Goool001Soool20000=Oooo`80000:oooo0`0001Ooool306Ko5oooo`80000Voooo00<0
I_ooooooool02_ooo`80000:oooo0`0003Coool200005oooo`00Loooo`80I_lJoooo00<0003ooooo
ool09Oooo`0306Kooooooooo06Koool0073oool306Ko7?ooo`030000oooooooo02Goool00`1Voooo
ooooo`1Voooo001^oooo0P1Voaooool00`000?ooooooo`0Uoooo00<0I_ooooooool0I_ooo`00K?oo
o`80I_lQoooo00<0003oooooool09Oooo`0306Kooooooooo06Koool006[oool206Ko8oooo`030000
oooooooo02Goool00`1Vooooooooo`1Voooo000@ooooo`00017oool001Koool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000D0000co`0co`0co`3o09T01c?o00030000<ol0<ol000Tco`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Xco`000`0003?o03?o0009<ol000<0
000co`0co`002C?o00030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0>Oooo`030000<ol0<ol002Dco`000ol0VC?o03?o000A<ol000<0000co`0co`00=S?o00D0000G
oooo002?oooo00<0000co`0co`009C?o0003o`2I<ol0<ol0048co`0800007?ooo`00Soooo`030000
<ol0<ol002Dco`000ol0VC?o03?o000l<ol01P0002Coool008ooool00`0003?o03?o000U<ol000?o
09Tco`0co`00=c?o00D0000Zoooo002?oooo00<0000co`0co`009C?o0003o`2I<ol0<ol0038co`05
0000;oooo`00Soooo`80000V<ol000?o09Tco`0co`00;C?o00D0000doooo002?oooo00<0000co`0c
o`009C?o0003o`2I<ol0<ol002Tco`040000>Oooo`00Soooo`030000<ol0<ol002Dco`000ol0VC?o
03?o000W<ol00P0003goool008ooool00`0003?o03?o000U<ol000?o09Tco`0co`0093?o00<0000o
oooo002?oooo00<0000co`0co`009C?o0003o`2I<ol0<ol0028co`020000@_ooo`00Soooo`030000
<ol0<ol002Dco`000ol0VC?o03?o000P<ol00P0004Coool008ooool200009S?o0003o`2I<ol0<ol0
01hco`020000A_ooo`00Soooo`030000<ol0<ol002Dco`000ol0VC?o03?o000L<ol00P0004Soool0
08ooool00`0003?o03?o000U<ol000?o09Tco`0co`006c?o00030000oooooooo04Soool008ooool0
0`0003?o03?o000U<ol000?o09Tco`0co`006C?o0080001;oooo002?oooo00<0000co`0co`009C?o
0003o`2I<ol0<ol001Lco`020000COooo`00Soooo`030000<ol0<ol002Dco`000ol0VC?o03?o000F
<ol000<0003oooooool0COooo`00Soooo`80000V<ol000?o09Tco`0co`0053?o0080001@oooo002?
oooo00<0000co`0co`009C?o0003o`2I<ol0<ol0018co`020000D_ooo`00Soooo`030000<ol0<ol0
02Dco`000ol0VC?o03?o000A<ol000<0003oooooool0D_ooo`00Soooo`030000<ol0<ol002Dco`00
0ol0VC?o03?o000@<ol000<0003oooooool0Doooo`00Soooo`030000<ol0<ol002Dco`000ol0VC?o
03?o000><ol00P0005Koool008ooool00`0003?o03?o000U<ol000?o09Tco`0co`003C?o00030000
oooooooo05Koool008ooool200009S?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1Goooo002?
oooo00<0000co`0co`009C?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1Hoooo002?oooo00<0
000co`0co`009C?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1Ioooo002?oooo00<0000co`0c
o`009C?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1Joooo002?oooo00<0000co`0co`009C?o
0003o`2I<ol0<ol000Tco`000`000?ooooooo`1Joooo0027oooo1@0000?oool00`0003?o03?o000U
<ol000?o09Tco`0co`0023?o00030000oooooooo05_oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`009C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1Loooo0029oooo00<0003ooooo
ool00oooo`<0000U<ol000?o09Tco`0co`001S?o00030000oooooooo05goool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`009C?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1Moooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol002Dco`000ol0VC?o03?o0005<ol000<0003ooooo
ool0G_ooo`00R?ooo`800005oooo00<0000co`0co`009C?o0003o`2I<ol0<ol000@co`000`000?oo
ooooo`1Ooooo002?oooo00<0000co`0co`009C?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1P
oooo002?oooo00<0000co`0co`009C?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1Poooo002?
oooo0P0002Hco`000ol0VC?o03?o0002<ol000<0003oooooool0HOooo`00Soooo`030000<ol0<ol0
02Dco`001Ol0VC?o03?o03?o0000001Toooo002?oooo00<0000co`0co`009C?o0005o`2I<ol0<ol0
<ol0000006Coool008ooool00`0003?o03?o000U<ol000Co09Tco`0co`00001Uoooo002?oooo00<0
000co`0co`009C?o0003o`2I<ol0000006Koool008ooool00`0003?o03?o000U<ol000?o09T0003o
ool0I_ooo`00Soooo`80000V<ol000?o09T0003oool0I_ooo`00Soooo`030000<ol0<ol002Dco`00
0ol0VOooooooo`1Voooo002?oooo00<0000co`0co`0093?o00030000o`2Ioooo06Ooool008ooool0
0`0003?o03?o000T<ol000<0003o09Woool0Ioooo`00Soooo`030000<ol0<ol002<co`000`000?oo
ool0V@1Xoooo002?oooo00<0000co`0co`008c?o00030000ooooo`2I06Soool008ooool00`0003?o
03?o000R<ol000@0003ooooooooo09UXoooo002?oooo0P0002<co`0010000?ooooooool0VFSoool0
08ooool00`0003?o03?o000Q<ol000D0003ooooooooooooo09T0J?ooo`00Soooo`030000<ol0<ol0
024co`001@000?ooooooooooool0V@1Xoooo002?oooo00<0000co`0co`0083?o00030000oooooooo
00;oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`0083?o00030000oooooooo00;oool0
0ol0VOooooooo`1Voooo002?oooo00<0000co`0co`0083?o00030000oooooooo00;oool00ol0VOoo
ooooo`1Voooo002?oooo0P00020co`000`000?ooooooo`03oooo00?o09Woooooool0I_ooo`00Sooo
o`030000<ol0<ol001lco`000`000?ooooooo`03oooo00?o09Woooooool0I_ooo`00Soooo`030000
<ol0<ol001hco`000`000?ooooooo`04oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol0
01hco`000`000?ooooooo`04oooo00?o09Woooooool0I_ooo`00Qoooo`@00004oooo00<0000co`0c
o`007S?o00030000oooooooo00Coool00ol0VOooooooo`1Voooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol001dco`000`000?ooooooo`05oooo00?o09Woooooool0I_ooo`00R?ooo`030000
oooooooo00Coool300007C?o00030000oooooooo00Goool00ol0VOooooooo`1Voooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`05oooo00?o09Woooooool0I_oo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001`co`000`000?ooooooo`06oooo00?o
09Woooooool0I_ooo`00R?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo00Koool0
0ol0VOooooooo`1Voooo002?oooo00<0000co`0co`006c?o00030000oooooooo00Ooool00ol0VOoo
ooooo`1Voooo002?oooo00<0000co`0co`006c?o00030000oooooooo00Ooool00ol0VOooooooo`1V
oooo002?oooo0P0001`co`000`000?ooooooo`07oooo00?o09Woooooool0I_ooo`00Soooo`030000
<ol0<ol001Xco`000`000?ooooooo`08oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol0
01Xco`000`000?ooooooo`08oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol001Xco`00
0`000?ooooooo`08oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`08oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`09
oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`09oooo00?o
09Woooooool0I_ooo`00Soooo`80000J<ol000<0003oooooool02Oooo`03o`2Ioooooooo06Koool0
08ooool00`0003?o03?o000H<ol000<0003oooooool02_ooo`03o`2Ioooooooo06Koool008ooool0
0`0003?o03?o000H<ol000<0003oooooool02_ooo`03o`2Ioooooooo06Koool008ooool00`0003?o
03?o000H<ol000<0003oooooool02_ooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000G
<ol000<0003oooooool02oooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000G<ol000<0
003oooooool02oooo`03o`2Ioooooooo06Koool008ooool2000063?o00030000oooooooo00_oool0
0ol0VOooooooo`1Voooo002?oooo00<0000co`0co`005c?o00030000oooooooo00_oool00ol0VOoo
ooooo`1Voooo002?oooo00<0000co`0co`005S?o00030000oooooooo00coool00ol0VOooooooo`1V
oooo002?oooo00<0000co`0co`005S?o00030000oooooooo00coool00ol0VOooooooo`1Voooo002?
oooo00<0000co`0co`005S?o00030000oooooooo00coool00ol0VOooooooo`1Voooo002?oooo00<0
000co`0co`005C?o00030000oooooooo00goool00ol0VOooooooo`1Voooo002?oooo0P0001Hco`00
0`000?ooooooo`0=oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol001Dco`000`000?oo
ooooo`0=oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0=
oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`0>oooo00?o
09Woooooool0I_ooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo00koool0
0ol0VOooooooo`1Voooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0053?o00030000
oooooooo00koool00ol0VOooooooo`1Voooo0029oooo00<0003oooooool00oooo`<0000C<ol000<0
003oooooool03oooo`03o`2Ioooooooo06Koool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`004c?o00030000oooooooo00ooool00ol0VOooooooo`1Voooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`004c?o00030000oooooooo00ooool00ol0VOooooooo`1Voooo0028oooo0P00
00Goool00`0003?o03?o000B<ol000<0003oooooool04?ooo`03o`2Ioooooooo06Koool008ooool0
0`0003?o03?o000B<ol000<0003oooooool04?ooo`03o`2Ioooooooo06Koool008ooool00`0003?o
03?o000B<ol000<0003oooooool04?ooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000B
<ol000<0003oooooool04?ooo`03o`2Ioooooooo06Koool008ooool200004S?o00030000oooooooo
017oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`004C?o00030000oooooooo017oool0
0ol0VOooooooo`1Voooo002?oooo00<0000co`0co`004C?o00030000oooooooo017oool00ol0VOoo
ooooo`1Voooo002?oooo00<0000co`0co`004C?o00030000oooooooo017oool00ol0VOooooooo`1V
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo01;oool00ol0VOooooooo`1Voooo002?
oooo00<0000co`0co`0043?o00030000oooooooo01;oool00ol0VOooooooo`1Voooo002?oooo0P00
014co`000`000?ooooooo`0Boooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`0Boooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`0Coooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0C
oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Coooo00?o
09Woooooool0I_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Coooo00?o09Wooooo
ool0I_ooo`00Soooo`80000@<ol000<0003oooooool04oooo`03o`2Ioooooooo06Koool008ooool0
0`0003?o03?o000><ol000<0003oooooool05?ooo`03o`2Ioooooooo06Koool008ooool00`0003?o
03?o000><ol000<0003oooooool05?ooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000>
<ol000<0003oooooool05?ooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000><ol000<0
003oooooool05?ooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000><ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo06Koool008ooool200003S?o00030000oooooooo01Goool00ol0VOoo
ooooo`1Voooo002?oooo00<0000co`0co`003C?o00030000oooooooo01Goool00ol0VOooooooo`1V
oooo002?oooo00<0000co`0co`003C?o00030000oooooooo01Goool00ol0VOooooooo`1Voooo002?
oooo00<0000co`0co`003C?o00030000oooooooo01Goool00ol0VOooooooo`1Voooo002?oooo00<0
000co`0co`0033?o00030000oooooooo01Koool00ol0VOooooooo`1Voooo0029oooo0`0000?oool0
0`0003?o03?o000<<ol000<0003oooooool05_ooo`03o`2Ioooooooo06Koool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0033?o00030000oooooooo01Koool00ol0VOooooooo`1Voooo0027
oooo1@0000?oool3000033?o00030000oooooooo01Koool00ol0VOooooooo`1Voooo0027oooo00@0
003oooooool00004oooo3c?o08;oool008Soool00`000?ooo`000004oooo3c?o08;oool008Woool2
00001?ooo`lco`22oooo002?oooo3c?o08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo
01?oool><ol01oooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`hco`08oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Ooool2000013?o00800004<ol00P00008co`02oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00008<ol000L0000co`0co`00000co`3oool000000_ooo`050000
oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002S?o00030000<ol0<ol000?oool00`000?ooooooo`03oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000;<ol000<0000co`3oool00ooo
o`050000oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00008<ol000@0000co`0co`000002oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200002S?o0080000013?o0?ooooooooooo`800003oooo00<0
003oooooool0NOooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65519 .12361 L
.65954 .12361 L
.66069 .12361 L
.66177 .12361 L
s
.66177 .12361 m
.66222 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.32831 .12361 L
.33304 .12361 L
.33443 .12361 L
.33575 .12361 L
.33693 .12361 L
.33823 .12354 L
.33945 .12291 L
.34075 .12224 L
.34309 .12106 L
.38467 .10272 L
.42473 .08932 L
.46328 .07967 L
.50429 .07222 L
.54378 .06581 L
.58175 .05958 L
.62217 .05319 L
.64081 .05039 L
.65064 .04897 L
.65602 .04821 L
.65866 .04784 L
.65982 .04768 L
.66108 .0475 L
.66231 .12361 L
.6636 .12361 L
.66632 .12361 L
.67211 .12361 L
.68232 .12361 L
.70244 .12361 L
.743 .12361 L
.78205 .12361 L
.82354 .12361 L
.86353 .12361 L
.90199 .12361 L
.94291 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool08oooo`@0I_mWoooo002?oooo0P00023oool406Ko0oooo`0306Kooooooooo
06Goool008ooool00`000?ooooooo`0Hoooo1`1Vo`Ooool00`1Vooooooooo`1Uoooo002?oooo00<0
003oooooool04?ooo`P0I_l>oooo00<0I_ooooooool0IOooo`00Soooo`030000oooooooo00_oool5
06Ko5_ooo`0306Kooooooooo06Goool008ooool00`000?ooooooo`04oooo1`1Voa_oool00`1Voooo
ooooo`1Uoooo002>oooo00<0I_l00000I_l01@1Vob;oool00`1Vooooooooo`1Uoooo0029oooo1@1V
o`03oooo0000000002Ooool00`1Vooooooooo`1Uoooo000Goooo1@0003?oool200001?ooo`800004
oooo0P0002Soool406Ko1_ooo`030000oooooooo02Koool00`1Vooooooooo`09oooo0P0000Coool2
00001?ooo`80000doooo1@0001Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00008
oooo00@0003oooooool0000Toooo0`1Vo`[oool00`000?ooooooo`0Voooo00<0I_ooooooool02?oo
o`040000oooooooo00002?ooo`040000oooooooo0000=Oooo`030000oooooooo01Goool001Woool0
0`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0003oooooool07_ooo`@0I_l=oooo00<0
003oooooool09_ooo`0306Kooooooooo00Soool010000?ooooooo`0000_oool00`000?ooooooo`0c
oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?ooo`@00002oooo00@0
003oooooool00009oooo0P0001koool306Ko4Oooo`030000oooooooo02Koool00`1Vooooooooo`08
oooo00@0003oooooool00009oooo0P0003Koool00`000?ooooooo`0Eoooo000Ioooo00<0003ooooo
ool0<_ooo`040000oooooooo00002Oooo`030000oooooooo01[oool306Ko5?ooo`030000oooooooo
02Koool00`1Vooooooooo`08oooo00@0003oooooool00009oooo00<0003oooooool0=Oooo`030000
oooooooo01Goool001Soool20000=Oooo`80000:oooo0`0001Koool406Ko5oooo`80000Woooo00<0
I_ooooooool02Oooo`80000:oooo0`0003Coool200005oooo`00LOooo`<0I_lKoooo00<0003ooooo
ool09_ooo`0306Kooooooooo06Goool006ooool206Ko7_ooo`030000oooooooo02Koool00`1Voooo
ooooo`1Uoooo001]oooo0P1Vob3oool00`000?ooooooo`0Voooo00<0I_ooooooool0IOooo`00Jooo
o`80I_lRoooo00<0003oooooool09_ooo`0306Kooooooooo06Goool006Woool206Ko9?ooo`030000
oooooooo02Koool00`1Vooooooooo`1Uoooo000@ooooo`00017oool001Koool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`000S?o0003o`2I<ol0<ol000@co`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000V<ol000?o09Tco`0co`0043?o00030000<ol0<ol0
03Hco`0500005oooo`00Soooo`030000<ol0<ol002Hco`000ol0VC?o03?o0011<ol0200001coool0
08ooool00`0003?o03?o000V<ol000?o09Tco`0co`00>c?o00H0000Toooo002?oooo00<0000co`0c
o`009S?o0003o`2I<ol0<ol003Hco`050000:_ooo`00Soooo`030000<ol0<ol002Hco`000ol0VC?o
03?o000a<ol01@0002ooool008ooool200009c?o0003o`2I<ol0<ol002`co`050000=?ooo`00Sooo
o`030000<ol0<ol002Hco`000ol0VC?o03?o000X<ol0100003Woool008ooool00`0003?o03?o000V
<ol000?o09Tco`0co`009S?o0080000moooo002?oooo00<0000co`0co`009S?o0003o`2I<ol0<ol0
02<co`030000?oooo`00Soooo`030000<ol0<ol002Hco`000ol0VC?o03?o000Q<ol00P0004;oool0
08ooool00`0003?o03?o000V<ol000?o09Tco`0co`007c?o00800014oooo002?oooo0P0002Lco`00
0ol0VC?o03?o000M<ol00P0004Koool008ooool00`0003?o03?o000V<ol000?o09Tco`0co`006c?o
00800018oooo002?oooo00<0000co`0co`009S?o0003o`2I<ol0<ol001Xco`000`000?ooooooo`18
oooo002?oooo00<0000co`0co`009S?o0003o`2I<ol0<ol001Pco`020000Boooo`00Soooo`030000
<ol0<ol002Hco`000ol0VC?o03?o000F<ol00P0004goool008ooool00`0003?o03?o000V<ol000?o
09Tco`0co`005C?o00030000oooooooo04goool008ooool200009c?o0003o`2I<ol0<ol001<co`02
0000D?ooo`00Soooo`030000<ol0<ol002Hco`000ol0VC?o03?o000A<ol00P0005;oool008ooool0
0`0003?o03?o000V<ol000?o09Tco`0co`0043?o00030000oooooooo05;oool008ooool00`0003?o
03?o000V<ol000?o09Tco`0co`003c?o00030000oooooooo05?oool008ooool00`0003?o03?o000V
<ol000?o09Tco`0co`003C?o0080001Foooo002?oooo00<0000co`0co`009S?o0003o`2I<ol0<ol0
00`co`000`000?ooooooo`1Foooo002?oooo0P0002Lco`000ol0VC?o03?o000;<ol000<0003ooooo
ool0Eoooo`00Soooo`030000<ol0<ol002Hco`000ol0VC?o03?o000:<ol000<0003oooooool0F?oo
o`00Soooo`030000<ol0<ol002Hco`000ol0VC?o03?o0009<ol000<0003oooooool0FOooo`00Sooo
o`030000<ol0<ol002Hco`000ol0VC?o03?o0008<ol000<0003oooooool0F_ooo`00Soooo`030000
<ol0<ol002Hco`000ol0VC?o03?o0008<ol000<0003oooooool0F_ooo`00Qoooo`D00003oooo00<0
000co`0co`009S?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1Koooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol002Hco`000ol0VC?o03?o0006<ol000<0003oooooool0G?ooo`00ROoo
o`030000oooooooo00?oool300009S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1Moooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol002Hco`000ol0VC?o03?o0005<ol000<0003ooooo
ool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000V<ol000?o09Tco`0co`0013?o
00030000oooooooo05koool008Soool200001Oooo`030000<ol0<ol002Hco`000ol0VC?o03?o0003
<ol000<0003oooooool0Goooo`00Soooo`030000<ol0<ol002Hco`000ol0VC?o03?o0002<ol000<0
003oooooool0H?ooo`00Soooo`030000<ol0<ol002Hco`000ol0VC?o03?o0002<ol000<0003ooooo
ool0H?ooo`00Soooo`80000W<ol000Go09Tco`0co`0co`000000Hoooo`00Soooo`030000<ol0<ol0
02Hco`001?l0VC?o03?o000006Coool008ooool00`0003?o03?o000V<ol000Co09Tco`0co`00001T
oooo002?oooo00<0000co`0co`009S?o0003o`2I<ol0000006Goool008ooool00`0003?o03?o000V
<ol000?o09T0003oool0IOooo`00Soooo`030000<ol0<ol002Hco`000ol0VOooooooo`1Uoooo002?
oooo0P0002Lco`000ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`009C?o00030000o`2Ioooo
06Koool008ooool00`0003?o03?o000T<ol000<0003ooooo09T0Ioooo`00Soooo`030000<ol0<ol0
02@co`000`000?ooool0V@1Woooo002?oooo00<0000co`0co`008c?o00040000ooooooooo`2IIooo
o`00Soooo`030000<ol0<ol002<co`0010000?ooooooool0VFOoool008ooool00`0003?o03?o000R
<ol000D0003ooooooooooooo09T0Ioooo`00Soooo`80000S<ol000D0003ooooooooooooo09T0Iooo
o`00Soooo`030000<ol0<ol0024co`000`000?ooooooo`02oooo00?o09Woooooool0IOooo`00Sooo
o`030000<ol0<ol0024co`000`000?ooooooo`02oooo00?o09Woooooool0IOooo`00Soooo`030000
<ol0<ol0020co`000`000?ooooooo`03oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0
020co`000`000?ooooooo`03oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0020co`00
0`000?ooooooo`03oooo00?o09Woooooool0IOooo`00Soooo`80000P<ol000<0003oooooool01?oo
o`03o`2Ioooooooo06Goool008ooool00`0003?o03?o000O<ol000<0003oooooool01?ooo`03o`2I
oooooooo06Goool008ooool00`0003?o03?o000N<ol000<0003oooooool01Oooo`03o`2Ioooooooo
06Goool008ooool00`0003?o03?o000N<ol000<0003oooooool01Oooo`03o`2Ioooooooo06Goool0
08Ooool400001?ooo`030000<ol0<ol001hco`000`000?ooooooo`05oooo00?o09Woooooool0IOoo
o`00Qoooo`030000oooooooo00Goool00`0003?o03?o000M<ol000<0003oooooool01_ooo`03o`2I
oooooooo06Goool008Soool00`000?ooooooo`04oooo0`0001dco`000`000?ooooooo`06oooo00?o
09Woooooool0IOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo06Goool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000L
<ol000<0003oooooool01oooo`03o`2Ioooooooo06Goool008Soool200001Oooo`030000<ol0<ol0
01`co`000`000?ooooooo`07oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol001/co`00
0`000?ooooooo`08oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol001/co`000`000?oo
ooooo`08oooo00?o09Woooooool0IOooo`00Soooo`80000L<ol000<0003oooooool02?ooo`03o`2I
oooooooo06Goool008ooool00`0003?o03?o000J<ol000<0003oooooool02Oooo`03o`2Ioooooooo
06Goool008ooool00`0003?o03?o000J<ol000<0003oooooool02Oooo`03o`2Ioooooooo06Goool0
08ooool00`0003?o03?o000J<ol000<0003oooooool02Oooo`03o`2Ioooooooo06Goool008ooool0
0`0003?o03?o000J<ol000<0003oooooool02Oooo`03o`2Ioooooooo06Goool008ooool00`0003?o
03?o000I<ol000<0003oooooool02_ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o000I
<ol000<0003oooooool02_ooo`03o`2Ioooooooo06Goool008ooool200006S?o00030000oooooooo
00[oool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`0063?o00030000oooooooo00_oool0
0ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`0063?o00030000oooooooo00_oool00ol0VOoo
ooooo`1Uoooo002?oooo00<0000co`0co`0063?o00030000oooooooo00_oool00ol0VOooooooo`1U
oooo002?oooo00<0000co`0co`005c?o00030000oooooooo00coool00ol0VOooooooo`1Uoooo002?
oooo00<0000co`0co`005c?o00030000oooooooo00coool00ol0VOooooooo`1Uoooo002?oooo0P00
01Pco`000`000?ooooooo`0<oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol001Lco`00
0`000?ooooooo`0<oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol001Hco`000`000?oo
ooooo`0=oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol001Hco`000`000?ooooooo`0=
oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol001Hco`000`000?ooooooo`0=oooo00?o
09Woooooool0IOooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0>oooo00?o09Wooooo
ool0IOooo`00Soooo`80000F<ol000<0003oooooool03_ooo`03o`2Ioooooooo06Goool008ooool0
0`0003?o03?o000E<ol000<0003oooooool03_ooo`03o`2Ioooooooo06Goool008ooool00`0003?o
03?o000E<ol000<0003oooooool03_ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o000D
<ol000<0003oooooool03oooo`03o`2Ioooooooo06Goool008Soool200001Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`0?oooo00?o09Woooooool0IOooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol001@co`000`000?ooooooo`0?oooo00?o09Woooooool0IOooo`00ROooo`030000
oooooooo00?oool300004c?o00030000oooooooo013oool00ol0VOooooooo`1Uoooo002:oooo00<0
003oooooool00_ooo`030000<ol0<ol001<co`000`000?ooooooo`0@oooo00?o09Woooooool0IOoo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0@oooo00?o
09Woooooool0IOooo`00R?ooo`800005oooo00<0000co`0co`004S?o00030000oooooooo017oool0
0ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`004S?o00030000oooooooo017oool00ol0VOoo
ooooo`1Uoooo002?oooo00<0000co`0co`004S?o00030000oooooooo017oool00ol0VOooooooo`1U
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo017oool00ol0VOooooooo`1Uoooo002?
oooo0P00018co`000`000?ooooooo`0Boooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0
014co`000`000?ooooooo`0Boooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`0Boooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`0Boooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0C
oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Coooo00?o
09Woooooool0IOooo`00Soooo`80000A<ol000<0003oooooool04oooo`03o`2Ioooooooo06Goool0
08ooool00`0003?o03?o000@<ol000<0003oooooool04oooo`03o`2Ioooooooo06Goool008ooool0
0`0003?o03?o000?<ol000<0003oooooool05?ooo`03o`2Ioooooooo06Goool008ooool00`0003?o
03?o000?<ol000<0003oooooool05?ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o000?
<ol000<0003oooooool05?ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o000?<ol000<0
003oooooool05?ooo`03o`2Ioooooooo06Goool008ooool2000043?o00030000oooooooo01Coool0
0ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`003S?o00030000oooooooo01Goool00ol0VOoo
ooooo`1Uoooo002?oooo00<0000co`0co`003S?o00030000oooooooo01Goool00ol0VOooooooo`1U
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo01Goool00ol0VOooooooo`1Uoooo002?
oooo00<0000co`0co`003S?o00030000oooooooo01Goool00ol0VOooooooo`1Uoooo002?oooo00<0
000co`0co`003S?o00030000oooooooo01Goool00ol0VOooooooo`1Uoooo002?oooo0P0000hco`00
0`000?ooooooo`0Foooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol000dco`000`000?oo
ooooo`0Foooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0F
oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0Foooo00?o
09Woooooool0IOooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Goooo00?o09Wooooo
ool0IOooo`00ROooo`<00003oooo00<0000co`0co`0033?o00030000oooooooo01Ooool00ol0VOoo
ooooo`1Uoooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`0G
oooo00?o09Woooooool0IOooo`00Qoooo`D00003oooo0`0000`co`000`000?ooooooo`0Goooo00?o
09Woooooool0IOooo`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool0
00001?ooo`lco`22oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o
08;oool007Woool00`000?ooooooo`0Coooo3S?o00Ooool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo00Woool><ol02?ooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000@co`02000013?o00800002
<ol00oooo`<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo000023?o00050000<ol0<ol0
0000<ol000Coool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000
oooooooo00goool010000?ooooooo`0000Xco`00100003?o03?o0?ooo`D00003oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000;<ol000@0000co`3o
ool00002oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Pco`00100003?o03?o000000?oool00`000?ooo`000003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200002S?o008000000c?o0?ooooooo`02oooo0P00
00;oool00`000?ooooooo`1ioooo002?oooo3C?o08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66177 .12361 L
.66412 .12361 L
.66534 .12361 L
.66604 .12361 L
s
.66604 .12361 m
.6663 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.32831 .12361 L
.33073 .12361 L
.33193 .12361 L
.33304 .12361 L
.33433 .12309 L
.33575 .12236 L
.33823 .12111 L
.34309 .1187 L
.38221 .10184 L
.4238 .08823 L
.46386 .07855 L
.50241 .0718 L
.54342 .06538 L
.5829 .05906 L
.62088 .05315 L
.64202 .05001 L
.65204 .04859 L
.6613 .0473 L
.66369 .04697 L
.66487 .04681 L
.66594 .04667 L
.66707 .12361 L
.66828 .12361 L
.67087 .12361 L
.68128 .12361 L
.70021 .12361 L
.73983 .12361 L
.77794 .12361 L
.8185 .12361 L
.85755 .12361 L
.89905 .12361 L
.93903 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool08oooo`D0I_mVoooo002?oooo0P00023oool406Ko1?ooo`0306Kooooooooo
06Coool008ooool00`000?ooooooo`0Hoooo1`1Vo`Soool00`1Vooooooooo`1Toooo002?oooo00<0
003oooooool04?ooo`P0I_l?oooo00<0I_ooooooool0I?ooo`00Soooo`030000oooooooo00_oool5
06Ko5oooo`0306Kooooooooo06Coool008ooool00`000?ooooooo`04oooo1`1Voacoool00`1Voooo
ooooo`1Toooo002>oooo00<0I_l00000I_l01@1Vob?oool00`1Vooooooooo`1Toooo0029oooo1@1V
o`03oooo0000000002Soool00`1Vooooooooo`1Toooo000Goooo1@0003?oool200001?ooo`800004
oooo0P0002Ooool506Ko1_ooo`030000oooooooo02Ooool00`1Vooooooooo`08oooo0P0000Coool2
00001?ooo`80000doooo1@0001Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00008
oooo00@0003oooooool0000Qoooo1@1Vo`_oool00`000?ooooooo`0Woooo00<0I_ooooooool01ooo
o`040000oooooooo00002?ooo`040000oooooooo0000=Oooo`030000oooooooo01Goool001Woool0
0`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0003oooooool06oooo`@0I_l@oooo00<0
003oooooool09oooo`0306Kooooooooo00Ooool010000?ooooooo`0000_oool00`000?ooooooo`0c
oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?ooo`@00002oooo00@0
003oooooool00009oooo0P0001_oool306Ko5?ooo`030000oooooooo02Ooool00`1Vooooooooo`07
oooo00@0003oooooool00009oooo0P0003Koool00`000?ooooooo`0Eoooo000Ioooo00<0003ooooo
ool0<_ooo`040000oooooooo00002Oooo`030000oooooooo01Soool206Ko5oooo`030000oooooooo
02Ooool00`1Vooooooooo`07oooo00@0003oooooool00009oooo00<0003oooooool0=Oooo`030000
oooooooo01Goool001Soool20000=Oooo`80000:oooo0`0001Goool306Ko6Oooo`80000Xoooo00<0
I_ooooooool02?ooo`80000:oooo0`0003Coool200005oooo`00L?ooo`<0I_lLoooo00<0003ooooo
ool09oooo`0306Kooooooooo06Coool006koool206Ko7oooo`030000oooooooo02Ooool00`1Voooo
ooooo`1Toooo001[oooo0`1Vob7oool00`000?ooooooo`0Woooo00<0I_ooooooool0I?ooo`00JOoo
o`80I_lToooo00<0003oooooool09oooo`0306Kooooooooo06Coool006Ooool206Ko9_ooo`030000
oooooooo02Ooool00`1Vooooooooo`1Toooo000@ooooo`00017oool001Koool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`000c?o0003o`2I<ol0<ol000<co`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000W<ol000?o09Tco`0co`003c?o00030000<ol0<ol0
03Hco`0500005oooo`00Soooo`030000<ol0<ol002Lco`000ol0VC?o03?o0010<ol0200001coool0
08ooool00`0003?o03?o000W<ol000?o09Tco`0co`00>S?o00H0000Toooo002?oooo00<0000co`0c
o`009c?o0003o`2I<ol0<ol003Dco`050000:_ooo`00Soooo`030000<ol0<ol002Lco`000ol0VC?o
03?o000`<ol01@0002ooool008ooool20000:3?o0003o`2I<ol0<ol002/co`050000=?ooo`00Sooo
o`030000<ol0<ol002Lco`000ol0VC?o03?o000W<ol0100003Woool008ooool00`0003?o03?o000W
<ol000?o09Tco`0co`009C?o0080000moooo002?oooo00<0000co`0co`009c?o0003o`2I<ol0<ol0
028co`030000?oooo`00Soooo`030000<ol0<ol002Lco`000ol0VC?o03?o000P<ol00P0004;oool0
08ooool00`0003?o03?o000W<ol000?o09Tco`0co`007S?o00800014oooo002?oooo0P0002Pco`00
0ol0VC?o03?o000L<ol00P0004Koool008ooool00`0003?o03?o000W<ol000?o09Tco`0co`006S?o
00800018oooo002?oooo00<0000co`0co`009c?o0003o`2I<ol0<ol001Tco`000`000?ooooooo`18
oooo002?oooo00<0000co`0co`009c?o0003o`2I<ol0<ol001Lco`020000Boooo`00Soooo`030000
<ol0<ol002Lco`000ol0VC?o03?o000E<ol00P0004goool008ooool00`0003?o03?o000W<ol000?o
09Tco`0co`0053?o00030000oooooooo04goool008ooool20000:3?o0003o`2I<ol0<ol0018co`02
0000D?ooo`00Soooo`030000<ol0<ol002Lco`000ol0VC?o03?o000@<ol00P0005;oool008ooool0
0`0003?o03?o000W<ol000?o09Tco`0co`003c?o00030000oooooooo05;oool008ooool00`0003?o
03?o000W<ol000?o09Tco`0co`003S?o00030000oooooooo05?oool008ooool00`0003?o03?o000W
<ol000?o09Tco`0co`0033?o0080001Foooo002?oooo00<0000co`0co`009c?o0003o`2I<ol0<ol0
00/co`000`000?ooooooo`1Foooo002?oooo0P0002Pco`000ol0VC?o03?o000:<ol000<0003ooooo
ool0Eoooo`00Soooo`030000<ol0<ol002Lco`000ol0VC?o03?o0009<ol000<0003oooooool0F?oo
o`00Soooo`030000<ol0<ol002Lco`000ol0VC?o03?o0008<ol000<0003oooooool0FOooo`00Sooo
o`030000<ol0<ol002Lco`000ol0VC?o03?o0007<ol000<0003oooooool0F_ooo`00Soooo`030000
<ol0<ol002Lco`000ol0VC?o03?o0007<ol000<0003oooooool0F_ooo`00Qoooo`D00003oooo00<0
000co`0co`009c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1Koooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol002Lco`000ol0VC?o03?o0005<ol000<0003oooooool0G?ooo`00ROoo
o`030000oooooooo00?oool300009c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1Moooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol002Lco`000ol0VC?o03?o0004<ol000<0003ooooo
ool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000W<ol000?o09Tco`0co`000c?o
00030000oooooooo05koool008Soool200001Oooo`030000<ol0<ol002Lco`000ol0VC?o03?o0002
<ol000<0003oooooool0Goooo`00Soooo`030000<ol0<ol002Lco`001Ol0VC?o03?o03?o0000001R
oooo002?oooo00<0000co`0co`009c?o0005o`2I<ol0<ol0<ol0000006;oool008ooool20000:3?o
0004o`2I<ol0<ol00000Hoooo`00Soooo`030000<ol0<ol002Lco`000ol0VC?o0000001Toooo002?
oooo00<0000co`0co`009c?o0003o`2I<ol0000006Coool008ooool00`0003?o03?o000W<ol000?o
09T0003oool0I?ooo`00Soooo`030000<ol0<ol002Lco`000ol0VOooooooo`1Toooo002?oooo00<0
000co`0co`009S?o00030000o`2Ioooo06Goool008ooool200009c?o00030000o`2Ioooo06Goool0
08ooool00`0003?o03?o000U<ol000<0003ooooo09T0I_ooo`00Soooo`030000<ol0<ol002@co`00
10000?ooooooool0VFKoool008ooool00`0003?o03?o000T<ol000@0003ooooooooo09UVoooo002?
oooo00<0000co`0co`008c?o00050000ooooooooooooo`2I06Koool008ooool00`0003?o03?o000S
<ol000D0003ooooooooooooo09T0I_ooo`00Soooo`030000<ol0<ol0028co`000`000?ooooooo`02
oooo00?o09Woooooool0I?ooo`00Soooo`80000S<ol000<0003oooooool00_ooo`03o`2Ioooooooo
06Coool008ooool00`0003?o03?o000Q<ol000<0003oooooool00oooo`03o`2Ioooooooo06Coool0
08ooool00`0003?o03?o000Q<ol000<0003oooooool00oooo`03o`2Ioooooooo06Coool008ooool0
0`0003?o03?o000P<ol000<0003oooooool01?ooo`03o`2Ioooooooo06Coool008ooool00`0003?o
03?o000P<ol000<0003oooooool01?ooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000P
<ol000<0003oooooool01?ooo`03o`2Ioooooooo06Coool008ooool2000083?o00030000oooooooo
00Goool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`007c?o00030000oooooooo00Goool0
0ol0VOooooooo`1Toooo002?oooo00<0000co`0co`007S?o00030000oooooooo00Koool00ol0VOoo
ooooo`1Toooo002?oooo00<0000co`0co`007S?o00030000oooooooo00Koool00ol0VOooooooo`1T
oooo0027oooo100000Coool00`0003?o03?o000N<ol000<0003oooooool01_ooo`03o`2Ioooooooo
06Coool008Ooool00`000?ooooooo`05oooo00<0000co`0co`007C?o00030000oooooooo00Ooool0
0ol0VOooooooo`1Toooo0028oooo00<0003oooooool01?ooo`<0000M<ol000<0003oooooool01ooo
o`03o`2Ioooooooo06Coool008Woool00`000?ooooooo`03oooo00<0000co`0co`007C?o00030000
oooooooo00Ooool00ol0VOooooooo`1Toooo0027oooo00@0003oooooool00004oooo00<0000co`0c
o`0073?o00030000oooooooo00Soool00ol0VOooooooo`1Toooo0028oooo0P0000Goool00`0003?o
03?o000L<ol000<0003oooooool02?ooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000K
<ol000<0003oooooool02Oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000K<ol000<0
003oooooool02Oooo`03o`2Ioooooooo06Coool008ooool2000073?o00030000oooooooo00Woool0
0ol0VOooooooo`1Toooo002?oooo00<0000co`0co`006S?o00030000oooooooo00[oool00ol0VOoo
ooooo`1Toooo002?oooo00<0000co`0co`006S?o00030000oooooooo00[oool00ol0VOooooooo`1T
oooo002?oooo00<0000co`0co`006S?o00030000oooooooo00[oool00ol0VOooooooo`1Toooo002?
oooo00<0000co`0co`006S?o00030000oooooooo00[oool00ol0VOooooooo`1Toooo002?oooo00<0
000co`0co`006C?o00030000oooooooo00_oool00ol0VOooooooo`1Toooo002?oooo00<0000co`0c
o`006C?o00030000oooooooo00_oool00ol0VOooooooo`1Toooo002?oooo0P0001Xco`000`000?oo
ooooo`0;oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0<
oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0<oooo00?o
09Woooooool0I?ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0<oooo00?o09Wooooo
ool0I?ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0=oooo00?o09Woooooool0I?oo
o`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0=oooo00?o09Woooooool0I?ooo`00Sooo
o`80000H<ol000<0003oooooool03Oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000G
<ol000<0003oooooool03Oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000F<ol000<0
003oooooool03_ooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000F<ol000<0003ooooo
ool03_ooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000F<ol000<0003oooooool03_oo
o`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000E<ol000<0003oooooool03oooo`03o`2I
oooooooo06Coool008ooool200005S?o00030000oooooooo00ooool00ol0VOooooooo`1Toooo002?
oooo00<0000co`0co`005C?o00030000oooooooo00ooool00ol0VOooooooo`1Toooo002?oooo00<0
000co`0co`005C?o00030000oooooooo00ooool00ol0VOooooooo`1Toooo002?oooo00<0000co`0c
o`0053?o00030000oooooooo013oool00ol0VOooooooo`1Toooo0028oooo0P0000Goool00`0003?o
03?o000D<ol000<0003oooooool04?ooo`03o`2Ioooooooo06Coool008Ooool010000?ooooooo`00
00Coool00`0003?o03?o000D<ol000<0003oooooool04?ooo`03o`2Ioooooooo06Coool008Woool0
0`000?ooooooo`03oooo0`0001<co`000`000?ooooooo`0Aoooo00?o09Woooooool0I?ooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o000C<ol000<0003oooooool04Oooo`03o`2Ioooooooo
06Coool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000C<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo06Coool008Soool200001Oooo`030000<ol0<ol0018co`000`000?ooooooo`0B
oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Boooo00?o
09Woooooool0I?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Boooo00?o09Wooooo
ool0I?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Boooo00?o09Woooooool0I?oo
o`00Soooo`80000B<ol000<0003oooooool04oooo`03o`2Ioooooooo06Coool008ooool00`0003?o
03?o000A<ol000<0003oooooool04oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000A
<ol000<0003oooooool04oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000A<ol000<0
003oooooool04oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000@<ol000<0003oooooool05?oo
o`03o`2Ioooooooo06Coool008ooool200004C?o00030000oooooooo01Coool00ol0VOooooooo`1T
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo01Coool00ol0VOooooooo`1Toooo002?
oooo00<0000co`0co`003c?o00030000oooooooo01Goool00ol0VOooooooo`1Toooo002?oooo00<0
000co`0co`003c?o00030000oooooooo01Goool00ol0VOooooooo`1Toooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo01Goool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`003c?o
00030000oooooooo01Goool00ol0VOooooooo`1Toooo002?oooo0P00010co`000`000?ooooooo`0E
oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Foooo00?o
09Woooooool0I?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Foooo00?o09Wooooo
ool0I?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Foooo00?o09Woooooool0I?oo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Foooo00?o09Woooooool0I?ooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`0Foooo00?o09Woooooool0I?ooo`00Soooo`80000>
<ol000<0003oooooool05oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000=<ol000<0
003oooooool05oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000=<ol000<0003ooooo
ool05oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000=<ol000<0003oooooool05ooo
o`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000<<ol000<0003oooooool06?ooo`03o`2I
oooooooo06Coool008Woool300000oooo`030000<ol0<ol000`co`000`000?ooooooo`0Hoooo00?o
09Woooooool0I?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000<<ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo06Coool008Ooool500000oooo`<0000<<ol000<0003oooooool06?oo
o`03o`2Ioooooooo06Coool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?ooo`030000
oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_ooo`00Sooo
o`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07oooo00<0003oooooool0NOooo`00N?oo
o`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o00Soool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004<ol00P0000@co`02
00000S?o00;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Pco`001`0003?o
03?o000003?o0?ooo`000002oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0=oooo00@0003oooooool0000:<ol000<0000co`0co`001?ooo`030000
oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?oo
ooooo`0000/co`00100003?o0?ooooooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Pco`00100003?o03?o000000?oool00`000?oo
ooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002S?o00800000
13?o0?ooooooooooo`<00002oooo00<0003oooooool0NOooo`00Soooo`dco`24oooo002?oooo3C?o
08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66412 .12361 L
.66652 .12361 L
.66906 .12361 L
.67014 .12361 L
.67129 .12361 L
s
.67129 .12361 m
.67179 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.31875 .12361 L
.32392 .12361 L
.32617 .12361 L
.32728 .12361 L
.32831 .12361 L
.32949 .12313 L
.33078 .12247 L
.33304 .12132 L
.34309 .11641 L
.38221 .10008 L
.4238 .08692 L
.46386 .07759 L
.50241 .07112 L
.54342 .06492 L
.5829 .05875 L
.62088 .05293 L
.64202 .04984 L
.6613 .04714 L
.66594 .04652 L
.66848 .04618 L
.66973 .04601 L
.67087 .04586 L
.67211 .12361 L
.67276 .12361 L
.67344 .12361 L
.67628 .12361 L
.68128 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool09?ooo`D0I_mUoooo002?oooo0P0001_oool:06Ko1?ooo`0306Kooooooooo
06?oool008ooool00`000?ooooooo`0Eoooo1@1Vo`koool00`1Vooooooooo`1Soooo002?oooo00<0
003oooooool04?ooo`D0I_lCoooo00<0I_ooooooool0Hoooo`00Soooo`030000oooooooo00_oool5
06Ko6?ooo`0306Kooooooooo06?oool008ooool00`000?ooooooo`04oooo1`1Voagoool00`1Voooo
ooooo`1Soooo002>oooo00<0I_l00000I_l01@1VobCoool00`1Vooooooooo`1Soooo0029oooo1@1V
o`03oooo0000000002Woool00`1Vooooooooo`1Soooo000Goooo1@0003?oool200001?ooo`800004
oooo0P0002Ooool506Ko1_ooo`030000oooooooo02Soool00`1Vooooooooo`07oooo0P0000Coool2
00001?ooo`80000doooo1@0001Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00008
oooo00@0003oooooool0000Qoooo1@1Vo`_oool00`000?ooooooo`0Xoooo00<0I_ooooooool01_oo
o`040000oooooooo00002?ooo`040000oooooooo0000=Oooo`030000oooooooo01Goool001Woool0
0`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0003oooooool06oooo`@0I_l@oooo00<0
003oooooool0:Oooo`0306Kooooooooo00Goool010000?ooooooo`0000_oool00`000?ooooooo`0c
oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?ooo`@00002oooo00@0
003oooooool00009oooo0P0001[oool406Ko5?ooo`030000oooooooo02Woool00`1Vooooooooo`05
oooo00@0003oooooool00009oooo0P0003Koool00`000?ooooooo`0Eoooo000Ioooo00<0003ooooo
ool0<_ooo`040000oooooooo00002Oooo`030000oooooooo01Goool406Ko6?ooo`030000oooooooo
02Woool00`1Vooooooooo`05oooo00@0003oooooool00009oooo00<0003oooooool0=Oooo`030000
oooooooo01Goool001Soool20000=Oooo`80000:oooo0`0001?oool206Ko7?ooo`80000Zoooo00<0
I_ooooooool01_ooo`80000:oooo0`0003Coool200005oooo`00Koooo`80I_lNoooo00<0003ooooo
ool0:Oooo`0306Kooooooooo06;oool006goool206Ko8?ooo`030000oooooooo02Woool00`1Voooo
ooooo`1Roooo001[oooo0P1Vob;oool00`000?ooooooo`0Yoooo00<0I_ooooooool0H_ooo`00JOoo
o`80I_lToooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool006Ooool206Ko9_ooo`030000
oooooooo02Woool00`1Vooooooooo`1Roooo000@ooooo`00017oool001Koool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`0013?o0003o`2I<ol0<ol0008co`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000X<ol000?o09Tco`0co`003S?o00030000<ol0<ol0
03Hco`0500005oooo`00Soooo`030000<ol0<ol002Pco`000ol0VC?o03?o000o<ol0200001coool0
08ooool00`0003?o03?o000X<ol000?o09Tco`0co`00>C?o00H0000Toooo002?oooo00<0000co`0c
o`00:3?o0003o`2I<ol0<ol003@co`050000:_ooo`00Soooo`030000<ol0<ol002Pco`000ol0VC?o
03?o000_<ol01@0002ooool008ooool20000:C?o0003o`2I<ol0<ol002Xco`050000=?ooo`00Sooo
o`030000<ol0<ol002Pco`000ol0VC?o03?o000V<ol0100003Woool008ooool00`0003?o03?o000X
<ol000?o09Tco`0co`0093?o0080000moooo002?oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol0
024co`030000?oooo`00Soooo`030000<ol0<ol002Pco`000ol0VC?o03?o000O<ol00P0004;oool0
08ooool00`0003?o03?o000X<ol000?o09Tco`0co`007C?o00800014oooo002?oooo0P0002Tco`00
0ol0VC?o03?o000K<ol00P0004Koool008ooool00`0003?o03?o000X<ol000?o09Tco`0co`006C?o
00800018oooo002?oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol001Pco`000`000?ooooooo`18
oooo002?oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol001Hco`020000Boooo`00Soooo`030000
<ol0<ol002Pco`000ol0VC?o03?o000D<ol00P0004goool008ooool00`0003?o03?o000X<ol000?o
09Tco`0co`004c?o00030000oooooooo04goool008ooool20000:C?o0003o`2I<ol0<ol0014co`02
0000D?ooo`00Soooo`030000<ol0<ol002Pco`000ol0VC?o03?o000?<ol00P0005;oool008ooool0
0`0003?o03?o000X<ol000?o09Tco`0co`003S?o00030000oooooooo05;oool008ooool00`0003?o
03?o000X<ol000?o09Tco`0co`003C?o00030000oooooooo05?oool008ooool00`0003?o03?o000X
<ol000?o09Tco`0co`002c?o0080001Foooo002?oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol0
00Xco`000`000?ooooooo`1Foooo002?oooo0P0002Tco`000ol0VC?o03?o0009<ol000<0003ooooo
ool0Eoooo`00Soooo`030000<ol0<ol002Pco`000ol0VC?o03?o0008<ol000<0003oooooool0F?oo
o`00Soooo`030000<ol0<ol002Pco`000ol0VC?o03?o0007<ol000<0003oooooool0FOooo`00Sooo
o`030000<ol0<ol002Pco`000ol0VC?o03?o0006<ol000<0003oooooool0F_ooo`00Soooo`030000
<ol0<ol002Pco`000ol0VC?o03?o0006<ol000<0003oooooool0F_ooo`00Qoooo`D00003oooo00<0
000co`0co`00:3?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1Koooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol002Pco`000ol0VC?o03?o0004<ol000<0003oooooool0G?ooo`00ROoo
o`030000oooooooo00?oool30000:3?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1Moooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol002Pco`000ol0VC?o03?o0003<ol000<0003ooooo
ool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000X<ol000?o09Tco`0co`000S?o
00030000oooooooo05koool008Soool200001Oooo`030000<ol0<ol002Pco`001Ol0VC?o03?o03?o
0000001Qoooo002?oooo00<0000co`0co`00:3?o0004o`2I<ol0<ol00000H_ooo`00Soooo`030000
<ol0<ol002Pco`001?l0VC?o03?o000006;oool008ooool20000:C?o0003o`2I<ol0000006?oool0
08ooool00`0003?o03?o000X<ol000?o09T0003oool0Hoooo`00Soooo`030000<ol0<ol002Pco`00
0ol0V@000?ooo`1Soooo002?oooo00<0000co`0co`00:3?o0003o`2Ioooooooo06?oool008ooool0
0`0003?o03?o000W<ol000<0003o09Woool0I?ooo`00Soooo`030000<ol0<ol002Hco`000`000?oo
ool0V@1Uoooo002?oooo0P0002Lco`000`000?ooool0V@1Uoooo002?oooo00<0000co`0co`009C?o
00040000ooooooooo`2IIOooo`00Soooo`030000<ol0<ol002@co`001@000?ooooooooooool0V@1U
oooo002?oooo00<0000co`0co`0093?o00050000ooooooooooooo`2I06Goool008ooool00`0003?o
03?o000S<ol000<0003oooooool00_ooo`03o`2Ioooooooo06?oool008ooool00`0003?o03?o000S
<ol000<0003oooooool00_ooo`03o`2Ioooooooo06?oool008ooool00`0003?o03?o000R<ol000<0
003oooooool00oooo`03o`2Ioooooooo06?oool008ooool200008c?o00030000oooooooo00?oool0
0ol0VOooooooo`1Soooo002?oooo00<0000co`0co`008C?o00030000oooooooo00Coool00ol0VOoo
ooooo`1Soooo002?oooo00<0000co`0co`008C?o00030000oooooooo00Coool00ol0VOooooooo`1S
oooo002?oooo00<0000co`0co`0083?o00030000oooooooo00Goool00ol0VOooooooo`1Soooo002?
oooo00<0000co`0co`0083?o00030000oooooooo00Goool00ol0VOooooooo`1Soooo002?oooo00<0
000co`0co`0083?o00030000oooooooo00Goool00ol0VOooooooo`1Soooo002?oooo0P00020co`00
0`000?ooooooo`06oooo00?o09Woooooool0Hoooo`00Soooo`030000<ol0<ol001lco`000`000?oo
ooooo`06oooo00?o09Woooooool0Hoooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`07
oooo00?o09Woooooool0Hoooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`07oooo00?o
09Woooooool0Hoooo`00Qoooo`@00004oooo00<0000co`0co`007S?o00030000oooooooo00Ooool0
0ol0VOooooooo`1Soooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol001dco`000`000?oo
ooooo`08oooo00?o09Woooooool0Hoooo`00R?ooo`030000oooooooo00Coool300007C?o00030000
oooooooo00Soool00ol0VOooooooo`1Soooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`000`000?ooooooo`09oooo00?o09Woooooool0H_ooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol001`co`000`000?ooooooo`0:oooo00?o09Woooooool0H_ooo`00R?ooo`800005
oooo00<0000co`0co`0073?o00030000oooooooo00[oool00ol0VOooooooo`1Roooo002?oooo00<0
000co`0co`006c?o00030000oooooooo00_oool00ol0VOooooooo`1Roooo002?oooo00<0000co`0c
o`006c?o00030000oooooooo00_oool00ol0VOooooooo`1Roooo002?oooo0P0001`co`000`000?oo
ooooo`0;oooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0<
oooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0<oooo00?o
09Woooooool0H_ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0<oooo00?o09Wooooo
ool0H_ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0<oooo00?o09Woooooool0H_oo
o`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0=oooo00?o09Woooooool0H_ooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`0=oooo00?o09Woooooool0H_ooo`00Soooo`80000J
<ol000<0003oooooool03Oooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o000H<ol000<0
003oooooool03_ooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool03_ooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o000H<ol000<0003oooooool03_oo
o`03o`2Ioooooooo06;oool008ooool00`0003?o03?o000G<ol000<0003oooooool03oooo`03o`2I
oooooooo06;oool008ooool00`0003?o03?o000G<ol000<0003oooooool03oooo`03o`2Ioooooooo
06;oool008ooool2000063?o00030000oooooooo00ooool00ol0VOooooooo`1Roooo002?oooo00<0
000co`0co`005c?o00030000oooooooo00ooool00ol0VOooooooo`1Roooo002?oooo00<0000co`0c
o`005S?o00030000oooooooo013oool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`005S?o
00030000oooooooo013oool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`005S?o00030000
oooooooo013oool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`005C?o00030000oooooooo
017oool00ol0VOooooooo`1Roooo002?oooo0P0001Hco`000`000?ooooooo`0Aoooo00?o09Wooooo
ool0H_ooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0Aoooo00?o09Woooooool0H_oo
o`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0Aoooo00?o09Woooooool0H_ooo`00Sooo
o`030000<ol0<ol001@co`000`000?ooooooo`0Boooo00?o09Woooooool0H_ooo`00R?ooo`800005
oooo00<0000co`0co`0053?o00030000oooooooo01;oool00ol0VOooooooo`1Roooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0053?o00030000oooooooo01;oool00ol0VOooooooo`1R
oooo0029oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool04oooo`03o`2Ioooooooo
06;oool008[oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo01?oool0
0ol0VOooooooo`1Roooo0027oooo00@0003oooooool00004oooo00<0000co`0co`004c?o00030000
oooooooo01?oool00ol0VOooooooo`1Roooo0028oooo0P0000Goool00`0003?o03?o000B<ol000<0
003oooooool05?ooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o000B<ol000<0003oooooool05?oo
o`03o`2Ioooooooo06;oool008ooool00`0003?o03?o000B<ol000<0003oooooool05?ooo`03o`2I
oooooooo06;oool008ooool200004S?o00030000oooooooo01Goool00ol0VOooooooo`1Roooo002?
oooo00<0000co`0co`004C?o00030000oooooooo01Goool00ol0VOooooooo`1Roooo002?oooo00<0
000co`0co`004C?o00030000oooooooo01Goool00ol0VOooooooo`1Roooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo01Goool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`0043?o
00030000oooooooo01Koool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`0043?o00030000
oooooooo01Koool00ol0VOooooooo`1Roooo002?oooo0P00014co`000`000?ooooooo`0Foooo00?o
09Woooooool0H_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Foooo00?o09Wooooo
ool0H_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Goooo00?o09Woooooool0H_oo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Goooo00?o09Woooooool0H_ooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0Goooo00?o09Woooooool0H_ooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0Goooo00?o09Woooooool0H_ooo`00Soooo`80000@<ol000<0
003oooooool05oooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o000><ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o000><ol000<0003oooooool06?oo
o`03o`2Ioooooooo06;oool008ooool00`0003?o03?o000><ol000<0003oooooool06?ooo`03o`2I
oooooooo06;oool008ooool00`0003?o03?o000><ol000<0003oooooool06?ooo`03o`2Ioooooooo
06;oool008ooool00`0003?o03?o000><ol000<0003oooooool06?ooo`03o`2Ioooooooo06;oool0
08ooool200003S?o00030000oooooooo01Woool00ol0VOooooooo`1Roooo002?oooo00<0000co`0c
o`003C?o00030000oooooooo01Woool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`003C?o
00030000oooooooo01Woool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`003C?o00030000
oooooooo01Woool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`0033?o00030000oooooooo
01[oool00ol0VOooooooo`1Roooo0029oooo0`0000?oool00`0003?o03?o000<<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo06;oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0033?o
00030000oooooooo01[oool00ol0VOooooooo`1Roooo0027oooo1@0000?oool3000033?o00030000
oooooooo01[oool00ol0VOooooooo`1Roooo0027oooo00@0003oooooool00004oooo3c?o08;oool0
08Soool00`000?ooo`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o
08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o
00800004<ol00P00008co`001?ooo`000000000000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool00008<ol000L0000co`0co`00000co`3oool000000_ooo`050000oooooooooooo000007[oool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002S?o00050000
<ol0<ol0oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000<oooo00@0003oooooool0000;<ol000<0000co`3oool00`0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo000023?o00040000
<ol0<ol000000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`80000:<ol00P000004<ol0oooooooooooo0`0000;oool00`000?ooooooo`1ioooo002?
oooo3C?o08Coool008ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.37) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66412 .12361 L
.66906 .12361 L
.67133 .12361 L
.67373 .12361 L
.67472 .12361 L
.67578 .12361 L
s
.67578 .12361 m
.67625 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.31304 .12361 L
.31574 .12361 L
.31865 .12361 L
.32006 .12361 L
.3214 .12361 L
.3226 .12361 L
.32392 .12355 L
.32522 .12288 L
.32644 .12225 L
.32873 .12109 L
.33386 .11855 L
.34309 .11419 L
.38164 .09857 L
.42264 .08596 L
.46213 .077 L
.5001 .07078 L
.54052 .06492 L
.57943 .05899 L
.62079 .05275 L
.64149 .04975 L
.65059 .04847 L
.66064 .0471 L
.66525 .04648 L
.67022 .04582 L
.67251 .04552 L
.67376 .04535 L
.67492 .0452 L
.67591 .04507 L
.67697 .12361 L
.67815 .12361 L
.67922 .12361 L
.69897 .12361 L
.73895 .12361 L
.77742 .12361 L
.81833 .12361 L
.85774 .12361 L
.89562 .12361 L
.93596 .12361 L
.97479 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.37) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Zoooo00<0
I_ooooooool0HOooo`00Soooo`030000oooooooo02?oool806KoHoooo`00Soooo`80000Koooo2@1V
o`Ooool00`1Vooooooooo`1Qoooo002?oooo00<0003oooooool05?ooo`H0I_l@oooo00<0I_oooooo
ool0HOooo`00Soooo`030000oooooooo00ooool506Ko5_ooo`0306Kooooooooo067oool008ooool0
0`000?ooooooo`0:oooo1@1Voa_oool00`1Vooooooooo`1Qoooo002?oooo00<0003oooooool00ooo
o`L0I_lPoooo00<0I_ooooooool0HOooo`00SOooo`80I_l00`00001Vo`1Vo`0306Ko9oooo`0306Ko
oooooooo067oool008Soool506Ko0_ooo`80000[oooo00<0I_ooooooool0HOooo`005oooo`D0000c
oooo0P0000Coool200001?ooo`80000Voooo1@1Vo`Ooool00`000?ooooooo`0Zoooo00<0I_oooooo
ool01Oooo`800004oooo0P0000Coool20000=?ooo`D0000Eoooo000Ioooo00<0003oooooool0<_oo
o`040000oooooooo00002?ooo`040000oooooooo00008?ooo`D0I_l<oooo00<0003oooooool0:_oo
o`0306Kooooooooo00Coool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
01[oool406Ko4Oooo`030000oooooooo02[oool00`1Vooooooooo`04oooo00@0003oooooool0000;
oooo00<0003oooooool0<oooo`030000oooooooo01Goool0017oool400001?ooo`030000oooooooo
02coool400000_ooo`040000oooooooo00002Oooo`80000Joooo0`1VoaGoool00`000?ooooooo`0Z
oooo00<0I_ooooooool01?ooo`040000oooooooo00002Oooo`80000foooo00<0003oooooool05Ooo
o`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?ooooooo`0Eoooo101V
oaSoool00`000?ooooooo`0Zoooo00<0I_ooooooool01?ooo`040000oooooooo00002Oooo`030000
oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000Boooo0`1V
oacoool20000:oooo`0306Kooooooooo00Goool200002_ooo`<0000doooo0P0001Ooool006koool2
06Ko7oooo`030000oooooooo02[oool00`1Vooooooooo`1Qoooo001[oooo0`1Vob7oool00`000?oo
ooooo`0Zoooo00<0I_ooooooool0HOooo`00JOooo`80I_lToooo00<0003oooooool0:_ooo`0306Ko
oooooooo067oool006Ooool206Ko9_ooo`030000oooooooo02[oool00`1Vooooooooo`1Qoooo001U
oooo0P1VobSoool00`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`001?l0VC?o03?o0000
00/co`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Xco`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000oooooooo01Goool001Koool00`000?ooooooo`0j
oooo00<0003oooooool0>Oooo`030000<ol0<ol002Xco`000ol0VC?o03?o000<<ol000<0000co`0c
o`00=S?o00D0000Goooo002?oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol003dco`0800007?oo
o`00Soooo`030000<ol0<ol002Xco`000ol0VC?o03?o000g<ol01P0002Coool008ooool00`0003?o
03?o000Z<ol000?o09Tco`0co`00<S?o00D0000Zoooo002?oooo00<0000co`0co`00:S?o0003o`2I
<ol0<ol002dco`050000;oooo`00Soooo`80000[<ol000?o09Tco`0co`00:3?o00D0000doooo002?
oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol002@co`040000>Oooo`00Soooo`030000<ol0<ol0
02Xco`000ol0VC?o03?o000R<ol00P0003goool008ooool00`0003?o03?o000Z<ol000?o09Tco`0c
o`007c?o00<0000ooooo002?oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol001dco`020000@_oo
o`00Soooo`030000<ol0<ol002Xco`000ol0VC?o03?o000K<ol00P0004Coool008ooool20000:c?o
0003o`2I<ol0<ol001Tco`020000A_ooo`00Soooo`030000<ol0<ol002Xco`000ol0VC?o03?o000G
<ol00P0004Soool008ooool00`0003?o03?o000Z<ol000?o09Tco`0co`005S?o00030000oooooooo
04Soool008ooool00`0003?o03?o000Z<ol000?o09Tco`0co`0053?o0080001;oooo002?oooo00<0
000co`0co`00:S?o0003o`2I<ol0<ol0018co`020000COooo`00Soooo`030000<ol0<ol002Xco`00
0ol0VC?o03?o000A<ol000<0003oooooool0COooo`00Soooo`80000[<ol000?o09Tco`0co`003c?o
0080001@oooo002?oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol000dco`020000D_ooo`00Sooo
o`030000<ol0<ol002Xco`000ol0VC?o03?o000<<ol000<0003oooooool0D_ooo`00Soooo`030000
<ol0<ol002Xco`000ol0VC?o03?o000;<ol000<0003oooooool0Doooo`00Soooo`030000<ol0<ol0
02Xco`000ol0VC?o03?o0009<ol00P0005Koool008ooool00`0003?o03?o000Z<ol000?o09Tco`0c
o`0023?o00030000oooooooo05Koool008ooool20000:c?o0003o`2I<ol0<ol000Lco`000`000?oo
ooooo`1Goooo002?oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1H
oooo002?oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1Ioooo002?
oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1Joooo002?oooo00<0
000co`0co`00:S?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1Joooo0027oooo1@0000?oool0
0`0003?o03?o000Z<ol000?o09Tco`0co`000c?o00030000oooooooo05_oool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1Loooo0029
oooo00<0003oooooool00oooo`<0000Z<ol000Go09Tco`0co`0co`000000Goooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000Z<ol000Go09Tco`0co`0co`000000Goooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000Z<ol000Co09Tco`0co`00001Poooo0028oooo0P0000Goool0
0`0003?o03?o000Z<ol000?o09Tco`000000HOooo`00Soooo`030000<ol0<ol002Xco`000ol0V@00
0?ooo`1Qoooo002?oooo00<0000co`0co`00:S?o0003o`2I0000oooo067oool008ooool20000:c?o
0003o`2Ioooooooo067oool008ooool00`0003?o03?o000Y<ol000<0003o09Woool0H_ooo`00Sooo
o`030000<ol0<ol002Tco`000`000?l0VOooo`1Roooo002?oooo00<0000co`0co`00:3?o00030000
ooooo`2I06?oool008ooool00`0003?o03?o000W<ol000@0003ooooooooo09USoooo002?oooo00<0
000co`0co`009S?o00050000ooooooooooooo`2I06?oool008ooool200009c?o00050000oooooooo
ooooo`2I06?oool008ooool00`0003?o03?o000U<ol000<0003oooooool00_ooo`03o`2Ioooooooo
067oool008ooool00`0003?o03?o000T<ol000<0003oooooool00oooo`03o`2Ioooooooo067oool0
08ooool00`0003?o03?o000T<ol000<0003oooooool00oooo`03o`2Ioooooooo067oool008ooool0
0`0003?o03?o000S<ol000<0003oooooool01?ooo`03o`2Ioooooooo067oool008ooool00`0003?o
03?o000S<ol000<0003oooooool01?ooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000R
<ol000<0003oooooool01Oooo`03o`2Ioooooooo067oool008ooool200008c?o00030000oooooooo
00Goool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`008C?o00030000oooooooo00Koool0
0ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`008C?o00030000oooooooo00Koool00ol0VOoo
ooooo`1Qoooo002?oooo00<0000co`0co`0083?o00030000oooooooo00Ooool00ol0VOooooooo`1Q
oooo002?oooo00<0000co`0co`0083?o00030000oooooooo00Ooool00ol0VOooooooo`1Qoooo002?
oooo00<0000co`0co`0083?o00030000oooooooo00Ooool00ol0VOooooooo`1Qoooo002?oooo0P00
020co`000`000?ooooooo`08oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol001lco`00
0`000?ooooooo`08oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol001hco`000`000?oo
ooooo`09oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`09
oooo00?o09Woooooool0HOooo`00Qoooo`@00004oooo00<0000co`0co`007S?o00030000oooooooo
00Woool00ol0VOooooooo`1Qoooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol001dco`00
0`000?ooooooo`0:oooo00?o09Woooooool0HOooo`00R?ooo`030000oooooooo00Coool300007C?o
00030000oooooooo00[oool00ol0VOooooooo`1Qoooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001dco`000`000?ooooooo`0:oooo00?o09Woooooool0HOooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol001`co`000`000?ooooooo`0;oooo00?o09Woooooool0HOooo`00R?oo
o`800005oooo00<0000co`0co`0073?o00030000oooooooo00_oool00ol0VOooooooo`1Qoooo002?
oooo00<0000co`0co`006c?o00030000oooooooo00coool00ol0VOooooooo`1Qoooo002?oooo00<0
000co`0co`006c?o00030000oooooooo00coool00ol0VOooooooo`1Qoooo002?oooo0P0001`co`00
0`000?ooooooo`0<oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0=oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0=
oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0=oooo00?o
09Woooooool0HOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0=oooo00?o09Wooooo
ool0HOooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0>oooo00?o09Woooooool0HOoo
o`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0>oooo00?o09Woooooool0HOooo`00Sooo
o`80000J<ol000<0003oooooool03_ooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000H
<ol000<0003oooooool03oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000H<ol000<0
003oooooool03oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool03oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000G<ol000<0003oooooool04?oo
o`03o`2Ioooooooo067oool008ooool00`0003?o03?o000G<ol000<0003oooooool04?ooo`03o`2I
oooooooo067oool008ooool2000063?o00030000oooooooo013oool00ol0VOooooooo`1Qoooo002?
oooo00<0000co`0co`005c?o00030000oooooooo013oool00ol0VOooooooo`1Qoooo002?oooo00<0
000co`0co`005S?o00030000oooooooo017oool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0c
o`005S?o00030000oooooooo017oool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`005S?o
00030000oooooooo017oool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`005C?o00030000
oooooooo01;oool00ol0VOooooooo`1Qoooo002?oooo0P0001Hco`000`000?ooooooo`0Boooo00?o
09Woooooool0HOooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0Boooo00?o09Wooooo
ool0HOooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0Boooo00?o09Woooooool0HOoo
o`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`0Coooo00?o09Woooooool0HOooo`00R?oo
o`800005oooo00<0000co`0co`0053?o00030000oooooooo01?oool00ol0VOooooooo`1Qoooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`0053?o00030000oooooooo01?oool00ol0VOoo
ooooo`1Qoooo0029oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool05?ooo`03o`2I
oooooooo067oool008[oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo
01Coool00ol0VOooooooo`1Qoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`004c?o
00030000oooooooo01Coool00ol0VOooooooo`1Qoooo0028oooo0P0000Goool00`0003?o03?o000B
<ol000<0003oooooool05Oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000B<ol000<0
003oooooool05Oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool05Oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000B<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo067oool008ooool200004S?o00030000oooooooo01Koool00ol0VOooooooo`1Q
oooo002?oooo00<0000co`0co`004C?o00030000oooooooo01Koool00ol0VOooooooo`1Qoooo002?
oooo00<0000co`0co`004C?o00030000oooooooo01Koool00ol0VOooooooo`1Qoooo002?oooo00<0
000co`0co`004C?o00030000oooooooo01Koool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo01Ooool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`0043?o
00030000oooooooo01Ooool00ol0VOooooooo`1Qoooo002?oooo0P00014co`000`000?ooooooo`0G
oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Goooo00?o
09Woooooool0HOooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Hoooo00?o09Wooooo
ool0HOooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Hoooo00?o09Woooooool0HOoo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Hoooo00?o09Woooooool0HOooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0Hoooo00?o09Woooooool0HOooo`00Soooo`80000@
<ol000<0003oooooool06?ooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000><ol000<0
003oooooool06Oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000><ol000<0003ooooo
ool06Oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000><ol000<0003oooooool06Ooo
o`03o`2Ioooooooo067oool008ooool00`0003?o03?o000><ol000<0003oooooool06Oooo`03o`2I
oooooooo067oool008ooool00`0003?o03?o000><ol000<0003oooooool06Oooo`03o`2Ioooooooo
067oool008ooool200003S?o00030000oooooooo01[oool00ol0VOooooooo`1Qoooo002?oooo00<0
000co`0co`003C?o00030000oooooooo01[oool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0c
o`003C?o00030000oooooooo01[oool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`003C?o
00030000oooooooo01[oool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`0033?o00030000
oooooooo01_oool00ol0VOooooooo`1Qoooo0029oooo0`0000?oool00`0003?o03?o000<<ol000<0
003oooooool06oooo`03o`2Ioooooooo067oool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0033?o00030000oooooooo01_oool00ol0VOooooooo`1Qoooo0027oooo1@0000?oool3000033?o
00030000oooooooo01_oool00ol0VOooooooo`1Qoooo0027oooo00@0003oooooool00004oooo3c?o
08;oool008Soool00`000?ooo`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?
oooo3c?o08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2
000013?o00800004<ol00P00008co`03oooo00<0003oooooool00_ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Pco`001@0003?o03?o000003?o0003oooo00<0003oooooool00_ooo`030000
oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00002S?o00030000<ol0<ol000?oool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000<oooo00@0003oooooool0000;<ol000<0000co`3oool00oooo`050000
oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008
<ol000@0000co`0co`000002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200002S?o008000000c?o0?ooooooo`0400000_ooo`030000oooooooo
07Woool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.66906 .12361 L
.67373 .12361 L
.67803 .12361 L
.67928 .12361 L
.68044 .12361 L
s
.68044 .12361 m
.68093 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.31304 .12361 L
.31574 .12361 L
.31723 .12361 L
.31797 .12361 L
.31865 .12361 L
.31997 .12313 L
.3214 .12239 L
.32392 .12112 L
.34309 .11204 L
.38221 .09671 L
.4238 .08443 L
.46386 .07578 L
.50241 .06984 L
.54342 .06408 L
.5829 .05819 L
.62088 .05256 L
.64202 .04954 L
.6613 .04689 L
.67087 .04562 L
.67349 .04528 L
.67628 .04492 L
.67866 .04462 L
.67931 .04453 L
.68001 .04445 L
.68128 .12361 L
.68247 .12361 L
.68358 .12361 L
.68609 .12361 L
.69116 .12361 L
.70021 .12361 L
.73925 .12361 L
.78075 .12361 L
.82073 .12361 L
.8592 .12361 L
.90012 .12361 L
.93952 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Zoooo0P1V
of;oool008ooool00`000?ooooooo`0Toooo1P1Vo`03oooo06Kooooo067oool008ooool200006ooo
o`X0I_l7oooo00<0I_ooooooool0H?ooo`00Soooo`030000oooooooo01Goool506Ko4Oooo`0306Ko
oooooooo063oool008ooool00`000?ooooooo`0>oooo1`1VoaKoool00`1Vooooooooo`1Poooo002?
oooo00<0003oooooool01_ooo`P0I_lMoooo00<0I_ooooooool0H?ooo`00Soooo`040000oooooooo
oooo1@1VobGoool00`1Vooooooooo`1Poooo002<oooo0`1Vo`04000006Ko06Ko06Ko:_ooo`0306Ko
oooooooo063oool008Coool806Ko0oooo`80000/oooo00<0I_ooooooool0H?ooo`005oooo`D0000c
oooo0P0000Coool200001?ooo`80000Roooo1@1Vo`_oool00`000?ooooooo`0[oooo00<0I_oooooo
ool01?ooo`800004oooo0P0000Coool20000=?ooo`D0000Eoooo000Ioooo00<0003oooooool0<_oo
o`040000oooooooo00002?ooo`040000oooooooo00007Oooo`@0I_l@oooo00<0003oooooool0:ooo
o`0306Kooooooooo00?oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
01Soool306Ko5?ooo`030000oooooooo02_oool00`1Vooooooooo`03oooo00@0003oooooool0000;
oooo00<0003oooooool0<oooo`030000oooooooo01Goool0017oool400001?ooo`030000oooooooo
02coool400000_ooo`040000oooooooo00002Oooo`80000Ioooo0P1VoaOoool00`000?ooooooo`0[
oooo00<0I_ooooooool00oooo`040000oooooooo00002Oooo`80000foooo00<0003oooooool05Ooo
o`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?ooooooo`0Eoooo0`1V
oaWoool00`000?ooooooo`0[oooo00<0I_ooooooool00oooo`040000oooooooo00002Oooo`030000
oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_ooo`<0000Boooo0`1V
oacoool20000;?ooo`0306Kooooooooo00Coool200002_ooo`<0000doooo0P0001Ooool006goool3
06Ko7oooo`030000oooooooo02_oool00`1Vooooooooo`1Poooo001Yoooo101Vob;oool00`000?oo
ooooo`0[oooo00<0I_ooooooool0H?ooo`00Ioooo`80I_lVoooo00<0003oooooool0:oooo`0306Ko
oooooooo063oool006Goool206Ko:?ooo`030000oooooooo02_oool00`1Vooooooooo`1Poooo001S
oooo0P1Vob[oool00`000?ooooooo`0[oooo00<0I_ooooooool0H?ooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Lco`000ol0VC?o0000000;
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000[<ol000?o09Tco`0co`002c?o00030000<ol0<ol0
03Hco`0500005oooo`00Soooo`030000<ol0<ol002/co`000ol0VC?o03?o000l<ol0200001coool0
08ooool00`0003?o03?o000[<ol000?o09Tco`0co`00=S?o00H0000Toooo002?oooo00<0000co`0c
o`00:c?o0003o`2I<ol0<ol0034co`050000:_ooo`00Soooo`030000<ol0<ol002/co`000ol0VC?o
03?o000/<ol01@0002ooool008ooool20000;3?o0003o`2I<ol0<ol002Lco`050000=?ooo`00Sooo
o`030000<ol0<ol002/co`000ol0VC?o03?o000S<ol0100003Woool008ooool00`0003?o03?o000[
<ol000?o09Tco`0co`008C?o0080000moooo002?oooo00<0000co`0co`00:c?o0003o`2I<ol0<ol0
01hco`030000?oooo`00Soooo`030000<ol0<ol002/co`000ol0VC?o03?o000L<ol00P0004;oool0
08ooool00`0003?o03?o000[<ol000?o09Tco`0co`006S?o00800014oooo002?oooo0P0002`co`00
0ol0VC?o03?o000H<ol00P0004Koool008ooool00`0003?o03?o000[<ol000?o09Tco`0co`005S?o
00800018oooo002?oooo00<0000co`0co`00:c?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`18
oooo002?oooo00<0000co`0co`00:c?o0003o`2I<ol0<ol001<co`020000Boooo`00Soooo`030000
<ol0<ol002/co`000ol0VC?o03?o000A<ol00P0004goool008ooool00`0003?o03?o000[<ol000?o
09Tco`0co`0043?o00030000oooooooo04goool008ooool20000;3?o0003o`2I<ol0<ol000hco`02
0000D?ooo`00Soooo`030000<ol0<ol002/co`000ol0VC?o03?o000<<ol00P0005;oool008ooool0
0`0003?o03?o000[<ol000?o09Tco`0co`002c?o00030000oooooooo05;oool008ooool00`0003?o
03?o000[<ol000?o09Tco`0co`002S?o00030000oooooooo05?oool008ooool00`0003?o03?o000[
<ol000?o09Tco`0co`0023?o0080001Foooo002?oooo00<0000co`0co`00:c?o0003o`2I<ol0<ol0
00Lco`000`000?ooooooo`1Foooo002?oooo0P0002`co`000ol0VC?o03?o0006<ol000<0003ooooo
ool0Eoooo`00Soooo`030000<ol0<ol002/co`000ol0VC?o03?o0005<ol000<0003oooooool0F?oo
o`00Soooo`030000<ol0<ol002/co`000ol0VC?o03?o0004<ol000<0003oooooool0FOooo`00Sooo
o`030000<ol0<ol002/co`000ol0VC?o03?o0003<ol000<0003oooooool0F_ooo`00Soooo`030000
<ol0<ol002/co`000ol0VC?o03?o0003<ol000<0003oooooool0F_ooo`00Qoooo`D00003oooo00<0
000co`0co`00:c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1Koooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol002/co`001Ol0VC?o03?o03?o0000001Noooo0029oooo00<0003ooooo
ool00oooo`<0000[<ol000Co09Tco`0co`00001Ooooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol002/co`001?l0VC?o03?o000005ooool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`00:c?o0003o`2I<ol00000063oool008Soool200001Oooo`030000<ol0<ol002/co`000ol0V@00
0?ooo`1Poooo002?oooo00<0000co`0co`00:c?o0003o`2Ioooooooo063oool008ooool00`0003?o
03?o000[<ol000?o09Woooooool0H?ooo`00Soooo`80000[<ol000<0003o09Woool0HOooo`00Sooo
o`030000<ol0<ol002Tco`000`000?ooool0V@1Roooo002?oooo00<0000co`0co`00:C?o00030000
ooooo`2I06;oool008ooool00`0003?o03?o000X<ol000@0003ooooooooo09URoooo002?oooo00<0
000co`0co`009c?o00050000ooooooooooooo`2I06;oool008ooool00`0003?o03?o000V<ol000<0
003oooooool00_ooo`03o`2Ioooooooo063oool008ooool200009c?o00030000oooooooo00;oool0
0ol0VOooooooo`1Poooo002?oooo00<0000co`0co`009C?o00030000oooooooo00?oool00ol0VOoo
ooooo`1Poooo002?oooo00<0000co`0co`0093?o00030000oooooooo00Coool00ol0VOooooooo`1P
oooo002?oooo00<0000co`0co`0093?o00030000oooooooo00Coool00ol0VOooooooo`1Poooo002?
oooo00<0000co`0co`008c?o00030000oooooooo00Goool00ol0VOooooooo`1Poooo002?oooo00<0
000co`0co`008c?o00030000oooooooo00Goool00ol0VOooooooo`1Poooo002?oooo00<0000co`0c
o`008S?o00030000oooooooo00Koool00ol0VOooooooo`1Poooo002?oooo0P0002<co`000`000?oo
ooooo`06oooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0024co`000`000?ooooooo`07
oooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0024co`000`000?ooooooo`07oooo00?o
09Woooooool0H?ooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`08oooo00?o09Wooooo
ool0H?ooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`08oooo00?o09Woooooool0H?oo
o`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`08oooo00?o09Woooooool0H?ooo`00Sooo
o`80000P<ol000<0003oooooool02Oooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000O
<ol000<0003oooooool02Oooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000N<ol000<0
003oooooool02_ooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000N<ol000<0003ooooo
ool02_ooo`03o`2Ioooooooo063oool008Ooool400001?ooo`030000<ol0<ol001hco`000`000?oo
ooooo`0:oooo00?o09Woooooool0H?ooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000M
<ol000<0003oooooool02oooo`03o`2Ioooooooo063oool008Soool00`000?ooooooo`04oooo0`00
01dco`000`000?ooooooo`0;oooo00?o09Woooooool0H?ooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000M<ol000<0003oooooool02oooo`03o`2Ioooooooo063oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o000L<ol000<0003oooooool03?ooo`03o`2Ioooooooo063oool0
08Soool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`0<oooo00?o09Woooooool0H?oo
o`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0=oooo00?o09Woooooool0H?ooo`00Sooo
o`030000<ol0<ol001/co`000`000?ooooooo`0=oooo00?o09Woooooool0H?ooo`00Soooo`80000L
<ol000<0003oooooool03Oooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000J<ol000<0
003oooooool03_ooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000J<ol000<0003ooooo
ool03_ooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000J<ol000<0003oooooool03_oo
o`03o`2Ioooooooo063oool008ooool00`0003?o03?o000J<ol000<0003oooooool03_ooo`03o`2I
oooooooo063oool008ooool00`0003?o03?o000I<ol000<0003oooooool03oooo`03o`2Ioooooooo
063oool008ooool00`0003?o03?o000I<ol000<0003oooooool03oooo`03o`2Ioooooooo063oool0
08ooool200006S?o00030000oooooooo00ooool00ol0VOooooooo`1Poooo002?oooo00<0000co`0c
o`0063?o00030000oooooooo013oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`0063?o
00030000oooooooo013oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`0063?o00030000
oooooooo013oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`005c?o00030000oooooooo
017oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`005c?o00030000oooooooo017oool0
0ol0VOooooooo`1Poooo002?oooo0P0001Pco`000`000?ooooooo`0Aoooo00?o09Woooooool0H?oo
o`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Aoooo00?o09Woooooool0H?ooo`00Sooo
o`030000<ol0<ol001Hco`000`000?ooooooo`0Boooo00?o09Woooooool0H?ooo`00Soooo`030000
<ol0<ol001Hco`000`000?ooooooo`0Boooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0
01Hco`000`000?ooooooo`0Boooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol001Dco`00
0`000?ooooooo`0Coooo00?o09Woooooool0H?ooo`00Soooo`80000F<ol000<0003oooooool04ooo
o`03o`2Ioooooooo063oool008ooool00`0003?o03?o000E<ol000<0003oooooool04oooo`03o`2I
oooooooo063oool008ooool00`0003?o03?o000E<ol000<0003oooooool04oooo`03o`2Ioooooooo
063oool008ooool00`0003?o03?o000D<ol000<0003oooooool05?ooo`03o`2Ioooooooo063oool0
08Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`0Doooo00?o09Woooooool0H?oo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001@co`000`000?ooooooo`0Doooo00?o
09Woooooool0H?ooo`00ROooo`030000oooooooo00?oool300004c?o00030000oooooooo01Goool0
0ol0VOooooooo`1Poooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol001<co`000`000?oo
ooooo`0Eoooo00?o09Woooooool0H?ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
01<co`000`000?ooooooo`0Eoooo00?o09Woooooool0H?ooo`00R?ooo`800005oooo00<0000co`0c
o`004S?o00030000oooooooo01Koool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`004S?o
00030000oooooooo01Koool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`004S?o00030000
oooooooo01Koool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`004S?o00030000oooooooo
01Koool00ol0VOooooooo`1Poooo002?oooo0P00018co`000`000?ooooooo`0Goooo00?o09Wooooo
ool0H?ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Goooo00?o09Woooooool0H?oo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Goooo00?o09Woooooool0H?ooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`0Goooo00?o09Woooooool0H?ooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0Hoooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0Hoooo00?o09Woooooool0H?ooo`00Soooo`80000A<ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000@<ol000<0003oooooool06?oo
o`03o`2Ioooooooo063oool008ooool00`0003?o03?o000?<ol000<0003oooooool06Oooo`03o`2I
oooooooo063oool008ooool00`0003?o03?o000?<ol000<0003oooooool06Oooo`03o`2Ioooooooo
063oool008ooool00`0003?o03?o000?<ol000<0003oooooool06Oooo`03o`2Ioooooooo063oool0
08ooool00`0003?o03?o000?<ol000<0003oooooool06Oooo`03o`2Ioooooooo063oool008ooool2
000043?o00030000oooooooo01Woool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`003S?o
00030000oooooooo01[oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`003S?o00030000
oooooooo01[oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`003S?o00030000oooooooo
01[oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`003S?o00030000oooooooo01[oool0
0ol0VOooooooo`1Poooo002?oooo00<0000co`0co`003S?o00030000oooooooo01[oool00ol0VOoo
ooooo`1Poooo002?oooo0P0000hco`000`000?ooooooo`0Koooo00?o09Woooooool0H?ooo`00Sooo
o`030000<ol0<ol000dco`000`000?ooooooo`0Koooo00?o09Woooooool0H?ooo`00Soooo`030000
<ol0<ol000dco`000`000?ooooooo`0Koooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`0Koooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`0Loooo00?o09Woooooool0H?ooo`00ROooo`<00003oooo00<0000co`0co`0033?o
00030000oooooooo01coool00ol0VOooooooo`1Poooo002:oooo00<0003oooooool00_ooo`030000
<ol0<ol000`co`000`000?ooooooo`0Loooo00?o09Woooooool0H?ooo`00Qoooo`D00003oooo0`00
00`co`000`000?ooooooo`0Loooo00?o09Woooooool0H?ooo`00Qoooo`040000oooooooo00001?oo
o`lco`22oooo0028oooo00<0003oool000001?ooo`lco`22oooo0029oooo0P0000Coool?<ol0P_oo
o`00Soooo`lco`22oooo002?oooo3c?o08;oool007Woool00`000?ooooooo`0Coooo3S?o00Ooool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo00Woool><ol02?oo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000@co`02000013?o00800002<ol00_ooo`800004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000
oooooooo000023?o00070000<ol0<ol00000<ol0oooo000000;oool01@000?ooooooooooo`00001j
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Xco`00
1@0003?o03?o0?ooo`000002oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002c?o00040000<ol0oooooooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo000023?o
00040000<ol0<ol000000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000Xco`02000000@co`3oooooooooool200000oooo`030000oooooooo
07Woool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.39) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.66906 .12361 L
.67803 .12361 L
.68044 .12361 L
.683 .12361 L
.68433 .12361 L
.68509 .12361 L
s
.68509 .12361 m
.68537 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.30791 .12361 L
.31054 .12361 L
.31183 .12361 L
.31304 .12361 L
.31371 .12361 L
.31444 .12353 L
.31524 .12311 L
.31597 .12274 L
.31865 .12137 L
.32392 .11876 L
.34309 .10995 L
.38315 .0948 L
.4217 .08377 L
.46271 .07513 L
.50219 .06928 L
.54016 .06415 L
.58059 .05828 L
.6195 .0526 L
.63931 .04979 L
.66086 .04685 L
.67089 .04553 L
.67639 .04482 L
.67909 .04448 L
.68156 .04417 L
.68369 .0439 L
.68476 .04376 L
.68594 .12361 L
.68712 .12361 L
.68838 .12361 L
.69066 .12361 L
.7007 .12361 L
.7422 .12361 L
.78218 .12361 L
.82065 .12361 L
.86157 .12361 L
.90097 .12361 L
.93886 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.39) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Zoooo0`1V
of7oool008ooool00`000?ooooooo`0Toooo1P1Vo`;oool00`1Vooooooooo`1Ooooo002?oooo0P00
01[oool;06Ko2?ooo`0306Kooooooooo05ooool008ooool00`000?ooooooo`0Doooo1@1Voa?oool0
0`1Vooooooooo`1Ooooo002?oooo00<0003oooooool03Oooo`L0I_lHoooo00<0I_ooooooool0Gooo
o`00Soooo`030000oooooooo00Goool806Ko7oooo`0306Kooooooooo05ooool008ooool010000?oo
ooooooooo`@0I_lWoooo00<0I_ooooooool0Goooo`00S?ooo`<0I_l01000001Vo`1Vo`1Vob_oool0
0`1Vooooooooo`1Ooooo0024oooo201Vo`?oool20000;Oooo`0306Kooooooooo05ooool001Ooool5
0000<oooo`800004oooo0P0000Coool200008Oooo`H0I_l;oooo00<0003oooooool0;?ooo`0306Ko
oooooooo00?oool200001?ooo`800004oooo0P0003Coool500005Oooo`006Oooo`030000oooooooo
03;oool010000?ooooooo`0000Soool010000?ooooooo`0001coool406Ko4Oooo`030000oooooooo
02coool00`1Vooooooooo`02oooo00@0003oooooool00008oooo00@0003oooooool0000eoooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000_oool00`000?oo
ooooo`0Goooo0`1VoaGoool00`000?ooooooo`0/oooo00<0I_ooooooool00_ooo`040000oooooooo
00002oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?oo
ooooo`0/oooo100000;oool010000?ooooooo`0000Woool200005_ooo`@0I_lHoooo00<0003ooooo
ool0;?ooo`0306Kooooooooo00;oool010000?ooooooo`0000Woool20000=_ooo`030000oooooooo
01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00009oooo00<0003oooooool04_oo
o`<0I_lLoooo00<0003oooooool0;?ooo`0306Kooooooooo00;oool010000?ooooooo`0000Woool0
0`000?ooooooo`0eoooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P0000[oool300004?oo
o`80I_lOoooo0P0002goool00`1Vooooooooo`03oooo0P0000[oool30000=?ooo`80000Goooo001[
oooo0`1Vob7oool00`000?ooooooo`0/oooo00<0I_ooooooool0Goooo`00JOooo`80I_lToooo00<0
003oooooool0;?ooo`0306Kooooooooo05ooool006Koool306Ko9_ooo`030000oooooooo02coool0
0`1Vooooooooo`1Ooooo001Toooo0P1VobWoool00`000?ooooooo`0/oooo00<0I_ooooooool0Gooo
o`00H_ooo`80I_l[oooo00<0003oooooool0;?ooo`0306Kooooooooo05ooool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0008<ol000?o09T0000c
o`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002S?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0ioooo00<0000co`0co`00;3?o0003o`2I<ol0<ol000Xco`000`0003?o
03?o000f<ol01@0001Ooool008ooool00`0003?o03?o000/<ol000?o09Tco`0co`00>c?o00P0000L
oooo002?oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol003Dco`0600009?ooo`00Soooo`030000
<ol0<ol002`co`000ol0VC?o03?o000`<ol01@0002[oool008ooool00`0003?o03?o000/<ol000?o
09Tco`0co`00:c?o00D0000_oooo002?oooo0P0002dco`000ol0VC?o03?o000V<ol01@0003Coool0
08ooool00`0003?o03?o000/<ol000?o09Tco`0co`008S?o00@0000ioooo002?oooo00<0000co`0c
o`00;3?o0003o`2I<ol0<ol0020co`020000?Oooo`00Soooo`030000<ol0<ol002`co`000ol0VC?o
03?o000M<ol00`0003ooool008ooool00`0003?o03?o000/<ol000?o09Tco`0co`006c?o00800012
oooo002?oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol001Tco`020000A?ooo`00Soooo`80000]
<ol000?o09Tco`0co`005c?o00800016oooo002?oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol0
01Dco`020000B?ooo`00Soooo`030000<ol0<ol002`co`000ol0VC?o03?o000D<ol000<0003ooooo
ool0B?ooo`00Soooo`030000<ol0<ol002`co`000ol0VC?o03?o000B<ol00P0004_oool008ooool0
0`0003?o03?o000/<ol000?o09Tco`0co`0043?o0080001=oooo002?oooo00<0000co`0co`00;3?o
0003o`2I<ol0<ol000lco`000`000?ooooooo`1=oooo002?oooo0P0002dco`000ol0VC?o03?o000=
<ol00P00053oool008ooool00`0003?o03?o000/<ol000?o09Tco`0co`002c?o0080001Boooo002?
oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1Boooo002?oooo00<0
000co`0co`00;3?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1Coooo002?oooo00<0000co`0c
o`00;3?o0003o`2I<ol0<ol000Lco`020000E_ooo`00Soooo`030000<ol0<ol002`co`000ol0VC?o
03?o0006<ol000<0003oooooool0E_ooo`00Soooo`80000]<ol000?o09Tco`0co`001C?o00030000
oooooooo05Ooool008ooool00`0003?o03?o000/<ol000?o09Tco`0co`0013?o00030000oooooooo
05Soool008ooool00`0003?o03?o000/<ol000?o09Tco`0co`000c?o00030000oooooooo05Woool0
08ooool00`0003?o03?o000/<ol000?o09Tco`0co`000S?o00030000oooooooo05[oool008ooool0
0`0003?o03?o000/<ol000?o09Tco`0co`000S?o00030000oooooooo05[oool008Ooool500000ooo
o`030000<ol0<ol002`co`001Ol0VC?o03?o03?o0000001Moooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol002`co`001?l0VC?o03?o000005koool008Woool00`000?ooooooo`03oooo0`00
02`co`000ol0VC?o0000001Ooooo0029oooo00<0003oooooool00oooo`030000<ol0<ol002`co`00
0ol0VC?o0000001Ooooo0029oooo00<0003oooooool00oooo`030000<ol0<ol002`co`000ol0V@00
0?ooo`1Ooooo0028oooo0P0000Goool00`0003?o03?o000/<ol000?o09Woooooool0Goooo`00Sooo
o`030000<ol0<ol002/co`000`000?l0VOooo`1Poooo002?oooo00<0000co`0co`00:c?o00030000
o`2Ioooo063oool008ooool20000:c?o00030000ooooo`2I067oool008ooool00`0003?o03?o000Y
<ol000@0003ooooooooo09UQoooo002?oooo00<0000co`0co`00:C?o00040000ooooooooo`2IHOoo
o`00Soooo`030000<ol0<ol002Pco`001@000?ooooooooooool0V@1Qoooo002?oooo00<0000co`0c
o`009c?o00030000oooooooo00;oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`009S?o
00030000oooooooo00?oool00ol0VOooooooo`1Ooooo002?oooo0P0002Lco`000`000?ooooooo`03
oooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`04oooo00?o
09Woooooool0Goooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`05oooo00?o09Wooooo
ool0Goooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`05oooo00?o09Woooooool0Gooo
o`00Soooo`030000<ol0<ol002<co`000`000?ooooooo`06oooo00?o09Woooooool0Goooo`00Sooo
o`030000<ol0<ol002<co`000`000?ooooooo`06oooo00?o09Woooooool0Goooo`00Soooo`030000
<ol0<ol0028co`000`000?ooooooo`07oooo00?o09Woooooool0Goooo`00Soooo`80000S<ol000<0
003oooooool01oooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000Q<ol000<0003ooooo
ool02?ooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000Q<ol000<0003oooooool02?oo
o`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000P<ol000<0003oooooool02Oooo`03o`2I
oooooooo05ooool008ooool00`0003?o03?o000P<ol000<0003oooooool02Oooo`03o`2Ioooooooo
05ooool008ooool00`0003?o03?o000P<ol000<0003oooooool02Oooo`03o`2Ioooooooo05ooool0
08ooool2000083?o00030000oooooooo00[oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0c
o`007c?o00030000oooooooo00[oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`007S?o
00030000oooooooo00_oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`007S?o00030000
oooooooo00_oool00ol0VOooooooo`1Ooooo0027oooo100000Coool00`0003?o03?o000N<ol000<0
003oooooool02oooo`03o`2Ioooooooo05ooool008Ooool00`000?ooooooo`05oooo00<0000co`0c
o`007C?o00030000oooooooo00coool00ol0VOooooooo`1Ooooo0028oooo00<0003oooooool01?oo
o`<0000M<ol000<0003oooooool03?ooo`03o`2Ioooooooo05ooool008Woool00`000?ooooooo`03
oooo00<0000co`0co`007C?o00030000oooooooo00coool00ol0VOooooooo`1Ooooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0073?o00030000oooooooo00goool00ol0VOooooooo`1O
oooo0028oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool03Oooo`03o`2Ioooooooo
05ooool008ooool00`0003?o03?o000K<ol000<0003oooooool03_ooo`03o`2Ioooooooo05ooool0
08ooool00`0003?o03?o000K<ol000<0003oooooool03_ooo`03o`2Ioooooooo05ooool008ooool2
000073?o00030000oooooooo00koool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`006S?o
00030000oooooooo00ooool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`006S?o00030000
oooooooo00ooool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`006S?o00030000oooooooo
00ooool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`006S?o00030000oooooooo00ooool0
0ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`006C?o00030000oooooooo013oool00ol0VOoo
ooooo`1Ooooo002?oooo00<0000co`0co`006C?o00030000oooooooo013oool00ol0VOooooooo`1O
oooo002?oooo0P0001Xco`000`000?ooooooo`0@oooo00?o09Woooooool0Goooo`00Soooo`030000
<ol0<ol001Pco`000`000?ooooooo`0Aoooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0
01Pco`000`000?ooooooo`0Aoooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol001Pco`00
0`000?ooooooo`0Aoooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol001Lco`000`000?oo
ooooo`0Boooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0B
oooo00?o09Woooooool0Goooo`00Soooo`80000H<ol000<0003oooooool04_ooo`03o`2Ioooooooo
05ooool008ooool00`0003?o03?o000G<ol000<0003oooooool04_ooo`03o`2Ioooooooo05ooool0
08ooool00`0003?o03?o000F<ol000<0003oooooool04oooo`03o`2Ioooooooo05ooool008ooool0
0`0003?o03?o000F<ol000<0003oooooool04oooo`03o`2Ioooooooo05ooool008ooool00`0003?o
03?o000F<ol000<0003oooooool04oooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000E
<ol000<0003oooooool05?ooo`03o`2Ioooooooo05ooool008ooool200005S?o00030000oooooooo
01Coool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`005C?o00030000oooooooo01Coool0
0ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`005C?o00030000oooooooo01Coool00ol0VOoo
ooooo`1Ooooo002?oooo00<0000co`0co`0053?o00030000oooooooo01Goool00ol0VOooooooo`1O
oooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool05Oooo`03o`2Ioooooooo
05ooool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000D<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo05ooool008Woool00`000?ooooooo`03oooo0`0001<co`000`000?ooooooo`0F
oooo00?o09Woooooool0Goooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000C<ol000<0
003oooooool05_ooo`03o`2Ioooooooo05ooool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o000C<ol000<0003oooooool05_ooo`03o`2Ioooooooo05ooool008Soool200001Oooo`030000
<ol0<ol0018co`000`000?ooooooo`0Goooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0
018co`000`000?ooooooo`0Goooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`0Goooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`0Goooo00?o09Woooooool0Goooo`00Soooo`80000B<ol000<0003oooooool06?ooo`03o`2I
oooooooo05ooool008ooool00`0003?o03?o000A<ol000<0003oooooool06?ooo`03o`2Ioooooooo
05ooool008ooool00`0003?o03?o000A<ol000<0003oooooool06?ooo`03o`2Ioooooooo05ooool0
08ooool00`0003?o03?o000A<ol000<0003oooooool06?ooo`03o`2Ioooooooo05ooool008ooool0
0`0003?o03?o000@<ol000<0003oooooool06Oooo`03o`2Ioooooooo05ooool008ooool00`0003?o
03?o000@<ol000<0003oooooool06Oooo`03o`2Ioooooooo05ooool008ooool200004C?o00030000
oooooooo01Woool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`0043?o00030000oooooooo
01Woool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`003c?o00030000oooooooo01[oool0
0ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`003c?o00030000oooooooo01[oool00ol0VOoo
ooooo`1Ooooo002?oooo00<0000co`0co`003c?o00030000oooooooo01[oool00ol0VOooooooo`1O
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo01[oool00ol0VOooooooo`1Ooooo002?
oooo0P00010co`000`000?ooooooo`0Joooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0Koooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`0Koooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`0Koooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0K
oooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Koooo00?o
09Woooooool0Goooo`00Soooo`80000><ol000<0003oooooool07?ooo`03o`2Ioooooooo05ooool0
08ooool00`0003?o03?o000=<ol000<0003oooooool07?ooo`03o`2Ioooooooo05ooool008ooool0
0`0003?o03?o000=<ol000<0003oooooool07?ooo`03o`2Ioooooooo05ooool008ooool00`0003?o
03?o000=<ol000<0003oooooool07?ooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000<
<ol000<0003oooooool07Oooo`03o`2Ioooooooo05ooool008Woool300000oooo`030000<ol0<ol0
00`co`000`000?ooooooo`0Moooo00?o09Woooooool0Goooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o000<<ol000<0003oooooool07Oooo`03o`2Ioooooooo05ooool008Ooool500000ooo
o`<0000<<ol000<0003oooooool07Oooo`03o`2Ioooooooo05ooool008Ooool010000?ooooooo`00
00Coool?<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o
08;oool008ooool?<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o
00Soool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004<ol00P0000@co`0200000S?o0004oooo0000000000001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000Pco`001@0003?o03?o000003?o0003oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002S?o00030000<ol0<ol000;oool300001?ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002c?o00040000<ol0oooo00000_ooo`050000
oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00008
<ol000@0000co`0co`000002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200002S?o0080000013?o0?ooooooooooo`<00002oooo00<0003ooooo
ool0NOooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.67803 .12361 L
.68335 .12361 L
.68596 .12361 L
.68711 .12361 L
.68837 .12361 L
.6895 .12361 L
s
.6895 .12361 m
.68992 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30316 .12361 L
.3056 .12361 L
.30791 .12361 L
.30919 .12361 L
.30992 .1234 L
.31059 .12306 L
.31304 .1218 L
.32392 .11647 L
.34309 .10793 L
.38221 .09356 L
.4238 .08212 L
.46386 .07412 L
.50241 .06869 L
.54342 .06333 L
.5829 .05771 L
.62088 .05227 L
.64202 .04931 L
.6613 .04671 L
.67087 .04546 L
.67592 .04481 L
.68128 .04413 L
.68595 .04355 L
.68724 .04339 L
.68862 .04322 L
.68992 .04307 L
.69111 .12361 L
.69221 .12361 L
.69323 .12361 L
.69554 .12361 L
.70021 .12361 L
.73925 .12361 L
.78075 .12361 L
.82073 .12361 L
.8592 .12361 L
.90012 .12361 L
.93952 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Zoooo101V
of3oool008ooool00`000?ooooooo`0Toooo1P1Vo`?oool00`1Vooooooooo`1Noooo002?oooo0P00
01_oool:06Ko2Oooo`0306Kooooooooo05koool008ooool00`000?ooooooo`0Eoooo1@1Voa?oool0
0`1Vooooooooo`1Noooo002?oooo00<0003oooooool03_ooo`L0I_lHoooo00<0I_ooooooool0G_oo
o`00Soooo`030000oooooooo00Coool:06Ko7oooo`0306Kooooooooo05koool008koool00`1Vo`00
001Vo`0506Ko:Oooo`0306Kooooooooo05koool008Woool506Ko00?oool0003oool0;_ooo`0306Ko
oooooooo05koool008Coool506Ko1_ooo`80000^oooo00<0I_ooooooool0G_ooo`005oooo`D0000c
oooo0P0000Coool200001?ooo`80000Roooo1@1Vo`_oool00`000?ooooooo`0]oooo00<0I_oooooo
ool00_ooo`800004oooo0P0000Coool20000=?ooo`D0000Eoooo000Ioooo00<0003oooooool0<_oo
o`040000oooooooo00002?ooo`040000oooooooo00007Oooo`@0I_l@oooo00<0003oooooool0;Ooo
o`0506Kooooooooooooo000000;oool00`000?ooooooo`06oooo00@0003oooooool0000eoooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000_oool00`000?oo
ooooo`0Goooo101VoaCoool00`000?ooooooo`0]oooo00D0I_ooooooooooool000000_ooo`030000
oooooooo00Woool00`000?ooooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0
003oooooool0;?ooo`@00002oooo00@0003oooooool00009oooo0P0001Koool406Ko6?ooo`030000
oooooooo02goool01@1Vooooooooooooo`000002oooo00<0003oooooool01oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0Boooo0`1Voacoool00`000?ooooooo`0]oooo00D0I_ooooooooooool000000_ooo`030000
oooooooo00Ooool00`000?ooooooo`0eoooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P00
00[oool300003oooo`<0I_lOoooo0P0002koool00`1Vooooooooo`02oooo0P0000[oool30000=?oo
o`80000Goooo001Yoooo101Vob;oool00`000?ooooooo`0]oooo00<0I_ooooooool0G_ooo`00Iooo
o`80I_lVoooo00<0003oooooool0;Oooo`0306Kooooooooo05koool006Goool206Ko:?ooo`030000
oooooooo02goool00`1Vooooooooo`1Noooo001Soooo0P1Vob[oool00`000?ooooooo`0]oooo00<0
I_ooooooool0G_ooo`00H_ooo`0306Kooooooooo02[oool00`000?ooooooo`0]oooo00<0I_oooooo
ool0G_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000]<ol000?o
09Tco`0co`002C?o00030000<ol0<ol003Hco`0500005oooo`00Soooo`030000<ol0<ol002dco`00
0ol0VC?o03?o000j<ol0200001coool008ooool00`0003?o03?o000]<ol000?o09Tco`0co`00=3?o
00H0000Toooo002?oooo00<0000co`0co`00;C?o0003o`2I<ol0<ol002lco`050000:_ooo`00Sooo
o`030000<ol0<ol002dco`000ol0VC?o03?o000Z<ol01@0002ooool008ooool20000;S?o0003o`2I
<ol0<ol002Dco`050000=?ooo`00Soooo`030000<ol0<ol002dco`000ol0VC?o03?o000Q<ol01000
03Woool008ooool00`0003?o03?o000]<ol000?o09Tco`0co`007c?o0080000moooo002?oooo00<0
000co`0co`00;C?o0003o`2I<ol0<ol001`co`030000?oooo`00Soooo`030000<ol0<ol002dco`00
0ol0VC?o03?o000J<ol00P0004;oool008ooool00`0003?o03?o000]<ol000?o09Tco`0co`0063?o
00800014oooo002?oooo0P0002hco`000ol0VC?o03?o000F<ol00P0004Koool008ooool00`0003?o
03?o000]<ol000?o09Tco`0co`0053?o00800018oooo002?oooo00<0000co`0co`00;C?o0003o`2I
<ol0<ol001<co`000`000?ooooooo`18oooo002?oooo00<0000co`0co`00;C?o0003o`2I<ol0<ol0
014co`020000Boooo`00Soooo`030000<ol0<ol002dco`000ol0VC?o03?o000?<ol00P0004goool0
08ooool00`0003?o03?o000]<ol000?o09Tco`0co`003S?o00030000oooooooo04goool008ooool2
0000;S?o0003o`2I<ol0<ol000`co`020000D?ooo`00Soooo`030000<ol0<ol002dco`000ol0VC?o
03?o000:<ol00P0005;oool008ooool00`0003?o03?o000]<ol000?o09Tco`0co`002C?o00030000
oooooooo05;oool008ooool00`0003?o03?o000]<ol000?o09Tco`0co`0023?o00030000oooooooo
05?oool008ooool00`0003?o03?o000]<ol000?o09Tco`0co`001S?o0080001Foooo002?oooo00<0
000co`0co`00;C?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1Foooo002?oooo0P0002hco`00
0ol0VC?o03?o0004<ol000<0003oooooool0Eoooo`00Soooo`030000<ol0<ol002dco`000ol0VC?o
03?o0003<ol000<0003oooooool0F?ooo`00Soooo`030000<ol0<ol002dco`000ol0VC?o03?o0002
<ol000<0003oooooool0FOooo`00Soooo`030000<ol0<ol002dco`001Ol0VC?o03?o03?o0000001L
oooo002?oooo00<0000co`0co`00;C?o0005o`2I<ol0<ol0<ol0000005coool008Ooool500000ooo
o`030000<ol0<ol002dco`001?l0VC?o03?o000005goool008Woool00`000?ooooooo`03oooo00<0
000co`0co`00;C?o0003o`2I<ol0000005koool008Woool00`000?ooooooo`03oooo0`0002dco`00
0ol0V@000?ooo`1Noooo0029oooo00<0003oooooool00oooo`030000<ol0<ol002dco`000ol0V@00
0?ooo`1Noooo0029oooo00<0003oooooool00oooo`030000<ol0<ol002dco`000ol0VOooooooo`1N
oooo0028oooo0P0000Goool00`0003?o03?o000/<ol000<0003o09Woool0Goooo`00Soooo`030000
<ol0<ol002/co`000`000?ooool0V@1Poooo002?oooo00<0000co`0co`00:c?o00030000ooooo`2I
063oool008ooool20000:c?o00040000ooooooooo`2IH?ooo`00Soooo`030000<ol0<ol002Tco`00
1@000?ooooooooooool0V@1Poooo002?oooo00<0000co`0co`00:C?o00050000ooooooooooooo`2I
063oool008ooool00`0003?o03?o000X<ol000<0003oooooool00_ooo`03o`2Ioooooooo05koool0
08ooool00`0003?o03?o000W<ol000<0003oooooool00oooo`03o`2Ioooooooo05koool008ooool0
0`0003?o03?o000V<ol000<0003oooooool01?ooo`03o`2Ioooooooo05koool008ooool200009c?o
00030000oooooooo00Coool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`009C?o00030000
oooooooo00Goool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`0093?o00030000oooooooo
00Koool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`0093?o00030000oooooooo00Koool0
0ol0VOooooooo`1Noooo002?oooo00<0000co`0co`008c?o00030000oooooooo00Ooool00ol0VOoo
ooooo`1Noooo002?oooo00<0000co`0co`008c?o00030000oooooooo00Ooool00ol0VOooooooo`1N
oooo002?oooo00<0000co`0co`008S?o00030000oooooooo00Soool00ol0VOooooooo`1Noooo002?
oooo0P0002<co`000`000?ooooooo`08oooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0
024co`000`000?ooooooo`09oooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0024co`00
0`000?ooooooo`09oooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0020co`000`000?oo
ooooo`0:oooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`0:
oooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`0:oooo00?o
09Woooooool0G_ooo`00Soooo`80000P<ol000<0003oooooool02oooo`03o`2Ioooooooo05koool0
08ooool00`0003?o03?o000O<ol000<0003oooooool02oooo`03o`2Ioooooooo05koool008ooool0
0`0003?o03?o000N<ol000<0003oooooool03?ooo`03o`2Ioooooooo05koool008ooool00`0003?o
03?o000N<ol000<0003oooooool03?ooo`03o`2Ioooooooo05koool008Ooool400001?ooo`030000
<ol0<ol001hco`000`000?ooooooo`0<oooo00?o09Woooooool0G_ooo`00Qoooo`030000oooooooo
00Goool00`0003?o03?o000M<ol000<0003oooooool03Oooo`03o`2Ioooooooo05koool008Soool0
0`000?ooooooo`04oooo0`0001dco`000`000?ooooooo`0=oooo00?o09Woooooool0G_ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool03Oooo`03o`2Ioooooooo
05koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000L<ol000<0003oooooool03_oo
o`03o`2Ioooooooo05koool008Soool200001Oooo`030000<ol0<ol001`co`000`000?ooooooo`0>
oooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0?oooo00?o
09Woooooool0G_ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0?oooo00?o09Wooooo
ool0G_ooo`00Soooo`80000L<ol000<0003oooooool03oooo`03o`2Ioooooooo05koool008ooool0
0`0003?o03?o000J<ol000<0003oooooool04?ooo`03o`2Ioooooooo05koool008ooool00`0003?o
03?o000J<ol000<0003oooooool04?ooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000J
<ol000<0003oooooool04?ooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000J<ol000<0
003oooooool04?ooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000I<ol000<0003ooooo
ool04Oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000I<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo05koool008ooool200006S?o00030000oooooooo017oool00ol0VOooooooo`1N
oooo002?oooo00<0000co`0co`0063?o00030000oooooooo01;oool00ol0VOooooooo`1Noooo002?
oooo00<0000co`0co`0063?o00030000oooooooo01;oool00ol0VOooooooo`1Noooo002?oooo00<0
000co`0co`0063?o00030000oooooooo01;oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo01?oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`005c?o
00030000oooooooo01?oool00ol0VOooooooo`1Noooo002?oooo0P0001Pco`000`000?ooooooo`0C
oooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Coooo00?o
09Woooooool0G_ooo`00Soooo`030000<ol0<ol001Hco`000`000?ooooooo`0Doooo00?o09Wooooo
ool0G_ooo`00Soooo`030000<ol0<ol001Hco`000`000?ooooooo`0Doooo00?o09Woooooool0G_oo
o`00Soooo`030000<ol0<ol001Hco`000`000?ooooooo`0Doooo00?o09Woooooool0G_ooo`00Sooo
o`030000<ol0<ol001Dco`000`000?ooooooo`0Eoooo00?o09Woooooool0G_ooo`00Soooo`80000F
<ol000<0003oooooool05Oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000E<ol000<0
003oooooool05Oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000E<ol000<0003ooooo
ool05Oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000D<ol000<0003oooooool05_oo
o`03o`2Ioooooooo05koool008Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`0F
oooo00?o09Woooooool0G_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001@co`00
0`000?ooooooo`0Foooo00?o09Woooooool0G_ooo`00ROooo`030000oooooooo00?oool300004c?o
00030000oooooooo01Ooool00ol0VOooooooo`1Noooo002:oooo00<0003oooooool00_ooo`030000
<ol0<ol001<co`000`000?ooooooo`0Goooo00?o09Woooooool0G_ooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0Goooo00?o09Woooooool0G_ooo`00R?oo
o`800005oooo00<0000co`0co`004S?o00030000oooooooo01Soool00ol0VOooooooo`1Noooo002?
oooo00<0000co`0co`004S?o00030000oooooooo01Soool00ol0VOooooooo`1Noooo002?oooo00<0
000co`0co`004S?o00030000oooooooo01Soool00ol0VOooooooo`1Noooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo01Soool00ol0VOooooooo`1Noooo002?oooo0P00018co`000`000?oo
ooooo`0Ioooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0I
oooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Ioooo00?o
09Woooooool0G_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Ioooo00?o09Wooooo
ool0G_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Joooo00?o09Woooooool0G_oo
o`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Joooo00?o09Woooooool0G_ooo`00Sooo
o`80000A<ol000<0003oooooool06_ooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000@
<ol000<0003oooooool06_ooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000?<ol000<0
003oooooool06oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool06oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000?<ol000<0003oooooool06ooo
o`03o`2Ioooooooo05koool008ooool00`0003?o03?o000?<ol000<0003oooooool06oooo`03o`2I
oooooooo05koool008ooool2000043?o00030000oooooooo01_oool00ol0VOooooooo`1Noooo002?
oooo00<0000co`0co`003S?o00030000oooooooo01coool00ol0VOooooooo`1Noooo002?oooo00<0
000co`0co`003S?o00030000oooooooo01coool00ol0VOooooooo`1Noooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo01coool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`003S?o
00030000oooooooo01coool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`003S?o00030000
oooooooo01coool00ol0VOooooooo`1Noooo002?oooo0P0000hco`000`000?ooooooo`0Moooo00?o
09Woooooool0G_ooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0Moooo00?o09Wooooo
ool0G_ooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0Moooo00?o09Woooooool0G_oo
o`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0Moooo00?o09Woooooool0G_ooo`00Sooo
o`030000<ol0<ol000`co`000`000?ooooooo`0Noooo00?o09Woooooool0G_ooo`00ROooo`<00003
oooo00<0000co`0co`0033?o00030000oooooooo01koool00ol0VOooooooo`1Noooo002:oooo00<0
003oooooool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`0Noooo00?o09Woooooool0G_oo
o`00Qoooo`D00003oooo0`0000`co`000`000?ooooooo`0Noooo00?o09Woooooool0G_ooo`00Qooo
o`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?ooo`lco`22oooo0029
oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool007coool00`000?oo
ooooo`0@oooo3S?o00Coool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo00Koool><ol01Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo00<co`000000000013?o00800005<ol00`0000;oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0000co`0co`00000:<ol000?oool0003oool00_ooo`030000oooooooo07_oool0
07[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000<ol0<ol0000023?o00D00003
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0000co`0co`000008
<ol000@0000co`3oool00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00ooool0100003?o03?o000000Tco`000`000?ooo`000003oooo00<0003oooooool0Noooo`00O?oo
o`030000oooooooo013oool00c?o00000000000:<ol000?oool0000000000_ooo`030000oooooooo
07coool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.41) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.67803 .12361 L
.68335 .12361 L
.68837 .12361 L
.69055 .12361 L
.69287 .12361 L
.69408 .12361 L
.69476 .12361 L
s
.69476 .12361 m
.69502 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30059 .12361 L
.30182 .12361 L
.30316 .12361 L
.30442 .12361 L
.3056 .12318 L
.30791 .12199 L
.31304 .11942 L
.32392 .11424 L
.34309 .10597 L
.38221 .09207 L
.4238 .08102 L
.44466 .07669 L
.46386 .07333 L
.50241 .06815 L
.5419 .06319 L
.57987 .05793 L
.6203 .05223 L
.65921 .04692 L
.66938 .0456 L
.68045 .04419 L
.68551 .04356 L
.68829 .04322 L
.6909 .0429 L
.69311 .04263 L
.69435 .04248 L
.69549 .12361 L
.69667 .12361 L
.69797 .12361 L
.70057 .12361 L
.74113 .12361 L
.78017 .12361 L
.82167 .12361 L
.86165 .12361 L
.90012 .12361 L
.94104 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.41) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Zoooo1@1V
oeooool008ooool00`000?ooooooo`0Qoooo2@1Vo`Coool00`1Vooooooooo`1Moooo002?oooo0P00
01[oool806Ko3Oooo`0306Kooooooooo05goool008ooool00`000?ooooooo`0Doooo1@1VoaGoool0
0`1Vooooooooo`1Moooo002?oooo00<0003oooooool03Oooo`L0I_lJoooo00<0I_ooooooool0GOoo
o`00Soooo`030000oooooooo00Coool906Ko8Oooo`0306Kooooooooo05goool008koool00`1Vo`00
001Vo`0506Ko:_ooo`0306Kooooooooo05goool008Woool506Ko00?oool0003oool0;oooo`0306Ko
oooooooo05goool008Coool506Ko1_ooo`80000_oooo00<0I_ooooooool0GOooo`005oooo`D0000c
oooo0P0000Coool200001?ooo`80000Roooo1@1Vo`_oool00`000?ooooooo`0^oooo00@0I_oooooo
ooooool200001?ooo`800004oooo0P0003Coool500005Oooo`006Oooo`030000oooooooo03;oool0
10000?ooooooo`0000Soool010000?ooooooo`0001coool506Ko4?ooo`030000oooooooo02koool0
101Vooooooooo`0000;oool00`000?ooooooo`06oooo00@0003oooooool0000eoooo00<0003ooooo
ool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000_oool00`000?ooooooo`0D
oooo1P1VoaGoool00`000?ooooooo`0_oooo00<0I_ooool000000_ooo`030000oooooooo00Woool0
0`000?ooooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?oo
o`@00002oooo00@0003oooooool00009oooo0P0001?oool406Ko6oooo`030000oooooooo02ooool0
0`1Vooooo`000002oooo00<0003oooooool01oooo`80000foooo00<0003oooooool05Oooo`006Ooo
o`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?ooooooo`0@oooo0P1Voaooool0
0`000?ooooooo`0_oooo00<0I_ooool000000_ooo`030000oooooooo00Ooool00`000?ooooooo`0e
oooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P0000[oool300003Oooo`<0I_lQoooo0P00
033oool00`1Vooooooooo`0200002_ooo`<0000doooo0P0001Ooool006Woool206Ko9?ooo`030000
oooooooo02ooool00`1Vooooooooo`1Loooo001Voooo0`1VobKoool00`000?ooooooo`0_oooo00<0
I_ooooooool0G?ooo`00I?ooo`80I_lYoooo00<0003oooooool0;oooo`0306Kooooooooo05coool0
06;oool206Ko:oooo`030000oooooooo02ooool00`1Vooooooooo`1Loooo001Poooo0P1Vobgoool0
0`000?ooooooo`0_oooo00<0I_ooooooool0G?ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?l0VC?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`0003?o03?o000^<ol000?o09Tco`0co`0023?o00030000<ol0<ol003Hco`0500005ooo
o`00Soooo`030000<ol0<ol002hco`000ol0VC?o03?o000i<ol0200001coool008ooool00`0003?o
03?o000^<ol000?o09Tco`0co`00<c?o00H0000Toooo002?oooo00<0000co`0co`00;S?o0003o`2I
<ol0<ol002hco`050000:_ooo`00Soooo`030000<ol0<ol002hco`000ol0VC?o03?o000Y<ol01@00
02ooool008ooool20000;c?o0003o`2I<ol0<ol002@co`050000=?ooo`00Soooo`030000<ol0<ol0
02hco`000ol0VC?o03?o000P<ol0100003Woool008ooool00`0003?o03?o000^<ol000?o09Tco`0c
o`007S?o0080000moooo002?oooo00<0000co`0co`00;S?o0003o`2I<ol0<ol001/co`030000?ooo
o`00Soooo`030000<ol0<ol002hco`000ol0VC?o03?o000I<ol00P0004;oool008ooool00`0003?o
03?o000^<ol000?o09Tco`0co`005c?o00800014oooo002?oooo0P0002lco`000ol0VC?o03?o000E
<ol00P0004Koool008ooool00`0003?o03?o000^<ol000?o09Tco`0co`004c?o00800018oooo002?
oooo00<0000co`0co`00;S?o0003o`2I<ol0<ol0018co`000`000?ooooooo`18oooo002?oooo00<0
000co`0co`00;S?o0003o`2I<ol0<ol0010co`020000Boooo`00Soooo`030000<ol0<ol002hco`00
0ol0VC?o03?o000><ol00P0004goool008ooool00`0003?o03?o000^<ol000?o09Tco`0co`003C?o
00030000oooooooo04goool008ooool20000;c?o0003o`2I<ol0<ol000/co`020000D?ooo`00Sooo
o`030000<ol0<ol002hco`000ol0VC?o03?o0009<ol00P0005;oool008ooool00`0003?o03?o000^
<ol000?o09Tco`0co`0023?o00030000oooooooo05;oool008ooool00`0003?o03?o000^<ol000?o
09Tco`0co`001c?o00030000oooooooo05?oool008ooool00`0003?o03?o000^<ol000?o09Tco`0c
o`001C?o0080001Foooo002?oooo00<0000co`0co`00;S?o0003o`2I<ol0<ol000@co`000`000?oo
ooooo`1Foooo002?oooo0P0002lco`000ol0VC?o03?o0003<ol000<0003oooooool0Eoooo`00Sooo
o`030000<ol0<ol002hco`000ol0VC?o03?o0002<ol000<0003oooooool0F?ooo`00Soooo`030000
<ol0<ol002hco`001Ol0VC?o03?o03?o0000001Koooo002?oooo00<0000co`0co`00;S?o0004o`2I
<ol0<ol00000G?ooo`00Soooo`030000<ol0<ol002hco`001?l0VC?o03?o000005coool008Ooool5
00000oooo`030000<ol0<ol002hco`000ol0VC?o0000001Moooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol002hco`000ol0V@000?ooo`1Moooo0029oooo00<0003oooooool00oooo`<0000^
<ol000?o09Woooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000^<ol000?o
09Woooooool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000]<ol000<0003o09Wo
ool0G_ooo`00R?ooo`800005oooo00<0000co`0co`00;3?o00030000ooooo`2I05ooool008ooool0
0`0003?o03?o000[<ol000@0003ooooooooo09UOoooo002?oooo00<0000co`0co`00:c?o00040000
ooooooooo`2IGoooo`00Soooo`80000[<ol000D0003ooooooooooooo09T0Goooo`00Soooo`030000
<ol0<ol002Tco`000`000?ooooooo`02oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol0
02Tco`000`000?ooooooo`02oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol002Pco`00
0`000?ooooooo`03oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol002Lco`000`000?oo
ooooo`04oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`05
oooo00?o09Woooooool0GOooo`00Soooo`80000W<ol000<0003oooooool01Oooo`03o`2Ioooooooo
05goool008ooool00`0003?o03?o000U<ol000<0003oooooool01_ooo`03o`2Ioooooooo05goool0
08ooool00`0003?o03?o000T<ol000<0003oooooool01oooo`03o`2Ioooooooo05goool008ooool0
0`0003?o03?o000T<ol000<0003oooooool01oooo`03o`2Ioooooooo05goool008ooool00`0003?o
03?o000S<ol000<0003oooooool02?ooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000S
<ol000<0003oooooool02?ooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000R<ol000<0
003oooooool02Oooo`03o`2Ioooooooo05goool008ooool200008c?o00030000oooooooo00Woool0
0ol0VOooooooo`1Moooo002?oooo00<0000co`0co`008C?o00030000oooooooo00[oool00ol0VOoo
ooooo`1Moooo002?oooo00<0000co`0co`008C?o00030000oooooooo00[oool00ol0VOooooooo`1M
oooo002?oooo00<0000co`0co`0083?o00030000oooooooo00_oool00ol0VOooooooo`1Moooo002?
oooo00<0000co`0co`0083?o00030000oooooooo00_oool00ol0VOooooooo`1Moooo002?oooo00<0
000co`0co`0083?o00030000oooooooo00_oool00ol0VOooooooo`1Moooo002?oooo0P00020co`00
0`000?ooooooo`0<oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol001lco`000`000?oo
ooooo`0<oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0=
oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0=oooo00?o
09Woooooool0GOooo`00Qoooo`@00004oooo00<0000co`0co`007S?o00030000oooooooo00goool0
0ol0VOooooooo`1Moooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol001dco`000`000?oo
ooooo`0>oooo00?o09Woooooool0GOooo`00R?ooo`030000oooooooo00Coool300007C?o00030000
oooooooo00koool00ol0VOooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01dco`000`000?ooooooo`0>oooo00?o09Woooooool0GOooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol001`co`000`000?ooooooo`0?oooo00?o09Woooooool0GOooo`00R?ooo`800005
oooo00<0000co`0co`0073?o00030000oooooooo00ooool00ol0VOooooooo`1Moooo002?oooo00<0
000co`0co`006c?o00030000oooooooo013oool00ol0VOooooooo`1Moooo002?oooo00<0000co`0c
o`006c?o00030000oooooooo013oool00ol0VOooooooo`1Moooo002?oooo0P0001`co`000`000?oo
ooooo`0@oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0A
oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Aoooo00?o
09Woooooool0GOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Aoooo00?o09Wooooo
ool0GOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Aoooo00?o09Woooooool0GOoo
o`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0Boooo00?o09Woooooool0GOooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`0Boooo00?o09Woooooool0GOooo`00Soooo`80000J
<ol000<0003oooooool04_ooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000H<ol000<0
003oooooool04oooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000H<ol000<0003oooooool04ooo
o`03o`2Ioooooooo05goool008ooool00`0003?o03?o000G<ol000<0003oooooool05?ooo`03o`2I
oooooooo05goool008ooool00`0003?o03?o000G<ol000<0003oooooool05?ooo`03o`2Ioooooooo
05goool008ooool2000063?o00030000oooooooo01Coool00ol0VOooooooo`1Moooo002?oooo00<0
000co`0co`005c?o00030000oooooooo01Coool00ol0VOooooooo`1Moooo002?oooo00<0000co`0c
o`005S?o00030000oooooooo01Goool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`005S?o
00030000oooooooo01Goool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`005S?o00030000
oooooooo01Goool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`005C?o00030000oooooooo
01Koool00ol0VOooooooo`1Moooo002?oooo0P0001Hco`000`000?ooooooo`0Foooo00?o09Wooooo
ool0GOooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0Foooo00?o09Woooooool0GOoo
o`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0Foooo00?o09Woooooool0GOooo`00Sooo
o`030000<ol0<ol001@co`000`000?ooooooo`0Goooo00?o09Woooooool0GOooo`00R?ooo`800005
oooo00<0000co`0co`0053?o00030000oooooooo01Ooool00ol0VOooooooo`1Moooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0053?o00030000oooooooo01Ooool00ol0VOooooooo`1M
oooo0029oooo00<0003oooooool00oooo`<0000C<ol000<0003oooooool06?ooo`03o`2Ioooooooo
05goool008[oool00`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo01Soool0
0ol0VOooooooo`1Moooo0027oooo00@0003oooooool00004oooo00<0000co`0co`004c?o00030000
oooooooo01Soool00ol0VOooooooo`1Moooo0028oooo0P0000Goool00`0003?o03?o000B<ol000<0
003oooooool06Oooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool06Oooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000B<ol000<0003oooooool06Ooo
o`03o`2Ioooooooo05goool008ooool00`0003?o03?o000B<ol000<0003oooooool06Oooo`03o`2I
oooooooo05goool008ooool200004S?o00030000oooooooo01[oool00ol0VOooooooo`1Moooo002?
oooo00<0000co`0co`004C?o00030000oooooooo01[oool00ol0VOooooooo`1Moooo002?oooo00<0
000co`0co`004C?o00030000oooooooo01[oool00ol0VOooooooo`1Moooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo01[oool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`0043?o
00030000oooooooo01_oool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`0043?o00030000
oooooooo01_oool00ol0VOooooooo`1Moooo002?oooo0P00014co`000`000?ooooooo`0Koooo00?o
09Woooooool0GOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Koooo00?o09Wooooo
ool0GOooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Loooo00?o09Woooooool0GOoo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Loooo00?o09Woooooool0GOooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0Loooo00?o09Woooooool0GOooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0Loooo00?o09Woooooool0GOooo`00Soooo`80000@<ol000<0
003oooooool07?ooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000><ol000<0003ooooo
ool07Oooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000><ol000<0003oooooool07Ooo
o`03o`2Ioooooooo05goool008ooool00`0003?o03?o000><ol000<0003oooooool07Oooo`03o`2I
oooooooo05goool008ooool00`0003?o03?o000><ol000<0003oooooool07Oooo`03o`2Ioooooooo
05goool008ooool00`0003?o03?o000><ol000<0003oooooool07Oooo`03o`2Ioooooooo05goool0
08ooool200003S?o00030000oooooooo01koool00ol0VOooooooo`1Moooo002?oooo00<0000co`0c
o`003C?o00030000oooooooo01koool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`003C?o
00030000oooooooo01koool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`003C?o00030000
oooooooo01koool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`0033?o00030000oooooooo
01ooool00ol0VOooooooo`1Moooo0029oooo0`0000?oool00`0003?o03?o000<<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo05goool008[oool00`000?ooooooo`02oooo00<0000co`0co`0033?o
00030000oooooooo01ooool00ol0VOooooooo`1Moooo0027oooo1@0000?oool3000033?o00030000
oooooooo01ooool00ol0VOooooooo`1Moooo0027oooo00@0003oooooool00004oooo3c?o08;oool0
08Soool00`000?ooo`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o
08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o
00800005<ol00`000003oooo0000000000<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002c?o00030000<ol0oooo00;oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008<ol01@0000?oool0
0`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0
003oooooool00008<ol000D0000co`0co`00000co`000oooo`030000oooooooo00;oool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002C?o00030000
<ol0000000Coool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
017oool200002c?o00800003oooo0P0000?oool00`000?ooooooo`1ioooo002?oooo3C?o08Coool0
08ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.6883 .12361 L
.69289 .12361 L
.6954 .12361 L
.69774 .12361 L
.69895 .12361 L
s
.69895 .12361 m
.69947 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.28302 .12361 L
.2881 .12361 L
.29349 .12361 L
.2957 .12361 L
.29809 .12361 L
.29879 .12361 L
.29945 .12361 L
.3007 .12324 L
.30188 .12264 L
.30316 .12198 L
.3438 .10379 L
.38293 .09041 L
.42451 .07981 L
.44538 .07568 L
.46458 .07248 L
.50313 .06756 L
.54262 .06277 L
.58059 .05764 L
.62101 .05203 L
.65992 .04678 L
.6701 .04547 L
.68116 .04407 L
.68623 .04344 L
.69161 .04279 L
.69621 .04224 L
.69747 .04209 L
.69813 .04201 L
.69883 .04193 L
.70011 .12361 L
.70128 .12361 L
.73939 .12361 L
.77995 .12361 L
.819 .12361 L
.8605 .12361 L
.90048 .12361 L
.93894 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Zoooo1P1V
oekoool008ooool00`000?ooooooo`0Roooo201Vo`Goool00`1Vooooooooo`1Loooo002?oooo0P00
01_oool806Ko3Oooo`0306Kooooooooo05coool008ooool00`000?ooooooo`0Doooo1P1VoaGoool0
0`1Vooooooooo`1Loooo002?oooo00<0003oooooool03Oooo`L0I_lKoooo00<0I_ooooooool0G?oo
o`00Soooo`030000oooooooo00Coool906Ko8_ooo`0306Kooooooooo05coool008coool306Ko00<0
0000I_l0I_l0101Vob_oool00`1Vooooooooo`1Loooo0024oooo201Vo`?oool00`000?ooooooo`0_
oooo00<0I_ooooooool0G?ooo`00Ooooo`D0I_l;oooo0P00033oool00`1Vooooooooo`1Loooo000G
oooo1@0003?oool200001?ooo`800004oooo0P0001koool406Ko4?ooo`030000oooooooo02ooool0
0`1Vooooooooo`0200001?ooo`800004oooo0P0003Coool500005Oooo`006Oooo`030000oooooooo
03;oool010000?ooooooo`0000Soool010000?ooooooo`0001Woool406Ko5?ooo`030000oooooooo
02ooool00`1Vooooo`000002oooo00<0003oooooool01_ooo`040000oooooooo0000=Oooo`030000
oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0003ooooo
ool04oooo`@0I_lHoooo00<0003oooooool0<?ooo`0506Ko0000oooooooo000000_oool00`000?oo
ooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?ooo`@00002
oooo00@0003oooooool00009oooo0P0001?oool306Ko7?ooo`030000oooooooo033oool01@1Vo`00
0?ooooooo`000009oooo0P0003Koool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_oo
o`040000oooooooo00002Oooo`030000oooooooo00ooool306Ko7oooo`030000oooooooo033oool0
1@1Vo`000?ooooooo`000009oooo00<0003oooooool0=Oooo`030000oooooooo01Goool001Soool2
0000=Oooo`80000:oooo0`0000_oool406Ko8_ooo`80000aoooo00@0I_ooool00000000:oooo0`00
03Coool200005oooo`00Ioooo`80I_lVoooo00<0003oooooool0<?ooo`0306Kooooooooo05_oool0
06Goool206Ko:?ooo`030000oooooooo033oool00`1Vooooooooo`1Koooo001Soooo0P1Vob[oool0
0`000?ooooooo`0`oooo00<0I_ooooooool0Foooo`00HOooo`80I_l/oooo00<0003oooooool0<?oo
o`0306Kooooooooo05_oool005ooool206Ko;_ooo`030000oooooooo033oool00`1Vooooooooo`1K
oooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0o`2I00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Xco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000oooooooo01Goool0
01Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol002lco`000ol0VC?o
03?o0007<ol000<0000co`0co`00=S?o00D0000Goooo002?oooo00<0000co`0co`00;c?o0003o`2I
<ol0<ol003Pco`0800007?ooo`00Soooo`030000<ol0<ol002lco`000ol0VC?o03?o000b<ol01P00
02Coool008ooool00`0003?o03?o000_<ol000?o09Tco`0co`00;C?o00D0000Zoooo002?oooo00<0
000co`0co`00;c?o0003o`2I<ol0<ol002Pco`050000;oooo`00Soooo`80000`<ol000?o09Tco`0c
o`008c?o00D0000doooo002?oooo00<0000co`0co`00;c?o0003o`2I<ol0<ol001lco`040000>Ooo
o`00Soooo`030000<ol0<ol002lco`000ol0VC?o03?o000M<ol00P0003goool008ooool00`0003?o
03?o000_<ol000?o09Tco`0co`006S?o00<0000ooooo002?oooo00<0000co`0co`00;c?o0003o`2I
<ol0<ol001Pco`020000@_ooo`00Soooo`030000<ol0<ol002lco`000ol0VC?o03?o000F<ol00P00
04Coool008ooool20000<3?o0003o`2I<ol0<ol001@co`020000A_ooo`00Soooo`030000<ol0<ol0
02lco`000ol0VC?o03?o000B<ol00P0004Soool008ooool00`0003?o03?o000_<ol000?o09Tco`0c
o`004C?o00030000oooooooo04Soool008ooool00`0003?o03?o000_<ol000?o09Tco`0co`003c?o
0080001;oooo002?oooo00<0000co`0co`00;c?o0003o`2I<ol0<ol000dco`020000COooo`00Sooo
o`030000<ol0<ol002lco`000ol0VC?o03?o000<<ol000<0003oooooool0COooo`00Soooo`80000`
<ol000?o09Tco`0co`002S?o0080001@oooo002?oooo00<0000co`0co`00;c?o0003o`2I<ol0<ol0
00Pco`020000D_ooo`00Soooo`030000<ol0<ol002lco`000ol0VC?o03?o0007<ol000<0003ooooo
ool0D_ooo`00Soooo`030000<ol0<ol002lco`000ol0VC?o03?o0006<ol000<0003oooooool0Dooo
o`00Soooo`030000<ol0<ol002lco`000ol0VC?o03?o0004<ol00P0005Koool008ooool00`0003?o
03?o000_<ol000?o09Tco`0co`000c?o00030000oooooooo05Koool008ooool20000<3?o0003o`2I
<ol0<ol0008co`000`000?ooooooo`1Goooo002?oooo00<0000co`0co`00;c?o0005o`2I<ol0<ol0
<ol0000005[oool008ooool00`0003?o03?o000_<ol000Co09Tco`0co`00001Koooo002?oooo00<0
000co`0co`00;c?o0003o`2I<ol0000005coool008ooool00`0003?o03?o000_<ol000?o09Tco`00
0000G?ooo`00Qoooo`D00003oooo00<0000co`0co`00;c?o0003o`2I0000oooo05coool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`00;c?o0003o`2Ioooooooo05coool008Woool00`000?oo
ooooo`03oooo0`0002hco`000`000?l0VOooo`1Moooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol002hco`000`000?l0VOooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
02dco`000`000?ooool0V@1Noooo0028oooo0P0000Goool00`0003?o03?o000/<ol000@0003ooooo
oooo09UNoooo002?oooo00<0000co`0co`00:c?o00050000ooooooooooooo`2I05koool008ooool0
0`0003?o03?o000[<ol000D0003ooooooooooooo09T0G_ooo`00Soooo`80000[<ol000<0003ooooo
ool00_ooo`03o`2Ioooooooo05coool008ooool00`0003?o03?o000Y<ol000<0003oooooool00ooo
o`03o`2Ioooooooo05coool008ooool00`0003?o03?o000Y<ol000<0003oooooool00oooo`03o`2I
oooooooo05coool008ooool00`0003?o03?o000X<ol000<0003oooooool01?ooo`03o`2Ioooooooo
05coool008ooool00`0003?o03?o000W<ol000<0003oooooool01Oooo`03o`2Ioooooooo05coool0
08ooool00`0003?o03?o000V<ol000<0003oooooool01_ooo`03o`2Ioooooooo05coool008ooool2
00009c?o00030000oooooooo00Koool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`009C?o
00030000oooooooo00Ooool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`0093?o00030000
oooooooo00Soool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`0093?o00030000oooooooo
00Soool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`008c?o00030000oooooooo00Woool0
0ol0VOooooooo`1Loooo002?oooo00<0000co`0co`008c?o00030000oooooooo00Woool00ol0VOoo
ooooo`1Loooo002?oooo00<0000co`0co`008S?o00030000oooooooo00[oool00ol0VOooooooo`1L
oooo002?oooo0P0002<co`000`000?ooooooo`0:oooo00?o09Woooooool0G?ooo`00Soooo`030000
<ol0<ol0024co`000`000?ooooooo`0;oooo00?o09Woooooool0G?ooo`00Soooo`030000<ol0<ol0
024co`000`000?ooooooo`0;oooo00?o09Woooooool0G?ooo`00Soooo`030000<ol0<ol0020co`00
0`000?ooooooo`0<oooo00?o09Woooooool0G?ooo`00Soooo`030000<ol0<ol0020co`000`000?oo
ooooo`0<oooo00?o09Woooooool0G?ooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`0<
oooo00?o09Woooooool0G?ooo`00Soooo`80000P<ol000<0003oooooool03Oooo`03o`2Ioooooooo
05coool008ooool00`0003?o03?o000O<ol000<0003oooooool03Oooo`03o`2Ioooooooo05coool0
08ooool00`0003?o03?o000N<ol000<0003oooooool03_ooo`03o`2Ioooooooo05coool008ooool0
0`0003?o03?o000N<ol000<0003oooooool03_ooo`03o`2Ioooooooo05coool008Ooool400001?oo
o`030000<ol0<ol001hco`000`000?ooooooo`0>oooo00?o09Woooooool0G?ooo`00Qoooo`030000
oooooooo00Goool00`0003?o03?o000M<ol000<0003oooooool03oooo`03o`2Ioooooooo05coool0
08Soool00`000?ooooooo`04oooo0`0001dco`000`000?ooooooo`0?oooo00?o09Woooooool0G?oo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000M<ol000<0003oooooool04?ooo`03o`2I
oooooooo05_oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000L<ol000<0003ooooo
ool04Oooo`03o`2Ioooooooo05_oool008Soool200001Oooo`030000<ol0<ol001`co`000`000?oo
ooooo`0Aoooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0B
oooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0Boooo00?o
09Woooooool0Foooo`00Soooo`80000L<ol000<0003oooooool04_ooo`03o`2Ioooooooo05_oool0
08ooool00`0003?o03?o000J<ol000<0003oooooool04oooo`03o`2Ioooooooo05_oool008ooool0
0`0003?o03?o000J<ol000<0003oooooool04oooo`03o`2Ioooooooo05_oool008ooool00`0003?o
03?o000J<ol000<0003oooooool04oooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o000J
<ol000<0003oooooool04oooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o000I<ol000<0
003oooooool05?ooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o000I<ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo05_oool008ooool200006S?o00030000oooooooo01Coool00ol0VOoo
ooooo`1Koooo002?oooo00<0000co`0co`0063?o00030000oooooooo01Goool00ol0VOooooooo`1K
oooo002?oooo00<0000co`0co`0063?o00030000oooooooo01Goool00ol0VOooooooo`1Koooo002?
oooo00<0000co`0co`0063?o00030000oooooooo01Goool00ol0VOooooooo`1Koooo002?oooo00<0
000co`0co`005c?o00030000oooooooo01Koool00ol0VOooooooo`1Koooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo01Koool00ol0VOooooooo`1Koooo002?oooo0P0001Pco`000`000?oo
ooooo`0Foooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0F
oooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol001Hco`000`000?ooooooo`0Goooo00?o
09Woooooool0Foooo`00Soooo`030000<ol0<ol001Hco`000`000?ooooooo`0Goooo00?o09Wooooo
ool0Foooo`00Soooo`030000<ol0<ol001Hco`000`000?ooooooo`0Goooo00?o09Woooooool0Fooo
o`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0Hoooo00?o09Woooooool0Foooo`00Sooo
o`80000F<ol000<0003oooooool06?ooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o000E
<ol000<0003oooooool06?ooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o000E<ol000<0
003oooooool06?ooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o000D<ol000<0003ooooo
ool06Oooo`03o`2Ioooooooo05_oool008Soool200001Oooo`030000<ol0<ol001@co`000`000?oo
ooooo`0Ioooo00?o09Woooooool0Foooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
01@co`000`000?ooooooo`0Ioooo00?o09Woooooool0Foooo`00ROooo`030000oooooooo00?oool3
00004c?o00030000oooooooo01[oool00ol0VOooooooo`1Koooo002:oooo00<0003oooooool00_oo
o`030000<ol0<ol001<co`000`000?ooooooo`0Joooo00?o09Woooooool0Foooo`00Qoooo`040000
oooooooo00001?ooo`030000<ol0<ol001<co`000`000?ooooooo`0Joooo00?o09Woooooool0Fooo
o`00R?ooo`800005oooo00<0000co`0co`004S?o00030000oooooooo01_oool00ol0VOooooooo`1K
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo01_oool00ol0VOooooooo`1Koooo002?
oooo00<0000co`0co`004S?o00030000oooooooo01_oool00ol0VOooooooo`1Koooo002?oooo00<0
000co`0co`004S?o00030000oooooooo01_oool00ol0VOooooooo`1Koooo002?oooo0P00018co`00
0`000?ooooooo`0Loooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`0Loooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0L
oooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Loooo00?o
09Woooooool0Foooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Moooo00?o09Wooooo
ool0Foooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Moooo00?o09Woooooool0Fooo
o`00Soooo`80000A<ol000<0003oooooool07Oooo`03o`2Ioooooooo05_oool008ooool00`0003?o
03?o000@<ol000<0003oooooool07Oooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o000?
<ol000<0003oooooool07_ooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o000?<ol000<0
003oooooool07_ooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o000?<ol000<0003oooooool07_oo
o`03o`2Ioooooooo05_oool008ooool2000043?o00030000oooooooo01koool00ol0VOooooooo`1K
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo01ooool00ol0VOooooooo`1Koooo002?
oooo00<0000co`0co`003S?o00030000oooooooo01ooool00ol0VOooooooo`1Koooo002?oooo00<0
000co`0co`003S?o00030000oooooooo01ooool00ol0VOooooooo`1Koooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo01ooool00ol0VOooooooo`1Koooo002?oooo00<0000co`0co`003S?o
00030000oooooooo01ooool00ol0VOooooooo`1Koooo002?oooo0P0000hco`000`000?ooooooo`0P
oooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0Poooo00?o
09Woooooool0Foooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0Poooo00?o09Wooooo
ool0Foooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0Poooo00?o09Woooooool0Fooo
o`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Qoooo00?o09Woooooool0Foooo`00ROoo
o`<00003oooo00<0000co`0co`0033?o00030000oooooooo027oool00ol0VOooooooo`1Koooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`0Qoooo00?o09Wooooo
ool0Foooo`00Qoooo`D00003oooo0`0000`co`000`000?ooooooo`0Qoooo00?o09Woooooool0Fooo
o`00Qoooo`040000oooooooo00001?ooo`lco`22oooo0028oooo00<0003oool000001?ooo`lco`22
oooo0029oooo0P0000Coool?<ol0P_ooo`00Soooo`lco`22oooo002?oooo3c?o08;oool007Woool0
0`000?ooooooo`0Coooo3S?o00Ooool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo00Woool><ol02?ooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000@co`0200001C?o00<000000oooo`0000000002
00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool010000?ooooooo`0000/co`00100003?o0?ooo`0000Koool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000Pco`0500000_ooo`030000oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000coool010000?ooooooo`0000Pco`001@0003?o03?o000003?o0003oooo00<0
003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00009<ol000<0000co`0000000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000/co`0200000oooo`800003oooo00<0003ooooo
ool0NOooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.43) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.6883 .12361 L
.69774 .12361 L
.7003 .12361 L
.7017 .12361 L
.70301 .12361 L
.70413 .12361 L
s
.70413 .12361 m
.70461 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.28302 .12361 L
.2881 .12361 L
.29088 .12361 L
.29224 .12361 L
.29349 .12361 L
.29462 .12361 L
.2957 .12337 L
.29684 .12278 L
.29809 .12214 L
.30316 .1196 L
.3438 .10196 L
.38293 .08902 L
.42451 .07881 L
.44538 .07483 L
.46458 .07177 L
.50313 .06708 L
.54262 .06247 L
.58059 .05746 L
.62101 .05194 L
.65992 .04675 L
.67973 .04423 L
.69018 .04295 L
.69591 .04226 L
.69871 .04193 L
.70128 .04163 L
.70359 .04136 L
.70475 .04123 L
.70602 .12361 L
.7073 .12361 L
.70866 .12361 L
.71112 .12361 L
.72198 .12361 L
.74113 .12361 L
.78263 .12361 L
.82261 .12361 L
.86107 .12361 L
.90199 .12361 L
.9414 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.43) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Yoooo2@1V
oecoool008ooool00`000?ooooooo`0Roooo1`1Vo`Soool00`1Vooooooooo`1Joooo002?oooo0P00
01_oool806Ko3oooo`0306Kooooooooo05[oool008ooool00`000?ooooooo`0Doooo1P1VoaOoool0
0`1Vooooooooo`1Joooo002?oooo00<0003oooooool03Oooo`L0I_lMoooo00<0I_ooooooool0F_oo
o`00Soooo`030000oooooooo00Coool906Ko9?ooo`0306Kooooooooo05[oool008coool306Ko00<0
0000I_l0I_l0101Vobgoool00`1Vooooooooo`1Joooo0024oooo201Vo`?oool00`000?ooooooo`0a
oooo00<0I_ooooooool0F_ooo`00Ooooo`D0I_l;oooo0P0003;oool00`1Vooooooooo`1Joooo000G
oooo1@0003?oool200001?ooo`800004oooo0P0001koool406Ko4?ooo`030000oooooooo037oool0
0`1Vo`0000000004oooo0P0000Coool20000=?ooo`D0000Eoooo000Ioooo00<0003oooooool0<_oo
o`040000oooooooo00002?ooo`040000oooooooo00006Oooo`@0I_lDoooo00<0003oooooool0<Ooo
o`040000oooooooo00002?ooo`040000oooooooo0000=Oooo`030000oooooooo01Goool001Woool0
0`000?ooooooo`0boooo00@0003oooooool0000;oooo00<0003oooooool04oooo`@0I_lHoooo00<0
003oooooool0<Oooo`040000oooooooo00002oooo`030000oooooooo03?oool00`000?ooooooo`0E
oooo000Aoooo100000Coool00`000?ooooooo`0/oooo100000;oool010000?ooooooo`0000Woool2
00004oooo`<0I_lLoooo00<0003oooooool0<Oooo`040000oooooooo00002Oooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`0?oooo0`1Voaooool00`000?ooooooo`0aoooo00@0003oooooool00009oooo00<0003ooooo
ool0=Oooo`030000oooooooo01Goool001Soool20000=Oooo`80000:oooo0`0000_oool406Ko8_oo
o`80000boooo00<0I_l0000000002_ooo`<0000doooo0P0001Ooool006Koool306Ko9_ooo`030000
oooooooo037oool00`1Vooooooooo`1Joooo001Toooo0P1VobWoool00`000?ooooooo`0aoooo00<0
I_ooooooool0F_ooo`00HOooo`<0I_l[oooo00<0003oooooool0<Oooo`0306Kooooooooo05[oool0
05ooool206Ko;_ooo`030000oooooooo037oool00`1Vooooooooo`1Joooo001Moooo0P1Voc3oool0
0`000?ooooooo`0aoooo00<0I_ooooooool0F_ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`001@0003?o03?o03?o0?l0V@07<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo03Woool00`0003?o03?o000a<ol000?o09Tco`0co`001C?o00030000<ol0<ol003Hco`05
00005oooo`00Soooo`030000<ol0<ol0034co`000ol0VC?o03?o000f<ol0200001coool008ooool0
0`0003?o03?o000a<ol000?o09Tco`0co`00<3?o00H0000Toooo002?oooo00<0000co`0co`00<C?o
0003o`2I<ol0<ol002/co`050000:_ooo`00Soooo`030000<ol0<ol0034co`000ol0VC?o03?o000V
<ol01@0002ooool008ooool20000<S?o0003o`2I<ol0<ol0024co`050000=?ooo`00Soooo`030000
<ol0<ol0034co`000ol0VC?o03?o000M<ol0100003Woool008ooool00`0003?o03?o000a<ol000?o
09Tco`0co`006c?o0080000moooo002?oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol001Pco`03
0000?oooo`00Soooo`030000<ol0<ol0034co`000ol0VC?o03?o000F<ol00P0004;oool008ooool0
0`0003?o03?o000a<ol000?o09Tco`0co`0053?o00800014oooo002?oooo0P00038co`000ol0VC?o
03?o000B<ol00P0004Koool008ooool00`0003?o03?o000a<ol000?o09Tco`0co`0043?o00800018
oooo002?oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol000lco`000`000?ooooooo`18oooo002?
oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol000dco`020000Boooo`00Soooo`030000<ol0<ol0
034co`000ol0VC?o03?o000;<ol00P0004goool008ooool00`0003?o03?o000a<ol000?o09Tco`0c
o`002S?o00030000oooooooo04goool008ooool20000<S?o0003o`2I<ol0<ol000Pco`020000D?oo
o`00Soooo`030000<ol0<ol0034co`000ol0VC?o03?o0006<ol00P0005;oool008ooool00`0003?o
03?o000a<ol000?o09Tco`0co`001C?o00030000oooooooo05;oool008ooool00`0003?o03?o000a
<ol000?o09Tco`0co`0013?o00030000oooooooo05?oool008ooool00`0003?o03?o000a<ol000?o
09Tco`0co`000S?o0080001Foooo002?oooo00<0000co`0co`00<C?o0005o`2I<ol0<ol0<ol00000
05Soool008ooool20000<S?o0004o`2I<ol0<ol00000FOooo`00Soooo`030000<ol0<ol0034co`00
0ol0VC?o0000001Joooo002?oooo00<0000co`0co`00<C?o0003o`2I0000oooo05[oool008ooool0
0`0003?o03?o000a<ol000?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0034co`000ol0VOoo
ooooo`1Joooo0027oooo1@0000?oool00`0003?o03?o000`<ol000<0003o09Woool0Foooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000_<ol000<0003ooooo09T0G?ooo`00ROooo`030000
oooooooo00?oool30000;S?o00040000ooooooooo`2IG?ooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000^<ol000@0003ooooooooo09ULoooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol002dco`001@000?ooooooooooool0V@1Loooo0028oooo0P0000Goool00`0003?o03?o000/
<ol000<0003oooooool00_ooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000[<ol000<0
003oooooool00oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000[<ol000<0003ooooo
ool00oooo`03o`2Ioooooooo05[oool008ooool20000:c?o00030000oooooooo00Coool00ol0VOoo
ooooo`1Joooo002?oooo00<0000co`0co`00:C?o00030000oooooooo00Goool00ol0VOooooooo`1J
oooo002?oooo00<0000co`0co`00:C?o00030000oooooooo00Goool00ol0VOooooooo`1Joooo002?
oooo00<0000co`0co`00:3?o00030000oooooooo00Koool00ol0VOooooooo`1Joooo002?oooo00<0
000co`0co`009c?o00030000oooooooo00Ooool00ol0VOooooooo`1Joooo002?oooo00<0000co`0c
o`009S?o00030000oooooooo00Soool00ol0VOooooooo`1Joooo002?oooo0P0002Lco`000`000?oo
ooooo`08oooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`09
oooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`0:oooo00?o
09Woooooool0F_ooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`0:oooo00?o09Wooooo
ool0F_ooo`00Soooo`030000<ol0<ol002<co`000`000?ooooooo`0;oooo00?o09Woooooool0F_oo
o`00Soooo`030000<ol0<ol002<co`000`000?ooooooo`0;oooo00?o09Woooooool0F_ooo`00Sooo
o`030000<ol0<ol0028co`000`000?ooooooo`0<oooo00?o09Woooooool0F_ooo`00Soooo`80000S
<ol000<0003oooooool03?ooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000Q<ol000<0
003oooooool03Oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000Q<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000P<ol000<0003oooooool03_oo
o`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000P<ol000<0003oooooool03_ooo`03o`2I
oooooooo05[oool008ooool00`0003?o03?o000P<ol000<0003oooooool03_ooo`03o`2Ioooooooo
05[oool008ooool2000083?o00030000oooooooo00ooool00ol0VOooooooo`1Joooo002?oooo00<0
000co`0co`007c?o00030000oooooooo00ooool00ol0VOooooooo`1Joooo002?oooo00<0000co`0c
o`007S?o00030000oooooooo013oool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`007S?o
00030000oooooooo013oool00ol0VOooooooo`1Joooo0027oooo100000Coool00`0003?o03?o000N
<ol000<0003oooooool04?ooo`03o`2Ioooooooo05[oool008Ooool00`000?ooooooo`05oooo00<0
000co`0co`007C?o00030000oooooooo017oool00ol0VOooooooo`1Joooo0028oooo00<0003ooooo
ool01?ooo`<0000M<ol000<0003oooooool04Oooo`03o`2Ioooooooo05[oool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`007C?o00030000oooooooo017oool00ol0VOooooooo`1Joooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`0073?o00030000oooooooo01;oool00ol0VOoo
ooooo`1Joooo0028oooo0P0000Goool00`0003?o03?o000L<ol000<0003oooooool04_ooo`03o`2I
oooooooo05[oool008ooool00`0003?o03?o000K<ol000<0003oooooool04oooo`03o`2Ioooooooo
05[oool008ooool00`0003?o03?o000K<ol000<0003oooooool04oooo`03o`2Ioooooooo05[oool0
08ooool2000073?o00030000oooooooo01?oool00ol0VOooooooo`1Joooo002?oooo00<0000co`0c
o`006S?o00030000oooooooo01Coool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`006S?o
00030000oooooooo01Coool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`006S?o00030000
oooooooo01Coool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`006S?o00030000oooooooo
01Coool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`006C?o00030000oooooooo01Goool0
0ol0VOooooooo`1Joooo002?oooo00<0000co`0co`006C?o00030000oooooooo01Goool00ol0VOoo
ooooo`1Joooo002?oooo0P0001Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0F_ooo`00Sooo
o`030000<ol0<ol001Pco`000`000?ooooooo`0Foooo00?o09Woooooool0F_ooo`00Soooo`030000
<ol0<ol001Pco`000`000?ooooooo`0Foooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0
01Pco`000`000?ooooooo`0Foooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol001Lco`00
0`000?ooooooo`0Goooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol001Lco`000`000?oo
ooooo`0Goooo00?o09Woooooool0F_ooo`00Soooo`80000H<ol000<0003oooooool05oooo`03o`2I
oooooooo05[oool008ooool00`0003?o03?o000G<ol000<0003oooooool05oooo`03o`2Ioooooooo
05[oool008ooool00`0003?o03?o000F<ol000<0003oooooool06?ooo`03o`2Ioooooooo05[oool0
08ooool00`0003?o03?o000F<ol000<0003oooooool06?ooo`03o`2Ioooooooo05[oool008ooool0
0`0003?o03?o000F<ol000<0003oooooool06?ooo`03o`2Ioooooooo05[oool008ooool00`0003?o
03?o000E<ol000<0003oooooool06Oooo`03o`2Ioooooooo05[oool008ooool200005S?o00030000
oooooooo01Woool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`005C?o00030000oooooooo
01Woool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`005C?o00030000oooooooo01Woool0
0ol0VOooooooo`1Joooo002?oooo00<0000co`0co`0053?o00030000oooooooo01[oool00ol0VOoo
ooooo`1Joooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool06_ooo`03o`2I
oooooooo05[oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000D<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo05[oool008Woool00`000?ooooooo`03oooo0`0001<co`000`000?oo
ooooo`0Koooo00?o09Woooooool0F_ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000C
<ol000<0003oooooool06oooo`03o`2Ioooooooo05[oool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o000C<ol000<0003oooooool06oooo`03o`2Ioooooooo05[oool008Soool200001Ooo
o`030000<ol0<ol0018co`000`000?ooooooo`0Loooo00?o09Woooooool0F_ooo`00Soooo`030000
<ol0<ol0018co`000`000?ooooooo`0Loooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0
018co`000`000?ooooooo`0Loooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`0Loooo00?o09Woooooool0F_ooo`00Soooo`80000B<ol000<0003oooooool07Ooo
o`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000A<ol000<0003oooooool07Oooo`03o`2I
oooooooo05[oool008ooool00`0003?o03?o000A<ol000<0003oooooool07Oooo`03o`2Ioooooooo
05[oool008ooool00`0003?o03?o000A<ol000<0003oooooool07Oooo`03o`2Ioooooooo05[oool0
08ooool00`0003?o03?o000@<ol000<0003oooooool07_ooo`03o`2Ioooooooo05[oool008ooool0
0`0003?o03?o000@<ol000<0003oooooool07_ooo`03o`2Ioooooooo05[oool008ooool200004C?o
00030000oooooooo01koool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`0043?o00030000
oooooooo01koool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`003c?o00030000oooooooo
01ooool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`003c?o00030000oooooooo01ooool0
0ol0VOooooooo`1Joooo002?oooo00<0000co`0co`003c?o00030000oooooooo01ooool00ol0VOoo
ooooo`1Joooo002?oooo00<0000co`0co`003c?o00030000oooooooo01ooool00ol0VOooooooo`1J
oooo002?oooo0P00010co`000`000?ooooooo`0Ooooo00?o09Woooooool0F_ooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`0Poooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0Poooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`0Poooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`0Poooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0P
oooo00?o09Woooooool0F_ooo`00Soooo`80000><ol000<0003oooooool08Oooo`03o`2Ioooooooo
05[oool008ooool00`0003?o03?o000=<ol000<0003oooooool08Oooo`03o`2Ioooooooo05[oool0
08ooool00`0003?o03?o000=<ol000<0003oooooool08Oooo`03o`2Ioooooooo05[oool008ooool0
0`0003?o03?o000=<ol000<0003oooooool08Oooo`03o`2Ioooooooo05[oool008ooool00`0003?o
03?o000<<ol000<0003oooooool08_ooo`03o`2Ioooooooo05[oool008Woool300000oooo`030000
<ol0<ol000`co`000`000?ooooooo`0Roooo00?o09Woooooool0F_ooo`00R_ooo`030000oooooooo
00;oool00`0003?o03?o000<<ol000<0003oooooool08_ooo`03o`2Ioooooooo05[oool008Ooool5
00000oooo`<0000<<ol000<0003oooooool08_ooo`03o`2Ioooooooo05[oool008Ooool010000?oo
ooooo`0000Coool?<ol0P_ooo`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004
oooo3c?o08;oool008ooool?<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0003oooooool04ooo
o`hco`07oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09
oooo3S?o00Soool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01oooo`800004<ol00P0000Dco`0300000_ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002c?o00040000<ol0oooo00000_ooo`050000oooooooooooo000007[oool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo000023?o00D00003
oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?oo
o`040000oooooooo000023?o00050000<ol0<ol00000<ol000Coool01@000?ooooooooooo`00001j
oooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002C?o00030000<ol00000
00;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Ooo
o`80000;<ol00P0000?oool200000oooo`030000oooooooo07Woool008ooool=<ol0Q?ooo`00Sooo
o`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.69774 .12361 L
.7026 .12361 L
.70516 .12361 L
.70656 .12361 L
.70787 .12361 L
.70901 .12361 L
s
.70901 .12361 m
.7095 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28302 .12361 L
.28542 .12361 L
.288 .12361 L
.28876 .12361 L
.28948 .12361 L
.29013 .12361 L
.29083 .12342 L
.2915 .12308 L
.29221 .12271 L
.29349 .12206 L
.30316 .11728 L
.34474 .09985 L
.3848 .08717 L
.42335 .07807 L
.4429 .07444 L
.46436 .07112 L
.50385 .06656 L
.54427 .06199 L
.58318 .05696 L
.62454 .0514 L
.66438 .04616 L
.6826 .04388 L
.69298 .04262 L
.69806 .04201 L
.70271 .04147 L
.70512 .04119 L
.70735 .04093 L
.70848 .04081 L
.70968 .12361 L
.71037 .12361 L
.71102 .12361 L
.71223 .12361 L
.72249 .12361 L
.7435 .12361 L
.78196 .12361 L
.82288 .12361 L
.86228 .12361 L
.90017 .12361 L
.94051 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo03;oool00`1Vooooooooo`1Ioooo002?oooo00<0
003oooooool0:_ooo`T0I_mKoooo002?oooo00<0003oooooool08oooo`L0I_l8oooo00<0I_oooooo
ool0FOooo`00Soooo`80000Loooo201Vo`ooool00`1Vooooooooo`1Ioooo002?oooo00<0003ooooo
ool05Oooo`H0I_lGoooo00<0I_ooooooool0FOooo`00Soooo`030000oooooooo00koool706Ko7Ooo
o`0306Kooooooooo05Woool008ooool00`000?ooooooo`04oooo2P1VobCoool00`1Vooooooooo`1I
oooo002<oooo0`1Vo`03000006Ko06Ko00@0I_l^oooo00<0I_ooooooool0FOooo`00Q?ooo`P0I_l3
oooo00<0003oooooool0<_ooo`0306Kooooooooo05Woool007ooool506Ko2oooo`80000coooo00<0
I_ooooooool0FOooo`005oooo`D0000coooo0P0000Coool200001?ooo`80000Moooo1@1Voa3oool0
0`000?ooooooo`0boooo0P0000Coool200001?ooo`80000doooo1@0001Goool001Woool00`000?oo
ooooo`0boooo00@0003oooooool00008oooo00@0003oooooool0000Goooo1@1VoaGoool00`000?oo
ooooo`0aoooo00@00000I_ooool00008oooo00@0003oooooool0000eoooo00<0003oooooool05Ooo
o`006Oooo`030000oooooooo03;oool010000?ooooooo`0000_oool00`000?ooooooo`0Aoooo101V
oa[oool00`000?ooooooo`0aoooo00@00000I_ooool0000;oooo00<0003oooooool0<oooo`030000
oooooooo01Goool0017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo
00002Oooo`80000Aoooo0`1Voakoool00`000?ooooooo`0aoooo00@00000I_ooool00009oooo0P00
03Koool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002Ooo
o`030000oooooooo00coool406Ko8Oooo`030000oooooooo037oool01000001Vooooo`0000Woool0
0`000?ooooooo`0eoooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P0000[oool300002Ooo
o`<0I_lUoooo0P0003?oool200002_ooo`<0000doooo0P0001Ooool006Goool206Ko:?ooo`030000
oooooooo03;oool00`1Vooooooooo`1Ioooo001Soooo0P1Vob[oool00`000?ooooooo`0boooo00<0
I_ooooooool0FOooo`00HOooo`80I_l/oooo00<0003oooooool0<_ooo`0306Kooooooooo05Woool0
05ooool206Ko;_ooo`030000oooooooo03;oool00`1Vooooooooo`1Ioooo001Moooo0P1Voc3oool0
0`000?ooooooo`0boooo00<0I_ooooooool0FOooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0002<ol000?o09Tco`0c
o`0013?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002S?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0ioooo00<0000co`0co`00<S?o0003o`2I<ol0<ol000@co`000`0003?o
03?o000f<ol01@0001Ooool008ooool00`0003?o03?o000b<ol000?o09Tco`0co`00=C?o00P0000L
oooo002?oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol002lco`0600009?ooo`00Soooo`030000
<ol0<ol0038co`000ol0VC?o03?o000Z<ol01@0002[oool008ooool00`0003?o03?o000b<ol000?o
09Tco`0co`009C?o00D0000_oooo002?oooo0P0003<co`000ol0VC?o03?o000P<ol01@0003Coool0
08ooool00`0003?o03?o000b<ol000?o09Tco`0co`0073?o00@0000ioooo002?oooo00<0000co`0c
o`00<S?o0003o`2I<ol0<ol001Xco`020000?Oooo`00Soooo`030000<ol0<ol0038co`000ol0VC?o
03?o000G<ol00`0003ooool008ooool00`0003?o03?o000b<ol000?o09Tco`0co`005C?o00800012
oooo002?oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol001<co`020000A?ooo`00Soooo`80000c
<ol000?o09Tco`0co`004C?o00800016oooo002?oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol0
00lco`020000B?ooo`00Soooo`030000<ol0<ol0038co`000ol0VC?o03?o000><ol000<0003ooooo
ool0B?ooo`00Soooo`030000<ol0<ol0038co`000ol0VC?o03?o000<<ol00P0004_oool008ooool0
0`0003?o03?o000b<ol000?o09Tco`0co`002S?o0080001=oooo002?oooo00<0000co`0co`00<S?o
0003o`2I<ol0<ol000Tco`000`000?ooooooo`1=oooo002?oooo0P0003<co`000ol0VC?o03?o0007
<ol00P00053oool008ooool00`0003?o03?o000b<ol000?o09Tco`0co`001C?o0080001Boooo002?
oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1Boooo002?oooo00<0
000co`0co`00<S?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1Coooo002?oooo00<0000co`0c
o`00<S?o0004o`2I<ol0<ol0<ol00P0005Koool008ooool00`0003?o03?o000b<ol000Co09Tco`0c
o`00001Hoooo002?oooo0P0003<co`000ol0VC?o0000001Ioooo002?oooo00<0000co`0co`00<S?o
0003o`2I0000oooo05Woool008ooool00`0003?o03?o000b<ol000?o09Woooooool0FOooo`00Sooo
o`030000<ol0<ol0034co`000`000?l0VOooo`1Joooo002?oooo00<0000co`0co`00<C?o00030000
o`2Ioooo05[oool008Ooool500000oooo`030000<ol0<ol0030co`000`000?ooool0V@1Koooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol002lco`0010000?ooooooool0VE_oool008Woool0
0`000?ooooooo`03oooo0`0002hco`001@000?ooooooooooool0V@1Koooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol002hco`001@000?ooooooooooool0V@1Koooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol002dco`000`000?ooooooo`02oooo00?o09Woooooool0FOooo`00R?oo
o`800005oooo00<0000co`0co`00;3?o00030000oooooooo00?oool00ol0VOooooooo`1Ioooo002?
oooo00<0000co`0co`00:c?o00030000oooooooo00Coool00ol0VOooooooo`1Ioooo002?oooo00<0
000co`0co`00:c?o00030000oooooooo00Coool00ol0VOooooooo`1Ioooo002?oooo0P0002/co`00
0`000?ooooooo`05oooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol002Tco`000`000?oo
ooooo`06oooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol002Tco`000`000?ooooooo`06
oooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol002Pco`000`000?ooooooo`07oooo00?o
09Woooooool0FOooo`00Soooo`030000<ol0<ol002Lco`000`000?ooooooo`08oooo00?o09Wooooo
ool0FOooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`09oooo00?o09Woooooool0FOoo
o`00Soooo`80000W<ol000<0003oooooool02Oooo`03o`2Ioooooooo05Woool008ooool00`0003?o
03?o000U<ol000<0003oooooool02_ooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000T
<ol000<0003oooooool02oooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000T<ol000<0
003oooooool02oooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000S<ol000<0003ooooo
ool03?ooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000S<ol000<0003oooooool03?oo
o`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000R<ol000<0003oooooool03Oooo`03o`2I
oooooooo05Woool008ooool200008c?o00030000oooooooo00goool00ol0VOooooooo`1Ioooo002?
oooo00<0000co`0co`008C?o00030000oooooooo00koool00ol0VOooooooo`1Ioooo002?oooo00<0
000co`0co`008C?o00030000oooooooo00koool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0c
o`0083?o00030000oooooooo00ooool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`0083?o
00030000oooooooo00ooool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`0083?o00030000
oooooooo00ooool00ol0VOooooooo`1Ioooo002?oooo0P00020co`000`000?ooooooo`0@oooo00?o
09Woooooool0FOooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0@oooo00?o09Wooooo
ool0FOooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0Aoooo00?o09Woooooool0FOoo
o`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0Aoooo00?o09Woooooool0FOooo`00Qooo
o`@00004oooo00<0000co`0co`007S?o00030000oooooooo017oool00ol0VOooooooo`1Ioooo0027
oooo00<0003oooooool01Oooo`030000<ol0<ol001dco`000`000?ooooooo`0Boooo00?o09Wooooo
ool0FOooo`00R?ooo`030000oooooooo00Coool300007C?o00030000oooooooo01;oool00ol0VOoo
ooooo`1Ioooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0B
oooo00?o09Woooooool0FOooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001`co`00
0`000?ooooooo`0Coooo00?o09Woooooool0FOooo`00R?ooo`800005oooo00<0000co`0co`0073?o
00030000oooooooo01?oool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`006c?o00030000
oooooooo01Coool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`006c?o00030000oooooooo
01Coool00ol0VOooooooo`1Ioooo002?oooo0P0001`co`000`000?ooooooo`0Doooo00?o09Wooooo
ool0FOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0FOoo
o`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0FOooo`00Sooo
o`030000<ol0<ol001Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0FOooo`00Soooo`030000
<ol0<ol001Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol0
01Tco`000`000?ooooooo`0Foooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol001Tco`00
0`000?ooooooo`0Foooo00?o09Woooooool0FOooo`00Soooo`80000J<ol000<0003oooooool05_oo
o`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000H<ol000<0003oooooool05oooo`03o`2I
oooooooo05Woool008ooool00`0003?o03?o000H<ol000<0003oooooool05oooo`03o`2Ioooooooo
05Woool008ooool00`0003?o03?o000H<ol000<0003oooooool05oooo`03o`2Ioooooooo05Woool0
08ooool00`0003?o03?o000G<ol000<0003oooooool06?ooo`03o`2Ioooooooo05Woool008ooool0
0`0003?o03?o000G<ol000<0003oooooool06?ooo`03o`2Ioooooooo05Woool008ooool2000063?o
00030000oooooooo01Soool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`005c?o00030000
oooooooo01Soool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`005S?o00030000oooooooo
01Woool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`005S?o00030000oooooooo01Woool0
0ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`005S?o00030000oooooooo01Woool00ol0VOoo
ooooo`1Ioooo002?oooo00<0000co`0co`005C?o00030000oooooooo01[oool00ol0VOooooooo`1I
oooo002?oooo0P0001Hco`000`000?ooooooo`0Joooo00?o09Woooooool0FOooo`00Soooo`030000
<ol0<ol001Dco`000`000?ooooooo`0Joooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0Joooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol001@co`00
0`000?ooooooo`0Koooo00?o09Woooooool0FOooo`00R?ooo`800005oooo00<0000co`0co`0053?o
00030000oooooooo01_oool00ol0VOooooooo`1Ioooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0053?o00030000oooooooo01_oool00ol0VOooooooo`1Ioooo0029oooo00<0003ooooo
ool00oooo`<0000C<ol000<0003oooooool07?ooo`03o`2Ioooooooo05Woool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`004c?o00030000oooooooo01coool00ol0VOooooooo`1Ioooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`004c?o00030000oooooooo01coool00ol0VOoo
ooooo`1Ioooo0028oooo0P0000Goool00`0003?o03?o000B<ol000<0003oooooool07Oooo`03o`2I
oooooooo05Woool008ooool00`0003?o03?o000B<ol000<0003oooooool07Oooo`03o`2Ioooooooo
05Woool008ooool00`0003?o03?o000B<ol000<0003oooooool07Oooo`03o`2Ioooooooo05Woool0
08ooool00`0003?o03?o000B<ol000<0003oooooool07Oooo`03o`2Ioooooooo05Woool008ooool2
00004S?o00030000oooooooo01koool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`004C?o
00030000oooooooo01koool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`004C?o00030000
oooooooo01koool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`004C?o00030000oooooooo
01koool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`0043?o00030000oooooooo01ooool0
0ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`0043?o00030000oooooooo01ooool00ol0VOoo
ooooo`1Ioooo002?oooo0P00014co`000`000?ooooooo`0Ooooo00?o09Woooooool0FOooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0Ooooo00?o09Woooooool0FOooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0Poooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooooooo`0Poooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`0Poooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`0Poooo00?o09Woooooool0FOooo`00Soooo`80000@<ol000<0003oooooool08?ooo`03o`2I
oooooooo05Woool008ooool00`0003?o03?o000><ol000<0003oooooool08Oooo`03o`2Ioooooooo
05Woool008ooool00`0003?o03?o000><ol000<0003oooooool08Oooo`03o`2Ioooooooo05Woool0
08ooool00`0003?o03?o000><ol000<0003oooooool08Oooo`03o`2Ioooooooo05Woool008ooool0
0`0003?o03?o000><ol000<0003oooooool08Oooo`03o`2Ioooooooo05Woool008ooool00`0003?o
03?o000><ol000<0003oooooool08Oooo`03o`2Ioooooooo05Woool008ooool200003S?o00030000
oooooooo02;oool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`003C?o00030000oooooooo
02;oool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`003C?o00030000oooooooo02;oool0
0ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`003C?o00030000oooooooo02;oool00ol0VOoo
ooooo`1Ioooo002?oooo00<0000co`0co`0033?o00030000oooooooo02?oool00ol0VOooooooo`1I
oooo0029oooo0`0000?oool00`0003?o03?o000<<ol000<0003oooooool08oooo`03o`2Ioooooooo
05Woool008[oool00`000?ooooooo`02oooo00<0000co`0co`0033?o00030000oooooooo02?oool0
0ol0VOooooooo`1Ioooo0027oooo1@0000?oool3000033?o00030000oooooooo02?oool00ol0VOoo
ooooo`1Ioooo0027oooo00@0003oooooool00004oooo3c?o08;oool008Soool00`000?ooo`000004
oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o08;oool008ooool?<ol0P_oo
o`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o00800005<ol00`0000?oool3
00000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool010000?ooooooo`0000/co`000`0003?o0?ooo`03oooo00D0
003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00008<ol01@000003oooo0000000000<00003oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000<oooo00@0003oooooool00008<ol000L0000co`0co`00000co`3oool0
00000_ooo`050000oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00009<ol000<0000co`0000000oooo`030000oooo000000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`80000;<ol00P0000Coool200000_ooo`030000oooooooo
07Woool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.69774 .12361 L
.7026 .12361 L
.70787 .12361 L
.71028 .12361 L
.7116 .12361 L
.71284 .12361 L
.71389 .12361 L
s
.71389 .12361 m
.71434 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28025 .12361 L
.28302 .12361 L
.28425 .12361 L
.28542 .12361 L
.28606 .12343 L
.28676 .12306 L
.288 .12243 L
.29349 .11967 L
.30316 .11504 L
.3438 .09848 L
.38293 .08639 L
.42451 .07691 L
.44538 .07324 L
.46458 .07044 L
.50313 .0662 L
.54262 .06193 L
.58059 .05716 L
.62101 .05182 L
.65992 .04674 L
.67973 .04425 L
.69018 .04297 L
.70128 .04166 L
.70602 .04111 L
.71112 .04053 L
.71254 .04037 L
.71332 .04028 L
.71404 .0402 L
.71532 .12361 L
.716 .12361 L
.71672 .12361 L
.72198 .12361 L
.74113 .12361 L
.78263 .12361 L
.82261 .12361 L
.86107 .12361 L
.90199 .12361 L
.9414 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo037oool306KoF_ooo`00Soooo`030000oooooooo
02Woool806Ko0_ooo`0306Kooooooooo05Soool008ooool00`000?ooooooo`0Roooo1`1Vo`[oool0
0`1Vooooooooo`1Hoooo002?oooo0P0001_oool806Ko4Oooo`0306Kooooooooo05Soool008ooool0
0`000?ooooooo`0Doooo1P1VoaWoool00`1Vooooooooo`1Hoooo002?oooo00<0003oooooool03Ooo
o`L0I_lOoooo00<0I_ooooooool0F?ooo`00Soooo`030000oooooooo00Coool906Ko9_ooo`0306Ko
oooooooo05Soool008coool306Ko00<00000I_l0I_l0101Vobooool00`1Vooooooooo`1Hoooo0024
oooo201Vo`?oool00`000?ooooooo`0coooo00<0I_ooooooool0F?ooo`00Ooooo`D0I_l;oooo0P00
03Coool00`1Vooooooooo`1Hoooo000Goooo1@0003?oool200001?ooo`800004oooo0P0001goool5
06Ko4?ooo`030000oooooooo03;oool200001?ooo`800004oooo0P0003Coool500005Oooo`006Ooo
o`030000oooooooo03;oool010000?ooooooo`0000Soool010000?ooooooo`0001Koool606Ko5Ooo
o`030000oooooooo037oool010000?ooooooo`0000Soool010000?ooooooo`0003Goool00`000?oo
ooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002oooo`030000oooooooo
013oool406Ko6oooo`030000oooooooo037oool010000?ooooooo`0000_oool00`000?ooooooo`0c
oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool0;?ooo`@00002oooo00@0
003oooooool00009oooo0P00013oool306Ko7oooo`030000oooooooo037oool010000?ooooooo`00
00Woool20000=_ooo`030000oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003ooooo
ool00009oooo00<0003oooooool02oooo`@0I_lRoooo00<0003oooooool0<Oooo`040000oooooooo
00002Oooo`030000oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_oo
o`<00008oooo0`1VobKoool20000<oooo`8000000`1Vooooooooo`07oooo0`0003Coool200005ooo
o`00I?ooo`80I_lYoooo00<0003oooooool0=?ooo`0306Kooooooooo05Ooool0067oool306Ko:ooo
o`030000oooooooo03Coool00`1Vooooooooo`1Goooo001Ooooo0P1Vobkoool00`000?ooooooo`0d
oooo00<0I_ooooooool0Eoooo`00GOooo`80I_l`oooo00<0003oooooool0=?ooo`0306Kooooooooo
05Ooool005_oool206Ko<_ooo`030000oooooooo03Coool00`1Vooooooooo`1Goooo000@ooooo`00
017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000<co`000ol0VC?o03?o0003<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000c<ol000?o
09Tco`0co`000c?o00030000<ol0<ol003Hco`0500005oooo`00Soooo`030000<ol0<ol003<co`00
0ol0VC?o03?o000d<ol0200001coool008ooool00`0003?o03?o000c<ol000?o09Tco`0co`00;S?o
00H0000Toooo002?oooo00<0000co`0co`00<c?o0003o`2I<ol0<ol002Tco`050000:_ooo`00Sooo
o`030000<ol0<ol003<co`000ol0VC?o03?o000T<ol01@0002ooool008ooool20000=3?o0003o`2I
<ol0<ol001lco`050000=?ooo`00Soooo`030000<ol0<ol003<co`000ol0VC?o03?o000K<ol01000
03Woool008ooool00`0003?o03?o000c<ol000?o09Tco`0co`006C?o0080000moooo002?oooo00<0
000co`0co`00<c?o0003o`2I<ol0<ol001Hco`030000?oooo`00Soooo`030000<ol0<ol003<co`00
0ol0VC?o03?o000D<ol00P0004;oool008ooool00`0003?o03?o000c<ol000?o09Tco`0co`004S?o
00800014oooo002?oooo0P0003@co`000ol0VC?o03?o000@<ol00P0004Koool008ooool00`0003?o
03?o000c<ol000?o09Tco`0co`003S?o00800018oooo002?oooo00<0000co`0co`00<c?o0003o`2I
<ol0<ol000dco`000`000?ooooooo`18oooo002?oooo00<0000co`0co`00<c?o0003o`2I<ol0<ol0
00/co`020000Boooo`00Soooo`030000<ol0<ol003<co`000ol0VC?o03?o0009<ol00P0004goool0
08ooool00`0003?o03?o000c<ol000?o09Tco`0co`0023?o00030000oooooooo04goool008ooool2
0000=3?o0003o`2I<ol0<ol000Hco`020000D?ooo`00Soooo`030000<ol0<ol003<co`000ol0VC?o
03?o0004<ol00P0005;oool008ooool00`0003?o03?o000c<ol000?o09Tco`0co`000c?o00030000
oooooooo05;oool008ooool00`0003?o03?o000c<ol000?o09Tco`0co`000S?o00030000oooooooo
05?oool008ooool00`0003?o03?o000c<ol000?o09Tco`0co`000P0005Koool008ooool00`0003?o
03?o000c<ol000?o09Tco`000000F?ooo`00Soooo`80000d<ol000?o09T0003oool0F?ooo`00Sooo
o`030000<ol0<ol003<co`000ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`00<S?o00030000
o`2Ioooo05Woool008ooool00`0003?o03?o000a<ol000<0003ooooo09T0F_ooo`00Soooo`030000
<ol0<ol0034co`000`000?ooool0V@1Joooo0027oooo1@0000?oool00`0003?o03?o000`<ol000@0
003ooooooooo09UJoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol002lco`001@000?oo
ooooooooool0V@1Joooo0029oooo00<0003oooooool00oooo`<0000^<ol000<0003oooooool00_oo
o`03o`2Ioooooooo05Soool008Woool00`000?ooooooo`03oooo00<0000co`0co`00;S?o00030000
oooooooo00;oool00ol0VOooooooo`1Hoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
02dco`000`000?ooooooo`03oooo00?o09Woooooool0F?ooo`00R?ooo`800005oooo00<0000co`0c
o`00;3?o00030000oooooooo00Coool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`00:c?o
00030000oooooooo00Goool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`00:c?o00030000
oooooooo00Goool00ol0VOooooooo`1Hoooo002?oooo0P0002/co`000`000?ooooooo`06oooo00?o
09Woooooool0F?ooo`00Soooo`030000<ol0<ol002Tco`000`000?ooooooo`07oooo00?o09Wooooo
ool0F?ooo`00Soooo`030000<ol0<ol002Tco`000`000?ooooooo`07oooo00?o09Woooooool0F?oo
o`00Soooo`030000<ol0<ol002Pco`000`000?ooooooo`08oooo00?o09Woooooool0F?ooo`00Sooo
o`030000<ol0<ol002Lco`000`000?ooooooo`09oooo00?o09Woooooool0F?ooo`00Soooo`030000
<ol0<ol002Hco`000`000?ooooooo`0:oooo00?o09Woooooool0F?ooo`00Soooo`80000W<ol000<0
003oooooool02_ooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000U<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000T<ol000<0003oooooool03?oo
o`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000T<ol000<0003oooooool03?ooo`03o`2I
oooooooo05Soool008ooool00`0003?o03?o000S<ol000<0003oooooool03Oooo`03o`2Ioooooooo
05Soool008ooool00`0003?o03?o000S<ol000<0003oooooool03Oooo`03o`2Ioooooooo05Soool0
08ooool00`0003?o03?o000R<ol000<0003oooooool03_ooo`03o`2Ioooooooo05Soool008ooool2
00008c?o00030000oooooooo00koool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`008C?o
00030000oooooooo00ooool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`008C?o00030000
oooooooo00ooool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`0083?o00030000oooooooo
013oool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`0083?o00030000oooooooo013oool0
0ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`0083?o00030000oooooooo013oool00ol0VOoo
ooooo`1Hoooo002?oooo0P00020co`000`000?ooooooo`0Aoooo00?o09Woooooool0F?ooo`00Sooo
o`030000<ol0<ol001lco`000`000?ooooooo`0Aoooo00?o09Woooooool0F?ooo`00Soooo`030000
<ol0<ol001hco`000`000?ooooooo`0Boooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol0
01hco`000`000?ooooooo`0Boooo00?o09Woooooool0F?ooo`00Qoooo`@00004oooo00<0000co`0c
o`007S?o00030000oooooooo01;oool00ol0VOooooooo`1Hoooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol001dco`000`000?ooooooo`0Coooo00?o09Woooooool0F?ooo`00R?ooo`030000
oooooooo00Coool300007C?o00030000oooooooo01?oool00ol0VOooooooo`1Hoooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol001dco`000`000?ooooooo`0Coooo00?o09Woooooool0F?oo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol001`co`000`000?ooooooo`0Doooo00?o
09Woooooool0F?ooo`00R?ooo`800005oooo00<0000co`0co`0073?o00030000oooooooo01Coool0
0ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`006c?o00030000oooooooo01Goool00ol0VOoo
ooooo`1Hoooo002?oooo00<0000co`0co`006c?o00030000oooooooo01Goool00ol0VOooooooo`1H
oooo002?oooo0P0001`co`000`000?ooooooo`0Eoooo00?o09Woooooool0F?ooo`00Soooo`030000
<ol0<ol001Xco`000`000?ooooooo`0Foooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol0
01Xco`000`000?ooooooo`0Foooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0Foooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0Foooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0G
oooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0Goooo00?o
09Woooooool0F?ooo`00Soooo`80000J<ol000<0003oooooool05oooo`03o`2Ioooooooo05Soool0
08ooool00`0003?o03?o000H<ol000<0003oooooool06?ooo`03o`2Ioooooooo05Soool008ooool0
0`0003?o03?o000H<ol000<0003oooooool06?ooo`03o`2Ioooooooo05Soool008ooool00`0003?o
03?o000H<ol000<0003oooooool06?ooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000G
<ol000<0003oooooool06Oooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000G<ol000<0
003oooooool06Oooo`03o`2Ioooooooo05Soool008ooool2000063?o00030000oooooooo01Woool0
0ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`005c?o00030000oooooooo01Woool00ol0VOoo
ooooo`1Hoooo002?oooo00<0000co`0co`005S?o00030000oooooooo01[oool00ol0VOooooooo`1H
oooo002?oooo00<0000co`0co`005S?o00030000oooooooo01[oool00ol0VOooooooo`1Hoooo002?
oooo00<0000co`0co`005S?o00030000oooooooo01[oool00ol0VOooooooo`1Hoooo002?oooo00<0
000co`0co`005C?o00030000oooooooo01_oool00ol0VOooooooo`1Hoooo002?oooo0P0001Hco`00
0`000?ooooooo`0Koooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol001Dco`000`000?oo
ooooo`0Koooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol001Dco`000`000?ooooooo`0K
oooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`0Loooo00?o
09Woooooool0F?ooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo01coool0
0ol0VOooooooo`1Hoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0053?o00030000
oooooooo01coool00ol0VOooooooo`1Hoooo0029oooo00<0003oooooool00oooo`<0000C<ol000<0
003oooooool07Oooo`03o`2Ioooooooo05Soool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`004c?o00030000oooooooo01goool00ol0VOooooooo`1Hoooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`004c?o00030000oooooooo01goool00ol0VOooooooo`1Hoooo0028oooo0P00
00Goool00`0003?o03?o000B<ol000<0003oooooool07_ooo`03o`2Ioooooooo05Soool008ooool0
0`0003?o03?o000B<ol000<0003oooooool07_ooo`03o`2Ioooooooo05Soool008ooool00`0003?o
03?o000B<ol000<0003oooooool07_ooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000B
<ol000<0003oooooool07_ooo`03o`2Ioooooooo05Soool008ooool200004S?o00030000oooooooo
01ooool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`004C?o00030000oooooooo01ooool0
0ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`004C?o00030000oooooooo01ooool00ol0VOoo
ooooo`1Hoooo002?oooo00<0000co`0co`004C?o00030000oooooooo01ooool00ol0VOooooooo`1H
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo023oool00ol0VOooooooo`1Hoooo002?
oooo00<0000co`0co`0043?o00030000oooooooo023oool00ol0VOooooooo`1Hoooo002?oooo0P00
014co`000`000?ooooooo`0Poooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`0Poooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`0Qoooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Q
oooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Qoooo00?o
09Woooooool0F?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Qoooo00?o09Wooooo
ool0F?ooo`00Soooo`80000@<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Soool008ooool0
0`0003?o03?o000><ol000<0003oooooool08_ooo`03o`2Ioooooooo05Soool008ooool00`0003?o
03?o000><ol000<0003oooooool08_ooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000>
<ol000<0003oooooool08_ooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000><ol000<0
003oooooool08_ooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000><ol000<0003ooooo
ool08_ooo`03o`2Ioooooooo05Soool008ooool200003S?o00030000oooooooo02?oool00ol0VOoo
ooooo`1Hoooo002?oooo00<0000co`0co`003C?o00030000oooooooo02?oool00ol0VOooooooo`1H
oooo002?oooo00<0000co`0co`003C?o00030000oooooooo02?oool00ol0VOooooooo`1Hoooo002?
oooo00<0000co`0co`003C?o00030000oooooooo02?oool00ol0VOooooooo`1Hoooo002?oooo00<0
000co`0co`0033?o00030000oooooooo02Coool00ol0VOooooooo`1Hoooo0029oooo0`0000?oool0
0`0003?o03?o000<<ol000<0003oooooool09?ooo`03o`2Ioooooooo05Soool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0033?o00030000oooooooo02Coool00ol0VOooooooo`1Hoooo0027
oooo1@0000?oool3000033?o00030000oooooooo02Coool00ol0VOooooooo`1Hoooo0027oooo00@0
003oooooool00004oooo3c?o08;oool008Soool00`000?ooo`000004oooo3c?o08;oool008Woool2
00001?ooo`lco`22oooo002?oooo3c?o08;oool008ooool?<ol0P_ooo`00NOooo`030000oooooooo
01?oool><ol01oooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`hco`08oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Ooool2000013?o00800005<ol00`0000;oool200001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000/co`00100003?o0?ooo`0000;oool01@000?ooooooooooo`00001j
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Pco`05
00001?ooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00coool010000?ooooooo`0000Pco`001@0003?o03?o000003?o0002oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002C?o00030000
<ol0000000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
017oool200002c?o00800003oooo0`0000;oool00`000?ooooooo`1ioooo002?oooo3C?o08Coool0
08ooool=<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.70787 .12361 L
.71284 .12361 L
.71502 .12361 L
.71741 .12361 L
.71805 .12361 L
.71874 .12361 L
s
.71874 .12361 m
.71924 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.26171 .12361 L
.26709 .12361 L
.27279 .12361 L
.27765 .12361 L
.27899 .12361 L
.27972 .12361 L
.28042 .12361 L
.28107 .12355 L
.28178 .12318 L
.28302 .12254 L
.30316 .11286 L
.3438 .09682 L
.38293 .08514 L
.42451 .07601 L
.44538 .0725 L
.46458 .06982 L
.50313 .06579 L
.54262 .06169 L
.58059 .05704 L
.62101 .05179 L
.65992 .04675 L
.67973 .04428 L
.69018 .04301 L
.70128 .0417 L
.71112 .04057 L
.71382 .04026 L
.71523 .04011 L
.71672 .03994 L
.71803 .0398 L
.71877 .03971 L
.71946 .12361 L
.72068 .12361 L
.72198 .12361 L
.74113 .12361 L
.78263 .12361 L
.82261 .12361 L
.86107 .12361 L
.90199 .12361 L
.9414 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo03;oool306KoFOooo`00Soooo`030000oooooooo
02Woool906Ko0_ooo`0306Kooooooooo05Ooool008ooool00`000?ooooooo`0Roooo1`1Vo`_oool0
0`1Vooooooooo`1Goooo002?oooo0P0001_oool806Ko4_ooo`0306Kooooooooo05Ooool008ooool0
0`000?ooooooo`0Doooo1P1Voa[oool00`1Vooooooooo`1Goooo002?oooo00<0003oooooool03Ooo
o`L0I_lPoooo00<0I_ooooooool0Eoooo`00Soooo`030000oooooooo00Coool906Ko9oooo`0306Ko
oooooooo05Ooool008coool306Ko00<00000I_l0I_l0101Voc3oool00`1Vooooooooo`1Goooo001o
oooo3@1Vo`?oool00`000?ooooooo`0doooo00<0I_ooooooool0Eoooo`00Noooo`@0I_l@oooo0P00
03Goool00`1Vooooooooo`1Goooo000Goooo1@0003?oool200001?ooo`800004oooo0P0001[oool4
06Ko5?ooo`030000oooooooo03;oool2000000@0I_ooooooooooool200001?ooo`80000doooo1@00
01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00008oooo00@0003oooooool0000E
oooo101VoaSoool00`000?ooooooo`0aoooo00D0003oooooool00000I_l01oooo`040000oooooooo
0000=Oooo`030000oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool0000;
oooo00<0003oooooool04?ooo`<0I_lLoooo00<0003oooooool0<Oooo`050000oooooooo000006Ko
00[oool00`000?ooooooo`0coooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003ooooo
ool0;?ooo`@00002oooo00@0003oooooool00009oooo0P00013oool306Ko7oooo`030000oooooooo
037oool01@000?ooooooo`00001Vo`08oooo0P0003Koool00`000?ooooooo`0Eoooo000Ioooo00<0
003oooooool0<_ooo`040000oooooooo00002Oooo`030000oooooooo00_oool406Ko8_ooo`030000
oooooooo037oool01@000?ooooooo`00001Vo`08oooo00<0003oooooool0=Oooo`030000oooooooo
01Goool001Soool20000=Oooo`80000:oooo0`0000Soool306Ko9_ooo`80000coooo0P000003oooo
06Kooooo00Ooool30000=?ooo`80000Goooo001Toooo0P1VobWoool00`000?ooooooo`0eoooo00<0
I_ooooooool0E_ooo`00HOooo`<0I_l[oooo00<0003oooooool0=Oooo`0306Kooooooooo05Koool0
05ooool206Ko;_ooo`030000oooooooo03Goool00`1Vooooooooo`1Foooo001Loooo0`1Voc3oool0
0`000?ooooooo`0eoooo00<0I_ooooooool0E_ooo`00F_ooo`80I_lcoooo00<0003oooooool0=Ooo
o`0306Kooooooooo05Koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`0013?o0003o`2I<ol0<ol0008co`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Xco`000`0003?o03?o0009<ol000<0
000co`0co`002C?o00030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0>Oooo`030000<ol0<ol003@co`000ol0VC?o03?o0002<ol000<0000co`0co`00=S?o00D0000G
oooo002?oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol003<co`0800007?ooo`00Soooo`030000
<ol0<ol003@co`000ol0VC?o03?o000]<ol01P0002Coool008ooool00`0003?o03?o000d<ol000?o
09Tco`0co`00:3?o00D0000Zoooo002?oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol002<co`05
0000;oooo`00Soooo`80000e<ol000?o09Tco`0co`007S?o00D0000doooo002?oooo00<0000co`0c
o`00=3?o0003o`2I<ol0<ol001Xco`040000>Oooo`00Soooo`030000<ol0<ol003@co`000ol0VC?o
03?o000H<ol00P0003goool008ooool00`0003?o03?o000d<ol000?o09Tco`0co`005C?o00<0000o
oooo002?oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol001<co`020000@_ooo`00Soooo`030000
<ol0<ol003@co`000ol0VC?o03?o000A<ol00P0004Coool008ooool20000=C?o0003o`2I<ol0<ol0
00lco`020000A_ooo`00Soooo`030000<ol0<ol003@co`000ol0VC?o03?o000=<ol00P0004Soool0
08ooool00`0003?o03?o000d<ol000?o09Tco`0co`0033?o00030000oooooooo04Soool008ooool0
0`0003?o03?o000d<ol000?o09Tco`0co`002S?o0080001;oooo002?oooo00<0000co`0co`00=3?o
0003o`2I<ol0<ol000Pco`020000COooo`00Soooo`030000<ol0<ol003@co`000ol0VC?o03?o0007
<ol000<0003oooooool0COooo`00Soooo`80000e<ol000?o09Tco`0co`001C?o0080001@oooo002?
oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol000<co`020000D_ooo`00Soooo`030000<ol0<ol0
03@co`000ol0VC?o03?o0002<ol000<0003oooooool0D_ooo`00Soooo`030000<ol0<ol003@co`00
1Ol0VC?o03?o03?o0000001Eoooo002?oooo00<0000co`0co`00=3?o0004o`2I<ol000000000E_oo
o`00Soooo`030000<ol0<ol003@co`000ol0V@000?ooo`1Goooo002?oooo0P0003Dco`000ol0VOoo
ooooo`1Goooo002?oooo00<0000co`0co`00<c?o00030000o`2Ioooo05Soool008ooool00`0003?o
03?o000b<ol000<0003ooooo09T0FOooo`00Soooo`030000<ol0<ol0034co`0010000?ooooooool0
VEWoool008ooool00`0003?o03?o000a<ol000@0003ooooooooo09UIoooo0027oooo1@0000?oool0
0`0003?o03?o000`<ol000D0003ooooooooooooo09T0FOooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000_<ol000<0003oooooool00_ooo`03o`2Ioooooooo05Ooool008Woool00`000?oo
ooooo`03oooo0`0002hco`000`000?ooooooo`03oooo00?o09Woooooool0Eoooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000^<ol000<0003oooooool00oooo`03o`2Ioooooooo05Ooool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`00;C?o00030000oooooooo00Coool00ol0VOoo
ooooo`1Goooo0028oooo0P0000Goool00`0003?o03?o000/<ol000<0003oooooool01Oooo`03o`2I
oooooooo05Ooool008ooool00`0003?o03?o000[<ol000<0003oooooool01_ooo`03o`2Ioooooooo
05Ooool008ooool00`0003?o03?o000[<ol000<0003oooooool01_ooo`03o`2Ioooooooo05Ooool0
08ooool20000:c?o00030000oooooooo00Ooool00ol0VOooooooo`1Goooo002?oooo00<0000co`0c
o`00:C?o00030000oooooooo00Soool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`00:C?o
00030000oooooooo00Soool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`00:3?o00030000
oooooooo00Woool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`009c?o00030000oooooooo
00[oool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`009S?o00030000oooooooo00_oool0
0ol0VOooooooo`1Goooo002?oooo0P0002Lco`000`000?ooooooo`0;oooo00?o09Woooooool0Eooo
o`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`0<oooo00?o09Woooooool0Eoooo`00Sooo
o`030000<ol0<ol002@co`000`000?ooooooo`0=oooo00?o09Woooooool0Eoooo`00Soooo`030000
<ol0<ol002@co`000`000?ooooooo`0=oooo00?o09Woooooool0Eoooo`00Soooo`030000<ol0<ol0
02<co`000`000?ooooooo`0>oooo00?o09Woooooool0Eoooo`00Soooo`030000<ol0<ol002<co`00
0`000?ooooooo`0>oooo00?o09Woooooool0Eoooo`00Soooo`030000<ol0<ol0028co`000`000?oo
ooooo`0?oooo00?o09Woooooool0Eoooo`00Soooo`80000S<ol000<0003oooooool03oooo`03o`2I
oooooooo05Ooool008ooool00`0003?o03?o000Q<ol000<0003oooooool04?ooo`03o`2Ioooooooo
05Ooool008ooool00`0003?o03?o000Q<ol000<0003oooooool04?ooo`03o`2Ioooooooo05Ooool0
08ooool00`0003?o03?o000P<ol000<0003oooooool04Oooo`03o`2Ioooooooo05Ooool008ooool0
0`0003?o03?o000P<ol000<0003oooooool04Oooo`03o`2Ioooooooo05Ooool008ooool00`0003?o
03?o000P<ol000<0003oooooool04Oooo`03o`2Ioooooooo05Ooool008ooool2000083?o00030000
oooooooo01;oool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`007c?o00030000oooooooo
01;oool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`007S?o00030000oooooooo01?oool0
0ol0VOooooooo`1Goooo002?oooo00<0000co`0co`007S?o00030000oooooooo01?oool00ol0VOoo
ooooo`1Goooo0027oooo100000Coool00`0003?o03?o000N<ol000<0003oooooool04oooo`03o`2I
oooooooo05Ooool008Ooool00`000?ooooooo`05oooo00<0000co`0co`007C?o00030000oooooooo
01Coool00ol0VOooooooo`1Goooo0028oooo00<0003oooooool01?ooo`<0000M<ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo05Ooool008Woool00`000?ooooooo`03oooo00<0000co`0co`007C?o
00030000oooooooo01Goool00ol0VOooooooo`1Foooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0073?o00030000oooooooo01Koool00ol0VOooooooo`1Foooo0028oooo0P0000Goool0
0`0003?o03?o000L<ol000<0003oooooool05_ooo`03o`2Ioooooooo05Koool008ooool00`0003?o
03?o000K<ol000<0003oooooool05oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000K
<ol000<0003oooooool05oooo`03o`2Ioooooooo05Koool008ooool2000073?o00030000oooooooo
01Ooool00ol0VOooooooo`1Foooo002?oooo00<0000co`0co`006S?o00030000oooooooo01Soool0
0ol0VOooooooo`1Foooo002?oooo00<0000co`0co`006S?o00030000oooooooo01Soool00ol0VOoo
ooooo`1Foooo002?oooo00<0000co`0co`006S?o00030000oooooooo01Soool00ol0VOooooooo`1F
oooo002?oooo00<0000co`0co`006S?o00030000oooooooo01Soool00ol0VOooooooo`1Foooo002?
oooo00<0000co`0co`006C?o00030000oooooooo01Woool00ol0VOooooooo`1Foooo002?oooo00<0
000co`0co`006C?o00030000oooooooo01Woool00ol0VOooooooo`1Foooo002?oooo0P0001Xco`00
0`000?ooooooo`0Ioooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol001Pco`000`000?oo
ooooo`0Joooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0J
oooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0Joooo00?o
09Woooooool0E_ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Koooo00?o09Wooooo
ool0E_ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Koooo00?o09Woooooool0E_oo
o`00Soooo`80000H<ol000<0003oooooool06oooo`03o`2Ioooooooo05Koool008ooool00`0003?o
03?o000G<ol000<0003oooooool06oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000F
<ol000<0003oooooool07?ooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000F<ol000<0
003oooooool07?ooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000F<ol000<0003ooooo
ool07?ooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000E<ol000<0003oooooool07Ooo
o`03o`2Ioooooooo05Koool008ooool200005S?o00030000oooooooo01goool00ol0VOooooooo`1F
oooo002?oooo00<0000co`0co`005C?o00030000oooooooo01goool00ol0VOooooooo`1Foooo002?
oooo00<0000co`0co`005C?o00030000oooooooo01goool00ol0VOooooooo`1Foooo002?oooo00<0
000co`0co`0053?o00030000oooooooo01koool00ol0VOooooooo`1Foooo0028oooo0P0000Goool0
0`0003?o03?o000D<ol000<0003oooooool07_ooo`03o`2Ioooooooo05Koool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o000D<ol000<0003oooooool07_ooo`03o`2Ioooooooo05Koool0
08Woool00`000?ooooooo`03oooo0`0001<co`000`000?ooooooo`0Ooooo00?o09Woooooool0E_oo
o`00R_ooo`030000oooooooo00;oool00`0003?o03?o000C<ol000<0003oooooool07oooo`03o`2I
oooooooo05Koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000C<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo05Koool008Soool200001Oooo`030000<ol0<ol0018co`000`000?oo
ooooo`0Poooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0P
oooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Poooo00?o
09Woooooool0E_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Poooo00?o09Wooooo
ool0E_ooo`00Soooo`80000B<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool008ooool0
0`0003?o03?o000A<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o
03?o000A<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000A
<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000@<ol000<0
003oooooool08_ooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool08_ooo`03o`2Ioooooooo05Koool008ooool200004C?o00030000oooooooo02;oool00ol0VOoo
ooooo`1Foooo002?oooo00<0000co`0co`0043?o00030000oooooooo02;oool00ol0VOooooooo`1F
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo02?oool00ol0VOooooooo`1Foooo002?
oooo00<0000co`0co`003c?o00030000oooooooo02?oool00ol0VOooooooo`1Foooo002?oooo00<0
000co`0co`003c?o00030000oooooooo02?oool00ol0VOooooooo`1Foooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo02?oool00ol0VOooooooo`1Foooo002?oooo0P00010co`000`000?oo
ooooo`0Soooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0T
oooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Toooo00?o
09Woooooool0E_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Toooo00?o09Wooooo
ool0E_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Toooo00?o09Woooooool0E_oo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Toooo00?o09Woooooool0E_ooo`00Sooo
o`80000><ol000<0003oooooool09Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000=
<ol000<0003oooooool09Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000=<ol000<0
003oooooool09Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000=<ol000<0003ooooo
ool09Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000<<ol000<0003oooooool09_oo
o`03o`2Ioooooooo05Koool008Woool300000oooo`030000<ol0<ol000`co`000`000?ooooooo`0V
oooo00?o09Woooooool0E_ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000<<ol000<0
003oooooool09_ooo`03o`2Ioooooooo05Koool008Ooool500000oooo`<0000<<ol000<0003ooooo
ool09_ooo`03o`2Ioooooooo05Koool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?oo
o`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_oo
o`00Soooo`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07oooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o00Soool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004<ol00P00
00Dco`03000000Coool0000000000004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002c?o
00040000<ol0oooo00000_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02
oooo00<0003oooooool03Oooo`040000oooooooo000023?o00D000001Oooo`000?ooooooo`000004
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008
<ol000H0000co`0co`00000co`3oool300001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00009<ol000<0000co`0000000oooo`030000oooooooo
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000;<ol00P0000?oool3
00000_ooo`030000oooooooo07Woool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.47) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.70787 .12361 L
.71741 .12361 L
.71998 .12361 L
.72138 .12361 L
.72269 .12361 L
.72338 .12361 L
s
.72338 .12361 m
.72367 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.26171 .12361 L
.26709 .12361 L
.27003 .12361 L
.27279 .12361 L
.27399 .12361 L
.27513 .12361 L
.27645 .12347 L
.27765 .12285 L
.28302 .12014 L
.30316 .11075 L
.34135 .09604 L
.38199 .08417 L
.42112 .07576 L
.4411 .07243 L
.46271 .06945 L
.50277 .06544 L
.54378 .06134 L
.58326 .0566 L
.62123 .05174 L
.66166 .04657 L
.70057 .04184 L
.71074 .04067 L
.71611 .04006 L
.71905 .03974 L
.72049 .03958 L
.72181 .03943 L
.72297 .03931 L
.7242 .12361 L
.72543 .12361 L
.72678 .12361 L
.73226 .12361 L
.74193 .12361 L
.78249 .12361 L
.82153 .12361 L
.86303 .12361 L
.90301 .12361 L
.94148 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.47) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo03;oool506KoEoooo`00Soooo`030000oooooooo
02coool606Ko1?ooo`0306Kooooooooo05Goool008ooool00`000?ooooooo`0Roooo2P1Vo`[oool0
0`1Vooooooooo`1Eoooo002?oooo0P0001Woool:06Ko5?ooo`0306Kooooooooo05Goool008ooool0
0`000?ooooooo`0@oooo201Voakoool00`1Vooooooooo`1Eoooo002?oooo00<0003oooooool02ooo
o`D0I_lVoooo00<0I_ooooooool0EOooo`00Soooo`030000oooooooo00Coool706Ko:oooo`0306Ko
oooooooo05Goool008coool306Ko00<00000I_l0I_l0101Voc;oool00`1Vooooooooo`1Eoooo001n
oooo3P1Vo`?oool00`000?ooooooo`0foooo00<0I_ooooooool0EOooo`00NOooo`D0I_lAoooo0P00
03Ooool00`1Vooooooooo`1Eoooo000Goooo1@0003?oool200001?ooo`800004oooo0P0001Ooool5
06Ko5_ooo`030000oooooooo03;oool200000_ooo`0406Kooooo000000001?ooo`80000doooo1@00
01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00008oooo00@0003oooooool0000B
oooo101Voa_oool00`000?ooooooo`0aoooo00H0003oooooool0003oool0I_l6oooo00@0003ooooo
ool0000eoooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`00
00_oool00`000?ooooooo`0=oooo0`1Voaooool00`000?ooooooo`0aoooo00H0003oooooool0003o
ool0I_l9oooo00<0003oooooool0<oooo`030000oooooooo01Goool0017oool400001?ooo`030000
oooooooo02coool400000_ooo`040000oooooooo00002Oooo`80000<oooo101Vob;oool00`000?oo
ooooo`0aoooo00H0003oooooool0003oool0I_l7oooo0P0003Koool00`000?ooooooo`0Eoooo000I
oooo00<0003oooooool0<_ooo`040000oooooooo00002Oooo`030000oooooooo00Soool306Ko9_oo
o`030000oooooooo037oool01P000?ooooooo`000?ooo`1Vo`Ooool00`000?ooooooo`0eoooo00<0
003oooooool05Oooo`006?ooo`80000eoooo0P0000[oool300001_ooo`80I_lYoooo0P0003?oool2
00000_ooo`0306Kooooooooo00Goool30000=?ooo`80000Goooo001Qoooo0`1Vob_oool00`000?oo
ooooo`0foooo00<0I_ooooooool0EOooo`00Goooo`80I_l^oooo00<0003oooooool0=_ooo`0306Ko
oooooooo05Goool005goool206Ko<?ooo`030000oooooooo03Koool00`1Vooooooooo`1Eoooo001K
oooo0P1Voc;oool00`000?ooooooo`0foooo00<0I_ooooooool0EOooo`00FOooo`80I_ldoooo00<0
003oooooool0=_ooo`0306Kooooooooo05Goool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o0004o`2I<ol0<ol0
00002c?o00030000<ol0<ol000Tco`000`0003?o03?o000:<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`0003?o03?o000f<ol000Co09Tco`0co`00000h<ol01@0001Ooool008ooool00`0003?o
03?o000f<ol000?o09Tco`0co`00<C?o00P0000Loooo002?oooo00<0000co`0co`00=S?o0003o`2I
<ol0<ol002/co`0600009?ooo`00Soooo`030000<ol0<ol003Hco`000ol0VC?o03?o000V<ol01@00
02[oool008ooool00`0003?o03?o000f<ol000?o09Tco`0co`008C?o00D0000_oooo002?oooo0P00
03Lco`000ol0VC?o03?o000L<ol01@0003Coool008ooool00`0003?o03?o000f<ol000?o09Tco`0c
o`0063?o00@0000ioooo002?oooo00<0000co`0co`00=S?o0003o`2I<ol0<ol001Hco`020000?Ooo
o`00Soooo`030000<ol0<ol003Hco`000ol0VC?o03?o000C<ol00`0003ooool008ooool00`0003?o
03?o000f<ol000?o09Tco`0co`004C?o00800012oooo002?oooo00<0000co`0co`00=S?o0003o`2I
<ol0<ol000lco`020000A?ooo`00Soooo`80000g<ol000?o09Tco`0co`003C?o00800016oooo002?
oooo00<0000co`0co`00=S?o0003o`2I<ol0<ol000/co`020000B?ooo`00Soooo`030000<ol0<ol0
03Hco`000ol0VC?o03?o000:<ol000<0003oooooool0B?ooo`00Soooo`030000<ol0<ol003Hco`00
0ol0VC?o03?o0008<ol00P0004_oool008ooool00`0003?o03?o000f<ol000?o09Tco`0co`001S?o
0080001=oooo002?oooo00<0000co`0co`00=S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1=
oooo002?oooo0P0003Lco`000ol0VC?o03?o0003<ol00P00053oool008ooool00`0003?o03?o000f
<ol000Co09Tco`0co`0co`020000D_ooo`00Soooo`030000<ol0<ol003Hco`001?l0VC?o03?o0000
05Coool008ooool00`0003?o03?o000f<ol000?o09Tco`000000EOooo`00Soooo`030000<ol0<ol0
03Hco`000ol0V@000?ooo`1Eoooo002?oooo00<0000co`0co`00=C?o00030000o`2Ioooo05Koool0
08ooool20000=C?o00030000ooooo`2I05Ooool008ooool00`0003?o03?o000c<ol000@0003ooooo
oooo09UGoooo002?oooo00<0000co`0co`00<S?o00050000ooooooooooooo`2I05Ooool008ooool0
0`0003?o03?o000a<ol000<0003oooooool00_ooo`03o`2Ioooooooo05Goool008ooool00`0003?o
03?o000a<ol000<0003oooooool00_ooo`03o`2Ioooooooo05Goool008Ooool500000oooo`030000
<ol0<ol0030co`000`000?ooooooo`03oooo00?o09Woooooool0EOooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000_<ol000<0003oooooool01?ooo`03o`2Ioooooooo05Goool008Woool0
0`000?ooooooo`03oooo0`0002hco`000`000?ooooooo`05oooo00?o09Woooooool0EOooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000^<ol000<0003oooooool01Oooo`03o`2Ioooooooo
05Goool008Woool00`000?ooooooo`03oooo00<0000co`0co`00;C?o00030000oooooooo00Koool0
0ol0VOooooooo`1Eoooo0028oooo0P0000Goool00`0003?o03?o000/<ol000<0003oooooool01ooo
o`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000[<ol000<0003oooooool02?ooo`03o`2I
oooooooo05Goool008ooool00`0003?o03?o000[<ol000<0003oooooool02?ooo`03o`2Ioooooooo
05Goool008ooool20000:c?o00030000oooooooo00Woool00ol0VOooooooo`1Eoooo002?oooo00<0
000co`0co`00:C?o00030000oooooooo00[oool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0c
o`00:C?o00030000oooooooo00[oool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`00:3?o
00030000oooooooo00_oool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`009c?o00030000
oooooooo00coool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`009S?o00030000oooooooo
00goool00ol0VOooooooo`1Eoooo002?oooo0P0002Lco`000`000?ooooooo`0=oooo00?o09Wooooo
ool0EOooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`0>oooo00?o09Woooooool0EOoo
o`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`0?oooo00?o09Woooooool0EOooo`00Sooo
o`030000<ol0<ol002@co`000`000?ooooooo`0?oooo00?o09Woooooool0EOooo`00Soooo`030000
<ol0<ol002<co`000`000?ooooooo`0@oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol0
02<co`000`000?ooooooo`0@oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol0028co`00
0`000?ooooooo`0Aoooo00?o09Woooooool0EOooo`00Soooo`80000S<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000Q<ol000<0003oooooool04_ooo`03o`2I
oooooooo05Goool008ooool00`0003?o03?o000Q<ol000<0003oooooool04_ooo`03o`2Ioooooooo
05Goool008ooool00`0003?o03?o000P<ol000<0003oooooool04oooo`03o`2Ioooooooo05Goool0
08ooool00`0003?o03?o000P<ol000<0003oooooool04oooo`03o`2Ioooooooo05Goool008ooool0
0`0003?o03?o000P<ol000<0003oooooool04oooo`03o`2Ioooooooo05Goool008ooool2000083?o
00030000oooooooo01Coool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`007c?o00030000
oooooooo01Coool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`007S?o00030000oooooooo
01Goool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`007S?o00030000oooooooo01Goool0
0ol0VOooooooo`1Eoooo0027oooo100000Coool00`0003?o03?o000N<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo05Goool008Ooool00`000?ooooooo`05oooo00<0000co`0co`007C?o00030000
oooooooo01Koool00ol0VOooooooo`1Eoooo0028oooo00<0003oooooool01?ooo`<0000M<ol000<0
003oooooool05_ooo`03o`2Ioooooooo05Goool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`007C?o00030000oooooooo01Koool00ol0VOooooooo`1Eoooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0073?o00030000oooooooo01Ooool00ol0VOooooooo`1Eoooo0028oooo0P00
00Goool00`0003?o03?o000L<ol000<0003oooooool05oooo`03o`2Ioooooooo05Goool008ooool0
0`0003?o03?o000K<ol000<0003oooooool06?ooo`03o`2Ioooooooo05Goool008ooool00`0003?o
03?o000K<ol000<0003oooooool06?ooo`03o`2Ioooooooo05Goool008ooool2000073?o00030000
oooooooo01Soool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`006S?o00030000oooooooo
01Woool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`006S?o00030000oooooooo01Woool0
0ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`006S?o00030000oooooooo01Woool00ol0VOoo
ooooo`1Eoooo002?oooo00<0000co`0co`006S?o00030000oooooooo01Woool00ol0VOooooooo`1E
oooo002?oooo00<0000co`0co`006C?o00030000oooooooo01[oool00ol0VOooooooo`1Eoooo002?
oooo00<0000co`0co`006C?o00030000oooooooo01[oool00ol0VOooooooo`1Eoooo002?oooo0P00
01Xco`000`000?ooooooo`0Joooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol001Pco`00
0`000?ooooooo`0Koooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol001Pco`000`000?oo
ooooo`0Koooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0K
oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Loooo00?o
09Woooooool0EOooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Loooo00?o09Wooooo
ool0EOooo`00Soooo`80000H<ol000<0003oooooool07?ooo`03o`2Ioooooooo05Goool008ooool0
0`0003?o03?o000G<ol000<0003oooooool07?ooo`03o`2Ioooooooo05Goool008ooool00`0003?o
03?o000F<ol000<0003oooooool07Oooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000F
<ol000<0003oooooool07Oooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000F<ol000<0
003oooooool07Oooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000E<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo05Goool008ooool200005S?o00030000oooooooo01koool00ol0VOoo
ooooo`1Eoooo002?oooo00<0000co`0co`005C?o00030000oooooooo01koool00ol0VOooooooo`1E
oooo002?oooo00<0000co`0co`005C?o00030000oooooooo01koool00ol0VOooooooo`1Eoooo002?
oooo00<0000co`0co`0053?o00030000oooooooo01ooool00ol0VOooooooo`1Eoooo0028oooo0P00
00Goool00`0003?o03?o000D<ol000<0003oooooool07oooo`03o`2Ioooooooo05Goool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o000D<ol000<0003oooooool07oooo`03o`2Ioooooooo
05Goool008Woool00`000?ooooooo`03oooo0`0001<co`000`000?ooooooo`0Poooo00?o09Wooooo
ool0EOooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000C<ol000<0003oooooool08?oo
o`03o`2Ioooooooo05Goool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000C<ol000<0
003oooooool08?ooo`03o`2Ioooooooo05Goool008Soool200001Oooo`030000<ol0<ol0018co`00
0`000?ooooooo`0Qoooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`0Qoooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Q
oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Qoooo00?o
09Woooooool0EOooo`00Soooo`80000B<ol000<0003oooooool08_ooo`03o`2Ioooooooo05Goool0
08ooool00`0003?o03?o000A<ol000<0003oooooool08_ooo`03o`2Ioooooooo05Goool008ooool0
0`0003?o03?o000A<ol000<0003oooooool08_ooo`03o`2Ioooooooo05Goool008ooool00`0003?o
03?o000A<ol000<0003oooooool08_ooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000@
<ol000<0003oooooool08oooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000@<ol000<0
003oooooool08oooo`03o`2Ioooooooo05Goool008ooool200004C?o00030000oooooooo02?oool0
0ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`0043?o00030000oooooooo02?oool00ol0VOoo
ooooo`1Eoooo002?oooo00<0000co`0co`003c?o00030000oooooooo02Coool00ol0VOooooooo`1E
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo02Coool00ol0VOooooooo`1Eoooo002?
oooo00<0000co`0co`003c?o00030000oooooooo02Coool00ol0VOooooooo`1Eoooo002?oooo00<0
000co`0co`003c?o00030000oooooooo02Coool00ol0VOooooooo`1Eoooo002?oooo0P00010co`00
0`000?ooooooo`0Toooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`0Uoooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0U
oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Uoooo00?o
09Woooooool0EOooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Uoooo00?o09Wooooo
ool0EOooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Uoooo00?o09Woooooool0EOoo
o`00Soooo`80000><ol000<0003oooooool09_ooo`03o`2Ioooooooo05Goool008ooool00`0003?o
03?o000=<ol000<0003oooooool09_ooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000=
<ol000<0003oooooool09_ooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000=<ol000<0
003oooooool09_ooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000<<ol000<0003ooooo
ool09oooo`03o`2Ioooooooo05Goool008Woool300000oooo`030000<ol0<ol000`co`000`000?oo
ooooo`0Woooo00?o09Woooooool0EOooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000<
<ol000<0003oooooool09oooo`03o`2Ioooooooo05Goool008Ooool500000oooo`<0000<<ol000<0
003oooooool09oooo`03o`2Ioooooooo05Goool008Ooool010000?ooooooo`0000Coool?<ol0P_oo
o`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?
<ol0P_ooo`00Soooo`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07oooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o00Soool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004
<ol00P0000Dco`0300000oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool0000;<ol000<0000co`3oool00_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Pco`0500000ooo
o`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool0
10000?ooooooo`0000Pco`001@0003?o03?o000003?o0004oooo00D0003oooooooooool00000N_oo
o`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Tco`000`0003?o00000002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00002c?o00800002oooo100000;oool00`000?ooooooo`1ioooo002?oooo3C?o08Coool008ooool=
<ol0Q?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71741 .12361 L
.72307 .12361 L
.72585 .12361 L
.72707 .12361 L
.72772 .12361 L
.72841 .12361 L
s
.72841 .12361 m
.72889 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.26171 .12361 L
.26698 .12361 L
.26843 .12361 L
.26922 .12361 L
.26998 .12361 L
.27068 .12361 L
.27145 .1236 L
.27214 .12324 L
.27279 .1229 L
.28302 .11781 L
.30316 .1087 L
.34228 .09415 L
.38387 .08255 L
.42393 .07443 L
.46248 .06891 L
.48242 .06679 L
.50349 .06502 L
.54146 .06139 L
.58188 .05668 L
.62079 .05179 L
.66215 .04655 L
.68285 .04401 L
.702 .04174 L
.71158 .04064 L
.72058 .03964 L
.7251 .03914 L
.72634 .03901 L
.72764 .03887 L
.72875 .12361 L
.72997 .12361 L
.74033 .12361 L
.78089 .12361 L
.81993 .12361 L
.86143 .12361 L
.90141 .12361 L
.93988 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo03;oool606KoE_ooo`00Soooo`030000oooooooo
02Woool906Ko1Oooo`0306Kooooooooo05Coool008ooool00`000?ooooooo`0Roooo1`1Vo`koool0
0`1Vooooooooo`1Doooo002?oooo0P0001Woool:06Ko5Oooo`0306Kooooooooo05Coool008ooool0
0`000?ooooooo`0@oooo201Voaooool00`1Vooooooooo`1Doooo002?oooo00<0003oooooool02_oo
o`H0I_lWoooo00<0I_ooooooool0E?ooo`00Soooo`030000oooooooo00?oool706Ko;Oooo`0306Ko
oooooooo05Coool008Woool606Ko00<00000I_l0I_l00`1VocCoool00`1Vooooooooo`1Doooo0021
oooo201Vo`Koool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`00N_ooo`L0I_l>oooo0P00
03Soool00`1Vooooooooo`1Doooo000Goooo1@0003?oool200001?ooo`800004oooo0P0001Soool5
06Ko5Oooo`030000oooooooo03;oool200000oooo`0306Ko0000000000Coool20000=?ooo`D0000E
oooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo00004ooo
o`@0I_lJoooo00<0003oooooool0<Oooo`040000oooooooo00000_ooo`0306Kooooooooo00?oool0
10000?ooooooo`0003Goool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000
oooooooo00002oooo`030000oooooooo00goool406Ko7_ooo`030000oooooooo037oool010000?oo
ooooo`0000;oool00`1Vooooooooo`06oooo00<0003oooooool0<oooo`030000oooooooo01Goool0
017oool400001?ooo`030000oooooooo02coool400000_ooo`040000oooooooo00002Oooo`80000<
oooo101Vob;oool00`000?ooooooo`0aoooo00@0003oooooool00002oooo00<0I_ooooooool01?oo
o`80000foooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`00
00Woool00`000?ooooooo`08oooo0`1VobKoool00`000?ooooooo`0aoooo00@0003oooooool00002
oooo00<0I_ooooooool01?ooo`030000oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P00
03Goool200002_ooo`<00006oooo0P1VobWoool20000<oooo`800003oooo00<0I_ooooooool01?oo
o`<0000doooo0P0001Ooool0067oool306Ko:oooo`030000oooooooo03Ooool00`1Vooooooooo`1D
oooo001Ooooo0P1Vobkoool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`00G?ooo`<0I_l`
oooo00<0003oooooool0=oooo`0306Kooooooooo05Coool005[oool206Ko<oooo`030000oooooooo
03Ooool00`1Vooooooooo`1Doooo001Goooo0`1VocGoool00`000?ooooooo`0goooo00<0I_oooooo
ool0E?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0007<ol000?o09Tco`0000002c?o00030000<ol0<ol000Tco`00
0`0003?o03?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000g<ol000?o
09Tco`000000>3?o00D0000Goooo002?oooo00<0000co`0co`00=c?o0003o`2I<ol0<ol0030co`08
00007?ooo`00Soooo`030000<ol0<ol003Lco`000ol0VC?o03?o000Z<ol01P0002Coool008ooool0
0`0003?o03?o000g<ol000?o09Tco`0co`009C?o00D0000Zoooo002?oooo00<0000co`0co`00=c?o
0003o`2I<ol0<ol0020co`050000;oooo`00Soooo`80000h<ol000?o09Tco`0co`006c?o00D0000d
oooo002?oooo00<0000co`0co`00=c?o0003o`2I<ol0<ol001Lco`040000>Oooo`00Soooo`030000
<ol0<ol003Lco`000ol0VC?o03?o000E<ol00P0003goool008ooool00`0003?o03?o000g<ol000?o
09Tco`0co`004S?o00<0000ooooo002?oooo00<0000co`0co`00=c?o0003o`2I<ol0<ol0010co`02
0000@_ooo`00Soooo`030000<ol0<ol003Lco`000ol0VC?o03?o000><ol00P0004Coool008ooool2
0000>3?o0003o`2I<ol0<ol000`co`020000A_ooo`00Soooo`030000<ol0<ol003Lco`000ol0VC?o
03?o000:<ol00P0004Soool008ooool00`0003?o03?o000g<ol000?o09Tco`0co`002C?o00030000
oooooooo04Soool008ooool00`0003?o03?o000g<ol000?o09Tco`0co`001c?o0080001;oooo002?
oooo00<0000co`0co`00=c?o0003o`2I<ol0<ol000Dco`020000COooo`00Soooo`030000<ol0<ol0
03Lco`000ol0VC?o03?o0004<ol000<0003oooooool0COooo`00Soooo`80000h<ol000?o09Tco`0c
o`000S?o0080001@oooo002?oooo00<0000co`0co`00=c?o0003o`2I<ol0<ol00080001Boooo002?
oooo00<0000co`0co`00=c?o0003o`2I<ol0000005Coool008ooool00`0003?o03?o000g<ol000?o
09T0003oool0E?ooo`00Soooo`030000<ol0<ol003Hco`000`000?l0VOooo`1Eoooo002?oooo00<0
000co`0co`00=C?o00030000ooooo`2I05Koool008ooool20000=C?o00040000ooooooooo`2IE_oo
o`00Soooo`030000<ol0<ol003<co`001@000?ooooooooooool0V@1Foooo002?oooo00<0000co`0c
o`00<S?o00030000oooooooo00;oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`00<C?o
00030000oooooooo00?oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`00<C?o00030000
oooooooo00?oool00ol0VOooooooo`1Doooo0027oooo1@0000?oool00`0003?o03?o000`<ol000<0
003oooooool01?ooo`03o`2Ioooooooo05Coool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`00;c?o00030000oooooooo00Goool00ol0VOooooooo`1Doooo0029oooo00<0003oooooool00ooo
o`<0000^<ol000<0003oooooool01_ooo`03o`2Ioooooooo05Coool008Woool00`000?ooooooo`03
oooo00<0000co`0co`00;S?o00030000oooooooo00Koool00ol0VOooooooo`1Doooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol002dco`000`000?ooooooo`07oooo00?o09Woooooool0E?oo
o`00R?ooo`800005oooo00<0000co`0co`00;3?o00030000oooooooo00Soool00ol0VOooooooo`1D
oooo002?oooo00<0000co`0co`00:c?o00030000oooooooo00Woool00ol0VOooooooo`1Doooo002?
oooo00<0000co`0co`00:c?o00030000oooooooo00Woool00ol0VOooooooo`1Doooo002?oooo0P00
02/co`000`000?ooooooo`0:oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol002Tco`00
0`000?ooooooo`0;oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol002Tco`000`000?oo
ooooo`0;oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol002Pco`000`000?ooooooo`0<
oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol002Lco`000`000?ooooooo`0=oooo00?o
09Woooooool0E?ooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`0>oooo00?o09Wooooo
ool0E?ooo`00Soooo`80000W<ol000<0003oooooool03_ooo`03o`2Ioooooooo05Coool008ooool0
0`0003?o03?o000U<ol000<0003oooooool03oooo`03o`2Ioooooooo05Coool008ooool00`0003?o
03?o000T<ol000<0003oooooool04?ooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000T
<ol000<0003oooooool04?ooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000S<ol000<0
003oooooool04Oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000S<ol000<0003ooooo
ool04Oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000R<ol000<0003oooooool04_oo
o`03o`2Ioooooooo05Coool008ooool200008c?o00030000oooooooo01;oool00ol0VOooooooo`1D
oooo002?oooo00<0000co`0co`008C?o00030000oooooooo01?oool00ol0VOooooooo`1Doooo002?
oooo00<0000co`0co`008C?o00030000oooooooo01?oool00ol0VOooooooo`1Doooo002?oooo00<0
000co`0co`0083?o00030000oooooooo01Coool00ol0VOooooooo`1Doooo002?oooo00<0000co`0c
o`0083?o00030000oooooooo01Coool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`0083?o
00030000oooooooo01Coool00ol0VOooooooo`1Doooo002?oooo0P00020co`000`000?ooooooo`0E
oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0Eoooo00?o
09Woooooool0E?ooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0Foooo00?o09Wooooo
ool0E?ooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0Foooo00?o09Woooooool0E?oo
o`00Qoooo`@00004oooo00<0000co`0co`007S?o00030000oooooooo01Koool00ol0VOooooooo`1D
oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol001dco`000`000?ooooooo`0Goooo00?o
09Woooooool0E?ooo`00R?ooo`030000oooooooo00Coool300007C?o00030000oooooooo01Ooool0
0ol0VOooooooo`1Doooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001dco`000`000?oo
ooooo`0Goooo00?o09Woooooool0E?ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
01`co`000`000?ooooooo`0Hoooo00?o09Woooooool0E?ooo`00R?ooo`800005oooo00<0000co`0c
o`0073?o00030000oooooooo01Soool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`006c?o
00030000oooooooo01Woool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`006c?o00030000
oooooooo01Woool00ol0VOooooooo`1Doooo002?oooo0P0001`co`000`000?ooooooo`0Ioooo00?o
09Woooooool0E?ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Joooo00?o09Wooooo
ool0E?ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Joooo00?o09Woooooool0E?oo
o`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Joooo00?o09Woooooool0E?ooo`00Sooo
o`030000<ol0<ol001Xco`000`000?ooooooo`0Joooo00?o09Woooooool0E?ooo`00Soooo`030000
<ol0<ol001Tco`000`000?ooooooo`0Koooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol0
01Tco`000`000?ooooooo`0Koooo00?o09Woooooool0E?ooo`00Soooo`80000J<ol000<0003ooooo
ool06oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000H<ol000<0003oooooool07?oo
o`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000H<ol000<0003oooooool07?ooo`03o`2I
oooooooo05Coool008ooool00`0003?o03?o000H<ol000<0003oooooool07?ooo`03o`2Ioooooooo
05Coool008ooool00`0003?o03?o000G<ol000<0003oooooool07Oooo`03o`2Ioooooooo05Coool0
08ooool00`0003?o03?o000G<ol000<0003oooooool07Oooo`03o`2Ioooooooo05Coool008ooool2
000063?o00030000oooooooo01goool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`005c?o
00030000oooooooo01goool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`005S?o00030000
oooooooo01koool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`005S?o00030000oooooooo
01koool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`005S?o00030000oooooooo01koool0
0ol0VOooooooo`1Doooo002?oooo00<0000co`0co`005C?o00030000oooooooo01ooool00ol0VOoo
ooooo`1Doooo002?oooo0P0001Hco`000`000?ooooooo`0Ooooo00?o09Woooooool0E?ooo`00Sooo
o`030000<ol0<ol001Dco`000`000?ooooooo`0Ooooo00?o09Woooooool0E?ooo`00Soooo`030000
<ol0<ol001Dco`000`000?ooooooo`0Ooooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol0
01@co`000`000?ooooooo`0Poooo00?o09Woooooool0E?ooo`00R?ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo023oool00ol0VOooooooo`1Doooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0053?o00030000oooooooo023oool00ol0VOooooooo`1Doooo0029oooo00<0
003oooooool00oooo`<0000C<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Coool008[oool0
0`000?ooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo027oool00ol0VOooooooo`1D
oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`004c?o00030000oooooooo027oool0
0ol0VOooooooo`1Doooo0028oooo0P0000Goool00`0003?o03?o000B<ol000<0003oooooool08_oo
o`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000B<ol000<0003oooooool08_ooo`03o`2I
oooooooo05Coool008ooool00`0003?o03?o000B<ol000<0003oooooool08_ooo`03o`2Ioooooooo
05Coool008ooool00`0003?o03?o000B<ol000<0003oooooool08_ooo`03o`2Ioooooooo05Coool0
08ooool200004S?o00030000oooooooo02?oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo02?oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`004C?o
00030000oooooooo02?oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`004C?o00030000
oooooooo02?oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`0043?o00030000oooooooo
02Coool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Coool0
0ol0VOooooooo`1Doooo002?oooo0P00014co`000`000?ooooooo`0Toooo00?o09Woooooool0E?oo
o`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Toooo00?o09Woooooool0E?ooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0Uoooo00?o09Woooooool0E?ooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0Uoooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooooooo`0Uoooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`0Uoooo00?o09Woooooool0E?ooo`00Soooo`80000@<ol000<0003oooooool09Ooo
o`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2I
oooooooo05Coool008ooool00`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2Ioooooooo
05Coool008ooool00`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2Ioooooooo05Coool0
08ooool00`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2Ioooooooo05Coool008ooool0
0`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2Ioooooooo05Coool008ooool200003S?o
00030000oooooooo02Ooool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`003C?o00030000
oooooooo02Ooool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`003C?o00030000oooooooo
02Ooool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`003C?o00030000oooooooo02Ooool0
0ol0VOooooooo`1Doooo002?oooo00<0000co`0co`0033?o00030000oooooooo02Soool00ol0VOoo
ooooo`1Doooo0029oooo0`0000?oool00`0003?o03?o000<<ol000<0003oooooool0:?ooo`03o`2I
oooooooo05Coool008[oool00`000?ooooooo`02oooo00<0000co`0co`0033?o00030000oooooooo
02Soool00ol0VOooooooo`1Doooo0027oooo1@0000?oool3000033?o00030000oooooooo02Soool0
0ol0VOooooooo`1Doooo0027oooo00@0003oooooool00004oooo3c?o08;oool008Soool00`000?oo
o`000004oooo3c?o08;oool008Woool200001?ooo`lco`22oooo002?oooo3c?o08;oool008ooool?
<ol0P_ooo`00NOooo`030000oooooooo01?oool><ol01oooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool02Oooo`hco`08oooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o00800005<ol00`00
00;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000/co`00100003?o0?ooo`00
00;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000Pco`05000000Goool0003oooooool000001?ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo000023?o00050000<ol0<ol0
0000<ol000;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00009<ol000<0000co`0000000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000/co`0200000oooo`800003oooo00<0
003oooooool0NOooo`00Soooo`dco`24oooo002?oooo3C?o08Coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.49) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71741 .12361 L
.72307 .12361 L
.72841 .12361 L
.73074 .12361 L
.73201 .12361 L
.7332 .12361 L
s
.7332 .12361 m
.73371 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.25666 .12361 L
.26171 .12361 L
.26425 .12361 L
.26498 .12361 L
.26568 .12361 L
.26698 .12344 L
.26768 .12308 L
.26842 .1227 L
.26976 .12202 L
.27279 .12049 L
.28302 .11555 L
.30316 .10672 L
.34474 .09188 L
.3848 .08123 L
.42335 .07373 L
.44329 .07074 L
.46436 .06815 L
.50233 .06477 L
.54275 .06107 L
.58166 .05664 L
.62302 .05152 L
.66287 .04652 L
.7012 .04191 L
.72097 .03968 L
.72578 .03915 L
.7283 .03888 L
.73096 .03859 L
.73237 .03844 L
.73318 .03836 L
.73392 .12361 L
.73524 .12361 L
.73664 .12361 L
.74198 .12361 L
.78348 .12361 L
.82346 .12361 L
.86193 .12361 L
.90285 .12361 L
.94225 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.49) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo03?oool606KoEOooo`00Soooo`030000oooooooo
02coool706Ko1Oooo`0306Kooooooooo05?oool008ooool00`000?ooooooo`0Roooo2P1Vo`coool0
0`1Vooooooooo`1Coooo002?oooo0P0001Woool:06Ko5_ooo`0306Kooooooooo05?oool008ooool0
0`000?ooooooo`0@oooo201Vob3oool00`1Vooooooooo`1Coooo002?oooo00<0003oooooool02ooo
o`D0I_lXoooo00<0I_ooooooool0Doooo`00S?ooo`<0I_l00`00001Vo`1Vo`0;06Ko;Oooo`0306Ko
oooooooo05?oool008Coool806Ko0oooo`030000oooooooo03Soool00`1Vooooooooo`1Coooo001o
oooo1@1Vo`_oool00`000?ooooooo`0hoooo00<0I_ooooooool0Doooo`00N_ooo`D0I_l@oooo0P00
03Woool00`1Vooooooooo`1Coooo000Goooo1@0003?oool200001?ooo`800004oooo0P0001Soool5
06Ko5Oooo`030000oooooooo03;oool200001?ooo`800004oooo0P0003Coool500005Oooo`006Ooo
o`030000oooooooo03;oool010000?ooooooo`0000Soool010000?ooooooo`0001;oool506Ko6_oo
o`030000oooooooo037oool010000?ooooooo`0000?oool00`1Vooooooooo`02oooo00@0003ooooo
ool0000eoooo00<0003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`00
00_oool00`000?ooooooo`0;oooo1@1Voaooool00`000?ooooooo`0aoooo00@0003oooooool00003
oooo00<0I_ooooooool01Oooo`030000oooooooo03?oool00`000?ooooooo`0Eoooo000Aoooo1000
00Coool00`000?ooooooo`0/oooo100000;oool010000?ooooooo`0000Woool200002_ooo`@0I_lT
oooo00<0003oooooool0<Oooo`040000oooooooo00000oooo`0306Kooooooooo00?oool20000=_oo
o`030000oooooooo01Goool001Woool00`000?ooooooo`0boooo00@0003oooooool00009oooo00<0
003oooooool01_ooo`<0I_lXoooo00<0003oooooool0<Oooo`040000oooooooo00000oooo`0306Ko
oooooooo00?oool00`000?ooooooo`0eoooo00<0003oooooool05Oooo`006?ooo`80000eoooo0P00
00[oool300001?ooo`80I_l[oooo0P0003?oool200001?ooo`0306Kooooooooo00?oool30000=?oo
o`80000Goooo001Ooooo0`1Vobgoool00`000?ooooooo`0hoooo00<0I_ooooooool0Doooo`00G?oo
o`<0I_l`oooo00<0003oooooool0>?ooo`0306Kooooooooo05?oool005[oool206Ko<oooo`030000
oooooooo03Soool00`1Vooooooooo`1Coooo001Hoooo0P1VocGoool00`000?ooooooo`0hoooo00<0
I_ooooooool0Doooo`00E_ooo`80I_lgoooo00<0003oooooool0>?ooo`0306Kooooooooo05?oool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`0023?o0003o`2I0000<ol000Xco`000`0003?o03?o0009<ol000<0000co`0c
o`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0003oooooool05Oooo`005_oo
o`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`00>3?o0003o`2I0000<ol0
03Lco`0500005oooo`00Soooo`030000<ol0<ol003Pco`000ol0VC?o03?o000_<ol0200001coool0
08ooool00`0003?o03?o000h<ol000?o09Tco`0co`00:C?o00H0000Toooo002?oooo00<0000co`0c
o`00>3?o0003o`2I<ol0<ol002@co`050000:_ooo`00Soooo`030000<ol0<ol003Pco`000ol0VC?o
03?o000O<ol01@0002ooool008ooool20000>C?o0003o`2I<ol0<ol001Xco`050000=?ooo`00Sooo
o`030000<ol0<ol003Pco`000ol0VC?o03?o000F<ol0100003Woool008ooool00`0003?o03?o000h
<ol000?o09Tco`0co`0053?o0080000moooo002?oooo00<0000co`0co`00>3?o0003o`2I<ol0<ol0
014co`030000?oooo`00Soooo`030000<ol0<ol003Pco`000ol0VC?o03?o000?<ol00P0004;oool0
08ooool00`0003?o03?o000h<ol000?o09Tco`0co`003C?o00800014oooo002?oooo0P0003Tco`00
0ol0VC?o03?o000;<ol00P0004Koool008ooool00`0003?o03?o000h<ol000?o09Tco`0co`002C?o
00800018oooo002?oooo00<0000co`0co`00>3?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`18
oooo002?oooo00<0000co`0co`00>3?o0003o`2I<ol0<ol000Hco`020000Boooo`00Soooo`030000
<ol0<ol003Pco`000ol0VC?o03?o0004<ol00P0004goool008ooool00`0003?o03?o000h<ol000?o
09Tco`0co`000c?o00030000oooooooo04goool008ooool20000>C?o0004o`2I<ol0<ol0<ol00P00
053oool008ooool00`0003?o03?o000h<ol000Co09Tco`000000001Boooo002?oooo00<0000co`0c
o`00>3?o0003o`2I0000oooo05?oool008ooool00`0003?o03?o000h<ol000?o09Woooooool0Dooo
o`00Soooo`030000<ol0<ol003Hco`02000000?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0
03Dco`0010000?ooooooool0VEGoool008ooool20000=C?o00050000ooooooooooooo`2I05Goool0
08ooool00`0003?o03?o000c<ol000<0003oooooool00_ooo`03o`2Ioooooooo05?oool008ooool0
0`0003?o03?o000b<ol000<0003oooooool00oooo`03o`2Ioooooooo05?oool008ooool00`0003?o
03?o000a<ol000<0003oooooool01?ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000a
<ol000<0003oooooool01?ooo`03o`2Ioooooooo05?oool008Ooool500000oooo`030000<ol0<ol0
030co`000`000?ooooooo`05oooo00?o09Woooooool0Doooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000_<ol000<0003oooooool01_ooo`03o`2Ioooooooo05?oool008Woool00`000?oo
ooooo`03oooo0`0002hco`000`000?ooooooo`07oooo00?o09Woooooool0Doooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000^<ol000<0003oooooool01oooo`03o`2Ioooooooo05?oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`00;C?o00030000oooooooo00Soool00ol0VOoo
ooooo`1Coooo0028oooo0P0000Goool00`0003?o03?o000/<ol000<0003oooooool02Oooo`03o`2I
oooooooo05?oool008ooool00`0003?o03?o000[<ol000<0003oooooool02_ooo`03o`2Ioooooooo
05?oool008ooool00`0003?o03?o000[<ol000<0003oooooool02_ooo`03o`2Ioooooooo05?oool0
08ooool20000:c?o00030000oooooooo00_oool00ol0VOooooooo`1Coooo002?oooo00<0000co`0c
o`00:C?o00030000oooooooo00coool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`00:C?o
00030000oooooooo00coool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`00:3?o00030000
oooooooo00goool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`009c?o00030000oooooooo
00koool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`009S?o00030000oooooooo00ooool0
0ol0VOooooooo`1Coooo002?oooo0P0002Lco`000`000?ooooooo`0?oooo00?o09Woooooool0Dooo
o`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`0@oooo00?o09Woooooool0Doooo`00Sooo
o`030000<ol0<ol002@co`000`000?ooooooo`0Aoooo00?o09Woooooool0Doooo`00Soooo`030000
<ol0<ol002@co`000`000?ooooooo`0Aoooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0
02<co`000`000?ooooooo`0Boooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol002<co`00
0`000?ooooooo`0Boooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0028co`000`000?oo
ooooo`0Coooo00?o09Woooooool0Doooo`00Soooo`80000S<ol000<0003oooooool04oooo`03o`2I
oooooooo05?oool008ooool00`0003?o03?o000Q<ol000<0003oooooool05?ooo`03o`2Ioooooooo
05?oool008ooool00`0003?o03?o000Q<ol000<0003oooooool05?ooo`03o`2Ioooooooo05?oool0
08ooool00`0003?o03?o000P<ol000<0003oooooool05Oooo`03o`2Ioooooooo05?oool008ooool0
0`0003?o03?o000P<ol000<0003oooooool05Oooo`03o`2Ioooooooo05?oool008ooool00`0003?o
03?o000P<ol000<0003oooooool05Oooo`03o`2Ioooooooo05?oool008ooool2000083?o00030000
oooooooo01Koool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`007c?o00030000oooooooo
01Koool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`007S?o00030000oooooooo01Ooool0
0ol0VOooooooo`1Coooo002?oooo00<0000co`0co`007S?o00030000oooooooo01Ooool00ol0VOoo
ooooo`1Coooo0027oooo100000Coool00`0003?o03?o000N<ol000<0003oooooool05oooo`03o`2I
oooooooo05?oool008Ooool00`000?ooooooo`05oooo00<0000co`0co`007C?o00030000oooooooo
01Soool00ol0VOooooooo`1Coooo0028oooo00<0003oooooool01?ooo`<0000M<ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo05?oool008Woool00`000?ooooooo`03oooo00<0000co`0co`007C?o
00030000oooooooo01Soool00ol0VOooooooo`1Coooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0073?o00030000oooooooo01Woool00ol0VOooooooo`1Coooo0028oooo0P0000Goool0
0`0003?o03?o000L<ol000<0003oooooool06Oooo`03o`2Ioooooooo05?oool008ooool00`0003?o
03?o000K<ol000<0003oooooool06_ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000K
<ol000<0003oooooool06_ooo`03o`2Ioooooooo05?oool008ooool2000073?o00030000oooooooo
01[oool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`006S?o00030000oooooooo01_oool0
0ol0VOooooooo`1Coooo002?oooo00<0000co`0co`006S?o00030000oooooooo01_oool00ol0VOoo
ooooo`1Coooo002?oooo00<0000co`0co`006S?o00030000oooooooo01_oool00ol0VOooooooo`1C
oooo002?oooo00<0000co`0co`006S?o00030000oooooooo01_oool00ol0VOooooooo`1Coooo002?
oooo00<0000co`0co`006C?o00030000oooooooo01coool00ol0VOooooooo`1Coooo002?oooo00<0
000co`0co`006C?o00030000oooooooo01coool00ol0VOooooooo`1Coooo002?oooo0P0001Xco`00
0`000?ooooooo`0Loooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol001Pco`000`000?oo
ooooo`0Moooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0M
oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0Moooo00?o
09Woooooool0Doooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Noooo00?o09Wooooo
ool0Doooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Noooo00?o09Woooooool0Dooo
o`00Soooo`80000H<ol000<0003oooooool07_ooo`03o`2Ioooooooo05?oool008ooool00`0003?o
03?o000G<ol000<0003oooooool07_ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000F
<ol000<0003oooooool07oooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000F<ol000<0
003oooooool07oooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000F<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000E<ol000<0003oooooool08?oo
o`03o`2Ioooooooo05?oool008ooool200005S?o00030000oooooooo023oool00ol0VOooooooo`1C
oooo002?oooo00<0000co`0co`005C?o00030000oooooooo023oool00ol0VOooooooo`1Coooo002?
oooo00<0000co`0co`005C?o00030000oooooooo023oool00ol0VOooooooo`1Coooo002?oooo00<0
000co`0co`0053?o00030000oooooooo027oool00ol0VOooooooo`1Coooo0028oooo0P0000Goool0
0`0003?o03?o000D<ol000<0003oooooool08Oooo`03o`2Ioooooooo05?oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o000D<ol000<0003oooooool08Oooo`03o`2Ioooooooo05?oool0
08Woool00`000?ooooooo`03oooo0`0001<co`000`000?ooooooo`0Roooo00?o09Woooooool0Dooo
o`00R_ooo`030000oooooooo00;oool00`0003?o03?o000C<ol000<0003oooooool08_ooo`03o`2I
oooooooo05?oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000C<ol000<0003ooooo
ool08_ooo`03o`2Ioooooooo05?oool008Soool200001Oooo`030000<ol0<ol0018co`000`000?oo
ooooo`0Soooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0S
oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Soooo00?o
09Woooooool0Doooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Soooo00?o09Wooooo
ool0Doooo`00Soooo`80000B<ol000<0003oooooool09?ooo`03o`2Ioooooooo05?oool008ooool0
0`0003?o03?o000A<ol000<0003oooooool09?ooo`03o`2Ioooooooo05?oool008ooool00`0003?o
03?o000A<ol000<0003oooooool09?ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000A
<ol000<0003oooooool09?ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000@<ol000<0
003oooooool09Oooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool09Oooo`03o`2Ioooooooo05?oool008ooool200004C?o00030000oooooooo02Goool00ol0VOoo
ooooo`1Coooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Goool00ol0VOooooooo`1C
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo02Koool00ol0VOooooooo`1Coooo002?
oooo00<0000co`0co`003c?o00030000oooooooo02Koool00ol0VOooooooo`1Coooo002?oooo00<0
000co`0co`003c?o00030000oooooooo02Koool00ol0VOooooooo`1Coooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo02Koool00ol0VOooooooo`1Coooo002?oooo0P00010co`000`000?oo
ooooo`0Voooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0W
oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Woooo00?o
09Woooooool0Doooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Woooo00?o09Wooooo
ool0Doooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Woooo00?o09Woooooool0Dooo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Woooo00?o09Woooooool0Doooo`00Sooo
o`80000><ol000<0003oooooool0:?ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000=
<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000=<ol000<0
003oooooool0:?ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000=<ol000<0003ooooo
ool0:?ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000<<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo05?oool008Woool300000oooo`030000<ol0<ol000`co`000`000?ooooooo`0Y
oooo00?o09Woooooool0Doooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000<<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo05?oool008Ooool500000oooo`<0000<<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo05?oool008Ooool010000?ooooooo`0000Coool?<ol0P_ooo`00R?oo
o`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?<ol0P_oo
o`00Soooo`lco`22oooo001ioooo00<0003oooooool04oooo`hco`07oooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo3S?o00Soool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004<ol00P00
00Dco`03000000Coool0000000000004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002c?o
00030000<ol0oooo00;oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008<ol01@0000;oool300001?oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo000023?o
00070000<ol0<ol00000<ol0oooo000000;oool01@000?ooooooooooo`00001joooo001hoooo00D0
003oooooooooool000003oooo`040000oooooooo00002C?o00030000<ol0000000;oool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000;<ol00P00
00?oool300000_ooo`030000oooooooo07Woool008ooool=<ol0Q?ooo`00Soooo`dco`24oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.10192 L
.50154 1.09355 L
.50226 1.08481 L
.50471 1.05582 L
.5095 1.00223 L
.51896 .90691 L
.53984 .73669 L
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50021 .61803 L
s
.55896 .61803 m
.55948 .61481 L
.57781 .52545 L
.61672 .38999 L
.63796 .33783 L
.65808 .29843 L
.69641 .2431 L
.71618 .22205 L
.73719 .20387 L
.77494 .17937 L
.79429 .16994 L
.81515 .16157 L
.83479 .15509 L
.85629 .14928 L
.89591 .14124 L
.91552 .13826 L
.93647 .13563 L
.97619 .13187 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71741 .12361 L
.72307 .12361 L
.72841 .12361 L
.7332 .12361 L
.73451 .12361 L
.7359 .12361 L
.73708 .12361 L
s
.73708 .12361 m
.7376 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.25666 .12361 L
.2593 .12361 L
.26045 .12361 L
.26171 .12361 L
.26301 .12303 L
.26425 .1224 L
.26698 .12101 L
.27279 .11815 L
.28302 .11335 L
.30316 .1048 L
.3438 .09072 L
.38293 .08058 L
.40291 .07649 L
.42451 .07278 L
.46458 .06762 L
.48452 .06576 L
.50558 .06422 L
.54355 .06082 L
.58398 .05631 L
.62289 .05156 L
.66425 .04643 L
.68494 .04392 L
.70409 .04167 L
.72268 .03958 L
.73206 .03857 L
.73463 .0383 L
.73599 .03816 L
.73672 .03808 L
.73741 .03801 L
.73866 .12361 L
.73932 .12361 L
.74002 .12361 L
.74242 .12361 L
.78392 .12361 L
.8239 .12361 L
.86237 .12361 L
.90329 .12361 L
.94269 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -12 -9 ]
[.2619 .11111 12 0 ]
[.7381 .11111 -9 -9 ]
[.7381 .11111 9 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-1)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-0.5)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(0.5)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(1)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo03Coool606KoE?ooo`00Soooo`030000oooooooo
02[oool:06Ko1Oooo`0306Kooooooooo05;oool008ooool00`000?ooooooo`0Roooo201Vo`ooool0
0`1Vooooooooo`1Boooo002?oooo0P0001Woool:06Ko5oooo`0306Kooooooooo05;oool008ooool0
0`000?ooooooo`0>oooo2P1Vob7oool00`1Vooooooooo`1Boooo002?oooo00<0003oooooool01?oo
o`X0I_l[oooo00<0I_ooooooool0D_ooo`00S_ooo`0306Ko000006Ko00D0I_leoooo00<0I_oooooo
ool0D_ooo`00Q?ooo`X0I_l00oooo`000?ooo`0joooo00<0I_ooooooool0D_ooo`00Ooooo`D0I_l;
oooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool007Coool;06Ko4?ooo`80000joooo00<0
I_ooooooool0D_ooo`005oooo`D0000coooo0P0000Coool200001?ooo`80000Coooo101Voa_oool0
0`000?ooooooo`0boooo0P0000Coool200001?ooo`80000doooo1@0001Goool001Woool00`000?oo
ooooo`0boooo00@0003oooooool00008oooo00@0003oooooool0000?oooo0`1Voaooool00`000?oo
ooooo`0aoooo00@0003oooooool00004oooo00D0I_ooooooooooool000000_ooo`030000oooooooo
03?oool00`000?ooooooo`0Eoooo000Ioooo00<0003oooooool0<_ooo`040000oooooooo00002ooo
o`030000oooooooo00Woool406Ko8_ooo`030000oooooooo037oool010000?ooooooo`0000Coool0
0`1Vooooooooo`04oooo00<0003oooooool0<oooo`030000oooooooo01Goool0017oool400001?oo
o`030000oooooooo02coool400000_ooo`040000oooooooo00002Oooo`800009oooo0`1VobKoool0
0`000?ooooooo`0aoooo00@0003oooooool00004oooo00<0I_ooooooool00_ooo`80000foooo00<0
003oooooool05Oooo`006Oooo`030000oooooooo03;oool010000?ooooooo`0000Woool00`000?oo
ooooo`06oooo0P1VobWoool00`000?ooooooo`0aoooo00@0003oooooool00004oooo00<0I_oooooo
ool00_ooo`030000oooooooo03Goool00`000?ooooooo`0Eoooo000Hoooo0P0003Goool200002_oo
o`<00003oooo0`1Vob_oool20000<oooo`800005oooo00<0I_ooooooool00_ooo`<0000doooo0P00
01Ooool005ooool206Ko;_ooo`030000oooooooo03Woool00`1Vooooooooo`1Boooo001Loooo0`1V
oc3oool00`000?ooooooo`0ioooo00<0I_ooooooool0D_ooo`00F_ooo`80I_lcoooo00<0003ooooo
ool0>Oooo`0306Kooooooooo05;oool005Ooool306Ko=Oooo`030000oooooooo03Woool00`1Voooo
ooooo`1Boooo001Eoooo0P1VocSoool00`000?ooooooo`0ioooo00<0I_ooooooool0D_ooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o000:
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`000?ooooooo`0Eoooo000Foooo00<0
003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000i<ol000<0000co`0co`00=S?o
00D0000Goooo002?oooo00<0000co`0co`00>C?o0003o`2I<ol0<ol002hco`0800007?ooo`00Sooo
o`030000<ol0<ol003Tco`000ol0VC?o03?o000X<ol01P0002Coool008ooool00`0003?o03?o000i
<ol000?o09Tco`0co`008c?o00D0000Zoooo002?oooo00<0000co`0co`00>C?o0003o`2I<ol0<ol0
01hco`050000;oooo`00Soooo`80000j<ol000?o09Tco`0co`006C?o00D0000doooo002?oooo00<0
000co`0co`00>C?o0003o`2I<ol0<ol001Dco`040000>Oooo`00Soooo`030000<ol0<ol003Tco`00
0ol0VC?o03?o000C<ol00P0003goool008ooool00`0003?o03?o000i<ol000?o09Tco`0co`0043?o
00<0000ooooo002?oooo00<0000co`0co`00>C?o0003o`2I<ol0<ol000hco`020000@_ooo`00Sooo
o`030000<ol0<ol003Tco`000ol0VC?o03?o000<<ol00P0004Coool008ooool20000>S?o0003o`2I
<ol0<ol000Xco`020000A_ooo`00Soooo`030000<ol0<ol003Tco`000ol0VC?o03?o0008<ol00P00
04Soool008ooool00`0003?o03?o000i<ol000?o09Tco`0co`001c?o00030000oooooooo04Soool0
08ooool00`0003?o03?o000i<ol000?o09Tco`0co`001C?o0080001;oooo002?oooo00<0000co`0c
o`00>C?o0003o`2I<ol0<ol000<co`020000COooo`00Soooo`030000<ol0<ol003Tco`000ol0VC?o
03?o0002<ol000<0003oooooool0COooo`00Soooo`80000j<ol000?o09Tco`0co`000P00053oool0
08ooool00`0003?o03?o000i<ol000?o09T000000000D_ooo`00Soooo`030000<ol0<ol003Tco`00
0ol0VOooooooo`1Boooo002?oooo00<0000co`0co`00>3?o00030000o`2Ioooo05?oool008ooool0
0`0003?o03?o000f<ol00P000003ooooo`2Ioooo05?oool008ooool00`0003?o03?o000e<ol000D0
003ooooooooooooo09T0E?ooo`00Soooo`80000e<ol000<0003oooooool00_ooo`03o`2Ioooooooo
05;oool008ooool00`0003?o03?o000c<ol000<0003oooooool00oooo`03o`2Ioooooooo05;oool0
08ooool00`0003?o03?o000b<ol000<0003oooooool01?ooo`03o`2Ioooooooo05;oool008ooool0
0`0003?o03?o000a<ol000<0003oooooool01Oooo`03o`2Ioooooooo05;oool008ooool00`0003?o
03?o000a<ol000<0003oooooool01Oooo`03o`2Ioooooooo05;oool008Ooool500000oooo`030000
<ol0<ol0030co`000`000?ooooooo`06oooo00?o09Woooooool0D_ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000_<ol000<0003oooooool01oooo`03o`2Ioooooooo05;oool008Woool0
0`000?ooooooo`03oooo0`0002hco`000`000?ooooooo`08oooo00?o09Woooooool0D_ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000^<ol000<0003oooooool02?ooo`03o`2Ioooooooo
05;oool008Woool00`000?ooooooo`03oooo00<0000co`0co`00;C?o00030000oooooooo00Woool0
0ol0VOooooooo`1Boooo0028oooo0P0000Goool00`0003?o03?o000/<ol000<0003oooooool02_oo
o`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000[<ol000<0003oooooool02oooo`03o`2I
oooooooo05;oool008ooool00`0003?o03?o000[<ol000<0003oooooool02oooo`03o`2Ioooooooo
05;oool008ooool20000:c?o00030000oooooooo00coool00ol0VOooooooo`1Boooo002?oooo00<0
000co`0co`00:C?o00030000oooooooo00goool00ol0VOooooooo`1Boooo002?oooo00<0000co`0c
o`00:C?o00030000oooooooo00goool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`00:3?o
00030000oooooooo00koool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`009c?o00030000
oooooooo00ooool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`009S?o00030000oooooooo
013oool00ol0VOooooooo`1Boooo002?oooo0P0002Lco`000`000?ooooooo`0@oooo00?o09Wooooo
ool0D_ooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`0Aoooo00?o09Woooooool0D_oo
o`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`0Boooo00?o09Woooooool0D_ooo`00Sooo
o`030000<ol0<ol002@co`000`000?ooooooo`0Boooo00?o09Woooooool0D_ooo`00Soooo`030000
<ol0<ol002<co`000`000?ooooooo`0Coooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol0
02<co`000`000?ooooooo`0Coooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol0028co`00
0`000?ooooooo`0Doooo00?o09Woooooool0D_ooo`00Soooo`80000S<ol000<0003oooooool05?oo
o`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000Q<ol000<0003oooooool05Oooo`03o`2I
oooooooo05;oool008ooool00`0003?o03?o000Q<ol000<0003oooooool05Oooo`03o`2Ioooooooo
05;oool008ooool00`0003?o03?o000P<ol000<0003oooooool05_ooo`03o`2Ioooooooo05;oool0
08ooool00`0003?o03?o000P<ol000<0003oooooool05_ooo`03o`2Ioooooooo05;oool008ooool0
0`0003?o03?o000P<ol000<0003oooooool05_ooo`03o`2Ioooooooo05;oool008ooool2000083?o
00030000oooooooo01Ooool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`007c?o00030000
oooooooo01Ooool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`007S?o00030000oooooooo
01Soool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`007S?o00030000oooooooo01Soool0
0ol0VOooooooo`1Boooo0027oooo100000Coool00`0003?o03?o000N<ol000<0003oooooool06?oo
o`03o`2Ioooooooo05;oool008Ooool00`000?ooooooo`05oooo00<0000co`0co`007C?o00030000
oooooooo01Woool00ol0VOooooooo`1Boooo0028oooo00<0003oooooool01?ooo`<0000M<ol000<0
003oooooool06Oooo`03o`2Ioooooooo05;oool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`007C?o00030000oooooooo01Woool00ol0VOooooooo`1Boooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0073?o00030000oooooooo01[oool00ol0VOooooooo`1Boooo0028oooo0P00
00Goool00`0003?o03?o000L<ol000<0003oooooool06_ooo`03o`2Ioooooooo05;oool008ooool0
0`0003?o03?o000K<ol000<0003oooooool06oooo`03o`2Ioooooooo05;oool008ooool00`0003?o
03?o000K<ol000<0003oooooool06oooo`03o`2Ioooooooo05;oool008ooool2000073?o00030000
oooooooo01_oool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`006S?o00030000oooooooo
01coool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`006S?o00030000oooooooo01coool0
0ol0VOooooooo`1Boooo002?oooo00<0000co`0co`006S?o00030000oooooooo01coool00ol0VOoo
ooooo`1Boooo002?oooo00<0000co`0co`006S?o00030000oooooooo01coool00ol0VOooooooo`1B
oooo002?oooo00<0000co`0co`006C?o00030000oooooooo01goool00ol0VOooooooo`1Boooo002?
oooo00<0000co`0co`006C?o00030000oooooooo01goool00ol0VOooooooo`1Boooo002?oooo0P00
01Xco`000`000?ooooooo`0Moooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol001Pco`00
0`000?ooooooo`0Noooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol001Pco`000`000?oo
ooooo`0Noooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0N
oooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Ooooo00?o
09Woooooool0D_ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Ooooo00?o09Wooooo
ool0D_ooo`00Soooo`80000H<ol000<0003oooooool07oooo`03o`2Ioooooooo05;oool008ooool0
0`0003?o03?o000G<ol000<0003oooooool07oooo`03o`2Ioooooooo05;oool008ooool00`0003?o
03?o000F<ol000<0003oooooool08?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000F
<ol000<0003oooooool08?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000F<ol000<0
003oooooool08?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000E<ol000<0003ooooo
ool08Oooo`03o`2Ioooooooo05;oool008ooool200005S?o00030000oooooooo027oool00ol0VOoo
ooooo`1Boooo002?oooo00<0000co`0co`005C?o00030000oooooooo027oool00ol0VOooooooo`1B
oooo002?oooo00<0000co`0co`005C?o00030000oooooooo027oool00ol0VOooooooo`1Boooo002?
oooo00<0000co`0co`0053?o00030000oooooooo02;oool00ol0VOooooooo`1Boooo0028oooo0P00
00Goool00`0003?o03?o000D<ol000<0003oooooool08_ooo`03o`2Ioooooooo05;oool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o000D<ol000<0003oooooool08_ooo`03o`2Ioooooooo
05;oool008Woool00`000?ooooooo`03oooo0`0001<co`000`000?ooooooo`0Soooo00?o09Wooooo
ool0D_ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000C<ol000<0003oooooool08ooo
o`03o`2Ioooooooo05;oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000C<ol000<0
003oooooool08oooo`03o`2Ioooooooo05;oool008Soool200001Oooo`030000<ol0<ol0018co`00
0`000?ooooooo`0Toooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`0Toooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0T
oooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Toooo00?o
09Woooooool0D_ooo`00Soooo`80000B<ol000<0003oooooool09Oooo`03o`2Ioooooooo05;oool0
08ooool00`0003?o03?o000A<ol000<0003oooooool09Oooo`03o`2Ioooooooo05;oool008ooool0
0`0003?o03?o000A<ol000<0003oooooool09Oooo`03o`2Ioooooooo05;oool008ooool00`0003?o
03?o000A<ol000<0003oooooool09Oooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000@
<ol000<0003oooooool09_ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000@<ol000<0
003oooooool09_ooo`03o`2Ioooooooo05;oool008ooool200004C?o00030000oooooooo02Koool0
0ol0VOooooooo`1Boooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Koool00ol0VOoo
ooooo`1Boooo002?oooo00<0000co`0co`003c?o00030000oooooooo02Ooool00ol0VOooooooo`1B
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo02Ooool00ol0VOooooooo`1Boooo002?
oooo00<0000co`0co`003c?o00030000oooooooo02Ooool00ol0VOooooooo`1Boooo002?oooo00<0
000co`0co`003c?o00030000oooooooo02Ooool00ol0VOooooooo`1Boooo002?oooo0P00010co`00
0`000?ooooooo`0Woooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`0Xoooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0X
oooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Xoooo00?o
09Woooooool0D_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0D_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Xoooo00?o09Woooooool0D_oo
o`00Soooo`80000><ol000<0003oooooool0:Oooo`03o`2Ioooooooo05;oool008ooool00`0003?o
03?o000=<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000=
<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000=<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000<<ol000<0003ooooo
ool0:_ooo`03o`2Ioooooooo05;oool008Woool300000oooo`030000<ol0<ol000`co`000`000?oo
ooooo`0Zoooo00?o09Woooooool0D_ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o000<
<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05;oool008Ooool500000oooo`<0000<<ol000<0
003oooooool0:_ooo`03o`2Ioooooooo05;oool008Ooool010000?ooooooo`0000Coool?<ol0P_oo
o`00R?ooo`030000oooo000000Coool?<ol0P_ooo`00ROooo`800004oooo3c?o08;oool008ooool?
<ol0P_ooo`00Soooo`lco`22oooo001loooo00<0003oooooool04?ooo`hco`04oooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`06oooo3S?o00Goool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`03<ol0
0000000000@co`02000013?o00800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000<ol0<ol0000023?o
00040000<ol0oooo00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000<ol0<ol000002S?o0003oooo0000oooo00?oool00`000?ooooooo`1j
oooo001koooo00<0003oooooool01@0000coool0100003?o03?o000000Tco`0200001?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0000co`0co`000009<ol000<0
003oooooool00oooo`030000oooooooo07_oool007coool00`000?ooooooo`0@oooo00<co`000000
00002S?o00<00002oooo00<0003oooooool0O?ooo`00Soooo`dco`24oooo002?oooo3C?o08Coool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-1.18824, \
-1.14361, 0.00828225, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-1.18824, -1.14361, 0.00828225, 0.031907}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
ScreenStyleEnvironment->"Working",
WindowSize->{757, 792},
WindowMargins->{{Automatic, 169}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 183, 5, 96, "Title"],
Cell[1913, 59, 971, 26, 239, "Text"],
Cell[2887, 87, 120, 4, 49, "Text"],
Cell[3010, 93, 630, 14, 19, "Input",
  CellOpen->False],
Cell[3643, 109, 73, 2, 19, "Input",
  CellOpen->False],
Cell[3719, 113, 99, 1, 49, "Text"],
Cell[3821, 116, 716, 16, 19, "Input",
  CellOpen->False],
Cell[4540, 134, 74, 2, 19, "Input",
  CellOpen->False],
Cell[4617, 138, 75, 2, 19, "Input",
  CellOpen->False],
Cell[4695, 142, 364, 12, 49, "Text"],

Cell[CellGroupData[{
Cell[5084, 158, 653, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[5762, 173, 26678, 1007, 186, 13194, 836, "GraphicsData", "PostScript", \
"Graphics"],
Cell[32443, 1182, 26791, 1009, 186, 13213, 837, "GraphicsData", "PostScript", \
"Graphics"],
Cell[59237, 2193, 26756, 1007, 186, 13178, 835, "GraphicsData", "PostScript", \
"Graphics"],
Cell[85996, 3202, 26758, 1008, 186, 13196, 836, "GraphicsData", "PostScript", \
"Graphics"],
Cell[112757, 4212, 26795, 1009, 186, 13213, 837, "GraphicsData", \
"PostScript", "Graphics"],
Cell[139555, 5223, 26682, 1008, 186, 13209, 837, "GraphicsData", \
"PostScript", "Graphics"],
Cell[166240, 6233, 26834, 1011, 186, 13244, 839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[193077, 7246, 26795, 1009, 186, 13213, 837, "GraphicsData", \
"PostScript", "Graphics"],
Cell[219875, 8257, 26774, 1009, 186, 13212, 837, "GraphicsData", \
"PostScript", "Graphics"],
Cell[246652, 9268, 26809, 1010, 186, 13227, 838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[273464, 10280, 26702, 1009, 186, 13225, 838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[300169, 11291, 26786, 1009, 186, 13212, 837, "GraphicsData", \
"PostScript", "Graphics"],
Cell[326958, 12302, 26803, 1010, 186, 13229, 838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[353764, 13314, 26801, 1011, 186, 13243, 839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[380568, 14327, 26795, 1009, 186, 13213, 837, "GraphicsData", \
"PostScript", "Graphics"],
Cell[407366, 15338, 26695, 1009, 186, 13226, 838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[434064, 16349, 26818, 1011, 186, 13244, 839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[460885, 17362, 26802, 1010, 186, 13228, 838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[487690, 18374, 26776, 1010, 186, 13243, 839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[514469, 19386, 26786, 1011, 186, 13244, 839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[541258, 20399, 26671, 1008, 186, 13227, 838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[567932, 21409, 26783, 1011, 186, 13245, 839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[594718, 22422, 26801, 1011, 186, 13243, 839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[621522, 23435, 26835, 1012, 186, 13261, 840, "GraphicsData", \
"PostScript", "Graphics"],
Cell[648360, 24449, 26815, 1011, 186, 13245, 839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[675178, 25462, 26694, 1009, 186, 13242, 839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[701875, 26473, 26850, 1012, 186, 13260, 840, "GraphicsData", \
"PostScript", "Graphics"],
Cell[728728, 27487, 26847, 1012, 186, 13261, 840, "GraphicsData", \
"PostScript", "Graphics"],
Cell[755578, 28501, 26803, 1011, 186, 13245, 839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[782384, 29514, 26847, 1012, 186, 13257, 840, "GraphicsData", \
"PostScript", "Graphics"],
Cell[809234, 30528, 26744, 1012, 186, 13275, 841, "GraphicsData", \
"PostScript", "Graphics"],
Cell[835981, 31542, 26874, 1014, 186, 13292, 842, "GraphicsData", \
"PostScript", "Graphics"],
Cell[862858, 32558, 26873, 1014, 186, 13291, 842, "GraphicsData", \
"PostScript", "Graphics"],
Cell[889734, 33574, 26843, 1013, 186, 13277, 841, "GraphicsData", \
"PostScript", "Graphics"],
Cell[916580, 34589, 26883, 1014, 186, 13293, 842, "GraphicsData", \
"PostScript", "Graphics"],
Cell[943466, 35605, 26752, 1012, 186, 13275, 841, "GraphicsData", \
"PostScript", "Graphics"],
Cell[970221, 36619, 26830, 1012, 186, 13260, 840, "GraphicsData", \
"PostScript", "Graphics"],
Cell[997054, 37633, 26889, 1015, 186, 13307, 843, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1023946, 38650, 26843, 1014, 186, 13289, 842, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1050792, 39666, 26697, 1012, 186, 13293, 842, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1077492, 40680, 26378, 1008, 186, 13290, 842, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1103873, 41690, 26462, 1010, 186, 13309, 843, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1130338, 42702, 26528, 1011, 186, 13323, 844, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1156869, 43715, 25028, 992, 186, 13309, 843, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1181900, 44709, 24408, 984, 186, 13309, 843, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1206311, 45695, 23599, 966, 186, 12941, 830, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1229913, 46663, 24149, 989, 186, 13264, 850, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1254065, 47654, 24749, 996, 186, 13261, 850, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1278817, 48652, 25550, 1007, 186, 13280, 851, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1304370, 49661, 26871, 1022, 186, 13261, 850, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1331244, 50685, 26547, 1018, 186, 13261, 850, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1357794, 51705, 26544, 1019, 186, 13270, 851, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1384341, 52726, 26315, 1016, 186, 13263, 850, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1410659, 53744, 26325, 1018, 186, 13306, 853, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1436987, 54764, 26235, 1015, 186, 13277, 851, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1463225, 55781, 26266, 1013, 186, 13227, 848, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1489494, 56796, 26523, 1019, 186, 13277, 851, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1516020, 57817, 26591, 1018, 186, 13244, 849, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1542614, 58837, 26752, 1023, 186, 13304, 853, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1569369, 59862, 26861, 1028, 186, 13372, 857, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1596233, 60892, 26808, 1025, 186, 13323, 854, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1623044, 61919, 26976, 1026, 186, 13305, 853, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1650023, 62947, 27050, 1029, 186, 13338, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1677076, 63978, 27119, 1030, 186, 13338, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1704198, 65010, 27071, 1026, 186, 13278, 851, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1731272, 66038, 26954, 1026, 186, 13303, 853, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1758229, 67066, 27107, 1030, 186, 13355, 856, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1785339, 68098, 27234, 1034, 186, 13409, 859, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1812576, 69134, 27292, 1036, 186, 13418, 860, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1839871, 70172, 27301, 1032, 186, 13338, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1867175, 71206, 27233, 1032, 186, 13355, 856, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1894411, 72240, 27281, 1032, 186, 13359, 856, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1921695, 73274, 27421, 1040, 186, 13458, 863, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1949119, 74316, 27442, 1039, 186, 13447, 862, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1976564, 75357, 27440, 1039, 186, 13449, 862, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2004007, 76398, 27489, 1041, 186, 13482, 864, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2031499, 77441, 27738, 1048, 186, 13544, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2059240, 78491, 27745, 1048, 186, 13551, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2086988, 79541, 27886, 1056, 186, 13668, 876, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2114877, 80599, 27947, 1059, 186, 13721, 879, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2142827, 81660, 28013, 1068, 186, 13872, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2170843, 82730, 28186, 1074, 186, 13956, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2199032, 83806, 28295, 1080, 186, 14045, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2227330, 84888, 28291, 1079, 186, 14012, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2255624, 85969, 28476, 1090, 186, 14189, 909, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2284103, 87061, 28338, 1087, 186, 14173, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2312444, 88150, 28488, 1089, 186, 14169, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2340935, 89241, 28530, 1092, 186, 14227, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2369468, 90335, 28487, 1089, 186, 14176, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2397958, 91426, 28520, 1092, 186, 14221, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2426481, 92520, 28418, 1091, 186, 14237, 912, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2454902, 93613, 28514, 1091, 186, 14211, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2483419, 94706, 28505, 1092, 186, 14222, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2511927, 95800, 28228, 1079, 186, 14038, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2540158, 96881, 28285, 1083, 186, 14112, 904, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2568446, 97966, 28143, 1087, 186, 14196, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2596592, 99055, 28342, 1084, 186, 14112, 904, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2624937, 100141, 28372, 1086, 186, 14142, 906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2653312, 101229, 28419, 1086, 186, 14112, 905, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2681734, 102317, 28399, 1084, 186, 14100, 903, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2710136, 103403, 28299, 1086, 186, 14150, 907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2738438, 104491, 28369, 1086, 186, 14139, 906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2766810, 105579, 28324, 1085, 186, 14118, 905, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2795137, 106666, 28344, 1083, 186, 14102, 903, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2823484, 107751, 28375, 1086, 186, 14145, 906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2851862, 108839, 28249, 1083, 186, 14116, 904, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2880114, 109924, 28407, 1086, 186, 14149, 906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2908524, 111012, 28378, 1086, 186, 14148, 906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2936905, 112100, 28358, 1083, 186, 14096, 903, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2965266, 113185, 28404, 1086, 186, 14133, 905, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2993673, 114273, 28323, 1089, 186, 14206, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3021999, 115364, 28427, 1088, 186, 14144, 907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3050429, 116454, 28365, 1085, 186, 14119, 905, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3078797, 117541, 28363, 1085, 186, 14117, 905, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3107163, 118628, 28232, 1079, 186, 14051, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3135398, 119709, 28143, 1084, 186, 14160, 907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3163544, 120795, 28256, 1086, 186, 14147, 907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3191803, 121883, 28341, 1089, 186, 14200, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3220147, 122974, 28288, 1086, 186, 14155, 907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3248438, 124062, 28390, 1089, 186, 14184, 909, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3276831, 125153, 28232, 1086, 186, 14160, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3305066, 126241, 28365, 1087, 186, 14184, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3333434, 127330, 28294, 1086, 186, 14161, 907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3361731, 128418, 28298, 1086, 186, 14157, 907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3390032, 129506, 28371, 1088, 186, 14173, 908, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3418406, 130596, 28220, 1083, 186, 14107, 904, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3446629, 131681, 28318, 1082, 186, 14068, 902, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3474950, 132765, 28335, 1081, 186, 14073, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3503288, 133848, 28337, 1082, 186, 14066, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3531628, 134932, 28267, 1078, 186, 13996, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3559898, 136012, 27993, 1066, 186, 13844, 887, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3587894, 137080, 28133, 1068, 186, 13854, 887, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3616030, 138150, 28053, 1065, 186, 13811, 885, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3644086, 139217, 28070, 1064, 186, 13779, 883, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3672159, 140283, 28095, 1066, 186, 13816, 885, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3700257, 141351, 27986, 1064, 186, 13800, 884, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3728246, 142417, 28096, 1065, 186, 13801, 884, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3756345, 143484, 28039, 1063, 186, 13764, 882, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3784387, 144549, 28072, 1063, 186, 13765, 882, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3812462, 145614, 28081, 1064, 186, 13790, 883, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3840546, 146680, 27978, 1063, 186, 13784, 883, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3868573, 147749, 654, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[3869252, 147764, 24578, 903, 186, 11583, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3893833, 148669, 24531, 901, 186, 11567, 737, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3918367, 149572, 24551, 902, 186, 11583, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3942921, 150476, 24544, 902, 186, 11567, 737, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3967468, 151380, 24568, 903, 186, 11583, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3992039, 152285, 24509, 903, 186, 11597, 739, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4016551, 153190, 24519, 903, 186, 11599, 739, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4041073, 154095, 24382, 900, 186, 11567, 737, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4065458, 154997, 24268, 898, 186, 11567, 737, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4089729, 155897, 24146, 897, 186, 11583, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4113878, 156796, 24145, 898, 186, 11598, 739, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4138026, 157696, 24183, 898, 186, 11583, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4162212, 158596, 22996, 884, 186, 11599, 739, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4185211, 159482, 22243, 874, 186, 11583, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4207457, 160358, 22089, 873, 186, 11599, 739, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4229549, 161233, 21284, 853, 186, 11199, 724, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4250836, 162088, 21772, 873, 186, 11472, 741, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4272611, 162963, 22207, 879, 186, 11482, 742, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4294821, 163844, 22465, 885, 186, 11554, 746, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4317289, 164731, 24583, 910, 186, 11534, 745, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4341875, 165643, 24634, 911, 186, 11536, 745, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4366512, 166556, 24698, 913, 186, 11551, 746, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4391213, 167471, 24710, 912, 186, 11535, 745, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4415926, 168385, 24702, 911, 186, 11523, 744, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4440631, 169298, 24718, 913, 186, 11555, 746, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4465352, 170213, 24519, 910, 186, 11551, 746, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4489874, 171125, 24573, 912, 186, 11568, 747, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4514450, 172039, 24486, 912, 186, 11586, 748, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4538939, 172953, 24320, 910, 186, 11586, 748, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4563262, 173865, 24281, 910, 186, 11600, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4587546, 174777, 24259, 910, 186, 11598, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4611808, 175689, 24245, 909, 186, 11601, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4636056, 176600, 24174, 905, 186, 11534, 745, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4660233, 177507, 24275, 908, 186, 11570, 747, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4684511, 178417, 24268, 906, 186, 11522, 744, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4708782, 179325, 24236, 907, 186, 11551, 746, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4733021, 180234, 24401, 910, 186, 11570, 747, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4757425, 181146, 24453, 912, 186, 11598, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4781881, 182060, 24535, 915, 186, 11648, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4806419, 182977, 24514, 913, 186, 11598, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4830936, 183892, 24610, 916, 186, 11650, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4855549, 184810, 24616, 914, 186, 11599, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4880168, 185726, 24683, 914, 186, 11585, 748, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4904854, 186642, 24688, 915, 186, 11598, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4929545, 187559, 24702, 915, 186, 11600, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4954250, 188476, 24673, 917, 186, 11644, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4978926, 189395, 24835, 919, 186, 11648, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5003764, 190316, 24849, 919, 186, 11629, 751, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5028616, 191237, 24984, 924, 186, 11708, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5053603, 192163, 24886, 917, 186, 11602, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5078492, 193082, 24891, 917, 186, 11582, 748, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5103386, 194001, 24951, 919, 186, 11618, 750, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5128340, 194922, 25072, 926, 186, 11727, 757, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5153415, 195850, 24978, 920, 186, 11633, 751, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5178396, 196772, 25010, 922, 186, 11661, 753, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5203409, 197696, 24907, 920, 186, 11643, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5228319, 198618, 24964, 921, 186, 11647, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5253286, 199541, 24864, 917, 186, 11596, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5278153, 200460, 24877, 920, 186, 11645, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5303033, 201382, 24940, 922, 186, 11676, 754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5327976, 202306, 24977, 922, 186, 11660, 753, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5352956, 203230, 25018, 921, 186, 11649, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5377977, 204153, 25009, 920, 186, 11619, 750, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5402989, 205075, 25054, 920, 186, 11616, 750, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5428046, 205997, 25107, 923, 186, 11648, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5453156, 206922, 25041, 923, 186, 11659, 753, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

