(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3928840,     165386]*)
(*NotebookOutlinePosition[   3929583,     165411]*)
(*  CellTagsIndexPosition[   3929539,     165407]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["FOCUSING", "Text",
    FontSize->14,
    Background->None],
  StyleBox[" BEHIND NONHOMOGENEITY", "Text",
    FontSize->14,
    Background->None]
}], "Title",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["The wavefront  and the tail  are incident from the left.\n\nThe \
nonhomogeneity  ",
    FontSize->12],
  StyleBox["is located on the negative ",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["x",
    FontSize->12,
    FontSlant->"Italic",
    CharacterEncoding->"WindowsANSI"],
  StyleBox["-axis.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["  \n\nThe focusing location,  ",
    FontSize->12],
  StyleBox["x0",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox[" >0, is behind the nonhomogeneity and needs to be specified. \n\n\
The potential   v[x], which is ",
    FontSize->12],
  StyleBox["the nonhomogeneity, is strictly positive.  \n\nThe transmission \
coefficient, left reflection coefficient, and right reflection coefficient, \
respectively, are denoted by  T[k],  L[k],  R[k].\n\nThe tail of the wave is \
denoted by  g[x,t].\n\nThe focusing moment is chosen as  t=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  FontSize->18,
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The potential and the scattering coefficients are given next:\
\>", \
"Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(Clear[v, T, L, R, x0, g]; 
    v[x_] = UnitStep[\(-x\)]\ 16 \((Sqrt[2] + 
              1)\)^2\ E^\((\(-2\)\ Sqrt[
                  2]\ x)\)/\((\((1 + 
                        Sqrt[2])\)^2\ \ E^\((\(-2\)\ Sqrt[2]\ x)\) - 
                1)\)^2;\ \), "\[IndentingNewLine]", 
    \(\(T[k_] = k \((k + I\ Sqrt[2])\)/\((k + I)\)^2;\)\), "\n", 
    \(\(L[
          k_] = \(-2\) \((k + 
                I\ Sqrt[2])\)/\((\((k + I)\)^2\ \((k - 
                    I\ Sqrt[2])\))\);\)\), "\n", 
    \(\(R[k_] = 1/\((k + I)\)^2;\)\)}], "Input",
  CellOpen->False],

Cell["\<\
Specify the focusing location  x0, a nonnegative number, \
next:\
\>", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(x0 = 1;\)\(\ \)\)\)], "Input"],

Cell["The tail  g[x,t]  of the focusing  wave is evaluated  next:", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(q[x_] = 
        2\ Sqrt[2]/\((\((1 + Sqrt[2])\)^2\ \ E^\((\(-2\)\ Sqrt[2]\ x)\) - 
                1)\);\)\n\t\t\), "\n", 
    \(\(q16[x_, t_] = \ 
        q[x]\ \((1 + 
                Sqrt[2])\)^2\ \ E^\((\(-\ Sqrt[2]\)\ \ \((x - x0 - t)\))\)/
            4;\)\n\t\), "\n", 
    \(\t\(q17[x_, 
          t_] = \((1 + q[x]/Sqrt[2])\)/
            Sqrt[2] - \((\(-1\) + Sqrt[2])\)^2\ \((1 + 
                q[x]/\((2\ Sqrt[2])\))\) 
            E^\((Sqrt[2]\ \ \((x - x0 - t)\))\)/Sqrt[2];\)\n\), "\n", 
    \(\(\(q18[x_, t_] = \(-q[x]\) 
          E^\((\(-\ Sqrt[2]\)\ \ \((x + x0 - t)\))\)/4;\)\(\n\)
    \)\), "\n", 
    \(\(q19[x_, 
          t_] = \(-\((1 + q[x]/Sqrt[2])\)\)/
            Sqrt[2] + \((1 + q[x]/\((2\ Sqrt[2])\))\) 
            E^\((Sqrt[2]\ \ \((x + x0 - t)\))\)/Sqrt[2];\)\n\t\t\t\), "\n", 
    \(\t\t\t\(q20[x_, t_] = 
        q[x]\ \ \ E^\((\(-\ Sqrt[2]\)\ \ \((x + x0 + t)\))\)/
            4;\)\n\t\t\t\t\t\), "\n", 
    \(\t\t\(q21[x_, 
          t_] = \((1 + q[x]/Sqrt[2])\)/
            Sqrt[2] - \((1 + q[x]/\((2\ Sqrt[2])\))\) 
            E^\((Sqrt[2]\ \ \((x + x0 + t)\))\)/
              Sqrt[2];\)\n\t\t\t\n\t\), "\n", 
    \(\t\(q22[x_, 
          t_] = \(-\((1 + q[x]/Sqrt[2])\)\)/
            Sqrt[2]\ \  + \((Sqrt[2] - 1)\)^2\ \((1 + 
                q[x]/\((2\ Sqrt[2])\))\) 
            E^\((\(-Sqrt[2]\)\ \ \((\(-x\) + x0 - t)\))\)/
              Sqrt[2];\)\n\), "\n", 
    \(\(\(q23[x_, 
          t_] = \ \(-q[
              x]\)\ \ \((Sqrt[2] + 1)\)^2\ \ E^\((\ 
                Sqrt[2]\ \ \((\(-x\) + x0 - t)\))\)/4;\)\(\n\)
    \)\), "\n", 
    \(\(q24[x_, 
          t_] = \((q[x] - 2 + 
              Sqrt[2] + \((\(-x\) + x0 - 
                    t)\)\ \((1 + q[x]\ \((Sqrt[2] + 1)\))\)/\((Sqrt[2] + 
                      1)\))\)\ E^\((\(-x\) + x0 - t)\);\)\), "\n", 
    \(\(g[x_, t_] = \ 
        UnitStep[
              x]\ \((x + x0 - t)\)\ \ E^\((x + x0 - t)\)\ UnitStep[\(-x\) - 
                x0 + t]\  + 
          UnitStep[\(-x\)] \((q16[x, t]\ \n\t\tUnitStep[x - x0 - t]\  + \ 
                q17[x, t]\ UnitStep[\(-x\) + x0 + t]\  + 
                q18[x, t]\ UnitStep[x + x0 - t]\n + 
                q19[x, t]\ UnitStep[\(-x\) - x0 + t]\  + \ 
                q20[x, t]\ UnitStep[x + x0 + t] + 
                q21[x, t]\ UnitStep[\(-x\) - x0 - t] + 
                q22[x, t]\ UnitStep[\(-x\) + x0 - t] + \((q23[x, t]\  + 
                      q24[x, t])\)\ UnitStep[x - x0 + t])\);\)\)}], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input",
  CellOpen->False],

Cell[TextData[{
  "The focusing wave is animated  next. The wavefront (",
  StyleBox["magenta",
    FontColor->RGBColor[1, 0, 1]],
  ") and the tail (",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  ") are incident from the left onto the nonhomogeneity (",
  StyleBox["green",
    FontColor->RGBColor[0, 1, 0]],
  "):"
}], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-7\), \ 
              5}, \ PlotRange -> {\(-1\), 4}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-7\), \ 5}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(-1\), 
                4}], \[IndentingNewLine]\ \ \ \ \ \ \ Plot[{g[x, 
                t]}, {x, \ \(-7\), \ 5}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(-1\), 4}]}, \[IndentingNewLine]\ {t, \ \(-5\), \ 
          3.8,  .1}, PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -22.0938 0 ]
[.5 .63053 22.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -83.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.25666 .12361 L
.2593 .12361 L
.26045 .12361 L
.26171 .12361 L
s
.26171 .12361 m
.26223 .61803 L
s
0 .4 1 r
.02381 .14464 m
.04262 .15301 L
.06244 .16548 L
.07286 .17401 L
.08255 .18352 L
.09388 .19691 L
.09944 .20456 L
.10189 .20816 L
.10256 .20918 L
.10328 .21012 L
.10458 .2101 L
.10933 .21002 L
.11437 .20993 L
.125 .2097 L
.14357 .20919 L
.15368 .20883 L
.16471 .20836 L
.17524 .20781 L
.1848 .20721 L
.20447 .20562 L
.21527 .20448 L
.22544 .20318 L
.23521 .20169 L
.24552 .19981 L
.25433 .19791 L
.25674 .19733 L
.25933 .19669 L
.26058 .19636 L
.26177 .19605 L
.26283 .12361 L
.26399 .12361 L
.26521 .12361 L
.26633 .12361 L
.26755 .12361 L
.26884 .12361 L
.26997 .12361 L
.27101 .12361 L
.27216 .12361 L
.27339 .12361 L
.27409 .12361 L
.27473 .12361 L
.27544 .12361 L
.27619 .12361 L
.27745 .12361 L
.27816 .12361 L
.27883 .12361 L
.27997 .12361 L
.28119 .12361 L
.28189 .12361 L
.28253 .12361 L
Mistroke
.28377 .12361 L
.28444 .12361 L
.28517 .12361 L
.28648 .12361 L
.28714 .12361 L
.28783 .12361 L
.28906 .12361 L
.29025 .12361 L
.29137 .12361 L
.29259 .12361 L
.2939 .12361 L
.29462 .12361 L
.2953 .12361 L
.29604 .12361 L
.29682 .12361 L
.29814 .12361 L
.29889 .12361 L
.29959 .12361 L
.30089 .12361 L
.30209 .12361 L
.3034 .12361 L
.30411 .12361 L
.30478 .12361 L
.30602 .12361 L
.30667 .12361 L
.30736 .12361 L
.30852 .12361 L
.30979 .12361 L
.31093 .12361 L
.31215 .12361 L
.3133 .12361 L
.31435 .12361 L
.31565 .12361 L
.31686 .12361 L
.31748 .12361 L
.31818 .12361 L
.31891 .12361 L
.31959 .12361 L
.32083 .12361 L
.32198 .12361 L
.32323 .12361 L
.32386 .12361 L
.32456 .12361 L
.3258 .12361 L
.32697 .12361 L
.32802 .12361 L
.32916 .12361 L
.3304 .12361 L
.33171 .12361 L
.33284 .12361 L
Mistroke
.33407 .12361 L
.33523 .12361 L
.33628 .12361 L
.3375 .12361 L
.33865 .12361 L
.33971 .12361 L
.3407 .12361 L
.34178 .12361 L
.34294 .12361 L
.34418 .12361 L
.34489 .12361 L
.34554 .12361 L
.34624 .12361 L
.34687 .12361 L
.34761 .12361 L
.3483 .12361 L
.34953 .12361 L
.35066 .12361 L
.35191 .12361 L
.35254 .12361 L
.35323 .12361 L
.35393 .12361 L
.35467 .12361 L
.356 .12361 L
.35673 .12361 L
.35742 .12361 L
.35817 .12361 L
.35897 .12361 L
.35967 .12361 L
.36043 .12361 L
.36114 .12361 L
.3618 .12361 L
.36304 .12361 L
.36372 .12361 L
.36436 .12361 L
.36562 .12361 L
.36678 .12361 L
.36786 .12361 L
.36903 .12361 L
.37032 .12361 L
.37104 .12361 L
.3717 .12361 L
.37297 .12361 L
.37417 .12361 L
.37543 .12361 L
.37607 .12361 L
.37677 .12361 L
.378 .12361 L
.37915 .12361 L
.37985 .12361 L
Mistroke
.38051 .12361 L
.38175 .12361 L
.38245 .12361 L
.38309 .12361 L
.38379 .12361 L
.38454 .12361 L
.38574 .12361 L
.38706 .12361 L
.3883 .12361 L
.38945 .12361 L
.39059 .12361 L
.39162 .12361 L
.39282 .12361 L
.39394 .12361 L
.39517 .12361 L
.39647 .12361 L
.39758 .12361 L
.3988 .12361 L
.40012 .12361 L
.40085 .12361 L
.40152 .12361 L
.40283 .12361 L
.40406 .12361 L
.40511 .12361 L
.40627 .12361 L
.40748 .12361 L
.40861 .12361 L
.40967 .12361 L
.41064 .12361 L
.41171 .12361 L
.41283 .12361 L
.41397 .12361 L
.41518 .12361 L
.41633 .12361 L
.41738 .12361 L
.41861 .12361 L
.4193 .12361 L
.41994 .12361 L
.42112 .12361 L
.42236 .12361 L
.42357 .12361 L
.42489 .12361 L
.42613 .12361 L
.42729 .12361 L
.42843 .12361 L
.42947 .12361 L
.4306 .12361 L
.43179 .12361 L
.4331 .12361 L
.4343 .12361 L
Mistroke
.43559 .12361 L
.43633 .12361 L
.43701 .12361 L
.43825 .12361 L
.43938 .12361 L
.44069 .12361 L
.44193 .12361 L
.44298 .12361 L
.44414 .12361 L
.44535 .12361 L
.44649 .12361 L
.44747 .12361 L
.44852 .12361 L
.44966 .12361 L
.4507 .12361 L
.45184 .12361 L
.45306 .12361 L
.45421 .12361 L
.45526 .12361 L
.45649 .12361 L
.45718 .12361 L
.45782 .12361 L
.45899 .12361 L
.46024 .12361 L
.46145 .12361 L
.46277 .12361 L
.46402 .12361 L
.46518 .12361 L
.46622 .12361 L
.46737 .12361 L
.46857 .12361 L
.46969 .12361 L
.47093 .12361 L
.47224 .12361 L
.47335 .12361 L
.47457 .12361 L
.47589 .12361 L
.47663 .12361 L
.4773 .12361 L
.47861 .12361 L
.47984 .12361 L
.4809 .12361 L
.48206 .12361 L
.48327 .12361 L
.48441 .12361 L
.48547 .12361 L
.48644 .12361 L
.48756 .12361 L
.48863 .12361 L
.48977 .12361 L
Mistroke
.49099 .12361 L
.49214 .12361 L
.49319 .12361 L
.49442 .12361 L
.49511 .12361 L
.49575 .12361 L
.49692 .12361 L
.49816 .12361 L
.49938 .12361 L
.50007 .12361 L
.50071 .12361 L
.50188 .12361 L
.50312 .12361 L
.50418 .12361 L
.5053 .12361 L
.50652 .12361 L
.50764 .12361 L
.50883 .12361 L
.51014 .12361 L
.51135 .12361 L
.51248 .12361 L
.51317 .12361 L
.51383 .12361 L
.51505 .12361 L
.51637 .12361 L
.51712 .12361 L
.51781 .12361 L
.51886 .12361 L
.52 .12361 L
.52107 .12361 L
.52205 .12361 L
.52319 .12361 L
.52444 .12361 L
.52562 .12361 L
.52671 .12361 L
.52795 .12361 L
.52911 .12361 L
.53015 .12361 L
.53128 .12361 L
.53251 .12361 L
.53381 .12361 L
.53493 .12361 L
.53614 .12361 L
.53745 .12361 L
.53866 .12361 L
.5393 .12361 L
.53999 .12361 L
.54072 .12361 L
.5414 .12361 L
.54265 .12361 L
Mistroke
.5438 .12361 L
.54512 .12361 L
.54638 .12361 L
.5475 .12361 L
.54869 .12361 L
.54981 .12361 L
.55083 .12361 L
.55203 .12361 L
.55334 .12361 L
.55456 .12361 L
.5557 .12361 L
.55691 .12361 L
.5582 .12361 L
.55943 .12361 L
.56055 .12361 L
.56185 .12361 L
.56259 .12361 L
.56328 .12361 L
.56454 .12361 L
.56517 .12361 L
.56587 .12361 L
.56655 .12361 L
.56726 .12361 L
.56854 .12361 L
.56925 .12361 L
.56991 .12361 L
.57064 .12361 L
.57142 .12361 L
.57209 .12361 L
.57282 .12361 L
.57351 .12361 L
.57415 .12361 L
.57535 .12361 L
.57663 .12361 L
.57783 .12361 L
.57915 .12361 L
.5804 .12361 L
.58155 .12361 L
.58605 .12361 L
.59618 .12361 L
.61449 .12361 L
.65365 .12361 L
.69526 .12361 L
.73535 .12361 L
.77393 .12361 L
.81496 .12361 L
.85447 .12361 L
.89247 .12361 L
.93293 .12361 L
.97186 .12361 L
Mistroke
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -22.0938 0 ]
[.5 .63053 22.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -83.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_oo
o`@0000K<ol000<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Yoooo001C
oooo00<0I_ooooooool0<_ooo`@0000G<ol000<0003oooooool0N_ooo`00Doooo`0306Kooooooooo
03Koool00`0003?o03?o000D<ol000<0003oooooool0N_ooo`00Doooo`0306Kooooooooo03Ooool2
000053?o00030000oooooooo07[oool001Koool206Ko>oooo`0306Kooooooooo03Woool00`0003?o
03?o000A<ol000<0003oooooool0N_ooo`006?ooo`80I_lioooo00<0I_ooooooool0>_ooo`030000
<ol0<ol0010co`020000Noooo`006_ooo`80I_lgoooo00<0I_ooooooool0>oooo`80000@<ol000<0
003oooooool0N_ooo`007?ooo`80I_leoooo00<0I_ooooooool0?Oooo`030000<ol0<ol000dco`00
0`000?ooooooo`1joooo000Noooo0P1Voc?oool00`1Vooooooooo`0moooo00<0000co`0co`003C?o
00030000oooooooo07[oool0023oool00`1Vooooooooo`0`oooo00<0I_ooooooool0?_ooo`030000
<ol0<ol000`co`000`000?ooooooo`1joooo000Qoooo0P1Voc3oool00`1Vooooooooo`0noooo00<0
000co`0co`0033?o00030000oooooooo07[oool002?oool00`1Vooooooooo`0]oooo00<0I_oooooo
ool0?oooo`030000<ol0<ol000/co`020000Noooo`009?ooo`0306Kooooooooo02coool00`1Voooo
ooooo`0ooooo00<0000co`0co`002c?o00030000oooooooo07[oool002Coool00`1Vooooooooo`0/
oooo00<0I_ooooooool0@?ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo000Uoooo00<0
I_ooooooool0:oooo`0306Kooooooooo043oool00`0003?o03?o000:<ol000<0003oooooool0N_oo
o`009_ooo`0306Kooooooooo02[oool00`1Vooooooooo`11oooo00<0000co`0co`002C?o00030000
oooooooo07[oool002Ooool00`1Vooooooooo`0Yoooo00<0I_ooooooool0@Oooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1joooo000Xoooo00<0I_ooooooool09Oooo`@0I_m4oooo00<0000co`0c
o`0023?o0080001koooo000Xoooo00<0I_ooooooool08?ooo`D0I_l3oooo00?o09Woooooool0@_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`1joooo000Yoooo00<0I_ooooooool05_ooo`T0I_l8
oooo00?o09Woooooool0@_ooo`030000<ol0<ol000Pco`000`000?ooooooo`1joooo000Zoooo601V
oa7oool00ol0VOooooooo`13oooo00<0000co`0co`001c?o00030000oooooooo07[oool005?oool0
0ol0VOooooooo`13oooo00<0000co`0co`001c?o00030000oooooooo07[oool005?oool00ol0VOoo
ooooo`13oooo00<0000co`0co`001c?o00030000oooooooo07[oool005?oool00ol0VOooooooo`13
oooo00<0000co`0co`001c?o0080001koooo001Coooo00?o09Woooooool0A?ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`1joooo001Coooo00?o09Woooooool0A?ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1joooo001Coooo00?o09Woooooool0A?ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1joooo001Coooo00?o09Woooooool0A?ooo`030000<ol0<ol000Hco`000`000?ooooooo`1j
oooo001Coooo00?o09Woooooool0AOooo`D00003<ol000<0003oooooool0N_ooo`00Doooo`03o`2I
oooooooo04Goool00`0003?o00000005<ol000<0003oooooool0N_ooo`00Doooo`03o`2Ioooooooo
04Goool00`0003?o00000005<ol00`0007[oool005?oool00ol0VOooooooo`16oooo0P0000Dco`00
0`000?ooooooo`1joooo001Coooo00?o09Woooooool0A_ooo`800005<ol000<0003oooooool0N_oo
o`00Doooo`03o`2Ioooooooo04Koool200001C?o00030000oooooooo07[oool005?oool00ol0VOoo
ooooo`16oooo00<0000co`0co`0013?o00030000oooooooo07[oool005?oool00ol0VOooooooo`16
oooo00<0000co`0co`0013?o00030000oooooooo07[oool005?oool00ol0VOooooooo`16oooo00<0
000co`0co`0013?o0080001koooo001Coooo00?o09Woooooool0Aoooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo001Coooo00?o09Woooooool0Aoooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo001Coooo00?o09Woooooool0Aoooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo001Coooo00?o09Woooooool0Aoooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001C
oooo00?o09Woooooool0Aoooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001Coooo00?o
09Woooooool0Aoooo`030000<ol0<ol000<co`020000Noooo`00Doooo`03o`2Ioooooooo04Ooool0
0`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Doooo`03o`2Ioooooooo04Ooool00`0003?o
03?o0003<ol000<0003oooooool0N_ooo`00Doooo`03o`2Ioooooooo04Soool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Doooo`03o`2Ioooooooo04Soool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00Doooo`03o`2Ioooooooo04Soool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00Doooo`03o`2Ioooooooo04Soool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00Doooo`03o`2Ioooooooo04Soool00`0003?o03?o0002<ol00P0007_oool005?oool00ol0VOoo
ooooo`18oooo00<0000co`0co`000S?o00030000oooooooo07[oool005?oool00ol0VOooooooo`18
oooo00<0000co`0co`000S?o00030000oooooooo07[oool005?oool00ol0VOooooooo`18oooo00<0
000co`0co`000S?o00030000oooooooo07[oool005?oool00ol0VOooooooo`18oooo00<0000co`0c
o`000S?o00030000oooooooo07[oool005?oool00ol0VOooooooo`18oooo00<0000co`0co`000S?o
00030000oooooooo07[oool005?oool00ol0VOooooooo`18oooo00<0000co`0co`000S?o0080001k
oooo001Coooo00?o09Woooooool0BOooo`050000<ol0<ol0<ol0000007coool005?oool00ol0VOoo
ooooo`19oooo00D0000co`0co`0co`000000O?ooo`00Doooo`03o`2Ioooooooo04Woool01@0003?o
03?o03?o0000001loooo001Coooo00?o09Woooooool0AOooo`D00003<ol000<0003oooooool0N_oo
o`00Doooo`03o`2Ioooooooo04Goool01@000?ooooooooooo`000003<ol000<0003oooooool0N_oo
o`00Doooo`03o`2Ioooooooo04Koool010000?ooooooo`0000<co`030000N_ooo`00Doooo`03o`2I
oooooooo04Ooool00`000?ooo`000003<ol000<0003oooooool0N_ooo`00Doooo`03o`2Ioooooooo
04Goool00`000?ooooooo`0200000c?o00030000oooooooo07[oool005?oool00ol0VOooooooo`16
oooo0P000003oooo0000<ol0008co`000`000?ooooooo`1joooo001Coooo00?o09Woooooool0BOoo
o`050000<ol0<ol0<ol0000007coool005?oool00ol0VOooooooo`1:oooo00@0000co`0co`00001l
oooo001Coooo00?o09Woooooool0B_ooo`030000<ol0<ol00080001koooo001Coooo00?o09Wooooo
ool0B_ooo`040000<ol0<ol00000O?ooo`00Doooo`03o`2Ioooooooo04[oool0100003?o03?o0000
07coool005?oool00ol0VOooooooo`1:oooo00@0000co`0co`00001loooo001Coooo00?o09Wooooo
ool0B_ooo`040000<ol0<ol00000O?ooo`00Doooo`03o`2Ioooooooo04[oool0100003?o03?o0000
07coool005?oool00ol0VOooooooo`1:oooo00@0000co`0co`00001loooo001Coooo00?o09Wooooo
ool0Boooo`040000<ol000000000Noooo`00Doooo`03o`2Ioooooooo04_oool00`0003?o0000001l
oooo001Coooo00?o09Woooooool0Boooo`030000<ol0000007coool005?oool00ol0VOooooooo`1;
oooo00<0000co`000000O?ooo`00Doooo`03o`2Ioooooooo04_oool00`0003?o0000001loooo001C
oooo00?o09Woooooool0Boooo`030000<ol0000007coool005?oool00ol0VOooooooo`1;oooo00@0
000co`000000001koooo001Coooo00?o09Woooooool0Boooo`030000<ol0000007coool005?oool0
0ol0VOooooooo`1;oooo00<0000co`000000O?ooo`00Doooo`03o`2Ioooooooo04_oool00`0003?o
0000001loooo001Coooo00?o09Woooooool0Boooo`030000<ol0000007coool005?oool00ol0VOoo
ooooo`1;oooo00<0000co`000000O?ooo`00Doooo`03o`2Ioooooooo04_oool0100003?o00000000
07_oool005?oool00ol0VOooooooo`1;oooo00<0000co`000000O?ooo`00Doooo`03o`2Ioooooooo
04_oool00`0003?o0000001loooo001Coooo00?o09Woooooool0Boooo`030000<ol0000007coool0
05?oool00ol0VOooooooo`16oooo0P0000?oool00`0003?o0000001loooo001Coooo00?o09Wooooo
ool0AOooo`040000oooooooo00000_ooo`030000<ol0000007coool005?oool00ol0VOooooooo`17
oooo00H0003oooooooooool0000co`030000N_ooo`00Doooo`03o`2Ioooooooo04Soool01P000?oo
ooooo`0003?o000007coool005?oool00ol0VOooooooo`15oooo00@0003oooooool00002oooo00<0
000co`000000O?ooo`00Doooo`03o`2Ioooooooo04Koool200001?ooo`80001loooo001Coooo00?o
09Woooooool0C?ooo`80001loooo001Coooo00?o09Woooooool0C?ooo`80001loooo001Coooo00?o
09Woooooool0C?ooo`80001loooo001Coooo00?o09Woooooool0C?ooo`<0001koooo001Coooo00?o
09Woooooool0C?ooo`80001loooo001Coooo00?o09Woooooool0C?ooo`80001loooo001Coooo00?o
09Woooooool0C?ooo`80001loooo001Coooo00?o09Woooooool0C?ooo`80001loooo001Coooo00?o
09Woooooool0C?ooo`80001loooo001Coooo00?o09Woooooool0C?ooo`<0001koooo001Coooo00?o
09Woooooool0C?ooo`80001loooo001Coooo00?o09Woooooool0C?ooo`80001loooo001Coooo00?o
09Woooooool0C?ooo`80001loooo001Coooo00?o09Woooooool0C?ooo`80001loooo001Coooo00?o
09Woooooool0C?ooo`80001loooo001Coooo00?o09Woooooool0C?ooo`<0001koooo001Coooo00?o
09Woooooool0COooo`030000oooooooo07[oool005?oool00ol0VOooooooo`1=oooo00<0003ooooo
ool0N_ooo`00Doooo`03o`2Ioooooooo04goool00`000?ooooooo`1joooo001Coooo00?o09Wooooo
ool0COooo`030000oooooooo07[oool005?oool00ol0VOooooooo`1=oooo00<0003oooooool0N_oo
o`00Doooo`03o`2Ioooooooo04goool20000Noooo`00Doooo`03o`2Ioooooooo04goool00`000?oo
ooooo`1joooo001Coooo00?o09Woooooool0COooo`030000oooooooo07[oool005?oool00ol0VOoo
ooooo`1=oooo00<0003oooooool0N_ooo`00Doooo`03o`2Ioooooooo04goool00`000?ooooooo`1j
oooo001Coooo00?o09Woooooool0Aoooo`<00003oooo00<0003oooooool0N_ooo`00Doooo`03o`2I
oooooooo04Soool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00Doooo`03o`2Ioooooooo
04Goool500000oooo`<0001joooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool0
0000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007ooool00`000?ooooooo`0L
oooo00<0003oooooool0Ooooo`00O_ooo`030000oooooooo00Soool00`000?ooooooo`0Coooo00<0
003oooooool0O_ooo`00O_ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool2
00001?ooo`030000oooooooo07koool007koool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00000oooo`030000oooooooo
07koool007goool00`000?ooooooo`02oooo00<0003oooooool05_ooo`030000oooooooo00;oool0
0`000?ooooooo`1moooo001noooo00<0003oooooool01@0001?oool200001?ooo`030000oooooooo
07koool007koool01@000?ooooooooooo`00000Foooo00<0003oooooool00oooo`030000oooooooo
07koool007ooool00`000?ooooooo`0Goooo0`0000;oool00`000?ooooooo`1ooooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{79.5625, 308.938}, {290.125, 148.813}} -> {-0.349561, \
1.05307, 0.00349883, 0.00566123}, {{79.875, 308.563}, {290.125, 148.813}} -> \
{-13.0867, 4.80237, 0.049786, 0.0319664}, {{79.875, 308.563}, {290.125, \
148.813}} -> {-13.0867, 4.80237, 0.049786, 0.0319664}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.26171 .12361 L
.26425 .12361 L
.26698 .12361 L
.26778 .12361 L
.26855 .12361 L
.26923 .12361 L
s
.26923 .12361 m
.26953 .61803 L
s
0 .4 1 r
.02381 .14187 m
.04262 .14914 L
.06244 .15996 L
.07286 .16736 L
.08255 .17562 L
.09388 .18725 L
.10458 .20062 L
.10933 .20742 L
.11049 .20917 L
.11173 .21011 L
.11244 .2101 L
.11309 .21009 L
.11437 .21007 L
.1199 .20997 L
.125 .20987 L
.14357 .20943 L
.16256 .20879 L
.1733 .20833 L
.18328 .2078 L
.2038 .20639 L
.22241 .20457 L
.24166 .20193 L
.2525 .2 L
.25732 .19901 L
.26248 .19786 L
.26509 .19723 L
.26757 .19661 L
.26865 .19633 L
.26979 .19603 L
.27105 .12361 L
.27221 .12361 L
.27329 .12361 L
.27444 .12361 L
.27553 .12361 L
.27653 .12361 L
.27764 .12361 L
.27886 .12361 L
.28012 .12361 L
.2813 .12361 L
.28259 .12361 L
.28332 .12361 L
.28399 .12361 L
.28523 .12361 L
.28654 .12361 L
.28771 .12361 L
.2888 .12361 L
.29 .12361 L
.29129 .12361 L
.292 .12361 L
.29266 .12361 L
Mistroke
.29338 .12361 L
.29415 .12361 L
.29489 .12361 L
.29558 .12361 L
.29687 .12361 L
.29815 .12361 L
.29932 .12361 L
.30061 .12361 L
.30125 .12361 L
.30197 .12361 L
.30327 .12361 L
.30449 .12361 L
.30512 .12361 L
.30581 .12361 L
.30654 .12361 L
.30722 .12361 L
.30847 .12361 L
.30962 .12361 L
.31087 .12361 L
.3122 .12361 L
.31331 .12361 L
.3145 .12361 L
.31563 .12361 L
.31665 .12361 L
.31785 .12361 L
.31915 .12361 L
.32038 .12361 L
.32151 .12361 L
.32272 .12361 L
.32402 .12361 L
.32524 .12361 L
.32636 .12361 L
.32767 .12361 L
.32841 .12361 L
.32909 .12361 L
.33035 .12361 L
.33098 .12361 L
.33169 .12361 L
.33236 .12361 L
.33308 .12361 L
.33435 .12361 L
.33506 .12361 L
.33573 .12361 L
.3365 .12361 L
.33723 .12361 L
.33855 .12361 L
.33975 .12361 L
.34104 .12361 L
.34177 .12361 L
.34244 .12361 L
Mistroke
.34369 .12361 L
.34488 .12361 L
.34594 .12361 L
.34711 .12361 L
.34836 .12361 L
.34907 .12361 L
.34971 .12361 L
.35095 .12361 L
.35212 .12361 L
.35322 .12361 L
.35439 .12361 L
.35538 .12361 L
.35647 .12361 L
.35765 .12361 L
.35891 .12361 L
.3601 .12361 L
.36118 .12361 L
.36246 .12361 L
.36316 .12361 L
.36382 .12361 L
.36498 .12361 L
.36626 .12361 L
.36693 .12361 L
.36765 .12361 L
.36892 .12361 L
.36962 .12361 L
.37028 .12361 L
.37101 .12361 L
.37178 .12361 L
.37308 .12361 L
.37381 .12361 L
.37448 .12361 L
.37572 .12361 L
.37704 .12361 L
.37821 .12361 L
.37931 .12361 L
.38062 .12361 L
.38181 .12361 L
.38307 .12361 L
.38375 .12361 L
.3844 .12361 L
.38555 .12361 L
.3868 .12361 L
.38746 .12361 L
.38818 .12361 L
.38893 .12361 L
.38963 .12361 L
.39089 .12361 L
.39159 .12361 L
.39223 .12361 L
Mistroke
.3935 .12361 L
.39467 .12361 L
.39595 .12361 L
.39661 .12361 L
.39731 .12361 L
.39849 .12361 L
.3996 .12361 L
.40091 .12361 L
.40211 .12361 L
.40325 .12361 L
.40431 .12361 L
.40554 .12361 L
.40666 .12361 L
.40789 .12361 L
.40859 .12361 L
.40923 .12361 L
.41039 .12361 L
.41162 .12361 L
.41269 .12361 L
.41385 .12361 L
.41493 .12361 L
.41593 .12361 L
.41709 .12361 L
.41836 .12361 L
.41955 .12361 L
.42066 .12361 L
.42183 .12361 L
.42307 .12361 L
.42413 .12361 L
.42529 .12361 L
.42654 .12361 L
.42723 .12361 L
.42787 .12361 L
.42911 .12361 L
.43028 .12361 L
.43136 .12361 L
.43238 .12361 L
.43344 .12361 L
.43461 .12361 L
.43579 .12361 L
.43706 .12361 L
.43823 .12361 L
.43931 .12361 L
.44058 .12361 L
.44129 .12361 L
.44193 .12361 L
.44319 .12361 L
.44437 .12361 L
.44504 .12361 L
.44575 .12361 L
Mistroke
.44701 .12361 L
.44772 .12361 L
.44838 .12361 L
.4491 .12361 L
.44988 .12361 L
.45117 .12361 L
.4519 .12361 L
.45257 .12361 L
.45381 .12361 L
.45513 .12361 L
.45622 .12361 L
.4574 .12361 L
.4587 .12361 L
.45991 .12361 L
.46117 .12361 L
.46231 .12361 L
.46364 .12361 L
.46488 .12361 L
.46604 .12361 L
.4671 .12361 L
.46827 .12361 L
.4695 .12361 L
.47075 .12361 L
.47144 .12361 L
.47208 .12361 L
.47332 .12361 L
.47449 .12361 L
.47515 .12361 L
.47586 .12361 L
.47712 .12361 L
.47782 .12361 L
.47848 .12361 L
.4792 .12361 L
.47998 .12361 L
.48062 .12361 L
.4813 .12361 L
.48254 .12361 L
.48329 .12361 L
.48401 .12361 L
.48464 .12361 L
.48534 .12361 L
.48602 .12361 L
.48677 .12361 L
.48755 .12361 L
.48828 .12361 L
.48958 .12361 L
.49032 .12361 L
.49099 .12361 L
.49219 .12361 L
.49346 .12361 L
Mistroke
.4942 .12361 L
.49487 .12361 L
.49617 .12361 L
.49739 .12361 L
.4987 .12361 L
.49995 .12361 L
.50109 .12361 L
.50235 .12361 L
.50355 .12361 L
.50462 .12361 L
.50579 .12361 L
.50706 .12361 L
.50776 .12361 L
.50841 .12361 L
.50956 .12361 L
.51083 .12361 L
.51194 .12361 L
.51311 .12361 L
.51411 .12361 L
.5152 .12361 L
.51639 .12361 L
.51765 .12361 L
.51884 .12361 L
.51992 .12361 L
.52121 .12361 L
.52186 .12361 L
.52257 .12361 L
.52384 .12361 L
.52502 .12361 L
.52574 .12361 L
.52641 .12361 L
.52769 .12361 L
.5284 .12361 L
.52906 .12361 L
.52978 .12361 L
.53055 .12361 L
.53186 .12361 L
.53259 .12361 L
.53326 .12361 L
.53451 .12361 L
.53582 .12361 L
.53699 .12361 L
.53809 .12361 L
.5393 .12361 L
.54059 .12361 L
.54181 .12361 L
.54251 .12361 L
.54316 .12361 L
.54447 .12361 L
.54515 .12361 L
Mistroke
.54589 .12361 L
.5472 .12361 L
.54845 .12361 L
.54966 .12361 L
.55079 .12361 L
.55143 .12361 L
.55211 .12361 L
.55286 .12361 L
.55355 .12361 L
.55479 .12361 L
.55549 .12361 L
.55615 .12361 L
.55691 .12361 L
.5576 .12361 L
.5584 .12361 L
.55915 .12361 L
.56045 .12361 L
.56114 .12361 L
.56187 .12361 L
.56311 .12361 L
.56428 .12361 L
.56555 .12361 L
.56627 .12361 L
.56694 .12361 L
.5676 .12361 L
.56831 .12361 L
.56906 .12361 L
.56975 .12361 L
.57039 .12361 L
.57107 .12361 L
.57233 .12361 L
.57349 .12361 L
.57477 .12361 L
.57542 .12361 L
.57611 .12361 L
.57736 .12361 L
.57861 .12361 L
.57979 .12361 L
.58085 .12361 L
.58201 .12361 L
.62268 .12361 L
.66184 .12361 L
.70345 .12361 L
.74354 .12361 L
.78212 .12361 L
.82315 .12361 L
.86266 .12361 L
.90066 .12361 L
.94112 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000o`2I06Ko00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo02Koool00`000?l0V@1Vo`0Uoooo00<0003oooooool01_oo
o`@0000K<ol000<0003oooooool09Oooo`030000oooooooo02Koool00`000?ooooooo`0Yoooo001D
oooo00?o09T0I_ooool0<Oooo`@0000G<ol000<0003oooooool0N_ooo`00E?ooo`03o`2I06Kooooo
03Goool00`0003?o03?o000D<ol000<0003oooooool0N_ooo`005_ooo`80I_lloooo00?o09T0I_oo
ool0=_ooo`80000D<ol000<0003oooooool0N_ooo`006?ooo`80I_ljoooo00?o09T0I_ooool0>?oo
o`030000<ol0<ol0014co`000`000?ooooooo`1joooo000Joooo0P1VocSoool00ol0V@1Vooooo`0i
oooo00<0000co`0co`0043?o0080001koooo000Loooo0P1VocKoool00ol0V@1Vooooo`0joooo0P00
010co`000`000?ooooooo`1joooo000Noooo0P1VocCoool00ol0V@1Vooooo`0loooo00<0000co`0c
o`003C?o00030000oooooooo07[oool0023oool206Ko<_ooo`03o`2I06Kooooo03coool00`0003?o
03?o000=<ol000<0003oooooool0N_ooo`008_ooo`80I_l`oooo00?o09T0I_ooool0?Oooo`030000
<ol0<ol000`co`000`000?ooooooo`1joooo000Toooo00<0I_ooooooool0;Oooo`03o`2I06Kooooo
03goool00`0003?o03?o000<<ol000<0003oooooool0N_ooo`009?ooo`0306Kooooooooo02goool0
0ol0V@1Vooooo`0noooo00<0000co`0co`002c?o0080001koooo000Uoooo00<0I_ooooooool0;?oo
o`03o`2I06Kooooo03koool00`0003?o03?o000;<ol000<0003oooooool0N_ooo`009_ooo`0306Ko
oooooooo02_oool00ol0V@1Vooooo`0ooooo00<0000co`0co`002S?o00030000oooooooo07[oool0
02Ooool00`1Vooooooooo`0Zoooo00?o09T0I_ooool0?oooo`030000<ol0<ol000Xco`000`000?oo
ooooo`1joooo000Xoooo00<0I_ooooooool0:Oooo`03o`2I06Kooooo043oool00`0003?o03?o0009
<ol000<0003oooooool0N_ooo`00:Oooo`0306Kooooooooo02Soool00ol0V@1Vooooo`10oooo00<0
000co`0co`002C?o00030000oooooooo07[oool002[oool00`1Vooooooooo`0Voooo0`1Vod;oool0
0`0003?o03?o0008<ol00P0007_oool002_oool00`1Vooooooooo`0Noooo1`1Vo`03ooooo`2Ioooo
04;oool00`0003?o03?o0008<ol000<0003oooooool0N_ooo`00:oooo`0306Kooooooooo01Coool:
06Ko2?ooo`03o`2Ioooooooo047oool00`0003?o03?o0008<ol000<0003oooooool0N_ooo`00;?oo
oaH0I_lBoooo00?o09Woooooool0@_ooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo001D
oooo00?o09Woooooool0@_ooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo001Doooo00?o
09Woooooool0@_ooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo001Doooo00?o09Wooooo
ool0@_ooo`030000<ol0<ol000Lco`020000Noooo`00E?ooo`03o`2Ioooooooo04?oool00`0003?o
03?o0006<ol000<0003oooooool0N_ooo`00E?ooo`03o`2Ioooooooo04?oool00`0003?o03?o0006
<ol000<0003oooooool0N_ooo`00E?ooo`03o`2Ioooooooo04?oool00`0003?o03?o0006<ol000<0
003oooooool0N_ooo`00E?ooo`03o`2Ioooooooo04?oool00`0003?o03?o0006<ol000<0003ooooo
ool0N_ooo`00E?ooo`03o`2Ioooooooo04Coool500000c?o00030000oooooooo07[oool005Coool0
0ol0VOooooooo`14oooo00<0000co`0000001C?o00030000oooooooo07[oool005Coool00ol0VOoo
ooooo`14oooo00<0000co`0000001C?o00<0001joooo001Doooo00?o09Woooooool0AOooo`800005
<ol000<0003oooooool0N_ooo`00E?ooo`03o`2Ioooooooo04Goool200001C?o00030000oooooooo
07[oool005Coool00ol0VOooooooo`15oooo0P0000Dco`000`000?ooooooo`1joooo001Doooo00?o
09Woooooool0AOooo`030000<ol0<ol000@co`000`000?ooooooo`1joooo001Doooo00?o09Wooooo
ool0AOooo`030000<ol0<ol000@co`000`000?ooooooo`1joooo001Doooo00?o09Woooooool0AOoo
o`030000<ol0<ol000@co`020000Noooo`00E?ooo`03o`2Ioooooooo04Koool00`0003?o03?o0003
<ol000<0003oooooool0N_ooo`00E?ooo`03o`2Ioooooooo04Koool00`0003?o03?o0003<ol000<0
003oooooool0N_ooo`00E?ooo`03o`2Ioooooooo04Koool00`0003?o03?o0003<ol000<0003ooooo
ool0N_ooo`00E?ooo`03o`2Ioooooooo04Koool00`0003?o03?o0003<ol000<0003oooooool0N_oo
o`00E?ooo`03o`2Ioooooooo04Koool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00E?oo
o`03o`2Ioooooooo04Koool00`0003?o03?o0003<ol00P0007_oool005Coool00ol0VOooooooo`16
oooo00<0000co`0co`000c?o00030000oooooooo07[oool005Coool00ol0VOooooooo`16oooo00<0
000co`0co`000c?o00030000oooooooo07[oool005Coool00ol0VOooooooo`17oooo00<0000co`0c
o`000S?o00030000oooooooo07[oool005Coool00ol0VOooooooo`17oooo00<0000co`0co`000S?o
00030000oooooooo07[oool005Coool00ol0VOooooooo`17oooo00<0000co`0co`000S?o00030000
oooooooo07[oool005Coool00ol0VOooooooo`17oooo00<0000co`0co`000S?o00030000oooooooo
07[oool005Coool00ol0VOooooooo`17oooo00<0000co`0co`000S?o0080001koooo001Doooo00?o
09Woooooool0Aoooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Doooo00?o09Wooooo
ool0Aoooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Doooo00?o09Woooooool0Aooo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Doooo00?o09Woooooool0Aoooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo001Doooo00?o09Woooooool0Aoooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo001Doooo00?o09Woooooool0Aoooo`030000<ol0<ol0008co`02
0000Noooo`00E?ooo`03o`2Ioooooooo04Soool01@0003?o03?o03?o0000001loooo001Doooo00?o
09Woooooool0B?ooo`050000<ol0<ol0<ol0000007coool005Coool00ol0VOooooooo`18oooo00D0
000co`0co`0co`000000O?ooo`00E?ooo`03o`2Ioooooooo04Coool500000c?o00030000oooooooo
07[oool005Coool00ol0VOooooooo`14oooo00D0003oooooooooool000000c?o00030000oooooooo
07[oool005Coool00ol0VOooooooo`15oooo00@0003oooooool00003<ol00`0007[oool005Goool0
0ol0VOooooooo`15oooo00<0003oool000000c?o00030000oooooooo07[oool005Goool00ol0VOoo
ooooo`13oooo00<0003oooooool00P0000<co`000`000?ooooooo`1joooo001Eoooo00?o09Wooooo
ool0A?ooo`8000000oooo`0003?o0002<ol000<0003oooooool0N_ooo`00EOooo`03o`2Ioooooooo
04Ooool01@0003?o03?o03?o0000001loooo001Eoooo00?o09Woooooool0B?ooo`040000<ol0<ol0
0000O?ooo`00EOooo`03o`2Ioooooooo04Soool00`0003?o03?o00020000Noooo`00EOooo`03o`2I
oooooooo04Soool0100003?o03?o000007coool005Goool00ol0VOooooooo`18oooo00@0000co`0c
o`00001loooo001Eoooo00?o09Woooooool0B?ooo`040000<ol0<ol00000O?ooo`00EOooo`03o`2I
oooooooo04Soool0100003?o03?o000007coool005Goool00ol0VOooooooo`18oooo00@0000co`0c
o`00001loooo001Eoooo00?o09Woooooool0B?ooo`040000<ol0<ol00000O?ooo`00EOooo`03o`2I
oooooooo04Woool0100003?o0000000007_oool005Goool00ol0VOooooooo`19oooo00<0000co`00
0000O?ooo`00EOooo`03o`2Ioooooooo04Woool00`0003?o0000001loooo001Eoooo00?o09Wooooo
ool0BOooo`030000<ol0000007coool005Goool00ol0VOooooooo`19oooo00<0000co`000000O?oo
o`00EOooo`03o`2Ioooooooo04Woool00`0003?o0000001loooo001Eoooo00?o09Woooooool0BOoo
o`040000<ol000000000Noooo`00EOooo`03o`2Ioooooooo04Woool00`0003?o0000001loooo001E
oooo00?o09Woooooool0BOooo`030000<ol0000007coool005Goool00ol0VOooooooo`19oooo00<0
000co`000000O?ooo`00EOooo`03o`2Ioooooooo04Woool00`0003?o0000001loooo001Eoooo00?o
09Woooooool0BOooo`030000<ol0000007coool005Goool00ol0VOooooooo`19oooo00@0000co`00
0000001koooo001Eoooo00?o09Woooooool0BOooo`030000<ol0000007coool005Goool00ol0VOoo
ooooo`19oooo00<0000co`000000O?ooo`00EOooo`03o`2Ioooooooo04Woool00`0003?o0000001l
oooo001Eoooo00?o09Woooooool0A?ooo`800003oooo00<0000co`000000O?ooo`00EOooo`03o`2I
oooooooo04?oool010000?ooooooo`0000;oool00`0003?o0000001loooo001Eoooo00?o09Wooooo
ool0AOooo`060000oooooooooooo0000<ol00`0007[oool005Goool00ol0VOooooooo`16oooo00H0
003oooooool0000co`00001loooo001Eoooo00?o09Woooooool0@oooo`040000oooooooo00000_oo
o`030000<ol0000007coool005Goool00ol0VOooooooo`14oooo0P0000Coool20000O?ooo`00EOoo
o`03o`2Ioooooooo04[oool20000O?ooo`00EOooo`03o`2Ioooooooo04[oool20000O?ooo`00EOoo
o`03o`2Ioooooooo04[oool20000O?ooo`00EOooo`03o`2Ioooooooo04[oool30000Noooo`00EOoo
o`03o`2Ioooooooo04[oool20000O?ooo`00EOooo`03o`2Ioooooooo04[oool20000O?ooo`00EOoo
o`03o`2Ioooooooo04[oool20000O?ooo`00EOooo`03o`2Ioooooooo04[oool20000O?ooo`00EOoo
o`03o`2Ioooooooo04[oool20000O?ooo`00EOooo`03o`2Ioooooooo04[oool30000Noooo`00EOoo
o`03o`2Ioooooooo04[oool20000O?ooo`00EOooo`03o`2Ioooooooo04[oool20000O?ooo`00EOoo
o`03o`2Ioooooooo04[oool20000O?ooo`00EOooo`03o`2Ioooooooo04[oool20000O?ooo`00EOoo
o`03o`2Ioooooooo04[oool20000O?ooo`00EOooo`03o`2Ioooooooo04[oool30000Noooo`00EOoo
o`03o`2Ioooooooo04_oool00`000?ooooooo`1joooo001Eoooo00?o09Woooooool0Boooo`030000
oooooooo07[oool005Goool00ol0VOooooooo`1;oooo00<0003oooooool0N_ooo`00EOooo`03o`2I
oooooooo04_oool00`000?ooooooo`1joooo001Eoooo00?o09Woooooool0Boooo`030000oooooooo
07[oool005Goool00ol0VOooooooo`1;oooo0P0007_oool005Goool00ol0VOooooooo`1;oooo00<0
003oooooool0N_ooo`00EOooo`03o`2Ioooooooo04_oool00`000?ooooooo`1joooo001Eoooo00?o
09Woooooool0Boooo`030000oooooooo07[oool005Goool00ol0VOooooooo`1;oooo00<0003ooooo
ool0N_ooo`00EOooo`03o`2Ioooooooo04Goool300000oooo`030000oooooooo07[oool005Goool0
0ol0VOooooooo`16oooo00<0003oooooool00_ooo`030000oooooooo07[oool005Goool00ol0VOoo
ooooo`13oooo1@0000?oool30000N_ooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000
oooo0000087oool009goool20000POooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0>
oooo0`0000;oool200000oooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00006oooo00<0003ooooo
ool02?ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01?oool500002?ooo`<00004oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Boooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000001Koool00`000?ooo`000008oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Soool200002Oooo`<00002
oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.26171 .12361 L
.26709 .12361 L
.27279 .12361 L
.27513 .12361 L
.27643 .12361 L
.27765 .12361 L
s
.27765 .12361 m
.27793 .61803 L
s
0 .4 1 r
.02381 .13946 m
.04262 .14577 L
.06244 .15516 L
.07286 .16159 L
.08255 .16876 L
.10458 .19046 L
.10961 .19673 L
.11508 .20421 L
.11758 .20789 L
.11884 .20981 L
.11956 .21012 L
.12023 .2101 L
.125 .21002 L
.14357 .20964 L
.16382 .20904 L
.18234 .20827 L
.20133 .20717 L
.21208 .20636 L
.22205 .20545 L
.24258 .203 L
.26118 .19985 L
.26606 .19884 L
.27121 .19767 L
.27333 .19716 L
.2756 .19658 L
.27691 .19624 L
.2781 .12361 L
.2793 .12361 L
.28043 .12361 L
.28173 .12361 L
.28294 .12361 L
.28421 .12361 L
.28488 .12361 L
.28561 .12361 L
.28683 .12361 L
.28811 .12361 L
.2892 .12361 L
.2904 .12361 L
.29107 .12361 L
.2918 .12361 L
.29312 .12361 L
.29391 .12361 L
.29464 .12361 L
.29531 .12361 L
.29602 .12361 L
.29731 .12361 L
.29851 .12361 L
.29983 .12361 L
.30057 .12361 L
.30125 .12361 L
Mistroke
.30254 .12361 L
.30376 .12361 L
.30485 .12361 L
.30603 .12361 L
.30732 .12361 L
.30803 .12361 L
.30868 .12361 L
.30985 .12361 L
.31112 .12361 L
.31231 .12361 L
.31343 .12361 L
.31444 .12361 L
.31554 .12361 L
.31673 .12361 L
.318 .12361 L
.31908 .12361 L
.32027 .12361 L
.32158 .12361 L
.32224 .12361 L
.32296 .12361 L
.32424 .12361 L
.32543 .12361 L
.32615 .12361 L
.32683 .12361 L
.32811 .12361 L
.32883 .12361 L
.32949 .12361 L
.33021 .12361 L
.33098 .12361 L
.33217 .12361 L
.33345 .12361 L
.33466 .12361 L
.33576 .12361 L
.33705 .12361 L
.33778 .12361 L
.33845 .12361 L
.33969 .12361 L
.34101 .12361 L
.34214 .12361 L
.34339 .12361 L
.34468 .12361 L
.34589 .12361 L
.34702 .12361 L
.34805 .12361 L
.34924 .12361 L
.35036 .12361 L
.35159 .12361 L
.35288 .12361 L
.35399 .12361 L
.35521 .12361 L
Mistroke
.35588 .12361 L
.35661 .12361 L
.35731 .12361 L
.35795 .12361 L
.35916 .12361 L
.36046 .12361 L
.36169 .12361 L
.36284 .12361 L
.36388 .12361 L
.365 .12361 L
.36624 .12361 L
.36755 .12361 L
.36867 .12361 L
.36989 .12361 L
.37105 .12361 L
.3721 .12361 L
.37331 .12361 L
.37446 .12361 L
.37553 .12361 L
.37651 .12361 L
.37758 .12361 L
.37873 .12361 L
.37987 .12361 L
.38111 .12361 L
.38241 .12361 L
.38362 .12361 L
.38476 .12361 L
.38579 .12361 L
.38698 .12361 L
.38811 .12361 L
.38933 .12361 L
.39063 .12361 L
.39174 .12361 L
.39296 .12361 L
.39427 .12361 L
.395 .12361 L
.39567 .12361 L
.39698 .12361 L
.39821 .12361 L
.39937 .12361 L
.40041 .12361 L
.40162 .12361 L
.40276 .12361 L
.40381 .12361 L
.40478 .12361 L
.40584 .12361 L
.40697 .12361 L
.4081 .12361 L
.40932 .12361 L
.41047 .12361 L
Mistroke
.41151 .12361 L
.41274 .12361 L
.41344 .12361 L
.41408 .12361 L
.41525 .12361 L
.4165 .12361 L
.4177 .12361 L
.41902 .12361 L
.42026 .12361 L
.42141 .12361 L
.42255 .12361 L
.42358 .12361 L
.42478 .12361 L
.4259 .12361 L
.42713 .12361 L
.42844 .12361 L
.43077 .12361 L
.43206 .12361 L
.43327 .12361 L
.43397 .12361 L
.4346 .12361 L
.43533 .12361 L
.43602 .12361 L
.43707 .12361 L
.43823 .12361 L
.43944 .12361 L
.44058 .12361 L
.44163 .12361 L
.4426 .12361 L
.44367 .12361 L
.44479 .12361 L
.44593 .12361 L
.44715 .12361 L
.4483 .12361 L
.44934 .12361 L
.45057 .12361 L
.45126 .12361 L
.4519 .12361 L
.45308 .12361 L
.45432 .12361 L
.45553 .12361 L
.45685 .12361 L
.45809 .12361 L
.45925 .12361 L
.46039 .12361 L
.46143 .12361 L
.46263 .12361 L
.46375 .12361 L
.46499 .12361 L
.46629 .12361 L
Mistroke
.4674 .12361 L
.46862 .12361 L
.46994 .12361 L
.47068 .12361 L
.47135 .12361 L
.47265 .12361 L
.47389 .12361 L
.47494 .12361 L
.4761 .12361 L
.47731 .12361 L
.47845 .12361 L
.47951 .12361 L
.48048 .12361 L
.48154 .12361 L
.48266 .12361 L
.4838 .12361 L
.48502 .12361 L
.48617 .12361 L
.48722 .12361 L
.48845 .12361 L
.48914 .12361 L
.48978 .12361 L
.49095 .12361 L
.4922 .12361 L
.49341 .12361 L
.49473 .12361 L
.49598 .12361 L
.49714 .12361 L
.49818 .12361 L
.49933 .12361 L
.50053 .12361 L
.50165 .12361 L
.50289 .12361 L
.5042 .12361 L
.50531 .12361 L
.50653 .12361 L
.50785 .12361 L
.50859 .12361 L
.50926 .12361 L
.51057 .12361 L
.5118 .12361 L
.51286 .12361 L
.51402 .12361 L
.51523 .12361 L
.51637 .12361 L
.51743 .12361 L
.5184 .12361 L
.51952 .12361 L
.52059 .12361 L
.52173 .12361 L
Mistroke
.52295 .12361 L
.5241 .12361 L
.52515 .12361 L
.52638 .12361 L
.52707 .12361 L
.52771 .12361 L
.52888 .12361 L
.53012 .12361 L
.53134 .12361 L
.53199 .12361 L
.53267 .12361 L
.53392 .12361 L
.53508 .12361 L
.53619 .12361 L
.53723 .12361 L
.53838 .12361 L
.53961 .12361 L
.54084 .12361 L
.54154 .12361 L
.54219 .12361 L
.5435 .12361 L
.54424 .12361 L
.54491 .12361 L
.54611 .12361 L
.54741 .12361 L
.54864 .12361 L
.54977 .12361 L
.55082 .12361 L
.55196 .12361 L
.55303 .12361 L
.55401 .12361 L
.55516 .12361 L
.5564 .12361 L
.55758 .12361 L
.55868 .12361 L
.55991 .12361 L
.56107 .12361 L
.56212 .12361 L
.56324 .12361 L
.56448 .12361 L
.56578 .12361 L
.56689 .12361 L
.5681 .12361 L
.56941 .12361 L
.57062 .12361 L
.57126 .12361 L
.57195 .12361 L
.57268 .12361 L
.57336 .12361 L
.57461 .12361 L
Mistroke
.57576 .12361 L
.57708 .12361 L
.57834 .12361 L
.57946 .12361 L
.58065 .12361 L
.58279 .12361 L
.58766 .12361 L
.60859 .12361 L
.65015 .12361 L
.69019 .12361 L
.72871 .12361 L
.76969 .12361 L
.80915 .12361 L
.8471 .12361 L
.8875 .12361 L
.92639 .12361 L
.96772 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`050000oooooooooooo06Ko00Goool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`00:_ooo`030000oooooooo02Koool01@000?ooooooooooo`1Vo`0Soooo00<0
003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000oooooooo02Koool00`000?oo
ooooo`0Yoooo001Goooo00<0I_ooooooool0;_ooo`@0000G<ol000<0003oooooool0N_ooo`005_oo
o`80I_looooo00<0I_ooooooool0<_ooo`030000<ol0<ol001@co`000`000?ooooooo`1joooo000H
oooo0P1Vocgoool00`1Vooooooooo`0coooo0P0001@co`000`000?ooooooo`1joooo000Joooo0`1V
oc[oool00`1Vooooooooo`0eoooo00<0000co`0co`004C?o00030000oooooooo07[oool001goool2
06Ko>?ooo`0306Kooooooooo03Koool00`0003?o03?o000@<ol00P0007_oool001ooool206Ko=_oo
o`0306Kooooooooo03Ooool2000043?o00030000oooooooo07[oool0027oool206Ko=?ooo`0306Ko
oooooooo03Woool00`0003?o03?o000=<ol000<0003oooooool0N_ooo`008oooo`0306Kooooooooo
033oool00`1Vool0VOooo`0joooo00<0000co`0co`003C?o00030000oooooooo07[oool002Coool0
0`1Vooooooooo`0_oooo00<0I_oo09Woool0>oooo`030000<ol0<ol000`co`000`000?ooooooo`1j
oooo000Uoooo00<0I_ooooooool0;_ooo`0306Koo`2Ioooo03_oool00`0003?o03?o000<<ol000<0
003oooooool0N_ooo`009_ooo`0306Kooooooooo02goool00`1Vool0VOooo`0loooo00<0000co`0c
o`002c?o0080001koooo000Woooo00<0I_ooooooool0;?ooo`0306Koo`2Ioooo03coool00`0003?o
03?o000;<ol000<0003oooooool0N_ooo`00:?ooo`80I_l/oooo00<0I_oo09Woool0?Oooo`030000
<ol0<ol000Xco`000`000?ooooooo`1joooo000Zoooo00<0I_ooooooool0:Oooo`0306Koo`2Ioooo
03goool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00:oooo`0306Kooooooooo02Soool0
0`1Vool0VOooo`0noooo00<0000co`0co`002C?o00030000oooooooo07[oool002_oool00`1Voooo
ooooo`0Xoooo00<0I_oo09Woool0?_ooo`030000<ol0<ol000Tco`000`000?ooooooo`1joooo000/
oooo00<0I_ooooooool09Oooo`<0I_l00ol0VOooooooo`0noooo00<0000co`0co`0023?o0080001k
oooo000/oooo00<0I_ooooooool08_ooo`<0I_l3oooo00?o09Woooooool0?_ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1joooo000]oooo00<0I_ooooooool05Oooo``0I_l6oooo00?o09Wooooo
ool0?_ooo`030000<ol0<ol000Pco`000`000?ooooooo`1joooo000^oooo5`1Voa;oool00ol0VOoo
ooooo`0ooooo00<0000co`0co`001c?o00030000oooooooo07[oool005Ooool00ol0VOooooooo`0o
oooo00<0000co`0co`001c?o00030000oooooooo07[oool005Ooool00ol0VOooooooo`0ooooo00<0
000co`0co`001c?o00030000oooooooo07[oool005Ooool00ol0VOooooooo`0ooooo00<0000co`0c
o`001c?o0080001koooo001Goooo00?o09Woooooool0@?ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1joooo001Goooo00?o09Woooooool0@?ooo`030000<ol0<ol000Hco`000`000?ooooooo`1j
oooo001Goooo00?o09Woooooool0@?ooo`030000<ol0<ol000Hco`000`000?ooooooo`1joooo001G
oooo00?o09Woooooool0@?ooo`030000<ol0<ol000Hco`000`000?ooooooo`1joooo001Goooo00?o
09Woooooool0@Oooo`D00003<ol000<0003oooooool0N_ooo`00Eoooo`03o`2Ioooooooo047oool0
0`0003?o00000005<ol000<0003oooooool0N_ooo`00Eoooo`03o`2Ioooooooo047oool00`0003?o
00000005<ol00`0007[oool005Ooool00ol0VOooooooo`12oooo0P0000Dco`000`000?ooooooo`1j
oooo001Goooo00?o09Woooooool0@_ooo`800005<ol000<0003oooooool0N_ooo`00Eoooo`03o`2I
oooooooo04;oool200001C?o00030000oooooooo07[oool005Ooool00ol0VOooooooo`12oooo00<0
000co`0co`0013?o00030000oooooooo07[oool005Ooool00ol0VOooooooo`12oooo00<0000co`0c
o`0013?o00030000oooooooo07[oool005Ooool00ol0VOooooooo`12oooo00<0000co`0co`0013?o
0080001koooo001Goooo00?o09Woooooool0@oooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo001Goooo00?o09Woooooool0@oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001G
oooo00?o09Woooooool0@oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001Goooo00?o
09Woooooool0@oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001Goooo00?o09Wooooo
ool0@oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001Goooo00?o09Woooooool0@ooo
o`030000<ol0<ol000<co`020000Noooo`00Eoooo`03o`2Ioooooooo04?oool00`0003?o03?o0003
<ol000<0003oooooool0N_ooo`00Eoooo`03o`2Ioooooooo04?oool00`0003?o03?o0003<ol000<0
003oooooool0N_ooo`00Eoooo`03o`2Ioooooooo04Coool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00Eoooo`03o`2Ioooooooo04Coool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00Eoooo`03o`2Ioooooooo04Coool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Eooo
o`03o`2Ioooooooo04Coool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Eoooo`03o`2I
oooooooo04Coool00`0003?o03?o0002<ol00P0007_oool005Ooool00ol0VOooooooo`14oooo00<0
000co`0co`000S?o00030000oooooooo07[oool005Ooool00ol0VOooooooo`14oooo00<0000co`0c
o`000S?o00030000oooooooo07[oool005Ooool00ol0VOooooooo`14oooo00<0000co`0co`000S?o
00030000oooooooo07[oool005Ooool00ol0VOooooooo`14oooo00<0000co`0co`000S?o00030000
oooooooo07[oool005Ooool00ol0VOooooooo`14oooo00<0000co`0co`000S?o00030000oooooooo
07[oool005Ooool00ol0VOooooooo`14oooo00<0000co`0co`000S?o0080001koooo001Goooo00?o
09Woooooool0AOooo`050000<ol0<ol0<ol0000007coool005Ooool00ol0VOooooooo`15oooo00D0
000co`0co`0co`000000O?ooo`00Eoooo`03o`2Ioooooooo04Goool01@0003?o03?o03?o0000001l
oooo001Goooo00?o09Woooooool0@Oooo`D00003<ol000<0003oooooool0N_ooo`00Eoooo`03o`2I
oooooooo047oool01@000?ooooooooooo`000003<ol000<0003oooooool0N_ooo`00Eoooo`03o`2I
oooooooo04;oool010000?ooooooo`0000<co`030000N_ooo`00Eoooo`03o`2Ioooooooo04?oool0
0`000?ooo`000003<ol000<0003oooooool0N_ooo`00Eoooo`03o`2Ioooooooo047oool00`000?oo
ooooo`0200000c?o00030000oooooooo07[oool005Ooool00ol0VOooooooo`12oooo0P000003oooo
0000<ol0008co`000`000?ooooooo`1joooo001Goooo00?o09Woooooool0AOooo`050000<ol0<ol0
<ol0000007coool005Ooool00ol0VOooooooo`16oooo00@0000co`0co`00001loooo001Goooo00?o
09Woooooool0A_ooo`030000<ol0<ol00080001koooo001Goooo00?o09Woooooool0A_ooo`040000
<ol0<ol00000O?ooo`00Eoooo`03o`2Ioooooooo04Koool0100003?o03?o000007coool005Ooool0
0ol0VOooooooo`16oooo00@0000co`0co`00001loooo001Goooo00?o09Woooooool0A_ooo`040000
<ol0<ol00000O?ooo`00Eoooo`03o`2Ioooooooo04Koool0100003?o03?o000007coool005Ooool0
0ol0VOooooooo`16oooo00@0000co`0co`00001loooo001Goooo00?o09Woooooool0Aoooo`040000
<ol000000000Noooo`00Eoooo`03o`2Ioooooooo04Ooool00`0003?o0000001loooo001Goooo00?o
09Woooooool0Aoooo`030000<ol0000007coool005Ooool00ol0VOooooooo`17oooo00<0000co`00
0000O?ooo`00Eoooo`03o`2Ioooooooo04Ooool00`0003?o0000001loooo001Goooo00?o09Wooooo
ool0Aoooo`030000<ol0000007coool005Ooool00ol0VOooooooo`17oooo00@0000co`000000001k
oooo001Goooo00?o09Woooooool0Aoooo`030000<ol0000007coool005Ooool00ol0VOooooooo`17
oooo00<0000co`000000O?ooo`00Eoooo`03o`2Ioooooooo04Ooool00`0003?o0000001loooo001G
oooo00?o09Woooooool0Aoooo`030000<ol0000007coool005Ooool00ol0VOooooooo`17oooo00<0
000co`000000O?ooo`00Eoooo`03o`2Ioooooooo04Ooool0100003?o0000000007_oool005Ooool0
0ol0VOooooooo`17oooo00<0000co`000000O?ooo`00Eoooo`03o`2Ioooooooo04Ooool00`0003?o
0000001loooo001Goooo00?o09Woooooool0Aoooo`030000<ol0000007coool005Ooool00ol0VOoo
ooooo`12oooo0P0000?oool00`0003?o0000001loooo001Goooo00?o09Woooooool0@Oooo`040000
oooooooo00000_ooo`030000<ol0000007coool005Ooool00ol0VOooooooo`13oooo00H0003ooooo
ooooool0000co`030000N_ooo`00Eoooo`03o`2Ioooooooo04Coool01P000?ooooooo`0003?o0000
07coool005Ooool00ol0VOooooooo`11oooo00@0003oooooool00002oooo00<0000co`000000O?oo
o`00Eoooo`03o`2Ioooooooo04;oool200001?ooo`80001loooo001Goooo00?o09Woooooool0B?oo
o`80001loooo001Goooo00?o09Woooooool0B?ooo`80001loooo001Goooo00?o09Woooooool0B?oo
o`80001loooo001Goooo00?o09Woooooool0B?ooo`<0001koooo001Goooo00?o09Woooooool0B?oo
o`80001loooo001Goooo00?o09Woooooool0B?ooo`80001loooo001Goooo00?o09Woooooool0B?oo
o`80001loooo001Goooo00?o09Woooooool0B?ooo`80001loooo001Goooo00?o09Woooooool0B?oo
o`80001loooo001Goooo00?o09Woooooool0B?ooo`<0001koooo001Goooo00?o09Woooooool0B?oo
o`80001loooo001Goooo00?o09Woooooool0B?ooo`80001loooo001Goooo00?o09Woooooool0B?oo
o`80001loooo001Goooo00?o09Woooooool0B?ooo`80001loooo001Goooo00?o09Woooooool0B?oo
o`80001loooo001Goooo00?o09Woooooool0B?ooo`<0001koooo001Goooo00?o09Woooooool0BOoo
o`030000oooooooo07[oool005Ooool00ol0VOooooooo`19oooo00<0003oooooool0N_ooo`00Eooo
o`03o`2Ioooooooo04Woool00`000?ooooooo`1joooo001Goooo00?o09Woooooool0BOooo`030000
oooooooo07[oool005Ooool00ol0VOooooooo`19oooo00<0003oooooool0N_ooo`00Eoooo`03o`2I
oooooooo04Woool20000Noooo`00Eoooo`03o`2Ioooooooo04Woool00`000?ooooooo`1joooo001G
oooo00?o09Woooooool0BOooo`030000oooooooo07[oool005Ooool00ol0VOooooooo`19oooo00<0
003oooooool0N_ooo`00Eoooo`03o`2Ioooooooo04Woool00`000?ooooooo`1joooo001Goooo00?o
09Woooooool0@oooo`<00003oooo00<0003oooooool0N_ooo`00Eoooo`03o`2Ioooooooo04Coool0
0`000?ooooooo`02oooo00<0003oooooool0N_ooo`00Eoooo`03o`2Ioooooooo047oool500000ooo
o`<0001joooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool00000POooo`00WOoo
o`800021oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00koool300000_ooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Koool00`000?ooooooo`06oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo1@0000Ooool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0001;oool010000?ooooooo`0000Woool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000Foooo00<0003oool000002?ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Hoooo0P0000Woool200000oooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28025 .12361 L
.28302 .12361 L
.28425 .12361 L
.28542 .12361 L
s
.28542 .12361 m
.28567 .61803 L
s
0 .4 1 r
.02381 .13737 m
.04262 .14285 L
.06244 .151 L
.07286 .15658 L
.08255 .16281 L
.10458 .18165 L
.11366 .19183 L
.12328 .20459 L
.1257 .20816 L
.12639 .20922 L
.12706 .21012 L
.1283 .2101 L
.13115 .21006 L
.13383 .21001 L
.14357 .20982 L
.15376 .20958 L
.16488 .20927 L
.17544 .20891 L
.18502 .20852 L
.20469 .20747 L
.21549 .20672 L
.22566 .20587 L
.24574 .20365 L
.26421 .20079 L
.2733 .19899 L
.2783 .19787 L
.28076 .19728 L
.28304 .19671 L
.28434 .19638 L
.28499 .1962 L
.28572 .12361 L
.28644 .12361 L
.28722 .12361 L
.28789 .12361 L
.28863 .12361 L
.28992 .12361 L
.29063 .12361 L
.29129 .12361 L
.29247 .12361 L
.29373 .12361 L
.29502 .12361 L
.29574 .12361 L
.29641 .12361 L
.29765 .12361 L
.29895 .12361 L
.30012 .12361 L
.30121 .12361 L
.30241 .12361 L
.3037 .12361 L
.30439 .12361 L
Mistroke
.30504 .12361 L
.30625 .12361 L
.30755 .12361 L
.30828 .12361 L
.30896 .12361 L
.31019 .12361 L
.31133 .12361 L
.31252 .12361 L
.31383 .12361 L
.31452 .12361 L
.31527 .12361 L
.31597 .12361 L
.31662 .12361 L
.31786 .12361 L
.31917 .12361 L
.31984 .12361 L
.32057 .12361 L
.32188 .12361 L
.32264 .12361 L
.32345 .12361 L
.32413 .12361 L
.32488 .12361 L
.32553 .12361 L
.32624 .12361 L
.32752 .12361 L
.32877 .12361 L
.32992 .12361 L
.33116 .12361 L
.33187 .12361 L
.33253 .12361 L
.33323 .12361 L
.33387 .12361 L
.3346 .12361 L
.3353 .12361 L
.33646 .12361 L
.3377 .12361 L
.33876 .12361 L
.33993 .12361 L
.34118 .12361 L
.34189 .12361 L
.34253 .12361 L
.34372 .12361 L
.34498 .12361 L
.34621 .12361 L
.3469 .12361 L
.34754 .12361 L
.34872 .12361 L
.34997 .12361 L
.35108 .12361 L
.35213 .12361 L
Mistroke
.35328 .12361 L
.35451 .12361 L
.35581 .12361 L
.35655 .12361 L
.35724 .12361 L
.35849 .12361 L
.35919 .12361 L
.35983 .12361 L
.36103 .12361 L
.36234 .12361 L
.36356 .12361 L
.3647 .12361 L
.36576 .12361 L
.3669 .12361 L
.36797 .12361 L
.36895 .12361 L
.3701 .12361 L
.37135 .12361 L
.37253 .12361 L
.37363 .12361 L
.37476 .12361 L
.376 .12361 L
.37722 .12361 L
.37852 .12361 L
.37968 .12361 L
.38089 .12361 L
.38192 .12361 L
.38305 .12361 L
.38438 .12361 L
.38559 .12361 L
.38623 .12361 L
.38693 .12361 L
.38766 .12361 L
.38835 .12361 L
.3896 .12361 L
.39075 .12361 L
.39139 .12361 L
.39208 .12361 L
.39334 .12361 L
.39457 .12361 L
.39569 .12361 L
.39698 .12361 L
.39819 .12361 L
.39931 .12361 L
.40035 .12361 L
.40148 .12361 L
.40268 .12361 L
.40399 .12361 L
.40518 .12361 L
.40584 .12361 L
Mistroke
.40656 .12361 L
.40786 .12361 L
.40907 .12361 L
.41036 .12361 L
.41147 .12361 L
.41268 .12361 L
.41341 .12361 L
.4141 .12361 L
.4154 .12361 L
.41613 .12361 L
.41681 .12361 L
.41755 .12361 L
.41834 .12361 L
.41902 .12361 L
.41977 .12361 L
.42047 .12361 L
.42111 .12361 L
.42234 .12361 L
.42364 .12361 L
.42485 .12361 L
.42554 .12361 L
.42618 .12361 L
.42735 .12361 L
.42859 .12361 L
.4297 .12361 L
.43074 .12361 L
.43188 .12361 L
.43311 .12361 L
.43434 .12361 L
.43504 .12361 L
.43569 .12361 L
.43642 .12361 L
.43711 .12361 L
.43841 .12361 L
.43953 .12361 L
.44075 .12361 L
.44206 .12361 L
.44326 .12361 L
.44432 .12361 L
.44545 .12361 L
.44652 .12361 L
.4475 .12361 L
.44992 .12361 L
.4511 .12361 L
.45217 .12361 L
.45329 .12361 L
.45448 .12361 L
.45578 .12361 L
.457 .12361 L
.45815 .12361 L
Mistroke
.45921 .12361 L
.46037 .12361 L
.4616 .12361 L
.46282 .12361 L
.46351 .12361 L
.46415 .12361 L
.46532 .12361 L
.46657 .12361 L
.46763 .12361 L
.46874 .12361 L
.46997 .12361 L
.47109 .12361 L
.47229 .12361 L
.47359 .12361 L
.4748 .12361 L
.47593 .12361 L
.47663 .12361 L
.47728 .12361 L
.47851 .12361 L
.47983 .12361 L
.48058 .12361 L
.48126 .12361 L
.48232 .12361 L
.48346 .12361 L
.48453 .12361 L
.48551 .12361 L
.48666 .12361 L
.48791 .12361 L
.48909 .12361 L
.49018 .12361 L
.4913 .12361 L
.49235 .12361 L
.4935 .12361 L
.49475 .12361 L
.49598 .12361 L
.49728 .12361 L
.49839 .12361 L
.49961 .12361 L
.50092 .12361 L
.50213 .12361 L
.50277 .12361 L
.50347 .12361 L
.50419 .12361 L
.50488 .12361 L
.50613 .12361 L
.50728 .12361 L
.50791 .12361 L
.5086 .12361 L
.50986 .12361 L
.51109 .12361 L
Mistroke
.5122 .12361 L
.51348 .12361 L
.5147 .12361 L
.51582 .12361 L
.51685 .12361 L
.51799 .12361 L
.51918 .12361 L
.52049 .12361 L
.52168 .12361 L
.52233 .12361 L
.52305 .12361 L
.52435 .12361 L
.52556 .12361 L
.52685 .12361 L
.52795 .12361 L
.52917 .12361 L
.52986 .12361 L
.53059 .12361 L
.53189 .12361 L
.53261 .12361 L
.53329 .12361 L
.53403 .12361 L
.53482 .12361 L
.5355 .12361 L
.53625 .12361 L
.53695 .12361 L
.5376 .12361 L
.53882 .12361 L
.54012 .12361 L
.54133 .12361 L
.54265 .12361 L
.5439 .12361 L
.54506 .12361 L
.5462 .12361 L
.54724 .12361 L
.54844 .12361 L
.54956 .12361 L
.5508 .12361 L
.5521 .12361 L
.55322 .12361 L
.55444 .12361 L
.55575 .12361 L
.55649 .12361 L
.55716 .12361 L
.55847 .12361 L
.5597 .12361 L
.56076 .12361 L
.56192 .12361 L
.56313 .12361 L
.56427 .12361 L
Mistroke
.56533 .12361 L
.5663 .12361 L
.56742 .12361 L
.56848 .12361 L
.56963 .12361 L
.57085 .12361 L
.572 .12361 L
.57304 .12361 L
.57427 .12361 L
.57496 .12361 L
.5756 .12361 L
.57678 .12361 L
.57802 .12361 L
.57923 .12361 L
.57992 .12361 L
.58056 .12361 L
.58297 .12361 L
.58748 .12361 L
.59764 .12361 L
.61597 .12361 L
.65521 .12361 L
.69293 .12361 L
.73311 .12361 L
.77177 .12361 L
.81289 .12361 L
.85249 .12361 L
.89057 .12361 L
.93111 .12361 L
.97013 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00?oool01@1Vooooooooooooo`000009oooo00<0
003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`03oooo00<0I_oooooo
ool07oooo`030000oooooooo00Koool400006c?o00030000oooooooo02Goool00`000?ooooooo`0V
oooo00<0003oooooool0:Oooo`00FOooo`0306Kooooooooo02coool400005c?o00030000oooooooo
07[oool001Koool306Ko@?ooo`0306Kooooooooo033oool00`0003?o03?o000D<ol000<0003ooooo
ool0N_ooo`006Oooo`@0I_lloooo00<0I_ooooooool0<Oooo`80000D<ol000<0003oooooool0N_oo
o`007Oooo`80I_ljoooo00<0I_ooooooool0<oooo`030000<ol0<ol0014co`000`000?ooooooo`1j
oooo000Ooooo0P1VocSoool00`1Vooooooooo`0doooo00<0000co`0co`0043?o0080001koooo000Q
oooo0P1VocKoool00`1Vooooooooo`0eoooo0P00010co`000`000?ooooooo`1joooo000Soooo00<0
I_ooooooool0<oooo`0306Kooooooooo03Ooool00`0003?o03?o000=<ol000<0003oooooool0N_oo
o`009?ooo`80I_lboooo00<0I_oo09Woool0>?ooo`030000<ol0<ol000dco`000`000?ooooooo`1j
oooo000Voooo00<0I_ooooooool0;oooo`0306Koo`2Ioooo03Woool00`0003?o03?o000<<ol000<0
003oooooool0N_ooo`009oooo`0306Kooooooooo02koool00`1Vool0VOooo`0ioooo00<0000co`0c
o`0033?o00030000oooooooo07[oool002Soool206Ko;_ooo`0306Koo`2Ioooo03[oool00`0003?o
03?o000;<ol00P0007_oool002[oool00`1Vooooooooo`0[oooo00<0I_oo09Woool0>_ooo`030000
<ol0<ol000/co`000`000?ooooooo`1joooo000[oooo00<0I_ooooooool0:_ooo`0306Koo`2Ioooo
03_oool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00;?ooo`0306Kooooooooo02Woool0
0`1Vool0VOooo`0koooo00<0000co`0co`002S?o00030000oooooooo07[oool002coool00`1Voooo
ooooo`0Yoooo00<0I_oo09Woool0??ooo`030000<ol0<ol000Tco`000`000?ooooooo`1joooo000]
oooo00<0I_ooooooool0:?ooo`0306Koo`2Ioooo03coool00`0003?o03?o0009<ol000<0003ooooo
ool0N_ooo`00;_ooo`0306Kooooooooo02Koool206Ko00?o09Woooooool0??ooo`030000<ol0<ol0
00Pco`020000Noooo`00;_ooo`0306Kooooooooo027oool506Ko0_ooo`03o`2Ioooooooo03coool0
0`0003?o03?o0008<ol000<0003oooooool0N_ooo`00;oooo`0306Kooooooooo01Coool<06Ko1ooo
o`03o`2Ioooooooo03coool00`0003?o03?o0008<ol000<0003oooooool0N_ooo`00<?oooaH0I_lC
oooo00?o09Woooooool0?Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo001Ioooo00?o
09Woooooool0?Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo001Ioooo00?o09Wooooo
ool0?Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0?Ooo
o`030000<ol0<ol000Lco`020000Noooo`00FOooo`03o`2Ioooooooo03koool00`0003?o03?o0006
<ol000<0003oooooool0N_ooo`00FOooo`03o`2Ioooooooo03koool00`0003?o03?o0006<ol000<0
003oooooool0N_ooo`00FOooo`03o`2Ioooooooo03koool00`0003?o03?o0006<ol000<0003ooooo
ool0N_ooo`00FOooo`03o`2Ioooooooo03koool00`0003?o03?o0006<ol000<0003oooooool0N_oo
o`00FOooo`03o`2Ioooooooo03ooool500000c?o00030000oooooooo07[oool005Woool00ol0VOoo
ooooo`0ooooo00<0000co`0000001C?o00030000oooooooo07[oool005Woool00ol0VOooooooo`0o
oooo00<0000co`0000001C?o00<0001joooo001Ioooo00?o09Woooooool0@?ooo`800005<ol000<0
003oooooool0N_ooo`00FOooo`03o`2Ioooooooo043oool200001C?o00030000oooooooo07[oool0
05Woool00ol0VOooooooo`10oooo0P0000Dco`000`000?ooooooo`1joooo001Ioooo00?o09Wooooo
ool0@?ooo`030000<ol0<ol000@co`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0@?oo
o`030000<ol0<ol000@co`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0@?ooo`030000
<ol0<ol000@co`020000Noooo`00FOooo`03o`2Ioooooooo047oool00`0003?o03?o0003<ol000<0
003oooooool0N_ooo`00FOooo`03o`2Ioooooooo047oool00`0003?o03?o0003<ol000<0003ooooo
ool0N_ooo`00FOooo`03o`2Ioooooooo047oool00`0003?o03?o0003<ol000<0003oooooool0N_oo
o`00FOooo`03o`2Ioooooooo047oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00FOoo
o`03o`2Ioooooooo047oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00FOooo`03o`2I
oooooooo047oool00`0003?o03?o0003<ol00P0007_oool005Woool00ol0VOooooooo`11oooo00<0
000co`0co`000c?o00030000oooooooo07[oool005Woool00ol0VOooooooo`11oooo00<0000co`0c
o`000c?o00030000oooooooo07[oool005Woool00ol0VOooooooo`12oooo00<0000co`0co`000S?o
00030000oooooooo07[oool005Woool00ol0VOooooooo`12oooo00<0000co`0co`000S?o00030000
oooooooo07[oool005Woool00ol0VOooooooo`12oooo00<0000co`0co`000S?o00030000oooooooo
07[oool005Woool00ol0VOooooooo`12oooo00<0000co`0co`000S?o00030000oooooooo07[oool0
05Woool00ol0VOooooooo`12oooo00<0000co`0co`000S?o0080001koooo001Ioooo00?o09Wooooo
ool0@_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0@_oo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0@_ooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0@_ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0@_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001Ioooo00?o09Woooooool0@_ooo`030000<ol0<ol0008co`020000Nooo
o`00FOooo`03o`2Ioooooooo04?oool01@0003?o03?o03?o0000001loooo001Ioooo00?o09Wooooo
ool0@oooo`050000<ol0<ol0<ol0000007coool005Woool00ol0VOooooooo`13oooo00D0000co`0c
o`0co`000000O?ooo`00FOooo`03o`2Ioooooooo03ooool500000c?o00030000oooooooo07[oool0
05Woool00ol0VOooooooo`0ooooo00D0003oooooooooool000000c?o00030000oooooooo07[oool0
05Woool00ol0VOooooooo`10oooo00@0003oooooool00003<ol00`0007[oool005Woool00ol0VOoo
ooooo`11oooo00<0003oool000000c?o00030000oooooooo07[oool005Woool00ol0VOooooooo`0o
oooo00<0003oooooool00P0000<co`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0@?oo
o`8000000oooo`0003?o0002<ol000<0003oooooool0N_ooo`00FOooo`03o`2Ioooooooo04?oool0
1@0003?o03?o03?o0000001loooo001Ioooo00?o09Woooooool0A?ooo`040000<ol0<ol00000O?oo
o`00FOooo`03o`2Ioooooooo04Coool00`0003?o03?o00020000Noooo`00FOooo`03o`2Ioooooooo
04Coool0100003?o03?o000007coool005Woool00ol0VOooooooo`14oooo00@0000co`0co`00001l
oooo001Ioooo00?o09Woooooool0A?ooo`040000<ol0<ol00000O?ooo`00FOooo`03o`2Ioooooooo
04Coool0100003?o03?o000007coool005Woool00ol0VOooooooo`14oooo00@0000co`0co`00001l
oooo001Ioooo00?o09Woooooool0A?ooo`040000<ol0<ol00000O?ooo`00FOooo`03o`2Ioooooooo
04Goool0100003?o0000000007_oool005Woool00ol0VOooooooo`15oooo00<0000co`000000O?oo
o`00FOooo`03o`2Ioooooooo04Goool00`0003?o0000001loooo001Ioooo00?o09Woooooool0AOoo
o`030000<ol0000007coool005Woool00ol0VOooooooo`15oooo00<0000co`000000O?ooo`00FOoo
o`03o`2Ioooooooo04Goool00`0003?o0000001loooo001Ioooo00?o09Woooooool0AOooo`040000
<ol000000000Noooo`00FOooo`03o`2Ioooooooo04Goool00`0003?o0000001loooo001Ioooo00?o
09Woooooool0AOooo`030000<ol0000007coool005Woool00ol0VOooooooo`15oooo00<0000co`00
0000O?ooo`00FOooo`03o`2Ioooooooo04Goool00`0003?o0000001loooo001Ioooo00?o09Wooooo
ool0AOooo`030000<ol0000007coool005Woool00ol0VOooooooo`15oooo00@0000co`000000001k
oooo001Ioooo00?o09Woooooool0AOooo`030000<ol0000007coool005Woool00ol0VOooooooo`15
oooo00<0000co`000000O?ooo`00FOooo`03o`2Ioooooooo04Goool00`0003?o0000001loooo001I
oooo00?o09Woooooool0@?ooo`800003oooo00<0000co`000000O?ooo`00FOooo`03o`2Ioooooooo
03ooool010000?ooooooo`0000;oool00`0003?o0000001loooo001Ioooo00?o09Woooooool0@Ooo
o`060000oooooooooooo0000<ol00`0007[oool005Woool00ol0VOooooooo`12oooo00H0003ooooo
ool0000co`00001loooo001Ioooo00?o09Woooooool0?oooo`040000oooooooo00000_ooo`030000
<ol0000007coool005Woool00ol0VOooooooo`10oooo0P0000Coool20000O?ooo`00FOooo`03o`2I
oooooooo04Koool20000O?ooo`00FOooo`03o`2Ioooooooo04Koool20000O?ooo`00FOooo`03o`2I
oooooooo04Koool20000O?ooo`00FOooo`03o`2Ioooooooo04Koool30000Noooo`00FOooo`03o`2I
oooooooo04Koool20000O?ooo`00FOooo`03o`2Ioooooooo04Koool20000O?ooo`00FOooo`03o`2I
oooooooo04Koool20000O?ooo`00FOooo`03o`2Ioooooooo04Koool20000O?ooo`00FOooo`03o`2I
oooooooo04Koool20000O?ooo`00FOooo`03o`2Ioooooooo04Koool30000Noooo`00FOooo`03o`2I
oooooooo04Koool20000O?ooo`00FOooo`03o`2Ioooooooo04Koool20000O?ooo`00FOooo`03o`2I
oooooooo04Koool20000O?ooo`00FOooo`03o`2Ioooooooo04Koool20000O?ooo`00FOooo`03o`2I
oooooooo04Koool20000O?ooo`00FOooo`03o`2Ioooooooo04Koool30000Noooo`00FOooo`03o`2I
oooooooo04Ooool00`000?ooooooo`1joooo001Ioooo00?o09Woooooool0Aoooo`030000oooooooo
07[oool005Woool00ol0VOooooooo`17oooo00<0003oooooool0N_ooo`00FOooo`03o`2Ioooooooo
04Ooool00`000?ooooooo`1joooo001Ioooo00?o09Woooooool0Aoooo`030000oooooooo07[oool0
05Woool00ol0VOooooooo`17oooo0P0007_oool005Woool00ol0VOooooooo`17oooo00<0003ooooo
ool0N_ooo`00FOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`1joooo001Ioooo00?o09Wooooo
ool0Aoooo`030000oooooooo07[oool005Woool00ol0VOooooooo`17oooo00<0003oooooool0N_oo
o`00FOooo`03o`2Ioooooooo047oool300000oooo`030000oooooooo07[oool005Woool00ol0VOoo
ooooo`12oooo00<0003oooooool00_ooo`030000oooooooo07[oool005Woool00ol0VOooooooo`0o
oooo1@0000?oool30000N_ooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000oooo0000
087oool009goool20000POooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000
oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0>oooo0`00
00;oool200001Oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000Koool00`000?oo
ooooo`08oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool04oooo`D00009oooo00<0003oooooool00oooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002oooo`050000oooooooooooo0000
07[oool007Soool01@000?ooooooooooo`00000Foooo00<0003oool000002?ooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Hoooo0P0000Soool400000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.28302 .12361 L
.2881 .12361 L
.29088 .12361 L
.29224 .12361 L
.29349 .12361 L
s
.29349 .12361 m
.29394 .61803 L
s
0 .4 1 r
.02381 .13555 m
.04262 .14031 L
.06244 .14739 L
.07286 .15223 L
.08255 .15764 L
.10458 .17399 L
.12328 .19391 L
.12836 .20058 L
.13313 .2074 L
.13436 .20926 L
.13552 .21011 L
.13617 .2101 L
.13687 .21009 L
.1381 .21007 L
.14357 .20998 L
.15465 .20975 L
.16488 .2095 L
.17544 .20918 L
.18502 .20885 L
.20469 .20794 L
.21549 .20728 L
.22566 .20654 L
.24574 .20462 L
.26421 .20213 L
.2733 .20057 L
.28304 .1986 L
.28591 .19794 L
.28863 .1973 L
.29107 .19669 L
.29174 .19651 L
.29245 .19633 L
.29373 .12361 L
.2949 .12361 L
.29617 .12361 L
.29737 .12361 L
.29847 .12361 L
.29969 .12361 L
.30038 .12361 L
.30102 .12361 L
.30232 .12361 L
.30304 .12361 L
.3037 .12361 L
.30489 .12361 L
.30601 .12361 L
.30724 .12361 L
.30855 .12361 L
.30921 .12361 L
.30993 .12361 L
.31123 .12361 L
.3125 .12361 L
Mistroke
.31368 .12361 L
.31489 .12361 L
.31602 .12361 L
.31704 .12361 L
.31814 .12361 L
.31934 .12361 L
.32061 .12361 L
.3217 .12361 L
.32289 .12361 L
.32419 .12361 L
.32484 .12361 L
.32557 .12361 L
.32635 .12361 L
.32708 .12361 L
.32776 .12361 L
.32848 .12361 L
.32912 .12361 L
.32983 .12361 L
.33056 .12361 L
.33124 .12361 L
.33247 .12361 L
.33377 .12361 L
.33506 .12361 L
.33578 .12361 L
.33645 .12361 L
.33767 .12361 L
.33897 .12361 L
.34013 .12361 L
.34122 .12361 L
.34241 .12361 L
.34368 .12361 L
.34499 .12361 L
.3462 .12361 L
.34683 .12361 L
.34752 .12361 L
.34825 .12361 L
.34893 .12361 L
.35018 .12361 L
.35132 .12361 L
.35197 .12361 L
.35266 .12361 L
.35391 .12361 L
.35504 .12361 L
.35607 .12361 L
.35729 .12361 L
.35845 .12361 L
.35964 .12361 L
.36074 .12361 L
.36195 .12361 L
.36323 .12361 L
Mistroke
.36453 .12361 L
.36571 .12361 L
.36636 .12361 L
.36708 .12361 L
.36838 .12361 L
.36959 .12361 L
.37088 .12361 L
.37209 .12361 L
.37319 .12361 L
.37388 .12361 L
.37461 .12361 L
.37591 .12361 L
.37663 .12361 L
.37731 .12361 L
.37805 .12361 L
.37884 .12361 L
.37953 .12361 L
.38027 .12361 L
.38097 .12361 L
.38162 .12361 L
.38285 .12361 L
.38416 .12361 L
.3853 .12361 L
.38655 .12361 L
.38785 .12361 L
.38905 .12361 L
.39019 .12361 L
.39122 .12361 L
.39242 .12361 L
.39354 .12361 L
.39477 .12361 L
.39606 .12361 L
.39717 .12361 L
.39839 .12361 L
.3997 .12361 L
.40044 .12361 L
.40111 .12361 L
.40241 .12361 L
.40365 .12361 L
.4047 .12361 L
.40583 .12361 L
.4069 .12361 L
.40789 .12361 L
.40904 .12361 L
.41025 .12361 L
.4124 .12361 L
.41354 .12361 L
.41476 .12361 L
.41546 .12361 L
.4161 .12361 L
Mistroke
.41735 .12361 L
.41849 .12361 L
.41971 .12361 L
.42085 .12361 L
.42193 .12361 L
.42313 .12361 L
.42423 .12361 L
.42544 .12361 L
.42676 .12361 L
.42804 .12361 L
.42876 .12361 L
.42941 .12361 L
.43068 .12361 L
.43188 .12361 L
.433 .12361 L
.43418 .12361 L
.43519 .12361 L
.43629 .12361 L
.43747 .12361 L
.43875 .12361 L
.43995 .12361 L
.44107 .12361 L
.44238 .12361 L
.44305 .12361 L
.44378 .12361 L
.44506 .12361 L
.44625 .12361 L
.44693 .12361 L
.44765 .12361 L
.44893 .12361 L
.44964 .12361 L
.45031 .12361 L
.45104 .12361 L
.45181 .12361 L
.45311 .12361 L
.45384 .12361 L
.45452 .12361 L
.45576 .12361 L
.45707 .12361 L
.45825 .12361 L
.45935 .12361 L
.46055 .12361 L
.46185 .12361 L
.46254 .12361 L
.46318 .12361 L
.46439 .12361 L
.46569 .12361 L
.46643 .12361 L
.4671 .12361 L
.46823 .12361 L
Mistroke
.46947 .12361 L
.47077 .12361 L
.47197 .12361 L
.47266 .12361 L
.47341 .12361 L
.47411 .12361 L
.47476 .12361 L
.476 .12361 L
.4773 .12361 L
.478 .12361 L
.47864 .12361 L
.47932 .12361 L
.48005 .12361 L
.4808 .12361 L
.4816 .12361 L
.48234 .12361 L
.48301 .12361 L
.48423 .12361 L
.48555 .12361 L
.4868 .12361 L
.48795 .12361 L
.48902 .12361 L
.49019 .12361 L
.49142 .12361 L
.49257 .12361 L
.49323 .12361 L
.49394 .12361 L
.49523 .12361 L
.49649 .12361 L
.49766 .12361 L
.49891 .12361 L
.49963 .12361 L
.5003 .12361 L
.50096 .12361 L
.50165 .12361 L
.50241 .12361 L
.50311 .12361 L
.50434 .12361 L
.50504 .12361 L
.50568 .12361 L
.50685 .12361 L
.5081 .12361 L
.50921 .12361 L
.51026 .12361 L
.5114 .12361 L
.51264 .12361 L
.51394 .12361 L
.51468 .12361 L
.51536 .12361 L
.51662 .12361 L
Mistroke
.51732 .12361 L
.51795 .12361 L
.51916 .12361 L
.52046 .12361 L
.52169 .12361 L
.52282 .12361 L
.52388 .12361 L
.52502 .12361 L
.5261 .12361 L
.52708 .12361 L
.52823 .12361 L
.52948 .12361 L
.53066 .12361 L
.53175 .12361 L
.53287 .12361 L
.53392 .12361 L
.53508 .12361 L
.53632 .12361 L
.53755 .12361 L
.53885 .12361 L
.53996 .12361 L
.54118 .12361 L
.5425 .12361 L
.54371 .12361 L
.54435 .12361 L
.54505 .12361 L
.54578 .12361 L
.54646 .12361 L
.54772 .12361 L
.54887 .12361 L
.54951 .12361 L
.5502 .12361 L
.55146 .12361 L
.55269 .12361 L
.5538 .12361 L
.55509 .12361 L
.5563 .12361 L
.55743 .12361 L
.55846 .12361 L
.5596 .12361 L
.56079 .12361 L
.5621 .12361 L
.56329 .12361 L
.56395 .12361 L
.56467 .12361 L
.56597 .12361 L
.56718 .12361 L
.56847 .12361 L
.56957 .12361 L
.57079 .12361 L
Mistroke
.57152 .12361 L
.57221 .12361 L
.57351 .12361 L
.57424 .12361 L
.57491 .12361 L
.57565 .12361 L
.57644 .12361 L
.57713 .12361 L
.57787 .12361 L
.57858 .12361 L
.57922 .12361 L
.58045 .12361 L
.58175 .12361 L
.61969 .12361 L
.66009 .12361 L
.69898 .12361 L
.74031 .12361 L
.78013 .12361 L
.81844 .12361 L
.8592 .12361 L
.89844 .12361 L
.93616 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Goool00`1Vooooo`000009oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`05oooo00<0I_ooooooool07Ooo
o`030000oooooooo00Koool400006c?o00030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
003oooooool0:Oooo`005_ooo`80I_m3oooo00<0I_ooooooool0:_ooo`@0000G<ol000<0003ooooo
ool0N_ooo`006?ooo`80I_m1oooo00<0I_ooooooool0;_ooo`030000<ol0<ol001@co`000`000?oo
ooooo`1joooo000Joooo101Vocgoool00`1Vooooooooo`0_oooo0P0001@co`000`000?ooooooo`1j
oooo000Noooo0`1Voc[oool00`1Vooooooooo`0aoooo00<0000co`0co`004C?o00030000oooooooo
07[oool0027oool206Ko>?ooo`0306Kooooooooo03;oool00`0003?o03?o000@<ol00P0007_oool0
02?oool00`1Vooooooooo`0eoooo00<0I_ooooooool0<oooo`80000@<ol000<0003oooooool0N_oo
o`009?ooo`80I_leoooo00<0I_ooooooool0=Oooo`030000<ol0<ol000dco`000`000?ooooooo`1j
oooo000Voooo0P1Voc;oool00`1Vool0VOooo`0foooo00<0000co`0co`003C?o00030000oooooooo
07[oool002Soool00`1Vooooooooo`0_oooo00<0I_oo09Woool0=oooo`030000<ol0<ol000`co`00
0`000?ooooooo`1joooo000Yoooo0P1Vobooool00`1Vool0VOooo`0goooo00<0000co`0co`0033?o
00030000oooooooo07[oool002_oool00`1Vooooooooo`0/oooo00<0I_oo09Woool0>?ooo`030000
<ol0<ol000/co`020000Noooo`00;?ooo`0306Kooooooooo02_oool00`1Vool0VOooo`0hoooo00<0
000co`0co`002c?o00030000oooooooo07[oool002goool00`1Vooooooooo`0Zoooo00<0I_oo09Wo
ool0>Oooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo000]oooo00<0I_ooooooool0:_oo
o`0306Koo`2Ioooo03Woool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00;_ooo`0306Ko
oooooooo02Woool00`1Vool0VOooo`0joooo00<0000co`0co`002C?o00030000oooooooo07[oool0
02ooool00`1Vooooooooo`0Xoooo00<0I_oo09Woool0>_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1joooo000`oooo00<0I_ooooooool09?ooo`@0I_l00ol0VOooooooo`0joooo00<0000co`0c
o`0023?o0080001koooo000aoooo00<0I_ooooooool07_ooo`D0I_l4oooo00?o09Woooooool0>_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`1joooo000aoooo00<0I_ooooooool05Oooo`T0I_l9
oooo00?o09Woooooool0>_ooo`030000<ol0<ol000Pco`000`000?ooooooo`1joooo000boooo5`1V
oa;oool00ol0VOooooooo`0koooo00<0000co`0co`001c?o00030000oooooooo07[oool005_oool0
0ol0VOooooooo`0koooo00<0000co`0co`001c?o00030000oooooooo07[oool005_oool00ol0VOoo
ooooo`0koooo00<0000co`0co`001c?o00030000oooooooo07[oool005_oool00ol0VOooooooo`0k
oooo00<0000co`0co`001c?o0080001koooo001Koooo00?o09Woooooool0??ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`1joooo001Koooo00?o09Woooooool0??ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1joooo001Koooo00?o09Woooooool0??ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1joooo001Koooo00?o09Woooooool0??ooo`030000<ol0<ol000Hco`000`000?ooooooo`1j
oooo001Koooo00?o09Woooooool0?Oooo`D00003<ol000<0003oooooool0N_ooo`00Foooo`03o`2I
oooooooo03goool00`0003?o00000005<ol000<0003oooooool0N_ooo`00Foooo`03o`2Ioooooooo
03goool00`0003?o00000005<ol00`0007[oool005_oool00ol0VOooooooo`0noooo0P0000Dco`00
0`000?ooooooo`1joooo001Koooo00?o09Woooooool0?_ooo`800005<ol000<0003oooooool0N_oo
o`00Foooo`03o`2Ioooooooo03koool200001C?o00030000oooooooo07[oool005_oool00ol0VOoo
ooooo`0noooo00<0000co`0co`0013?o00030000oooooooo07[oool005_oool00ol0VOooooooo`0n
oooo00<0000co`0co`0013?o00030000oooooooo07[oool005_oool00ol0VOooooooo`0noooo00<0
000co`0co`0013?o0080001koooo001Koooo00?o09Woooooool0?oooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo001Koooo00?o09Woooooool0?oooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo001Koooo00?o09Woooooool0?oooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo001Koooo00?o09Woooooool0?oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001K
oooo00?o09Woooooool0?oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001Koooo00?o
09Woooooool0?oooo`030000<ol0<ol000<co`020000Noooo`00Foooo`03o`2Ioooooooo03ooool0
0`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Foooo`03o`2Ioooooooo03ooool00`0003?o
03?o0003<ol000<0003oooooool0N_ooo`00Foooo`03o`2Ioooooooo043oool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Foooo`03o`2Ioooooooo043oool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00Foooo`03o`2Ioooooooo043oool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00Foooo`03o`2Ioooooooo043oool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00Foooo`03o`2Ioooooooo043oool00`0003?o03?o0002<ol00P0007_oool005_oool00ol0VOoo
ooooo`10oooo00<0000co`0co`000S?o00030000oooooooo07[oool005_oool00ol0VOooooooo`10
oooo00<0000co`0co`000S?o00030000oooooooo07[oool005_oool00ol0VOooooooo`10oooo00<0
000co`0co`000S?o00030000oooooooo07[oool005_oool00ol0VOooooooo`10oooo00<0000co`0c
o`000S?o00030000oooooooo07[oool005_oool00ol0VOooooooo`10oooo00<0000co`0co`000S?o
00030000oooooooo07[oool005_oool00ol0VOooooooo`10oooo00<0000co`0co`000S?o0080001k
oooo001Koooo00?o09Woooooool0@Oooo`050000<ol0<ol0<ol0000007coool005_oool00ol0VOoo
ooooo`11oooo00D0000co`0co`0co`000000O?ooo`00Foooo`03o`2Ioooooooo047oool01@0003?o
03?o03?o0000001loooo001Koooo00?o09Woooooool0?Oooo`D00003<ol000<0003oooooool0N_oo
o`00Foooo`03o`2Ioooooooo03goool01@000?ooooooooooo`000003<ol000<0003oooooool0N_oo
o`00Foooo`03o`2Ioooooooo03koool010000?ooooooo`0000<co`030000N_ooo`00Foooo`03o`2I
oooooooo03ooool00`000?ooo`000003<ol000<0003oooooool0N_ooo`00Foooo`03o`2Ioooooooo
03goool00`000?ooooooo`0200000c?o00030000oooooooo07[oool005_oool00ol0VOooooooo`0n
oooo0P000003oooo0000<ol0008co`000`000?ooooooo`1joooo001Koooo00?o09Woooooool0@Ooo
o`050000<ol0<ol0<ol0000007coool005_oool00ol0VOooooooo`12oooo00@0000co`0co`00001l
oooo001Koooo00?o09Woooooool0@_ooo`030000<ol0<ol00080001koooo001Koooo00?o09Wooooo
ool0@_ooo`040000<ol0<ol00000O?ooo`00Foooo`03o`2Ioooooooo04;oool0100003?o03?o0000
07coool005_oool00ol0VOooooooo`12oooo00@0000co`0co`00001loooo001Koooo00?o09Wooooo
ool0@_ooo`040000<ol0<ol00000O?ooo`00Foooo`03o`2Ioooooooo04;oool0100003?o03?o0000
07coool005_oool00ol0VOooooooo`12oooo00@0000co`0co`00001loooo001Koooo00?o09Wooooo
ool0@oooo`040000<ol000000000Noooo`00Foooo`03o`2Ioooooooo04?oool00`0003?o0000001l
oooo001Koooo00?o09Woooooool0@oooo`030000<ol0000007coool005_oool00ol0VOooooooo`13
oooo00<0000co`000000O?ooo`00Foooo`03o`2Ioooooooo04?oool00`0003?o0000001loooo001K
oooo00?o09Woooooool0@oooo`030000<ol0000007coool005_oool00ol0VOooooooo`13oooo00@0
000co`000000001koooo001Koooo00?o09Woooooool0@oooo`030000<ol0000007coool005_oool0
0ol0VOooooooo`13oooo00<0000co`000000O?ooo`00Foooo`03o`2Ioooooooo04?oool00`0003?o
0000001loooo001Koooo00?o09Woooooool0@oooo`030000<ol0000007coool005_oool00ol0VOoo
ooooo`13oooo00<0000co`000000O?ooo`00Foooo`03o`2Ioooooooo04?oool0100003?o00000000
07_oool005_oool00ol0VOooooooo`13oooo00<0000co`000000O?ooo`00Foooo`03o`2Ioooooooo
04?oool00`0003?o0000001loooo001Koooo00?o09Woooooool0@oooo`030000<ol0000007coool0
05_oool00ol0VOooooooo`0noooo0P0000?oool00`0003?o0000001loooo001Koooo00?o09Wooooo
ool0?Oooo`040000oooooooo00000_ooo`030000<ol0000007coool005_oool00ol0VOooooooo`0o
oooo00H0003oooooooooool0000co`030000N_ooo`00Foooo`03o`2Ioooooooo043oool01P000?oo
ooooo`0003?o000007coool005_oool00ol0VOooooooo`0moooo00@0003oooooool00002oooo00<0
000co`000000O?ooo`00Foooo`03o`2Ioooooooo03koool200001?ooo`80001loooo001Koooo00?o
09Woooooool0A?ooo`80001loooo001Koooo00?o09Woooooool0A?ooo`80001loooo001Koooo00?o
09Woooooool0A?ooo`80001loooo001Koooo00?o09Woooooool0A?ooo`<0001koooo001Koooo00?o
09Woooooool0A?ooo`80001loooo001Koooo00?o09Woooooool0A?ooo`80001loooo001Koooo00?o
09Woooooool0A?ooo`80001loooo001Koooo00?o09Woooooool0A?ooo`80001loooo001Koooo00?o
09Woooooool0A?ooo`80001loooo001Koooo00?o09Woooooool0A?ooo`<0001koooo001Koooo00?o
09Woooooool0A?ooo`80001loooo001Koooo00?o09Woooooool0A?ooo`80001loooo001Koooo00?o
09Woooooool0A?ooo`80001loooo001Koooo00?o09Woooooool0A?ooo`80001loooo001Koooo00?o
09Woooooool0A?ooo`80001loooo001Koooo00?o09Woooooool0A?ooo`<0001koooo001Koooo00?o
09Woooooool0AOooo`030000oooooooo07[oool005_oool00ol0VOooooooo`15oooo00<0003ooooo
ool0N_ooo`00Foooo`03o`2Ioooooooo04Goool00`000?ooooooo`1joooo001Koooo00?o09Wooooo
ool0AOooo`030000oooooooo07[oool005_oool00ol0VOooooooo`15oooo00<0003oooooool0N_oo
o`00Foooo`03o`2Ioooooooo04Goool20000Noooo`00Foooo`03o`2Ioooooooo04Goool00`000?oo
ooooo`1joooo001Koooo00?o09Woooooool0AOooo`030000oooooooo07[oool005_oool00ol0VOoo
ooooo`15oooo00<0003oooooool0N_ooo`00Foooo`03o`2Ioooooooo04Goool00`000?ooooooo`1j
oooo001Koooo00?o09Woooooool0?oooo`<00003oooo00<0003oooooool0N_ooo`00Foooo`03o`2I
oooooooo043oool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00Foooo`03o`2Ioooooooo
03goool500000oooo`<0001joooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool0
0000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00koool3
00000_ooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000Koool00`000?ooooooo`06
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0Coooo1@0000Ooool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool300001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000Foooo00<0003oool000002Oooo`030000oooooooo
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool06?ooo`800009oooo0`0000;oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.28302 .12361 L
.2881 .12361 L
.29349 .12361 L
.29809 .12361 L
.29935 .12361 L
.30004 .12361 L
.3007 .12361 L
s
.3007 .12361 m
.30122 .61803 L
s
0 .4 1 r
.02381 .13398 m
.04262 .13811 L
.06244 .14425 L
.07286 .14846 L
.08255 .15315 L
.09388 .15975 L
.10458 .16735 L
.125 .18654 L
.13384 .19728 L
.13886 .20418 L
.14012 .20601 L
.14132 .20779 L
.1424 .20942 L
.14357 .21011 L
.14475 .21009 L
.14599 .21007 L
.14824 .21003 L
.15327 .20994 L
.16355 .20973 L
.18199 .20923 L
.19227 .20887 L
.2034 .2084 L
.21301 .20792 L
.22357 .20727 L
.24351 .20568 L
.2544 .20454 L
.26457 .20325 L
.27502 .20167 L
.28492 .19986 L
.29381 .19795 L
.29625 .19737 L
.29883 .19673 L
.2999 .19646 L
.30104 .19616 L
.3023 .12361 L
.30348 .12361 L
.30474 .12361 L
.30588 .12361 L
.3072 .12361 L
.30844 .12361 L
.30959 .12361 L
.31065 .12361 L
.31182 .12361 L
.31305 .12361 L
.31429 .12361 L
.31499 .12361 L
.31563 .12361 L
.31686 .12361 L
.31804 .12361 L
.3187 .12361 L
Mistroke
.3194 .12361 L
.32066 .12361 L
.32143 .12361 L
.32216 .12361 L
.32282 .12361 L
.32352 .12361 L
.32484 .12361 L
.32607 .12361 L
.32678 .12361 L
.32743 .12361 L
.32817 .12361 L
.32887 .12361 L
.32955 .12361 L
.33028 .12361 L
.33158 .12361 L
.3323 .12361 L
.33298 .12361 L
.33372 .12361 L
.33452 .12361 L
.33575 .12361 L
.33644 .12361 L
.33709 .12361 L
.3384 .12361 L
.33913 .12361 L
.33979 .12361 L
.34098 .12361 L
.34228 .12361 L
.3435 .12361 L
.34462 .12361 L
.34588 .12361 L
.34707 .12361 L
.34814 .12361 L
.34931 .12361 L
.35058 .12361 L
.35122 .12361 L
.35192 .12361 L
.35317 .12361 L
.35434 .12361 L
.35545 .12361 L
.35662 .12361 L
.35763 .12361 L
.35871 .12361 L
.35987 .12361 L
.36096 .12361 L
.36225 .12361 L
.36342 .12361 L
.36471 .12361 L
.36536 .12361 L
.36607 .12361 L
.36733 .12361 L
Mistroke
.36852 .12361 L
.36922 .12361 L
.37 .12361 L
.37073 .12361 L
.3714 .12361 L
.37268 .12361 L
.37339 .12361 L
.37404 .12361 L
.37524 .12361 L
.37653 .12361 L
.37775 .12361 L
.37888 .12361 L
.38008 .12361 L
.38077 .12361 L
.38141 .12361 L
.38269 .12361 L
.38342 .12361 L
.38408 .12361 L
.38526 .12361 L
.38636 .12361 L
.38758 .12361 L
.38889 .12361 L
.39019 .12361 L
.39084 .12361 L
.39156 .12361 L
.39282 .12361 L
.394 .12361 L
.3952 .12361 L
.39632 .12361 L
.39734 .12361 L
.39844 .12361 L
.39964 .12361 L
.4009 .12361 L
.40199 .12361 L
.40318 .12361 L
.40384 .12361 L
.40456 .12361 L
.40588 .12361 L
.40716 .12361 L
.40835 .12361 L
.40908 .12361 L
.40976 .12361 L
.41104 .12361 L
.41176 .12361 L
.41242 .12361 L
.41314 .12361 L
.41391 .12361 L
.4151 .12361 L
.41639 .12361 L
.41759 .12361 L
Mistroke
.41869 .12361 L
.41999 .12361 L
.42072 .12361 L
.42139 .12361 L
.42263 .12361 L
.42394 .12361 L
.42514 .12361 L
.42646 .12361 L
.4277 .12361 L
.42885 .12361 L
.42999 .12361 L
.43103 .12361 L
.43222 .12361 L
.43335 .12361 L
.43458 .12361 L
.43588 .12361 L
.43699 .12361 L
.43821 .12361 L
.43952 .12361 L
.44026 .12361 L
.44093 .12361 L
.44223 .12361 L
.44347 .12361 L
.44452 .12361 L
.44567 .12361 L
.44688 .12361 L
.44802 .12361 L
.44907 .12361 L
.45004 .12361 L
.45111 .12361 L
.45223 .12361 L
.45337 .12361 L
.45459 .12361 L
.45574 .12361 L
.45678 .12361 L
.45801 .12361 L
.4587 .12361 L
.45934 .12361 L
.46052 .12361 L
.46176 .12361 L
.46297 .12361 L
.46429 .12361 L
.46554 .12361 L
.46669 .12361 L
.46784 .12361 L
.46887 .12361 L
.47007 .12361 L
.47119 .12361 L
.47243 .12361 L
.47373 .12361 L
Mistroke
.47485 .12361 L
.47607 .12361 L
.47738 .12361 L
.47812 .12361 L
.47879 .12361 L
.48009 .12361 L
.48133 .12361 L
.48238 .12361 L
.48354 .12361 L
.48475 .12361 L
.48589 .12361 L
.48695 .12361 L
.48792 .12361 L
.48898 .12361 L
.4901 .12361 L
.49125 .12361 L
.49247 .12361 L
.49362 .12361 L
.49466 .12361 L
.49589 .12361 L
.49658 .12361 L
.49722 .12361 L
.4984 .12361 L
.49964 .12361 L
.50085 .12361 L
.50218 .12361 L
.50343 .12361 L
.50458 .12361 L
.50562 .12361 L
.50677 .12361 L
.50797 .12361 L
.50909 .12361 L
.50974 .12361 L
.51043 .12361 L
.51167 .12361 L
.51297 .12361 L
.51371 .12361 L
.51439 .12361 L
.51558 .12361 L
.51688 .12361 L
.51811 .12361 L
.51924 .12361 L
.52029 .12361 L
.52128 .12361 L
.52236 .12361 L
.52352 .12361 L
.52474 .12361 L
.52589 .12361 L
.52703 .12361 L
.52806 .12361 L
Mistroke
.5292 .12361 L
.53041 .12361 L
.53154 .12361 L
.5326 .12361 L
.53385 .12361 L
.53499 .12361 L
.53624 .12361 L
.53687 .12361 L
.53757 .12361 L
.53887 .12361 L
.54008 .12361 L
.54071 .12361 L
.5414 .12361 L
.54213 .12361 L
.54281 .12361 L
.54406 .12361 L
.5452 .12361 L
.54645 .12361 L
.54778 .12361 L
.54889 .12361 L
.55008 .12361 L
.5512 .12361 L
.55222 .12361 L
.55342 .12361 L
.55472 .12361 L
.55595 .12361 L
.55708 .12361 L
.55829 .12361 L
.55958 .12361 L
.5608 .12361 L
.56192 .12361 L
.56323 .12361 L
.56397 .12361 L
.56465 .12361 L
.56591 .12361 L
.56661 .12361 L
.56724 .12361 L
.56792 .12361 L
.56863 .12361 L
.56991 .12361 L
.57062 .12361 L
.57128 .12361 L
.57201 .12361 L
.57278 .12361 L
.57346 .12361 L
.57419 .12361 L
.57488 .12361 L
.57551 .12361 L
.57672 .12361 L
.578 .12361 L
Mistroke
.5792 .12361 L
.58051 .12361 L
.58175 .12361 L
.5829 .12361 L
.5874 .12361 L
.59751 .12361 L
.61581 .12361 L
.65491 .12361 L
.69647 .12361 L
.73651 .12361 L
.77504 .12361 L
.81602 .12361 L
.85548 .12361 L
.89343 .12361 L
.93383 .12361 L
.97271 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Koool00ol0V@000?ooo`08oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`06oooo00?o09T0I_ooool07?oo
o`030000oooooooo00Koool400006c?o00030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
003oooooool0:Oooo`005_ooo`<0I_m3oooo00?o09T0I_ooool0:Oooo`@0000G<ol000<0003ooooo
ool0N_ooo`006Oooo`@0I_looooo00?o09T0I_ooool0;Oooo`030000<ol0<ol001@co`000`000?oo
ooooo`1joooo000Moooo0P1Vocgoool00ol0V@1Vooooo`0^oooo0P0001@co`000`000?ooooooo`1j
oooo000Ooooo0`1Voc[oool00ol0V@1Vooooo`0`oooo00<0000co`0co`004C?o00030000oooooooo
07[oool002;oool206Ko>?ooo`03o`2I06Kooooo037oool00`0003?o03?o000@<ol00P0007_oool0
02Coool206Ko=_ooo`03o`2I06Kooooo03;oool2000043?o00030000oooooooo07[oool002Koool2
06Ko=?ooo`03o`2I06Kooooo03Coool00`0003?o03?o000=<ol000<0003oooooool0N_ooo`00:?oo
o`80I_lboooo00?o09T0I_ooool0=?ooo`030000<ol0<ol000dco`000`000?ooooooo`1joooo000Z
oooo0P1Voc3oool00ol0V@1Vooooo`0eoooo00<0000co`0co`0033?o00030000oooooooo07[oool0
02coool00`1Vooooooooo`0]oooo00?o09T0I_ooool0=Oooo`030000<ol0<ol000`co`000`000?oo
ooooo`1joooo000]oooo00<0I_ooooooool0;?ooo`03o`2I06Kooooo03Koool00`0003?o03?o000;
<ol00P0007_oool002koool00`1Vooooooooo`0[oooo00?o09T0I_ooool0=_ooo`030000<ol0<ol0
00/co`000`000?ooooooo`1joooo000_oooo00<0I_ooooooool0:_ooo`03o`2I06Kooooo03Ooool0
0`0003?o03?o000:<ol000<0003oooooool0N_ooo`00<?ooo`0306Kooooooooo02Woool00ol0V@1V
ooooo`0goooo00<0000co`0co`002S?o00030000oooooooo07[oool0037oool00`1Vooooooooo`0X
oooo00?o09T0I_ooool0>?ooo`030000<ol0<ol000Tco`000`000?ooooooo`1joooo000aoooo00<0
I_ooooooool0:?ooo`03o`2I06Kooooo03Soool00`0003?o03?o0009<ol000<0003oooooool0N_oo
o`00<_ooo`0306Kooooooooo02Goool406Ko>_ooo`030000<ol0<ol000Pco`020000Noooo`00<_oo
o`0306Kooooooooo023oool506Ko0_ooo`03o`2Ioooooooo03Woool00`0003?o03?o0008<ol000<0
003oooooool0N_ooo`00<oooo`80I_lGoooo2@1Vo`Ooool00ol0VOooooooo`0ioooo00<0000co`0c
o`0023?o00030000oooooooo07[oool003CooolH06Ko4?ooo`03o`2Ioooooooo03[oool00`0003?o
03?o0007<ol000<0003oooooool0N_ooo`00G?ooo`03o`2Ioooooooo03[oool00`0003?o03?o0007
<ol000<0003oooooool0N_ooo`00G?ooo`03o`2Ioooooooo03[oool00`0003?o03?o0007<ol000<0
003oooooool0N_ooo`00G?ooo`03o`2Ioooooooo03[oool00`0003?o03?o0007<ol00P0007_oool0
05coool00ol0VOooooooo`0koooo00<0000co`0co`001S?o00030000oooooooo07[oool005coool0
0ol0VOooooooo`0koooo00<0000co`0co`001S?o00030000oooooooo07[oool005coool00ol0VOoo
ooooo`0koooo00<0000co`0co`001S?o00030000oooooooo07[oool005coool00ol0VOooooooo`0k
oooo00<0000co`0co`001S?o00030000oooooooo07[oool005coool00ol0VOooooooo`0loooo1@00
00<co`000`000?ooooooo`1joooo001Loooo00?o09Woooooool0??ooo`030000<ol0000000Dco`00
0`000?ooooooo`1joooo001Loooo00?o09Woooooool0??ooo`030000<ol0000000Dco`030000N_oo
o`00G?ooo`03o`2Ioooooooo03goool200001C?o00030000oooooooo07[oool005coool00ol0VOoo
ooooo`0moooo0P0000Dco`000`000?ooooooo`1joooo001Loooo00?o09Woooooool0?Oooo`800005
<ol000<0003oooooool0N_ooo`00G?ooo`03o`2Ioooooooo03goool00`0003?o03?o0004<ol000<0
003oooooool0N_ooo`00G?ooo`03o`2Ioooooooo03goool00`0003?o03?o0004<ol000<0003ooooo
ool0N_ooo`00G?ooo`03o`2Ioooooooo03goool00`0003?o03?o0004<ol00P0007_oool005coool0
0ol0VOooooooo`0noooo00<0000co`0co`000c?o00030000oooooooo07[oool005coool00ol0VOoo
ooooo`0noooo00<0000co`0co`000c?o00030000oooooooo07[oool005coool00ol0VOooooooo`0n
oooo00<0000co`0co`000c?o00030000oooooooo07[oool005coool00ol0VOooooooo`0noooo00<0
000co`0co`000c?o00030000oooooooo07[oool005coool00ol0VOooooooo`0noooo00<0000co`0c
o`000c?o00030000oooooooo07[oool005coool00ol0VOooooooo`0noooo00<0000co`0co`000c?o
0080001koooo001Loooo00?o09Woooooool0?_ooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo001Loooo00?o09Woooooool0?_ooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001L
oooo00?o09Woooooool0?oooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Loooo00?o
09Woooooool0?oooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Loooo00?o09Wooooo
ool0?oooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Loooo00?o09Woooooool0?ooo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Loooo00?o09Woooooool0?oooo`030000
<ol0<ol0008co`020000Noooo`00G?ooo`03o`2Ioooooooo03ooool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00G?ooo`03o`2Ioooooooo03ooool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00G?ooo`03o`2Ioooooooo03ooool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00G?ooo`03o`2Ioooooooo03ooool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00G?oo
o`03o`2Ioooooooo03ooool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00G?ooo`03o`2I
oooooooo03ooool00`0003?o03?o0002<ol00P0007_oool005coool00ol0VOooooooo`10oooo00D0
000co`0co`0co`000000O?ooo`00G?ooo`03o`2Ioooooooo043oool01@0003?o03?o03?o0000001l
oooo001Loooo00?o09Woooooool0@?ooo`050000<ol0<ol0<ol0000007coool005coool00ol0VOoo
ooooo`0loooo1@0000<co`000`000?ooooooo`1joooo001Loooo00?o09Woooooool0??ooo`050000
oooooooooooo000000<co`000`000?ooooooo`1joooo001Loooo00?o09Woooooool0?Oooo`040000
oooooooo00000c?o00<0001joooo001Moooo00?o09Woooooool0?Oooo`030000oooo000000<co`00
0`000?ooooooo`1joooo001Moooo00?o09Woooooool0>oooo`030000oooooooo00800003<ol000<0
003oooooool0N_ooo`00GOooo`03o`2Ioooooooo03coool2000000?oool0000co`000S?o00030000
oooooooo07[oool005goool00ol0VOooooooo`0ooooo00D0000co`0co`0co`000000O?ooo`00GOoo
o`03o`2Ioooooooo043oool0100003?o03?o000007coool005goool00ol0VOooooooo`10oooo00<0
000co`0co`000P0007_oool005goool00ol0VOooooooo`10oooo00@0000co`0co`00001loooo001M
oooo00?o09Woooooool0@?ooo`040000<ol0<ol00000O?ooo`00GOooo`03o`2Ioooooooo043oool0
100003?o03?o000007coool005goool00ol0VOooooooo`10oooo00@0000co`0co`00001loooo001M
oooo00?o09Woooooool0@?ooo`040000<ol0<ol00000O?ooo`00GOooo`03o`2Ioooooooo043oool0
100003?o03?o000007coool005goool00ol0VOooooooo`11oooo00@0000co`000000001koooo001M
oooo00?o09Woooooool0@Oooo`030000<ol0000007coool005goool00ol0VOooooooo`11oooo00<0
000co`000000O?ooo`00GOooo`03o`2Ioooooooo047oool00`0003?o0000001loooo001Moooo00?o
09Woooooool0@Oooo`030000<ol0000007coool005goool00ol0VOooooooo`11oooo00<0000co`00
0000O?ooo`00GOooo`03o`2Ioooooooo047oool0100003?o0000000007_oool005goool00ol0VOoo
ooooo`11oooo00<0000co`000000O?ooo`00GOooo`03o`2Ioooooooo047oool00`0003?o0000001l
oooo001Moooo00?o09Woooooool0@Oooo`030000<ol0000007coool005goool00ol0VOooooooo`11
oooo00<0000co`000000O?ooo`00GOooo`03o`2Ioooooooo047oool00`0003?o0000001loooo001M
oooo00?o09Woooooool0@Oooo`040000<ol000000000Noooo`00GOooo`03o`2Ioooooooo047oool0
0`0003?o0000001loooo001Moooo00?o09Woooooool0@Oooo`030000<ol0000007coool005goool0
0ol0VOooooooo`11oooo00<0000co`000000O?ooo`00GOooo`03o`2Ioooooooo03coool200000ooo
o`030000<ol0000007coool005goool00ol0VOooooooo`0koooo00@0003oooooool00002oooo00<0
000co`000000O?ooo`00GOooo`03o`2Ioooooooo03goool01P000?ooooooooooo`0003?o00<0001j
oooo001Moooo00?o09Woooooool0?_ooo`060000oooooooo0000<ol00000O?ooo`00GOooo`03o`2I
oooooooo03_oool010000?ooooooo`0000;oool00`0003?o0000001loooo001Moooo00?o09Wooooo
ool0??ooo`800004oooo0P0007coool005goool00ol0VOooooooo`12oooo0P0007coool005goool0
0ol0VOooooooo`12oooo0P0007coool005goool00ol0VOooooooo`12oooo0P0007coool005goool0
0ol0VOooooooo`12oooo0`0007_oool005goool00ol0VOooooooo`12oooo0P0007coool005goool0
0ol0VOooooooo`12oooo0P0007coool005goool00ol0VOooooooo`12oooo0P0007coool005goool0
0ol0VOooooooo`12oooo0P0007coool005goool00ol0VOooooooo`12oooo0P0007coool005goool0
0ol0VOooooooo`12oooo0`0007_oool005goool00ol0VOooooooo`12oooo0P0007coool005goool0
0ol0VOooooooo`12oooo0P0007coool005goool00ol0VOooooooo`12oooo0P0007coool005goool0
0ol0VOooooooo`12oooo0P0007coool005goool00ol0VOooooooo`12oooo0P0007coool005goool0
0ol0VOooooooo`12oooo0`0007_oool005goool00ol0VOooooooo`13oooo00<0003oooooool0N_oo
o`00GOooo`03o`2Ioooooooo04?oool00`000?ooooooo`1joooo001Moooo00?o09Woooooool0@ooo
o`030000oooooooo07[oool005goool00ol0VOooooooo`13oooo00<0003oooooool0N_ooo`00GOoo
o`03o`2Ioooooooo04?oool00`000?ooooooo`1joooo001Moooo00?o09Woooooool0@oooo`80001k
oooo001Moooo00?o09Woooooool0@oooo`030000oooooooo07[oool005goool00ol0VOooooooo`13
oooo00<0003oooooool0N_ooo`00GOooo`03o`2Ioooooooo04?oool00`000?ooooooo`1joooo001M
oooo00?o09Woooooool0@oooo`030000oooooooo07[oool005goool00ol0VOooooooo`0moooo0`00
00?oool00`000?ooooooo`1joooo001Moooo00?o09Woooooool0?_ooo`030000oooooooo00;oool0
0`000?ooooooo`1joooo001Moooo00?o09Woooooool0>oooo`D00003oooo0`0007[oool009_oool0
10000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQ
oooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03_ooo`<00002oooo0P0000Coool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool400001_ooo`030000oooooooo00Koool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01?oool500002_ooo`030000
oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000Woool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000F
oooo00<0003oool000002Oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool06?ooo`800009oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30316 .12361 L
.3056 .12361 L
.30791 .12361 L
.30919 .12361 L
s
.30919 .12361 m
.30948 .61803 L
s
0 .4 1 r
.02381 .13261 m
.04262 .13619 L
.06244 .14153 L
.07286 .14518 L
.08255 .14925 L
.09388 .15499 L
.10458 .16158 L
.125 .17824 L
.14357 .19968 L
.14598 .20302 L
.14858 .20678 L
.14983 .20866 L
.15103 .21012 L
.1521 .2101 L
.15327 .21008 L
.15816 .21 L
.16355 .2099 L
.18199 .20946 L
.20166 .20882 L
.21266 .20834 L
.22263 .20782 L
.24188 .20652 L
.25272 .20556 L
.2627 .2045 L
.28152 .2019 L
.29221 .19999 L
.30219 .19785 L
.30461 .19727 L
.30719 .19662 L
.30854 .19627 L
.3093 .19607 L
.31002 .12361 L
.31128 .12361 L
.31199 .12361 L
.31264 .12361 L
.31383 .12361 L
.31494 .12361 L
.31616 .12361 L
.31746 .12361 L
.31812 .12361 L
.31883 .12361 L
.32012 .12361 L
.32138 .12361 L
.32254 .12361 L
.32361 .12361 L
.32476 .12361 L
.32584 .12361 L
.32683 .12361 L
.32799 .12361 L
.32925 .12361 L
Mistroke
.33045 .12361 L
.33155 .12361 L
.3328 .12361 L
.33398 .12361 L
.33503 .12361 L
.33617 .12361 L
.33742 .12361 L
.33874 .12361 L
.33986 .12361 L
.34109 .12361 L
.3424 .12361 L
.34361 .12361 L
.34425 .12361 L
.34494 .12361 L
.34567 .12361 L
.34635 .12361 L
.3476 .12361 L
.34875 .12361 L
.35 .12361 L
.35133 .12361 L
.35244 .12361 L
.35363 .12361 L
.35476 .12361 L
.35578 .12361 L
.35698 .12361 L
.35828 .12361 L
.35951 .12361 L
.36064 .12361 L
.36185 .12361 L
.36315 .12361 L
.36437 .12361 L
.36549 .12361 L
.3668 .12361 L
.36754 .12361 L
.36822 .12361 L
.36948 .12361 L
.37011 .12361 L
.37082 .12361 L
.37149 .12361 L
.37221 .12361 L
.37348 .12361 L
.37419 .12361 L
.37486 .12361 L
.37558 .12361 L
.37636 .12361 L
.37703 .12361 L
.37776 .12361 L
.37845 .12361 L
.37909 .12361 L
.38029 .12361 L
Mistroke
.38157 .12361 L
.38278 .12361 L
.38409 .12361 L
.38534 .12361 L
.38649 .12361 L
.38763 .12361 L
.38867 .12361 L
.38987 .12361 L
.39099 .12361 L
.39223 .12361 L
.39353 .12361 L
.39464 .12361 L
.39586 .12361 L
.39717 .12361 L
.39791 .12361 L
.39858 .12361 L
.39989 .12361 L
.40112 .12361 L
.40217 .12361 L
.40333 .12361 L
.40454 .12361 L
.40568 .12361 L
.40674 .12361 L
.40771 .12361 L
.40877 .12361 L
.40989 .12361 L
.41103 .12361 L
.41225 .12361 L
.4134 .12361 L
.41445 .12361 L
.41568 .12361 L
.41637 .12361 L
.41701 .12361 L
.41943 .12361 L
.42068 .12361 L
.42187 .12361 L
.42294 .12361 L
.42411 .12361 L
.42537 .12361 L
.42607 .12361 L
.42671 .12361 L
.42796 .12361 L
.42913 .12361 L
.43024 .12361 L
.4314 .12361 L
.4324 .12361 L
.43349 .12361 L
.43467 .12361 L
.43593 .12361 L
.43712 .12361 L
Mistroke
.4382 .12361 L
.43949 .12361 L
.44014 .12361 L
.44085 .12361 L
.44211 .12361 L
.44329 .12361 L
.444 .12361 L
.44468 .12361 L
.44595 .12361 L
.44666 .12361 L
.44732 .12361 L
.44804 .12361 L
.44882 .12361 L
.45012 .12361 L
.45085 .12361 L
.45152 .12361 L
.45277 .12361 L
.45408 .12361 L
.45525 .12361 L
.45635 .12361 L
.45756 .12361 L
.45885 .12361 L
.46007 .12361 L
.46076 .12361 L
.46141 .12361 L
.46272 .12361 L
.46345 .12361 L
.46413 .12361 L
.46527 .12361 L
.46651 .12361 L
.46781 .12361 L
.46902 .12361 L
.46971 .12361 L
.47046 .12361 L
.47117 .12361 L
.47182 .12361 L
.47305 .12361 L
.47436 .12361 L
.47504 .12361 L
.47577 .12361 L
.47709 .12361 L
.47789 .12361 L
.47865 .12361 L
.47933 .12361 L
.48008 .12361 L
.48074 .12361 L
.48145 .12361 L
.48273 .12361 L
.48398 .12361 L
.48513 .12361 L
Mistroke
.48638 .12361 L
.48709 .12361 L
.48775 .12361 L
.48845 .12361 L
.48909 .12361 L
.48982 .12361 L
.49052 .12361 L
.49169 .12361 L
.49293 .12361 L
.49399 .12361 L
.49516 .12361 L
.49641 .12361 L
.49711 .12361 L
.49776 .12361 L
.49895 .12361 L
.5002 .12361 L
.50144 .12361 L
.50213 .12361 L
.50278 .12361 L
.50396 .12361 L
.50521 .12361 L
.50633 .12361 L
.50738 .12361 L
.50853 .12361 L
.50976 .12361 L
.51107 .12361 L
.51177 .12361 L
.5125 .12361 L
.51314 .12361 L
.51385 .12361 L
.5151 .12361 L
.51631 .12361 L
.51761 .12361 L
.51884 .12361 L
.51997 .12361 L
.52104 .12361 L
.52218 .12361 L
.52326 .12361 L
.52424 .12361 L
.52539 .12361 L
.52664 .12361 L
.52783 .12361 L
.52892 .12361 L
.53004 .12361 L
.5311 .12361 L
.53225 .12361 L
.53349 .12361 L
.53835 .12361 L
.53965 .12361 L
.54088 .12361 L
Mistroke
.54157 .12361 L
.5423 .12361 L
.54359 .12361 L
.54482 .12361 L
.54612 .12361 L
.54734 .12361 L
.54845 .12361 L
.54977 .12361 L
.55049 .12361 L
.55118 .12361 L
.55239 .12361 L
.55308 .12361 L
.55371 .12361 L
.5544 .12361 L
.55504 .12361 L
.55575 .12361 L
.55651 .12361 L
.55727 .12361 L
.55806 .12361 L
.55874 .12361 L
.55949 .12361 L
.56014 .12361 L
.56084 .12361 L
.56212 .12361 L
.56337 .12361 L
.56452 .12361 L
.56576 .12361 L
.56647 .12361 L
.56713 .12361 L
.56783 .12361 L
.56846 .12361 L
.5692 .12361 L
.5699 .12361 L
.57106 .12361 L
.5723 .12361 L
.57347 .12361 L
.57453 .12361 L
.57578 .12361 L
.57644 .12361 L
.57713 .12361 L
.57841 .12361 L
.57958 .12361 L
.5808 .12361 L
.58214 .12361 L
.58455 .12361 L
.58909 .12361 L
.59926 .12361 L
.61761 .12361 L
.65845 .12361 L
.69778 .12361 L
Mistroke
.73559 .12361 L
.77585 .12361 L
.8146 .12361 L
.8558 .12361 L
.89548 .12361 L
.93365 .12361 L
.97427 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`1Vo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`09oooo00<0I_ooooooool06Ooo
o`030000oooooooo00Koool400006c?o00030000oooooooo02Goool00`000?ooooooo`0Voooo00<0
003oooooool0:Oooo`005_ooo`<0I_m6oooo00<0I_ooooooool09_ooo`@0000G<ol000<0003ooooo
ool0N_ooo`006Oooo`D0I_m1oooo00<0I_ooooooool0:_ooo`030000<ol0<ol001@co`000`000?oo
ooooo`1joooo000Noooo101Vocgoool00`1Vooooooooo`0[oooo0P0001@co`000`000?ooooooo`1j
oooo000Roooo0P1Voc_oool00`1Vooooooooo`0]oooo00<0000co`0co`004C?o00030000oooooooo
07[oool002Coool306Ko>?ooo`0306Kooooooooo02koool00`0003?o03?o000@<ol00P0007_oool0
02Ooool206Ko=_ooo`0306Kooooooooo02ooool2000043?o00030000oooooooo07[oool002Woool2
06Ko=?ooo`0306Kooooooooo037oool00`0003?o03?o000=<ol000<0003oooooool0N_ooo`00:ooo
o`0306Kooooooooo037oool00`1Vooooooooo`0aoooo00<0000co`0co`003C?o00030000oooooooo
07[oool002coool00`1Vooooooooo`0`oooo00<0I_ooooooool0<_ooo`030000<ol0<ol000`co`00
0`000?ooooooo`1joooo000]oooo0P1Voc3oool00`1Vooooooooo`0boooo00<0000co`0co`0033?o
00030000oooooooo07[oool002ooool00`1Vooooooooo`0]oooo00<0I_ooooooool0<oooo`030000
<ol0<ol000/co`020000Noooo`00<?ooo`0306Kooooooooo02coool00`1Vooooooooo`0coooo00<0
000co`0co`002c?o00030000oooooooo07[oool0037oool00`1Vooooooooo`0[oooo00<0I_oooooo
ool0=?ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo000boooo00<0I_ooooooool0:_oo
o`0306Kooooooooo03Coool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00<_ooo`0306Ko
oooooooo02[oool00`1Vooooooooo`0eoooo00<0000co`0co`002C?o00030000oooooooo07[oool0
03?oool00`1Vooooooooo`0Yoooo00<0I_ooooooool0=Oooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1joooo000doooo00<0I_ooooooool09Oooo`@0I_lhoooo00<0000co`0co`0023?o0080001k
oooo000eoooo00<0I_ooooooool07_ooo`H0I_l3oooo00?o09Woooooool0=_ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1joooo000eoooo0P1VoaGoool:06Ko2Oooo`03o`2Ioooooooo03Koool0
0`0003?o03?o0008<ol000<0003oooooool0N_ooo`00=_oooaH0I_lCoooo00?o09Woooooool0=ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1joooo001Ooooo00?o09Woooooool0=oooo`030000
<ol0<ol000Lco`000`000?ooooooo`1joooo001Ooooo00?o09Woooooool0=oooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1joooo001Ooooo00?o09Woooooool0=oooo`030000<ol0<ol000Lco`02
0000Noooo`00Goooo`03o`2Ioooooooo03Soool00`0003?o03?o0006<ol000<0003oooooool0N_oo
o`00Goooo`03o`2Ioooooooo03Soool00`0003?o03?o0006<ol000<0003oooooool0N_ooo`00Gooo
o`03o`2Ioooooooo03Soool00`0003?o03?o0006<ol000<0003oooooool0N_ooo`00Goooo`03o`2I
oooooooo03Soool00`0003?o03?o0006<ol000<0003oooooool0N_ooo`00Goooo`03o`2Ioooooooo
03Woool500000c?o00030000oooooooo07[oool005ooool00ol0VOooooooo`0ioooo00<0000co`00
00001C?o00030000oooooooo07[oool005ooool00ol0VOooooooo`0ioooo00<0000co`0000001C?o
00<0001joooo001Ooooo00?o09Woooooool0>_ooo`800005<ol000<0003oooooool0N_ooo`00Gooo
o`03o`2Ioooooooo03[oool200001C?o00030000oooooooo07[oool005ooool00ol0VOooooooo`0j
oooo0P0000Dco`000`000?ooooooo`1joooo001Ooooo00?o09Woooooool0>_ooo`030000<ol0<ol0
00@co`000`000?ooooooo`1joooo001Ooooo00?o09Woooooool0>_ooo`030000<ol0<ol000@co`00
0`000?ooooooo`1joooo001Ooooo00?o09Woooooool0>_ooo`030000<ol0<ol000@co`020000Nooo
o`00Goooo`03o`2Ioooooooo03_oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Gooo
o`03o`2Ioooooooo03_oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Goooo`03o`2I
oooooooo03_oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Goooo`03o`2Ioooooooo
03_oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Goooo`03o`2Ioooooooo03_oool0
0`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Goooo`03o`2Ioooooooo03_oool00`0003?o
03?o0003<ol00P0007_oool005ooool00ol0VOooooooo`0koooo00<0000co`0co`000c?o00030000
oooooooo07[oool005ooool00ol0VOooooooo`0koooo00<0000co`0co`000c?o00030000oooooooo
07[oool005ooool00ol0VOooooooo`0loooo00<0000co`0co`000S?o00030000oooooooo07[oool0
05ooool00ol0VOooooooo`0loooo00<0000co`0co`000S?o00030000oooooooo07[oool005ooool0
0ol0VOooooooo`0loooo00<0000co`0co`000S?o00030000oooooooo07[oool005ooool00ol0VOoo
ooooo`0loooo00<0000co`0co`000S?o00030000oooooooo07[oool005ooool00ol0VOooooooo`0l
oooo00<0000co`0co`000S?o0080001koooo001Ooooo00?o09Woooooool0??ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo001Ooooo00?o09Woooooool0??ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001Ooooo00?o09Woooooool0??ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo001Ooooo00?o09Woooooool0??ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001Ooooo00?o09Woooooool0??ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001O
oooo00?o09Woooooool0??ooo`030000<ol0<ol0008co`020000Noooo`00Goooo`03o`2Ioooooooo
03goool01@0003?o03?o03?o0000001loooo001Ooooo00?o09Woooooool0?Oooo`050000<ol0<ol0
<ol0000007coool005ooool00ol0VOooooooo`0moooo00D0000co`0co`0co`000000O?ooo`00Gooo
o`03o`2Ioooooooo03Woool500000c?o00030000oooooooo07[oool005ooool00ol0VOooooooo`0i
oooo00D0003oooooooooool000000c?o00030000oooooooo07[oool005ooool00ol0VOooooooo`0j
oooo00@0003oooooool00003<ol00`0007[oool005ooool00ol0VOooooooo`0koooo00<0003oool0
00000c?o00030000oooooooo07[oool005ooool00ol0VOooooooo`0ioooo00<0003oooooool00P00
00<co`000`000?ooooooo`1joooo001Ooooo00?o09Woooooool0>_ooo`8000000oooo`0003?o0002
<ol000<0003oooooool0N_ooo`00Goooo`03o`2Ioooooooo03goool01@0003?o03?o03?o0000001l
oooo001Ooooo00?o09Woooooool0?_ooo`040000<ol0<ol00000O?ooo`00Goooo`03o`2Ioooooooo
03koool00`0003?o03?o00020000Noooo`00Goooo`03o`2Ioooooooo03koool0100003?o03?o0000
07coool005ooool00ol0VOooooooo`0noooo00@0000co`0co`00001loooo001Ooooo00?o09Wooooo
ool0?_ooo`040000<ol0<ol00000O?ooo`00Goooo`03o`2Ioooooooo03koool0100003?o03?o0000
07coool005ooool00ol0VOooooooo`0noooo00@0000co`0co`00001loooo001Ooooo00?o09Wooooo
ool0?_ooo`040000<ol0<ol00000O?ooo`00Goooo`03o`2Ioooooooo03ooool0100003?o00000000
07_oool005ooool00ol0VOooooooo`0ooooo00<0000co`000000O?ooo`00Goooo`03o`2Ioooooooo
03ooool00`0003?o0000001loooo001Ooooo00?o09Woooooool0?oooo`030000<ol0000007coool0
05ooool00ol0VOooooooo`0ooooo00<0000co`000000O?ooo`00Goooo`03o`2Ioooooooo03ooool0
0`0003?o0000001loooo001Ooooo00?o09Woooooool0?oooo`040000<ol000000000Noooo`00Gooo
o`03o`2Ioooooooo03ooool00`0003?o0000001loooo001Ooooo00?o09Woooooool0?oooo`030000
<ol0000007coool005ooool00ol0VOooooooo`0ooooo00<0000co`000000O?ooo`00Goooo`03o`2I
oooooooo03ooool00`0003?o0000001loooo001Ooooo00?o09Woooooool0?oooo`030000<ol00000
07coool005ooool00ol0VOooooooo`0ooooo00@0000co`000000001koooo001Ooooo00?o09Wooooo
ool0?oooo`030000<ol0000007coool005ooool00ol0VOooooooo`0ooooo00<0000co`000000O?oo
o`00Goooo`03o`2Ioooooooo03ooool00`0003?o0000001loooo001Ooooo00?o09Woooooool0>_oo
o`800003oooo00<0000co`000000O?ooo`00Goooo`03o`2Ioooooooo03Woool010000?ooooooo`00
00;oool00`0003?o0000001loooo001Ooooo00?o09Woooooool0>oooo`060000oooooooooooo0000
<ol00`0007[oool005ooool00ol0VOooooooo`0loooo00H0003oooooool0000co`00001loooo001O
oooo00?o09Woooooool0>Oooo`040000oooooooo00000_ooo`030000<ol0000007coool005ooool0
0ol0VOooooooo`0joooo0P0000Coool20000O?ooo`00Goooo`03o`2Ioooooooo043oool20000O?oo
o`00Goooo`03o`2Ioooooooo043oool20000O?ooo`00Goooo`03o`2Ioooooooo043oool20000O?oo
o`00Goooo`03o`2Ioooooooo043oool30000Noooo`00Goooo`03o`2Ioooooooo043oool20000O?oo
o`00Goooo`03o`2Ioooooooo043oool20000O?ooo`00Goooo`03o`2Ioooooooo043oool20000O?oo
o`00Goooo`03o`2Ioooooooo043oool20000O?ooo`00Goooo`03o`2Ioooooooo043oool20000O?oo
o`00Goooo`03o`2Ioooooooo043oool30000Noooo`00Goooo`03o`2Ioooooooo043oool20000O?oo
o`00Goooo`03o`2Ioooooooo043oool20000O?ooo`00Goooo`03o`2Ioooooooo043oool20000O?oo
o`00Goooo`03o`2Ioooooooo043oool20000O?ooo`00Goooo`03o`2Ioooooooo043oool20000O?oo
o`00Goooo`03o`2Ioooooooo043oool30000Noooo`00Goooo`03o`2Ioooooooo047oool00`000?oo
ooooo`1joooo001Ooooo00?o09Woooooool0@Oooo`030000oooooooo07[oool005ooool00ol0VOoo
ooooo`11oooo00<0003oooooool0N_ooo`00Goooo`03o`2Ioooooooo047oool00`000?ooooooo`1j
oooo001Ooooo00?o09Woooooool0@Oooo`030000oooooooo07[oool005ooool00ol0VOooooooo`11
oooo0P0007_oool005ooool00ol0VOooooooo`11oooo00<0003oooooool0N_ooo`00Goooo`03o`2I
oooooooo047oool00`000?ooooooo`1joooo001Ooooo00?o09Woooooool0@Oooo`030000oooooooo
07[oool005ooool00ol0VOooooooo`11oooo00<0003oooooool0N_ooo`00Goooo`03o`2Ioooooooo
03_oool300000oooo`030000oooooooo07[oool005ooool00ol0VOooooooo`0loooo00<0003ooooo
ool00_ooo`030000oooooooo07[oool005ooool00ol0VOooooooo`0ioooo1@0000?oool30000N_oo
o`00Voooo`040000oooooooo0000POooo`00W?ooo`030000oooo0000087oool009goool20000POoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0>oooo0`0000;oool200001Oooo`<00002
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00006oooo00<0003oooooool02Oooo`050000oooooooooooo0000
07[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`D00007oooo1@0000?oool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005_oo
o`030000oooo000000Woool00`000?ooo`000003oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo01Soool200002_ooo`800002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.30791 .12361 L
.31304 .12361 L
.31454 .12361 L
.31597 .12361 L
.31725 .12361 L
s
.31725 .12361 m
.31754 .61803 L
s
0 .4 1 r
.02381 .13142 m
.04262 .13453 L
.06244 .13917 L
.07286 .14234 L
.08255 .14587 L
.09388 .15085 L
.10458 .15657 L
.125 .17104 L
.14357 .18965 L
.15327 .2021 L
.15562 .20547 L
.15692 .20738 L
.15816 .20925 L
.15885 .21012 L
.15961 .21011 L
.16094 .21009 L
.16355 .21004 L
.18199 .20967 L
.20166 .2091 L
.21266 .20869 L
.22263 .20824 L
.24188 .20711 L
.25272 .20628 L
.2627 .20536 L
.28152 .2031 L
.29221 .20144 L
.30219 .19958 L
.30719 .19852 L
.30983 .19791 L
.31264 .19724 L
.31508 .19663 L
.31575 .19646 L
.31647 .19627 L
.31778 .12361 L
.31899 .12361 L
.32026 .12361 L
.32135 .12361 L
.32254 .12361 L
.32379 .12361 L
.32497 .12361 L
.32604 .12361 L
.32719 .12361 L
.32844 .12361 L
.32907 .12361 L
.32977 .12361 L
.331 .12361 L
.33215 .12361 L
.33331 .12361 L
.3344 .12361 L
.33539 .12361 L
Mistroke
.33646 .12361 L
.33763 .12361 L
.33887 .12361 L
.34004 .12361 L
.34109 .12361 L
.3423 .12361 L
.34343 .12361 L
.34466 .12361 L
.34599 .12361 L
.34665 .12361 L
.34737 .12361 L
.34869 .12361 L
.34996 .12361 L
.35115 .12361 L
.35225 .12361 L
.35328 .12361 L
.35441 .12361 L
.35563 .12361 L
.35684 .12361 L
.35811 .12361 L
.35919 .12361 L
.36038 .12361 L
.36106 .12361 L
.36179 .12361 L
.36248 .12361 L
.36312 .12361 L
.36433 .12361 L
.3656 .12361 L
.36627 .12361 L
.36698 .12361 L
.36826 .12361 L
.36904 .12361 L
.36979 .12361 L
.37045 .12361 L
.37118 .12361 L
.37238 .12361 L
.37306 .12361 L
.3737 .12361 L
.375 .12361 L
.37572 .12361 L
.37639 .12361 L
.37761 .12361 L
.37874 .12361 L
.37992 .12361 L
.38121 .12361 L
.38249 .12361 L
.38313 .12361 L
.38383 .12361 L
.38508 .12361 L
.38625 .12361 L
Mistroke
.38696 .12361 L
.38763 .12361 L
.38889 .12361 L
.38959 .12361 L
.39026 .12361 L
.39102 .12361 L
.39172 .12361 L
.3929 .12361 L
.39418 .12361 L
.39537 .12361 L
.39647 .12361 L
.39767 .12361 L
.39899 .12361 L
.39965 .12361 L
.40036 .12361 L
.40165 .12361 L
.40289 .12361 L
.40404 .12361 L
.4053 .12361 L
.40594 .12361 L
.40664 .12361 L
.40781 .12361 L
.40908 .12361 L
.41027 .12361 L
.41137 .12361 L
.41244 .12361 L
.41343 .12361 L
.41452 .12361 L
.41568 .12361 L
.41691 .12361 L
.41806 .12361 L
.4191 .12361 L
.42023 .12361 L
.42146 .12361 L
.42259 .12361 L
.42389 .12361 L
.42512 .12361 L
.42626 .12361 L
.42731 .12361 L
.42847 .12361 L
.4297 .12361 L
.43041 .12361 L
.43106 .12361 L
.43177 .12361 L
.43252 .12361 L
.43378 .12361 L
.4345 .12361 L
.43517 .12361 L
.43642 .12361 L
.43756 .12361 L
Mistroke
.43887 .12361 L
.44012 .12361 L
.44133 .12361 L
.44202 .12361 L
.44266 .12361 L
.44396 .12361 L
.44463 .12361 L
.44536 .12361 L
.44666 .12361 L
.44789 .12361 L
.44909 .12361 L
.45021 .12361 L
.4509 .12361 L
.45164 .12361 L
.4523 .12361 L
.45299 .12361 L
.4543 .12361 L
.45551 .12361 L
.45618 .12361 L
.4569 .12361 L
.45821 .12361 L
.459 .12361 L
.45975 .12361 L
.46043 .12361 L
.46117 .12361 L
.46238 .12361 L
.4635 .12361 L
.46472 .12361 L
.46601 .12361 L
.46713 .12361 L
.46818 .12361 L
.46933 .12361 L
.47056 .12361 L
.47126 .12361 L
.4719 .12361 L
.47261 .12361 L
.47335 .12361 L
.47461 .12361 L
.47532 .12361 L
.47599 .12361 L
.47724 .12361 L
.47837 .12361 L
.47968 .12361 L
.48093 .12361 L
.48161 .12361 L
.48225 .12361 L
.48345 .12361 L
.48475 .12361 L
.48547 .12361 L
.48614 .12361 L
Mistroke
.48727 .12361 L
.4885 .12361 L
.48978 .12361 L
.49098 .12361 L
.49166 .12361 L
.4924 .12361 L
.4931 .12361 L
.49375 .12361 L
.49497 .12361 L
.49627 .12361 L
.49694 .12361 L
.49766 .12361 L
.49896 .12361 L
.49972 .12361 L
.50051 .12361 L
.50119 .12361 L
.50193 .12361 L
.50317 .12361 L
.50448 .12361 L
.50516 .12361 L
.50591 .12361 L
.50723 .12361 L
.50848 .12361 L
.50918 .12361 L
.50982 .12361 L
.51105 .12361 L
.51223 .12361 L
.51336 .12361 L
.51455 .12361 L
.51557 .12361 L
.5167 .12361 L
.51791 .12361 L
.51921 .12361 L
.52045 .12361 L
.52157 .12361 L
.52278 .12361 L
.52393 .12361 L
.52525 .12361 L
.52645 .12361 L
.52713 .12361 L
.52777 .12361 L
.52847 .12361 L
.52921 .12361 L
.53043 .12361 L
.53113 .12361 L
.53178 .12361 L
.53244 .12361 L
.53317 .12361 L
.53449 .12361 L
.53577 .12361 L
Mistroke
.53696 .12361 L
.53769 .12361 L
.53838 .12361 L
.53966 .12361 L
.54038 .12361 L
.54104 .12361 L
.54177 .12361 L
.54254 .12361 L
.54376 .12361 L
.54445 .12361 L
.54508 .12361 L
.54625 .12361 L
.5475 .12361 L
.5486 .12361 L
.54965 .12361 L
.55078 .12361 L
.55202 .12361 L
.55326 .12361 L
.55457 .12361 L
.55578 .12361 L
.55691 .12361 L
.5576 .12361 L
.55824 .12361 L
.55946 .12361 L
.56076 .12361 L
.5615 .12361 L
.56218 .12361 L
.56324 .12361 L
.56437 .12361 L
.56544 .12361 L
.56642 .12361 L
.56757 .12361 L
.56881 .12361 L
.56999 .12361 L
.57109 .12361 L
.57232 .12361 L
.57348 .12361 L
.57453 .12361 L
.57565 .12361 L
.57689 .12361 L
.57819 .12361 L
.5793 .12361 L
.58052 .12361 L
.58183 .12361 L
.58304 .12361 L
.58578 .12361 L
.59075 .12361 L
.60007 .12361 L
.621 .12361 L
.66033 .12361 L
Mistroke
.69814 .12361 L
.7384 .12361 L
.77715 .12361 L
.81835 .12361 L
.85803 .12361 L
.8962 .12361 L
.93682 .12361 L
.97592 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool01@000?ooooooooooo`1Vo`05oooo00<0
003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`005_ooo`<0I_lAoooo00<0003oooooool09_ooo`030000oooooooo00_oool0
0`1Vooooooooo`0Goooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000
oooooooo02Koool00`000?ooooooo`0Yoooo000Ioooo1@1Vod?oool00`1Vooooooooo`0Toooo1000
01Lco`000`000?ooooooo`1joooo000Noooo101Vocooool00`1Vooooooooo`0Xoooo00<0000co`0c
o`0053?o00030000oooooooo07[oool002;oool206Ko?Oooo`0306Kooooooooo02Woool2000053?o
00030000oooooooo07[oool002Coool306Ko>_ooo`0306Kooooooooo02_oool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`009oooo`80I_lhoooo00<0I_ooooooool0;?ooo`030000<ol0<ol0
010co`020000Noooo`00:Oooo`80I_lfoooo00<0I_ooooooool0;Oooo`80000@<ol000<0003ooooo
ool0N_ooo`00:oooo`0306Kooooooooo03?oool00`1Vooooooooo`0_oooo00<0000co`0co`003C?o
00030000oooooooo07[oool002coool206Ko<_ooo`0306Koo`2Ioooo033oool00`0003?o03?o000=
<ol000<0003oooooool0N_ooo`00;_ooo`80I_l`oooo00<0I_oo09Woool0<Oooo`030000<ol0<ol0
00`co`000`000?ooooooo`1joooo000`oooo00<0I_ooooooool0;Oooo`0306Koo`2Ioooo037oool0
0`0003?o03?o000<<ol000<0003oooooool0N_ooo`00<Oooo`0306Kooooooooo02coool00`1Vool0
VOooo`0boooo00<0000co`0co`002c?o0080001koooo000boooo00<0I_ooooooool0:oooo`0306Ko
o`2Ioooo03;oool00`0003?o03?o000;<ol000<0003oooooool0N_ooo`00<oooo`0306Kooooooooo
02[oool00`1Vool0VOooo`0coooo00<0000co`0co`002S?o00030000oooooooo07[oool003Coool0
0`1Vooooooooo`0Yoooo00<0I_oo09Woool0<oooo`030000<ol0<ol000Xco`000`000?ooooooo`1j
oooo000eoooo00<0I_ooooooool0:?ooo`0306Koo`2Ioooo03Coool00`0003?o03?o0009<ol000<0
003oooooool0N_ooo`00=_ooo`0306Kooooooooo02Ooool00`1Vool0VOooo`0doooo00<0000co`0c
o`002C?o00030000oooooooo07[oool003Koool00`1Vooooooooo`0Uoooo0`1Vo`03o`2Ioooooooo
03Coool00`0003?o03?o0008<ol00P0007_oool003Ooool00`1Vooooooooo`0Poooo101Vo`?oool0
0ol0VOooooooo`0doooo00<0000co`0co`0023?o00030000oooooooo07[oool003Soool00`1Voooo
ooooo`0Eoooo2P1Vo`Ooool00ol0VOooooooo`0doooo00<0000co`0co`0023?o00030000oooooooo
07[oool003SooolH06Ko4Oooo`03o`2Ioooooooo03Goool00`0003?o03?o0007<ol000<0003ooooo
ool0N_ooo`00HOooo`03o`2Ioooooooo03Goool00`0003?o03?o0007<ol000<0003oooooool0N_oo
o`00HOooo`03o`2Ioooooooo03Goool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00HOoo
o`03o`2Ioooooooo03Goool00`0003?o03?o0007<ol00P0007_oool0067oool00ol0VOooooooo`0f
oooo00<0000co`0co`001S?o00030000oooooooo07[oool0067oool00ol0VOooooooo`0foooo00<0
000co`0co`001S?o00030000oooooooo07[oool0067oool00ol0VOooooooo`0foooo00<0000co`0c
o`001S?o00030000oooooooo07[oool0067oool00ol0VOooooooo`0foooo00<0000co`0co`001S?o
00030000oooooooo07[oool0067oool00ol0VOooooooo`0goooo1@0000<co`000`000?ooooooo`1j
oooo001Qoooo00?o09Woooooool0=oooo`030000<ol0000000Dco`000`000?ooooooo`1joooo001Q
oooo00?o09Woooooool0=oooo`030000<ol0000000Dco`030000N_ooo`00HOooo`03o`2Ioooooooo
03Soool200001C?o00030000oooooooo07[oool0067oool00ol0VOooooooo`0hoooo0P0000Dco`00
0`000?ooooooo`1joooo001Qoooo00?o09Woooooool0>?ooo`800005<ol000<0003oooooool0N_oo
o`00HOooo`03o`2Ioooooooo03Soool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00HOoo
o`03o`2Ioooooooo03Soool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00HOooo`03o`2I
oooooooo03Soool00`0003?o03?o0004<ol00P0007_oool0067oool00ol0VOooooooo`0ioooo00<0
000co`0co`000c?o00030000oooooooo07[oool0067oool00ol0VOooooooo`0ioooo00<0000co`0c
o`000c?o00030000oooooooo07[oool0067oool00ol0VOooooooo`0ioooo00<0000co`0co`000c?o
00030000oooooooo07[oool0067oool00ol0VOooooooo`0ioooo00<0000co`0co`000c?o00030000
oooooooo07[oool0067oool00ol0VOooooooo`0ioooo00<0000co`0co`000c?o00030000oooooooo
07[oool0067oool00ol0VOooooooo`0ioooo00<0000co`0co`000c?o0080001koooo001Qoooo00?o
09Woooooool0>Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001Qoooo00?o09Wooooo
ool0>Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001Qoooo00?o09Woooooool0>_oo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Qoooo00?o09Woooooool0>_ooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo001Qoooo00?o09Woooooool0>_ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo001Qoooo00?o09Woooooool0>_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001Qoooo00?o09Woooooool0>_ooo`030000<ol0<ol0008co`020000Nooo
o`00HOooo`03o`2Ioooooooo03[oool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00HOoo
o`03o`2Ioooooooo03[oool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00HOooo`03o`2I
oooooooo03[oool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00HOooo`03o`2Ioooooooo
03[oool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00HOooo`03o`2Ioooooooo03[oool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00HOooo`03o`2Ioooooooo03[oool00`0003?o
03?o0002<ol00P0007_oool0067oool00ol0VOooooooo`0koooo00D0000co`0co`0co`000000O?oo
o`00HOooo`03o`2Ioooooooo03_oool01@0003?o03?o03?o0000001loooo001Qoooo00?o09Wooooo
ool0>oooo`050000<ol0<ol0<ol0000007coool0067oool00ol0VOooooooo`0goooo1@0000<co`00
0`000?ooooooo`1joooo001Qoooo00?o09Woooooool0=oooo`050000oooooooooooo000000<co`00
0`000?ooooooo`1joooo001Qoooo00?o09Woooooool0>?ooo`040000oooooooo00000c?o00<0001j
oooo001Qoooo00?o09Woooooool0>Oooo`030000oooo000000<co`000`000?ooooooo`1joooo001Q
oooo00?o09Woooooool0=oooo`030000oooooooo00800003<ol000<0003oooooool0N_ooo`00HOoo
o`03o`2Ioooooooo03Soool2000000?oool0000co`000S?o00030000oooooooo07[oool0067oool0
0ol0VOooooooo`0koooo00D0000co`0co`0co`000000O?ooo`00HOooo`03o`2Ioooooooo03coool0
100003?o03?o000007coool0067oool00ol0VOooooooo`0loooo00<0000co`0co`000P0007_oool0
067oool00ol0VOooooooo`0loooo00@0000co`0co`00001loooo001Qoooo00?o09Woooooool0??oo
o`040000<ol0<ol00000O?ooo`00HOooo`03o`2Ioooooooo03coool0100003?o03?o000007coool0
067oool00ol0VOooooooo`0loooo00@0000co`0co`00001loooo001Qoooo00?o09Woooooool0??oo
o`040000<ol0<ol00000O?ooo`00HOooo`03o`2Ioooooooo03coool0100003?o03?o000007coool0
067oool00ol0VOooooooo`0moooo00@0000co`000000001koooo001Qoooo00?o09Woooooool0?Ooo
o`030000<ol0000007coool0067oool00ol0VOooooooo`0moooo00<0000co`000000O?ooo`00HOoo
o`03o`2Ioooooooo03goool00`0003?o0000001loooo001Qoooo00?o09Woooooool0?Oooo`030000
<ol0000007coool0067oool00ol0VOooooooo`0moooo00<0000co`000000O?ooo`00HOooo`03o`2I
oooooooo03goool0100003?o0000000007_oool0067oool00ol0VOooooooo`0moooo00<0000co`00
0000O?ooo`00HOooo`03o`2Ioooooooo03goool00`0003?o0000001loooo001Qoooo00?o09Wooooo
ool0?Oooo`030000<ol0000007coool0067oool00ol0VOooooooo`0moooo00<0000co`000000O?oo
o`00HOooo`03o`2Ioooooooo03goool00`0003?o0000001loooo001Qoooo00?o09Woooooool0?Ooo
o`040000<ol000000000Noooo`00HOooo`03o`2Ioooooooo03goool00`0003?o0000001loooo001Q
oooo00?o09Woooooool0?Oooo`030000<ol0000007coool0067oool00ol0VOooooooo`0moooo00<0
000co`000000O?ooo`00HOooo`03o`2Ioooooooo03Soool200000oooo`030000<ol0000007coool0
067oool00ol0VOooooooo`0goooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00HOoo
o`03o`2Ioooooooo03Woool01P000?ooooooooooo`0003?o00<0001joooo001Qoooo00?o09Wooooo
ool0>_ooo`060000oooooooo0000<ol00000O?ooo`00HOooo`03o`2Ioooooooo03Ooool010000?oo
ooooo`0000;oool00`0003?o0000001loooo001Qoooo00?o09Woooooool0>?ooo`800004oooo0P00
07coool0067oool00ol0VOooooooo`0noooo0P0007coool0067oool00ol0VOooooooo`0noooo0P00
07coool0067oool00ol0VOooooooo`0noooo0P0007coool0067oool00ol0VOooooooo`0noooo0`00
07_oool0067oool00ol0VOooooooo`0noooo0P0007coool0067oool00ol0VOooooooo`0noooo0P00
07coool0067oool00ol0VOooooooo`0noooo0P0007coool0067oool00ol0VOooooooo`0noooo0P00
07coool0067oool00ol0VOooooooo`0noooo0P0007coool0067oool00ol0VOooooooo`0noooo0`00
07_oool0067oool00ol0VOooooooo`0noooo0P0007coool0067oool00ol0VOooooooo`0noooo0P00
07coool0067oool00ol0VOooooooo`0noooo0P0007coool0067oool00ol0VOooooooo`0noooo0P00
07coool0067oool00ol0VOooooooo`0noooo0P0007coool0067oool00ol0VOooooooo`0noooo0`00
07_oool0067oool00ol0VOooooooo`0ooooo00<0003oooooool0N_ooo`00HOooo`03o`2Ioooooooo
03ooool00`000?ooooooo`1joooo001Qoooo00?o09Woooooool0?oooo`030000oooooooo07[oool0
067oool00ol0VOooooooo`0ooooo00<0003oooooool0N_ooo`00HOooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`1joooo001Qoooo00?o09Woooooool0?oooo`80001koooo001Qoooo00?o09Wooooo
ool0?oooo`030000oooooooo07[oool0067oool00ol0VOooooooo`0ooooo00<0003oooooool0N_oo
o`00HOooo`03o`2Ioooooooo03ooool00`000?ooooooo`1joooo001Qoooo00?o09Woooooool0?ooo
o`030000oooooooo07[oool0067oool00ol0VOooooooo`0ioooo0`0000?oool00`000?ooooooo`1j
oooo001Qoooo00?o09Woooooool0>_ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001Q
oooo00?o09Woooooool0=oooo`D00003oooo0`0007[oool009_oool010000?ooooooo`00087oool0
09coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03_ooo`<00002oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001_oo
o`030000oooooooo00Koool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0
003oooooool00_ooo`030000oooooooo01?oool500002Oooo`030000oooooooo00?oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?ooooooo`0000_oool01@000?oo
ooooooooo`00001joooo001hoooo00D0003oooooooooool000005_ooo`030000oooo000000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool06?ooo`800009
oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.31875 .12361 L
.32145 .12361 L
.32263 .12361 L
.32392 .12361 L
.32509 .12361 L
s
.32509 .12361 m
.32552 .61803 L
s
0 .4 1 r
.02381 .13039 m
.04262 .13309 L
.06244 .13711 L
.07286 .13987 L
.08255 .14293 L
.09388 .14725 L
.10458 .15222 L
.125 .16478 L
.14357 .18094 L
.15238 .19068 L
.16185 .20301 L
.16464 .20705 L
.1653 .20804 L
.16601 .20911 L
.16728 .21011 L
.16853 .21009 L
.16966 .21007 L
.17225 .21003 L
.18199 .20984 L
.20182 .20935 L
.21265 .209 L
.22285 .2086 L
.24293 .20756 L
.2614 .20621 L
.28023 .2043 L
.29092 .20289 L
.30089 .20131 L
.31134 .19933 L
.31649 .19821 L
.31875 .19768 L
.32124 .19708 L
.32231 .19681 L
.32347 .19651 L
.32456 .19623 L
.32555 .12361 L
.32662 .12361 L
.32778 .12361 L
.329 .12361 L
.33013 .12361 L
.33139 .12361 L
.33258 .12361 L
.33365 .12361 L
.33481 .12361 L
.33607 .12361 L
.3367 .12361 L
.3374 .12361 L
.33864 .12361 L
.3398 .12361 L
.34105 .12361 L
.34175 .12361 L
Mistroke
.34238 .12361 L
.34362 .12361 L
.34478 .12361 L
.34544 .12361 L
.34614 .12361 L
.34739 .12361 L
.34804 .12361 L
.34873 .12361 L
.3495 .12361 L
.35021 .12361 L
.35148 .12361 L
.3522 .12361 L
.35286 .12361 L
.35408 .12361 L
.35538 .12361 L
.35653 .12361 L
.35762 .12361 L
.35881 .12361 L
.36009 .12361 L
.36126 .12361 L
.36234 .12361 L
.36353 .12361 L
.3648 .12361 L
.36603 .12361 L
.36672 .12361 L
.36736 .12361 L
.36853 .12361 L
.36976 .12361 L
.37091 .12361 L
.37198 .12361 L
.37315 .12361 L
.37441 .12361 L
.37554 .12361 L
.37661 .12361 L
.37766 .12361 L
.37862 .12361 L
.37976 .12361 L
.38099 .12361 L
.38207 .12361 L
.3832 .12361 L
.38445 .12361 L
.38562 .12361 L
.3869 .12361 L
.38761 .12361 L
.38826 .12361 L
.38958 .12361 L
.39079 .12361 L
.39209 .12361 L
.39284 .12361 L
.39353 .12361 L
Mistroke
.3947 .12361 L
.39595 .12361 L
.39663 .12361 L
.39729 .12361 L
.39851 .12361 L
.39967 .12361 L
.40072 .12361 L
.40193 .12361 L
.40308 .12361 L
.40414 .12361 L
.40511 .12361 L
.40618 .12361 L
.40731 .12361 L
.40846 .12361 L
.40968 .12361 L
.41084 .12361 L
.4119 .12361 L
.41313 .12361 L
.41383 .12361 L
.41448 .12361 L
.41566 .12361 L
.41692 .12361 L
.41806 .12361 L
.41931 .12361 L
.42061 .12361 L
.42182 .12361 L
.42295 .12361 L
.42399 .12361 L
.42518 .12361 L
.4263 .12361 L
.42753 .12361 L
.42883 .12361 L
.42993 .12361 L
.43115 .12361 L
.43246 .12361 L
.4332 .12361 L
.43387 .12361 L
.43517 .12361 L
.43641 .12361 L
.43756 .12361 L
.43861 .12361 L
.43981 .12361 L
.44095 .12361 L
.442 .12361 L
.44297 .12361 L
.44403 .12361 L
.44516 .12361 L
.4463 .12361 L
.44737 .12361 L
.44864 .12361 L
Mistroke
.4498 .12361 L
.451 .12361 L
.45231 .12361 L
.45355 .12361 L
.45469 .12361 L
.45594 .12361 L
.45712 .12361 L
.45819 .12361 L
.45935 .12361 L
.4606 .12361 L
.46131 .12361 L
.46194 .12361 L
.46318 .12361 L
.46435 .12361 L
.46546 .12361 L
.46662 .12361 L
.46762 .12361 L
.4687 .12361 L
.46986 .12361 L
.47095 .12361 L
.47223 .12361 L
.47341 .12361 L
.47469 .12361 L
.47533 .12361 L
.47604 .12361 L
.4773 .12361 L
.47848 .12361 L
.47915 .12361 L
.47986 .12361 L
.48113 .12361 L
.48184 .12361 L
.4825 .12361 L
.48322 .12361 L
.484 .12361 L
.48529 .12361 L
.48603 .12361 L
.4867 .12361 L
.48794 .12361 L
.48925 .12361 L
.49036 .12361 L
.49154 .12361 L
.49283 .12361 L
.49403 .12361 L
.49471 .12361 L
.49536 .12361 L
.49656 .12361 L
.49771 .12361 L
.49896 .12361 L
.5001 .12361 L
.5013 .12361 L
Mistroke
.50233 .12361 L
.50346 .12361 L
.50414 .12361 L
.50479 .12361 L
.50599 .12361 L
.50729 .12361 L
.50803 .12361 L
.5087 .12361 L
.50983 .12361 L
.51108 .12361 L
.51238 .12361 L
.5136 .12361 L
.51467 .12361 L
.51584 .12361 L
.51706 .12361 L
.5182 .12361 L
.51927 .12361 L
.52024 .12361 L
.52136 .12361 L
.52241 .12361 L
.52356 .12361 L
.52478 .12361 L
.52583 .12361 L
.52697 .12361 L
.5282 .12361 L
.52952 .12361 L
.53077 .12361 L
.53191 .12361 L
.53308 .12361 L
.53418 .12361 L
.53539 .12361 L
.5367 .12361 L
.53799 .12361 L
.53864 .12361 L
.53936 .12361 L
.54062 .12361 L
.5418 .12361 L
.54299 .12361 L
.54411 .12361 L
.54513 .12361 L
.54622 .12361 L
.54742 .12361 L
.54869 .12361 L
.54977 .12361 L
.55096 .12361 L
.55162 .12361 L
.55234 .12361 L
.55365 .12361 L
.55493 .12361 L
.55612 .12361 L
Mistroke
.55685 .12361 L
.55753 .12361 L
.55881 .12361 L
.55952 .12361 L
.56018 .12361 L
.56091 .12361 L
.56167 .12361 L
.56287 .12361 L
.56415 .12361 L
.56535 .12361 L
.56646 .12361 L
.56775 .12361 L
.56848 .12361 L
.56915 .12361 L
.57039 .12361 L
.57171 .12361 L
.57284 .12361 L
.57409 .12361 L
.57539 .12361 L
.5766 .12361 L
.57773 .12361 L
.57876 .12361 L
.57996 .12361 L
.58108 .12361 L
.59118 .12361 L
.60946 .12361 L
.64794 .12361 L
.68886 .12361 L
.72828 .12361 L
.76617 .12361 L
.80652 .12361 L
.84535 .12361 L
.88663 .12361 L
.9264 .12361 L
.96465 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`03oooo00D0I_oooooo
ooooool000002Oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`005_ooo`<0I_lAoooo00<0003oooooool09_ooo`030000oooooooo00goool0
0`1Vooooooooo`0Eoooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000
oooooooo02Koool00`000?ooooooo`0Yoooo000Ioooo1@1VodGoool00`1Vooooooooo`0Roooo1000
01Lco`000`000?ooooooo`1joooo000Noooo101Vod7oool00`1Vooooooooo`0Voooo00<0000co`0c
o`0053?o00030000oooooooo07[oool002;oool506Ko??ooo`0306Kooooooooo02Ooool2000053?o
00030000oooooooo07[oool002Ooool206Ko>_ooo`0306Kooooooooo02Woool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00:Oooo`80I_lhoooo00<0I_ooooooool0:_ooo`030000<ol0<ol0
010co`020000Noooo`00:oooo`0306Kooooooooo03Goool00`1Vooooooooo`0[oooo0P00010co`00
0`000?ooooooo`1joooo000/oooo0P1VocGoool00`1Vooooooooo`0]oooo00<0000co`0co`003C?o
00030000oooooooo07[oool002koool206Ko<_ooo`0306Koo`2Ioooo02koool00`0003?o03?o000=
<ol000<0003oooooool0N_ooo`00<?ooo`0306Kooooooooo02ooool00`1Vool0VOooo`0_oooo00<0
000co`0co`0033?o00030000oooooooo07[oool0037oool00`1Vooooooooo`0^oooo00<0I_oo09Wo
ool0;oooo`030000<ol0<ol000`co`000`000?ooooooo`1joooo000boooo0P1Vobkoool00`1Vool0
VOooo`0`oooo00<0000co`0co`002c?o0080001koooo000doooo00<0I_ooooooool0:oooo`0306Ko
o`2Ioooo033oool00`0003?o03?o000;<ol000<0003oooooool0N_ooo`00=Oooo`0306Kooooooooo
02[oool00`1Vool0VOooo`0aoooo00<0000co`0co`002S?o00030000oooooooo07[oool003Koool0
0`1Vooooooooo`0Yoooo00<0I_oo09Woool0<Oooo`030000<ol0<ol000Xco`000`000?ooooooo`1j
oooo000goooo00<0I_ooooooool0:?ooo`0306Koo`2Ioooo03;oool00`0003?o03?o0009<ol000<0
003oooooool0N_ooo`00=oooo`0306Kooooooooo02Soool00`1Vool0VOooo`0boooo00<0000co`0c
o`002C?o00030000oooooooo07[oool003Soool00`1Vooooooooo`0Uoooo0`1Vo`03o`2Ioooooooo
03;oool00`0003?o03?o0008<ol00P0007_oool003Soool00`1Vooooooooo`0Qoooo101Vo`?oool0
0ol0VOooooooo`0boooo00<0000co`0co`0023?o00030000oooooooo07[oool003Woool00`1Voooo
ooooo`0Eoooo2`1Vo`Ooool00ol0VOooooooo`0boooo00<0000co`0co`0023?o00030000oooooooo
07[oool003[ooolG06Ko4_ooo`03o`2Ioooooooo03?oool00`0003?o03?o0007<ol000<0003ooooo
ool0N_ooo`00Hoooo`03o`2Ioooooooo03?oool00`0003?o03?o0007<ol000<0003oooooool0N_oo
o`00Hoooo`03o`2Ioooooooo03?oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Hooo
o`03o`2Ioooooooo03?oool00`0003?o03?o0007<ol00P0007_oool006?oool00ol0VOooooooo`0d
oooo00<0000co`0co`001S?o00030000oooooooo07[oool006?oool00ol0VOooooooo`0doooo00<0
000co`0co`001S?o00030000oooooooo07[oool006?oool00ol0VOooooooo`0doooo00<0000co`0c
o`001S?o00030000oooooooo07[oool006?oool00ol0VOooooooo`0doooo00<0000co`0co`001S?o
00030000oooooooo07[oool006?oool00ol0VOooooooo`0eoooo1@0000<co`000`000?ooooooo`1j
oooo001Soooo00?o09Woooooool0=Oooo`030000<ol0000000Dco`000`000?ooooooo`1joooo001S
oooo00?o09Woooooool0=Oooo`030000<ol0000000Dco`030000N_ooo`00Hoooo`03o`2Ioooooooo
03Koool200001C?o00030000oooooooo07[oool006?oool00ol0VOooooooo`0foooo0P0000Dco`00
0`000?ooooooo`1joooo001Soooo00?o09Woooooool0=_ooo`800005<ol000<0003oooooool0N_oo
o`00Hoooo`03o`2Ioooooooo03Koool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Hooo
o`03o`2Ioooooooo03Koool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Hoooo`03o`2I
oooooooo03Koool00`0003?o03?o0004<ol00P0007_oool006?oool00ol0VOooooooo`0goooo00<0
000co`0co`000c?o00030000oooooooo07[oool006?oool00ol0VOooooooo`0goooo00<0000co`0c
o`000c?o00030000oooooooo07[oool006?oool00ol0VOooooooo`0goooo00<0000co`0co`000c?o
00030000oooooooo07[oool006?oool00ol0VOooooooo`0goooo00<0000co`0co`000c?o00030000
oooooooo07[oool006?oool00ol0VOooooooo`0goooo00<0000co`0co`000c?o00030000oooooooo
07[oool006?oool00ol0VOooooooo`0goooo00<0000co`0co`000c?o0080001koooo001Soooo00?o
09Woooooool0=oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001Soooo00?o09Wooooo
ool0=oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001Soooo00?o09Woooooool0>?oo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Soooo00?o09Woooooool0>?ooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo001Soooo00?o09Woooooool0>?ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo001Soooo00?o09Woooooool0>?ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001Soooo00?o09Woooooool0>?ooo`030000<ol0<ol0008co`020000Nooo
o`00Hoooo`03o`2Ioooooooo03Soool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Hooo
o`03o`2Ioooooooo03Soool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Hoooo`03o`2I
oooooooo03Soool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Hoooo`03o`2Ioooooooo
03Soool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Hoooo`03o`2Ioooooooo03Soool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Hoooo`03o`2Ioooooooo03Soool00`0003?o
03?o0002<ol00P0007_oool006?oool00ol0VOooooooo`0ioooo00D0000co`0co`0co`000000O?oo
o`00Hoooo`03o`2Ioooooooo03Woool01@0003?o03?o03?o0000001loooo001Soooo00?o09Wooooo
ool0>Oooo`050000<ol0<ol0<ol0000007coool006?oool00ol0VOooooooo`0eoooo1@0000<co`00
0`000?ooooooo`1joooo001Soooo00?o09Woooooool0=Oooo`050000oooooooooooo000000<co`00
0`000?ooooooo`1joooo001Soooo00?o09Woooooool0=_ooo`040000oooooooo00000c?o00<0001j
oooo001Soooo00?o09Woooooool0=oooo`030000oooo000000<co`000`000?ooooooo`1joooo001S
oooo00?o09Woooooool0=Oooo`030000oooooooo00800003<ol000<0003oooooool0N_ooo`00Hooo
o`03o`2Ioooooooo03Koool2000000?oool0000co`000S?o00030000oooooooo07[oool006?oool0
0ol0VOooooooo`0ioooo00D0000co`0co`0co`000000O?ooo`00Hoooo`03o`2Ioooooooo03[oool0
100003?o03?o000007coool006?oool00ol0VOooooooo`0joooo00<0000co`0co`000P0007_oool0
06?oool00ol0VOooooooo`0joooo00@0000co`0co`00001loooo001Soooo00?o09Woooooool0>_oo
o`040000<ol0<ol00000O?ooo`00Hoooo`03o`2Ioooooooo03[oool0100003?o03?o000007coool0
06?oool00ol0VOooooooo`0joooo00@0000co`0co`00001loooo001Soooo00?o09Woooooool0>_oo
o`040000<ol0<ol00000O?ooo`00Hoooo`03o`2Ioooooooo03[oool0100003?o03?o000007coool0
06?oool00ol0VOooooooo`0koooo00@0000co`000000001koooo001Soooo00?o09Woooooool0>ooo
o`030000<ol0000007coool006?oool00ol0VOooooooo`0koooo00<0000co`000000O?ooo`00Hooo
o`03o`2Ioooooooo03_oool00`0003?o0000001loooo001Soooo00?o09Woooooool0>oooo`030000
<ol0000007coool006?oool00ol0VOooooooo`0koooo00<0000co`000000O?ooo`00Hoooo`03o`2I
oooooooo03_oool0100003?o0000000007_oool006?oool00ol0VOooooooo`0koooo00<0000co`00
0000O?ooo`00Hoooo`03o`2Ioooooooo03_oool00`0003?o0000001loooo001Soooo00?o09Wooooo
ool0>oooo`030000<ol0000007coool006?oool00ol0VOooooooo`0koooo00<0000co`000000O?oo
o`00Hoooo`03o`2Ioooooooo03_oool00`0003?o0000001loooo001Soooo00?o09Woooooool0>ooo
o`040000<ol000000000Noooo`00Hoooo`03o`2Ioooooooo03_oool00`0003?o0000001loooo001S
oooo00?o09Woooooool0>oooo`030000<ol0000007coool006?oool00ol0VOooooooo`0koooo00<0
000co`000000O?ooo`00Hoooo`03o`2Ioooooooo03Koool200000oooo`030000<ol0000007coool0
06?oool00ol0VOooooooo`0eoooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00Hooo
o`03o`2Ioooooooo03Ooool01P000?ooooooooooo`0003?o00<0001joooo001Soooo00?o09Wooooo
ool0>?ooo`060000oooooooo0000<ol00000O?ooo`00Hoooo`03o`2Ioooooooo03Goool010000?oo
ooooo`0000;oool00`0003?o0000001loooo001Soooo00?o09Woooooool0=_ooo`800004oooo0P00
07coool006?oool00ol0VOooooooo`0loooo0P0007coool006?oool00ol0VOooooooo`0loooo0P00
07coool006?oool00ol0VOooooooo`0loooo0P0007coool006?oool00ol0VOooooooo`0loooo0`00
07_oool006?oool00ol0VOooooooo`0loooo0P0007coool006?oool00ol0VOooooooo`0loooo0P00
07coool006?oool00ol0VOooooooo`0loooo0P0007coool006?oool00ol0VOooooooo`0loooo0P00
07coool006?oool00ol0VOooooooo`0loooo0P0007coool006?oool00ol0VOooooooo`0loooo0`00
07_oool006?oool00ol0VOooooooo`0loooo0P0007coool006?oool00ol0VOooooooo`0loooo0P00
07coool006?oool00ol0VOooooooo`0loooo0P0007coool006?oool00ol0VOooooooo`0loooo0P00
07coool006?oool00ol0VOooooooo`0loooo0P0007coool006?oool00ol0VOooooooo`0loooo0`00
07_oool006?oool00ol0VOooooooo`0moooo00<0003oooooool0N_ooo`00Hoooo`03o`2Ioooooooo
03goool00`000?ooooooo`1joooo001Soooo00?o09Woooooool0?Oooo`030000oooooooo07[oool0
06?oool00ol0VOooooooo`0moooo00<0003oooooool0N_ooo`00Hoooo`03o`2Ioooooooo03goool0
0`000?ooooooo`1joooo001Soooo00?o09Woooooool0?Oooo`80001koooo001Soooo00?o09Wooooo
ool0?Oooo`030000oooooooo07[oool006?oool00ol0VOooooooo`0moooo00<0003oooooool0N_oo
o`00Hoooo`03o`2Ioooooooo03goool00`000?ooooooo`1joooo001Soooo00?o09Woooooool0?Ooo
o`030000oooooooo07[oool006?oool00ol0VOooooooo`0goooo0`0000?oool00`000?ooooooo`1j
oooo001Soooo00?o09Woooooool0>?ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001S
oooo00?o09Woooooool0=Oooo`D00003oooo0`0007[oool009_oool010000?ooooooo`00087oool0
09coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03_ooo`<00002oooo0P0000?oool400000oooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001_oo
o`030000oooooooo00Koool00`000?ooooooo`04oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo1@0000Soool00`000?ooooooo`04oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool0000:oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Foooo00<0003oool0
00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0H
oooo0P0000Woool200000oooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.32831 .12361 L
.33073 .12361 L
.33193 .12361 L
.33304 .12361 L
s
.33304 .12361 m
.33356 .61803 L
s
0 .4 1 r
.02381 .1295 m
.04262 .13184 L
.06244 .13533 L
.07286 .13772 L
.08255 .14039 L
.09388 .14414 L
.10458 .14845 L
.125 .15935 L
.14357 .17338 L
.16185 .19254 L
.16686 .19897 L
.16962 .20278 L
.17225 .20657 L
.17343 .20833 L
.17468 .21012 L
.1754 .21011 L
.17606 .2101 L
.17733 .21008 L
.18199 .21 L
.20182 .20957 L
.21265 .20926 L
.22285 .20891 L
.24293 .20801 L
.2614 .20684 L
.28023 .20518 L
.29092 .20396 L
.30089 .20259 L
.31134 .20087 L
.32124 .19891 L
.32555 .19795 L
.33013 .19684 L
.33128 .19654 L
.33252 .19622 L
.33323 .19603 L
.33388 .12361 L
.33515 .12361 L
.33623 .12361 L
.33742 .12361 L
.33865 .12361 L
.3398 .12361 L
.34108 .12361 L
.34172 .12361 L
.34243 .12361 L
.34368 .12361 L
.34485 .12361 L
.34556 .12361 L
.34623 .12361 L
.34749 .12361 L
.34819 .12361 L
.34884 .12361 L
Mistroke
.34956 .12361 L
.35032 .12361 L
.35161 .12361 L
.35234 .12361 L
.35301 .12361 L
.35424 .12361 L
.35554 .12361 L
.3567 .12361 L
.35779 .12361 L
.35898 .12361 L
.36026 .12361 L
.3615 .12361 L
.36265 .12361 L
.36392 .12361 L
.36456 .12361 L
.36526 .12361 L
.36642 .12361 L
.36751 .12361 L
.3688 .12361 L
.36999 .12361 L
.37106 .12361 L
.37205 .12361 L
.37314 .12361 L
.3743 .12361 L
.37553 .12361 L
.37669 .12361 L
.37772 .12361 L
.37885 .12361 L
.38008 .12361 L
.38121 .12361 L
.38252 .12361 L
.38375 .12361 L
.38489 .12361 L
.38595 .12361 L
.3871 .12361 L
.38834 .12361 L
.38956 .12361 L
.39025 .12361 L
.39089 .12361 L
.39206 .12361 L
.39329 .12361 L
.39394 .12361 L
.39464 .12361 L
.3959 .12361 L
.39667 .12361 L
.3974 .12361 L
.39805 .12361 L
.39876 .12361 L
.40007 .12361 L
.40129 .12361 L
Mistroke
.40199 .12361 L
.40263 .12361 L
.40337 .12361 L
.40408 .12361 L
.40475 .12361 L
.40547 .12361 L
.40677 .12361 L
.40757 .12361 L
.40831 .12361 L
.40899 .12361 L
.40971 .12361 L
.41093 .12361 L
.41163 .12361 L
.41227 .12361 L
.41358 .12361 L
.41431 .12361 L
.41498 .12361 L
.41617 .12361 L
.41746 .12361 L
.41869 .12361 L
.41982 .12361 L
.421 .12361 L
.42224 .12361 L
.4233 .12361 L
.42445 .12361 L
.42571 .12361 L
.42641 .12361 L
.42704 .12361 L
.42828 .12361 L
.42945 .12361 L
.43055 .12361 L
.43171 .12361 L
.4327 .12361 L
.43379 .12361 L
.43496 .12361 L
.43622 .12361 L
.43741 .12361 L
.4385 .12361 L
.43977 .12361 L
.44048 .12361 L
.44112 .12361 L
.44238 .12361 L
.44356 .12361 L
.44423 .12361 L
.44494 .12361 L
.44621 .12361 L
.44691 .12361 L
.44757 .12361 L
.4483 .12361 L
.44907 .12361 L
Mistroke
.45036 .12361 L
.45109 .12361 L
.45177 .12361 L
.45298 .12361 L
.45367 .12361 L
.45432 .12361 L
.45544 .12361 L
.45664 .12361 L
.45791 .12361 L
.4591 .12361 L
.45974 .12361 L
.46043 .12361 L
.46164 .12361 L
.46232 .12361 L
.46304 .12361 L
.46434 .12361 L
.46554 .12361 L
.46666 .12361 L
.46788 .12361 L
.4692 .12361 L
.46994 .12361 L
.47062 .12361 L
.47137 .12361 L
.47216 .12361 L
.47285 .12361 L
.4735 .12361 L
.4742 .12361 L
.47497 .12361 L
.47561 .12361 L
.4763 .12361 L
.47703 .12361 L
.47771 .12361 L
.47893 .12361 L
.48023 .12361 L
.48149 .12361 L
.48212 .12361 L
.48282 .12361 L
.48358 .12361 L
.48429 .12361 L
.48494 .12361 L
.48564 .12361 L
.48629 .12361 L
.48701 .12361 L
.48831 .12361 L
.48958 .12361 L
.49075 .12361 L
.492 .12361 L
.49318 .12361 L
.49424 .12361 L
.49538 .12361 L
Mistroke
.49663 .12361 L
.49795 .12361 L
.49908 .12361 L
.50031 .12361 L
.50162 .12361 L
.50283 .12361 L
.50346 .12361 L
.50416 .12361 L
.50489 .12361 L
.50557 .12361 L
.50682 .12361 L
.50796 .12361 L
.50922 .12361 L
.51054 .12361 L
.51166 .12361 L
.51285 .12361 L
.51397 .12361 L
.51499 .12361 L
.51619 .12361 L
.51749 .12361 L
.51985 .12361 L
.52117 .12361 L
.52191 .12361 L
.52259 .12361 L
.5239 .12361 L
.52515 .12361 L
.52642 .12361 L
.52715 .12361 L
.52781 .12361 L
.52849 .12361 L
.52924 .12361 L
.53001 .12361 L
.53075 .12361 L
.53197 .12361 L
.53326 .12361 L
.53436 .12361 L
.53557 .12361 L
.53687 .12361 L
.5376 .12361 L
.53827 .12361 L
.53956 .12361 L
.54078 .12361 L
.54193 .12361 L
.54316 .12361 L
.54433 .12361 L
.54539 .12361 L
.54664 .12361 L
.54735 .12361 L
.548 .12361 L
.5492 .12361 L
Mistroke
.55048 .12361 L
.55117 .12361 L
.55181 .12361 L
.55251 .12361 L
.55325 .12361 L
.5545 .12361 L
.55521 .12361 L
.55587 .12361 L
.5571 .12361 L
.55823 .12361 L
.55953 .12361 L
.56076 .12361 L
.56182 .12361 L
.56298 .12361 L
.5642 .12361 L
.56535 .12361 L
.56641 .12361 L
.56739 .12361 L
.56846 .12361 L
.56959 .12361 L
.57074 .12361 L
.57197 .12361 L
.57313 .12361 L
.57418 .12361 L
.57542 .12361 L
.57612 .12361 L
.57676 .12361 L
.57795 .12361 L
.5792 .12361 L
.58041 .12361 L
.58173 .12361 L
.58413 .12361 L
.58864 .12361 L
.59878 .12361 L
.6171 .12361 L
.6578 .12361 L
.69699 .12361 L
.73863 .12361 L
.77876 .12361 L
.81737 .12361 L
.85843 .12361 L
.89798 .12361 L
.93601 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`05oooo00<0I_ooool0
00002Oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`005_ooo`P0I_l<oooo00<0003oooooool09_ooo`030000oooooooo00ooool00`1Voooo
ooooo`0Coooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000oooooooo
02Koool00`000?ooooooo`0Yoooo000Noooo101Vod?oool00`1Vooooooooo`0Poooo100001Lco`00
0`000?ooooooo`1joooo000Roooo0P1Vod7oool00`1Vooooooooo`0Toooo00<0000co`0co`0053?o
00030000oooooooo07[oool002Coool306Ko?_ooo`0306Kooooooooo02Goool2000053?o00030000
oooooooo07[oool002Ooool306Ko>oooo`0306Kooooooooo02Ooool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00:_ooo`<0I_lhoooo00<0I_ooooooool0:?ooo`030000<ol0<ol0010co`02
0000Noooo`00;Oooo`80I_lfoooo00<0I_ooooooool0:Oooo`80000@<ol000<0003oooooool0N_oo
o`00;oooo`80I_ldoooo00<0I_ooooooool0:oooo`030000<ol0<ol000dco`000`000?ooooooo`1j
oooo000aoooo00<0I_ooooooool0<Oooo`0306Kooooooooo02_oool00`0003?o03?o000=<ol000<0
003oooooool0N_ooo`00<_ooo`80I_laoooo00<0I_ooooooool0;?ooo`030000<ol0<ol000`co`00
0`000?ooooooo`1joooo000doooo00<0I_ooooooool0;_ooo`0306Kooooooooo02coool00`0003?o
03?o000<<ol000<0003oooooool0N_ooo`00=Oooo`0306Kooooooooo02goool00`1Vooooooooo`0]
oooo00<0000co`0co`002c?o0080001koooo000foooo00<0I_ooooooool0;?ooo`0306Kooooooooo
02goool00`0003?o03?o000;<ol000<0003oooooool0N_ooo`00=oooo`0306Kooooooooo02_oool0
0`1Vooooooooo`0^oooo00<0000co`0co`002S?o00030000oooooooo07[oool003Ooool00`1Voooo
ooooo`0[oooo00<0I_ooooooool0;_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo000h
oooo00<0I_ooooooool0:_ooo`0306Kooooooooo02ooool00`0003?o03?o0009<ol000<0003ooooo
ool0N_ooo`00>Oooo`0306Kooooooooo02Woool00`1Vooooooooo`0_oooo00<0000co`0co`002C?o
00030000oooooooo07[oool003[oool00`1Vooooooooo`0Toooo1@1Voc;oool00`0003?o03?o0008
<ol00P0007_oool003_oool00`1Vooooooooo`0Noooo1@1Vo`Coool00ol0VOooooooo`0`oooo00<0
000co`0co`0023?o00030000oooooooo07[oool003coool00`1Vooooooooo`0Foooo1`1Vo`Woool0
0ol0VOooooooo`0`oooo00<0000co`0co`0023?o00030000oooooooo07[oool003cooolI06Ko4?oo
o`03o`2Ioooooooo037oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00IOooo`03o`2I
oooooooo037oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo
037oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo037oool0
0`0003?o03?o0007<ol00P0007_oool006Goool00ol0VOooooooo`0boooo00<0000co`0co`001S?o
00030000oooooooo07[oool006Goool00ol0VOooooooo`0boooo00<0000co`0co`001S?o00030000
oooooooo07[oool006Goool00ol0VOooooooo`0boooo00<0000co`0co`001S?o00030000oooooooo
07[oool006Goool00ol0VOooooooo`0boooo00<0000co`0co`001S?o00030000oooooooo07[oool0
06Goool00ol0VOooooooo`0coooo1@0000<co`000`000?ooooooo`1joooo001Uoooo00?o09Wooooo
ool0<oooo`030000<ol0000000Dco`000`000?ooooooo`1joooo001Uoooo00?o09Woooooool0<ooo
o`030000<ol0000000Dco`030000N_ooo`00IOooo`03o`2Ioooooooo03Coool200001C?o00030000
oooooooo07[oool006Goool00ol0VOooooooo`0doooo0P0000Dco`000`000?ooooooo`1joooo001U
oooo00?o09Woooooool0=?ooo`800005<ol000<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo
03Coool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo03Coool0
0`0003?o03?o0004<ol000<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo03Coool00`0003?o
03?o0004<ol00P0007_oool006Goool00ol0VOooooooo`0eoooo00<0000co`0co`000c?o00030000
oooooooo07[oool006Goool00ol0VOooooooo`0eoooo00<0000co`0co`000c?o00030000oooooooo
07[oool006Goool00ol0VOooooooo`0eoooo00<0000co`0co`000c?o00030000oooooooo07[oool0
06Goool00ol0VOooooooo`0eoooo00<0000co`0co`000c?o00030000oooooooo07[oool006Goool0
0ol0VOooooooo`0eoooo00<0000co`0co`000c?o00030000oooooooo07[oool006Goool00ol0VOoo
ooooo`0eoooo00<0000co`0co`000c?o0080001koooo001Uoooo00?o09Woooooool0=Oooo`030000
<ol0<ol000<co`000`000?ooooooo`1joooo001Uoooo00?o09Woooooool0=Oooo`030000<ol0<ol0
00<co`000`000?ooooooo`1joooo001Uoooo00?o09Woooooool0=_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001Uoooo00?o09Woooooool0=_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo001Uoooo00?o09Woooooool0=_ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001Uoooo00?o09Woooooool0=_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001U
oooo00?o09Woooooool0=_ooo`030000<ol0<ol0008co`020000Noooo`00IOooo`03o`2Ioooooooo
03Koool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo03Koool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo03Koool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo03Koool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo03Koool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00IOooo`03o`2Ioooooooo03Koool00`0003?o03?o0002<ol00P0007_oool0
06Goool00ol0VOooooooo`0goooo00D0000co`0co`0co`000000O?ooo`00IOooo`03o`2Ioooooooo
03Ooool01@0003?o03?o03?o0000001loooo001Uoooo00?o09Woooooool0=oooo`050000<ol0<ol0
<ol0000007coool006Goool00ol0VOooooooo`0coooo1@0000<co`000`000?ooooooo`1joooo001U
oooo00?o09Woooooool0<oooo`050000oooooooooooo000000<co`000`000?ooooooo`1joooo001U
oooo00?o09Woooooool0=?ooo`040000oooooooo00000c?o00<0001joooo001Uoooo00?o09Wooooo
ool0=Oooo`030000oooo000000<co`000`000?ooooooo`1joooo001Uoooo00?o09Woooooool0<ooo
o`030000oooooooo00800003<ol000<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo03Coool2
000000?oool0000co`000S?o00030000oooooooo07[oool006Goool00ol0VOooooooo`0goooo00D0
000co`0co`0co`000000O?ooo`00IOooo`03o`2Ioooooooo03Soool0100003?o03?o000007coool0
06Goool00ol0VOooooooo`0hoooo00<0000co`0co`000P0007_oool006Goool00ol0VOooooooo`0h
oooo00@0000co`0co`00001loooo001Uoooo00?o09Woooooool0>?ooo`040000<ol0<ol00000O?oo
o`00IOooo`03o`2Ioooooooo03Soool0100003?o03?o000007coool006Goool00ol0VOooooooo`0h
oooo00@0000co`0co`00001loooo001Uoooo00?o09Woooooool0>?ooo`040000<ol0<ol00000O?oo
o`00IOooo`03o`2Ioooooooo03Soool0100003?o03?o000007coool006Goool00ol0VOooooooo`0i
oooo00@0000co`000000001koooo001Uoooo00?o09Woooooool0>Oooo`030000<ol0000007coool0
06Goool00ol0VOooooooo`0ioooo00<0000co`000000O?ooo`00IOooo`03o`2Ioooooooo03Woool0
0`0003?o0000001loooo001Uoooo00?o09Woooooool0>Oooo`030000<ol0000007coool006Goool0
0ol0VOooooooo`0ioooo00<0000co`000000O?ooo`00IOooo`03o`2Ioooooooo03Woool0100003?o
0000000007_oool006Goool00ol0VOooooooo`0ioooo00<0000co`000000O?ooo`00IOooo`03o`2I
oooooooo03Woool00`0003?o0000001loooo001Uoooo00?o09Woooooool0>Oooo`030000<ol00000
07coool006Goool00ol0VOooooooo`0ioooo00<0000co`000000O?ooo`00IOooo`03o`2Ioooooooo
03Woool00`0003?o0000001loooo001Uoooo00?o09Woooooool0>Oooo`040000<ol000000000Nooo
o`00IOooo`03o`2Ioooooooo03Woool00`0003?o0000001loooo001Uoooo00?o09Woooooool0>Ooo
o`030000<ol0000007coool006Goool00ol0VOooooooo`0ioooo00<0000co`000000O?ooo`00IOoo
o`03o`2Ioooooooo03Coool200000oooo`030000<ol0000007coool006Goool00ol0VOooooooo`0c
oooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00IOooo`03o`2Ioooooooo03Goool0
1P000?ooooooooooo`0003?o00<0001joooo001Uoooo00?o09Woooooool0=_ooo`060000oooooooo
0000<ol00000O?ooo`00IOooo`03o`2Ioooooooo03?oool010000?ooooooo`0000;oool00`0003?o
0000001loooo001Uoooo00?o09Woooooool0=?ooo`800004oooo0P0007coool006Goool00ol0VOoo
ooooo`0joooo0P0007coool006Goool00ol0VOooooooo`0joooo0P0007coool006Goool00ol0VOoo
ooooo`0joooo0P0007coool006Goool00ol0VOooooooo`0joooo0`0007_oool006Goool00ol0VOoo
ooooo`0joooo0P0007coool006Goool00ol0VOooooooo`0joooo0P0007coool006Goool00ol0VOoo
ooooo`0joooo0P0007coool006Goool00ol0VOooooooo`0joooo0P0007coool006Goool00ol0VOoo
ooooo`0joooo0P0007coool006Goool00ol0VOooooooo`0joooo0`0007_oool006Goool00ol0VOoo
ooooo`0joooo0P0007coool006Goool00ol0VOooooooo`0joooo0P0007coool006Goool00ol0VOoo
ooooo`0joooo0P0007coool006Goool00ol0VOooooooo`0joooo0P0007coool006Goool00ol0VOoo
ooooo`0joooo0P0007coool006Goool00ol0VOooooooo`0joooo0`0007_oool006Goool00ol0VOoo
ooooo`0koooo00<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo03_oool00`000?ooooooo`1j
oooo001Uoooo00?o09Woooooool0>oooo`030000oooooooo07[oool006Goool00ol0VOooooooo`0k
oooo00<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo03_oool00`000?ooooooo`1joooo001U
oooo00?o09Woooooool0>oooo`80001koooo001Uoooo00?o09Woooooool0>oooo`030000oooooooo
07[oool006Goool00ol0VOooooooo`0koooo00<0003oooooool0N_ooo`00IOooo`03o`2Ioooooooo
03_oool00`000?ooooooo`1joooo001Uoooo00?o09Woooooool0>oooo`030000oooooooo07[oool0
06Goool00ol0VOooooooo`0eoooo0`0000?oool00`000?ooooooo`1joooo001Uoooo00?o09Wooooo
ool0=_ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001Uoooo00?o09Woooooool0<ooo
o`D00003oooo0`0007[oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021
oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03_ooo`<00002
oooo0P0000?oool500000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001_ooo`030000oooooooo00Soool0
0`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0Coooo1@0000Woool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Boooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000Foooo00<0003oool000002_ooo`030000oooooooo
00;oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool06?ooo`800009oooo0P0000?oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
s
.34076 .12361 m
.34121 .61803 L
s
0 .4 1 r
.02381 .12872 m
.04262 .13076 L
.06244 .13379 L
.07286 .13586 L
.08255 .13817 L
.09388 .14143 L
.10458 .14517 L
.125 .15464 L
.14357 .16681 L
.16355 .18528 L
.17243 .19586 L
.17733 .20245 L
.17974 .20592 L
.18092 .20766 L
.18199 .20927 L
.18316 .21011 L
.1844 .21009 L
.18704 .21005 L
.19166 .20997 L
.20071 .20978 L
.21145 .20952 L
.22134 .20924 L
.24058 .20851 L
.25071 .20802 L
.2614 .20739 L
.28104 .20588 L
.29938 .20389 L
.31973 .20078 L
.32873 .19901 L
.33366 .19791 L
.33828 .19678 L
.33939 .1965 L
.34055 .19619 L
.34183 .12361 L
.343 .12361 L
.34428 .12361 L
.34548 .12361 L
.34679 .12361 L
.34753 .12361 L
.3482 .12361 L
.34938 .12361 L
.35046 .12361 L
.35165 .12361 L
.35292 .12361 L
.35401 .12361 L
.35504 .12361 L
.35616 .12361 L
.35737 .12361 L
.35804 .12361 L
.35875 .12361 L
Mistroke
.36003 .12361 L
.36082 .12361 L
.36156 .12361 L
.36222 .12361 L
.36293 .12361 L
.36357 .12361 L
.36427 .12361 L
.36501 .12361 L
.36569 .12361 L
.36691 .12361 L
.36822 .12361 L
.3695 .12361 L
.37022 .12361 L
.37088 .12361 L
.37211 .12361 L
.37341 .12361 L
.37457 .12361 L
.37565 .12361 L
.37685 .12361 L
.37813 .12361 L
.37939 .12361 L
.38054 .12361 L
.38186 .12361 L
.3831 .12361 L
.38426 .12361 L
.38532 .12361 L
.38649 .12361 L
.38773 .12361 L
.38897 .12361 L
.38966 .12361 L
.39031 .12361 L
.39157 .12361 L
.39272 .12361 L
.39338 .12361 L
.39409 .12361 L
.39535 .12361 L
.39605 .12361 L
.39671 .12361 L
.39743 .12361 L
.39821 .12361 L
.39885 .12361 L
.39953 .12361 L
.40077 .12361 L
.40152 .12361 L
.40224 .12361 L
.40288 .12361 L
.40357 .12361 L
.40425 .12361 L
.405 .12361 L
.40578 .12361 L
Mistroke
.40651 .12361 L
.40781 .12361 L
.40855 .12361 L
.40922 .12361 L
.4105 .12361 L
.4117 .12361 L
.41301 .12361 L
.41374 .12361 L
.4144 .12361 L
.41562 .12361 L
.41693 .12361 L
.41818 .12361 L
.41932 .12361 L
.42059 .12361 L
.42178 .12361 L
.42286 .12361 L
.42403 .12361 L
.4253 .12361 L
.42594 .12361 L
.42665 .12361 L
.42789 .12361 L
.42907 .12361 L
.43018 .12361 L
.43135 .12361 L
.43235 .12361 L
.43344 .12361 L
.43463 .12361 L
.43589 .12361 L
.43708 .12361 L
.43816 .12361 L
.43945 .12361 L
.4401 .12361 L
.44082 .12361 L
.44208 .12361 L
.44326 .12361 L
.44398 .12361 L
.44466 .12361 L
.44593 .12361 L
.44664 .12361 L
.4473 .12361 L
.44803 .12361 L
.4488 .12361 L
.4501 .12361 L
.45083 .12361 L
.45151 .12361 L
.45275 .12361 L
.45406 .12361 L
.45524 .12361 L
.45634 .12361 L
.45754 .12361 L
Mistroke
.45883 .12361 L
.46005 .12361 L
.46075 .12361 L
.46141 .12361 L
.46272 .12361 L
.46346 .12361 L
.46414 .12361 L
.46534 .12361 L
.46665 .12361 L
.46789 .12361 L
.46904 .12361 L
.46973 .12361 L
.47049 .12361 L
.4712 .12361 L
.47185 .12361 L
.47309 .12361 L
.4744 .12361 L
.47508 .12361 L
.47581 .12361 L
.47713 .12361 L
.47794 .12361 L
.4787 .12361 L
.47938 .12361 L
.48013 .12361 L
.48137 .12361 L
.48253 .12361 L
.48381 .12361 L
.48453 .12361 L
.4852 .12361 L
.48645 .12361 L
.48717 .12361 L
.48782 .12361 L
.48851 .12361 L
.48925 .12361 L
.48994 .12361 L
.49058 .12361 L
.49176 .12361 L
.493 .12361 L
.49406 .12361 L
.49523 .12361 L
.49648 .12361 L
.49718 .12361 L
.49783 .12361 L
.49908 .12361 L
.50026 .12361 L
.50142 .12361 L
.50264 .12361 L
.50328 .12361 L
.50398 .12361 L
.50521 .12361 L
Mistroke
.50637 .12361 L
.50762 .12361 L
.5088 .12361 L
.50987 .12361 L
.51119 .12361 L
.51194 .12361 L
.51263 .12361 L
.51389 .12361 L
.51453 .12361 L
.51524 .12361 L
.51644 .12361 L
.51775 .12361 L
.51897 .12361 L
.5201 .12361 L
.52117 .12361 L
.52232 .12361 L
.5234 .12361 L
.52438 .12361 L
.52554 .12361 L
.52679 .12361 L
.52798 .12361 L
.52906 .12361 L
.53019 .12361 L
.53125 .12361 L
.53241 .12361 L
.53365 .12361 L
.53495 .12361 L
.53618 .12361 L
.53729 .12361 L
.5385 .12361 L
.53971 .12361 L
.54082 .12361 L
.54204 .12361 L
.54333 .12361 L
.54445 .12361 L
.5455 .12361 L
.54665 .12361 L
.54787 .12361 L
.54857 .12361 L
.54921 .12361 L
.54992 .12361 L
.55066 .12361 L
.55192 .12361 L
.55263 .12361 L
.5533 .12361 L
.55454 .12361 L
.55568 .12361 L
.55699 .12361 L
.55824 .12361 L
.55956 .12361 L
Mistroke
.56076 .12361 L
.56142 .12361 L
.56214 .12361 L
.56344 .12361 L
.56467 .12361 L
.56596 .12361 L
.56706 .12361 L
.56828 .12361 L
.56901 .12361 L
.56971 .12361 L
.57101 .12361 L
.57174 .12361 L
.57242 .12361 L
.57316 .12361 L
.57394 .12361 L
.57524 .12361 L
.57646 .12361 L
.57715 .12361 L
.57779 .12361 L
.57849 .12361 L
.57923 .12361 L
.58047 .12361 L
.58116 .12361 L
.58181 .12361 L
.58424 .12361 L
.58878 .12361 L
.59898 .12361 L
.61735 .12361 L
.65676 .12361 L
.69465 .12361 L
.735 .12361 L
.77383 .12361 L
.81512 .12361 L
.85489 .12361 L
.89314 .12361 L
.93384 .12361 L
.97303 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`005_ooo`P0I_l<oooo00<0003oooooool09_ooo`030000oooooooo017oool00`1Voooo
ooooo`0Aoooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000oooooooo
02Koool00`000?ooooooo`0Yoooo000Noooo101VodGoool00`1Vooooooooo`0Noooo100001Lco`00
0`000?ooooooo`1joooo000Roooo1@1Vod3oool00`1Vooooooooo`0Roooo00<0000co`0co`0053?o
00030000oooooooo07[oool002Ooool306Ko?Oooo`0306Kooooooooo02?oool2000053?o00030000
oooooooo07[oool002[oool306Ko>_ooo`0306Kooooooooo02Goool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00;Oooo`80I_lhoooo00<0I_ooooooool09_ooo`030000<ol0<ol0010co`02
0000Noooo`00;oooo`80I_lfoooo00<0I_ooooooool09oooo`80000@<ol000<0003oooooool0N_oo
o`00<Oooo`80I_ldoooo00<0I_ooooooool0:Oooo`030000<ol0<ol000dco`000`000?ooooooo`1j
oooo000coooo0P1Voc;oool00`1Vooooooooo`0Yoooo00<0000co`0co`003C?o00030000oooooooo
07[oool003Goool00`1Vooooooooo`0_oooo00<0I_ooooooool0:_ooo`030000<ol0<ol000`co`00
0`000?ooooooo`1joooo000foooo00<0I_ooooooool0;_ooo`0306Kooooooooo02[oool00`0003?o
03?o000<<ol000<0003oooooool0N_ooo`00=oooo`0306Kooooooooo02goool00`1Vooooooooo`0[
oooo00<0000co`0co`002c?o0080001koooo000hoooo00<0I_ooooooool0;?ooo`0306Kooooooooo
02_oool00`0003?o03?o000;<ol000<0003oooooool0N_ooo`00>Oooo`0306Kooooooooo02_oool0
0`1Vooooooooo`0/oooo00<0000co`0co`002S?o00030000oooooooo07[oool003[oool00`1Voooo
ooooo`0Zoooo00<0I_ooooooool0;?ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo000k
oooo00<0I_ooooooool0:Oooo`0306Kooooooooo02goool00`0003?o03?o0009<ol000<0003ooooo
ool0N_ooo`00>oooo`0306Kooooooooo02Woool00`1Vooooooooo`0]oooo00<0000co`0co`002C?o
00030000oooooooo07[oool003coool00`1Vooooooooo`0Voooo0`1Voc3oool00`0003?o03?o0008
<ol00P0007_oool003goool00`1Vooooooooo`0Ooooo1P1Vo`;oool00ol0VOooooooo`0^oooo00<0
000co`0co`0023?o00030000oooooooo07[oool003koool00`1Vooooooooo`0Doooo2P1Vo`Soool0
0ol0VOooooooo`0^oooo00<0000co`0co`0023?o00030000oooooooo07[oool003kooolG06Ko4_oo
o`03o`2Ioooooooo02ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Ioooo`03o`2I
oooooooo02ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo
02ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo02ooool0
0`0003?o03?o0007<ol00P0007_oool006Ooool00ol0VOooooooo`0`oooo00<0000co`0co`001S?o
00030000oooooooo07[oool006Ooool00ol0VOooooooo`0`oooo00<0000co`0co`001S?o00030000
oooooooo07[oool006Ooool00ol0VOooooooo`0`oooo00<0000co`0co`001S?o00030000oooooooo
07[oool006Ooool00ol0VOooooooo`0`oooo00<0000co`0co`001S?o00030000oooooooo07[oool0
06Ooool00ol0VOooooooo`0aoooo1@0000<co`000`000?ooooooo`1joooo001Woooo00?o09Wooooo
ool0<Oooo`030000<ol0000000Dco`000`000?ooooooo`1joooo001Woooo00?o09Woooooool0<Ooo
o`030000<ol0000000Dco`030000N_ooo`00Ioooo`03o`2Ioooooooo03;oool200001C?o00030000
oooooooo07[oool006Ooool00ol0VOooooooo`0boooo0P0000Dco`000`000?ooooooo`1joooo001W
oooo00?o09Woooooool0<_ooo`800005<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo
03;oool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo03;oool0
0`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo03;oool00`0003?o
03?o0004<ol00P0007_oool006Ooool00ol0VOooooooo`0coooo00<0000co`0co`000c?o00030000
oooooooo07[oool006Ooool00ol0VOooooooo`0coooo00<0000co`0co`000c?o00030000oooooooo
07[oool006Ooool00ol0VOooooooo`0coooo00<0000co`0co`000c?o00030000oooooooo07[oool0
06Ooool00ol0VOooooooo`0coooo00<0000co`0co`000c?o00030000oooooooo07[oool006Ooool0
0ol0VOooooooo`0coooo00<0000co`0co`000c?o00030000oooooooo07[oool006Ooool00ol0VOoo
ooooo`0coooo00<0000co`0co`000c?o0080001koooo001Woooo00?o09Woooooool0<oooo`030000
<ol0<ol000<co`000`000?ooooooo`1joooo001Woooo00?o09Woooooool0<oooo`030000<ol0<ol0
00<co`000`000?ooooooo`1joooo001Woooo00?o09Woooooool0=?ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001Woooo00?o09Woooooool0=?ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo001Woooo00?o09Woooooool0=?ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001Woooo00?o09Woooooool0=?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001W
oooo00?o09Woooooool0=?ooo`030000<ol0<ol0008co`020000Noooo`00Ioooo`03o`2Ioooooooo
03Coool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo03Coool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo03Coool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo03Coool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo03Coool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo03Coool00`0003?o03?o0002<ol00P0007_oool0
06Ooool00ol0VOooooooo`0eoooo00D0000co`0co`0co`000000O?ooo`00Ioooo`03o`2Ioooooooo
03Goool01@0003?o03?o03?o0000001loooo001Woooo00?o09Woooooool0=Oooo`050000<ol0<ol0
<ol0000007coool006Ooool00ol0VOooooooo`0aoooo1@0000<co`000`000?ooooooo`1joooo001W
oooo00?o09Woooooool0<Oooo`050000oooooooooooo000000<co`000`000?ooooooo`1joooo001W
oooo00?o09Woooooool0<_ooo`040000oooooooo00000c?o00<0001joooo001Woooo00?o09Wooooo
ool0<oooo`030000oooo000000<co`000`000?ooooooo`1joooo001Woooo00?o09Woooooool0<Ooo
o`030000oooooooo00800003<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo03;oool2
000000?oool0000co`000S?o00030000oooooooo07[oool006Ooool00ol0VOooooooo`0eoooo00D0
000co`0co`0co`000000O?ooo`00Ioooo`03o`2Ioooooooo03Koool0100003?o03?o000007coool0
06Ooool00ol0VOooooooo`0foooo00<0000co`0co`000P0007_oool006Ooool00ol0VOooooooo`0f
oooo00@0000co`0co`00001loooo001Woooo00?o09Woooooool0=_ooo`040000<ol0<ol00000O?oo
o`00Ioooo`03o`2Ioooooooo03Koool0100003?o03?o000007coool006Ooool00ol0VOooooooo`0f
oooo00@0000co`0co`00001loooo001Woooo00?o09Woooooool0=_ooo`040000<ol0<ol00000O?oo
o`00Ioooo`03o`2Ioooooooo03Koool0100003?o03?o000007coool006Ooool00ol0VOooooooo`0g
oooo00@0000co`000000001koooo001Woooo00?o09Woooooool0=oooo`030000<ol0000007coool0
06Ooool00ol0VOooooooo`0goooo00<0000co`000000O?ooo`00Ioooo`03o`2Ioooooooo03Ooool0
0`0003?o0000001loooo001Woooo00?o09Woooooool0=oooo`030000<ol0000007coool006Ooool0
0ol0VOooooooo`0goooo00<0000co`000000O?ooo`00Ioooo`03o`2Ioooooooo03Ooool0100003?o
0000000007_oool006Ooool00ol0VOooooooo`0goooo00<0000co`000000O?ooo`00Ioooo`03o`2I
oooooooo03Ooool00`0003?o0000001loooo001Woooo00?o09Woooooool0=oooo`030000<ol00000
07coool006Ooool00ol0VOooooooo`0goooo00<0000co`000000O?ooo`00Ioooo`03o`2Ioooooooo
03Ooool00`0003?o0000001loooo001Woooo00?o09Woooooool0=oooo`040000<ol000000000Nooo
o`00Ioooo`03o`2Ioooooooo03Ooool00`0003?o0000001loooo001Woooo00?o09Woooooool0=ooo
o`030000<ol0000007coool006Ooool00ol0VOooooooo`0goooo00<0000co`000000O?ooo`00Iooo
o`03o`2Ioooooooo03;oool200000oooo`030000<ol0000007coool006Ooool00ol0VOooooooo`0a
oooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00Ioooo`03o`2Ioooooooo03?oool0
1P000?ooooooooooo`0003?o00<0001joooo001Woooo00?o09Woooooool0=?ooo`060000oooooooo
0000<ol00000O?ooo`00Ioooo`03o`2Ioooooooo037oool010000?ooooooo`0000;oool00`0003?o
0000001loooo001Woooo00?o09Woooooool0<_ooo`800004oooo0P0007coool006Ooool00ol0VOoo
ooooo`0hoooo0P0007coool006Ooool00ol0VOooooooo`0hoooo0P0007coool006Ooool00ol0VOoo
ooooo`0hoooo0P0007coool006Ooool00ol0VOooooooo`0hoooo0`0007_oool006Ooool00ol0VOoo
ooooo`0hoooo0P0007coool006Ooool00ol0VOooooooo`0hoooo0P0007coool006Ooool00ol0VOoo
ooooo`0hoooo0P0007coool006Ooool00ol0VOooooooo`0hoooo0P0007coool006Ooool00ol0VOoo
ooooo`0hoooo0P0007coool006Ooool00ol0VOooooooo`0hoooo0`0007_oool006Ooool00ol0VOoo
ooooo`0hoooo0P0007coool006Ooool00ol0VOooooooo`0hoooo0P0007coool006Ooool00ol0VOoo
ooooo`0hoooo0P0007coool006Ooool00ol0VOooooooo`0hoooo0P0007coool006Ooool00ol0VOoo
ooooo`0hoooo0P0007coool006Ooool00ol0VOooooooo`0hoooo0`0007_oool006Ooool00ol0VOoo
ooooo`0ioooo00<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo03Woool00`000?ooooooo`1j
oooo001Woooo00?o09Woooooool0>Oooo`030000oooooooo07[oool006Ooool00ol0VOooooooo`0i
oooo00<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo03Woool00`000?ooooooo`1joooo001W
oooo00?o09Woooooool0>Oooo`80001koooo001Woooo00?o09Woooooool0>Oooo`030000oooooooo
07[oool006Ooool00ol0VOooooooo`0ioooo00<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo
03Woool00`000?ooooooo`1joooo001Woooo00?o09Woooooool0>Oooo`030000oooooooo07[oool0
06Ooool00ol0VOooooooo`0coooo0`0000?oool00`000?ooooooo`1joooo001Woooo00?o09Wooooo
ool0=?ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001Woooo00?o09Woooooool0<Ooo
o`D00003oooo0`0007[oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021
oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03_ooo`<00002
oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Koool00`000?ooooooo`07oooo00<0003ooooo
ool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo1@0000Woool00`000?oo
ooooo`1joooo001koooo00<0003oooooool01@0001;oool010000?ooooooo`0000Woool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000005_ooo`030000oooo000000Woool00`000?oo
ooooo`1koooo001loooo00<0003oooooool06?ooo`800008oooo00<0003oooooool0O?ooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.33788 .12361 L
.34309 .12361 L
.34566 .12361 L
.34693 .12361 L
.34811 .12361 L
.34918 .12361 L
s
.34918 .12361 m
.34963 .61803 L
s
0 .4 1 r
.02381 .12805 m
.04262 .12981 L
.06244 .13244 L
.07286 .13424 L
.08255 .13625 L
.09388 .13908 L
.10458 .14233 L
.125 .15054 L
.14357 .16111 L
.16355 .17715 L
.18199 .19798 L
.18664 .20441 L
.18787 .2062 L
.18921 .2082 L
.19048 .21012 L
.19166 .2101 L
.19638 .21002 L
.20071 .20994 L
.21133 .20972 L
.22134 .20947 L
.24186 .20879 L
.26047 .20792 L
.28055 .20659 L
.29902 .20487 L
.31784 .20242 L
.32853 .20062 L
.33851 .1986 L
.34351 .19745 L
.34615 .19679 L
.3476 .19642 L
.34831 .19624 L
.34896 .19606 L
.35013 .12361 L
.3514 .12361 L
.35272 .12361 L
.35338 .12361 L
.3541 .12361 L
.35529 .12361 L
.35656 .12361 L
.35777 .12361 L
.35886 .12361 L
.36002 .12361 L
.36124 .12361 L
.36229 .12361 L
.36344 .12361 L
.36467 .12361 L
.36537 .12361 L
.366 .12361 L
.36723 .12361 L
.3684 .12361 L
Mistroke
.36949 .12361 L
.37064 .12361 L
.37173 .12361 L
.37271 .12361 L
.37388 .12361 L
.37514 .12361 L
.37632 .12361 L
.37741 .12361 L
.37868 .12361 L
.37988 .12361 L
.38096 .12361 L
.38213 .12361 L
.3834 .12361 L
.38404 .12361 L
.38475 .12361 L
.386 .12361 L
.38718 .12361 L
.38829 .12361 L
.38946 .12361 L
.39046 .12361 L
.39156 .12361 L
.39274 .12361 L
.394 .12361 L
.3952 .12361 L
.39628 .12361 L
.39757 .12361 L
.39822 .12361 L
.39894 .12361 L
.4002 .12361 L
.40139 .12361 L
.4021 .12361 L
.40278 .12361 L
.40406 .12361 L
.40477 .12361 L
.40543 .12361 L
.40615 .12361 L
.40692 .12361 L
.4081 .12361 L
.40938 .12361 L
.41058 .12361 L
.41169 .12361 L
.41291 .12361 L
.41361 .12361 L
.41425 .12361 L
.41556 .12361 L
.41629 .12361 L
.41695 .12361 L
.41814 .12361 L
.41926 .12361 L
.42048 .12361 L
Mistroke
.42179 .12361 L
.42245 .12361 L
.42317 .12361 L
.42447 .12361 L
.42574 .12361 L
.42692 .12361 L
.42812 .12361 L
.42925 .12361 L
.43027 .12361 L
.43137 .12361 L
.43257 .12361 L
.43384 .12361 L
.43493 .12361 L
.43612 .12361 L
.43739 .12361 L
.43811 .12361 L
.43878 .12361 L
.44001 .12361 L
.44131 .12361 L
.44202 .12361 L
.44269 .12361 L
.44343 .12361 L
.44422 .12361 L
.44489 .12361 L
.4456 .12361 L
.44687 .12361 L
.44807 .12361 L
.44935 .12361 L
.45056 .12361 L
.45166 .12361 L
.45296 .12361 L
.45369 .12361 L
.45436 .12361 L
.4556 .12361 L
.4569 .12361 L
.45812 .12361 L
.45944 .12361 L
.46068 .12361 L
.46184 .12361 L
.46299 .12361 L
.46403 .12361 L
.46522 .12361 L
.46635 .12361 L
.46759 .12361 L
.46889 .12361 L
.47001 .12361 L
.47123 .12361 L
.47254 .12361 L
.47328 .12361 L
.47395 .12361 L
Mistroke
.47526 .12361 L
.47649 .12361 L
.47755 .12361 L
.47871 .12361 L
.47992 .12361 L
.48106 .12361 L
.48212 .12361 L
.48309 .12361 L
.48421 .12361 L
.48527 .12361 L
.48642 .12361 L
.48764 .12361 L
.48879 .12361 L
.48983 .12361 L
.49106 .12361 L
.49176 .12361 L
.4924 .12361 L
.49357 .12361 L
.49481 .12361 L
.49603 .12361 L
.49667 .12361 L
.49735 .12361 L
.49861 .12361 L
.49976 .12361 L
.50087 .12361 L
.50191 .12361 L
.50305 .12361 L
.50428 .12361 L
.50551 .12361 L
.50621 .12361 L
.50686 .12361 L
.50818 .12361 L
.50891 .12361 L
.50958 .12361 L
.51078 .12361 L
.51208 .12361 L
.51331 .12361 L
.51444 .12361 L
.51549 .12361 L
.51663 .12361 L
.5177 .12361 L
.51868 .12361 L
.51982 .12361 L
.52107 .12361 L
.52225 .12361 L
.52334 .12361 L
.52458 .12361 L
.52574 .12361 L
.52678 .12361 L
.52791 .12361 L
Mistroke
.52914 .12361 L
.53044 .12361 L
.53155 .12361 L
.53277 .12361 L
.53399 .12361 L
.53529 .12361 L
.53596 .12361 L
.53671 .12361 L
.53802 .12361 L
.53926 .12361 L
.53991 .12361 L
.54059 .12361 L
.54185 .12361 L
.543 .12361 L
.54411 .12361 L
.5453 .12361 L
.54643 .12361 L
.54745 .12361 L
.54865 .12361 L
.54995 .12361 L
.55118 .12361 L
.55231 .12361 L
.55352 .12361 L
.55481 .12361 L
.55604 .12361 L
.55715 .12361 L
.55846 .12361 L
.5592 .12361 L
.55989 .12361 L
.56114 .12361 L
.56178 .12361 L
.56248 .12361 L
.56316 .12361 L
.56387 .12361 L
.56515 .12361 L
.56586 .12361 L
.56652 .12361 L
.56725 .12361 L
.56802 .12361 L
.5687 .12361 L
.56943 .12361 L
.57012 .12361 L
.57075 .12361 L
.57196 .12361 L
.57323 .12361 L
.57444 .12361 L
.57576 .12361 L
.577 .12361 L
.57815 .12361 L
.57929 .12361 L
Mistroke
.58033 .12361 L
.58152 .12361 L
.58265 .12361 L
.59277 .12361 L
.61108 .12361 L
.64964 .12361 L
.69065 .12361 L
.73014 .12361 L
.76812 .12361 L
.80855 .12361 L
.84747 .12361 L
.88884 .12361 L
.92869 .12361 L
.96703 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oool0
I_l01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`005_ooo`P0I_l<oooo00<0003oooooool09_ooo`030000oooooooo01?oool00`1Voooo
ooooo`0?oooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000oooooooo
02Koool00`000?ooooooo`0Yoooo000Noooo1P1VodGoool00`1Vooooooooo`0Loooo100001Lco`00
0`000?ooooooo`1joooo000Toooo1P1Vocooool00`1Vooooooooo`0Poooo00<0000co`0co`0053?o
00030000oooooooo07[oool002[oool306Ko??ooo`0306Kooooooooo027oool2000053?o00030000
oooooooo07[oool002goool206Ko>_ooo`0306Kooooooooo02?oool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00;oooo`80I_lhoooo00<0I_ooooooool09?ooo`030000<ol0<ol0010co`02
0000Noooo`00<Oooo`80I_lfoooo00<0I_ooooooool09Oooo`80000@<ol000<0003oooooool0N_oo
o`00<oooo`80I_ldoooo00<0I_ooooooool09oooo`030000<ol0<ol000dco`000`000?ooooooo`1j
oooo000eoooo00<0I_ooooooool0<Oooo`0306Kooooooooo02Ooool00`0003?o03?o000=<ol000<0
003oooooool0N_ooo`00=_ooo`0306Kooooooooo033oool00`1Vooooooooo`0Xoooo00<0000co`0c
o`0033?o00030000oooooooo07[oool003Ooool206Ko<?ooo`0306Kooooooooo02Soool00`0003?o
03?o000<<ol000<0003oooooool0N_ooo`00>Oooo`0306Kooooooooo02goool00`1Vooooooooo`0Y
oooo00<0000co`0co`002c?o0080001koooo000joooo00<0I_ooooooool0;?ooo`0306Kooooooooo
02Woool00`0003?o03?o000;<ol000<0003oooooool0N_ooo`00>oooo`0306Kooooooooo02_oool0
0`1Vooooooooo`0Zoooo00<0000co`0co`002S?o00030000oooooooo07[oool003coool00`1Voooo
ooooo`0Zoooo00<0I_ooooooool0:_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo000l
oooo00<0I_ooooooool0:_ooo`0306Kooooooooo02_oool00`0003?o03?o0009<ol000<0003ooooo
ool0N_ooo`00?Oooo`0306Kooooooooo02Woool00`1Vooooooooo`0[oooo00<0000co`0co`002C?o
00030000oooooooo07[oool003koool00`1Vooooooooo`0Toooo1@1Vobkoool00`0003?o03?o0008
<ol00P0007_oool003ooool00`1Vooooooooo`0Moooo1P1Vo`Coool00ol0VOooooooo`0/oooo00<0
000co`0co`0023?o00030000oooooooo07[oool0043oool00`1Vooooooooo`0Boooo2P1Vo`[oool0
0ol0VOooooooo`0/oooo00<0000co`0co`0023?o00030000oooooooo07[oool0043ooolE06Ko5?oo
o`03o`2Ioooooooo02goool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00JOooo`03o`2I
oooooooo02goool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo
02goool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo02goool0
0`0003?o03?o0007<ol00P0007_oool006Woool00ol0VOooooooo`0^oooo00<0000co`0co`001S?o
00030000oooooooo07[oool006Woool00ol0VOooooooo`0^oooo00<0000co`0co`001S?o00030000
oooooooo07[oool006Woool00ol0VOooooooo`0^oooo00<0000co`0co`001S?o00030000oooooooo
07[oool006Woool00ol0VOooooooo`0^oooo00<0000co`0co`001S?o00030000oooooooo07[oool0
06Woool00ol0VOooooooo`0_oooo1@0000<co`000`000?ooooooo`1joooo001Yoooo00?o09Wooooo
ool0;oooo`030000<ol0000000Dco`000`000?ooooooo`1joooo001Yoooo00?o09Woooooool0;ooo
o`030000<ol0000000Dco`030000N_ooo`00JOooo`03o`2Ioooooooo033oool200001C?o00030000
oooooooo07[oool006Woool00ol0VOooooooo`0`oooo0P0000Dco`000`000?ooooooo`1joooo001Y
oooo00?o09Woooooool0<?ooo`800005<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo
033oool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo033oool0
0`0003?o03?o0004<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo033oool00`0003?o
03?o0004<ol00P0007_oool006Woool00ol0VOooooooo`0aoooo00<0000co`0co`000c?o00030000
oooooooo07[oool006Woool00ol0VOooooooo`0aoooo00<0000co`0co`000c?o00030000oooooooo
07[oool006Woool00ol0VOooooooo`0aoooo00<0000co`0co`000c?o00030000oooooooo07[oool0
06Woool00ol0VOooooooo`0aoooo00<0000co`0co`000c?o00030000oooooooo07[oool006Woool0
0ol0VOooooooo`0aoooo00<0000co`0co`000c?o00030000oooooooo07[oool006Woool00ol0VOoo
ooooo`0aoooo00<0000co`0co`000c?o0080001koooo001Yoooo00?o09Woooooool0<Oooo`030000
<ol0<ol000<co`000`000?ooooooo`1joooo001Yoooo00?o09Woooooool0<Oooo`030000<ol0<ol0
00<co`000`000?ooooooo`1joooo001Yoooo00?o09Woooooool0<_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001Yoooo00?o09Woooooool0<_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo001Yoooo00?o09Woooooool0<_ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001Yoooo00?o09Woooooool0<_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001Y
oooo00?o09Woooooool0<_ooo`030000<ol0<ol0008co`020000Noooo`00JOooo`03o`2Ioooooooo
03;oool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo03;oool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo03;oool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo03;oool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo03;oool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00JOooo`03o`2Ioooooooo03;oool00`0003?o03?o0002<ol00P0007_oool0
06Woool00ol0VOooooooo`0coooo00D0000co`0co`0co`000000O?ooo`00JOooo`03o`2Ioooooooo
03?oool01@0003?o03?o03?o0000001loooo001Yoooo00?o09Woooooool0<oooo`050000<ol0<ol0
<ol0000007coool006Woool00ol0VOooooooo`0_oooo1@0000<co`000`000?ooooooo`1joooo001Y
oooo00?o09Woooooool0;oooo`050000oooooooooooo000000<co`000`000?ooooooo`1joooo001Y
oooo00?o09Woooooool0<?ooo`040000oooooooo00000c?o00<0001joooo001Yoooo00?o09Wooooo
ool0<Oooo`030000oooo000000<co`000`000?ooooooo`1joooo001Yoooo00?o09Woooooool0;ooo
o`030000oooooooo00800003<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo033oool2
000000?oool0000co`000S?o00030000oooooooo07[oool006Woool00ol0VOooooooo`0coooo00D0
000co`0co`0co`000000O?ooo`00JOooo`03o`2Ioooooooo03Coool0100003?o03?o000007coool0
06Woool00ol0VOooooooo`0doooo00<0000co`0co`000P0007_oool006Woool00ol0VOooooooo`0d
oooo00@0000co`0co`00001loooo001Yoooo00?o09Woooooool0=?ooo`040000<ol0<ol00000O?oo
o`00JOooo`03o`2Ioooooooo03Coool0100003?o03?o000007coool006Woool00ol0VOooooooo`0d
oooo00@0000co`0co`00001loooo001Yoooo00?o09Woooooool0=?ooo`040000<ol0<ol00000O?oo
o`00JOooo`03o`2Ioooooooo03Coool0100003?o03?o000007coool006Woool00ol0VOooooooo`0e
oooo00@0000co`000000001koooo001Yoooo00?o09Woooooool0=Oooo`030000<ol0000007coool0
06Woool00ol0VOooooooo`0eoooo00<0000co`000000O?ooo`00JOooo`03o`2Ioooooooo03Goool0
0`0003?o0000001loooo001Yoooo00?o09Woooooool0=Oooo`030000<ol0000007coool006Woool0
0ol0VOooooooo`0eoooo00<0000co`000000O?ooo`00JOooo`03o`2Ioooooooo03Goool0100003?o
0000000007_oool006Woool00ol0VOooooooo`0eoooo00<0000co`000000O?ooo`00JOooo`03o`2I
oooooooo03Goool00`0003?o0000001loooo001Yoooo00?o09Woooooool0=Oooo`030000<ol00000
07coool006Woool00ol0VOooooooo`0eoooo00<0000co`000000O?ooo`00JOooo`03o`2Ioooooooo
03Goool00`0003?o0000001loooo001Yoooo00?o09Woooooool0=Oooo`040000<ol000000000Nooo
o`00JOooo`03o`2Ioooooooo03Goool00`0003?o0000001loooo001Yoooo00?o09Woooooool0=Ooo
o`030000<ol0000007coool006Woool00ol0VOooooooo`0eoooo00<0000co`000000O?ooo`00JOoo
o`03o`2Ioooooooo033oool200000oooo`030000<ol0000007coool006Woool00ol0VOooooooo`0_
oooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00JOooo`03o`2Ioooooooo037oool0
1P000?ooooooooooo`0003?o00<0001joooo001Yoooo00?o09Woooooool0<_ooo`060000oooooooo
0000<ol00000O?ooo`00JOooo`03o`2Ioooooooo02ooool010000?ooooooo`0000;oool00`0003?o
0000001loooo001Yoooo00?o09Woooooool0<?ooo`800004oooo0P0007coool006Woool00ol0VOoo
ooooo`0foooo0P0007coool006Woool00ol0VOooooooo`0foooo0P0007coool006Woool00ol0VOoo
ooooo`0foooo0P0007coool006Woool00ol0VOooooooo`0foooo0`0007_oool006Woool00ol0VOoo
ooooo`0foooo0P0007coool006Woool00ol0VOooooooo`0foooo0P0007coool006Woool00ol0VOoo
ooooo`0foooo0P0007coool006Woool00ol0VOooooooo`0foooo0P0007coool006Woool00ol0VOoo
ooooo`0foooo0P0007coool006Woool00ol0VOooooooo`0foooo0`0007_oool006Woool00ol0VOoo
ooooo`0foooo0P0007coool006Woool00ol0VOooooooo`0foooo0P0007coool006Woool00ol0VOoo
ooooo`0foooo0P0007coool006Woool00ol0VOooooooo`0foooo0P0007coool006Woool00ol0VOoo
ooooo`0foooo0P0007coool006Woool00ol0VOooooooo`0foooo0`0007_oool006Woool00ol0VOoo
ooooo`0goooo00<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`1j
oooo001Yoooo00?o09Woooooool0=oooo`030000oooooooo07[oool006Woool00ol0VOooooooo`0g
oooo00<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`1joooo001Y
oooo00?o09Woooooool0=oooo`80001koooo001Yoooo00?o09Woooooool0=oooo`030000oooooooo
07[oool006Woool00ol0VOooooooo`0goooo00<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo
03Ooool00`000?ooooooo`1joooo001Yoooo00?o09Woooooool0=oooo`030000oooooooo07[oool0
06Woool00ol0VOooooooo`0aoooo0`0000?oool00`000?ooooooo`1joooo001Yoooo00?o09Wooooo
ool0<_ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001Yoooo00?o09Woooooool0;ooo
o`D00003oooo0`0007[oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021
oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004
oooo0P0000?oool300001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_oo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000
oooooooo01Goool00`000?ooooooo`08oooo0`0000Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0001Goool00`000?ooooooo`06oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0`00
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.34309 .12361 L
.34772 .12361 L
.35028 .12361 L
.35271 .12361 L
.35496 .12361 L
.35624 .12361 L
s
.35624 .12361 m
.35671 .61803 L
s
0 .4 1 r
.02381 .12746 m
.04262 .12899 L
.06244 .13128 L
.07286 .13284 L
.08255 .13458 L
.09388 .13704 L
.10458 .13986 L
.125 .14699 L
.14357 .15617 L
.16355 .17009 L
.18199 .18817 L
.19101 .19943 L
.19339 .20271 L
.19598 .20646 L
.19717 .20823 L
.19844 .21012 L
.19963 .2101 L
.20071 .21008 L
.20627 .20999 L
.21136 .20989 L
.22134 .20967 L
.24058 .20913 L
.25143 .20873 L
.2614 .20828 L
.28023 .20719 L
.29092 .20639 L
.30089 .2055 L
.32124 .20309 L
.3398 .19998 L
.34461 .199 L
.34971 .19785 L
.35407 .19679 L
.35527 .19649 L
.35656 .19615 L
.35777 .12361 L
.35889 .12361 L
.36009 .12361 L
.36139 .12361 L
.36261 .12361 L
.36371 .12361 L
.36502 .12361 L
.36575 .12361 L
.36643 .12361 L
.36768 .12361 L
.369 .12361 L
.37026 .12361 L
.37097 .12361 L
.37162 .12361 L
.37287 .12361 L
.37407 .12361 L
Mistroke
.37474 .12361 L
.37545 .12361 L
.37674 .12361 L
.37752 .12361 L
.37826 .12361 L
.37899 .12361 L
.37965 .12361 L
.38081 .12361 L
.38206 .12361 L
.38322 .12361 L
.38432 .12361 L
.38559 .12361 L
.38677 .12361 L
.38806 .12361 L
.38872 .12361 L
.38943 .12361 L
.39009 .12361 L
.39077 .12361 L
.392 .12361 L
.39332 .12361 L
.39407 .12361 L
.39477 .12361 L
.39603 .12361 L
.39718 .12361 L
.39782 .12361 L
.39851 .12361 L
.39976 .12361 L
.40092 .12361 L
.40199 .12361 L
.40317 .12361 L
.40444 .12361 L
.40508 .12361 L
.40577 .12361 L
.40703 .12361 L
.40825 .12361 L
.40939 .12361 L
.41044 .12361 L
.41143 .12361 L
.41251 .12361 L
.41368 .12361 L
.41484 .12361 L
.41606 .12361 L
.41711 .12361 L
.41825 .12361 L
.41956 .12361 L
.42078 .12361 L
.42141 .12361 L
.42211 .12361 L
.42284 .12361 L
.42352 .12361 L
Mistroke
.42478 .12361 L
.42592 .12361 L
.42656 .12361 L
.42725 .12361 L
.42851 .12361 L
.42974 .12361 L
.43085 .12361 L
.43213 .12361 L
.43335 .12361 L
.43447 .12361 L
.4355 .12361 L
.43664 .12361 L
.43784 .12361 L
.43914 .12361 L
.44033 .12361 L
.44099 .12361 L
.4417 .12361 L
.443 .12361 L
.44422 .12361 L
.44551 .12361 L
.44661 .12361 L
.44782 .12361 L
.44851 .12361 L
.44924 .12361 L
.45054 .12361 L
.45127 .12361 L
.45194 .12361 L
.45268 .12361 L
.45347 .12361 L
.45416 .12361 L
.4549 .12361 L
.45561 .12361 L
.45625 .12361 L
.45748 .12361 L
.45878 .12361 L
.45999 .12361 L
.46131 .12361 L
.46256 .12361 L
.46371 .12361 L
.46486 .12361 L
.4659 .12361 L
.46703 .12361 L
.46822 .12361 L
.46953 .12361 L
.47074 .12361 L
.47203 .12361 L
.47277 .12361 L
.47345 .12361 L
.47469 .12361 L
.47583 .12361 L
Mistroke
.47713 .12361 L
.47837 .12361 L
.47942 .12361 L
.48058 .12361 L
.48171 .12361 L
.48293 .12361 L
.48407 .12361 L
.48511 .12361 L
.48615 .12361 L
.48715 .12361 L
.48829 .12361 L
.48951 .12361 L
.49066 .12361 L
.49171 .12361 L
.49294 .12361 L
.49363 .12361 L
.49427 .12361 L
.49544 .12361 L
.49668 .12361 L
.4979 .12361 L
.49859 .12361 L
.49923 .12361 L
.5004 .12361 L
.50164 .12361 L
.50267 .12361 L
.50379 .12361 L
.50501 .12361 L
.50616 .12361 L
.50739 .12361 L
.50809 .12361 L
.50874 .12361 L
.51005 .12361 L
.51079 .12361 L
.51145 .12361 L
.51265 .12361 L
.51395 .12361 L
.51518 .12361 L
.51631 .12361 L
.51737 .12361 L
.5185 .12361 L
.51957 .12361 L
.52055 .12361 L
.5217 .12361 L
.52294 .12361 L
.52412 .12361 L
.52522 .12361 L
.52645 .12361 L
.52761 .12361 L
.52865 .12361 L
.52978 .12361 L
Mistroke
.53101 .12361 L
.53232 .12361 L
.53343 .12361 L
.53464 .12361 L
.53595 .12361 L
.53716 .12361 L
.53779 .12361 L
.53849 .12361 L
.53922 .12361 L
.5399 .12361 L
.54115 .12361 L
.54229 .12361 L
.54355 .12361 L
.54487 .12361 L
.55418 .12361 L
.55547 .12361 L
.55669 .12361 L
.55736 .12361 L
.55809 .12361 L
.55937 .12361 L
.56058 .12361 L
.56187 .12361 L
.56297 .12361 L
.56418 .12361 L
.56491 .12361 L
.56561 .12361 L
.56691 .12361 L
.56763 .12361 L
.56831 .12361 L
.56904 .12361 L
.56983 .12361 L
.57047 .12361 L
.57116 .12361 L
.5724 .12361 L
.57369 .12361 L
.57443 .12361 L
.57511 .12361 L
.57631 .12361 L
.57761 .12361 L
.57885 .12361 L
.57998 .12361 L
.58102 .12361 L
.58215 .12361 L
.58446 .12361 L
.59455 .12361 L
.61281 .12361 L
.65311 .12361 L
.69189 .12361 L
.73312 .12361 L
.77284 .12361 L
Mistroke
.81104 .12361 L
.85169 .12361 L
.89083 .12361 L
.93242 .12361 L
.97249 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00D0003ooooo
ooooool0I_l01Oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`006Oooo`T0I_l8oooo00<0003oooooool09_ooo`030000oooooooo01Goool0
0`1Vooooooooo`0=oooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000
oooooooo02Koool00`000?ooooooo`0Yoooo000Roooo1@1VodCoool00`1Vooooooooo`0Joooo1000
01Lco`000`000?ooooooo`1joooo000Woooo0`1Vod7oool00`1Vooooooooo`0Noooo00<0000co`0c
o`0053?o00030000oooooooo07[oool002[oool406Ko?Oooo`0306Kooooooooo01ooool2000053?o
00030000oooooooo07[oool002koool306Ko>_ooo`0306Kooooooooo027oool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00<Oooo`80I_lhoooo00<0I_ooooooool08_ooo`030000<ol0<ol0
010co`020000Noooo`00<oooo`80I_lfoooo00<0I_ooooooool08oooo`80000@<ol000<0003ooooo
ool0N_ooo`00=Oooo`0306Kooooooooo03?oool00`1Vooooooooo`0Uoooo00<0000co`0co`003C?o
00030000oooooooo07[oool003Koool206Ko<oooo`0306Kooooooooo02Goool00`0003?o03?o000=
<ol000<0003oooooool0N_ooo`00>?ooo`80I_laoooo00<0I_ooooooool09_ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1joooo000joooo00<0I_ooooooool0;_ooo`0306Kooooooooo02Koool0
0`0003?o03?o000<<ol000<0003oooooool0N_ooo`00>oooo`0306Kooooooooo02goool00`1Voooo
ooooo`0Woooo00<0000co`0co`002c?o0080001koooo000loooo00<0I_ooooooool0;?ooo`0306Ko
oooooooo02Ooool00`0003?o03?o000;<ol000<0003oooooool0N_ooo`00??ooo`0306Kooooooooo
02coool00`1Vooooooooo`0Xoooo00<0000co`0co`002S?o00030000oooooooo07[oool003goool0
0`1Vooooooooo`0[oooo00<0I_ooooooool0:?ooo`030000<ol0<ol000Xco`000`000?ooooooo`1j
oooo000noooo00<0I_ooooooool0:_ooo`0306Kooooooooo02Woool00`0003?o03?o0009<ol000<0
003oooooool0N_ooo`00?oooo`0306Kooooooooo02Woool00`1Vooooooooo`0Yoooo00<0000co`0c
o`002C?o00030000oooooooo07[oool0043oool00`1Vooooooooo`0Voooo0`1Vobcoool00`0003?o
03?o0008<ol00P0007_oool0047oool00`1Vooooooooo`0Qoooo101Vo`;oool00ol0VOooooooo`0Z
oooo00<0000co`0co`0023?o00030000oooooooo07[oool004;oool00`1Vooooooooo`0Doooo301V
o`Koool00ol0VOooooooo`0Zoooo00<0000co`0co`0023?o00030000oooooooo07[oool004;ooolG
06Ko4_ooo`03o`2Ioooooooo02_oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Jooo
o`03o`2Ioooooooo02_oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Joooo`03o`2I
oooooooo02_oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo
02_oool00`0003?o03?o0007<ol00P0007_oool006_oool00ol0VOooooooo`0/oooo00<0000co`0c
o`001S?o00030000oooooooo07[oool006_oool00ol0VOooooooo`0/oooo00<0000co`0co`001S?o
00030000oooooooo07[oool006_oool00ol0VOooooooo`0/oooo00<0000co`0co`001S?o00030000
oooooooo07[oool006_oool00ol0VOooooooo`0/oooo00<0000co`0co`001S?o00030000oooooooo
07[oool006_oool00ol0VOooooooo`0]oooo1@0000<co`000`000?ooooooo`1joooo001[oooo00?o
09Woooooool0;Oooo`030000<ol0000000Dco`000`000?ooooooo`1joooo001[oooo00?o09Wooooo
ool0;Oooo`030000<ol0000000Dco`030000N_ooo`00Joooo`03o`2Ioooooooo02koool200001C?o
00030000oooooooo07[oool006_oool00ol0VOooooooo`0^oooo0P0000Dco`000`000?ooooooo`1j
oooo001[oooo00?o09Woooooool0;_ooo`800005<ol000<0003oooooool0N_ooo`00Joooo`03o`2I
oooooooo02koool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo
02koool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo02koool0
0`0003?o03?o0004<ol00P0007_oool006_oool00ol0VOooooooo`0_oooo00<0000co`0co`000c?o
00030000oooooooo07[oool006_oool00ol0VOooooooo`0_oooo00<0000co`0co`000c?o00030000
oooooooo07[oool006_oool00ol0VOooooooo`0_oooo00<0000co`0co`000c?o00030000oooooooo
07[oool006_oool00ol0VOooooooo`0_oooo00<0000co`0co`000c?o00030000oooooooo07[oool0
06_oool00ol0VOooooooo`0_oooo00<0000co`0co`000c?o00030000oooooooo07[oool006_oool0
0ol0VOooooooo`0_oooo00<0000co`0co`000c?o0080001koooo001[oooo00?o09Woooooool0;ooo
o`030000<ol0<ol000<co`000`000?ooooooo`1joooo001[oooo00?o09Woooooool0;oooo`030000
<ol0<ol000<co`000`000?ooooooo`1joooo001[oooo00?o09Woooooool0<?ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo001[oooo00?o09Woooooool0<?ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001[oooo00?o09Woooooool0<?ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo001[oooo00?o09Woooooool0<?ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001[oooo00?o09Woooooool0<?ooo`030000<ol0<ol0008co`020000Noooo`00Joooo`03o`2I
oooooooo033oool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo
033oool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo033oool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo033oool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo033oool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo033oool00`0003?o03?o0002<ol00P00
07_oool006_oool00ol0VOooooooo`0aoooo00D0000co`0co`0co`000000O?ooo`00Joooo`03o`2I
oooooooo037oool01@0003?o03?o03?o0000001loooo001[oooo00?o09Woooooool0<Oooo`050000
<ol0<ol0<ol0000007coool006_oool00ol0VOooooooo`0]oooo1@0000<co`000`000?ooooooo`1j
oooo001[oooo00?o09Woooooool0;Oooo`050000oooooooooooo000000<co`000`000?ooooooo`1j
oooo001[oooo00?o09Woooooool0;_ooo`040000oooooooo00000c?o00<0001joooo001[oooo00?o
09Woooooool0;oooo`030000oooo000000<co`000`000?ooooooo`1joooo001[oooo00?o09Wooooo
ool0;Oooo`030000oooooooo00800003<ol000<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo
02koool2000000?oool0000co`000S?o00030000oooooooo07[oool006_oool00ol0VOooooooo`0a
oooo00D0000co`0co`0co`000000O?ooo`00Joooo`03o`2Ioooooooo03;oool0100003?o03?o0000
07coool006_oool00ol0VOooooooo`0boooo00<0000co`0co`000P0007_oool006_oool00ol0VOoo
ooooo`0boooo00@0000co`0co`00001loooo001[oooo00?o09Woooooool0<_ooo`040000<ol0<ol0
0000O?ooo`00Joooo`03o`2Ioooooooo03;oool0100003?o03?o000007coool006_oool00ol0VOoo
ooooo`0boooo00@0000co`0co`00001loooo001[oooo00?o09Woooooool0<_ooo`040000<ol0<ol0
0000O?ooo`00Joooo`03o`2Ioooooooo03;oool0100003?o03?o000007coool006_oool00ol0VOoo
ooooo`0coooo00@0000co`000000001koooo001[oooo00?o09Woooooool0<oooo`030000<ol00000
07coool006_oool00ol0VOooooooo`0coooo00<0000co`000000O?ooo`00Joooo`03o`2Ioooooooo
03?oool00`0003?o0000001loooo001[oooo00?o09Woooooool0<oooo`030000<ol0000007coool0
06_oool00ol0VOooooooo`0coooo00<0000co`000000O?ooo`00Joooo`03o`2Ioooooooo03?oool0
100003?o0000000007_oool006_oool00ol0VOooooooo`0coooo00<0000co`000000O?ooo`00Jooo
o`03o`2Ioooooooo03?oool00`0003?o0000001loooo001[oooo00?o09Woooooool0<oooo`030000
<ol0000007coool006_oool00ol0VOooooooo`0coooo00<0000co`000000O?ooo`00Joooo`03o`2I
oooooooo03?oool00`0003?o0000001loooo001[oooo00?o09Woooooool0<oooo`040000<ol00000
0000Noooo`00Joooo`03o`2Ioooooooo03?oool00`0003?o0000001loooo001[oooo00?o09Wooooo
ool0<oooo`030000<ol0000007coool006_oool00ol0VOooooooo`0coooo00<0000co`000000O?oo
o`00Joooo`03o`2Ioooooooo02koool200000oooo`030000<ol0000007coool006_oool00ol0VOoo
ooooo`0]oooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00Joooo`03o`2Ioooooooo
02ooool01P000?ooooooooooo`0003?o00<0001joooo001[oooo00?o09Woooooool0<?ooo`060000
oooooooo0000<ol00000O?ooo`00Joooo`03o`2Ioooooooo02goool010000?ooooooo`0000;oool0
0`0003?o0000001loooo001[oooo00?o09Woooooool0;_ooo`800004oooo0P0007coool006_oool0
0ol0VOooooooo`0doooo0P0007coool006_oool00ol0VOooooooo`0doooo0P0007coool006_oool0
0ol0VOooooooo`0doooo0P0007coool006_oool00ol0VOooooooo`0doooo0`0007_oool006_oool0
0ol0VOooooooo`0doooo0P0007coool006_oool00ol0VOooooooo`0doooo0P0007coool006_oool0
0ol0VOooooooo`0doooo0P0007coool006_oool00ol0VOooooooo`0doooo0P0007coool006_oool0
0ol0VOooooooo`0doooo0P0007coool006_oool00ol0VOooooooo`0doooo0`0007_oool006_oool0
0ol0VOooooooo`0doooo0P0007coool006_oool00ol0VOooooooo`0doooo0P0007coool006_oool0
0ol0VOooooooo`0doooo0P0007coool006_oool00ol0VOooooooo`0doooo0P0007coool006_oool0
0ol0VOooooooo`0doooo0P0007coool006_oool00ol0VOooooooo`0doooo0`0007_oool006_oool0
0ol0VOooooooo`0eoooo00<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`1joooo001[oooo00?o09Woooooool0=Oooo`030000oooooooo07[oool006_oool00ol0VOoo
ooooo`0eoooo00<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo03Goool00`000?ooooooo`1j
oooo001[oooo00?o09Woooooool0=Oooo`80001koooo001[oooo00?o09Woooooool0=Oooo`030000
oooooooo07[oool006_oool00ol0VOooooooo`0eoooo00<0003oooooool0N_ooo`00Joooo`03o`2I
oooooooo03Goool00`000?ooooooo`1joooo001[oooo00?o09Woooooool0=Oooo`030000oooooooo
07[oool006_oool00ol0VOooooooo`0_oooo0`0000?oool00`000?ooooooo`1joooo001[oooo00?o
09Woooooool0<?ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001[oooo00?o09Wooooo
ool0;Oooo`D00003oooo0`0007[oool009_oool010000?ooooooo`00087oool009coool00`000?oo
o`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0001Goool00`000?ooooooo`07oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P00
00[oool200000oooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.35271 .12361 L
.35742 .12361 L
.36173 .12361 L
.36284 .12361 L
.36405 .12361 L
s
.36405 .12361 m
.36451 .61803 L
s
0 .4 1 r
.02381 .12695 m
.04262 .12828 L
.06244 .13027 L
.07286 .13162 L
.08255 .13314 L
.09388 .13527 L
.10458 .13772 L
.125 .14391 L
.14357 .15187 L
.16355 .16396 L
.18199 .17965 L
.19177 .19033 L
.19717 .19707 L
.2023 .2041 L
.2046 .20747 L
.20587 .20938 L
.20706 .21011 L
.20773 .2101 L
.20847 .21009 L
.20975 .21007 L
.21224 .21002 L
.22134 .20985 L
.24104 .20936 L
.25917 .20873 L
.278 .20782 L
.28868 .20716 L
.29866 .20641 L
.31901 .2044 L
.33757 .2018 L
.34682 .20016 L
.35665 .19808 L
.36178 .19684 L
.36318 .19648 L
.36392 .19629 L
.3647 .19609 L
.36538 .12361 L
.36613 .12361 L
.36744 .12361 L
.36875 .12361 L
.36994 .12361 L
.37059 .12361 L
.37131 .12361 L
.37261 .12361 L
.37382 .12361 L
.37511 .12361 L
.37621 .12361 L
.37741 .12361 L
.37871 .12361 L
.37991 .12361 L
.38064 .12361 L
Mistroke
.38134 .12361 L
.38263 .12361 L
.38378 .12361 L
.38502 .12361 L
.38567 .12361 L
.38635 .12361 L
.38758 .12361 L
.38868 .12361 L
.38987 .12361 L
.39099 .12361 L
.39201 .12361 L
.3932 .12361 L
.3945 .12361 L
.39573 .12361 L
.39686 .12361 L
.39806 .12361 L
.39935 .12361 L
.40057 .12361 L
.40168 .12361 L
.40292 .12361 L
.40362 .12361 L
.40427 .12361 L
.40559 .12361 L
.40633 .12361 L
.407 .12361 L
.40767 .12361 L
.40838 .12361 L
.40966 .12361 L
.41032 .12361 L
.41103 .12361 L
.41181 .12361 L
.41253 .12361 L
.41321 .12361 L
.41394 .12361 L
.41463 .12361 L
.41526 .12361 L
.41647 .12361 L
.41775 .12361 L
.41889 .12361 L
.42013 .12361 L
.42143 .12361 L
.42263 .12361 L
.42377 .12361 L
.4248 .12361 L
.42598 .12361 L
.42711 .12361 L
.42833 .12361 L
.42963 .12361 L
.43073 .12361 L
.43195 .12361 L
Mistroke
.43326 .12361 L
.43399 .12361 L
.43466 .12361 L
.43596 .12361 L
.4372 .12361 L
.43835 .12361 L
.43939 .12361 L
.4406 .12361 L
.44173 .12361 L
.44279 .12361 L
.44375 .12361 L
.44482 .12361 L
.44594 .12361 L
.44707 .12361 L
.44813 .12361 L
.44936 .12361 L
.45048 .12361 L
.45172 .12361 L
.45242 .12361 L
.45306 .12361 L
.45423 .12361 L
.45547 .12361 L
.45661 .12361 L
.45786 .12361 L
.45916 .12361 L
.46037 .12361 L
.4615 .12361 L
.46254 .12361 L
.46373 .12361 L
.46485 .12361 L
.46608 .12361 L
.46738 .12361 L
.4697 .12361 L
.471 .12361 L
.47224 .12361 L
.47292 .12361 L
.47366 .12361 L
.47496 .12361 L
.47609 .12361 L
.47729 .12361 L
.47843 .12361 L
.47946 .12361 L
.4805 .12361 L
.48163 .12361 L
.48269 .12361 L
.48367 .12361 L
.48482 .12361 L
.48589 .12361 L
.48707 .12361 L
.48833 .12361 L
Mistroke
.48965 .12361 L
.4909 .12361 L
.49202 .12361 L
.49324 .12361 L
.49445 .12361 L
.49559 .12361 L
.49691 .12361 L
.49811 .12361 L
.49924 .12361 L
.50029 .12361 L
.50145 .12361 L
.50268 .12361 L
.50333 .12361 L
.50402 .12361 L
.50478 .12361 L
.50548 .12361 L
.50674 .12361 L
.50746 .12361 L
.50813 .12361 L
.50937 .12361 L
.51051 .12361 L
.51183 .12361 L
.51307 .12361 L
.51428 .12361 L
.51496 .12361 L
.51561 .12361 L
.5169 .12361 L
.51763 .12361 L
.5183 .12361 L
.51943 .12361 L
.52066 .12361 L
.52194 .12361 L
.52314 .12361 L
.52382 .12361 L
.52457 .12361 L
.52527 .12361 L
.52591 .12361 L
.52714 .12361 L
.52844 .12361 L
.52911 .12361 L
.52983 .12361 L
.53113 .12361 L
.53193 .12361 L
.53268 .12361 L
.53336 .12361 L
.5341 .12361 L
.53475 .12361 L
.53543 .12361 L
.53666 .12361 L
.53798 .12361 L
Mistroke
.53872 .12361 L
.53942 .12361 L
.54069 .12361 L
.54184 .12361 L
.54248 .12361 L
.54318 .12361 L
.54444 .12361 L
.54548 .12361 L
.54658 .12361 L
.54778 .12361 L
.54889 .12361 L
.5501 .12361 L
.55079 .12361 L
.55142 .12361 L
.55265 .12361 L
.5538 .12361 L
.55444 .12361 L
.55514 .12361 L
.55636 .12361 L
.55705 .12361 L
.55778 .12361 L
.55909 .12361 L
.55976 .12361 L
.56047 .12361 L
.56176 .12361 L
.56255 .12361 L
.5633 .12361 L
.56397 .12361 L
.5647 .12361 L
.56591 .12361 L
.56659 .12361 L
.56724 .12361 L
.56854 .12361 L
.56927 .12361 L
.56994 .12361 L
.57106 .12361 L
.5723 .12361 L
.57358 .12361 L
.57478 .12361 L
.57605 .12361 L
.57669 .12361 L
.5774 .12361 L
.57865 .12361 L
.57982 .12361 L
.58052 .12361 L
.58119 .12361 L
.58245 .12361 L
.58528 .12361 L
.59521 .12361 L
.61378 .12361 L
Mistroke
.65198 .12361 L
.69264 .12361 L
.73177 .12361 L
.77336 .12361 L
.81344 .12361 L
.852 .12361 L
.89301 .12361 L
.9325 .12361 L
.97048 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool00oooo`0606Kooooooooooooo0000oooo4@000003<ol00000<ol000Pco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`0Eoooo000Ioooo2`1Vo`Koool00`000?ooooooo`0Voooo00<0003oooooool05ooo
o`0306Kooooooooo00_oool00`000?ooooooo`06oooo100001/co`000`000?ooooooo`0Uoooo00<0
003oooooool09_ooo`030000oooooooo02Woool002Coool606Ko@oooo`0306Kooooooooo01Soool4
00005c?o00030000oooooooo07[oool002[oool306Ko@?ooo`0306Kooooooooo01coool00`0003?o
03?o000D<ol000<0003oooooool0N_ooo`00;Oooo`80I_lnoooo00<0I_ooooooool07Oooo`80000D
<ol000<0003oooooool0N_ooo`00;oooo`<0I_lkoooo00<0I_ooooooool07oooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo000boooo0P1VocWoool00`1Vooooooooo`0Poooo00<0000co`0c
o`0043?o0080001koooo000doooo0P1VocOoool00`1Vooooooooo`0Qoooo0P00010co`000`000?oo
ooooo`1joooo000foooo0P1VocGoool00`1Vooooooooo`0Soooo00<0000co`0co`003C?o00030000
oooooooo07[oool003Soool206Ko<oooo`0306Kooooooooo02?oool00`0003?o03?o000=<ol000<0
003oooooool0N_ooo`00>_ooo`0306Kooooooooo033oool00`1Vooooooooo`0Toooo00<0000co`0c
o`0033?o00030000oooooooo07[oool003_oool00`1Vooooooooo`0_oooo00<0I_ooooooool09?oo
o`030000<ol0<ol000`co`000`000?ooooooo`1joooo000loooo00<0I_ooooooool0;_ooo`0306Ko
oooooooo02Goool00`0003?o03?o000;<ol00P0007_oool003goool00`1Vooooooooo`0]oooo00<0
I_ooooooool09Oooo`030000<ol0<ol000/co`000`000?ooooooo`1joooo000noooo00<0I_oooooo
ool0;?ooo`0306Kooooooooo02Koool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00?ooo
o`80I_l/oooo00<0I_ooooooool09_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo0011
oooo00<0I_ooooooool0:Oooo`0306Kooooooooo02Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0N_ooo`00@Oooo`0306Kooooooooo02Woool00`1Vooooooooo`0Woooo00<0000co`0co`002C?o
00030000oooooooo07[oool004;oool00`1Vooooooooo`0Uoooo101Vob[oool00`0003?o03?o0008
<ol00P0007_oool004;oool00`1Vooooooooo`0Ooooo1P1Vo`?oool00ol0VOooooooo`0Xoooo00<0
000co`0co`0023?o00030000oooooooo07[oool004?oool00`1Vooooooooo`0Eoooo2@1Vo`Woool0
0ol0VOooooooo`0Xoooo00<0000co`0co`0023?o00030000oooooooo07[oool004CooolG06Ko4_oo
o`03o`2Ioooooooo02Woool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00KOooo`03o`2I
oooooooo02Woool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo
02Woool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo02Woool0
0`0003?o03?o0007<ol00P0007_oool006goool00ol0VOooooooo`0Zoooo00<0000co`0co`001S?o
00030000oooooooo07[oool006goool00ol0VOooooooo`0Zoooo00<0000co`0co`001S?o00030000
oooooooo07[oool006goool00ol0VOooooooo`0Zoooo00<0000co`0co`001S?o00030000oooooooo
07[oool006goool00ol0VOooooooo`0Zoooo00<0000co`0co`001S?o00030000oooooooo07[oool0
06goool00ol0VOooooooo`0[oooo1@0000<co`000`000?ooooooo`1joooo001]oooo00?o09Wooooo
ool0:oooo`030000<ol0000000Dco`000`000?ooooooo`1joooo001]oooo00?o09Woooooool0:ooo
o`030000<ol0000000Dco`030000N_ooo`00KOooo`03o`2Ioooooooo02coool200001C?o00030000
oooooooo07[oool006goool00ol0VOooooooo`0/oooo0P0000Dco`000`000?ooooooo`1joooo001]
oooo00?o09Woooooool0;?ooo`800005<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo
02coool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo02coool0
0`0003?o03?o0004<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo02coool00`0003?o
03?o0004<ol00P0007_oool006goool00ol0VOooooooo`0]oooo00<0000co`0co`000c?o00030000
oooooooo07[oool006goool00ol0VOooooooo`0]oooo00<0000co`0co`000c?o00030000oooooooo
07[oool006goool00ol0VOooooooo`0]oooo00<0000co`0co`000c?o00030000oooooooo07[oool0
06goool00ol0VOooooooo`0]oooo00<0000co`0co`000c?o00030000oooooooo07[oool006goool0
0ol0VOooooooo`0]oooo00<0000co`0co`000c?o00030000oooooooo07[oool006goool00ol0VOoo
ooooo`0]oooo00<0000co`0co`000c?o0080001koooo001]oooo00?o09Woooooool0;Oooo`030000
<ol0<ol000<co`000`000?ooooooo`1joooo001]oooo00?o09Woooooool0;Oooo`030000<ol0<ol0
00<co`000`000?ooooooo`1joooo001]oooo00?o09Woooooool0;_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001]oooo00?o09Woooooool0;_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo001]oooo00?o09Woooooool0;_ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001]oooo00?o09Woooooool0;_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001]
oooo00?o09Woooooool0;_ooo`030000<ol0<ol0008co`020000Noooo`00KOooo`03o`2Ioooooooo
02koool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo02koool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo02koool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo02koool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo02koool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00KOooo`03o`2Ioooooooo02koool00`0003?o03?o0002<ol00P0007_oool0
06goool00ol0VOooooooo`0_oooo00D0000co`0co`0co`000000O?ooo`00KOooo`03o`2Ioooooooo
02ooool01@0003?o03?o03?o0000001loooo001]oooo00?o09Woooooool0;oooo`050000<ol0<ol0
<ol0000007coool006goool00ol0VOooooooo`0[oooo1@0000<co`000`000?ooooooo`1joooo001]
oooo00?o09Woooooool0:oooo`050000oooooooooooo000000<co`000`000?ooooooo`1joooo001]
oooo00?o09Woooooool0;?ooo`040000oooooooo00000c?o00<0001joooo001]oooo00?o09Wooooo
ool0;Oooo`030000oooo000000<co`000`000?ooooooo`1joooo001]oooo00?o09Woooooool0:ooo
o`030000oooooooo00800003<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo02coool2
000000?oool0000co`000S?o00030000oooooooo07[oool006goool00ol0VOooooooo`0_oooo00D0
000co`0co`0co`000000O?ooo`00KOooo`03o`2Ioooooooo033oool0100003?o03?o000007coool0
06goool00ol0VOooooooo`0`oooo00<0000co`0co`000P0007_oool006goool00ol0VOooooooo`0`
oooo00@0000co`0co`00001loooo001]oooo00?o09Woooooool0<?ooo`040000<ol0<ol00000O?oo
o`00KOooo`03o`2Ioooooooo033oool0100003?o03?o000007coool006goool00ol0VOooooooo`0`
oooo00@0000co`0co`00001loooo001]oooo00?o09Woooooool0<?ooo`040000<ol0<ol00000O?oo
o`00KOooo`03o`2Ioooooooo033oool0100003?o03?o000007coool006goool00ol0VOooooooo`0a
oooo00@0000co`000000001koooo001]oooo00?o09Woooooool0<Oooo`030000<ol0000007coool0
06goool00ol0VOooooooo`0aoooo00<0000co`000000O?ooo`00KOooo`03o`2Ioooooooo037oool0
0`0003?o0000001loooo001]oooo00?o09Woooooool0<Oooo`030000<ol0000007coool006goool0
0ol0VOooooooo`0aoooo00<0000co`000000O?ooo`00KOooo`03o`2Ioooooooo037oool0100003?o
0000000007_oool006goool00ol0VOooooooo`0aoooo00<0000co`000000O?ooo`00KOooo`03o`2I
oooooooo037oool00`0003?o0000001loooo001]oooo00?o09Woooooool0<Oooo`030000<ol00000
07coool006goool00ol0VOooooooo`0aoooo00<0000co`000000O?ooo`00KOooo`03o`2Ioooooooo
037oool00`0003?o0000001loooo001]oooo00?o09Woooooool0<Oooo`040000<ol000000000Nooo
o`00KOooo`03o`2Ioooooooo037oool00`0003?o0000001loooo001]oooo00?o09Woooooool0<Ooo
o`030000<ol0000007coool006goool00ol0VOooooooo`0aoooo00<0000co`000000O?ooo`00KOoo
o`03o`2Ioooooooo02coool200000oooo`030000<ol0000007coool006goool00ol0VOooooooo`0[
oooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00KOooo`03o`2Ioooooooo02goool0
1P000?ooooooooooo`0003?o00<0001joooo001]oooo00?o09Woooooool0;_ooo`060000oooooooo
0000<ol00000O?ooo`00KOooo`03o`2Ioooooooo02_oool010000?ooooooo`0000;oool00`0003?o
0000001loooo001]oooo00?o09Woooooool0;?ooo`800004oooo0P0007coool006goool00ol0VOoo
ooooo`0boooo0P0007coool006goool00ol0VOooooooo`0boooo0P0007coool006goool00ol0VOoo
ooooo`0boooo0P0007coool006goool00ol0VOooooooo`0boooo0`0007_oool006goool00ol0VOoo
ooooo`0boooo0P0007coool006goool00ol0VOooooooo`0boooo0P0007coool006goool00ol0VOoo
ooooo`0boooo0P0007coool006goool00ol0VOooooooo`0boooo0P0007coool006goool00ol0VOoo
ooooo`0boooo0P0007coool006goool00ol0VOooooooo`0boooo0`0007_oool006goool00ol0VOoo
ooooo`0boooo0P0007coool006goool00ol0VOooooooo`0boooo0P0007coool006goool00ol0VOoo
ooooo`0boooo0P0007coool006goool00ol0VOooooooo`0boooo0P0007coool006goool00ol0VOoo
ooooo`0boooo0P0007coool006goool00ol0VOooooooo`0boooo0`0007_oool006goool00ol0VOoo
ooooo`0coooo00<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo03?oool00`000?ooooooo`1j
oooo001]oooo00?o09Woooooool0<oooo`030000oooooooo07[oool006goool00ol0VOooooooo`0c
oooo00<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo03?oool00`000?ooooooo`1joooo001]
oooo00?o09Woooooool0<oooo`80001koooo001]oooo00?o09Woooooool0<oooo`030000oooooooo
07[oool006goool00ol0VOooooooo`0coooo00<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo
03?oool00`000?ooooooo`1joooo001]oooo00?o09Woooooool0<oooo`030000oooooooo07[oool0
06goool00ol0VOooooooo`0]oooo0`0000?oool00`000?ooooooo`1joooo001]oooo00?o09Wooooo
ool0;_ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001]oooo00?o09Woooooool0:ooo
o`D00003oooo0`0007[oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021
oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004
oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003ooooo
ool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Eoooo00<0003oooooool02Oooo`050000oooooooo
oooo000007[oool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002Ooo
o`@00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.36626 .12361 L
.36876 .12361 L
.37114 .12361 L
.37178 .12361 L
.37247 .12361 L
s
.37247 .12361 m
.37278 .61803 L
s
0 .4 1 r
.02381 .12651 m
.04262 .12767 L
.06244 .12939 L
.07286 .13057 L
.08255 .13188 L
.09388 .13373 L
.10458 .13586 L
.125 .14123 L
.14357 .14815 L
.16355 .15864 L
.18199 .17226 L
.2023 .19349 L
.2074 .20013 L
.20991 .20363 L
.21224 .20703 L
.21333 .20866 L
.21435 .21012 L
.21552 .2101 L
.21659 .21008 L
.22134 .21 L
.23957 .20961 L
.25917 .20903 L
.26894 .20865 L
.27925 .20818 L
.29772 .20708 L
.31736 .20543 L
.3357 .20327 L
.34615 .20169 L
.35605 .1999 L
.36494 .19799 L
.36737 .19741 L
.36996 .19677 L
.37102 .1965 L
.37217 .1962 L
.37342 .12361 L
.3746 .12361 L
.37586 .12361 L
.377 .12361 L
.37832 .12361 L
.37956 .12361 L
.38071 .12361 L
.38178 .12361 L
.38294 .12361 L
.38417 .12361 L
.38542 .12361 L
.38611 .12361 L
.38675 .12361 L
.38799 .12361 L
.38916 .12361 L
.39182 .12361 L
Mistroke
.39252 .12361 L
.39327 .12361 L
.39399 .12361 L
.39464 .12361 L
.39528 .12361 L
.39598 .12361 L
.39671 .12361 L
.39739 .12361 L
.3986 .12361 L
.39988 .12361 L
.40119 .12361 L
.40242 .12361 L
.40353 .12361 L
.40474 .12361 L
.40606 .12361 L
.40681 .12361 L
.40751 .12361 L
.40825 .12361 L
.40893 .12361 L
.40968 .12361 L
.41046 .12361 L
.41168 .12361 L
.41298 .12361 L
.41373 .12361 L
.41441 .12361 L
.4151 .12361 L
.41574 .12361 L
.4169 .12361 L
.41814 .12361 L
.41932 .12361 L
.42039 .12361 L
.42164 .12361 L
.42235 .12361 L
.42301 .12361 L
.42421 .12361 L
.42549 .12361 L
.42671 .12361 L
.42802 .12361 L
.42925 .12361 L
.43039 .12361 L
.43165 .12361 L
.43236 .12361 L
.43302 .12361 L
.43372 .12361 L
.43436 .12361 L
.4351 .12361 L
.4358 .12361 L
.43686 .12361 L
.43803 .12361 L
.43926 .12361 L
Mistroke
.4404 .12361 L
.44147 .12361 L
.44245 .12361 L
.44358 .12361 L
.44465 .12361 L
.44581 .12361 L
.44704 .12361 L
.4482 .12361 L
.44925 .12361 L
.45049 .12361 L
.45119 .12361 L
.45183 .12361 L
.45301 .12361 L
.45426 .12361 L
.45548 .12361 L
.45617 .12361 L
.45681 .12361 L
.45798 .12361 L
.45923 .12361 L
.46034 .12361 L
.46138 .12361 L
.46252 .12361 L
.46375 .12361 L
.46498 .12361 L
.46568 .12361 L
.46633 .12361 L
.46765 .12361 L
.46839 .12361 L
.46905 .12361 L
.47025 .12361 L
.47156 .12361 L
.47278 .12361 L
.47392 .12361 L
.47497 .12361 L
.47611 .12361 L
.47718 .12361 L
.47816 .12361 L
.47931 .12361 L
.48055 .12361 L
.48173 .12361 L
.48283 .12361 L
.48406 .12361 L
.48522 .12361 L
.48627 .12361 L
.48739 .12361 L
.48863 .12361 L
.48993 .12361 L
.49104 .12361 L
.49225 .12361 L
.49346 .12361 L
Mistroke
.49459 .12361 L
.49577 .12361 L
.49707 .12361 L
.49839 .12361 L
.49912 .12361 L
.4998 .12361 L
.50108 .12361 L
.50231 .12361 L
.50345 .12361 L
.50467 .12361 L
.50581 .12361 L
.50685 .12361 L
.50808 .12361 L
.50877 .12361 L
.50941 .12361 L
.51058 .12361 L
.51182 .12361 L
.51312 .12361 L
.51385 .12361 L
.51452 .12361 L
.51581 .12361 L
.51704 .12361 L
.51773 .12361 L
.51847 .12361 L
.51979 .12361 L
.52052 .12361 L
.52121 .12361 L
.52196 .12361 L
.52278 .12361 L
.52399 .12361 L
.52468 .12361 L
.52531 .12361 L
.52598 .12361 L
.52669 .12361 L
.52798 .12361 L
.52916 .12361 L
.53043 .12361 L
.53164 .12361 L
.53275 .12361 L
.534 .12361 L
.53519 .12361 L
.53626 .12361 L
.53742 .12361 L
.53868 .12361 L
.53939 .12361 L
.54002 .12361 L
.54127 .12361 L
.54244 .12361 L
.54354 .12361 L
.54471 .12361 L
Mistroke
.5457 .12361 L
.5468 .12361 L
.54797 .12361 L
.54923 .12361 L
.55042 .12361 L
.5515 .12361 L
.55279 .12361 L
.55343 .12361 L
.55415 .12361 L
.5554 .12361 L
.55659 .12361 L
.55726 .12361 L
.55797 .12361 L
.55924 .12361 L
.55995 .12361 L
.56061 .12361 L
.56134 .12361 L
.56211 .12361 L
.56341 .12361 L
.56414 .12361 L
.56481 .12361 L
.56605 .12361 L
.56737 .12361 L
.56854 .12361 L
.56964 .12361 L
.57085 .12361 L
.57214 .12361 L
.57335 .12361 L
.57405 .12361 L
.57469 .12361 L
.576 .12361 L
.57667 .12361 L
.57741 .12361 L
.57865 .12361 L
.57996 .12361 L
.58117 .12361 L
.58229 .12361 L
.59335 .12361 L
.61346 .12361 L
.65246 .12361 L
.69391 .12361 L
.73385 .12361 L
.77227 .12361 L
.81314 .12361 L
.8525 .12361 L
.89035 .12361 L
.93064 .12361 L
.96942 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00D0I_l2
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Goool0101Vooooo`000?oooa4000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`007_ooo`H0I_l6oooo00<0003oooooool09_ooo`030000oooooooo01Woool0
0`1Vooooooooo`09oooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000
oooooooo02Koool00`000?ooooooo`0Yoooo000Toooo1P1VodGoool00`1Vooooooooo`0Foooo1000
01Lco`000`000?ooooooo`1joooo000Zoooo101Vod7oool00`1Vooooooooo`0Joooo00<0000co`0c
o`0053?o00030000oooooooo07[oool002koool406Ko?Oooo`0306Kooooooooo01_oool2000053?o
00030000oooooooo07[oool003;oool206Ko>oooo`0306Kooooooooo01goool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00=?ooo`<0I_lhoooo00<0I_ooooooool07_ooo`030000<ol0<ol0
010co`020000Noooo`00=oooo`80I_lfoooo00<0I_ooooooool07oooo`80000@<ol000<0003ooooo
ool0N_ooo`00>Oooo`80I_ldoooo00<0I_ooooooool08Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1joooo000koooo00<0I_ooooooool0<Oooo`0306Kooooooooo027oool00`0003?o03?o000=
<ol000<0003oooooool0N_ooo`00??ooo`0306Kooooooooo033oool00`1Vooooooooo`0Roooo00<0
000co`0co`0033?o00030000oooooooo07[oool003goool00`1Vooooooooo`0_oooo00<0I_oooooo
ool08_ooo`030000<ol0<ol000`co`000`000?ooooooo`1joooo000noooo00<0I_ooooooool0;_oo
o`0306Kooooooooo02?oool00`0003?o03?o000;<ol00P0007_oool003ooool00`1Vooooooooo`0]
oooo00<0I_ooooooool08oooo`030000<ol0<ol000/co`000`000?ooooooo`1joooo0010oooo00<0
I_ooooooool0;?ooo`0306Kooooooooo02Coool00`0003?o03?o000:<ol000<0003oooooool0N_oo
o`00@Oooo`0306Kooooooooo02_oool00`1Vooooooooo`0Toooo00<0000co`0co`002S?o00030000
oooooooo07[oool004;oool00`1Vooooooooo`0Zoooo00<0I_ooooooool09Oooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1joooo0013oooo00<0I_ooooooool0:Oooo`0306Kooooooooo02Goool0
0`0003?o03?o0009<ol000<0003oooooool0N_ooo`00A?ooo`0306Kooooooooo02Goool406Ko:?oo
o`030000<ol0<ol000Pco`020000Noooo`00AOooo`0306Kooooooooo01ooool506Ko0oooo`03o`2I
oooooooo02Koool00`0003?o03?o0008<ol000<0003oooooool0N_ooo`00AOooo`0306Kooooooooo
01Ooool806Ko2?ooo`03o`2Ioooooooo02Koool00`0003?o03?o0008<ol000<0003oooooool0N_oo
o`00A_oooaT0I_l@oooo00?o09Woooooool09oooo`030000<ol0<ol000Lco`000`000?ooooooo`1j
oooo001_oooo00?o09Woooooool09oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo001_
oooo00?o09Woooooool09oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo001_oooo00?o
09Woooooool09oooo`030000<ol0<ol000Lco`020000Noooo`00Koooo`03o`2Ioooooooo02Soool0
0`0003?o03?o0006<ol000<0003oooooool0N_ooo`00Koooo`03o`2Ioooooooo02Soool00`0003?o
03?o0006<ol000<0003oooooool0N_ooo`00Koooo`03o`2Ioooooooo02Soool00`0003?o03?o0006
<ol000<0003oooooool0N_ooo`00Koooo`03o`2Ioooooooo02Soool00`0003?o03?o0006<ol000<0
003oooooool0N_ooo`00Koooo`03o`2Ioooooooo02Woool500000c?o00030000oooooooo07[oool0
06ooool00ol0VOooooooo`0Yoooo00<0000co`0000001C?o00030000oooooooo07[oool006ooool0
0ol0VOooooooo`0Yoooo00<0000co`0000001C?o00<0001joooo001_oooo00?o09Woooooool0:_oo
o`800005<ol000<0003oooooool0N_ooo`00Koooo`03o`2Ioooooooo02[oool200001C?o00030000
oooooooo07[oool006ooool00ol0VOooooooo`0Zoooo0P0000Dco`000`000?ooooooo`1joooo001_
oooo00?o09Woooooool0:_ooo`030000<ol0<ol000@co`000`000?ooooooo`1joooo001_oooo00?o
09Woooooool0:_ooo`030000<ol0<ol000@co`000`000?ooooooo`1joooo001_oooo00?o09Wooooo
ool0:_ooo`030000<ol0<ol000@co`020000Noooo`00Koooo`03o`2Ioooooooo02_oool00`0003?o
03?o0003<ol000<0003oooooool0N_ooo`00Koooo`03o`2Ioooooooo02_oool00`0003?o03?o0003
<ol000<0003oooooool0N_ooo`00Koooo`03o`2Ioooooooo02_oool00`0003?o03?o0003<ol000<0
003oooooool0N_ooo`00Koooo`03o`2Ioooooooo02_oool00`0003?o03?o0003<ol000<0003ooooo
ool0N_ooo`00Koooo`03o`2Ioooooooo02_oool00`0003?o03?o0003<ol000<0003oooooool0N_oo
o`00Koooo`03o`2Ioooooooo02_oool00`0003?o03?o0003<ol00P0007_oool006ooool00ol0VOoo
ooooo`0[oooo00<0000co`0co`000c?o00030000oooooooo07[oool006ooool00ol0VOooooooo`0[
oooo00<0000co`0co`000c?o00030000oooooooo07[oool006ooool00ol0VOooooooo`0/oooo00<0
000co`0co`000S?o00030000oooooooo07[oool006ooool00ol0VOooooooo`0/oooo00<0000co`0c
o`000S?o00030000oooooooo07[oool006ooool00ol0VOooooooo`0/oooo00<0000co`0co`000S?o
00030000oooooooo07[oool006ooool00ol0VOooooooo`0/oooo00<0000co`0co`000S?o00030000
oooooooo07[oool006ooool00ol0VOooooooo`0/oooo00<0000co`0co`000S?o0080001koooo001_
oooo00?o09Woooooool0;?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001_oooo00?o
09Woooooool0;?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001_oooo00?o09Wooooo
ool0;?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001_oooo00?o09Woooooool0;?oo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo001_oooo00?o09Woooooool0;?ooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo001_oooo00?o09Woooooool0;?ooo`030000<ol0<ol0
008co`020000Noooo`00Koooo`03o`2Ioooooooo02goool01@0003?o03?o03?o0000001loooo001_
oooo00?o09Woooooool0;Oooo`050000<ol0<ol0<ol0000007coool006ooool00ol0VOooooooo`0]
oooo00D0000co`0co`0co`000000O?ooo`00Koooo`03o`2Ioooooooo02Woool500000c?o00030000
oooooooo07[oool006ooool00ol0VOooooooo`0Yoooo00D0003oooooooooool000000c?o00030000
oooooooo07[oool006ooool00ol0VOooooooo`0Zoooo00@0003oooooool00003<ol00`0007[oool0
06ooool00ol0VOooooooo`0[oooo00<0003oool000000c?o00030000oooooooo07[oool006ooool0
0ol0VOooooooo`0Yoooo00<0003oooooool00P0000<co`000`000?ooooooo`1joooo001_oooo00?o
09Woooooool0:_ooo`8000000oooo`0003?o0002<ol000<0003oooooool0N_ooo`00Koooo`03o`2I
oooooooo02goool01@0003?o03?o03?o0000001loooo001_oooo00?o09Woooooool0;_ooo`040000
<ol0<ol00000O?ooo`00Koooo`03o`2Ioooooooo02koool00`0003?o03?o00020000Noooo`00Kooo
o`03o`2Ioooooooo02koool0100003?o03?o000007coool006ooool00ol0VOooooooo`0^oooo00@0
000co`0co`00001loooo001_oooo00?o09Woooooool0;_ooo`040000<ol0<ol00000O?ooo`00Kooo
o`03o`2Ioooooooo02koool0100003?o03?o000007coool006ooool00ol0VOooooooo`0^oooo00@0
000co`0co`00001loooo001_oooo00?o09Woooooool0;_ooo`040000<ol0<ol00000O?ooo`00Kooo
o`03o`2Ioooooooo02ooool0100003?o0000000007_oool006ooool00ol0VOooooooo`0_oooo00<0
000co`000000O?ooo`00Koooo`03o`2Ioooooooo02ooool00`0003?o0000001loooo001_oooo00?o
09Woooooool0;oooo`030000<ol0000007coool006ooool00ol0VOooooooo`0_oooo00<0000co`00
0000O?ooo`00Koooo`03o`2Ioooooooo02ooool00`0003?o0000001loooo001_oooo00?o09Wooooo
ool0;oooo`040000<ol000000000Noooo`00Koooo`03o`2Ioooooooo02ooool00`0003?o0000001l
oooo001_oooo00?o09Woooooool0;oooo`030000<ol0000007coool006ooool00ol0VOooooooo`0_
oooo00<0000co`000000O?ooo`00Koooo`03o`2Ioooooooo02ooool00`0003?o0000001loooo001_
oooo00?o09Woooooool0;oooo`030000<ol0000007coool006ooool00ol0VOooooooo`0_oooo00@0
000co`000000001koooo001_oooo00?o09Woooooool0;oooo`030000<ol0000007coool006ooool0
0ol0VOooooooo`0_oooo00<0000co`000000O?ooo`00Koooo`03o`2Ioooooooo02ooool00`0003?o
0000001loooo001_oooo00?o09Woooooool0:_ooo`800003oooo00<0000co`000000O?ooo`00Kooo
o`03o`2Ioooooooo02Woool010000?ooooooo`0000;oool00`0003?o0000001loooo001_oooo00?o
09Woooooool0:oooo`060000oooooooooooo0000<ol00`0007[oool006ooool00ol0VOooooooo`0/
oooo00H0003oooooool0000co`00001loooo001_oooo00?o09Woooooool0:Oooo`040000oooooooo
00000_ooo`030000<ol0000007coool006ooool00ol0VOooooooo`0Zoooo0P0000Coool20000O?oo
o`00Koooo`03o`2Ioooooooo033oool20000O?ooo`00Koooo`03o`2Ioooooooo033oool20000O?oo
o`00Koooo`03o`2Ioooooooo033oool20000O?ooo`00Koooo`03o`2Ioooooooo033oool30000Nooo
o`00Koooo`03o`2Ioooooooo033oool20000O?ooo`00Koooo`03o`2Ioooooooo033oool20000O?oo
o`00Koooo`03o`2Ioooooooo033oool20000O?ooo`00Koooo`03o`2Ioooooooo033oool20000O?oo
o`00Koooo`03o`2Ioooooooo033oool20000O?ooo`00Koooo`03o`2Ioooooooo033oool30000Nooo
o`00Koooo`03o`2Ioooooooo033oool20000O?ooo`00Koooo`03o`2Ioooooooo033oool20000O?oo
o`00Koooo`03o`2Ioooooooo033oool20000O?ooo`00Koooo`03o`2Ioooooooo033oool20000O?oo
o`00Koooo`03o`2Ioooooooo033oool20000O?ooo`00Koooo`03o`2Ioooooooo033oool30000Nooo
o`00Koooo`03o`2Ioooooooo037oool00`000?ooooooo`1joooo001_oooo00?o09Woooooool0<Ooo
o`030000oooooooo07[oool006ooool00ol0VOooooooo`0aoooo00<0003oooooool0N_ooo`00Kooo
o`03o`2Ioooooooo037oool00`000?ooooooo`1joooo001_oooo00?o09Woooooool0<Oooo`030000
oooooooo07[oool006ooool00ol0VOooooooo`0aoooo0P0007_oool006ooool00ol0VOooooooo`0a
oooo00<0003oooooool0N_ooo`00Koooo`03o`2Ioooooooo037oool00`000?ooooooo`1joooo001_
oooo00?o09Woooooool0<Oooo`030000oooooooo07[oool006ooool00ol0VOooooooo`0aoooo00<0
003oooooool0N_ooo`00Koooo`03o`2Ioooooooo02_oool300000oooo`030000oooooooo07[oool0
06ooool00ol0VOooooooo`0/oooo00<0003oooooool00_ooo`030000oooooooo07[oool006ooool0
0ol0VOooooooo`0Yoooo1@0000?oool30000N_ooo`00Voooo`040000oooooooo0000POooo`00W?oo
o`030000oooo0000087oool009goool20000POooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`0=oooo0P0000Coool200000oooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool01oooo`040000oooooooo00001?oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005Oooo`030000oooooooo00Koool3
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00009oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0G
oooo0P0000[oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.37114 .12361 L
.37372 .12361 L
.37649 .12361 L
.37783 .12361 L
.3791 .12361 L
.38025 .12361 L
s
.38025 .12361 m
.38075 .61803 L
s
0 .4 1 r
.02381 .12613 m
.04262 .12713 L
.06244 .12863 L
.07286 .12965 L
.08255 .13079 L
.09388 .13239 L
.10458 .13424 L
.125 .13891 L
.14357 .14491 L
.16355 .15402 L
.18199 .16585 L
.20071 .18258 L
.21136 .1949 L
.21653 .20178 L
.21905 .20537 L
.22134 .20877 L
.22257 .21011 L
.22374 .21009 L
.2263 .21005 L
.23172 .20996 L
.24158 .20975 L
.26011 .20926 L
.28019 .20851 L
.29866 .20753 L
.31748 .20615 L
.32817 .20513 L
.33815 .20399 L
.3585 .20092 L
.3675 .19917 L
.37243 .19808 L
.37706 .19697 L
.37932 .19639 L
.3806 .19606 L
.38177 .12361 L
.38298 .12361 L
.38366 .12361 L
.3843 .12361 L
.38559 .12361 L
.38631 .12361 L
.38697 .12361 L
.38815 .12361 L
.38923 .12361 L
.39043 .12361 L
.39169 .12361 L
.39278 .12361 L
.39381 .12361 L
.39493 .12361 L
.39614 .12361 L
.39681 .12361 L
.39752 .12361 L
Mistroke
.3988 .12361 L
.39959 .12361 L
.40033 .12361 L
.40099 .12361 L
.40171 .12361 L
.40235 .12361 L
.40305 .12361 L
.40378 .12361 L
.40446 .12361 L
.40568 .12361 L
.40699 .12361 L
.40827 .12361 L
.40899 .12361 L
.40966 .12361 L
.41088 .12361 L
.41218 .12361 L
.41334 .12361 L
.41442 .12361 L
.41562 .12361 L
.4169 .12361 L
.41816 .12361 L
.41931 .12361 L
.42063 .12361 L
.42188 .12361 L
.42295 .12361 L
.4241 .12361 L
.42535 .12361 L
.4265 .12361 L
.42774 .12361 L
.42844 .12361 L
.42908 .12361 L
.43032 .12361 L
.43149 .12361 L
.43215 .12361 L
.43286 .12361 L
.43412 .12361 L
.43482 .12361 L
.43548 .12361 L
.4362 .12361 L
.43698 .12361 L
.43762 .12361 L
.43831 .12361 L
.43954 .12361 L
.44029 .12361 L
.44101 .12361 L
.44165 .12361 L
.44234 .12361 L
.44302 .12361 L
.44377 .12361 L
.44455 .12361 L
Mistroke
.44528 .12361 L
.44659 .12361 L
.44732 .12361 L
.44799 .12361 L
.44928 .12361 L
.45047 .12361 L
.45178 .12361 L
.45251 .12361 L
.45317 .12361 L
.45439 .12361 L
.45571 .12361 L
.45695 .12361 L
.45809 .12361 L
.45936 .12361 L
.46056 .12361 L
.46163 .12361 L
.4628 .12361 L
.46407 .12361 L
.46471 .12361 L
.46542 .12361 L
.46667 .12361 L
.46784 .12361 L
.46895 .12361 L
.47012 .12361 L
.47112 .12361 L
.47222 .12361 L
.4734 .12361 L
.47466 .12361 L
.47585 .12361 L
.47693 .12361 L
.47822 .12361 L
.47887 .12361 L
.47959 .12361 L
.48085 .12361 L
.48204 .12361 L
.48275 .12361 L
.48343 .12361 L
.4847 .12361 L
.48541 .12361 L
.48607 .12361 L
.4868 .12361 L
.48757 .12361 L
.48887 .12361 L
.48961 .12361 L
.49028 .12361 L
.49152 .12361 L
.49283 .12361 L
.49401 .12361 L
.49511 .12361 L
.49631 .12361 L
Mistroke
.4976 .12361 L
.49883 .12361 L
.49952 .12361 L
.50018 .12361 L
.50149 .12361 L
.50223 .12361 L
.50291 .12361 L
.50411 .12361 L
.50542 .12361 L
.50666 .12361 L
.50781 .12361 L
.50851 .12361 L
.50926 .12361 L
.50997 .12361 L
.51062 .12361 L
.51186 .12361 L
.51318 .12361 L
.51386 .12361 L
.51459 .12361 L
.5159 .12361 L
.51671 .12361 L
.51747 .12361 L
.51815 .12361 L
.5189 .12361 L
.52014 .12361 L
.52131 .12361 L
.52259 .12361 L
.52331 .12361 L
.52397 .12361 L
.52522 .12361 L
.52593 .12361 L
.52659 .12361 L
.52729 .12361 L
.52793 .12361 L
.52866 .12361 L
.52936 .12361 L
.53053 .12361 L
.53177 .12361 L
.53283 .12361 L
.534 .12361 L
.53525 .12361 L
.53596 .12361 L
.5366 .12361 L
.53785 .12361 L
.53903 .12361 L
.54028 .12361 L
.54099 .12361 L
.54163 .12361 L
.54282 .12361 L
.54407 .12361 L
Mistroke
.5452 .12361 L
.54625 .12361 L
.54741 .12361 L
.54864 .12361 L
.54996 .12361 L
.5507 .12361 L
.55139 .12361 L
.55265 .12361 L
.5533 .12361 L
.55399 .12361 L
.55519 .12361 L
.55631 .12361 L
.55696 .12361 L
.55765 .12361 L
.55887 .12361 L
.56003 .12361 L
.56107 .12361 L
.56228 .12361 L
.56343 .12361 L
.56448 .12361 L
.56546 .12361 L
.56653 .12361 L
.56766 .12361 L
.56879 .12361 L
.56987 .12361 L
.57111 .12361 L
.57224 .12361 L
.57348 .12361 L
.57419 .12361 L
.57484 .12361 L
.57601 .12361 L
.57727 .12361 L
.5784 .12361 L
.57964 .12361 L
.58094 .12361 L
.58214 .12361 L
.58662 .12361 L
.5967 .12361 L
.61497 .12361 L
.65397 .12361 L
.69543 .12361 L
.73536 .12361 L
.77379 .12361 L
.81466 .12361 L
.85402 .12361 L
.89186 .12361 L
.93216 .12361 L
.97094 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00D0I_l2
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool001koool906Ko0oooo`030000oooooooo02Koool00`000?ooooooo`0Koooo00<0
I_ooooooool01oooo`030000oooooooo00Koool400006c?o00030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0003oooooool0:Oooo`009oooo`L0I_m3oooo00<0I_ooooooool05?ooo`@0000G
<ol000<0003oooooool0N_ooo`00;_ooo`@0I_looooo00<0I_ooooooool06?ooo`030000<ol0<ol0
01@co`000`000?ooooooo`1joooo000boooo0P1Vocgoool00`1Vooooooooo`0Ioooo0P0001@co`00
0`000?ooooooo`1joooo000doooo0`1Voc[oool00`1Vooooooooo`0Koooo00<0000co`0co`004C?o
00030000oooooooo07[oool003Ooool206Ko>?ooo`0306Kooooooooo01coool00`0003?o03?o000@
<ol00P0007_oool003Woool206Ko=_ooo`0306Kooooooooo01goool2000043?o00030000oooooooo
07[oool003_oool00`1Vooooooooo`0coooo00<0I_ooooooool07oooo`030000<ol0<ol000dco`00
0`000?ooooooo`1joooo000loooo0P1Voc?oool00`1Vooooooooo`0Ooooo00<0000co`0co`003C?o
00030000oooooooo07[oool003koool00`1Vooooooooo`0`oooo00<0I_ooooooool08?ooo`030000
<ol0<ol000`co`000`000?ooooooo`1joooo000ooooo00<0I_ooooooool0;oooo`0306Kooooooooo
023oool00`0003?o03?o000<<ol000<0003oooooool0N_ooo`00@?ooo`80I_l_oooo00<0I_oooooo
ool08Oooo`030000<ol0<ol000/co`020000Noooo`00@_ooo`0306Kooooooooo02coool00`1Voooo
ooooo`0Qoooo00<0000co`0co`002c?o00030000oooooooo07[oool004?oool00`1Vooooooooo`0[
oooo00<0I_ooooooool08_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo0014oooo00<0
I_ooooooool0:_ooo`0306Kooooooooo02;oool00`0003?o03?o000:<ol000<0003oooooool0N_oo
o`00AOooo`0306Kooooooooo02Woool00`1Vooooooooo`0Soooo00<0000co`0co`002C?o00030000
oooooooo07[oool004Koool00`1Vooooooooo`0Xoooo00<0I_ooooooool08oooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1joooo0016oooo00<0I_ooooooool09_ooo`<0I_lVoooo00<0000co`0c
o`0023?o0080001koooo0017oooo00<0I_ooooooool07oooo`H0I_l2oooo00?o09Woooooool09?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`1joooo0018oooo00<0I_ooooooool05?ooo`X0I_l8
oooo00?o09Woooooool09?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1joooo0018oooo5`1V
oa;oool00ol0VOooooooo`0Uoooo00<0000co`0co`001c?o00030000oooooooo07[oool0077oool0
0ol0VOooooooo`0Uoooo00<0000co`0co`001c?o00030000oooooooo07[oool0077oool00ol0VOoo
ooooo`0Uoooo00<0000co`0co`001c?o00030000oooooooo07[oool0077oool00ol0VOooooooo`0U
oooo00<0000co`0co`001c?o0080001koooo001aoooo00?o09Woooooool09_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`1joooo001aoooo00?o09Woooooool09_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1joooo001aoooo00?o09Woooooool09_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1joooo001aoooo00?o09Woooooool09_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1j
oooo001aoooo00?o09Woooooool09oooo`D00003<ol000<0003oooooool0N_ooo`00LOooo`03o`2I
oooooooo02Ooool00`0003?o00000005<ol000<0003oooooool0N_ooo`00LOooo`03o`2Ioooooooo
02Ooool00`0003?o00000005<ol00`0007[oool0077oool00ol0VOooooooo`0Xoooo0P0000Dco`00
0`000?ooooooo`1joooo001aoooo00?o09Woooooool0:?ooo`800005<ol000<0003oooooool0N_oo
o`00LOooo`03o`2Ioooooooo02Soool200001C?o00030000oooooooo07[oool0077oool00ol0VOoo
ooooo`0Xoooo00<0000co`0co`0013?o00030000oooooooo07[oool0077oool00ol0VOooooooo`0X
oooo00<0000co`0co`0013?o00030000oooooooo07[oool0077oool00ol0VOooooooo`0Xoooo00<0
000co`0co`0013?o0080001koooo001aoooo00?o09Woooooool0:Oooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo001aoooo00?o09Woooooool0:Oooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo001aoooo00?o09Woooooool0:Oooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo001aoooo00?o09Woooooool0:Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001a
oooo00?o09Woooooool0:Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001aoooo00?o
09Woooooool0:Oooo`030000<ol0<ol000<co`020000Noooo`00LOooo`03o`2Ioooooooo02Woool0
0`0003?o03?o0003<ol000<0003oooooool0N_ooo`00LOooo`03o`2Ioooooooo02Woool00`0003?o
03?o0003<ol000<0003oooooool0N_ooo`00LOooo`03o`2Ioooooooo02[oool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00LOooo`03o`2Ioooooooo02[oool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00LOooo`03o`2Ioooooooo02[oool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00LOooo`03o`2Ioooooooo02[oool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00LOooo`03o`2Ioooooooo02[oool00`0003?o03?o0002<ol00P0007_oool0077oool00ol0VOoo
ooooo`0Zoooo00<0000co`0co`000S?o00030000oooooooo07[oool0077oool00ol0VOooooooo`0Z
oooo00<0000co`0co`000S?o00030000oooooooo07[oool0077oool00ol0VOooooooo`0Zoooo00<0
000co`0co`000S?o00030000oooooooo07[oool0077oool00ol0VOooooooo`0Zoooo00<0000co`0c
o`000S?o00030000oooooooo07[oool0077oool00ol0VOooooooo`0Zoooo00<0000co`0co`000S?o
00030000oooooooo07[oool0077oool00ol0VOooooooo`0Zoooo00<0000co`0co`000S?o0080001k
oooo001aoooo00?o09Woooooool0:oooo`050000<ol0<ol0<ol0000007coool0077oool00ol0VOoo
ooooo`0[oooo00D0000co`0co`0co`000000O?ooo`00LOooo`03o`2Ioooooooo02_oool01@0003?o
03?o03?o0000001loooo001aoooo00?o09Woooooool09oooo`D00003<ol000<0003oooooool0N_oo
o`00LOooo`03o`2Ioooooooo02Ooool01@000?ooooooooooo`000003<ol000<0003oooooool0N_oo
o`00LOooo`03o`2Ioooooooo02Soool010000?ooooooo`0000<co`030000N_ooo`00LOooo`03o`2I
oooooooo02Woool00`000?ooo`000003<ol000<0003oooooool0N_ooo`00LOooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`0200000c?o00030000oooooooo07[oool0077oool00ol0VOooooooo`0X
oooo0P000003oooo0000<ol0008co`000`000?ooooooo`1joooo001aoooo00?o09Woooooool0:ooo
o`050000<ol0<ol0<ol0000007coool0077oool00ol0VOooooooo`0/oooo00@0000co`0co`00001l
oooo001aoooo00?o09Woooooool0;?ooo`030000<ol0<ol00080001koooo001aoooo00?o09Wooooo
ool0;?ooo`040000<ol0<ol00000O?ooo`00LOooo`03o`2Ioooooooo02coool0100003?o03?o0000
07coool0077oool00ol0VOooooooo`0/oooo00@0000co`0co`00001loooo001aoooo00?o09Wooooo
ool0;?ooo`040000<ol0<ol00000O?ooo`00LOooo`03o`2Ioooooooo02coool0100003?o03?o0000
07coool0077oool00ol0VOooooooo`0/oooo00@0000co`0co`00001loooo001aoooo00?o09Wooooo
ool0;Oooo`040000<ol000000000Noooo`00LOooo`03o`2Ioooooooo02goool00`0003?o0000001l
oooo001aoooo00?o09Woooooool0;Oooo`030000<ol0000007coool0077oool00ol0VOooooooo`0]
oooo00<0000co`000000O?ooo`00LOooo`03o`2Ioooooooo02goool00`0003?o0000001loooo001a
oooo00?o09Woooooool0;Oooo`030000<ol0000007coool0077oool00ol0VOooooooo`0]oooo00@0
000co`000000001koooo001aoooo00?o09Woooooool0;Oooo`030000<ol0000007coool0077oool0
0ol0VOooooooo`0]oooo00<0000co`000000O?ooo`00LOooo`03o`2Ioooooooo02goool00`0003?o
0000001loooo001aoooo00?o09Woooooool0;Oooo`030000<ol0000007coool0077oool00ol0VOoo
ooooo`0]oooo00<0000co`000000O?ooo`00LOooo`03o`2Ioooooooo02goool0100003?o00000000
07_oool0077oool00ol0VOooooooo`0]oooo00<0000co`000000O?ooo`00LOooo`03o`2Ioooooooo
02goool00`0003?o0000001loooo001aoooo00?o09Woooooool0;Oooo`030000<ol0000007coool0
077oool00ol0VOooooooo`0Xoooo0P0000?oool00`0003?o0000001loooo001aoooo00?o09Wooooo
ool09oooo`040000oooooooo00000_ooo`030000<ol0000007coool0077oool00ol0VOooooooo`0Y
oooo00H0003oooooooooool0000co`030000N_ooo`00LOooo`03o`2Ioooooooo02[oool01P000?oo
ooooo`0003?o000007coool0077oool00ol0VOooooooo`0Woooo00@0003oooooool00002oooo00<0
000co`000000O?ooo`00LOooo`03o`2Ioooooooo02Soool200001?ooo`80001loooo001aoooo00?o
09Woooooool0;_ooo`80001loooo001aoooo00?o09Woooooool0;_ooo`80001loooo001aoooo00?o
09Woooooool0;_ooo`80001loooo001aoooo00?o09Woooooool0;_ooo`<0001koooo001aoooo00?o
09Woooooool0;_ooo`80001loooo001aoooo00?o09Woooooool0;_ooo`80001loooo001aoooo00?o
09Woooooool0;_ooo`80001loooo001aoooo00?o09Woooooool0;_ooo`80001loooo001aoooo00?o
09Woooooool0;_ooo`80001loooo001aoooo00?o09Woooooool0;_ooo`<0001koooo001aoooo00?o
09Woooooool0;_ooo`80001loooo001aoooo00?o09Woooooool0;_ooo`80001loooo001aoooo00?o
09Woooooool0;_ooo`80001loooo001aoooo00?o09Woooooool0;_ooo`80001loooo001aoooo00?o
09Woooooool0;_ooo`80001loooo001aoooo00?o09Woooooool0;_ooo`<0001koooo001aoooo00?o
09Woooooool0;oooo`030000oooooooo07[oool0077oool00ol0VOooooooo`0_oooo00<0003ooooo
ool0N_ooo`00LOooo`03o`2Ioooooooo02ooool00`000?ooooooo`1joooo001aoooo00?o09Wooooo
ool0;oooo`030000oooooooo07[oool0077oool00ol0VOooooooo`0_oooo00<0003oooooool0N_oo
o`00LOooo`03o`2Ioooooooo02ooool20000Noooo`00LOooo`03o`2Ioooooooo02ooool00`000?oo
ooooo`1joooo001aoooo00?o09Woooooool0;oooo`030000oooooooo07[oool0077oool00ol0VOoo
ooooo`0_oooo00<0003oooooool0N_ooo`00LOooo`03o`2Ioooooooo02ooool00`000?ooooooo`1j
oooo001aoooo00?o09Woooooool0:Oooo`<00003oooo00<0003oooooool0N_ooo`00LOooo`03o`2I
oooooooo02[oool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00LOooo`03o`2Ioooooooo
02Ooool500000oooo`<0001joooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool0
0000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool2
00001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01Goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500005Oooo`030000oooooooo00Ooool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.37685 .12361 L
.3815 .12361 L
.38384 .12361 L
.3864 .12361 L
.38757 .12361 L
.38881 .12361 L
s
.38881 .12361 m
.38928 .61803 L
s
0 .4 1 r
.02381 .1258 m
.04262 .12667 L
.06244 .12796 L
.07286 .12885 L
.08255 .12984 L
.09388 .13123 L
.10458 .13284 L
.125 .13689 L
.14357 .1421 L
.16355 .15001 L
.18199 .16027 L
.20071 .1748 L
.21136 .18549 L
.22134 .19753 L
.2263 .20437 L
.22892 .20823 L
.22968 .20938 L
.23039 .21011 L
.23103 .2101 L
.23172 .21009 L
.23683 .21001 L
.24158 .20992 L
.26011 .20949 L
.28005 .20884 L
.29009 .20842 L
.30111 .20785 L
.32062 .20654 L
.33156 .20558 L
.34154 .20452 L
.36062 .2019 L
.37141 .19997 L
.37621 .19899 L
.38138 .19783 L
.38383 .19724 L
.3864 .1966 L
.38747 .19632 L
.3886 .19602 L
.38985 .12361 L
.39101 .12361 L
.39218 .12361 L
.39344 .12361 L
.39464 .12361 L
.39574 .12361 L
.39674 .12361 L
.39783 .12361 L
.39898 .12361 L
.40005 .12361 L
.40132 .12361 L
.40204 .12361 L
.40271 .12361 L
Mistroke
.40393 .12361 L
.40524 .12361 L
.40652 .12361 L
.40773 .12361 L
.40881 .12361 L
.40998 .12361 L
.41127 .12361 L
.412 .12361 L
.41268 .12361 L
.41341 .12361 L
.41406 .12361 L
.41482 .12361 L
.41554 .12361 L
.41681 .12361 L
.41799 .12361 L
.41928 .12361 L
.41993 .12361 L
.42065 .12361 L
.42187 .12361 L
.42301 .12361 L
.42425 .12361 L
.42495 .12361 L
.42558 .12361 L
.42686 .12361 L
.42759 .12361 L
.42825 .12361 L
.42947 .12361 L
.43077 .12361 L
.43187 .12361 L
.43305 .12361 L
.43417 .12361 L
.43518 .12361 L
.43638 .12361 L
.43767 .12361 L
.4389 .12361 L
.44003 .12361 L
.44123 .12361 L
.44251 .12361 L
.44373 .12361 L
.44484 .12361 L
.44607 .12361 L
.44677 .12361 L
.44743 .12361 L
.44874 .12361 L
.44948 .12361 L
.45015 .12361 L
.45082 .12361 L
.45153 .12361 L
.4528 .12361 L
.45351 .12361 L
Mistroke
.45417 .12361 L
.4549 .12361 L
.45568 .12361 L
.45635 .12361 L
.45708 .12361 L
.45777 .12361 L
.45841 .12361 L
.45962 .12361 L
.4609 .12361 L
.46215 .12361 L
.46285 .12361 L
.46351 .12361 L
.46421 .12361 L
.46484 .12361 L
.46557 .12361 L
.46627 .12361 L
.4675 .12361 L
.46863 .12361 L
.46988 .12361 L
.47051 .12361 L
.4712 .12361 L
.4719 .12361 L
.47264 .12361 L
.47396 .12361 L
.4747 .12361 L
.47539 .12361 L
.47614 .12361 L
.47694 .12361 L
.47764 .12361 L
.4784 .12361 L
.47911 .12361 L
.47977 .12361 L
.481 .12361 L
.4817 .12361 L
.48233 .12361 L
.48357 .12361 L
.48474 .12361 L
.48582 .12361 L
.487 .12361 L
.48829 .12361 L
.48901 .12361 L
.48966 .12361 L
.49094 .12361 L
.49213 .12361 L
.49336 .12361 L
.49452 .12361 L
.49517 .12361 L
.49586 .12361 L
.49708 .12361 L
.49779 .12361 L
Mistroke
.49854 .12361 L
.49918 .12361 L
.49989 .12361 L
.50054 .12361 L
.50124 .12361 L
.50251 .12361 L
.50376 .12361 L
.50447 .12361 L
.50513 .12361 L
.50634 .12361 L
.50762 .12361 L
.50889 .12361 L
.51008 .12361 L
.51115 .12361 L
.51231 .12361 L
.51355 .12361 L
.51426 .12361 L
.51492 .12361 L
.51769 .12361 L
.51891 .12361 L
.52008 .12361 L
.52072 .12361 L
.52142 .12361 L
.52264 .12361 L
.52378 .12361 L
.52485 .12361 L
.52603 .12361 L
.52729 .12361 L
.52855 .12361 L
.52918 .12361 L
.52988 .12361 L
.5311 .12361 L
.53224 .12361 L
.5334 .12361 L
.53449 .12361 L
.53547 .12361 L
.53654 .12361 L
.5377 .12361 L
.53893 .12361 L
.53998 .12361 L
.54113 .12361 L
.54232 .12361 L
.54344 .12361 L
.54473 .12361 L
.5459 .12361 L
.5472 .12361 L
.54793 .12361 L
.5486 .12361 L
.54981 .12361 L
.5511 .12361 L
Mistroke
.55231 .12361 L
.55346 .12361 L
.5541 .12361 L
.55479 .12361 L
.556 .12361 L
.55715 .12361 L
.55837 .12361 L
.55942 .12361 L
.56057 .12361 L
.56186 .12361 L
.56259 .12361 L
.56325 .12361 L
.56448 .12361 L
.56577 .12361 L
.56646 .12361 L
.56719 .12361 L
.5685 .12361 L
.5693 .12361 L
.57006 .12361 L
.57074 .12361 L
.57148 .12361 L
.57268 .12361 L
.574 .12361 L
.57467 .12361 L
.57538 .12361 L
.57667 .12361 L
.57796 .12361 L
.57917 .12361 L
.58027 .12361 L
.58146 .12361 L
.62219 .12361 L
.66142 .12361 L
.69912 .12361 L
.73928 .12361 L
.77792 .12361 L
.81902 .12361 L
.8586 .12361 L
.89666 .12361 L
.93718 .12361 L
.97618 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00D0I_l2
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`1Vo`0@000000<co`00000co`0023?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool001koool<06Ko00<0003oooooool09_ooo`030000oooooooo01goool00`1Voooo
ooooo`05oooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000oooooooo
02Koool00`000?ooooooo`0Yoooo000Zoooo101VodGoool00`1Vooooooooo`0Boooo100001Lco`00
0`000?ooooooo`1joooo000^oooo1@1Vod3oool00`1Vooooooooo`0Foooo00<0000co`0co`0053?o
00030000oooooooo07[oool003?oool406Ko??ooo`0306Kooooooooo01Ooool2000053?o00030000
oooooooo07[oool003Ooool206Ko>_ooo`0306Kooooooooo01Woool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00>Oooo`80I_lhoooo00<0I_ooooooool06_ooo`030000<ol0<ol0010co`02
0000Noooo`00>oooo`0306Kooooooooo03Goool00`1Vooooooooo`0Koooo0P00010co`000`000?oo
ooooo`1joooo000loooo0P1VocGoool00`1Vooooooooo`0Moooo00<0000co`0co`003C?o00030000
oooooooo07[oool003koool00`1Vooooooooo`0boooo00<0I_ooooooool07Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1joooo000ooooo0P1Voc;oool00`1Vooooooooo`0Noooo00<0000co`0c
o`0033?o00030000oooooooo07[oool0047oool206Ko<?ooo`0306Kooooooooo01koool00`0003?o
03?o000<<ol000<0003oooooool0N_ooo`00@oooo`0306Kooooooooo02goool00`1Vooooooooo`0O
oooo00<0000co`0co`002c?o0080001koooo0014oooo00<0I_ooooooool0;?ooo`0306Kooooooooo
01ooool00`0003?o03?o000;<ol000<0003oooooool0N_ooo`00AOooo`0306Kooooooooo02_oool0
0`1Vooooooooo`0Poooo00<0000co`0co`002S?o00030000oooooooo07[oool004Koool00`1Voooo
ooooo`0Zoooo00<0I_ooooooool08?ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo0017
oooo00<0I_ooooooool0:Oooo`0306Kooooooooo027oool00`0003?o03?o0009<ol000<0003ooooo
ool0N_ooo`00Aoooo`0306Kooooooooo02Woool00`1Vooooooooo`0Qoooo00<0000co`0co`002C?o
00030000oooooooo07[oool004Soool00`1Vooooooooo`0Voooo0`1VobCoool00`0003?o03?o0008
<ol00P0007_oool004Woool00`1Vooooooooo`0Noooo1`1Vo`;oool00ol0VOooooooo`0Roooo00<0
000co`0co`0023?o00030000oooooooo07[oool004[oool00`1Vooooooooo`0Coooo2P1Vo`Woool0
0ol0VOooooooo`0Roooo00<0000co`0co`0023?o00030000oooooooo07[oool004[ooolF06Ko4ooo
o`03o`2Ioooooooo02?oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Loooo`03o`2I
oooooooo02?oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo
02?oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02?oool0
0`0003?o03?o0007<ol00P0007_oool007?oool00ol0VOooooooo`0Toooo00<0000co`0co`001S?o
00030000oooooooo07[oool007?oool00ol0VOooooooo`0Toooo00<0000co`0co`001S?o00030000
oooooooo07[oool007?oool00ol0VOooooooo`0Toooo00<0000co`0co`001S?o00030000oooooooo
07[oool007?oool00ol0VOooooooo`0Toooo00<0000co`0co`001S?o00030000oooooooo07[oool0
07?oool00ol0VOooooooo`0Uoooo1@0000<co`000`000?ooooooo`1joooo001coooo00?o09Wooooo
ool09Oooo`030000<ol0000000Dco`000`000?ooooooo`1joooo001coooo00?o09Woooooool09Ooo
o`030000<ol0000000Dco`030000N_ooo`00Loooo`03o`2Ioooooooo02Koool200001C?o00030000
oooooooo07[oool007?oool00ol0VOooooooo`0Voooo0P0000Dco`000`000?ooooooo`1joooo001c
oooo00?o09Woooooool09_ooo`800005<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo
02Koool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02Koool0
0`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02Koool00`0003?o
03?o0004<ol00P0007_oool007?oool00ol0VOooooooo`0Woooo00<0000co`0co`000c?o00030000
oooooooo07[oool007?oool00ol0VOooooooo`0Woooo00<0000co`0co`000c?o00030000oooooooo
07[oool007?oool00ol0VOooooooo`0Woooo00<0000co`0co`000c?o00030000oooooooo07[oool0
07?oool00ol0VOooooooo`0Woooo00<0000co`0co`000c?o00030000oooooooo07[oool007?oool0
0ol0VOooooooo`0Woooo00<0000co`0co`000c?o00030000oooooooo07[oool007?oool00ol0VOoo
ooooo`0Woooo00<0000co`0co`000c?o0080001koooo001coooo00?o09Woooooool09oooo`030000
<ol0<ol000<co`000`000?ooooooo`1joooo001coooo00?o09Woooooool09oooo`030000<ol0<ol0
00<co`000`000?ooooooo`1joooo001coooo00?o09Woooooool0:?ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001coooo00?o09Woooooool0:?ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo001coooo00?o09Woooooool0:?ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001coooo00?o09Woooooool0:?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001c
oooo00?o09Woooooool0:?ooo`030000<ol0<ol0008co`020000Noooo`00Loooo`03o`2Ioooooooo
02Soool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02Soool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02Soool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02Soool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02Soool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02Soool00`0003?o03?o0002<ol00P0007_oool0
07?oool00ol0VOooooooo`0Yoooo00D0000co`0co`0co`000000O?ooo`00Loooo`03o`2Ioooooooo
02Woool01@0003?o03?o03?o0000001loooo001coooo00?o09Woooooool0:Oooo`050000<ol0<ol0
<ol0000007coool007?oool00ol0VOooooooo`0Uoooo1@0000<co`000`000?ooooooo`1joooo001c
oooo00?o09Woooooool09Oooo`050000oooooooooooo000000<co`000`000?ooooooo`1joooo001c
oooo00?o09Woooooool09_ooo`040000oooooooo00000c?o00<0001joooo001coooo00?o09Wooooo
ool09oooo`030000oooo000000<co`000`000?ooooooo`1joooo001coooo00?o09Woooooool09Ooo
o`030000oooooooo00800003<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02Koool2
000000?oool0000co`000S?o00030000oooooooo07[oool007?oool00ol0VOooooooo`0Yoooo00D0
000co`0co`0co`000000O?ooo`00Loooo`03o`2Ioooooooo02[oool0100003?o03?o000007coool0
07?oool00ol0VOooooooo`0Zoooo00<0000co`0co`000P0007_oool007?oool00ol0VOooooooo`0Z
oooo00@0000co`0co`00001loooo001coooo00?o09Woooooool0:_ooo`040000<ol0<ol00000O?oo
o`00Loooo`03o`2Ioooooooo02[oool0100003?o03?o000007coool007?oool00ol0VOooooooo`0Z
oooo00@0000co`0co`00001loooo001coooo00?o09Woooooool0:_ooo`040000<ol0<ol00000O?oo
o`00Loooo`03o`2Ioooooooo02[oool0100003?o03?o000007coool007?oool00ol0VOooooooo`0[
oooo00@0000co`000000001koooo001coooo00?o09Woooooool0:oooo`030000<ol0000007coool0
07?oool00ol0VOooooooo`0[oooo00<0000co`000000O?ooo`00Loooo`03o`2Ioooooooo02_oool0
0`0003?o0000001loooo001coooo00?o09Woooooool0:oooo`030000<ol0000007coool007?oool0
0ol0VOooooooo`0[oooo00<0000co`000000O?ooo`00Loooo`03o`2Ioooooooo02_oool0100003?o
0000000007_oool007?oool00ol0VOooooooo`0[oooo00<0000co`000000O?ooo`00Loooo`03o`2I
oooooooo02_oool00`0003?o0000001loooo001coooo00?o09Woooooool0:oooo`030000<ol00000
07coool007?oool00ol0VOooooooo`0[oooo00<0000co`000000O?ooo`00Loooo`03o`2Ioooooooo
02_oool00`0003?o0000001loooo001coooo00?o09Woooooool0:oooo`040000<ol000000000Nooo
o`00Loooo`03o`2Ioooooooo02_oool00`0003?o0000001loooo001coooo00?o09Woooooool0:ooo
o`030000<ol0000007coool007?oool00ol0VOooooooo`0[oooo00<0000co`000000O?ooo`00Looo
o`03o`2Ioooooooo02Koool200000oooo`030000<ol0000007coool007?oool00ol0VOooooooo`0U
oooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00Loooo`03o`2Ioooooooo02Ooool0
1P000?ooooooooooo`0003?o00<0001joooo001coooo00?o09Woooooool0:?ooo`060000oooooooo
0000<ol00000O?ooo`00Loooo`03o`2Ioooooooo02Goool010000?ooooooo`0000;oool00`0003?o
0000001loooo001coooo00?o09Woooooool09_ooo`800004oooo0P0007coool007?oool00ol0VOoo
ooooo`0/oooo0P0007coool007?oool00ol0VOooooooo`0/oooo0P0007coool007?oool00ol0VOoo
ooooo`0/oooo0P0007coool007?oool00ol0VOooooooo`0/oooo0`0007_oool007?oool00ol0VOoo
ooooo`0/oooo0P0007coool007?oool00ol0VOooooooo`0/oooo0P0007coool007?oool00ol0VOoo
ooooo`0/oooo0P0007coool007?oool00ol0VOooooooo`0/oooo0P0007coool007?oool00ol0VOoo
ooooo`0/oooo0P0007coool007?oool00ol0VOooooooo`0/oooo0`0007_oool007?oool00ol0VOoo
ooooo`0/oooo0P0007coool007?oool00ol0VOooooooo`0/oooo0P0007coool007?oool00ol0VOoo
ooooo`0/oooo0P0007coool007?oool00ol0VOooooooo`0/oooo0P0007coool007?oool00ol0VOoo
ooooo`0/oooo0P0007coool007?oool00ol0VOooooooo`0/oooo0`0007_oool007?oool00ol0VOoo
ooooo`0]oooo00<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02goool00`000?ooooooo`1j
oooo001coooo00?o09Woooooool0;Oooo`030000oooooooo07[oool007?oool00ol0VOooooooo`0]
oooo00<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo02goool00`000?ooooooo`1joooo001c
oooo00?o09Woooooool0;Oooo`80001koooo001coooo00?o09Woooooool0;Oooo`030000oooooooo
07[oool007?oool00ol0VOooooooo`0]oooo00<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo
02goool00`000?ooooooo`1joooo001coooo00?o09Woooooool0;Oooo`030000oooooooo07[oool0
07?oool00ol0VOooooooo`0Woooo0`0000?oool00`000?ooooooo`1joooo001coooo00?o09Wooooo
ool0:?ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001coooo00?o09Woooooool09Ooo
o`D00003oooo0`0007[oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021
oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004
oooo0P0000Goool300000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002ooo
o`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`030000oooooooo00Ooool500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00005Oooo`030000oooooooo00Koool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002Oooo`030000oooo000000?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000;oooo0P0000;oool00`000?oo
ooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.3815 .12361 L
.39106 .12361 L
.39381 .12361 L
.39516 .12361 L
.39642 .12361 L
s
.39642 .12361 m
.39688 .61803 L
s
0 .4 1 r
.02381 .12551 m
.04262 .12626 L
.06244 .12739 L
.07286 .12816 L
.08255 .12902 L
.09388 .13023 L
.10458 .13162 L
.125 .13514 L
.14357 .13966 L
.16355 .14652 L
.18199 .15544 L
.20071 .16805 L
.21136 .17733 L
.22134 .18778 L
.23172 .20082 L
.23419 .20431 L
.23555 .20629 L
.23683 .20819 L
.23803 .21002 L
.23933 .2101 L
.2405 .21008 L
.24158 .21006 L
.25044 .2099 L
.26011 .20969 L
.27893 .20916 L
.28962 .20877 L
.2996 .20834 L
.31995 .20717 L
.33851 .20566 L
.35759 .2035 L
.36837 .20191 L
.37835 .20015 L
.38298 .19922 L
.38798 .19812 L
.39027 .19758 L
.39269 .19699 L
.39476 .19647 L
.39593 .19616 L
.39702 .12361 L
.3983 .12361 L
.39903 .12361 L
.3997 .12361 L
.40093 .12361 L
.40223 .12361 L
.4034 .12361 L
.40449 .12361 L
.40569 .12361 L
.40698 .12361 L
.40768 .12361 L
.40834 .12361 L
Mistroke
.40906 .12361 L
.40983 .12361 L
.41056 .12361 L
.41125 .12361 L
.41254 .12361 L
.41381 .12361 L
.41498 .12361 L
.41626 .12361 L
.41691 .12361 L
.41762 .12361 L
.41893 .12361 L
.42014 .12361 L
.42082 .12361 L
.42147 .12361 L
.42214 .12361 L
.42287 .12361 L
.42413 .12361 L
.42527 .12361 L
.42653 .12361 L
.42785 .12361 L
.42897 .12361 L
.43016 .12361 L
.43128 .12361 L
.4323 .12361 L
.4335 .12361 L
.43481 .12361 L
.43603 .12361 L
.43717 .12361 L
.43837 .12361 L
.43967 .12361 L
.4409 .12361 L
.44201 .12361 L
.44332 .12361 L
.44406 .12361 L
.44475 .12361 L
.446 .12361 L
.44664 .12361 L
.44734 .12361 L
.44802 .12361 L
.44873 .12361 L
.45001 .12361 L
.45072 .12361 L
.45138 .12361 L
.45211 .12361 L
.45288 .12361 L
.45356 .12361 L
.45429 .12361 L
.45498 .12361 L
.45561 .12361 L
.45682 .12361 L
Mistroke
.45809 .12361 L
.45921 .12361 L
.4604 .12361 L
.46171 .12361 L
.46292 .12361 L
.46416 .12361 L
.46533 .12361 L
.46638 .12361 L
.46751 .12361 L
.46815 .12361 L
.46886 .12361 L
.46959 .12361 L
.47027 .12361 L
.47149 .12361 L
.47281 .12361 L
.47411 .12361 L
.47534 .12361 L
.47644 .12361 L
.47764 .12361 L
.47877 .12361 L
.47984 .12361 L
.481 .12361 L
.48226 .12361 L
.4835 .12361 L
.48481 .12361 L
.48593 .12361 L
.48715 .12361 L
.48821 .12361 L
.4892 .12361 L
.49024 .12361 L
.49138 .12361 L
.49252 .12361 L
.49376 .12361 L
.4949 .12361 L
.49595 .12361 L
.49725 .12361 L
.49798 .12361 L
.49866 .12361 L
.49991 .12361 L
.50061 .12361 L
.50124 .12361 L
.50248 .12361 L
.50317 .12361 L
.50381 .12361 L
.50499 .12361 L
.50623 .12361 L
.50735 .12361 L
.50854 .12361 L
.50967 .12361 L
.51069 .12361 L
Mistroke
.51189 .12361 L
.5132 .12361 L
.51443 .12361 L
.51557 .12361 L
.51678 .12361 L
.51807 .12361 L
.51929 .12361 L
.52041 .12361 L
.52172 .12361 L
.52246 .12361 L
.52315 .12361 L
.5244 .12361 L
.52511 .12361 L
.52574 .12361 L
.52642 .12361 L
.52713 .12361 L
.52841 .12361 L
.52912 .12361 L
.52979 .12361 L
.53052 .12361 L
.5313 .12361 L
.53197 .12361 L
.5327 .12361 L
.53335 .12361 L
.53403 .12361 L
.53533 .12361 L
.53653 .12361 L
.53776 .12361 L
.53891 .12361 L
.5401 .12361 L
.54141 .12361 L
.54255 .12361 L
.54358 .12361 L
.54477 .12361 L
.54589 .12361 L
.54712 .12361 L
.54841 .12361 L
.54952 .12361 L
.55074 .12361 L
.55205 .12361 L
.55278 .12361 L
.55345 .12361 L
.55475 .12361 L
.55599 .12361 L
.55714 .12361 L
.55819 .12361 L
.55939 .12361 L
.56053 .12361 L
.56158 .12361 L
.56255 .12361 L
Mistroke
.56361 .12361 L
.56473 .12361 L
.56587 .12361 L
.56709 .12361 L
.56824 .12361 L
.56928 .12361 L
.57051 .12361 L
.5712 .12361 L
.57184 .12361 L
.57302 .12361 L
.57427 .12361 L
.57541 .12361 L
.57666 .12361 L
.57796 .12361 L
.57917 .12361 L
.58031 .12361 L
.58134 .12361 L
.58366 .12361 L
.59377 .12361 L
.61206 .12361 L
.65208 .12361 L
.69059 .12361 L
.73155 .12361 L
.77099 .12361 L
.80892 .12361 L
.84929 .12361 L
.88816 .12361 L
.92948 .12361 L
.96928 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`050000oooo0000000006Ko00h000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`008_ooo`P0I_l01000001Vo`1Vo`1VobGoool00`000?ooooooo`0Ooooo00<0
I_ooooooool00oooo`030000oooooooo00Koool400006c?o00030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0003oooooool0:Oooo`00;_ooo`D0I_m2oooo00<0I_ooooooool04?ooo`@0000G
<ol000<0003oooooool0N_ooo`00<oooo`@0I_lnoooo00<0I_ooooooool05?ooo`030000<ol0<ol0
01@co`000`000?ooooooo`1joooo000goooo0P1Voccoool00`1Vooooooooo`0Eoooo0P0001@co`00
0`000?ooooooo`1joooo000ioooo0P1Voc[oool00`1Vooooooooo`0Goooo00<0000co`0co`004C?o
00030000oooooooo07[oool003_oool206Ko>?ooo`0306Kooooooooo01Soool00`0003?o03?o000@
<ol00P0007_oool003goool206Ko=_ooo`0306Kooooooooo01Woool2000043?o00030000oooooooo
07[oool003ooool00`1Vooooooooo`0coooo00<0I_ooooooool06oooo`030000<ol0<ol000dco`00
0`000?ooooooo`1joooo0010oooo0P1Voc?oool00`1Vooooooooo`0Koooo00<0000co`0co`003C?o
00030000oooooooo07[oool004;oool00`1Vooooooooo`0`oooo00<0I_ooooooool07?ooo`030000
<ol0<ol000`co`000`000?ooooooo`1joooo0013oooo00<0I_ooooooool0;oooo`0306Kooooooooo
01coool00`0003?o03?o000<<ol000<0003oooooool0N_ooo`00A?ooo`80I_l_oooo00<0I_oooooo
ool07Oooo`030000<ol0<ol000/co`020000Noooo`00A_ooo`0306Kooooooooo02coool00`1Voooo
ooooo`0Moooo00<0000co`0co`002c?o00030000oooooooo07[oool004Ooool00`1Vooooooooo`0[
oooo00<0I_ooooooool07_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo0017oooo00<0
I_ooooooool0:oooo`0306Kooooooooo01koool00`0003?o03?o000:<ol000<0003oooooool0N_oo
o`00B?ooo`0306Kooooooooo02[oool00`1Vooooooooo`0Ooooo00<0000co`0co`002C?o00030000
oooooooo07[oool004Woool00`1Vooooooooo`0Yoooo00<0I_ooooooool07oooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1joooo001:oooo00<0I_ooooooool09_ooo`<0I_lRoooo00<0000co`0c
o`0023?o0080001koooo001;oooo00<0I_ooooooool07oooo`H0I_l2oooo00?o09Woooooool08?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`1joooo001<oooo00<0I_ooooooool05Oooo`T0I_l8
oooo00?o09Woooooool08?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1joooo001<oooo601V
oa7oool00ol0VOooooooo`0Qoooo00<0000co`0co`001c?o00030000oooooooo07[oool007Goool0
0ol0VOooooooo`0Qoooo00<0000co`0co`001c?o00030000oooooooo07[oool007Goool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`001c?o00030000oooooooo07[oool007Goool00ol0VOooooooo`0Q
oooo00<0000co`0co`001c?o0080001koooo001eoooo00?o09Woooooool08_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`1joooo001eoooo00?o09Woooooool08_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1joooo001eoooo00?o09Woooooool08_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1joooo001eoooo00?o09Woooooool08_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1j
oooo001eoooo00?o09Woooooool08oooo`D00003<ol000<0003oooooool0N_ooo`00MOooo`03o`2I
oooooooo02?oool00`0003?o00000005<ol000<0003oooooool0N_ooo`00MOooo`03o`2Ioooooooo
02?oool00`0003?o00000005<ol00`0007[oool007Goool00ol0VOooooooo`0Toooo0P0000Dco`00
0`000?ooooooo`1joooo001eoooo00?o09Woooooool09?ooo`800005<ol000<0003oooooool0N_oo
o`00MOooo`03o`2Ioooooooo02Coool200001C?o00030000oooooooo07[oool007Goool00ol0VOoo
ooooo`0Toooo00<0000co`0co`0013?o00030000oooooooo07[oool007Goool00ol0VOooooooo`0T
oooo00<0000co`0co`0013?o00030000oooooooo07[oool007Goool00ol0VOooooooo`0Toooo00<0
000co`0co`0013?o0080001koooo001eoooo00?o09Woooooool09Oooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo001eoooo00?o09Woooooool09Oooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo001eoooo00?o09Woooooool09Oooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo001eoooo00?o09Woooooool09Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001e
oooo00?o09Woooooool09Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001eoooo00?o
09Woooooool09Oooo`030000<ol0<ol000<co`020000Noooo`00MOooo`03o`2Ioooooooo02Goool0
0`0003?o03?o0003<ol000<0003oooooool0N_ooo`00MOooo`03o`2Ioooooooo02Goool00`0003?o
03?o0003<ol000<0003oooooool0N_ooo`00MOooo`03o`2Ioooooooo02Koool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00MOooo`03o`2Ioooooooo02Koool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00MOooo`03o`2Ioooooooo02Koool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00MOooo`03o`2Ioooooooo02Koool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00MOooo`03o`2Ioooooooo02Koool00`0003?o03?o0002<ol00P0007_oool007Goool00ol0VOoo
ooooo`0Voooo00<0000co`0co`000S?o00030000oooooooo07[oool007Goool00ol0VOooooooo`0V
oooo00<0000co`0co`000S?o00030000oooooooo07[oool007Goool00ol0VOooooooo`0Voooo00<0
000co`0co`000S?o00030000oooooooo07[oool007Goool00ol0VOooooooo`0Voooo00<0000co`0c
o`000S?o00030000oooooooo07[oool007Goool00ol0VOooooooo`0Voooo00<0000co`0co`000S?o
00030000oooooooo07[oool007Goool00ol0VOooooooo`0Voooo00<0000co`0co`000S?o0080001k
oooo001eoooo00?o09Woooooool09oooo`050000<ol0<ol0<ol0000007coool007Goool00ol0VOoo
ooooo`0Woooo00D0000co`0co`0co`000000O?ooo`00MOooo`03o`2Ioooooooo02Ooool01@0003?o
03?o03?o0000001loooo001eoooo00?o09Woooooool08oooo`D00003<ol000<0003oooooool0N_oo
o`00MOooo`03o`2Ioooooooo02?oool01@000?ooooooooooo`000003<ol000<0003oooooool0N_oo
o`00MOooo`03o`2Ioooooooo02Coool010000?ooooooo`0000<co`030000N_ooo`00MOooo`03o`2I
oooooooo02Goool00`000?ooo`000003<ol000<0003oooooool0N_ooo`00MOooo`03o`2Ioooooooo
02?oool00`000?ooooooo`0200000c?o00030000oooooooo07[oool007Goool00ol0VOooooooo`0T
oooo0P000003oooo0000<ol0008co`000`000?ooooooo`1joooo001eoooo00?o09Woooooool09ooo
o`050000<ol0<ol0<ol0000007coool007Goool00ol0VOooooooo`0Xoooo00@0000co`0co`00001l
oooo001eoooo00?o09Woooooool0:?ooo`030000<ol0<ol00080001koooo001eoooo00?o09Wooooo
ool0:?ooo`040000<ol0<ol00000O?ooo`00MOooo`03o`2Ioooooooo02Soool0100003?o03?o0000
07coool007Goool00ol0VOooooooo`0Xoooo00@0000co`0co`00001loooo001eoooo00?o09Wooooo
ool0:?ooo`040000<ol0<ol00000O?ooo`00MOooo`03o`2Ioooooooo02Soool0100003?o03?o0000
07coool007Goool00ol0VOooooooo`0Xoooo00@0000co`0co`00001loooo001eoooo00?o09Wooooo
ool0:Oooo`040000<ol000000000Noooo`00MOooo`03o`2Ioooooooo02Woool00`0003?o0000001l
oooo001eoooo00?o09Woooooool0:Oooo`030000<ol0000007coool007Goool00ol0VOooooooo`0Y
oooo00<0000co`000000O?ooo`00MOooo`03o`2Ioooooooo02Woool00`0003?o0000001loooo001e
oooo00?o09Woooooool0:Oooo`030000<ol0000007coool007Goool00ol0VOooooooo`0Yoooo00@0
000co`000000001koooo001eoooo00?o09Woooooool0:Oooo`030000<ol0000007coool007Goool0
0ol0VOooooooo`0Yoooo00<0000co`000000O?ooo`00MOooo`03o`2Ioooooooo02Woool00`0003?o
0000001loooo001eoooo00?o09Woooooool0:Oooo`030000<ol0000007coool007Goool00ol0VOoo
ooooo`0Yoooo00<0000co`000000O?ooo`00MOooo`03o`2Ioooooooo02Woool0100003?o00000000
07_oool007Goool00ol0VOooooooo`0Yoooo00<0000co`000000O?ooo`00MOooo`03o`2Ioooooooo
02Woool00`0003?o0000001loooo001eoooo00?o09Woooooool0:Oooo`030000<ol0000007coool0
07Goool00ol0VOooooooo`0Toooo0P0000?oool00`0003?o0000001loooo001eoooo00?o09Wooooo
ool08oooo`040000oooooooo00000_ooo`030000<ol0000007coool007Goool00ol0VOooooooo`0U
oooo00H0003oooooooooool0000co`030000N_ooo`00MOooo`03o`2Ioooooooo02Koool01P000?oo
ooooo`0003?o000007coool007Goool00ol0VOooooooo`0Soooo00@0003oooooool00002oooo00<0
000co`000000O?ooo`00MOooo`03o`2Ioooooooo02Coool200001?ooo`80001loooo001eoooo00?o
09Woooooool0:_ooo`80001loooo001eoooo00?o09Woooooool0:_ooo`80001loooo001eoooo00?o
09Woooooool0:_ooo`80001loooo001eoooo00?o09Woooooool0:_ooo`<0001koooo001eoooo00?o
09Woooooool0:_ooo`80001loooo001eoooo00?o09Woooooool0:_ooo`80001loooo001eoooo00?o
09Woooooool0:_ooo`80001loooo001eoooo00?o09Woooooool0:_ooo`80001loooo001eoooo00?o
09Woooooool0:_ooo`80001loooo001eoooo00?o09Woooooool0:_ooo`<0001koooo001eoooo00?o
09Woooooool0:_ooo`80001loooo001eoooo00?o09Woooooool0:_ooo`80001loooo001eoooo00?o
09Woooooool0:_ooo`80001loooo001eoooo00?o09Woooooool0:_ooo`80001loooo001eoooo00?o
09Woooooool0:_ooo`80001loooo001eoooo00?o09Woooooool0:_ooo`<0001koooo001eoooo00?o
09Woooooool0:oooo`030000oooooooo07[oool007Goool00ol0VOooooooo`0[oooo00<0003ooooo
ool0N_ooo`00MOooo`03o`2Ioooooooo02_oool00`000?ooooooo`1joooo001eoooo00?o09Wooooo
ool0:oooo`030000oooooooo07[oool007Goool00ol0VOooooooo`0[oooo00<0003oooooool0N_oo
o`00MOooo`03o`2Ioooooooo02_oool20000Noooo`00MOooo`03o`2Ioooooooo02_oool00`000?oo
ooooo`1joooo001eoooo00?o09Woooooool0:oooo`030000oooooooo07[oool007Goool00ol0VOoo
ooooo`0[oooo00<0003oooooool0N_ooo`00MOooo`03o`2Ioooooooo02_oool00`000?ooooooo`1j
oooo001eoooo00?o09Woooooool09Oooo`<00003oooo00<0003oooooool0N_ooo`00MOooo`03o`2I
oooooooo02Koool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00MOooo`03o`2Ioooooooo
02?oool500000oooo`<0001joooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool0
0000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool2
00001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01Goool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500005Oooo`030000oooooooo00Woool01@000?oooooooooo
o`00001joooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool2
00000oooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.39174 .12361 L
.39675 .12361 L
.40134 .12361 L
.40252 .12361 L
.40381 .12361 L
s
.40381 .12361 m
.4043 .61803 L
s
0 .4 1 r
.02381 .12526 m
.04262 .12591 L
.06244 .12689 L
.07286 .12756 L
.08255 .12831 L
.09388 .12936 L
.10458 .13056 L
.125 .13362 L
.14357 .13754 L
.16355 .1435 L
.18199 .15124 L
.20071 .16218 L
.21136 .17025 L
.22134 .17932 L
.23988 .20113 L
.24249 .20482 L
.24495 .20847 L
.24562 .20948 L
.24632 .21011 L
.24709 .2101 L
.24779 .21009 L
.25037 .21004 L
.26011 .20986 L
.27018 .20963 L
.28124 .20933 L
.29175 .20899 L
.30133 .20861 L
.32084 .20761 L
.33158 .2069 L
.34176 .20608 L
.36167 .20398 L
.38009 .20126 L
.38907 .19957 L
.39875 .19743 L
.40145 .19676 L
.40293 .19638 L
.40364 .19619 L
.4043 .19602 L
.40547 .12361 L
.40672 .12361 L
.40738 .12361 L
.40809 .12361 L
.40938 .12361 L
.41058 .12361 L
.4119 .12361 L
.41256 .12361 L
.41328 .12361 L
.41457 .12361 L
.41586 .12361 L
.41708 .12361 L
Mistroke
.41817 .12361 L
.41935 .12361 L
.42 .12361 L
.42068 .12361 L
.4219 .12361 L
.42319 .12361 L
.42393 .12361 L
.42461 .12361 L
.42584 .12361 L
.42696 .12361 L
.42826 .12361 L
.42949 .12361 L
.43012 .12361 L
.43082 .12361 L
.43155 .12361 L
.43224 .12361 L
.43346 .12361 L
.43478 .12361 L
.43548 .12361 L
.43624 .12361 L
.43704 .12361 L
.43778 .12361 L
.43848 .12361 L
.43911 .12361 L
.43984 .12361 L
.44053 .12361 L
.44169 .12361 L
.44297 .12361 L
.44362 .12361 L
.44431 .12361 L
.44555 .12361 L
.4468 .12361 L
.44797 .12361 L
.44903 .12361 L
.45018 .12361 L
.45143 .12361 L
.45214 .12361 L
.45281 .12361 L
.45351 .12361 L
.45416 .12361 L
.45486 .12361 L
.45561 .12361 L
.45685 .12361 L
.45801 .12361 L
.45928 .12361 L
.45992 .12361 L
.46063 .12361 L
.46128 .12361 L
.46198 .12361 L
.46325 .12361 L
Mistroke
.46451 .12361 L
.46567 .12361 L
.46637 .12361 L
.46701 .12361 L
.46772 .12361 L
.46847 .12361 L
.46919 .12361 L
.46987 .12361 L
.47114 .12361 L
.47235 .12361 L
.47362 .12361 L
.47471 .12361 L
.47591 .12361 L
.47719 .12361 L
.47792 .12361 L
.47857 .12361 L
.47985 .12361 L
.48106 .12361 L
.48213 .12361 L
.48331 .12361 L
.48454 .12361 L
.48569 .12361 L
.48676 .12361 L
.48775 .12361 L
.48883 .12361 L
.48997 .12361 L
.49112 .12361 L
.49236 .12361 L
.49353 .12361 L
.49459 .12361 L
.49584 .12361 L
.49654 .12361 L
.49719 .12361 L
.49838 .12361 L
.49964 .12361 L
.50218 .12361 L
.50342 .12361 L
.50458 .12361 L
.50563 .12361 L
.50674 .12361 L
.50797 .12361 L
.50909 .12361 L
.5104 .12361 L
.5116 .12361 L
.51292 .12361 L
.51359 .12361 L
.51432 .12361 L
.51555 .12361 L
.51686 .12361 L
.5181 .12361 L
Mistroke
.51923 .12361 L
.52037 .12361 L
.52158 .12361 L
.52261 .12361 L
.52375 .12361 L
.52497 .12361 L
.52628 .12361 L
.52751 .12361 L
.52865 .12361 L
.52978 .12361 L
.53083 .12361 L
.53198 .12361 L
.53321 .12361 L
.53438 .12361 L
.53549 .12361 L
.53657 .12361 L
.53755 .12361 L
.53871 .12361 L
.53996 .12361 L
.54111 .12361 L
.5422 .12361 L
.54347 .12361 L
.54465 .12361 L
.54594 .12361 L
.54659 .12361 L
.54731 .12361 L
.54796 .12361 L
.54864 .12361 L
.54987 .12361 L
.55118 .12361 L
.55193 .12361 L
.55263 .12361 L
.55389 .12361 L
.55504 .12361 L
.55568 .12361 L
.55637 .12361 L
.55762 .12361 L
.55877 .12361 L
.55984 .12361 L
.56102 .12361 L
.56229 .12361 L
.56292 .12361 L
.56361 .12361 L
.56487 .12361 L
.56611 .12361 L
.56723 .12361 L
.56837 .12361 L
.56945 .12361 L
.57059 .12361 L
.57183 .12361 L
Mistroke
.57291 .12361 L
.57405 .12361 L
.57502 .12361 L
.57609 .12361 L
.5774 .12361 L
.57861 .12361 L
.57929 .12361 L
.57993 .12361 L
.5806 .12361 L
.58134 .12361 L
.58631 .12361 L
.59563 .12361 L
.61655 .12361 L
.65528 .12361 L
.69646 .12361 L
.73612 .12361 L
.77427 .12361 L
.81487 .12361 L
.85396 .12361 L
.8955 .12361 L
.93552 .12361 L
.97402 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
1000001Vo`1Vo`1Vo`Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oool000000`00000306Ko0000000000X000000c?o000003?o0008<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool05Oooo`009?ooo`H0I_l01000001Vo`1Vo`1VobGoool00`000?oo
ooooo`0Qoooo00D0I_ooooooooooool000002?ooo`@0000K<ol000<0003oooooool09Oooo`030000
oooooooo02Koool00`000?ooooooo`0Yoooo000^oooo1@1VodCoool00`1Vooooooooo`0>oooo1000
01Lco`000`000?ooooooo`1joooo000coooo1@1Vocooool00`1Vooooooooo`0Boooo00<0000co`0c
o`0053?o00030000oooooooo07[oool003Soool306Ko??ooo`0306Kooooooooo01?oool2000053?o
00030000oooooooo07[oool003_oool206Ko>_ooo`0306Kooooooooo01Goool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00?Oooo`80I_lhoooo00<0I_ooooooool05_ooo`030000<ol0<ol0
010co`020000Noooo`00?oooo`80I_lfoooo00<0I_ooooooool05oooo`80000@<ol000<0003ooooo
ool0N_ooo`00@Oooo`80I_ldoooo00<0I_ooooooool06Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1joooo0013oooo00<0I_ooooooool0<Oooo`0306Kooooooooo01Woool00`0003?o03?o000=
<ol000<0003oooooool0N_ooo`00A?ooo`80I_laoooo00<0I_ooooooool06_ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1joooo0016oooo00<0I_ooooooool0;_ooo`0306Kooooooooo01[oool0
0`0003?o03?o000<<ol000<0003oooooool0N_ooo`00Aoooo`0306Kooooooooo02goool00`1Voooo
ooooo`0Koooo00<0000co`0co`002c?o0080001koooo0017oooo00<0I_ooooooool0;Oooo`0306Ko
oooooooo01_oool00`0003?o03?o000;<ol000<0003oooooool0N_ooo`00B?ooo`0306Kooooooooo
02coool00`1Vooooooooo`0Loooo00<0000co`0co`002S?o00030000oooooooo07[oool004Woool0
0`1Vooooooooo`0[oooo00<0I_ooooooool07?ooo`030000<ol0<ol000Xco`000`000?ooooooo`1j
oooo001:oooo00<0I_ooooooool0:_ooo`0306Kooooooooo01goool00`0003?o03?o0009<ol000<0
003oooooool0N_ooo`00Boooo`0306Kooooooooo02Woool00`1Vooooooooo`0Moooo00<0000co`0c
o`002C?o00030000oooooooo07[oool004coool00`1Vooooooooo`0Voooo0`1Vob3oool00`0003?o
03?o0008<ol00P0007_oool004goool00`1Vooooooooo`0Ooooo1P1Vo`;oool00ol0VOooooooo`0N
oooo00<0000co`0co`0023?o00030000oooooooo07[oool004koool00`1Vooooooooo`0Eoooo2@1V
o`Soool00ol0VOooooooo`0Noooo00<0000co`0co`0023?o00030000oooooooo07[oool004kooolH
06Ko4Oooo`03o`2Ioooooooo01ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Mooo
o`03o`2Ioooooooo01ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Moooo`03o`2I
oooooooo01ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo
01ooool00`0003?o03?o0007<ol00P0007_oool007Ooool00ol0VOooooooo`0Poooo00<0000co`0c
o`001S?o00030000oooooooo07[oool007Ooool00ol0VOooooooo`0Poooo00<0000co`0co`001S?o
00030000oooooooo07[oool007Ooool00ol0VOooooooo`0Poooo00<0000co`0co`001S?o00030000
oooooooo07[oool007Ooool00ol0VOooooooo`0Poooo00<0000co`0co`001S?o00030000oooooooo
07[oool007Ooool00ol0VOooooooo`0Qoooo1@0000<co`000`000?ooooooo`1joooo001goooo00?o
09Woooooool08Oooo`030000<ol0000000Dco`000`000?ooooooo`1joooo001goooo00?o09Wooooo
ool08Oooo`030000<ol0000000Dco`030000N_ooo`00Moooo`03o`2Ioooooooo02;oool200001C?o
00030000oooooooo07[oool007Ooool00ol0VOooooooo`0Roooo0P0000Dco`000`000?ooooooo`1j
oooo001goooo00?o09Woooooool08_ooo`800005<ol000<0003oooooool0N_ooo`00Moooo`03o`2I
oooooooo02;oool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo
02;oool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo02;oool0
0`0003?o03?o0004<ol00P0007_oool007Ooool00ol0VOooooooo`0Soooo00<0000co`0co`000c?o
00030000oooooooo07[oool007Ooool00ol0VOooooooo`0Soooo00<0000co`0co`000c?o00030000
oooooooo07[oool007Ooool00ol0VOooooooo`0Soooo00<0000co`0co`000c?o00030000oooooooo
07[oool007Ooool00ol0VOooooooo`0Soooo00<0000co`0co`000c?o00030000oooooooo07[oool0
07Ooool00ol0VOooooooo`0Soooo00<0000co`0co`000c?o00030000oooooooo07[oool007Ooool0
0ol0VOooooooo`0Soooo00<0000co`0co`000c?o0080001koooo001goooo00?o09Woooooool08ooo
o`030000<ol0<ol000<co`000`000?ooooooo`1joooo001goooo00?o09Woooooool08oooo`030000
<ol0<ol000<co`000`000?ooooooo`1joooo001goooo00?o09Woooooool09?ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo001goooo00?o09Woooooool09?ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001goooo00?o09Woooooool09?ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo001goooo00?o09Woooooool09?ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001goooo00?o09Woooooool09?ooo`030000<ol0<ol0008co`020000Noooo`00Moooo`03o`2I
oooooooo02Coool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo
02Coool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo02Coool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo02Coool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo02Coool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo02Coool00`0003?o03?o0002<ol00P00
07_oool007Ooool00ol0VOooooooo`0Uoooo00D0000co`0co`0co`000000O?ooo`00Moooo`03o`2I
oooooooo02Goool01@0003?o03?o03?o0000001loooo001goooo00?o09Woooooool09Oooo`050000
<ol0<ol0<ol0000007coool007Ooool00ol0VOooooooo`0Qoooo1@0000<co`000`000?ooooooo`1j
oooo001goooo00?o09Woooooool08Oooo`050000oooooooooooo000000<co`000`000?ooooooo`1j
oooo001goooo00?o09Woooooool08_ooo`040000oooooooo00000c?o00<0001joooo001goooo00?o
09Woooooool08oooo`030000oooo000000<co`000`000?ooooooo`1joooo001goooo00?o09Wooooo
ool08Oooo`030000oooooooo00800003<ol000<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo
02;oool2000000?oool0000co`000S?o00030000oooooooo07[oool007Ooool00ol0VOooooooo`0U
oooo00D0000co`0co`0co`000000O?ooo`00Moooo`03o`2Ioooooooo02Koool0100003?o03?o0000
07coool007Ooool00ol0VOooooooo`0Voooo00<0000co`0co`000P0007_oool007Ooool00ol0VOoo
ooooo`0Voooo00@0000co`0co`00001loooo001goooo00?o09Woooooool09_ooo`040000<ol0<ol0
0000O?ooo`00Moooo`03o`2Ioooooooo02Koool0100003?o03?o000007coool007Ooool00ol0VOoo
ooooo`0Voooo00@0000co`0co`00001loooo001goooo00?o09Woooooool09_ooo`040000<ol0<ol0
0000O?ooo`00Moooo`03o`2Ioooooooo02Koool0100003?o03?o000007coool007Ooool00ol0VOoo
ooooo`0Woooo00@0000co`000000001koooo001goooo00?o09Woooooool09oooo`030000<ol00000
07coool007Ooool00ol0VOooooooo`0Woooo00<0000co`000000O?ooo`00Moooo`03o`2Ioooooooo
02Ooool00`0003?o0000001loooo001goooo00?o09Woooooool09oooo`030000<ol0000007coool0
07Ooool00ol0VOooooooo`0Woooo00<0000co`000000O?ooo`00Moooo`03o`2Ioooooooo02Ooool0
100003?o0000000007_oool007Ooool00ol0VOooooooo`0Woooo00<0000co`000000O?ooo`00Mooo
o`03o`2Ioooooooo02Ooool00`0003?o0000001loooo001goooo00?o09Woooooool09oooo`030000
<ol0000007coool007Ooool00ol0VOooooooo`0Woooo00<0000co`000000O?ooo`00Moooo`03o`2I
oooooooo02Ooool00`0003?o0000001loooo001goooo00?o09Woooooool09oooo`040000<ol00000
0000Noooo`00Moooo`03o`2Ioooooooo02Ooool00`0003?o0000001loooo001goooo00?o09Wooooo
ool09oooo`030000<ol0000007coool007Ooool00ol0VOooooooo`0Woooo00<0000co`000000O?oo
o`00Moooo`03o`2Ioooooooo02;oool200000oooo`030000<ol0000007coool007Ooool00ol0VOoo
ooooo`0Qoooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00Moooo`03o`2Ioooooooo
02?oool01P000?ooooooooooo`0003?o00<0001joooo001goooo00?o09Woooooool09?ooo`060000
oooooooo0000<ol00000O?ooo`00Moooo`03o`2Ioooooooo027oool010000?ooooooo`0000;oool0
0`0003?o0000001loooo001goooo00?o09Woooooool08_ooo`800004oooo0P0007coool007Ooool0
0ol0VOooooooo`0Xoooo0P0007coool007Ooool00ol0VOooooooo`0Xoooo0P0007coool007Ooool0
0ol0VOooooooo`0Xoooo0P0007coool007Ooool00ol0VOooooooo`0Xoooo0`0007_oool007Ooool0
0ol0VOooooooo`0Xoooo0P0007coool007Ooool00ol0VOooooooo`0Xoooo0P0007coool007Ooool0
0ol0VOooooooo`0Xoooo0P0007coool007Ooool00ol0VOooooooo`0Xoooo0P0007coool007Ooool0
0ol0VOooooooo`0Xoooo0P0007coool007Ooool00ol0VOooooooo`0Xoooo0`0007_oool007Ooool0
0ol0VOooooooo`0Xoooo0P0007coool007Ooool00ol0VOooooooo`0Xoooo0P0007coool007Ooool0
0ol0VOooooooo`0Xoooo0P0007coool007Ooool00ol0VOooooooo`0Xoooo0P0007coool007Ooool0
0ol0VOooooooo`0Xoooo0P0007coool007Ooool00ol0VOooooooo`0Xoooo0`0007_oool007Ooool0
0ol0VOooooooo`0Yoooo00<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`1joooo001goooo00?o09Woooooool0:Oooo`030000oooooooo07[oool007Ooool00ol0VOoo
ooooo`0Yoooo00<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo02Woool00`000?ooooooo`1j
oooo001goooo00?o09Woooooool0:Oooo`80001koooo001goooo00?o09Woooooool0:Oooo`030000
oooooooo07[oool007Ooool00ol0VOooooooo`0Yoooo00<0003oooooool0N_ooo`00Moooo`03o`2I
oooooooo02Woool00`000?ooooooo`1joooo001goooo00?o09Woooooool0:Oooo`030000oooooooo
07[oool007Ooool00ol0VOooooooo`0Soooo0`0000?oool00`000?ooooooo`1joooo001goooo00?o
09Woooooool09?ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001goooo00?o09Wooooo
ool08Oooo`D00003oooo0`0007[oool009_oool010000?ooooooo`00087oool009coool00`000?oo
o`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000?oool400000oooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002?ooo`030000oooooooo00Coool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01Goool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500005Oooo`030000oooooooo00Soool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05ooo
o`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40134 .12361 L
.40616 .12361 L
.40882 .12361 L
.41013 .12361 L
.41134 .12361 L
.41203 .12361 L
s
.41203 .12361 m
.41232 .61803 L
s
0 .4 1 r
.02381 .12504 m
.04262 .12561 L
.06244 .12646 L
.07286 .12704 L
.08255 .12769 L
.09388 .1286 L
.10458 .12965 L
.125 .1323 L
.14357 .1357 L
.16355 .14088 L
.18199 .14759 L
.20071 .1571 L
.21136 .16409 L
.22134 .17197 L
.23988 .1909 L
.24967 .20373 L
.25102 .20569 L
.25249 .20786 L
.25316 .20888 L
.25387 .20996 L
.25514 .21009 L
.25637 .21007 L
.25751 .21005 L
.26011 .21001 L
.27107 .20979 L
.28124 .20955 L
.30133 .20892 L
.31179 .20849 L
.32169 .20801 L
.34024 .20683 L
.36015 .20505 L
.37857 .20274 L
.39724 .19949 L
.40235 .1984 L
.40504 .19778 L
.40786 .1971 L
.41035 .19647 L
.41103 .1963 L
.41176 .19611 L
.41307 .12361 L
.41435 .12361 L
.41557 .12361 L
.41666 .12361 L
.41784 .12361 L
.41907 .12361 L
.4202 .12361 L
.42149 .12361 L
.42273 .12361 L
.42386 .12361 L
.42492 .12361 L
Mistroke
.42607 .12361 L
.4273 .12361 L
.42801 .12361 L
.42866 .12361 L
.42937 .12361 L
.43012 .12361 L
.43277 .12361 L
.43391 .12361 L
.43513 .12361 L
.43583 .12361 L
.43647 .12361 L
.43771 .12361 L
.43902 .12361 L
.43968 .12361 L
.44041 .12361 L
.44169 .12361 L
.4429 .12361 L
.44359 .12361 L
.44431 .12361 L
.44561 .12361 L
.44633 .12361 L
.447 .12361 L
.44774 .12361 L
.44853 .12361 L
.44922 .12361 L
.44985 .12361 L
.45055 .12361 L
.45129 .12361 L
.45253 .12361 L
.45323 .12361 L
.45389 .12361 L
.45512 .12361 L
.45624 .12361 L
.45753 .12361 L
.45876 .12361 L
.45989 .12361 L
.46112 .12361 L
.46227 .12361 L
.46334 .12361 L
.46451 .12361 L
.4658 .12361 L
.46645 .12361 L
.46714 .12361 L
.46839 .12361 L
.46908 .12361 L
.46972 .12361 L
.47042 .12361 L
.47115 .12361 L
.4724 .12361 L
.4731 .12361 L
Mistroke
.47376 .12361 L
.47499 .12361 L
.47611 .12361 L
.47741 .12361 L
.47864 .12361 L
.4798 .12361 L
.48085 .12361 L
.48207 .12361 L
.48321 .12361 L
.48427 .12361 L
.48525 .12361 L
.48632 .12361 L
.48745 .12361 L
.48859 .12361 L
.48982 .12361 L
.49097 .12361 L
.49203 .12361 L
.49327 .12361 L
.49396 .12361 L
.49461 .12361 L
.4958 .12361 L
.49705 .12361 L
.49819 .12361 L
.49944 .12361 L
.50074 .12361 L
.50195 .12361 L
.50309 .12361 L
.50412 .12361 L
.50531 .12361 L
.50643 .12361 L
.50766 .12361 L
.50896 .12361 L
.51007 .12361 L
.51128 .12361 L
.51259 .12361 L
.51333 .12361 L
.514 .12361 L
.5153 .12361 L
.51654 .12361 L
.5177 .12361 L
.51874 .12361 L
.51995 .12361 L
.52108 .12361 L
.52214 .12361 L
.52311 .12361 L
.52417 .12361 L
.52529 .12361 L
.52642 .12361 L
.52749 .12361 L
.52872 .12361 L
Mistroke
.52984 .12361 L
.53108 .12361 L
.53178 .12361 L
.53242 .12361 L
.53359 .12361 L
.53483 .12361 L
.53603 .12361 L
.53734 .12361 L
.53858 .12361 L
.53974 .12361 L
.54088 .12361 L
.54191 .12361 L
.5431 .12361 L
.54423 .12361 L
.54546 .12361 L
.54676 .12361 L
.54787 .12361 L
.54909 .12361 L
.5504 .12361 L
.55114 .12361 L
.55181 .12361 L
.55311 .12361 L
.55435 .12361 L
.5554 .12361 L
.55656 .12361 L
.55777 .12361 L
.5589 .12361 L
.55996 .12361 L
.56093 .12361 L
.56199 .12361 L
.56311 .12361 L
.56425 .12361 L
.56547 .12361 L
.56662 .12361 L
.56767 .12361 L
.5689 .12361 L
.56959 .12361 L
.57023 .12361 L
.5714 .12361 L
.57265 .12361 L
.57386 .12361 L
.57518 .12361 L
.57642 .12361 L
.57757 .12361 L
.57872 .12361 L
.57976 .12361 L
.58095 .12361 L
.58208 .12361 L
.59221 .12361 L
.61052 .12361 L
Mistroke
.64911 .12361 L
.69016 .12361 L
.72968 .12361 L
.7677 .12361 L
.80816 .12361 L
.84711 .12361 L
.88851 .12361 L
.92839 .12361 L
.96676 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0406Ko0oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`000005000000<0I_l00000000020000003<ol00000<ol000Pco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`0Eoooo000Woooo0`1Vo`04000006Ko06Ko06Ko9Oooo`030000
oooooooo02?oool00`1Vooooo`000008oooo100001/co`000`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000oooooooo02Woool002koool906Ko@_ooo`0306Kooooooooo00coool400005c?o
00030000oooooooo07[oool003Ooool206Ko@?ooo`0306Kooooooooo013oool00`0003?o03?o000D
<ol000<0003oooooool0N_ooo`00>Oooo`<0I_lmoooo00<0I_ooooooool04Oooo`80000D<ol000<0
003oooooool0N_ooo`00??ooo`<0I_ljoooo00<0I_ooooooool04oooo`030000<ol0<ol0014co`00
0`000?ooooooo`1joooo000ooooo0P1VocSoool00`1Vooooooooo`0Doooo00<0000co`0co`0043?o
0080001koooo0011oooo0P1VocKoool00`1Vooooooooo`0Eoooo0P00010co`000`000?ooooooo`1j
oooo0013oooo00<0I_ooooooool0<oooo`0306Kooooooooo01Ooool00`0003?o03?o000=<ol000<0
003oooooool0N_ooo`00A?ooo`80I_lcoooo00<0I_ooooooool05oooo`030000<ol0<ol000dco`00
0`000?ooooooo`1joooo0016oooo00<0I_ooooooool0<?ooo`0306Kooooooooo01Soool00`0003?o
03?o000<<ol000<0003oooooool0N_ooo`00Aoooo`0306Kooooooooo02ooool00`1Vooooooooo`0H
oooo00<0000co`0co`0033?o00030000oooooooo07[oool004Soool00`1Vooooooooo`0^oooo00<0
I_ooooooool06Oooo`030000<ol0<ol000/co`020000Noooo`00BOooo`0306Kooooooooo02goool0
0`1Vooooooooo`0Ioooo00<0000co`0co`002c?o00030000oooooooo07[oool004[oool206Ko;Ooo
o`0306Kooooooooo01[oool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00C?ooo`0306Ko
oooooooo02[oool00`1Vooooooooo`0Joooo00<0000co`0co`002S?o00030000oooooooo07[oool0
04goool00`1Vooooooooo`0Yoooo00<0I_ooooooool06oooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1joooo001=oooo00<0I_ooooooool0:Oooo`0306Kooooooooo01_oool00`0003?o03?o0009
<ol000<0003oooooool0N_ooo`00C_ooo`0306Kooooooooo02Goool406Ko7_ooo`030000<ol0<ol0
00Pco`020000Noooo`00C_ooo`0306Kooooooooo01koool706Ko0oooo`03o`2Ioooooooo01coool0
0`0003?o03?o0008<ol000<0003oooooool0N_ooo`00Coooo`80I_lIoooo1@1Vo`[oool00ol0VOoo
ooooo`0Loooo00<0000co`0co`0023?o00030000oooooooo07[oool0053ooolJ06Ko3oooo`03o`2I
oooooooo01goool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo
01goool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo01goool0
0`0003?o03?o0007<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo01goool00`0003?o
03?o0007<ol00P0007_oool007Woool00ol0VOooooooo`0Noooo00<0000co`0co`001S?o00030000
oooooooo07[oool007Woool00ol0VOooooooo`0Noooo00<0000co`0co`001S?o00030000oooooooo
07[oool007Woool00ol0VOooooooo`0Noooo00<0000co`0co`001S?o00030000oooooooo07[oool0
07Woool00ol0VOooooooo`0Noooo00<0000co`0co`001S?o00030000oooooooo07[oool007Woool0
0ol0VOooooooo`0Ooooo1@0000<co`000`000?ooooooo`1joooo001ioooo00?o09Woooooool07ooo
o`030000<ol0000000Dco`000`000?ooooooo`1joooo001ioooo00?o09Woooooool07oooo`030000
<ol0000000Dco`030000N_ooo`00NOooo`03o`2Ioooooooo023oool200001C?o00030000oooooooo
07[oool007Woool00ol0VOooooooo`0Poooo0P0000Dco`000`000?ooooooo`1joooo001ioooo00?o
09Woooooool08?ooo`800005<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo023oool0
0`0003?o03?o0004<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo023oool00`0003?o
03?o0004<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo023oool00`0003?o03?o0004
<ol00P0007_oool007Woool00ol0VOooooooo`0Qoooo00<0000co`0co`000c?o00030000oooooooo
07[oool007Woool00ol0VOooooooo`0Qoooo00<0000co`0co`000c?o00030000oooooooo07[oool0
07Woool00ol0VOooooooo`0Qoooo00<0000co`0co`000c?o00030000oooooooo07[oool007Woool0
0ol0VOooooooo`0Qoooo00<0000co`0co`000c?o00030000oooooooo07[oool007Woool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`000c?o00030000oooooooo07[oool007Woool00ol0VOooooooo`0Q
oooo00<0000co`0co`000c?o0080001koooo001ioooo00?o09Woooooool08Oooo`030000<ol0<ol0
00<co`000`000?ooooooo`1joooo001ioooo00?o09Woooooool08Oooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo001ioooo00?o09Woooooool08_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo001ioooo00?o09Woooooool08_ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001ioooo00?o09Woooooool08_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001i
oooo00?o09Woooooool08_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001ioooo00?o
09Woooooool08_ooo`030000<ol0<ol0008co`020000Noooo`00NOooo`03o`2Ioooooooo02;oool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo02;oool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo02;oool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo02;oool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00NOooo`03o`2Ioooooooo02;oool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00NOooo`03o`2Ioooooooo02;oool00`0003?o03?o0002<ol00P0007_oool007Woool0
0ol0VOooooooo`0Soooo00D0000co`0co`0co`000000O?ooo`00NOooo`03o`2Ioooooooo02?oool0
1@0003?o03?o03?o0000001loooo001ioooo00?o09Woooooool08oooo`050000<ol0<ol0<ol00000
07coool007Woool00ol0VOooooooo`0Ooooo1@0000<co`000`000?ooooooo`1joooo001ioooo00?o
09Woooooool07oooo`050000oooooooooooo000000<co`000`000?ooooooo`1joooo001ioooo00?o
09Woooooool08?ooo`040000oooooooo00000c?o00<0001joooo001ioooo00?o09Woooooool08Ooo
o`030000oooo000000<co`000`000?ooooooo`1joooo001ioooo00?o09Woooooool07oooo`030000
oooooooo00800003<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo023oool2000000?o
ool0000co`000S?o00030000oooooooo07[oool007Woool00ol0VOooooooo`0Soooo00D0000co`0c
o`0co`000000O?ooo`00NOooo`03o`2Ioooooooo02Coool0100003?o03?o000007coool007Woool0
0ol0VOooooooo`0Toooo00<0000co`0co`000P0007_oool007Woool00ol0VOooooooo`0Toooo00@0
000co`0co`00001loooo001ioooo00?o09Woooooool09?ooo`040000<ol0<ol00000O?ooo`00NOoo
o`03o`2Ioooooooo02Coool0100003?o03?o000007coool007Woool00ol0VOooooooo`0Toooo00@0
000co`0co`00001loooo001ioooo00?o09Woooooool09?ooo`040000<ol0<ol00000O?ooo`00NOoo
o`03o`2Ioooooooo02Coool0100003?o03?o000007coool007Woool00ol0VOooooooo`0Uoooo00@0
000co`000000001koooo001ioooo00?o09Woooooool09Oooo`030000<ol0000007coool007Woool0
0ol0VOooooooo`0Uoooo00<0000co`000000O?ooo`00NOooo`03o`2Ioooooooo02Goool00`0003?o
0000001loooo001ioooo00?o09Woooooool09Oooo`030000<ol0000007coool007Woool00ol0VOoo
ooooo`0Uoooo00<0000co`000000O?ooo`00NOooo`03o`2Ioooooooo02Goool0100003?o00000000
07_oool007Woool00ol0VOooooooo`0Uoooo00<0000co`000000O?ooo`00NOooo`03o`2Ioooooooo
02Goool00`0003?o0000001loooo001ioooo00?o09Woooooool09Oooo`030000<ol0000007coool0
07Woool00ol0VOooooooo`0Uoooo00<0000co`000000O?ooo`00NOooo`03o`2Ioooooooo02Goool0
0`0003?o0000001loooo001ioooo00?o09Woooooool09Oooo`040000<ol000000000Noooo`00NOoo
o`03o`2Ioooooooo02Goool00`0003?o0000001loooo001ioooo00?o09Woooooool09Oooo`030000
<ol0000007coool007Woool00ol0VOooooooo`0Uoooo00<0000co`000000O?ooo`00NOooo`03o`2I
oooooooo023oool200000oooo`030000<ol0000007coool007Woool00ol0VOooooooo`0Ooooo00@0
003oooooool00002oooo00<0000co`000000O?ooo`00NOooo`03o`2Ioooooooo027oool01P000?oo
ooooooooo`0003?o00<0001joooo001ioooo00?o09Woooooool08_ooo`060000oooooooo0000<ol0
0000O?ooo`00NOooo`03o`2Ioooooooo01ooool010000?ooooooo`0000;oool00`0003?o0000001l
oooo001ioooo00?o09Woooooool08?ooo`800004oooo0P0007coool007Woool00ol0VOooooooo`0V
oooo0P0007coool007Woool00ol0VOooooooo`0Voooo0P0007coool007Woool00ol0VOooooooo`0V
oooo0P0007coool007Woool00ol0VOooooooo`0Voooo0`0007_oool007Woool00ol0VOooooooo`0V
oooo0P0007coool007Woool00ol0VOooooooo`0Voooo0P0007coool007Woool00ol0VOooooooo`0V
oooo0P0007coool007Woool00ol0VOooooooo`0Voooo0P0007coool007Woool00ol0VOooooooo`0V
oooo0P0007coool007Woool00ol0VOooooooo`0Voooo0`0007_oool007Woool00ol0VOooooooo`0V
oooo0P0007coool007Woool00ol0VOooooooo`0Voooo0P0007coool007Woool00ol0VOooooooo`0V
oooo0P0007coool007Woool00ol0VOooooooo`0Voooo0P0007coool007Woool00ol0VOooooooo`0V
oooo0P0007coool007Woool00ol0VOooooooo`0Voooo0`0007_oool007Woool00ol0VOooooooo`0W
oooo00<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1joooo001i
oooo00?o09Woooooool09oooo`030000oooooooo07[oool007Woool00ol0VOooooooo`0Woooo00<0
003oooooool0N_ooo`00NOooo`03o`2Ioooooooo02Ooool00`000?ooooooo`1joooo001ioooo00?o
09Woooooool09oooo`80001koooo001ioooo00?o09Woooooool09oooo`030000oooooooo07[oool0
07Woool00ol0VOooooooo`0Woooo00<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo02Ooool0
0`000?ooooooo`1joooo001ioooo00?o09Woooooool09oooo`030000oooooooo07[oool007Woool0
0ol0VOooooooo`0Qoooo0`0000?oool00`000?ooooooo`1joooo001ioooo00?o09Woooooool08_oo
o`030000oooooooo00;oool00`000?ooooooo`1joooo001ioooo00?o09Woooooool07oooo`D00003
oooo0`0007[oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002M
oooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P00
00?oool500000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_ooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo
01Goool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500005Oooo`030000oooooooo00Soool00`000?ooooooo`02oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003
oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40134 .12361 L
.41134 .12361 L
.41408 .12361 L
.41703 .12361 L
.41846 .12361 L
.41917 .12361 L
.41982 .12361 L
s
.41982 .12361 m
.42031 .61803 L
s
0 .4 1 r
.02381 .12485 m
.04262 .12534 L
.06244 .12608 L
.07286 .12659 L
.08255 .12715 L
.09388 .12794 L
.10458 .12885 L
.125 .13115 L
.14357 .13411 L
.16355 .1386 L
.18199 .14443 L
.20071 .15268 L
.21136 .15875 L
.22134 .16559 L
.24158 .18383 L
.25055 .19426 L
.25547 .20074 L
.26011 .20738 L
.26132 .2092 L
.26259 .21009 L
.26326 .21008 L
.26399 .21007 L
.26527 .21005 L
.26995 .20997 L
.27909 .20978 L
.28993 .20952 L
.29982 .20923 L
.31933 .2085 L
.33007 .20797 L
.34024 .20736 L
.36015 .20581 L
.37857 .2038 L
.39724 .20097 L
.40798 .19886 L
.41269 .1978 L
.41518 .19721 L
.41784 .19654 L
.41915 .1962 L
.4204 .19587 L
.42151 .12361 L
.42272 .12361 L
.42387 .12361 L
.42508 .12361 L
.42612 .12361 L
.42726 .12361 L
.42855 .12361 L
.42973 .12361 L
.43039 .12361 L
.4311 .12361 L
.43239 .12361 L
Mistroke
.43359 .12361 L
.43488 .12361 L
.43609 .12361 L
.43719 .12361 L
.43849 .12361 L
.4397 .12361 L
.44096 .12361 L
.44163 .12361 L
.44235 .12361 L
.44313 .12361 L
.44387 .12361 L
.44454 .12361 L
.44526 .12361 L
.44593 .12361 L
.44665 .12361 L
.44793 .12361 L
.44913 .12361 L
.45041 .12361 L
.45163 .12361 L
.45274 .12361 L
.45398 .12361 L
.45467 .12361 L
.45532 .12361 L
.45664 .12361 L
.45737 .12361 L
.45804 .12361 L
.45924 .12361 L
.46036 .12361 L
.46159 .12361 L
.46291 .12361 L
.46357 .12361 L
.46429 .12361 L
.4656 .12361 L
.46687 .12361 L
.46805 .12361 L
.46914 .12361 L
.47017 .12361 L
.4713 .12361 L
.47252 .12361 L
.47372 .12361 L
.47499 .12361 L
.47608 .12361 L
.47726 .12361 L
.47794 .12361 L
.47867 .12361 L
.47936 .12361 L
.47999 .12361 L
.4812 .12361 L
.48247 .12361 L
.48313 .12361 L
Mistroke
.48384 .12361 L
.48512 .12361 L
.4859 .12361 L
.48665 .12361 L
.48731 .12361 L
.48804 .12361 L
.48936 .12361 L
.49056 .12361 L
.49123 .12361 L
.49194 .12361 L
.49325 .12361 L
.49447 .12361 L
.49576 .12361 L
.49687 .12361 L
.49808 .12361 L
.49929 .12361 L
.50059 .12361 L
.50126 .12361 L
.50201 .12361 L
.50332 .12361 L
.50456 .12361 L
.50525 .12361 L
.50589 .12361 L
.50706 .12361 L
.50829 .12361 L
.50941 .12361 L
.5106 .12361 L
.51172 .12361 L
.51274 .12361 L
.51394 .12361 L
.51524 .12361 L
.51647 .12361 L
.5176 .12361 L
.51881 .12361 L
.5201 .12361 L
.52122 .12361 L
.52244 .12361 L
.52318 .12361 L
.52387 .12361 L
.52453 .12361 L
.52522 .12361 L
.52591 .12361 L
.52656 .12361 L
.52776 .12361 L
.52908 .12361 L
.52974 .12361 L
.53046 .12361 L
.53174 .12361 L
.53294 .12361 L
.53366 .12361 L
Mistroke
.53435 .12361 L
.53563 .12361 L
.53635 .12361 L
.53702 .12361 L
.53775 .12361 L
.53852 .12361 L
.53972 .12361 L
.54104 .12361 L
.5422 .12361 L
.54343 .12361 L
.54465 .12361 L
.54576 .12361 L
.54688 .12361 L
.54793 .12361 L
.54916 .12361 L
.55046 .12361 L
.55157 .12361 L
.55279 .12361 L
.5541 .12361 L
.55483 .12361 L
.55551 .12361 L
.55681 .12361 L
.55805 .12361 L
.55909 .12361 L
.56025 .12361 L
.56146 .12361 L
.5626 .12361 L
.56365 .12361 L
.56462 .12361 L
.56569 .12361 L
.56681 .12361 L
.56795 .12361 L
.56917 .12361 L
.57032 .12361 L
.57136 .12361 L
.57259 .12361 L
.57328 .12361 L
.57392 .12361 L
.5751 .12361 L
.57634 .12361 L
.57755 .12361 L
.57887 .12361 L
.58012 .12361 L
.58127 .12361 L
.58577 .12361 L
.59591 .12361 L
.61422 .12361 L
.65339 .12361 L
.69501 .12361 L
.73512 .12361 L
Mistroke
.77371 .12361 L
.81475 .12361 L
.85428 .12361 L
.89229 .12361 L
.93275 .12361 L
.9717 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0406Ko0oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool002Ooool306Ko00<00000I_l0I_l01P1Vob3oool00`000?ooooooo`0Uoooo00<0
003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000oooooooo02Koool00`000?oo
ooooo`0Yoooo000coooo1@1Vod?oool00`1Vooooooooo`0:oooo100001Lco`000`000?ooooooo`1j
oooo000hoooo0`1Vod3oool00`1Vooooooooo`0>oooo00<0000co`0co`0053?o00030000oooooooo
07[oool003_oool206Ko?_ooo`0306Kooooooooo00ooool2000053?o00030000oooooooo07[oool0
03goool306Ko>oooo`0306Kooooooooo017oool00`0003?o03?o000A<ol000<0003oooooool0N_oo
o`00@?ooo`80I_lioooo00<0I_ooooooool04_ooo`030000<ol0<ol0010co`020000Noooo`00@_oo
o`<0I_lfoooo00<0I_ooooooool04oooo`80000@<ol000<0003oooooool0N_ooo`00AOooo`80I_ld
oooo00<0I_ooooooool05Oooo`030000<ol0<ol000dco`000`000?ooooooo`1joooo0017oooo00<0
I_ooooooool0<Oooo`0306Kooooooooo01Goool00`0003?o03?o000=<ol000<0003oooooool0N_oo
o`00B?ooo`0306Kooooooooo033oool00`1Vooooooooo`0Foooo00<0000co`0co`0033?o00030000
oooooooo07[oool004Woool00`1Vooooooooo`0_oooo00<0I_ooooooool05_ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1joooo001:oooo00<0I_ooooooool0;_ooo`0306Kooooooooo01Ooool0
0`0003?o03?o000;<ol00P0007_oool004_oool00`1Vooooooooo`0]oooo00<0I_ooooooool05ooo
o`030000<ol0<ol000/co`000`000?ooooooo`1joooo001<oooo00<0I_ooooooool0;?ooo`0306Ko
oooooooo01Soool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00COooo`0306Kooooooooo
02_oool00`1Vooooooooo`0Hoooo00<0000co`0co`002S?o00030000oooooooo07[oool004koool2
06Ko:oooo`0306Kooooooooo01Woool00`0003?o03?o0009<ol000<0003oooooool0N_ooo`00D?oo
o`0306Kooooooooo02Soool00`1Vooooooooo`0Ioooo00<0000co`0co`002C?o00030000oooooooo
07[oool0053oool00`1Vooooooooo`0Toooo1@1Voacoool00`0003?o03?o0008<ol00P0007_oool0
057oool00`1Vooooooooo`0Ooooo101Vo`Coool00ol0VOooooooo`0Joooo00<0000co`0co`0023?o
00030000oooooooo07[oool0057oool00`1Vooooooooo`0Foooo2@1Vo`Soool00ol0VOooooooo`0J
oooo00<0000co`0co`0023?o00030000oooooooo07[oool005;ooolH06Ko4Oooo`03o`2Ioooooooo
01_oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Noooo`03o`2Ioooooooo01_oool0
0`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Noooo`03o`2Ioooooooo01_oool00`0003?o
03?o0007<ol000<0003oooooool0N_ooo`00Noooo`03o`2Ioooooooo01_oool00`0003?o03?o0007
<ol00P0007_oool007_oool00ol0VOooooooo`0Loooo00<0000co`0co`001S?o00030000oooooooo
07[oool007_oool00ol0VOooooooo`0Loooo00<0000co`0co`001S?o00030000oooooooo07[oool0
07_oool00ol0VOooooooo`0Loooo00<0000co`0co`001S?o00030000oooooooo07[oool007_oool0
0ol0VOooooooo`0Loooo00<0000co`0co`001S?o00030000oooooooo07[oool007_oool00ol0VOoo
ooooo`0Moooo1@0000<co`000`000?ooooooo`1joooo001koooo00?o09Woooooool07Oooo`030000
<ol0000000Dco`000`000?ooooooo`1joooo001koooo00?o09Woooooool07Oooo`030000<ol00000
00Dco`030000N_ooo`00Noooo`03o`2Ioooooooo01koool200001C?o00030000oooooooo07[oool0
07_oool00ol0VOooooooo`0Noooo0P0000Dco`000`000?ooooooo`1joooo001koooo00?o09Wooooo
ool07_ooo`800005<ol000<0003oooooool0N_ooo`00Noooo`03o`2Ioooooooo01koool00`0003?o
03?o0004<ol000<0003oooooool0N_ooo`00Noooo`03o`2Ioooooooo01koool00`0003?o03?o0004
<ol000<0003oooooool0N_ooo`00Noooo`03o`2Ioooooooo01koool00`0003?o03?o0004<ol00P00
07_oool007_oool00ol0VOooooooo`0Ooooo00<0000co`0co`000c?o00030000oooooooo07[oool0
07_oool00ol0VOooooooo`0Ooooo00<0000co`0co`000c?o00030000oooooooo07[oool007_oool0
0ol0VOooooooo`0Ooooo00<0000co`0co`000c?o00030000oooooooo07[oool007_oool00ol0VOoo
ooooo`0Ooooo00<0000co`0co`000c?o00030000oooooooo07[oool007_oool00ol0VOooooooo`0O
oooo00<0000co`0co`000c?o00030000oooooooo07[oool007_oool00ol0VOooooooo`0Ooooo00<0
000co`0co`000c?o0080001koooo001koooo00?o09Woooooool07oooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo001koooo00?o09Woooooool07oooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo001koooo00?o09Woooooool08?ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001koooo00?o09Woooooool08?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001k
oooo00?o09Woooooool08?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001koooo00?o
09Woooooool08?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo001koooo00?o09Wooooo
ool08?ooo`030000<ol0<ol0008co`020000Noooo`00Noooo`03o`2Ioooooooo023oool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00Noooo`03o`2Ioooooooo023oool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Noooo`03o`2Ioooooooo023oool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00Noooo`03o`2Ioooooooo023oool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00Noooo`03o`2Ioooooooo023oool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00Noooo`03o`2Ioooooooo023oool00`0003?o03?o0002<ol00P0007_oool007_oool00ol0VOoo
ooooo`0Qoooo00D0000co`0co`0co`000000O?ooo`00Noooo`03o`2Ioooooooo027oool01@0003?o
03?o03?o0000001loooo001koooo00?o09Woooooool08Oooo`050000<ol0<ol0<ol0000007coool0
07_oool00ol0VOooooooo`0Moooo1@0000<co`000`000?ooooooo`1joooo001koooo00?o09Wooooo
ool07Oooo`050000oooooooooooo000000<co`000`000?ooooooo`1joooo001koooo00?o09Wooooo
ool07_ooo`040000oooooooo00000c?o00<0001joooo001koooo00?o09Woooooool07oooo`030000
oooo000000<co`000`000?ooooooo`1joooo001koooo00?o09Woooooool07Oooo`030000oooooooo
00800003<ol000<0003oooooool0N_ooo`00Noooo`03o`2Ioooooooo01koool2000000?oool0000c
o`000S?o00030000oooooooo07[oool007_oool00ol0VOooooooo`0Qoooo00D0000co`0co`0co`00
0000O?ooo`00Noooo`03o`2Ioooooooo02;oool0100003?o03?o000007coool007_oool00ol0VOoo
ooooo`0Roooo00<0000co`0co`000P0007_oool007_oool00ol0VOooooooo`0Roooo00@0000co`0c
o`00001loooo001koooo00?o09Woooooool08_ooo`040000<ol0<ol00000O?ooo`00Noooo`03o`2I
oooooooo02;oool0100003?o03?o000007coool007_oool00ol0VOooooooo`0Roooo00@0000co`0c
o`00001loooo001koooo00?o09Woooooool08_ooo`040000<ol0<ol00000O?ooo`00Noooo`03o`2I
oooooooo02;oool0100003?o03?o000007coool007_oool00ol0VOooooooo`0Soooo00@0000co`00
0000001koooo001koooo00?o09Woooooool08oooo`030000<ol0000007coool007_oool00ol0VOoo
ooooo`0Soooo00<0000co`000000O?ooo`00Noooo`03o`2Ioooooooo02?oool00`0003?o0000001l
oooo001koooo00?o09Woooooool08oooo`030000<ol0000007coool007_oool00ol0VOooooooo`0S
oooo00<0000co`000000O?ooo`00Noooo`03o`2Ioooooooo02?oool0100003?o0000000007_oool0
07_oool00ol0VOooooooo`0Soooo00<0000co`000000O?ooo`00Noooo`03o`2Ioooooooo02?oool0
0`0003?o0000001loooo001koooo00?o09Woooooool08oooo`030000<ol0000007coool007_oool0
0ol0VOooooooo`0Soooo00<0000co`000000O?ooo`00Noooo`03o`2Ioooooooo02?oool00`0003?o
0000001loooo001koooo00?o09Woooooool08oooo`040000<ol000000000Noooo`00Noooo`03o`2I
oooooooo02?oool00`0003?o0000001loooo001koooo00?o09Woooooool08oooo`030000<ol00000
07coool007_oool00ol0VOooooooo`0Soooo00<0000co`000000O?ooo`00Noooo`03o`2Ioooooooo
01koool200000oooo`030000<ol0000007coool007_oool00ol0VOooooooo`0Moooo00@0003ooooo
ool00002oooo00<0000co`000000O?ooo`00Noooo`03o`2Ioooooooo01ooool01P000?oooooooooo
o`0003?o00<0001joooo001koooo00?o09Woooooool08?ooo`060000oooooooo0000<ol00000O?oo
o`00Noooo`03o`2Ioooooooo01goool010000?ooooooo`0000;oool00`0003?o0000001loooo001k
oooo00?o09Woooooool07_ooo`800004oooo0P0007coool007_oool00ol0VOooooooo`0Toooo0P00
07coool007_oool00ol0VOooooooo`0Toooo0P0007coool007_oool00ol0VOooooooo`0Toooo0P00
07coool007_oool00ol0VOooooooo`0Toooo0`0007_oool007_oool00ol0VOooooooo`0Toooo0P00
07coool007_oool00ol0VOooooooo`0Toooo0P0007coool007_oool00ol0VOooooooo`0Toooo0P00
07coool007_oool00ol0VOooooooo`0Toooo0P0007coool007_oool00ol0VOooooooo`0Toooo0P00
07coool007_oool00ol0VOooooooo`0Toooo0`0007_oool007_oool00ol0VOooooooo`0Toooo0P00
07coool007_oool00ol0VOooooooo`0Toooo0P0007coool007_oool00ol0VOooooooo`0Toooo0P00
07coool007_oool00ol0VOooooooo`0Toooo0P0007coool007_oool00ol0VOooooooo`0Toooo0P00
07coool007_oool00ol0VOooooooo`0Toooo0`0007_oool007_oool00ol0VOooooooo`0Uoooo00<0
003oooooool0N_ooo`00Noooo`03o`2Ioooooooo02Goool00`000?ooooooo`1joooo001koooo00?o
09Woooooool09Oooo`030000oooooooo07[oool007_oool00ol0VOooooooo`0Uoooo00<0003ooooo
ool0N_ooo`00Noooo`03o`2Ioooooooo02Goool00`000?ooooooo`1joooo001koooo00?o09Wooooo
ool09Oooo`80001koooo001koooo00?o09Woooooool09Oooo`030000oooooooo07[oool007_oool0
0ol0VOooooooo`0Uoooo00<0003oooooool0N_ooo`00Noooo`03o`2Ioooooooo02Goool00`000?oo
ooooo`1joooo001koooo00?o09Woooooool09Oooo`030000oooooooo07[oool007_oool00ol0VOoo
ooooo`0Ooooo0`0000?oool00`000?ooooooo`1joooo001koooo00?o09Woooooool08?ooo`030000
oooooooo00;oool00`000?ooooooo`1joooo001koooo00?o09Woooooool07Oooo`D00003oooo0`00
07[oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00
087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Woool00`000?ooooooo`1koooo001j
oooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`09oooo00<0003ooooo
ool0N_ooo`00Noooo`030000oooooooo00D0000Eoooo00<0003oooooool01oooo`030000oooooooo
07_oool007_oool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009oooo00<0003ooooo
ool0Noooo`00O?ooo`030000oooooooo01Ooool200002Oooo`030000oooooooo07coool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.41696 .12361 L
.42237 .12361 L
.42482 .12361 L
.42617 .12361 L
.42744 .12361 L
.42816 .12361 L
s
.42816 .12361 m
.42847 .61803 L
s
0 .4 1 r
.02381 .12469 m
.04262 .12512 L
.06244 .12575 L
.07286 .12619 L
.08255 .12668 L
.09388 .12737 L
.10458 .12816 L
.125 .13015 L
.14357 .13272 L
.16355 .13662 L
.18199 .14168 L
.20071 .14884 L
.21136 .15412 L
.22134 .16005 L
.24158 .17588 L
.26011 .19633 L
.26487 .20277 L
.26749 .20655 L
.26877 .20847 L
.26995 .2101 L
.27107 .21008 L
.27226 .21006 L
.27475 .21002 L
.27909 .20994 L
.2891 .20973 L
.29982 .20946 L
.31946 .20881 L
.33779 .20796 L
.34796 .20736 L
.35903 .20656 L
.36859 .20574 L
.37915 .20465 L
.39893 .20197 L
.40976 .20006 L
.41462 .19908 L
.41993 .1979 L
.4224 .19732 L
.42503 .19666 L
.4263 .19634 L
.42751 .19602 L
.42859 .12361 L
.42976 .12361 L
.43101 .12361 L
.43172 .12361 L
.43238 .12361 L
.43308 .12361 L
.43372 .12361 L
.43445 .12361 L
.43515 .12361 L
.43638 .12361 L
Mistroke
.43753 .12361 L
.43878 .12361 L
.43948 .12361 L
.44012 .12361 L
.44128 .12361 L
.4425 .12361 L
.44355 .12361 L
.4447 .12361 L
.44594 .12361 L
.44663 .12361 L
.44726 .12361 L
.44849 .12361 L
.44965 .12361 L
.45073 .12361 L
.45188 .12361 L
.45287 .12361 L
.45395 .12361 L
.45511 .12361 L
.45636 .12361 L
.45754 .12361 L
.45862 .12361 L
.4598 .12361 L
.46107 .12361 L
.46227 .12361 L
.46338 .12361 L
.46467 .12361 L
.46532 .12361 L
.46604 .12361 L
.46728 .12361 L
.46845 .12361 L
.46963 .12361 L
.47075 .12361 L
.47176 .12361 L
.47286 .12361 L
.47404 .12361 L
.47531 .12361 L
.47639 .12361 L
.47758 .12361 L
.47889 .12361 L
.47954 .12361 L
.48026 .12361 L
.48153 .12361 L
.48272 .12361 L
.48344 .12361 L
.48412 .12361 L
.4854 .12361 L
.48611 .12361 L
.48677 .12361 L
.4875 .12361 L
.48826 .12361 L
Mistroke
.48945 .12361 L
.49073 .12361 L
.49194 .12361 L
.49304 .12361 L
.49433 .12361 L
.49506 .12361 L
.49573 .12361 L
.49698 .12361 L
.4983 .12361 L
.5033 .12361 L
.50463 .12361 L
.50537 .12361 L
.50604 .12361 L
.50735 .12361 L
.50859 .12361 L
.50928 .12361 L
.50992 .12361 L
.51062 .12361 L
.51136 .12361 L
.5121 .12361 L
.5128 .12361 L
.51357 .12361 L
.51439 .12361 L
.51504 .12361 L
.51575 .12361 L
.51649 .12361 L
.51717 .12361 L
.51841 .12361 L
.51972 .12361 L
.52038 .12361 L
.52108 .12361 L
.52233 .12361 L
.52303 .12361 L
.52368 .12361 L
.5244 .12361 L
.52516 .12361 L
.52582 .12361 L
.52654 .12361 L
.52785 .12361 L
.52912 .12361 L
.5303 .12361 L
.53156 .12361 L
.53274 .12361 L
.5338 .12361 L
.53495 .12361 L
.5362 .12361 L
.53684 .12361 L
.53753 .12361 L
.53876 .12361 L
.5399 .12361 L
Mistroke
.54117 .12361 L
.54181 .12361 L
.54251 .12361 L
.54376 .12361 L
.54493 .12361 L
.54563 .12361 L
.5463 .12361 L
.54756 .12361 L
.54826 .12361 L
.54891 .12361 L
.54963 .12361 L
.55039 .12361 L
.55167 .12361 L
.5524 .12361 L
.55307 .12361 L
.55429 .12361 L
.55559 .12361 L
.55675 .12361 L
.55784 .12361 L
.55903 .12361 L
.56031 .12361 L
.56146 .12361 L
.5627 .12361 L
.56334 .12361 L
.56404 .12361 L
.56529 .12361 L
.56647 .12361 L
.56773 .12361 L
.56893 .12361 L
.57002 .12361 L
.57109 .12361 L
.57208 .12361 L
.57317 .12361 L
.57434 .12361 L
.57556 .12361 L
.57672 .12361 L
.57775 .12361 L
.57888 .12361 L
.58011 .12361 L
.58123 .12361 L
.58377 .12361 L
.58834 .12361 L
.59875 .12361 L
.61979 .12361 L
.65953 .12361 L
.69777 .12361 L
.73845 .12361 L
.77762 .12361 L
.81924 .12361 L
.85935 .12361 L
Mistroke
.89794 .12361 L
.93898 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0706Ko00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo000000T000000`1Vo`0000000004000000<co`00000co`0023?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo01Goool002[oool00`00001Vo`1Vo`0606Ko8?ooo`030000oooooooo
02Goool00`000?ooo`1Vo`06oooo100001/co`000`000?ooooooo`0Uoooo00<0003oooooool09_oo
o`030000oooooooo02Woool003?oool506KoAOooo`0306Kooooooooo00Soool400005c?o00030000
oooooooo07[oool003Soool406Ko@Oooo`0306Kooooooooo00coool00`0003?o03?o000D<ol000<0
003oooooool0N_ooo`00??ooo`@0I_lmoooo00<0I_ooooooool03Oooo`80000D<ol000<0003ooooo
ool0N_ooo`00@?ooo`80I_lkoooo00<0I_ooooooool03oooo`030000<ol0<ol0014co`000`000?oo
ooooo`1joooo0012oooo0`1VocSoool00`1Vooooooooo`0@oooo00<0000co`0co`0043?o0080001k
oooo0015oooo0P1VocKoool00`1Vooooooooo`0Aoooo0P00010co`000`000?ooooooo`1joooo0017
oooo00<0I_ooooooool0<oooo`0306Kooooooooo01?oool00`0003?o03?o000=<ol000<0003ooooo
ool0N_ooo`00B?ooo`0306Kooooooooo03;oool00`1Vooooooooo`0Coooo00<0000co`0co`003C?o
00030000oooooooo07[oool004Woool00`1Vooooooooo`0aoooo00<0I_ooooooool05?ooo`030000
<ol0<ol000`co`000`000?ooooooo`1joooo001:oooo0P1Voc7oool00`1Vooooooooo`0Doooo00<0
000co`0co`0033?o00030000oooooooo07[oool004coool00`1Vooooooooo`0^oooo00<0I_oooooo
ool05Oooo`030000<ol0<ol000/co`020000Noooo`00COooo`0306Kooooooooo02goool00`1Voooo
ooooo`0Eoooo00<0000co`0co`002c?o00030000oooooooo07[oool004koool00`1Vooooooooo`0/
oooo00<0I_ooooooool05_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo001?oooo00<0
I_ooooooool0:oooo`0306Kooooooooo01Koool00`0003?o03?o000:<ol000<0003oooooool0N_oo
o`00D?ooo`0306Kooooooooo02[oool00`1Vooooooooo`0Goooo00<0000co`0co`002C?o00030000
oooooooo07[oool0057oool00`1Vooooooooo`0Yoooo00<0I_ooooooool05oooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1joooo001Boooo00<0I_ooooooool09_ooo`<0I_lJoooo00<0000co`0c
o`0023?o0080001koooo001Coooo00<0I_ooooooool07Oooo`P0I_l2oooo00?o09Woooooool06?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`1joooo001Doooo00<0I_ooooooool04oooo`T0I_l:
oooo00?o09Woooooool06?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1joooo001Doooo5P1V
oa?oool00ol0VOooooooo`0Ioooo00<0000co`0co`001c?o00030000oooooooo07[oool007goool0
0ol0VOooooooo`0Ioooo00<0000co`0co`001c?o00030000oooooooo07[oool007goool00ol0VOoo
ooooo`0Ioooo00<0000co`0co`001c?o00030000oooooooo07[oool007goool00ol0VOooooooo`0I
oooo00<0000co`0co`001c?o0080001koooo001moooo00?o09Woooooool06_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`1joooo001moooo00?o09Woooooool06_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1joooo001moooo00?o09Woooooool06_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1joooo001moooo00?o09Woooooool06_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1j
oooo001moooo00?o09Woooooool06oooo`D00003<ol000<0003oooooool0N_ooo`00OOooo`03o`2I
oooooooo01_oool00`0003?o00000005<ol000<0003oooooool0N_ooo`00OOooo`03o`2Ioooooooo
01_oool00`0003?o00000005<ol00`0007[oool007goool00ol0VOooooooo`0Loooo0P0000Dco`00
0`000?ooooooo`1joooo001moooo00?o09Woooooool07?ooo`800005<ol000<0003oooooool0N_oo
o`00OOooo`03o`2Ioooooooo01coool200001C?o00030000oooooooo07[oool007goool00ol0VOoo
ooooo`0Loooo00<0000co`0co`0013?o00030000oooooooo07[oool007goool00ol0VOooooooo`0L
oooo00<0000co`0co`0013?o00030000oooooooo07[oool007goool00ol0VOooooooo`0Loooo00<0
000co`0co`0013?o0080001koooo001moooo00?o09Woooooool07Oooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo001moooo00?o09Woooooool07Oooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo001moooo00?o09Woooooool07Oooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo001moooo00?o09Woooooool07Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001m
oooo00?o09Woooooool07Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo001moooo00?o
09Woooooool07Oooo`030000<ol0<ol000<co`020000Noooo`00OOooo`03o`2Ioooooooo01goool0
0`0003?o03?o0003<ol000<0003oooooool0N_ooo`00OOooo`03o`2Ioooooooo01goool00`0003?o
03?o0003<ol000<0003oooooool0N_ooo`00OOooo`03o`2Ioooooooo01koool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00OOooo`03o`2Ioooooooo01koool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00OOooo`03o`2Ioooooooo01koool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00OOooo`03o`2Ioooooooo01koool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00OOooo`03o`2Ioooooooo01koool00`0003?o03?o0002<ol00P0007_oool007goool00ol0VOoo
ooooo`0Noooo00<0000co`0co`000S?o00030000oooooooo07[oool007goool00ol0VOooooooo`0N
oooo00<0000co`0co`000S?o00030000oooooooo07[oool007goool00ol0VOooooooo`0Noooo00<0
000co`0co`000S?o00030000oooooooo07[oool007goool00ol0VOooooooo`0Noooo00<0000co`0c
o`000S?o00030000oooooooo07[oool007goool00ol0VOooooooo`0Noooo00<0000co`0co`000S?o
00030000oooooooo07[oool007goool00ol0VOooooooo`0Noooo00<0000co`0co`000S?o0080001k
oooo001moooo00?o09Woooooool07oooo`050000<ol0<ol0<ol0000007coool007goool00ol0VOoo
ooooo`0Ooooo00D0000co`0co`0co`000000O?ooo`00OOooo`03o`2Ioooooooo01ooool01@0003?o
03?o03?o0000001loooo001moooo00?o09Woooooool06oooo`D00003<ol000<0003oooooool0N_oo
o`00OOooo`03o`2Ioooooooo01_oool01@000?ooooooooooo`000003<ol000<0003oooooool0N_oo
o`00OOooo`03o`2Ioooooooo01coool010000?ooooooo`0000<co`030000N_ooo`00OOooo`03o`2I
oooooooo01goool00`000?ooo`000003<ol000<0003oooooool0N_ooo`00OOooo`03o`2Ioooooooo
01_oool00`000?ooooooo`0200000c?o00030000oooooooo07[oool007goool00ol0VOooooooo`0L
oooo0P000003oooo0000<ol0008co`000`000?ooooooo`1joooo001moooo00?o09Woooooool07ooo
o`050000<ol0<ol0<ol0000007coool007goool00ol0VOooooooo`0Poooo00@0000co`0co`00001l
oooo001moooo00?o09Woooooool08?ooo`030000<ol0<ol00080001koooo001moooo00?o09Wooooo
ool08?ooo`040000<ol0<ol00000O?ooo`00OOooo`03o`2Ioooooooo023oool0100003?o03?o0000
07coool007goool00ol0VOooooooo`0Poooo00@0000co`0co`00001loooo001moooo00?o09Wooooo
ool08?ooo`040000<ol0<ol00000O?ooo`00OOooo`03o`2Ioooooooo023oool0100003?o03?o0000
07coool007goool00ol0VOooooooo`0Poooo00@0000co`0co`00001loooo001moooo00?o09Wooooo
ool08Oooo`040000<ol000000000Noooo`00OOooo`03o`2Ioooooooo027oool00`0003?o0000001l
oooo001moooo00?o09Woooooool08Oooo`030000<ol0000007coool007goool00ol0VOooooooo`0Q
oooo00<0000co`000000O?ooo`00OOooo`03o`2Ioooooooo027oool00`0003?o0000001loooo001m
oooo00?o09Woooooool08Oooo`030000<ol0000007coool007goool00ol0VOooooooo`0Qoooo00@0
000co`000000001koooo001moooo00?o09Woooooool08Oooo`030000<ol0000007coool007goool0
0ol0VOooooooo`0Qoooo00<0000co`000000O?ooo`00OOooo`03o`2Ioooooooo027oool00`0003?o
0000001loooo001moooo00?o09Woooooool08Oooo`030000<ol0000007coool007goool00ol0VOoo
ooooo`0Qoooo00<0000co`000000O?ooo`00OOooo`03o`2Ioooooooo027oool0100003?o00000000
07_oool007goool00ol0VOooooooo`0Qoooo00<0000co`000000O?ooo`00OOooo`03o`2Ioooooooo
027oool00`0003?o0000001loooo001moooo00?o09Woooooool08Oooo`030000<ol0000007coool0
07goool00ol0VOooooooo`0Loooo0P0000?oool00`0003?o0000001loooo001moooo00?o09Wooooo
ool06oooo`040000oooooooo00000_ooo`030000<ol0000007coool007goool00ol0VOooooooo`0M
oooo00H0003oooooooooool0000co`030000N_ooo`00OOooo`03o`2Ioooooooo01koool01P000?oo
ooooo`0003?o000007coool007goool00ol0VOooooooo`0Koooo00@0003oooooool00002oooo00<0
000co`000000O?ooo`00OOooo`03o`2Ioooooooo01coool200001?ooo`80001loooo001moooo00?o
09Woooooool08_ooo`80001loooo001moooo00?o09Woooooool08_ooo`80001loooo001moooo00?o
09Woooooool08_ooo`80001loooo001moooo00?o09Woooooool08_ooo`<0001koooo001moooo00?o
09Woooooool08_ooo`80001loooo001moooo00?o09Woooooool08_ooo`80001loooo001moooo00?o
09Woooooool08_ooo`80001loooo001moooo00?o09Woooooool08_ooo`80001loooo001moooo00?o
09Woooooool08_ooo`80001loooo001moooo00?o09Woooooool08_ooo`<0001koooo001moooo00?o
09Woooooool08_ooo`80001loooo001moooo00?o09Woooooool08_ooo`80001loooo001moooo00?o
09Woooooool08_ooo`80001loooo001moooo00?o09Woooooool08_ooo`80001loooo001moooo00?o
09Woooooool08_ooo`80001loooo001moooo00?o09Woooooool08_ooo`<0001koooo001moooo00?o
09Woooooool08oooo`030000oooooooo07[oool007goool00ol0VOooooooo`0Soooo00<0003ooooo
ool0N_ooo`00OOooo`03o`2Ioooooooo02?oool00`000?ooooooo`1joooo001moooo00?o09Wooooo
ool08oooo`030000oooooooo07[oool007goool00ol0VOooooooo`0Soooo00<0003oooooool0N_oo
o`00OOooo`03o`2Ioooooooo02?oool20000Noooo`00OOooo`03o`2Ioooooooo02?oool00`000?oo
ooooo`1joooo001moooo00?o09Woooooool08oooo`030000oooooooo07[oool007goool00ol0VOoo
ooooo`0Soooo00<0003oooooool0N_ooo`00OOooo`03o`2Ioooooooo02?oool00`000?ooooooo`1j
oooo001moooo00?o09Woooooool07Oooo`<00003oooo00<0003oooooool0N_ooo`00OOooo`03o`2I
oooooooo01koool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00OOooo`03o`2Ioooooooo
01_oool500000oooo`<0001joooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool0
0000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool4
00000oooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool00`000?ooooooo`0;
oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0
003oooooool05?ooo`030000oooooooo00Woool300001?ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500005?ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.42237 .12361 L
.42781 .12361 L
.43049 .12361 L
.43298 .12361 L
.43522 .12361 L
.43648 .12361 L
s
.43648 .12361 m
.43693 .61803 L
s
0 .4 1 r
.02381 .12454 m
.04262 .12492 L
.06244 .12547 L
.07286 .12585 L
.08255 .12627 L
.09388 .12687 L
.10458 .12756 L
.125 .12929 L
.14357 .13152 L
.16355 .1349 L
.18199 .1393 L
.20071 .14551 L
.21136 .15009 L
.22134 .15524 L
.24158 .16899 L
.26011 .18673 L
.2693 .19796 L
.27434 .20496 L
.27555 .20672 L
.27682 .20863 L
.2779 .21009 L
.27909 .21007 L
.2818 .21002 L
.28473 .20997 L
.28984 .20987 L
.29982 .20965 L
.31933 .20909 L
.33027 .20867 L
.34024 .20822 L
.35933 .2071 L
.37011 .20627 L
.38009 .20535 L
.39875 .20313 L
.4095 .20148 L
.41935 .19966 L
.42878 .1976 L
.43352 .19643 L
.43482 .1961 L
.43553 .19591 L
.4362 .19573 L
.43751 .12361 L
.4387 .12361 L
.43991 .12361 L
.44059 .12361 L
.44123 .12361 L
.44252 .12361 L
.44325 .12361 L
.44391 .12361 L
.44509 .12361 L
.44637 .12361 L
Mistroke
.44758 .12361 L
.44871 .12361 L
.44939 .12361 L
.45013 .12361 L
.45083 .12361 L
.45147 .12361 L
.45268 .12361 L
.45396 .12361 L
.45463 .12361 L
.45534 .12361 L
.45663 .12361 L
.45742 .12361 L
.45816 .12361 L
.45889 .12361 L
.45956 .12361 L
.4607 .12361 L
.46193 .12361 L
.46302 .12361 L
.46416 .12361 L
.46533 .12361 L
.46659 .12361 L
.46731 .12361 L
.46796 .12361 L
.46924 .12361 L
.47056 .12361 L
.47177 .12361 L
.47241 .12361 L
.47311 .12361 L
.47384 .12361 L
.47452 .12361 L
.47578 .12361 L
.47693 .12361 L
.47756 .12361 L
.47825 .12361 L
.47951 .12361 L
.48064 .12361 L
.48171 .12361 L
.48288 .12361 L
.48415 .12361 L
.4854 .12361 L
.48672 .12361 L
.48784 .12361 L
.48908 .12361 L
.49024 .12361 L
.49129 .12361 L
.49251 .12361 L
.49367 .12361 L
.49473 .12361 L
.49572 .12361 L
.4968 .12361 L
Mistroke
.49794 .12361 L
.49915 .12361 L
.50046 .12361 L
.50171 .12361 L
.50286 .12361 L
.504 .12361 L
.50504 .12361 L
.50623 .12361 L
.50736 .12361 L
.50859 .12361 L
.5099 .12361 L
.51101 .12361 L
.51223 .12361 L
.51354 .12361 L
.51428 .12361 L
.51495 .12361 L
.51625 .12361 L
.51749 .12361 L
.51854 .12361 L
.5197 .12361 L
.52091 .12361 L
.52205 .12361 L
.5231 .12361 L
.52407 .12361 L
.52514 .12361 L
.52626 .12361 L
.5274 .12361 L
.52862 .12361 L
.52977 .12361 L
.53081 .12361 L
.53204 .12361 L
.53274 .12361 L
.53338 .12361 L
.53455 .12361 L
.53579 .12361 L
.53701 .12361 L
.53833 .12361 L
.53958 .12361 L
.54073 .12361 L
.54188 .12361 L
.54292 .12361 L
.54411 .12361 L
.54524 .12361 L
.54648 .12361 L
.54778 .12361 L
.5489 .12361 L
.55012 .12361 L
.55143 .12361 L
.55217 .12361 L
.55284 .12361 L
Mistroke
.55415 .12361 L
.55538 .12361 L
.55644 .12361 L
.55758 .12361 L
.55866 .12361 L
.55965 .12361 L
.56075 .12361 L
.5618 .12361 L
.56293 .12361 L
.56417 .12361 L
.56541 .12361 L
.56611 .12361 L
.56674 .12361 L
.56796 .12361 L
.56912 .12361 L
.57027 .12361 L
.57132 .12361 L
.57248 .12361 L
.5737 .12361 L
.57492 .12361 L
.57561 .12361 L
.57624 .12361 L
.57741 .12361 L
.57866 .12361 L
.57976 .12361 L
.5808 .12361 L
.58317 .12361 L
.59333 .12361 L
.61166 .12361 L
.65034 .12361 L
.69146 .12361 L
.73108 .12361 L
.76917 .12361 L
.80972 .12361 L
.84875 .12361 L
.89024 .12361 L
.93021 .12361 L
.96866 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0706Ko00@00000I_l0I_l0I_l6oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oool000002`00000306Ko00000000008000000c?o000003?o0008<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool05Oooo`00:_ooo`040000oooooooooooo2P1Voa_oool00`000?oo
ooooo`0Uoooo00D0003oooooooooool0I_l01?ooo`@0000K<ol000<0003oooooool09Oooo`030000
oooooooo02Koool00`000?ooooooo`0Yoooo000hoooo101Vod?oool00`1Vooooooooo`06oooo1000
01Lco`000`000?ooooooo`1joooo000loooo101Vocooool00`1Vooooooooo`0:oooo00<0000co`0c
o`0053?o00030000oooooooo07[oool0043oool206Ko?Oooo`0306Kooooooooo00_oool2000053?o
00030000oooooooo07[oool004;oool306Ko>_ooo`0306Kooooooooo00goool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00AOooo`80I_lhoooo00<0I_ooooooool03_ooo`030000<ol0<ol0
010co`020000Noooo`00Aoooo`80I_lfoooo00<0I_ooooooool03oooo`80000@<ol000<0003ooooo
ool0N_ooo`00BOooo`0306Kooooooooo03?oool00`1Vooooooooo`0Aoooo00<0000co`0co`003C?o
00030000oooooooo07[oool004[oool206Ko<oooo`0306Kooooooooo017oool00`0003?o03?o000=
<ol000<0003oooooool0N_ooo`00C?ooo`0306Kooooooooo033oool00`1Vooooooooo`0Boooo00<0
000co`0co`0033?o00030000oooooooo07[oool004goool00`1Vooooooooo`0_oooo00<0I_oooooo
ool04_ooo`030000<ol0<ol000`co`000`000?ooooooo`1joooo001>oooo00<0I_ooooooool0;_oo
o`0306Kooooooooo01?oool00`0003?o03?o000;<ol00P0007_oool004ooool206Ko;_ooo`0306Ko
oooooooo01?oool00`0003?o03?o000;<ol000<0003oooooool0N_ooo`00DOooo`0306Kooooooooo
02_oool00`1Vooooooooo`0Doooo00<0000co`0co`002S?o00030000oooooooo07[oool005;oool0
0`1Vooooooooo`0Zoooo00<0I_ooooooool05?ooo`030000<ol0<ol000Xco`000`000?ooooooo`1j
oooo001Coooo00<0I_ooooooool0:Oooo`0306Kooooooooo01Goool00`0003?o03?o0009<ol000<0
003oooooool0N_ooo`00Doooo`0306Kooooooooo02Woool00`1Vooooooooo`0Eoooo00<0000co`0c
o`002C?o00030000oooooooo07[oool005Coool00`1Vooooooooo`0Voooo0`1VoaSoool00`0003?o
03?o0008<ol00P0007_oool005Goool00`1Vooooooooo`0Ooooo1P1Vo`;oool00ol0VOooooooo`0F
oooo00<0000co`0co`0023?o00030000oooooooo07[oool005Koool00`1Vooooooooo`0Doooo2P1V
o`Soool00ol0VOooooooo`0Foooo00<0000co`0co`0023?o00030000oooooooo07[oool005KooolG
06Ko4_ooo`03o`2Ioooooooo01Ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Oooo
o`03o`2Ioooooooo01Ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Ooooo`03o`2I
oooooooo01Ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo
01Ooool00`0003?o03?o0007<ol00P0007_oool007ooool00ol0VOooooooo`0Hoooo00<0000co`0c
o`001S?o00030000oooooooo07[oool007ooool00ol0VOooooooo`0Hoooo00<0000co`0co`001S?o
00030000oooooooo07[oool007ooool00ol0VOooooooo`0Hoooo00<0000co`0co`001S?o00030000
oooooooo07[oool007ooool00ol0VOooooooo`0Hoooo00<0000co`0co`001S?o00030000oooooooo
07[oool007ooool00ol0VOooooooo`0Ioooo1@0000<co`000`000?ooooooo`1joooo001ooooo00?o
09Woooooool06Oooo`030000<ol0000000Dco`000`000?ooooooo`1joooo001ooooo00?o09Wooooo
ool06Oooo`030000<ol0000000Dco`030000N_ooo`00Ooooo`03o`2Ioooooooo01[oool200001C?o
00030000oooooooo07[oool007ooool00ol0VOooooooo`0Joooo0P0000Dco`000`000?ooooooo`1j
oooo001ooooo00?o09Woooooool06_ooo`800005<ol000<0003oooooool0N_ooo`00Ooooo`03o`2I
oooooooo01[oool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo
01[oool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo01[oool0
0`0003?o03?o0004<ol00P0007_oool007ooool00ol0VOooooooo`0Koooo00<0000co`0co`000c?o
00030000oooooooo07[oool007ooool00ol0VOooooooo`0Koooo00<0000co`0co`000c?o00030000
oooooooo07[oool007ooool00ol0VOooooooo`0Koooo00<0000co`0co`000c?o00030000oooooooo
07[oool007ooool00ol0VOooooooo`0Koooo00<0000co`0co`000c?o00030000oooooooo07[oool0
07ooool00ol0VOooooooo`0Koooo00<0000co`0co`000c?o00030000oooooooo07[oool007ooool0
0ol0VOooooooo`0Koooo00<0000co`0co`000c?o0080001koooo001ooooo00?o09Woooooool06ooo
o`030000<ol0<ol000<co`000`000?ooooooo`1joooo001ooooo00?o09Woooooool06oooo`030000
<ol0<ol000<co`000`000?ooooooo`1joooo001ooooo00?o09Woooooool07?ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo001ooooo00?o09Woooooool07?ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo001ooooo00?o09Woooooool07?ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo001ooooo00?o09Woooooool07?ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo001ooooo00?o09Woooooool07?ooo`030000<ol0<ol0008co`020000Noooo`00Ooooo`03o`2I
oooooooo01coool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo
01coool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo01coool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo01coool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo01coool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo01coool00`0003?o03?o0002<ol00P00
07_oool007ooool00ol0VOooooooo`0Moooo00D0000co`0co`0co`000000O?ooo`00Ooooo`03o`2I
oooooooo01goool01@0003?o03?o03?o0000001loooo001ooooo00?o09Woooooool07Oooo`050000
<ol0<ol0<ol0000007coool007ooool00ol0VOooooooo`0Ioooo1@0000<co`000`000?ooooooo`1j
oooo001ooooo00?o09Woooooool06Oooo`050000oooooooooooo000000<co`000`000?ooooooo`1j
oooo001ooooo00?o09Woooooool06_ooo`040000oooooooo00000c?o00<0001joooo001ooooo00?o
09Woooooool06oooo`030000oooo000000<co`000`000?ooooooo`1joooo001ooooo00?o09Wooooo
ool06Oooo`030000oooooooo00800003<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo
01[oool2000000?oool0000co`000S?o00030000oooooooo07[oool007ooool00ol0VOooooooo`0M
oooo00D0000co`0co`0co`000000O?ooo`00Ooooo`03o`2Ioooooooo01koool0100003?o03?o0000
07coool007ooool00ol0VOooooooo`0Noooo00<0000co`0co`000P0007_oool007ooool00ol0VOoo
ooooo`0Noooo00@0000co`0co`00001loooo001ooooo00?o09Woooooool07_ooo`040000<ol0<ol0
0000O?ooo`00Ooooo`03o`2Ioooooooo01koool0100003?o03?o000007coool007ooool00ol0VOoo
ooooo`0Noooo00@0000co`0co`00001loooo001ooooo00?o09Woooooool07_ooo`040000<ol0<ol0
0000O?ooo`00Ooooo`03o`2Ioooooooo01koool0100003?o03?o000007coool007ooool00ol0VOoo
ooooo`0Ooooo00@0000co`000000001koooo001ooooo00?o09Woooooool07oooo`030000<ol00000
07coool007ooool00ol0VOooooooo`0Ooooo00<0000co`000000O?ooo`00Ooooo`03o`2Ioooooooo
01ooool00`0003?o0000001loooo001ooooo00?o09Woooooool07oooo`030000<ol0000007coool0
07ooool00ol0VOooooooo`0Ooooo00<0000co`000000O?ooo`00Ooooo`03o`2Ioooooooo01ooool0
100003?o0000000007_oool007ooool00ol0VOooooooo`0Ooooo00<0000co`000000O?ooo`00Oooo
o`03o`2Ioooooooo01ooool00`0003?o0000001loooo001ooooo00?o09Woooooool07oooo`030000
<ol0000007coool007ooool00ol0VOooooooo`0Ooooo00<0000co`000000O?ooo`00Ooooo`03o`2I
oooooooo01ooool00`0003?o0000001loooo001ooooo00?o09Woooooool07oooo`040000<ol00000
0000Noooo`00Ooooo`03o`2Ioooooooo01ooool00`0003?o0000001loooo001ooooo00?o09Wooooo
ool07oooo`030000<ol0000007coool007ooool00ol0VOooooooo`0Ooooo00<0000co`000000O?oo
o`00Ooooo`03o`2Ioooooooo01[oool200000oooo`030000<ol0000007coool007ooool00ol0VOoo
ooooo`0Ioooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00Ooooo`03o`2Ioooooooo
01_oool01P000?ooooooooooo`0003?o00<0001joooo001ooooo00?o09Woooooool07?ooo`060000
oooooooo0000<ol00000O?ooo`00Ooooo`03o`2Ioooooooo01Woool010000?ooooooo`0000;oool0
0`0003?o0000001loooo001ooooo00?o09Woooooool06_ooo`800004oooo0P0007coool007ooool0
0ol0VOooooooo`0Poooo0P0007coool007ooool00ol0VOooooooo`0Poooo0P0007coool007ooool0
0ol0VOooooooo`0Poooo0P0007coool007ooool00ol0VOooooooo`0Poooo0`0007_oool007ooool0
0ol0VOooooooo`0Poooo0P0007coool007ooool00ol0VOooooooo`0Poooo0P0007coool007ooool0
0ol0VOooooooo`0Poooo0P0007coool007ooool00ol0VOooooooo`0Poooo0P0007coool007ooool0
0ol0VOooooooo`0Poooo0P0007coool007ooool00ol0VOooooooo`0Poooo0`0007_oool007ooool0
0ol0VOooooooo`0Poooo0P0007coool007ooool00ol0VOooooooo`0Poooo0P0007coool007ooool0
0ol0VOooooooo`0Poooo0P0007coool007ooool00ol0VOooooooo`0Poooo0P0007coool007ooool0
0ol0VOooooooo`0Poooo0P0007coool007ooool00ol0VOooooooo`0Poooo0`0007_oool007ooool0
0ol0VOooooooo`0Qoooo00<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo027oool00`000?oo
ooooo`1joooo001ooooo00?o09Woooooool08Oooo`030000oooooooo07[oool007ooool00ol0VOoo
ooooo`0Qoooo00<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo027oool00`000?ooooooo`1j
oooo001ooooo00?o09Woooooool08Oooo`80001koooo001ooooo00?o09Woooooool08Oooo`030000
oooooooo07[oool007ooool00ol0VOooooooo`0Qoooo00<0003oooooool0N_ooo`00Ooooo`03o`2I
oooooooo027oool00`000?ooooooo`1joooo001ooooo00?o09Woooooool08Oooo`030000oooooooo
07[oool007ooool00ol0VOooooooo`0Koooo0`0000?oool00`000?ooooooo`1joooo001ooooo00?o
09Woooooool07?ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001ooooo00?o09Wooooo
ool06Oooo`D00003oooo0`0007[oool009_oool010000?ooooooo`00087oool009coool00`000?oo
o`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?oo
o`@00003oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`030000oooooooo
00Woool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01Coool00`000?ooooooo`08oooo00@0003oooooool00004oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool02?ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:
oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44021 .12361 L
.44151 .12361 L
.44268 .12361 L
.44387 .12361 L
s
.44387 .12361 m
.44431 .61803 L
s
0 .4 1 r
.02381 .12442 m
.04262 .12474 L
.06244 .12523 L
.07286 .12555 L
.08255 .12592 L
.09388 .12644 L
.10458 .12704 L
.125 .12854 L
.14357 .13048 L
.16355 .13341 L
.18199 .13723 L
.20071 .14262 L
.21136 .14659 L
.22134 .15107 L
.24158 .163 L
.26011 .1784 L
.27008 .18905 L
.27555 .19575 L
.2807 .20269 L
.28304 .20606 L
.28432 .20796 L
.28552 .20978 L
.28681 .21006 L
.2875 .21005 L
.28823 .21004 L
.29073 .21 L
.29982 .20982 L
.3198 .20931 L
.33801 .20866 L
.3571 .20771 L
.36788 .20701 L
.37786 .20624 L
.39652 .20436 L
.41712 .20144 L
.42655 .19971 L
.43647 .19755 L
.43898 .19694 L
.44167 .19626 L
.44246 .19606 L
.44321 .19586 L
.44388 .19568 L
.44461 .12361 L
.4453 .12361 L
.44604 .12361 L
.44735 .12361 L
.44853 .12361 L
.4498 .12361 L
.451 .12361 L
.4521 .12361 L
.45338 .12361 L
Mistroke
.45411 .12361 L
.45478 .12361 L
.45601 .12361 L
.45733 .12361 L
.45857 .12361 L
.45928 .12361 L
.45994 .12361 L
.46064 .12361 L
.46127 .12361 L
.46201 .12361 L
.4627 .12361 L
.46393 .12361 L
.46507 .12361 L
.46631 .12361 L
.46694 .12361 L
.46764 .12361 L
.46834 .12361 L
.46908 .12361 L
.46972 .12361 L
.47041 .12361 L
.47115 .12361 L
.47195 .12361 L
.4727 .12361 L
.47339 .12361 L
.47408 .12361 L
.47472 .12361 L
.47542 .12361 L
.47616 .12361 L
.47741 .12361 L
.47812 .12361 L
.47878 .12361 L
.48003 .12361 L
.48074 .12361 L
.48139 .12361 L
.48259 .12361 L
.48387 .12361 L
.48501 .12361 L
.48608 .12361 L
.48725 .12361 L
.48851 .12361 L
.48978 .12361 L
.4905 .12361 L
.49117 .12361 L
.49187 .12361 L
.49252 .12361 L
.49326 .12361 L
.49396 .12361 L
.49521 .12361 L
.49636 .12361 L
.49762 .12361 L
Mistroke
.49826 .12361 L
.49896 .12361 L
.50025 .12361 L
.50145 .12361 L
.50276 .12361 L
.5035 .12361 L
.50416 .12361 L
.50539 .12361 L
.50671 .12361 L
.50796 .12361 L
.50911 .12361 L
.51022 .12361 L
.51126 .12361 L
.5124 .12361 L
.51362 .12361 L
.5149 .12361 L
.51611 .12361 L
.5172 .12361 L
.51838 .12361 L
.51967 .12361 L
.52089 .12361 L
.52158 .12361 L
.52221 .12361 L
.52291 .12361 L
.52365 .12361 L
.52432 .12361 L
.52503 .12361 L
.52632 .12361 L
.5271 .12361 L
.52785 .12361 L
.52851 .12361 L
.52923 .12361 L
.53044 .12361 L
.53113 .12361 L
.53177 .12361 L
.53307 .12361 L
.53379 .12361 L
.53446 .12361 L
.53564 .12361 L
.53693 .12361 L
.53814 .12361 L
.53927 .12361 L
.54056 .12361 L
.54121 .12361 L
.54193 .12361 L
.54319 .12361 L
.54437 .12361 L
.54508 .12361 L
.54576 .12361 L
.54703 .12361 L
Mistroke
.54774 .12361 L
.54839 .12361 L
.54911 .12361 L
.54987 .12361 L
.55105 .12361 L
.55232 .12361 L
.55342 .12361 L
.55462 .12361 L
.55534 .12361 L
.55602 .12361 L
.55666 .12361 L
.55735 .12361 L
.55866 .12361 L
.55985 .12361 L
.56101 .12361 L
.56224 .12361 L
.5633 .12361 L
.56445 .12361 L
.56569 .12361 L
.56639 .12361 L
.56703 .12361 L
.56826 .12361 L
.56943 .12361 L
.57052 .12361 L
.57168 .12361 L
.57267 .12361 L
.57376 .12361 L
.57493 .12361 L
.57619 .12361 L
.57738 .12361 L
.57847 .12361 L
.57975 .12361 L
.58095 .12361 L
.58321 .12361 L
.58827 .12361 L
.59738 .12361 L
.61808 .12361 L
.65654 .12361 L
.69744 .12361 L
.73683 .12361 L
.77471 .12361 L
.81504 .12361 L
.85385 .12361 L
.89511 .12361 L
.93486 .12361 L
.97309 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0706Ko00@00000I_l0I_l0I_l6oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oool000003@00000506Ko00000000<ol0000000Tco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`0Eoooo000Zoooo00@0003oooooooooool:06Ko6oooo`030000oooooooo02Goool0
0`000?ooooooo`03oooo00<0I_ooooooool0100001/co`000`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000oooooooo02Woool003Soool406KoAOooo`0306Kooooooooo00Coool400005c?o
00030000oooooooo07[oool003coool506Ko@?ooo`0306Kooooooooo00Soool00`0003?o03?o000D
<ol000<0003oooooool0N_ooo`00@Oooo`@0I_lloooo00<0I_ooooooool02Oooo`80000D<ol000<0
003oooooool0N_ooo`00AOooo`80I_ljoooo00<0I_ooooooool02oooo`030000<ol0<ol0014co`00
0`000?ooooooo`1joooo0017oooo0P1VocSoool00`1Vooooooooo`0<oooo00<0000co`0co`0043?o
0080001koooo0019oooo0P1VocKoool00`1Vooooooooo`0=oooo0P00010co`000`000?ooooooo`1j
oooo001;oooo0P1VocCoool00`1Vooooooooo`0?oooo00<0000co`0co`003C?o00030000oooooooo
07[oool004goool00`1Vooooooooo`0aoooo00<0I_ooooooool03oooo`030000<ol0<ol000dco`00
0`000?ooooooo`1joooo001>oooo00<0I_ooooooool0<?ooo`0306Kooooooooo013oool00`0003?o
03?o000<<ol000<0003oooooool0N_ooo`00Coooo`80I_l`oooo00<0I_ooooooool04?ooo`030000
<ol0<ol000`co`000`000?ooooooo`1joooo001Aoooo00<0I_ooooooool0;Oooo`0306Kooooooooo
017oool00`0003?o03?o000;<ol00P0007_oool005;oool00`1Vooooooooo`0/oooo00<0I_oooooo
ool04Oooo`030000<ol0<ol000/co`000`000?ooooooo`1joooo001Coooo00<0I_ooooooool0:ooo
o`0306Kooooooooo01;oool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00E?ooo`0306Ko
oooooooo02[oool00`1Vooooooooo`0Boooo00<0000co`0co`002S?o00030000oooooooo07[oool0
05Goool00`1Vooooooooo`0Yoooo00<0I_ooooooool04oooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1joooo001Eoooo00<0I_ooooooool0:Oooo`0306Kooooooooo01?oool00`0003?o03?o0009
<ol000<0003oooooool0N_ooo`00E_ooo`0306Kooooooooo02Goool406Ko5_ooo`030000<ol0<ol0
00Pco`020000Noooo`00Eoooo`0306Kooooooooo01koool606Ko0oooo`03o`2Ioooooooo01Coool0
0`0003?o03?o0008<ol000<0003oooooool0N_ooo`00F?ooo`0306Kooooooooo01Coool906Ko2Ooo
o`03o`2Ioooooooo01Coool00`0003?o03?o0008<ol000<0003oooooool0N_ooo`00F?oooaL0I_lB
oooo00?o09Woooooool05Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo0021oooo00?o
09Woooooool05Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo0021oooo00?o09Wooooo
ool05Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo0021oooo00?o09Woooooool05Ooo
o`030000<ol0<ol000Lco`020000Noooo`00POooo`03o`2Ioooooooo01Koool00`0003?o03?o0006
<ol000<0003oooooool0N_ooo`00POooo`03o`2Ioooooooo01Koool00`0003?o03?o0006<ol000<0
003oooooool0N_ooo`00POooo`03o`2Ioooooooo01Koool00`0003?o03?o0006<ol000<0003ooooo
ool0N_ooo`00POooo`03o`2Ioooooooo01Koool00`0003?o03?o0006<ol000<0003oooooool0N_oo
o`00POooo`03o`2Ioooooooo01Ooool500000c?o00030000oooooooo07[oool0087oool00ol0VOoo
ooooo`0Goooo00<0000co`0000001C?o00030000oooooooo07[oool0087oool00ol0VOooooooo`0G
oooo00<0000co`0000001C?o00<0001joooo0021oooo00?o09Woooooool06?ooo`800005<ol000<0
003oooooool0N_ooo`00POooo`03o`2Ioooooooo01Soool200001C?o00030000oooooooo07[oool0
087oool00ol0VOooooooo`0Hoooo0P0000Dco`000`000?ooooooo`1joooo0021oooo00?o09Wooooo
ool06?ooo`030000<ol0<ol000@co`000`000?ooooooo`1joooo0021oooo00?o09Woooooool06?oo
o`030000<ol0<ol000@co`000`000?ooooooo`1joooo0021oooo00?o09Woooooool06?ooo`030000
<ol0<ol000@co`020000Noooo`00POooo`03o`2Ioooooooo01Woool00`0003?o03?o0003<ol000<0
003oooooool0N_ooo`00POooo`03o`2Ioooooooo01Woool00`0003?o03?o0003<ol000<0003ooooo
ool0N_ooo`00POooo`03o`2Ioooooooo01Woool00`0003?o03?o0003<ol000<0003oooooool0N_oo
o`00POooo`03o`2Ioooooooo01Woool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00POoo
o`03o`2Ioooooooo01Woool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00POooo`03o`2I
oooooooo01Woool00`0003?o03?o0003<ol00P0007_oool0087oool00ol0VOooooooo`0Ioooo00<0
000co`0co`000c?o00030000oooooooo07[oool0087oool00ol0VOooooooo`0Ioooo00<0000co`0c
o`000c?o00030000oooooooo07[oool0087oool00ol0VOooooooo`0Joooo00<0000co`0co`000S?o
00030000oooooooo07[oool0087oool00ol0VOooooooo`0Joooo00<0000co`0co`000S?o00030000
oooooooo07[oool0087oool00ol0VOooooooo`0Joooo00<0000co`0co`000S?o00030000oooooooo
07[oool0087oool00ol0VOooooooo`0Joooo00<0000co`0co`000S?o00030000oooooooo07[oool0
087oool00ol0VOooooooo`0Joooo00<0000co`0co`000S?o0080001koooo0021oooo00?o09Wooooo
ool06_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo0021oooo00?o09Woooooool06_oo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo0021oooo00?o09Woooooool06_ooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo0021oooo00?o09Woooooool06_ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo0021oooo00?o09Woooooool06_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo0021oooo00?o09Woooooool06_ooo`030000<ol0<ol0008co`020000Nooo
o`00POooo`03o`2Ioooooooo01_oool01@0003?o03?o03?o0000001loooo0021oooo00?o09Wooooo
ool06oooo`050000<ol0<ol0<ol0000007coool0087oool00ol0VOooooooo`0Koooo00D0000co`0c
o`0co`000000O?ooo`00POooo`03o`2Ioooooooo01Ooool500000c?o00030000oooooooo07[oool0
087oool00ol0VOooooooo`0Goooo00D0003oooooooooool000000c?o00030000oooooooo07[oool0
087oool00ol0VOooooooo`0Hoooo00@0003oooooool00003<ol00`0007[oool0087oool00ol0VOoo
ooooo`0Ioooo00<0003oool000000c?o00030000oooooooo07[oool0087oool00ol0VOooooooo`0G
oooo00<0003oooooool00P0000<co`000`000?ooooooo`1joooo0021oooo00?o09Woooooool06?oo
o`8000000oooo`0003?o0002<ol000<0003oooooool0N_ooo`00POooo`03o`2Ioooooooo01_oool0
1@0003?o03?o03?o0000001loooo0021oooo00?o09Woooooool07?ooo`040000<ol0<ol00000O?oo
o`00POooo`03o`2Ioooooooo01coool00`0003?o03?o00020000Noooo`00POooo`03o`2Ioooooooo
01coool0100003?o03?o000007coool0087oool00ol0VOooooooo`0Loooo00@0000co`0co`00001l
oooo0021oooo00?o09Woooooool07?ooo`040000<ol0<ol00000O?ooo`00POooo`03o`2Ioooooooo
01coool0100003?o03?o000007coool0087oool00ol0VOooooooo`0Loooo00@0000co`0co`00001l
oooo0021oooo00?o09Woooooool07?ooo`040000<ol0<ol00000O?ooo`00POooo`03o`2Ioooooooo
01goool0100003?o0000000007_oool0087oool00ol0VOooooooo`0Moooo00<0000co`000000O?oo
o`00POooo`03o`2Ioooooooo01goool00`0003?o0000001loooo0021oooo00?o09Woooooool07Ooo
o`030000<ol0000007coool0087oool00ol0VOooooooo`0Moooo00<0000co`000000O?ooo`00POoo
o`03o`2Ioooooooo01goool00`0003?o0000001loooo0021oooo00?o09Woooooool07Oooo`040000
<ol000000000Noooo`00POooo`03o`2Ioooooooo01goool00`0003?o0000001loooo0021oooo00?o
09Woooooool07Oooo`030000<ol0000007coool0087oool00ol0VOooooooo`0Moooo00<0000co`00
0000O?ooo`00POooo`03o`2Ioooooooo01goool00`0003?o0000001loooo0021oooo00?o09Wooooo
ool07Oooo`030000<ol0000007coool0087oool00ol0VOooooooo`0Moooo00@0000co`000000001k
oooo0021oooo00?o09Woooooool07Oooo`030000<ol0000007coool0087oool00ol0VOooooooo`0M
oooo00<0000co`000000O?ooo`00POooo`03o`2Ioooooooo01goool00`0003?o0000001loooo0021
oooo00?o09Woooooool06?ooo`800003oooo00<0000co`000000O?ooo`00POooo`03o`2Ioooooooo
01Ooool010000?ooooooo`0000;oool00`0003?o0000001loooo0021oooo00?o09Woooooool06Ooo
o`060000oooooooooooo0000<ol00`0007[oool0087oool00ol0VOooooooo`0Joooo00H0003ooooo
ool0000co`00001loooo0021oooo00?o09Woooooool05oooo`040000oooooooo00000_ooo`030000
<ol0000007coool0087oool00ol0VOooooooo`0Hoooo0P0000Coool20000O?ooo`00POooo`03o`2I
oooooooo01koool20000O?ooo`00POooo`03o`2Ioooooooo01koool20000O?ooo`00POooo`03o`2I
oooooooo01koool20000O?ooo`00POooo`03o`2Ioooooooo01koool30000Noooo`00POooo`03o`2I
oooooooo01koool20000O?ooo`00POooo`03o`2Ioooooooo01koool20000O?ooo`00POooo`03o`2I
oooooooo01koool20000O?ooo`00POooo`03o`2Ioooooooo01koool20000O?ooo`00POooo`03o`2I
oooooooo01koool20000O?ooo`00POooo`03o`2Ioooooooo01koool30000Noooo`00POooo`03o`2I
oooooooo01koool20000O?ooo`00POooo`03o`2Ioooooooo01koool20000O?ooo`00POooo`03o`2I
oooooooo01koool20000O?ooo`00POooo`03o`2Ioooooooo01koool20000O?ooo`00POooo`03o`2I
oooooooo01koool20000O?ooo`00POooo`03o`2Ioooooooo01koool30000Noooo`00POooo`03o`2I
oooooooo01ooool00`000?ooooooo`1joooo0021oooo00?o09Woooooool07oooo`030000oooooooo
07[oool0087oool00ol0VOooooooo`0Ooooo00<0003oooooool0N_ooo`00POooo`03o`2Ioooooooo
01ooool00`000?ooooooo`1joooo0021oooo00?o09Woooooool07oooo`030000oooooooo07[oool0
087oool00ol0VOooooooo`0Ooooo0P0007_oool0087oool00ol0VOooooooo`0Ooooo00<0003ooooo
ool0N_ooo`00POooo`03o`2Ioooooooo01ooool00`000?ooooooo`1joooo0021oooo00?o09Wooooo
ool07oooo`030000oooooooo07[oool0087oool00ol0VOooooooo`0Ooooo00<0003oooooool0N_oo
o`00POooo`03o`2Ioooooooo01Woool300000oooo`030000oooooooo07[oool0087oool00ol0VOoo
ooooo`0Joooo00<0003oooooool00_ooo`030000oooooooo07[oool0087oool00ol0VOooooooo`0G
oooo1@0000?oool30000N_ooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000oooo0000
087oool009goool20000POooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000
oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1000
00?oool200001Oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool00`000?oo
ooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool05?ooo`030000oooooooo00[oool00`000?ooooooo`03oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool02_ooo`050000oooooooo
oooo000007[oool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002Ooo
o`@00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44268 .12361 L
.44744 .12361 L
.44874 .12361 L
.45013 .12361 L
.45143 .12361 L
s
.45143 .12361 m
.45191 .61803 L
s
0 .4 1 r
.02381 .12431 m
.04262 .12459 L
.06244 .12501 L
.07286 .1253 L
.08255 .12562 L
.09388 .12607 L
.10458 .12658 L
.125 .12789 L
.14357 .12957 L
.16355 .13212 L
.18199 .13543 L
.20071 .14011 L
.21136 .14356 L
.22134 .14744 L
.24158 .1578 L
.26011 .17117 L
.2807 .19225 L
.28586 .19887 L
.29073 .20568 L
.29285 .20885 L
.29392 .21006 L
.29509 .21004 L
.29755 .21 L
.29982 .20996 L
.3183 .20955 L
.33801 .20894 L
.35752 .20808 L
.36846 .20745 L
.37844 .20676 L
.39752 .20506 L
.40739 .20392 L
.41828 .20242 L
.43806 .19884 L
.44327 .19767 L
.44601 .19702 L
.44889 .19629 L
.45012 .19597 L
.45142 .19562 L
.45218 .19542 L
.45286 .12361 L
.45355 .12361 L
.4542 .12361 L
.45541 .12361 L
.45653 .12361 L
.45776 .12361 L
.45906 .12361 L
.46027 .12361 L
.46159 .12361 L
.46284 .12361 L
.46399 .12361 L
Mistroke
.46514 .12361 L
.46618 .12361 L
.46737 .12361 L
.4685 .12361 L
.46974 .12361 L
.47104 .12361 L
.47215 .12361 L
.47337 .12361 L
.47469 .12361 L
.47543 .12361 L
.4761 .12361 L
.4774 .12361 L
.47864 .12361 L
.47969 .12361 L
.48085 .12361 L
.48206 .12361 L
.4832 .12361 L
.48426 .12361 L
.48523 .12361 L
.48629 .12361 L
.48741 .12361 L
.48856 .12361 L
.48978 .12361 L
.49093 .12361 L
.49197 .12361 L
.4932 .12361 L
.4939 .12361 L
.49453 .12361 L
.49571 .12361 L
.49695 .12361 L
.49817 .12361 L
.49885 .12361 L
.49949 .12361 L
.50063 .12361 L
.5019 .12361 L
.50303 .12361 L
.50409 .12361 L
.5052 .12361 L
.50641 .12361 L
.50764 .12361 L
.50834 .12361 L
.50899 .12361 L
.5103 .12361 L
.51104 .12361 L
.51171 .12361 L
.5129 .12361 L
.5142 .12361 L
.51543 .12361 L
.51656 .12361 L
.51762 .12361 L
Mistroke
.51875 .12361 L
.51982 .12361 L
.5208 .12361 L
.52194 .12361 L
.52319 .12361 L
.52437 .12361 L
.52546 .12361 L
.52669 .12361 L
.52786 .12361 L
.5289 .12361 L
.53003 .12361 L
.53126 .12361 L
.53256 .12361 L
.53367 .12361 L
.53489 .12361 L
.5362 .12361 L
.5374 .12361 L
.53803 .12361 L
.53873 .12361 L
.53946 .12361 L
.54014 .12361 L
.54138 .12361 L
.54253 .12361 L
.54378 .12361 L
.5451 .12361 L
.54622 .12361 L
.54741 .12361 L
.54853 .12361 L
.54955 .12361 L
.55075 .12361 L
.55205 .12361 L
.55328 .12361 L
.55441 .12361 L
.55562 .12361 L
.55692 .12361 L
.55814 .12361 L
.55926 .12361 L
.56056 .12361 L
.5613 .12361 L
.56199 .12361 L
.56324 .12361 L
.56394 .12361 L
.56458 .12361 L
.56525 .12361 L
.56597 .12361 L
.56724 .12361 L
.56795 .12361 L
.56862 .12361 L
.56934 .12361 L
.57012 .12361 L
Mistroke
.57079 .12361 L
.57152 .12361 L
.57217 .12361 L
.57285 .12361 L
.57414 .12361 L
.57533 .12361 L
.57654 .12361 L
.57785 .12361 L
.57909 .12361 L
.58024 .12361 L
.58139 .12361 L
.58242 .12361 L
.58474 .12361 L
.59486 .12361 L
.61316 .12361 L
.65321 .12361 L
.69175 .12361 L
.73274 .12361 L
.77222 .12361 L
.81017 .12361 L
.85059 .12361 L
.88948 .12361 L
.93083 .12361 L
.97066 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0706Ko00<00000I_l0I_l01P1Vo`03oooo0000oooo00Soool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo000000l000000`1Voc?o00000009<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo00Koool506Ko6oooo`030000oooooooo02Goool00`000?oo
ooooo`05oooo00<0I_l0000000000P0001/co`000`000?ooooooo`0Uoooo00<0003oooooool09_oo
o`030000oooooooo02Woool003Soool806Ko@oooo`0306Kooooooooo00;oool400005c?o00030000
oooooooo07[oool0043oool206Ko@Oooo`0306Kooooooooo00Koool00`0003?o03?o000D<ol000<0
003oooooool0N_ooo`00@_ooo`D0I_lloooo00<0I_ooooooool01oooo`80000D<ol000<0003ooooo
ool0N_ooo`00Aoooo`80I_ljoooo00<0I_ooooooool02Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`1joooo0019oooo0P1VocSoool00`1Vooooooooo`0:oooo00<0000co`0co`0043?o0080001k
oooo001;oooo0P1VocKoool00`1Vooooooooo`0;oooo0P00010co`000`000?ooooooo`1joooo001=
oooo00<0I_ooooooool0<oooo`0306Kooooooooo00goool00`0003?o03?o000=<ol000<0003ooooo
ool0N_ooo`00C_ooo`80I_lcoooo00<0I_ooooooool03Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1joooo001@oooo0P1Voc7oool00`1Vooooooooo`0>oooo00<0000co`0co`0033?o00030000
oooooooo07[oool005;oool00`1Vooooooooo`0^oooo00<0I_ooooooool03_ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1joooo001Coooo00<0I_ooooooool0;Oooo`0306Kooooooooo00ooool0
0`0003?o03?o000;<ol00P0007_oool005Coool00`1Vooooooooo`0/oooo00<0I_ooooooool03ooo
o`030000<ol0<ol000/co`000`000?ooooooo`1joooo001Doooo00<0I_ooooooool0;?ooo`0306Ko
oooooooo013oool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00EOooo`0306Kooooooooo
02_oool00`1Vooooooooo`0@oooo00<0000co`0co`002S?o00030000oooooooo07[oool005Koool0
0`1Vooooooooo`0Zoooo00<0I_ooooooool04Oooo`030000<ol0<ol000Tco`000`000?ooooooo`1j
oooo001Goooo00<0I_ooooooool0:Oooo`0306Kooooooooo017oool00`0003?o03?o0009<ol000<0
003oooooool0N_ooo`00F?ooo`80I_lSoooo1`1VoaCoool00`0003?o03?o0008<ol00P0007_oool0
05Woool00`1Vooooooooo`0Moooo101Vo`Koool00ol0VOooooooo`0Boooo00<0000co`0co`0023?o
00030000oooooooo07[oool005[oool00`1Vooooooooo`0Coooo2@1Vo`[oool00ol0VOooooooo`0B
oooo00<0000co`0co`0023?o00030000oooooooo07[oool005[ooolF06Ko4oooo`03o`2Ioooooooo
01?oool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01?oool0
0`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01?oool00`0003?o
03?o0007<ol000<0003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01?oool00`0003?o03?o0007
<ol00P0007_oool008?oool00ol0VOooooooo`0Doooo00<0000co`0co`001S?o00030000oooooooo
07[oool008?oool00ol0VOooooooo`0Doooo00<0000co`0co`001S?o00030000oooooooo07[oool0
08?oool00ol0VOooooooo`0Doooo00<0000co`0co`001S?o00030000oooooooo07[oool008?oool0
0ol0VOooooooo`0Doooo00<0000co`0co`001S?o00030000oooooooo07[oool008?oool00ol0VOoo
ooooo`0Eoooo1@0000<co`000`000?ooooooo`1joooo0023oooo00?o09Woooooool05Oooo`030000
<ol0000000Dco`000`000?ooooooo`1joooo0023oooo00?o09Woooooool05Oooo`030000<ol00000
00Dco`030000N_ooo`00Poooo`03o`2Ioooooooo01Koool200001C?o00030000oooooooo07[oool0
08?oool00ol0VOooooooo`0Foooo0P0000Dco`000`000?ooooooo`1joooo0023oooo00?o09Wooooo
ool05_ooo`800005<ol000<0003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01Koool00`0003?o
03?o0004<ol000<0003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01Koool00`0003?o03?o0004
<ol000<0003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01Koool00`0003?o03?o0004<ol00P00
07_oool008?oool00ol0VOooooooo`0Goooo00<0000co`0co`000c?o00030000oooooooo07[oool0
08?oool00ol0VOooooooo`0Goooo00<0000co`0co`000c?o00030000oooooooo07[oool008?oool0
0ol0VOooooooo`0Goooo00<0000co`0co`000c?o00030000oooooooo07[oool008?oool00ol0VOoo
ooooo`0Goooo00<0000co`0co`000c?o00030000oooooooo07[oool008?oool00ol0VOooooooo`0G
oooo00<0000co`0co`000c?o00030000oooooooo07[oool008?oool00ol0VOooooooo`0Goooo00<0
000co`0co`000c?o0080001koooo0023oooo00?o09Woooooool05oooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo0023oooo00?o09Woooooool05oooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo0023oooo00?o09Woooooool06?ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo0023oooo00?o09Woooooool06?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo0023
oooo00?o09Woooooool06?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo0023oooo00?o
09Woooooool06?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo0023oooo00?o09Wooooo
ool06?ooo`030000<ol0<ol0008co`020000Noooo`00Poooo`03o`2Ioooooooo01Soool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01Soool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01Soool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01Soool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00Poooo`03o`2Ioooooooo01Soool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00Poooo`03o`2Ioooooooo01Soool00`0003?o03?o0002<ol00P0007_oool008?oool00ol0VOoo
ooooo`0Ioooo00D0000co`0co`0co`000000O?ooo`00Poooo`03o`2Ioooooooo01Woool01@0003?o
03?o03?o0000001loooo0023oooo00?o09Woooooool06Oooo`050000<ol0<ol0<ol0000007coool0
08?oool00ol0VOooooooo`0Eoooo1@0000<co`000`000?ooooooo`1joooo0023oooo00?o09Wooooo
ool05Oooo`050000oooooooooooo000000<co`000`000?ooooooo`1joooo0023oooo00?o09Wooooo
ool05_ooo`040000oooooooo00000c?o00<0001joooo0023oooo00?o09Woooooool05oooo`030000
oooo000000<co`000`000?ooooooo`1joooo0023oooo00?o09Woooooool05Oooo`030000oooooooo
00800003<ol000<0003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01Koool2000000?oool0000c
o`000S?o00030000oooooooo07[oool008?oool00ol0VOooooooo`0Ioooo00D0000co`0co`0co`00
0000O?ooo`00Poooo`03o`2Ioooooooo01[oool0100003?o03?o000007coool008?oool00ol0VOoo
ooooo`0Joooo00<0000co`0co`000P0007_oool008?oool00ol0VOooooooo`0Joooo00@0000co`0c
o`00001loooo0023oooo00?o09Woooooool06_ooo`040000<ol0<ol00000O?ooo`00Poooo`03o`2I
oooooooo01[oool0100003?o03?o000007coool008?oool00ol0VOooooooo`0Joooo00@0000co`0c
o`00001loooo0023oooo00?o09Woooooool06_ooo`040000<ol0<ol00000O?ooo`00Poooo`03o`2I
oooooooo01[oool0100003?o03?o000007coool008?oool00ol0VOooooooo`0Koooo00@0000co`00
0000001koooo0023oooo00?o09Woooooool06oooo`030000<ol0000007coool008?oool00ol0VOoo
ooooo`0Koooo00<0000co`000000O?ooo`00Poooo`03o`2Ioooooooo01_oool00`0003?o0000001l
oooo0023oooo00?o09Woooooool06oooo`030000<ol0000007coool008?oool00ol0VOooooooo`0K
oooo00<0000co`000000O?ooo`00Poooo`03o`2Ioooooooo01_oool0100003?o0000000007_oool0
08?oool00ol0VOooooooo`0Koooo00<0000co`000000O?ooo`00Poooo`03o`2Ioooooooo01_oool0
0`0003?o0000001loooo0023oooo00?o09Woooooool06oooo`030000<ol0000007coool008?oool0
0ol0VOooooooo`0Koooo00<0000co`000000O?ooo`00Poooo`03o`2Ioooooooo01_oool00`0003?o
0000001loooo0023oooo00?o09Woooooool06oooo`040000<ol000000000Noooo`00Poooo`03o`2I
oooooooo01_oool00`0003?o0000001loooo0023oooo00?o09Woooooool06oooo`030000<ol00000
07coool008?oool00ol0VOooooooo`0Koooo00<0000co`000000O?ooo`00Poooo`03o`2Ioooooooo
01Koool200000oooo`030000<ol0000007coool008?oool00ol0VOooooooo`0Eoooo00@0003ooooo
ool00002oooo00<0000co`000000O?ooo`00Poooo`03o`2Ioooooooo01Ooool01P000?oooooooooo
o`0003?o00<0001joooo0023oooo00?o09Woooooool06?ooo`060000oooooooo0000<ol00000O?oo
o`00Poooo`03o`2Ioooooooo01Goool010000?ooooooo`0000;oool00`0003?o0000001loooo0023
oooo00?o09Woooooool05_ooo`800004oooo0P0007coool008?oool00ol0VOooooooo`0Loooo0P00
07coool008?oool00ol0VOooooooo`0Loooo0P0007coool008?oool00ol0VOooooooo`0Loooo0P00
07coool008?oool00ol0VOooooooo`0Loooo0`0007_oool008?oool00ol0VOooooooo`0Loooo0P00
07coool008?oool00ol0VOooooooo`0Loooo0P0007coool008?oool00ol0VOooooooo`0Loooo0P00
07coool008?oool00ol0VOooooooo`0Loooo0P0007coool008?oool00ol0VOooooooo`0Loooo0P00
07coool008?oool00ol0VOooooooo`0Loooo0`0007_oool008?oool00ol0VOooooooo`0Loooo0P00
07coool008?oool00ol0VOooooooo`0Loooo0P0007coool008?oool00ol0VOooooooo`0Loooo0P00
07coool008?oool00ol0VOooooooo`0Loooo0P0007coool008?oool00ol0VOooooooo`0Loooo0P00
07coool008?oool00ol0VOooooooo`0Loooo0`0007_oool008?oool00ol0VOooooooo`0Moooo00<0
003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01goool00`000?ooooooo`1joooo0023oooo00?o
09Woooooool07Oooo`030000oooooooo07[oool008?oool00ol0VOooooooo`0Moooo00<0003ooooo
ool0N_ooo`00Poooo`03o`2Ioooooooo01goool00`000?ooooooo`1joooo0023oooo00?o09Wooooo
ool07Oooo`80001koooo0023oooo00?o09Woooooool07Oooo`030000oooooooo07[oool008?oool0
0ol0VOooooooo`0Moooo00<0003oooooool0N_ooo`00Poooo`03o`2Ioooooooo01goool00`000?oo
ooooo`1joooo0023oooo00?o09Woooooool07Oooo`030000oooooooo07[oool008?oool00ol0VOoo
ooooo`0Goooo0`0000?oool00`000?ooooooo`1joooo0023oooo00?o09Woooooool06?ooo`030000
oooooooo00;oool00`000?ooooooo`1joooo0023oooo00?o09Woooooool05Oooo`D00003oooo0`00
07[oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00
087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1i
oooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`@00003oooo0P0000?oool3
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400000oooo`030000oooooooo00Woool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Coool0
0`000?ooooooo`08oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Doooo00<0003oooooool01oooo`<00004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.44268 .12361 L
.44778 .12361 L
.45262 .12361 L
.45697 .12361 L
.45816 .12361 L
.45943 .12361 L
s
.45943 .12361 m
.45991 .61803 L
s
0 .4 1 r
.02381 .12422 m
.04262 .12446 L
.06244 .12483 L
.07286 .12507 L
.08255 .12535 L
.09388 .12574 L
.10458 .12619 L
.125 .12732 L
.14357 .12878 L
.16355 .13099 L
.18199 .13387 L
.20071 .13793 L
.21136 .14092 L
.22134 .14429 L
.24158 .15328 L
.26011 .16489 L
.27909 .18151 L
.28984 .19373 L
.29504 .20053 L
.29982 .20737 L
.30109 .2093 L
.30229 .21004 L
.30353 .21002 L
.30489 .20999 L
.31039 .20989 L
.32034 .20967 L
.33895 .20915 L
.3593 .20834 L
.37786 .20729 L
.39694 .2058 L
.40681 .20481 L
.4177 .2035 L
.43748 .20037 L
.44831 .19815 L
.45317 .19701 L
.45574 .19637 L
.45715 .196 L
.45848 .19565 L
.45976 .1953 L
.46049 .12361 L
.46115 .12361 L
.46233 .12361 L
.46358 .12361 L
.46474 .12361 L
.46583 .12361 L
.46703 .12361 L
.46832 .12361 L
.469 .12361 L
.46964 .12361 L
.47034 .12361 L
Mistroke
.47109 .12361 L
.4718 .12361 L
.47247 .12361 L
.47372 .12361 L
.47496 .12361 L
.4761 .12361 L
.47735 .12361 L
.47867 .12361 L
.47982 .12361 L
.48087 .12361 L
.48209 .12361 L
.48323 .12361 L
.4843 .12361 L
.48528 .12361 L
.48635 .12361 L
.48749 .12361 L
.48864 .12361 L
.48987 .12361 L
.49093 .12361 L
.4921 .12361 L
.49339 .12361 L
.49409 .12361 L
.49475 .12361 L
.49592 .12361 L
.49717 .12361 L
.49841 .12361 L
.49911 .12361 L
.49977 .12361 L
.50045 .12361 L
.5011 .12361 L
.50184 .12361 L
.50252 .12361 L
.50374 .12361 L
.50487 .12361 L
.50612 .12361 L
.50744 .12361 L
.50875 .12361 L
.50949 .12361 L
.51016 .12361 L
.51141 .12361 L
.51272 .12361 L
.51342 .12361 L
.51416 .12361 L
.51487 .12361 L
.51551 .12361 L
.51626 .12361 L
.51708 .12361 L
.51785 .12361 L
.51856 .12361 L
.51972 .12361 L
Mistroke
.52096 .12361 L
.52214 .12361 L
.52322 .12361 L
.52448 .12361 L
.52519 .12361 L
.52585 .12361 L
.52706 .12361 L
.52835 .12361 L
.52905 .12361 L
.52969 .12361 L
.53115 .12361 L
.53241 .12361 L
.53312 .12361 L
.53379 .12361 L
.53495 .12361 L
.53619 .12361 L
.53687 .12361 L
.53751 .12361 L
.53872 .12361 L
.53986 .12361 L
.54109 .12361 L
.54225 .12361 L
.54332 .12361 L
.5445 .12361 L
.54579 .12361 L
.54644 .12361 L
.54713 .12361 L
.54838 .12361 L
.54903 .12361 L
.54971 .12361 L
.55046 .12361 L
.55115 .12361 L
.55239 .12361 L
.5531 .12361 L
.55376 .12361 L
.55499 .12361 L
.55612 .12361 L
.55741 .12361 L
.55865 .12361 L
.55981 .12361 L
.56086 .12361 L
.56208 .12361 L
.56322 .12361 L
.56429 .12361 L
.56526 .12361 L
.56633 .12361 L
.56746 .12361 L
.56861 .12361 L
.56984 .12361 L
.57099 .12361 L
Mistroke
.57205 .12361 L
.57329 .12361 L
.57398 .12361 L
.57463 .12361 L
.57581 .12361 L
.57707 .12361 L
.57827 .12361 L
.57959 .12361 L
.58083 .12361 L
.58198 .12361 L
.58648 .12361 L
.5966 .12361 L
.61489 .12361 L
.65401 .12361 L
.69558 .12361 L
.73563 .12361 L
.77417 .12361 L
.81516 .12361 L
.85464 .12361 L
.8926 .12361 L
.93301 .12361 L
.97191 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0706Ko00<00000I_l0I_l01P1Vo`03oooo0000oooo00Soool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo00Koool906Ko5oooo`030000oooooooo02Goool00`000?oo
ooooo`06oooo00@00000I_l00000000K<ol000<0003oooooool09Oooo`030000oooooooo02Koool0
0`000?ooooooo`0Yoooo000loooo1@1VodCoool00`1Vooooooooo`0400005c?o00030000oooooooo
07[oool0047oool406Ko@?ooo`0306Kooooooooo00Coool00`0003?o03?o000D<ol000<0003ooooo
ool0N_ooo`00AOooo`80I_lnoooo00<0I_ooooooool01Oooo`80000D<ol000<0003oooooool0N_oo
o`00Aoooo`<0I_lkoooo00<0I_ooooooool01oooo`030000<ol0<ol0014co`000`000?ooooooo`1j
oooo001:oooo0P1VocWoool00`1Vooooooooo`08oooo00<0000co`0co`0043?o0080001koooo001<
oooo0P1VocOoool00`1Vooooooooo`09oooo0P00010co`000`000?ooooooo`1joooo001>oooo0P1V
ocGoool00`1Vooooooooo`0;oooo00<0000co`0co`003C?o00030000oooooooo07[oool0053oool2
06Ko<oooo`0306Kooooooooo00_oool00`0003?o03?o000=<ol000<0003oooooool0N_ooo`00D_oo
o`0306Kooooooooo033oool00`1Vooooooooo`0<oooo00<0000co`0co`0033?o00030000oooooooo
07[oool005?oool00`1Vooooooooo`0_oooo00<0I_ooooooool03?ooo`030000<ol0<ol000`co`00
0`000?ooooooo`1joooo001Doooo0P1Vobooool00`1Vooooooooo`0=oooo00<0000co`0co`002c?o
0080001koooo001Foooo00<0I_ooooooool0;?ooo`0306Kooooooooo00goool00`0003?o03?o000;
<ol000<0003oooooool0N_ooo`00Eoooo`0306Kooooooooo02_oool00`1Vooooooooo`0>oooo00<0
000co`0co`002S?o00030000oooooooo07[oool005Soool00`1Vooooooooo`0Zoooo00<0I_oooooo
ool03_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo001Ioooo00<0I_ooooooool0:Ooo
o`0306Kooooooooo00ooool00`0003?o03?o0009<ol000<0003oooooool0N_ooo`00F_ooo`0306Ko
oooooooo02Soool00`1Vooooooooo`0?oooo00<0000co`0co`002C?o00030000oooooooo07[oool0
05[oool00`1Vooooooooo`0Toooo1@1Voa;oool00`0003?o03?o0008<ol00P0007_oool005_oool0
0`1Vooooooooo`0Ooooo101Vo`Coool00ol0VOooooooo`0@oooo00<0000co`0co`0023?o00030000
oooooooo07[oool005_oool00`1Vooooooooo`0Eoooo2P1Vo`Soool00ol0VOooooooo`0@oooo00<0
000co`0co`0023?o00030000oooooooo07[oool005cooolG06Ko4_ooo`03o`2Ioooooooo017oool0
0`0003?o03?o0007<ol000<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo017oool00`0003?o
03?o0007<ol000<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo017oool00`0003?o03?o0007
<ol000<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo017oool00`0003?o03?o0007<ol00P00
07_oool008Goool00ol0VOooooooo`0Boooo00<0000co`0co`001S?o00030000oooooooo07[oool0
08Goool00ol0VOooooooo`0Boooo00<0000co`0co`001S?o00030000oooooooo07[oool008Goool0
0ol0VOooooooo`0Boooo00<0000co`0co`001S?o00030000oooooooo07[oool008Goool00ol0VOoo
ooooo`0Boooo00<0000co`0co`001S?o00030000oooooooo07[oool008Goool00ol0VOooooooo`0C
oooo1@0000<co`000`000?ooooooo`1joooo0025oooo00?o09Woooooool04oooo`030000<ol00000
00Dco`000`000?ooooooo`1joooo0025oooo00?o09Woooooool04oooo`030000<ol0000000Dco`03
0000N_ooo`00QOooo`03o`2Ioooooooo01Coool200001C?o00030000oooooooo07[oool008Goool0
0ol0VOooooooo`0Doooo0P0000Dco`000`000?ooooooo`1joooo0025oooo00?o09Woooooool05?oo
o`800005<ol000<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo01Coool00`0003?o03?o0004
<ol000<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo01Coool00`0003?o03?o0004<ol000<0
003oooooool0N_ooo`00QOooo`03o`2Ioooooooo01Coool00`0003?o03?o0004<ol00P0007_oool0
08Goool00ol0VOooooooo`0Eoooo00<0000co`0co`000c?o00030000oooooooo07[oool008Goool0
0ol0VOooooooo`0Eoooo00<0000co`0co`000c?o00030000oooooooo07[oool008Goool00ol0VOoo
ooooo`0Eoooo00<0000co`0co`000c?o00030000oooooooo07[oool008Goool00ol0VOooooooo`0E
oooo00<0000co`0co`000c?o00030000oooooooo07[oool008Goool00ol0VOooooooo`0Eoooo00<0
000co`0co`000c?o00030000oooooooo07[oool008Goool00ol0VOooooooo`0Eoooo00<0000co`0c
o`000c?o0080001koooo0025oooo00?o09Woooooool05Oooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo0025oooo00?o09Woooooool05Oooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo0025oooo00?o09Woooooool05_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo0025
oooo00?o09Woooooool05_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo0025oooo00?o
09Woooooool05_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo0025oooo00?o09Wooooo
ool05_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo0025oooo00?o09Woooooool05_oo
o`030000<ol0<ol0008co`020000Noooo`00QOooo`03o`2Ioooooooo01Koool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo01Koool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00QOooo`03o`2Ioooooooo01Koool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00QOooo`03o`2Ioooooooo01Koool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00QOooo`03o`2Ioooooooo01Koool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00QOoo
o`03o`2Ioooooooo01Koool00`0003?o03?o0002<ol00P0007_oool008Goool00ol0VOooooooo`0G
oooo00D0000co`0co`0co`000000O?ooo`00QOooo`03o`2Ioooooooo01Ooool01@0003?o03?o03?o
0000001loooo0025oooo00?o09Woooooool05oooo`050000<ol0<ol0<ol0000007coool008Goool0
0ol0VOooooooo`0Coooo1@0000<co`000`000?ooooooo`1joooo0025oooo00?o09Woooooool04ooo
o`050000oooooooooooo000000<co`000`000?ooooooo`1joooo0025oooo00?o09Woooooool05?oo
o`040000oooooooo00000c?o00<0001joooo0025oooo00?o09Woooooool05Oooo`030000oooo0000
00<co`000`000?ooooooo`1joooo0025oooo00?o09Woooooool04oooo`030000oooooooo00800003
<ol000<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo01Coool2000000?oool0000co`000S?o
00030000oooooooo07[oool008Goool00ol0VOooooooo`0Goooo00D0000co`0co`0co`000000O?oo
o`00QOooo`03o`2Ioooooooo01Soool0100003?o03?o000007coool008Goool00ol0VOooooooo`0H
oooo00<0000co`0co`000P0007_oool008Goool00ol0VOooooooo`0Hoooo00@0000co`0co`00001l
oooo0025oooo00?o09Woooooool06?ooo`040000<ol0<ol00000O?ooo`00QOooo`03o`2Ioooooooo
01Soool0100003?o03?o000007coool008Goool00ol0VOooooooo`0Hoooo00@0000co`0co`00001l
oooo0025oooo00?o09Woooooool06?ooo`040000<ol0<ol00000O?ooo`00QOooo`03o`2Ioooooooo
01Soool0100003?o03?o000007coool008Goool00ol0VOooooooo`0Ioooo00@0000co`000000001k
oooo0025oooo00?o09Woooooool06Oooo`030000<ol0000007coool008Goool00ol0VOooooooo`0I
oooo00<0000co`000000O?ooo`00QOooo`03o`2Ioooooooo01Woool00`0003?o0000001loooo0025
oooo00?o09Woooooool06Oooo`030000<ol0000007coool008Goool00ol0VOooooooo`0Ioooo00<0
000co`000000O?ooo`00QOooo`03o`2Ioooooooo01Woool0100003?o0000000007_oool008Goool0
0ol0VOooooooo`0Ioooo00<0000co`000000O?ooo`00QOooo`03o`2Ioooooooo01Woool00`0003?o
0000001loooo0025oooo00?o09Woooooool06Oooo`030000<ol0000007coool008Goool00ol0VOoo
ooooo`0Ioooo00<0000co`000000O?ooo`00QOooo`03o`2Ioooooooo01Woool00`0003?o0000001l
oooo0025oooo00?o09Woooooool06Oooo`040000<ol000000000Noooo`00QOooo`03o`2Ioooooooo
01Woool00`0003?o0000001loooo0025oooo00?o09Woooooool06Oooo`030000<ol0000007coool0
08Goool00ol0VOooooooo`0Ioooo00<0000co`000000O?ooo`00QOooo`03o`2Ioooooooo01Coool2
00000oooo`030000<ol0000007coool008Goool00ol0VOooooooo`0Coooo00@0003oooooool00002
oooo00<0000co`000000O?ooo`00QOooo`03o`2Ioooooooo01Goool01P000?ooooooooooo`0003?o
00<0001joooo0025oooo00?o09Woooooool05_ooo`060000oooooooo0000<ol00000O?ooo`00QOoo
o`03o`2Ioooooooo01?oool010000?ooooooo`0000;oool00`0003?o0000001loooo0025oooo00?o
09Woooooool05?ooo`800004oooo0P0007coool008Goool00ol0VOooooooo`0Joooo0P0007coool0
08Goool00ol0VOooooooo`0Joooo0P0007coool008Goool00ol0VOooooooo`0Joooo0P0007coool0
08Goool00ol0VOooooooo`0Joooo0`0007_oool008Goool00ol0VOooooooo`0Joooo0P0007coool0
08Goool00ol0VOooooooo`0Joooo0P0007coool008Goool00ol0VOooooooo`0Joooo0P0007coool0
08Goool00ol0VOooooooo`0Joooo0P0007coool008Goool00ol0VOooooooo`0Joooo0P0007coool0
08Goool00ol0VOooooooo`0Joooo0`0007_oool008Goool00ol0VOooooooo`0Joooo0P0007coool0
08Goool00ol0VOooooooo`0Joooo0P0007coool008Goool00ol0VOooooooo`0Joooo0P0007coool0
08Goool00ol0VOooooooo`0Joooo0P0007coool008Goool00ol0VOooooooo`0Joooo0P0007coool0
08Goool00ol0VOooooooo`0Joooo0`0007_oool008Goool00ol0VOooooooo`0Koooo00<0003ooooo
ool0N_ooo`00QOooo`03o`2Ioooooooo01_oool00`000?ooooooo`1joooo0025oooo00?o09Wooooo
ool06oooo`030000oooooooo07[oool008Goool00ol0VOooooooo`0Koooo00<0003oooooool0N_oo
o`00QOooo`03o`2Ioooooooo01_oool00`000?ooooooo`1joooo0025oooo00?o09Woooooool06ooo
o`80001koooo0025oooo00?o09Woooooool06oooo`030000oooooooo07[oool008Goool00ol0VOoo
ooooo`0Koooo00<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo01_oool00`000?ooooooo`1j
oooo0025oooo00?o09Woooooool06oooo`030000oooooooo07[oool008Goool00ol0VOooooooo`0E
oooo0`0000?oool00`000?ooooooo`1joooo0025oooo00?o09Woooooool05_ooo`030000oooooooo
00;oool00`000?ooooooo`1joooo0025oooo00?o09Woooooool04oooo`D00003oooo0`0007[oool0
09_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`@00003oooo0P0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`030000oooooooo00Woool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Coool00`000?oo
ooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00005?ooo`030000oooooooo00Soool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000Eoooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46388 .12361 L
.46618 .12361 L
.46687 .12361 L
.46751 .12361 L
s
.46751 .12361 m
.46799 .61803 L
s
0 .4 1 r
.02381 .12414 m
.04262 .12435 L
.06244 .12466 L
.07286 .12488 L
.08255 .12512 L
.09388 .12546 L
.10458 .12585 L
.125 .12683 L
.14357 .1281 L
.16355 .13002 L
.18199 .13251 L
.20071 .13604 L
.21136 .13864 L
.22134 .14156 L
.24158 .14936 L
.26011 .15943 L
.27909 .17386 L
.28984 .18446 L
.29982 .1963 L
.30489 .20318 L
.30756 .20706 L
.30827 .20812 L
.30902 .20926 L
.30974 .21002 L
.31039 .21001 L
.31286 .20997 L
.31557 .20992 L
.32034 .20982 L
.33895 .20935 L
.35803 .20868 L
.36882 .20819 L
.37879 .20765 L
.39746 .20634 L
.41806 .20429 L
.43741 .20157 L
.44737 .19978 L
.45263 .1987 L
.45826 .19743 L
.46106 .19676 L
.4637 .19609 L
.46607 .19546 L
.46672 .19529 L
.46741 .1951 L
.46864 .12361 L
.46979 .12361 L
.47102 .12361 L
.47218 .12361 L
.47324 .12361 L
.47449 .12361 L
.47519 .12361 L
Mistroke
.47584 .12361 L
.47703 .12361 L
.4783 .12361 L
.479 .12361 L
.47973 .12361 L
.48105 .12361 L
.48178 .12361 L
.48246 .12361 L
.48321 .12361 L
.48401 .12361 L
.4847 .12361 L
.48545 .12361 L
.48616 .12361 L
.48682 .12361 L
.48806 .12361 L
.48938 .12361 L
.49056 .12361 L
.49184 .12361 L
.49304 .12361 L
.49415 .12361 L
.49537 .12361 L
.49606 .12361 L
.49671 .12361 L
.49801 .12361 L
.49874 .12361 L
.4994 .12361 L
.5006 .12361 L
.50172 .12361 L
.50295 .12361 L
.50427 .12361 L
.50493 .12361 L
.50565 .12361 L
.50696 .12361 L
.50823 .12361 L
.50941 .12361 L
.5105 .12361 L
.51153 .12361 L
.51266 .12361 L
.51388 .12361 L
.51508 .12361 L
.51635 .12361 L
.51744 .12361 L
.51863 .12361 L
.5193 .12361 L
.52003 .12361 L
.52072 .12361 L
.52135 .12361 L
.52256 .12361 L
.52383 .12361 L
.52449 .12361 L
Mistroke
.5252 .12361 L
.52648 .12361 L
.52727 .12361 L
.52801 .12361 L
.52868 .12361 L
.5294 .12361 L
.53072 .12361 L
.53192 .12361 L
.53259 .12361 L
.53331 .12361 L
.53461 .12361 L
.53583 .12361 L
.53712 .12361 L
.53823 .12361 L
.53944 .12361 L
.54074 .12361 L
.54195 .12361 L
.54325 .12361 L
.54399 .12361 L
.54468 .12361 L
.54584 .12361 L
.54709 .12361 L
.54774 .12361 L
.54843 .12361 L
.54965 .12361 L
.55077 .12361 L
.55196 .12361 L
.55308 .12361 L
.5541 .12361 L
.5553 .12361 L
.5566 .12361 L
.55774 .12361 L
.55896 .12361 L
.56026 .12361 L
.56148 .12361 L
.56222 .12361 L
.56293 .12361 L
.56425 .12361 L
.56492 .12361 L
.56564 .12361 L
.56693 .12361 L
.56772 .12361 L
.56846 .12361 L
.56913 .12361 L
.56985 .12361 L
.57106 .12361 L
.57175 .12361 L
.57239 .12361 L
.57369 .12361 L
.57442 .12361 L
Mistroke
.57508 .12361 L
.57626 .12361 L
.57755 .12361 L
.57876 .12361 L
.57988 .12361 L
.58113 .12361 L
.58231 .12361 L
.58454 .12361 L
.58954 .12361 L
.5986 .12361 L
.61922 .12361 L
.6574 .12361 L
.69803 .12361 L
.73715 .12361 L
.77872 .12361 L
.81877 .12361 L
.85731 .12361 L
.8983 .12361 L
.93778 .12361 L
.97574 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0706Ko00<00000I_l0I_l01P1Vo`03oooo0000oooo00Soool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo00000100000013?o000003?o001Vo`Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`0Eoooo000Zoooo00<0003oooooool01_ooo`T0I_lGoooo00<0003oooooool09Oooo`030000
oooooooo00Koool3000000<0I_lco`0co`006C?o00030000oooooooo02Goool00`000?ooooooo`0V
oooo00<0003oooooool0:Oooo`00??ooo`D0I_m6oooo00<0I_l0000000000P0001Lco`000`000?oo
ooooo`1joooo0011oooo1P1Vod3oool00`1Vooooooooo`02oooo00<0000co`0co`0053?o00030000
oooooooo07[oool004Ooool306Ko?Oooo`0306Kooooooooo00?oool2000053?o00030000oooooooo
07[oool004[oool206Ko>oooo`0306Kooooooooo00Goool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00C?ooo`<0I_lhoooo00<0I_ooooooool01_ooo`030000<ol0<ol0010co`020000Nooo
o`00Coooo`80I_lfoooo00<0I_ooooooool01oooo`80000@<ol000<0003oooooool0N_ooo`00DOoo
o`80I_ldoooo00<0I_ooooooool02Oooo`030000<ol0<ol000dco`000`000?ooooooo`1joooo001C
oooo00<0I_ooooooool0<Oooo`0306Kooooooooo00Woool00`0003?o03?o000=<ol000<0003ooooo
ool0N_ooo`00E?ooo`80I_laoooo00<0I_ooooooool02_ooo`030000<ol0<ol000`co`000`000?oo
ooooo`1joooo001Foooo00<0I_ooooooool0;_ooo`0306Kooooooooo00[oool00`0003?o03?o000<
<ol000<0003oooooool0N_ooo`00Eoooo`0306Kooooooooo02goool00`1Vooooooooo`0;oooo00<0
000co`0co`002c?o0080001koooo001Hoooo00<0I_ooooooool0;?ooo`0306Kooooooooo00_oool0
0`0003?o03?o000;<ol000<0003oooooool0N_ooo`00FOooo`0306Kooooooooo02_oool00`1Voooo
ooooo`0<oooo00<0000co`0co`002S?o00030000oooooooo07[oool005[oool00`1Vooooooooo`0Z
oooo00<0I_ooooooool03?ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo001Koooo00<0
I_ooooooool0:Oooo`0306Kooooooooo00goool00`0003?o03?o0009<ol000<0003oooooool0N_oo
o`00Foooo`0306Kooooooooo02Woool00`1Vooooooooo`0=oooo00<0000co`0co`002C?o00030000
oooooooo07[oool005coool00`1Vooooooooo`0Toooo1@1Voa3oool00`0003?o03?o0008<ol00P00
07_oool005coool00`1Vooooooooo`0Noooo1P1Vo`Coool00ol0VOooooooo`0>oooo00<0000co`0c
o`0023?o00030000oooooooo07[oool005goool00`1Vooooooooo`0Coooo2P1Vo`[oool00ol0VOoo
ooooo`0>oooo00<0000co`0co`0023?o00030000oooooooo07[oool005kooolE06Ko5?ooo`03o`2I
oooooooo00ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo
00ooool00`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo00ooool0
0`0003?o03?o0007<ol000<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo00ooool00`0003?o
03?o0007<ol00P0007_oool008Ooool00ol0VOooooooo`0@oooo00<0000co`0co`001S?o00030000
oooooooo07[oool008Ooool00ol0VOooooooo`0@oooo00<0000co`0co`001S?o00030000oooooooo
07[oool008Ooool00ol0VOooooooo`0@oooo00<0000co`0co`001S?o00030000oooooooo07[oool0
08Ooool00ol0VOooooooo`0@oooo00<0000co`0co`001S?o00030000oooooooo07[oool008Ooool0
0ol0VOooooooo`0Aoooo1@0000<co`000`000?ooooooo`1joooo0027oooo00?o09Woooooool04Ooo
o`030000<ol0000000Dco`000`000?ooooooo`1joooo0027oooo00?o09Woooooool04Oooo`030000
<ol0000000Dco`030000N_ooo`00Qoooo`03o`2Ioooooooo01;oool200001C?o00030000oooooooo
07[oool008Ooool00ol0VOooooooo`0Boooo0P0000Dco`000`000?ooooooo`1joooo0027oooo00?o
09Woooooool04_ooo`800005<ol000<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01;oool0
0`0003?o03?o0004<ol000<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01;oool00`0003?o
03?o0004<ol000<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01;oool00`0003?o03?o0004
<ol00P0007_oool008Ooool00ol0VOooooooo`0Coooo00<0000co`0co`000c?o00030000oooooooo
07[oool008Ooool00ol0VOooooooo`0Coooo00<0000co`0co`000c?o00030000oooooooo07[oool0
08Ooool00ol0VOooooooo`0Coooo00<0000co`0co`000c?o00030000oooooooo07[oool008Ooool0
0ol0VOooooooo`0Coooo00<0000co`0co`000c?o00030000oooooooo07[oool008Ooool00ol0VOoo
ooooo`0Coooo00<0000co`0co`000c?o00030000oooooooo07[oool008Ooool00ol0VOooooooo`0C
oooo00<0000co`0co`000c?o0080001koooo0027oooo00?o09Woooooool04oooo`030000<ol0<ol0
00<co`000`000?ooooooo`1joooo0027oooo00?o09Woooooool04oooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo0027oooo00?o09Woooooool05?ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo0027oooo00?o09Woooooool05?ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo0027oooo00?o09Woooooool05?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo0027
oooo00?o09Woooooool05?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo0027oooo00?o
09Woooooool05?ooo`030000<ol0<ol0008co`020000Noooo`00Qoooo`03o`2Ioooooooo01Coool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01Coool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01Coool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01Coool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01Coool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00Qoooo`03o`2Ioooooooo01Coool00`0003?o03?o0002<ol00P0007_oool008Ooool0
0ol0VOooooooo`0Eoooo00D0000co`0co`0co`000000O?ooo`00Qoooo`03o`2Ioooooooo01Goool0
1@0003?o03?o03?o0000001loooo0027oooo00?o09Woooooool05Oooo`050000<ol0<ol0<ol00000
07coool008Ooool00ol0VOooooooo`0Aoooo1@0000<co`000`000?ooooooo`1joooo0027oooo00?o
09Woooooool04Oooo`050000oooooooooooo000000<co`000`000?ooooooo`1joooo0027oooo00?o
09Woooooool04_ooo`040000oooooooo00000c?o00<0001joooo0027oooo00?o09Woooooool04ooo
o`030000oooo000000<co`000`000?ooooooo`1joooo0027oooo00?o09Woooooool04Oooo`030000
oooooooo00800003<ol000<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01;oool2000000?o
ool0000co`000S?o00030000oooooooo07[oool008Ooool00ol0VOooooooo`0Eoooo00D0000co`0c
o`0co`000000O?ooo`00Qoooo`03o`2Ioooooooo01Koool0100003?o03?o000007coool008Ooool0
0ol0VOooooooo`0Foooo00<0000co`0co`000P0007_oool008Ooool00ol0VOooooooo`0Foooo00@0
000co`0co`00001loooo0027oooo00?o09Woooooool05_ooo`040000<ol0<ol00000O?ooo`00Qooo
o`03o`2Ioooooooo01Koool0100003?o03?o000007coool008Ooool00ol0VOooooooo`0Foooo00@0
000co`0co`00001loooo0027oooo00?o09Woooooool05_ooo`040000<ol0<ol00000O?ooo`00Qooo
o`03o`2Ioooooooo01Koool0100003?o03?o000007coool008Ooool00ol0VOooooooo`0Goooo00@0
000co`000000001koooo0027oooo00?o09Woooooool05oooo`030000<ol0000007coool008Ooool0
0ol0VOooooooo`0Goooo00<0000co`000000O?ooo`00Qoooo`03o`2Ioooooooo01Ooool00`0003?o
0000001loooo0027oooo00?o09Woooooool05oooo`030000<ol0000007coool008Ooool00ol0VOoo
ooooo`0Goooo00<0000co`000000O?ooo`00Qoooo`03o`2Ioooooooo01Ooool0100003?o00000000
07_oool008Ooool00ol0VOooooooo`0Goooo00<0000co`000000O?ooo`00Qoooo`03o`2Ioooooooo
01Ooool00`0003?o0000001loooo0027oooo00?o09Woooooool05oooo`030000<ol0000007coool0
08Ooool00ol0VOooooooo`0Goooo00<0000co`000000O?ooo`00Qoooo`03o`2Ioooooooo01Ooool0
0`0003?o0000001loooo0027oooo00?o09Woooooool05oooo`040000<ol000000000Noooo`00Qooo
o`03o`2Ioooooooo01Ooool00`0003?o0000001loooo0027oooo00?o09Woooooool05oooo`030000
<ol0000007coool008Ooool00ol0VOooooooo`0Goooo00<0000co`000000O?ooo`00Qoooo`03o`2I
oooooooo01;oool200000oooo`030000<ol0000007coool008Ooool00ol0VOooooooo`0Aoooo00@0
003oooooool00002oooo00<0000co`000000O?ooo`00Qoooo`03o`2Ioooooooo01?oool01P000?oo
ooooooooo`0003?o00<0001joooo0027oooo00?o09Woooooool05?ooo`060000oooooooo0000<ol0
0000O?ooo`00Qoooo`03o`2Ioooooooo017oool010000?ooooooo`0000;oool00`0003?o0000001l
oooo0027oooo00?o09Woooooool04_ooo`800004oooo0P0007coool008Ooool00ol0VOooooooo`0H
oooo0P0007coool008Ooool00ol0VOooooooo`0Hoooo0P0007coool008Ooool00ol0VOooooooo`0H
oooo0P0007coool008Ooool00ol0VOooooooo`0Hoooo0`0007_oool008Ooool00ol0VOooooooo`0H
oooo0P0007coool008Ooool00ol0VOooooooo`0Hoooo0P0007coool008Ooool00ol0VOooooooo`0H
oooo0P0007coool008Ooool00ol0VOooooooo`0Hoooo0P0007coool008Ooool00ol0VOooooooo`0H
oooo0P0007coool008Ooool00ol0VOooooooo`0Hoooo0`0007_oool008Ooool00ol0VOooooooo`0H
oooo0P0007coool008Ooool00ol0VOooooooo`0Hoooo0P0007coool008Ooool00ol0VOooooooo`0H
oooo0P0007coool008Ooool00ol0VOooooooo`0Hoooo0P0007coool008Ooool00ol0VOooooooo`0H
oooo0P0007coool008Ooool00ol0VOooooooo`0Hoooo0`0007_oool008Ooool00ol0VOooooooo`0I
oooo00<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01Woool00`000?ooooooo`1joooo0027
oooo00?o09Woooooool06Oooo`030000oooooooo07[oool008Ooool00ol0VOooooooo`0Ioooo00<0
003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01Woool00`000?ooooooo`1joooo0027oooo00?o
09Woooooool06Oooo`80001koooo0027oooo00?o09Woooooool06Oooo`030000oooooooo07[oool0
08Ooool00ol0VOooooooo`0Ioooo00<0003oooooool0N_ooo`00Qoooo`03o`2Ioooooooo01Woool0
0`000?ooooooo`1joooo0027oooo00?o09Woooooool06Oooo`030000oooooooo07[oool008Ooool0
0ol0VOooooooo`0Coooo0`0000?oool00`000?ooooooo`1joooo0027oooo00?o09Woooooool05?oo
o`030000oooooooo00;oool00`000?ooooooo`1joooo0027oooo00?o09Woooooool04Oooo`D00003
oooo0`0007[oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002M
oooo0P00087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`@00003oooo0P00
00Goool300000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400000oooo`030000oooooooo00coool01@000?oo
ooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo01Coool00`000?oo
ooooo`08oooo1@0000?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001Coool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo01Ooool200002oooo`800002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46618 .12361 L
.47106 .12361 L
.47329 .12361 L
.47451 .12361 L
.47567 .12361 L
s
.47567 .12361 m
.4761 .61803 L
s
0 .4 1 r
.02381 .12407 m
.04262 .12425 L
.06244 .12453 L
.07286 .12471 L
.08255 .12492 L
.09388 .12521 L
.10458 .12555 L
.125 .12641 L
.14357 .1275 L
.16355 .12917 L
.18199 .13133 L
.20071 .1344 L
.21136 .13665 L
.22134 .13919 L
.24158 .14596 L
.26011 .1547 L
.27909 .16721 L
.28984 .17642 L
.29982 .18669 L
.31039 .19976 L
.31291 .20326 L
.31557 .20713 L
.31667 .20878 L
.31784 .20999 L
.31914 .20996 L
.32034 .20994 L
.32928 .20976 L
.33895 .20952 L
.34912 .20923 L
.36019 .20884 L
.38031 .20792 L
.40008 .20663 L
.41007 .20578 L
.42109 .20467 L
.44044 .20211 L
.4504 .20043 L
.46129 .19823 L
.46631 .19707 L
.46907 .19639 L
.47168 .19572 L
.4741 .19507 L
.47477 .19489 L
.47547 .19469 L
.47674 .12361 L
.47787 .12361 L
.47893 .12361 L
.48009 .12361 L
.48133 .12361 L
.48201 .12361 L
.48274 .12361 L
Mistroke
.48404 .12361 L
.48484 .12361 L
.48559 .12361 L
.48626 .12361 L
.48699 .12361 L
.48764 .12361 L
.48835 .12361 L
.4891 .12361 L
.48979 .12361 L
.49103 .12361 L
.49173 .12361 L
.49236 .12361 L
.49356 .12361 L
.49484 .12361 L
.49551 .12361 L
.49624 .12361 L
.49754 .12361 L
.49875 .12361 L
.50006 .12361 L
.5013 .12361 L
.50243 .12361 L
.50372 .12361 L
.50493 .12361 L
.50601 .12361 L
.50719 .12361 L
.50847 .12361 L
.50912 .12361 L
.50983 .12361 L
.51109 .12361 L
.51226 .12361 L
.51345 .12361 L
.51457 .12361 L
.51557 .12361 L
.51667 .12361 L
.51786 .12361 L
.51912 .12361 L
.5202 .12361 L
.5214 .12361 L
.5227 .12361 L
.52336 .12361 L
.52407 .12361 L
.52535 .12361 L
.52653 .12361 L
.52725 .12361 L
.52794 .12361 L
.52921 .12361 L
.52993 .12361 L
.53059 .12361 L
.53131 .12361 L
.53208 .12361 L
Mistroke
.53326 .12361 L
.53454 .12361 L
.53575 .12361 L
.53685 .12361 L
.53814 .12361 L
.53882 .12361 L
.53955 .12361 L
.54025 .12361 L
.54088 .12361 L
.54211 .12361 L
.54331 .12361 L
.54444 .12361 L
.54567 .12361 L
.54699 .12361 L
.54765 .12361 L
.54838 .12361 L
.54969 .12361 L
.55096 .12361 L
.55214 .12361 L
.55324 .12361 L
.55427 .12361 L
.5554 .12361 L
.55662 .12361 L
.55783 .12361 L
.5591 .12361 L
.56018 .12361 L
.56137 .12361 L
.56205 .12361 L
.56278 .12361 L
.56347 .12361 L
.56411 .12361 L
.56531 .12361 L
.56659 .12361 L
.56725 .12361 L
.56796 .12361 L
.56924 .12361 L
.57003 .12361 L
.57077 .12361 L
.57144 .12361 L
.57216 .12361 L
.57285 .12361 L
.57349 .12361 L
.57469 .12361 L
.57598 .12361 L
.5767 .12361 L
.57737 .12361 L
.57849 .12361 L
.57972 .12361 L
.581 .12361 L
.5822 .12361 L
Mistroke
.62118 .12361 L
.66261 .12361 L
.70253 .12361 L
.74093 .12361 L
.78178 .12361 L
.82112 .12361 L
.85895 .12361 L
.89922 .12361 L
.93798 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0706Ko00<00000I_l0I_l01`1Vo`04000006Ko06Ko06Ko1_ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oool0000040000003<ol00000<ol0008co`000`1Voc?o03?o0003<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo00_oool906Ko4_ooo`030000
oooooooo02Goool00`000?ooooooo`06oooo10000003<ol006Ko<ol001Pco`000`000?ooooooo`0U
oooo00<0003oooooool09_ooo`030000oooooooo02Woool0047oool406Ko@oooo`04000006Ko0000
00005c?o00030000oooooooo07[oool004Goool506Ko?oooo`0406Kooooooooo00005S?o00030000
oooooooo07[oool004[oool206Ko?Oooo`0406Kooooooooooooo0P0001@co`000`000?ooooooo`1j
oooo001<oooo0`1Voc[oool00`1Vooooooooo`03oooo00<0000co`0co`004C?o00030000oooooooo
07[oool004ooool206Ko>?ooo`0306Kooooooooo00Coool00`0003?o03?o000@<ol00P0007_oool0
057oool206Ko=_ooo`0306Kooooooooo00Goool2000043?o00030000oooooooo07[oool005?oool2
06Ko=?ooo`0306Kooooooooo00Ooool00`0003?o03?o000=<ol000<0003oooooool0N_ooo`00EOoo
o`80I_lboooo00<0I_ooooooool01oooo`030000<ol0<ol000dco`000`000?ooooooo`1joooo001G
oooo00<0I_ooooooool0;oooo`0306Kooooooooo00Soool00`0003?o03?o000<<ol000<0003ooooo
ool0N_ooo`00F?ooo`0306Kooooooooo02koool00`1Vooooooooo`08oooo00<0000co`0co`0033?o
00030000oooooooo07[oool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool02Oooo`030000
<ol0<ol000/co`020000Noooo`00F_ooo`0306Kooooooooo02coool00`1Vooooooooo`09oooo00<0
000co`0co`002c?o00030000oooooooo07[oool005_oool00`1Vooooooooo`0[oooo00<0I_oooooo
ool02_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo001Loooo00<0I_ooooooool0:_oo
o`0306Kooooooooo00[oool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00GOooo`0306Ko
oooooooo02Woool00`1Vooooooooo`0;oooo00<0000co`0co`002C?o00030000oooooooo07[oool0
05goool00`1Vooooooooo`0Yoooo00<0I_ooooooool02oooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1joooo001Noooo00<0I_ooooooool08oooo`D0I_l00ol0VOooooooo`0<oooo00<0000co`0c
o`0023?o0080001koooo001Ooooo00<0I_ooooooool07?ooo`H0I_l5oooo00?o09Woooooool03?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`1joooo001Poooo00<0I_ooooooool04Oooo`X0I_l;
oooo00?o09Woooooool03?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1joooo001Poooo501V
oaGoool00ol0VOooooooo`0=oooo00<0000co`0co`001c?o00030000oooooooo07[oool008Woool0
0ol0VOooooooo`0=oooo00<0000co`0co`001c?o00030000oooooooo07[oool008Woool00ol0VOoo
ooooo`0=oooo00<0000co`0co`001c?o00030000oooooooo07[oool008Woool00ol0VOooooooo`0=
oooo00<0000co`0co`001c?o0080001koooo0029oooo00?o09Woooooool03_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`1joooo0029oooo00?o09Woooooool03_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1joooo0029oooo00?o09Woooooool03_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1joooo0029oooo00?o09Woooooool03_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1j
oooo0029oooo00?o09Woooooool03oooo`D00003<ol000<0003oooooool0N_ooo`00ROooo`03o`2I
oooooooo00ooool00`0003?o00000005<ol000<0003oooooool0N_ooo`00ROooo`03o`2Ioooooooo
00ooool00`0003?o00000005<ol00`0007[oool008Woool00ol0VOooooooo`0@oooo0P0000Dco`00
0`000?ooooooo`1joooo0029oooo00?o09Woooooool04?ooo`800005<ol000<0003oooooool0N_oo
o`00ROooo`03o`2Ioooooooo013oool200001C?o00030000oooooooo07[oool008Woool00ol0VOoo
ooooo`0@oooo00<0000co`0co`0013?o00030000oooooooo07[oool008Woool00ol0VOooooooo`0@
oooo00<0000co`0co`0013?o00030000oooooooo07[oool008Woool00ol0VOooooooo`0@oooo00<0
000co`0co`0013?o0080001koooo0029oooo00?o09Woooooool04Oooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo0029oooo00?o09Woooooool04Oooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo0029oooo00?o09Woooooool04Oooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo0029oooo00?o09Woooooool04Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo0029
oooo00?o09Woooooool04Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo0029oooo00?o
09Woooooool04Oooo`030000<ol0<ol000<co`020000Noooo`00ROooo`03o`2Ioooooooo017oool0
0`0003?o03?o0003<ol000<0003oooooool0N_ooo`00ROooo`03o`2Ioooooooo017oool00`0003?o
03?o0003<ol000<0003oooooool0N_ooo`00ROooo`03o`2Ioooooooo01;oool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00ROooo`03o`2Ioooooooo01;oool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00ROooo`03o`2Ioooooooo01;oool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00ROooo`03o`2Ioooooooo01;oool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00ROooo`03o`2Ioooooooo01;oool00`0003?o03?o0002<ol00P0007_oool008Woool00ol0VOoo
ooooo`0Boooo00<0000co`0co`000S?o00030000oooooooo07[oool008Woool00ol0VOooooooo`0B
oooo00<0000co`0co`000S?o00030000oooooooo07[oool008Woool00ol0VOooooooo`0Boooo00<0
000co`0co`000S?o00030000oooooooo07[oool008Woool00ol0VOooooooo`0Boooo00<0000co`0c
o`000S?o00030000oooooooo07[oool008Woool00ol0VOooooooo`0Boooo00<0000co`0co`000S?o
00030000oooooooo07[oool008Woool00ol0VOooooooo`0Boooo00<0000co`0co`000S?o0080001k
oooo0029oooo00?o09Woooooool04oooo`050000<ol0<ol0<ol0000007coool008Woool00ol0VOoo
ooooo`0Coooo00D0000co`0co`0co`000000O?ooo`00ROooo`03o`2Ioooooooo01?oool01@0003?o
03?o03?o0000001loooo0029oooo00?o09Woooooool03oooo`D00003<ol000<0003oooooool0N_oo
o`00ROooo`03o`2Ioooooooo00ooool01@000?ooooooooooo`000003<ol000<0003oooooool0N_oo
o`00ROooo`03o`2Ioooooooo013oool010000?ooooooo`0000<co`030000N_ooo`00ROooo`03o`2I
oooooooo017oool00`000?ooo`000003<ol000<0003oooooool0N_ooo`00ROooo`03o`2Ioooooooo
00ooool00`000?ooooooo`0200000c?o00030000oooooooo07[oool008Woool00ol0VOooooooo`0@
oooo0P000003oooo0000<ol0008co`000`000?ooooooo`1joooo0029oooo00?o09Woooooool04ooo
o`050000<ol0<ol0<ol0000007coool008Woool00ol0VOooooooo`0Doooo00@0000co`0co`00001l
oooo0029oooo00?o09Woooooool05?ooo`030000<ol0<ol00080001koooo0029oooo00?o09Wooooo
ool05?ooo`040000<ol0<ol00000O?ooo`00ROooo`03o`2Ioooooooo01Coool0100003?o03?o0000
07coool008Woool00ol0VOooooooo`0Doooo00@0000co`0co`00001loooo0029oooo00?o09Wooooo
ool05?ooo`040000<ol0<ol00000O?ooo`00ROooo`03o`2Ioooooooo01Coool0100003?o03?o0000
07coool008Woool00ol0VOooooooo`0Doooo00@0000co`0co`00001loooo0029oooo00?o09Wooooo
ool05Oooo`040000<ol000000000Noooo`00ROooo`03o`2Ioooooooo01Goool00`0003?o0000001l
oooo0029oooo00?o09Woooooool05Oooo`030000<ol0000007coool008Woool00ol0VOooooooo`0E
oooo00<0000co`000000O?ooo`00ROooo`03o`2Ioooooooo01Goool00`0003?o0000001loooo0029
oooo00?o09Woooooool05Oooo`030000<ol0000007coool008Woool00ol0VOooooooo`0Eoooo00@0
000co`000000001koooo0029oooo00?o09Woooooool05Oooo`030000<ol0000007coool008Woool0
0ol0VOooooooo`0Eoooo00<0000co`000000O?ooo`00ROooo`03o`2Ioooooooo01Goool00`0003?o
0000001loooo0029oooo00?o09Woooooool05Oooo`030000<ol0000007coool008Woool00ol0VOoo
ooooo`0Eoooo00<0000co`000000O?ooo`00ROooo`03o`2Ioooooooo01Goool0100003?o00000000
07_oool008Woool00ol0VOooooooo`0Eoooo00<0000co`000000O?ooo`00ROooo`03o`2Ioooooooo
01Goool00`0003?o0000001loooo0029oooo00?o09Woooooool05Oooo`030000<ol0000007coool0
08Woool00ol0VOooooooo`0@oooo0P0000?oool00`0003?o0000001loooo0029oooo00?o09Wooooo
ool03oooo`040000oooooooo00000_ooo`030000<ol0000007coool008Woool00ol0VOooooooo`0A
oooo00H0003oooooooooool0000co`030000N_ooo`00ROooo`03o`2Ioooooooo01;oool01P000?oo
ooooo`0003?o000007coool008Woool00ol0VOooooooo`0?oooo00@0003oooooool00002oooo00<0
000co`000000O?ooo`00ROooo`03o`2Ioooooooo013oool200001?ooo`80001loooo0029oooo00?o
09Woooooool05_ooo`80001loooo0029oooo00?o09Woooooool05_ooo`80001loooo0029oooo00?o
09Woooooool05_ooo`80001loooo0029oooo00?o09Woooooool05_ooo`<0001koooo0029oooo00?o
09Woooooool05_ooo`80001loooo0029oooo00?o09Woooooool05_ooo`80001loooo0029oooo00?o
09Woooooool05_ooo`80001loooo0029oooo00?o09Woooooool05_ooo`80001loooo0029oooo00?o
09Woooooool05_ooo`80001loooo0029oooo00?o09Woooooool05_ooo`<0001koooo0029oooo00?o
09Woooooool05_ooo`80001loooo0029oooo00?o09Woooooool05_ooo`80001loooo0029oooo00?o
09Woooooool05_ooo`80001loooo0029oooo00?o09Woooooool05_ooo`80001loooo0029oooo00?o
09Woooooool05_ooo`80001loooo0029oooo00?o09Woooooool05_ooo`<0001koooo0029oooo00?o
09Woooooool05oooo`030000oooooooo07[oool008Woool00ol0VOooooooo`0Goooo00<0003ooooo
ool0N_ooo`00ROooo`03o`2Ioooooooo01Ooool00`000?ooooooo`1joooo0029oooo00?o09Wooooo
ool05oooo`030000oooooooo07[oool008Woool00ol0VOooooooo`0Goooo00<0003oooooool0N_oo
o`00ROooo`03o`2Ioooooooo01Ooool20000Noooo`00ROooo`03o`2Ioooooooo01Ooool00`000?oo
ooooo`1joooo0029oooo00?o09Woooooool05oooo`030000oooooooo07[oool008Woool00ol0VOoo
ooooo`0Goooo00<0003oooooool0N_ooo`00ROooo`03o`2Ioooooooo01Ooool00`000?ooooooo`1j
oooo0029oooo00?o09Woooooool04Oooo`<00003oooo00<0003oooooool0N_ooo`00ROooo`03o`2I
oooooooo01;oool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00ROooo`03o`2Ioooooooo
00ooool500000oooo`<0001joooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool0
0000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool4
00000oooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool00`000?ooooooo`09
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0Doooo00<0003oooooool02_ooo`030000oooooooo00?oool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0001Coool00`000?ooooooo`0:oooo00D0003oooooooooool0
0000N_ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P00
00?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47567 .12361 L
.47994 .12361 L
.48231 .12361 L
.483 .12361 L
.48364 .12361 L
s
.48364 .12361 m
.48412 .61803 L
s
0 .4 1 r
.02381 .12401 m
.04262 .12417 L
.06244 .1244 L
.07286 .12457 L
.08255 .12475 L
.09388 .125 L
.10458 .12529 L
.125 .12604 L
.14357 .12699 L
.16355 .12843 L
.18199 .13031 L
.20071 .13297 L
.21136 .13492 L
.22134 .13713 L
.24158 .143 L
.26011 .15058 L
.27909 .16144 L
.28984 .16943 L
.29982 .17835 L
.31861 .20012 L
.32128 .20384 L
.32376 .20748 L
.32502 .20937 L
.32572 .20995 L
.32636 .20994 L
.3292 .20988 L
.33895 .20967 L
.34994 .20938 L
.36036 .20905 L
.38053 .2082 L
.40044 .20702 L
.41886 .2055 L
.43752 .20338 L
.45813 .2001 L
.46755 .19818 L
.47747 .19581 L
.47999 .19515 L
.48137 .19477 L
.48267 .1944 L
.48341 .19419 L
.48421 .12361 L
.48494 .12361 L
.48561 .12361 L
.48625 .12361 L
.48694 .12361 L
.48767 .12361 L
.48835 .12361 L
.48964 .12361 L
.49087 .12361 L
.49196 .12361 L
Mistroke
.49316 .12361 L
.49446 .12361 L
.49519 .12361 L
.49584 .12361 L
.49712 .12361 L
.49833 .12361 L
.4995 .12361 L
.50075 .12361 L
.50193 .12361 L
.503 .12361 L
.50426 .12361 L
.50497 .12361 L
.50563 .12361 L
.50684 .12361 L
.50812 .12361 L
.50934 .12361 L
.51065 .12361 L
.5119 .12361 L
.51303 .12361 L
.51429 .12361 L
.51501 .12361 L
.51567 .12361 L
.51638 .12361 L
.51701 .12361 L
.51775 .12361 L
.51845 .12361 L
.51952 .12361 L
.52069 .12361 L
.52192 .12361 L
.52307 .12361 L
.52414 .12361 L
.52512 .12361 L
.52625 .12361 L
.52732 .12361 L
.52848 .12361 L
.52971 .12361 L
.53076 .12361 L
.53192 .12361 L
.53317 .12361 L
.53386 .12361 L
.53451 .12361 L
.53569 .12361 L
.53693 .12361 L
.53816 .12361 L
.53886 .12361 L
.5395 .12361 L
.54068 .12361 L
.54192 .12361 L
.54304 .12361 L
.54408 .12361 L
Mistroke
.54523 .12361 L
.54646 .12361 L
.54777 .12361 L
.5485 .12361 L
.54919 .12361 L
.55045 .12361 L
.55115 .12361 L
.55178 .12361 L
.55299 .12361 L
.55429 .12361 L
.55552 .12361 L
.55665 .12361 L
.55771 .12361 L
.55885 .12361 L
.55993 .12361 L
.56091 .12361 L
.56206 .12361 L
.56331 .12361 L
.56449 .12361 L
.56558 .12361 L
.5667 .12361 L
.56775 .12361 L
.56891 .12361 L
.57015 .12361 L
.57139 .12361 L
.57269 .12361 L
.5738 .12361 L
.57501 .12361 L
.57633 .12361 L
.57755 .12361 L
.57818 .12361 L
.57889 .12361 L
.57962 .12361 L
.5803 .12361 L
.58529 .12361 L
.59463 .12361 L
.61559 .12361 L
.65443 .12361 L
.69573 .12361 L
.73551 .12361 L
.77378 .12361 L
.81449 .12361 L
.85369 .12361 L
.89535 .12361 L
.93549 .12361 L
.97411 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0706Ko00<00000I_l0I_l01`1Vo`04000006Ko06Ko06Ko1_ooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oool0000040000003<ol00000<ol000@co`001@1Voc?o03?o03?o00000009
<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`0Eoooo000Zoooo00<0003oooooool02oooo`T0I_lBoooo00<0003oooooool09Ooo
o`030000oooooooo00Koool400000c?o000306Ko<ol0<ol001Dco`000`000?ooooooo`0Uoooo00<0
003oooooool09_ooo`030000oooooooo02Woool0047oool606Ko@Oooo`<000000`1Voc?o03?o000E
<ol000<0003oooooool0N_ooo`00Aoooo`@0I_m0oooo00<0I_l0000co`005C?o00030000oooooooo
07[oool004_oool406Ko??ooo`0406Kooooo0000000053?o00030000oooooooo07[oool004ooool2
06Ko>_ooo`0506Kooooooooooooo000001<co`000`000?ooooooo`1joooo001Aoooo0P1VocSoool0
0`1Vooooooooo`02oooo00<0000co`0co`0043?o0080001koooo001Coooo0P1VocKoool00`1Voooo
ooooo`03oooo0P00010co`000`000?ooooooo`1joooo001Eoooo0P1VocCoool00`1Vooooooooo`05
oooo00<0000co`0co`003C?o00030000oooooooo07[oool005Ooool00`1Vooooooooo`0aoooo00<0
I_ooooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1joooo001Hoooo0P1Voc7oool0
0`1Vooooooooo`06oooo00<0000co`0co`0033?o00030000oooooooo07[oool005[oool00`1Voooo
ooooo`0^oooo00<0I_ooooooool01_ooo`030000<ol0<ol000`co`000`000?ooooooo`1joooo001K
oooo00<0I_ooooooool0;Oooo`0306Kooooooooo00Ooool00`0003?o03?o000;<ol00P0007_oool0
05coool00`1Vooooooooo`0/oooo00<0I_ooooooool01oooo`030000<ol0<ol000/co`000`000?oo
ooooo`1joooo001Moooo00<0I_ooooooool0:oooo`0306Kooooooooo00Soool00`0003?o03?o000:
<ol000<0003oooooool0N_ooo`00G_ooo`0306Kooooooooo02[oool00`1Vooooooooo`08oooo00<0
000co`0co`002S?o00030000oooooooo07[oool005koool00`1Vooooooooo`0Zoooo00<0I_oooooo
ool02Oooo`030000<ol0<ol000Tco`000`000?ooooooo`1joooo001Ooooo00<0I_ooooooool0:?oo
o`80I_l;oooo00<0000co`0co`002C?o00030000oooooooo07[oool0063oool00`1Vooooooooo`0S
oooo1@1Vo`03o`2Ioooooooo00[oool00`0003?o03?o0008<ol00P0007_oool0067oool00`1Voooo
ooooo`0Noooo101Vo`Goool00ol0VOooooooo`0:oooo00<0000co`0co`0023?o00030000oooooooo
07[oool006;oool00`1Vooooooooo`0Doooo2@1Vo`Woool00ol0VOooooooo`0:oooo00<0000co`0c
o`0023?o00030000oooooooo07[oool006;ooolG06Ko4_ooo`03o`2Ioooooooo00_oool00`0003?o
03?o0007<ol000<0003oooooool0N_ooo`00Roooo`03o`2Ioooooooo00_oool00`0003?o03?o0007
<ol000<0003oooooool0N_ooo`00Roooo`03o`2Ioooooooo00_oool00`0003?o03?o0007<ol000<0
003oooooool0N_ooo`00Roooo`03o`2Ioooooooo00_oool00`0003?o03?o0007<ol00P0007_oool0
08_oool00ol0VOooooooo`0<oooo00<0000co`0co`001S?o00030000oooooooo07[oool008_oool0
0ol0VOooooooo`0<oooo00<0000co`0co`001S?o00030000oooooooo07[oool008_oool00ol0VOoo
ooooo`0<oooo00<0000co`0co`001S?o00030000oooooooo07[oool008_oool00ol0VOooooooo`0<
oooo00<0000co`0co`001S?o00030000oooooooo07[oool008_oool00ol0VOooooooo`0=oooo1@00
00<co`000`000?ooooooo`1joooo002;oooo00?o09Woooooool03Oooo`030000<ol0000000Dco`00
0`000?ooooooo`1joooo002;oooo00?o09Woooooool03Oooo`030000<ol0000000Dco`030000N_oo
o`00Roooo`03o`2Ioooooooo00koool200001C?o00030000oooooooo07[oool008_oool00ol0VOoo
ooooo`0>oooo0P0000Dco`000`000?ooooooo`1joooo002;oooo00?o09Woooooool03_ooo`800005
<ol000<0003oooooool0N_ooo`00Roooo`03o`2Ioooooooo00koool00`0003?o03?o0004<ol000<0
003oooooool0N_ooo`00Roooo`03o`2Ioooooooo00koool00`0003?o03?o0004<ol000<0003ooooo
ool0N_ooo`00Roooo`03o`2Ioooooooo00koool00`0003?o03?o0004<ol00P0007_oool008_oool0
0ol0VOooooooo`0?oooo00<0000co`0co`000c?o00030000oooooooo07[oool008_oool00ol0VOoo
ooooo`0?oooo00<0000co`0co`000c?o00030000oooooooo07[oool008_oool00ol0VOooooooo`0?
oooo00<0000co`0co`000c?o00030000oooooooo07[oool008_oool00ol0VOooooooo`0?oooo00<0
000co`0co`000c?o00030000oooooooo07[oool008_oool00ol0VOooooooo`0?oooo00<0000co`0c
o`000c?o00030000oooooooo07[oool008_oool00ol0VOooooooo`0?oooo00<0000co`0co`000c?o
0080001koooo002;oooo00?o09Woooooool03oooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo002;oooo00?o09Woooooool03oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo002;
oooo00?o09Woooooool04?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo002;oooo00?o
09Woooooool04?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo002;oooo00?o09Wooooo
ool04?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo002;oooo00?o09Woooooool04?oo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo002;oooo00?o09Woooooool04?ooo`030000
<ol0<ol0008co`020000Noooo`00Roooo`03o`2Ioooooooo013oool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00Roooo`03o`2Ioooooooo013oool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00Roooo`03o`2Ioooooooo013oool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00Roooo`03o`2Ioooooooo013oool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Rooo
o`03o`2Ioooooooo013oool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00Roooo`03o`2I
oooooooo013oool00`0003?o03?o0002<ol00P0007_oool008_oool00ol0VOooooooo`0Aoooo00D0
000co`0co`0co`000000O?ooo`00Roooo`03o`2Ioooooooo017oool01@0003?o03?o03?o0000001l
oooo002;oooo00?o09Woooooool04Oooo`050000<ol0<ol0<ol0000007coool008_oool00ol0VOoo
ooooo`0=oooo1@0000<co`000`000?ooooooo`1joooo002;oooo00?o09Woooooool03Oooo`050000
oooooooooooo000000<co`000`000?ooooooo`1joooo002;oooo00?o09Woooooool03_ooo`040000
oooooooo00000c?o00<0001joooo002;oooo00?o09Woooooool03oooo`030000oooo000000<co`00
0`000?ooooooo`1joooo002;oooo00?o09Woooooool03Oooo`030000oooooooo00800003<ol000<0
003oooooool0N_ooo`00Roooo`03o`2Ioooooooo00koool2000000?oool0000co`000S?o00030000
oooooooo07[oool008_oool00ol0VOooooooo`0Aoooo00D0000co`0co`0co`000000O?ooo`00Rooo
o`03o`2Ioooooooo01;oool0100003?o03?o000007coool008_oool00ol0VOooooooo`0Boooo00<0
000co`0co`000P0007_oool008_oool00ol0VOooooooo`0Boooo00@0000co`0co`00001loooo002;
oooo00?o09Woooooool04_ooo`040000<ol0<ol00000O?ooo`00Roooo`03o`2Ioooooooo01;oool0
100003?o03?o000007coool008_oool00ol0VOooooooo`0Boooo00@0000co`0co`00001loooo002;
oooo00?o09Woooooool04_ooo`040000<ol0<ol00000O?ooo`00Roooo`03o`2Ioooooooo01;oool0
100003?o03?o000007coool008_oool00ol0VOooooooo`0Coooo00@0000co`000000001koooo002;
oooo00?o09Woooooool04oooo`030000<ol0000007coool008_oool00ol0VOooooooo`0Coooo00<0
000co`000000O?ooo`00Roooo`03o`2Ioooooooo01?oool00`0003?o0000001loooo002;oooo00?o
09Woooooool04oooo`030000<ol0000007coool008_oool00ol0VOooooooo`0Coooo00<0000co`00
0000O?ooo`00Roooo`03o`2Ioooooooo01?oool0100003?o0000000007_oool008_oool00ol0VOoo
ooooo`0Coooo00<0000co`000000O?ooo`00Roooo`03o`2Ioooooooo01?oool00`0003?o0000001l
oooo002;oooo00?o09Woooooool04oooo`030000<ol0000007coool008_oool00ol0VOooooooo`0C
oooo00<0000co`000000O?ooo`00Roooo`03o`2Ioooooooo01?oool00`0003?o0000001loooo002;
oooo00?o09Woooooool04oooo`040000<ol000000000Noooo`00Roooo`03o`2Ioooooooo01?oool0
0`0003?o0000001loooo002;oooo00?o09Woooooool04oooo`030000<ol0000007coool008_oool0
0ol0VOooooooo`0Coooo00<0000co`000000O?ooo`00Roooo`03o`2Ioooooooo00koool200000ooo
o`030000<ol0000007coool008_oool00ol0VOooooooo`0=oooo00@0003oooooool00002oooo00<0
000co`000000O?ooo`00Roooo`03o`2Ioooooooo00ooool01P000?ooooooooooo`0003?o00<0001j
oooo002;oooo00?o09Woooooool04?ooo`060000oooooooo0000<ol00000O?ooo`00Roooo`03o`2I
oooooooo00goool010000?ooooooo`0000;oool00`0003?o0000001loooo002;oooo00?o09Wooooo
ool03_ooo`800004oooo0P0007coool008_oool00ol0VOooooooo`0Doooo0P0007coool008_oool0
0ol0VOooooooo`0Doooo0P0007coool008_oool00ol0VOooooooo`0Doooo0P0007coool008_oool0
0ol0VOooooooo`0Doooo0`0007_oool008_oool00ol0VOooooooo`0Doooo0P0007coool008_oool0
0ol0VOooooooo`0Doooo0P0007coool008_oool00ol0VOooooooo`0Doooo0P0007coool008_oool0
0ol0VOooooooo`0Doooo0P0007coool008_oool00ol0VOooooooo`0Doooo0P0007coool008_oool0
0ol0VOooooooo`0Doooo0`0007_oool008_oool00ol0VOooooooo`0Doooo0P0007coool008_oool0
0ol0VOooooooo`0Doooo0P0007coool008_oool00ol0VOooooooo`0Doooo0P0007coool008_oool0
0ol0VOooooooo`0Doooo0P0007coool008_oool00ol0VOooooooo`0Doooo0P0007coool008_oool0
0ol0VOooooooo`0Doooo0`0007_oool008_oool00ol0VOooooooo`0Eoooo00<0003oooooool0N_oo
o`00Roooo`03o`2Ioooooooo01Goool00`000?ooooooo`1joooo002;oooo00?o09Woooooool05Ooo
o`030000oooooooo07[oool008_oool00ol0VOooooooo`0Eoooo00<0003oooooool0N_ooo`00Rooo
o`03o`2Ioooooooo01Goool00`000?ooooooo`1joooo002;oooo00?o09Woooooool05Oooo`80001k
oooo002;oooo00?o09Woooooool05Oooo`030000oooooooo07[oool008_oool00ol0VOooooooo`0E
oooo00<0003oooooool0N_ooo`00Roooo`03o`2Ioooooooo01Goool00`000?ooooooo`1joooo002;
oooo00?o09Woooooool05Oooo`030000oooooooo07[oool008_oool00ol0VOooooooo`0?oooo0`00
00?oool00`000?ooooooo`1joooo002;oooo00?o09Woooooool04?ooo`030000oooooooo00;oool0
0`000?ooooooo`1joooo002;oooo00?o09Woooooool03Oooo`D00003oooo0`0007[oool009_oool0
10000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQ
oooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03?ooo`@00003oooo0P0000?oool400000oooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool400000oooo`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Doooo00<0003oooooool02Ooo
o`030000oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001Coool0
0`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47994 .12361 L
.48519 .12361 L
.48778 .12361 L
.48904 .12361 L
.49018 .12361 L
.4913 .12361 L
s
.4913 .12361 m
.49172 .61803 L
s
0 .4 1 r
.02381 .12395 m
.04262 .12409 L
.06244 .1243 L
.07286 .12444 L
.08255 .1246 L
.09388 .12482 L
.10458 .12507 L
.125 .12571 L
.14357 .12654 L
.16355 .12779 L
.18199 .12942 L
.20071 .13173 L
.21136 .13343 L
.22134 .13534 L
.24158 .14043 L
.26011 .14701 L
.27909 .15643 L
.28984 .16336 L
.29982 .1711 L
.31861 .18999 L
.3285 .20278 L
.33091 .20624 L
.33223 .20822 L
.33348 .2099 L
.33419 .20988 L
.33496 .20987 L
.33631 .20984 L
.33895 .20978 L
.3501 .20951 L
.36036 .20921 L
.38053 .20845 L
.4003 .20738 L
.41029 .20668 L
.42131 .20576 L
.44066 .20366 L
.46152 .20047 L
.48156 .19619 L
.48643 .19492 L
.48911 .19418 L
.49042 .1938 L
.49163 .19345 L
.49233 .12361 L
.49307 .12361 L
.49381 .12361 L
.49462 .12361 L
.4953 .12361 L
.49603 .12361 L
.49734 .12361 L
.49802 .12361 L
.49877 .12361 L
Mistroke
.49947 .12361 L
.50012 .12361 L
.50135 .12361 L
.50266 .12361 L
.5039 .12361 L
.50461 .12361 L
.50527 .12361 L
.50597 .12361 L
.5066 .12361 L
.50734 .12361 L
.50803 .12361 L
.50926 .12361 L
.5104 .12361 L
.51164 .12361 L
.51227 .12361 L
.51297 .12361 L
.51367 .12361 L
.51441 .12361 L
.51504 .12361 L
.51574 .12361 L
.51648 .12361 L
.51728 .12361 L
.51803 .12361 L
.51872 .12361 L
.51941 .12361 L
.52005 .12361 L
.52075 .12361 L
.52149 .12361 L
.52274 .12361 L
.52345 .12361 L
.52411 .12361 L
.52536 .12361 L
.52602 .12361 L
.52672 .12361 L
.52801 .12361 L
.5292 .12361 L
.53034 .12361 L
.53141 .12361 L
.53258 .12361 L
.53384 .12361 L
.53511 .12361 L
.53583 .12361 L
.5365 .12361 L
.5372 .12361 L
.53785 .12361 L
.5386 .12361 L
.53929 .12361 L
.54052 .12361 L
.54117 .12361 L
.54186 .12361 L
Mistroke
.54312 .12361 L
.54429 .12361 L
.5455 .12361 L
.54681 .12361 L
.54797 .12361 L
.54921 .12361 L
.55043 .12361 L
.55157 .12361 L
.55371 .12361 L
.55504 .12361 L
.55628 .12361 L
.55757 .12361 L
.55825 .12361 L
.55899 .12361 L
.56029 .12361 L
.56153 .12361 L
.56263 .12361 L
.56384 .12361 L
.56489 .12361 L
.56606 .12361 L
.56727 .12361 L
.56841 .12361 L
.56947 .12361 L
.57044 .12361 L
.57151 .12361 L
.57263 .12361 L
.57377 .12361 L
.57499 .12361 L
.57604 .12361 L
.57718 .12361 L
.57787 .12361 L
.57852 .12361 L
.57978 .12361 L
.58093 .12361 L
.58214 .12361 L
.62005 .12361 L
.66041 .12361 L
.69926 .12361 L
.74055 .12361 L
.78033 .12361 L
.8186 .12361 L
.85932 .12361 L
.89852 .12361 L
.94017 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00L0I_l0
0`00001Vo`1Vo`0706Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko00D0I_l2oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`001S?o000306Ko<ol0000000Tco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool002[oool00`000?ooooooo`0?oooo2@1Vo`koool00`000?ooooooo`0Uoooo00<0
003oooooool01_ooo`@00005<ol000<0I_lco`0co`004c?o00030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0003oooooool0:Oooo`00AOooo`D0I_lnoooo10000003<ol006Ko<ol001@co`00
0`000?ooooooo`1joooo001:oooo0P1Vod3oool00`00001Voc?o000D<ol000<0003oooooool0N_oo
o`00C?ooo`@0I_lmoooo00<0I_l0000co`004c?o00030000oooooooo07[oool0053oool306Ko>_oo
o`0306Kooooo000001<co`000`000?ooooooo`1joooo001Coooo0P1VocSoool0101Vooooooooo`00
018co`020000Noooo`00EOooo`80I_lfoooo00@0I_ooooooooooool2000043?o00030000oooooooo
07[oool005Ooool206Ko=?ooo`0306Kooooooooo00?oool00`0003?o03?o000=<ol000<0003ooooo
ool0N_ooo`00FOooo`80I_lboooo00<0I_ooooooool00oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1joooo001Koooo00<0I_ooooooool0;oooo`0306Kooooooooo00Coool00`0003?o03?o000<
<ol000<0003oooooool0N_ooo`00G?ooo`0306Kooooooooo02koool00`1Vooooooooo`04oooo00<0
000co`0co`0033?o00030000oooooooo07[oool005goool00`1Vooooooooo`0]oooo00<0I_oooooo
ool01Oooo`030000<ol0<ol000/co`020000Noooo`00G_ooo`0306Kooooooooo02coool00`1Voooo
ooooo`05oooo00<0000co`0co`002c?o00030000oooooooo07[oool005ooool00`1Vooooooooo`0[
oooo00<0I_ooooooool01_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo001Poooo00<0
I_ooooooool0:_ooo`0306Kooooooooo00Koool00`0003?o03?o000:<ol000<0003oooooool0N_oo
o`00HOooo`0306Kooooooooo02Woool00`1Vooooooooo`07oooo00<0000co`0co`002C?o00030000
oooooooo07[oool006;oool00`1Vooooooooo`0Woooo0P1Vo`Woool00`0003?o03?o0009<ol000<0
003oooooool0N_ooo`00H_ooo`0306Kooooooooo02?oool406Ko00?ooooo09Woool02Oooo`030000
<ol0<ol000Pco`020000Noooo`00Hoooo`0306Kooooooooo01goool506Ko1Oooo`03o`2Ioooooooo
00Soool00`0003?o03?o0008<ol000<0003oooooool0N_ooo`00I?ooo`0306Kooooooooo017oool;
06Ko2_ooo`03o`2Ioooooooo00Soool00`0003?o03?o0008<ol000<0003oooooool0N_ooo`00I?oo
oa@0I_lEoooo00?o09Woooooool02Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo002=
oooo00?o09Woooooool02Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo002=oooo00?o
09Woooooool02Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo002=oooo00?o09Wooooo
ool02Oooo`030000<ol0<ol000Lco`020000Noooo`00SOooo`03o`2Ioooooooo00[oool00`0003?o
03?o0006<ol000<0003oooooool0N_ooo`00SOooo`03o`2Ioooooooo00[oool00`0003?o03?o0006
<ol000<0003oooooool0N_ooo`00SOooo`03o`2Ioooooooo00[oool00`0003?o03?o0006<ol000<0
003oooooool0N_ooo`00SOooo`03o`2Ioooooooo00[oool00`0003?o03?o0006<ol000<0003ooooo
ool0N_ooo`00SOooo`03o`2Ioooooooo00_oool500000c?o00030000oooooooo07[oool008goool0
0ol0VOooooooo`0;oooo00<0000co`0000001C?o00030000oooooooo07[oool008goool00ol0VOoo
ooooo`0;oooo00<0000co`0000001C?o00<0001joooo002=oooo00?o09Woooooool03?ooo`800005
<ol000<0003oooooool0N_ooo`00SOooo`03o`2Ioooooooo00coool200001C?o00030000oooooooo
07[oool008goool00ol0VOooooooo`0<oooo0P0000Dco`000`000?ooooooo`1joooo002=oooo00?o
09Woooooool03?ooo`030000<ol0<ol000@co`000`000?ooooooo`1joooo002=oooo00?o09Wooooo
ool03?ooo`030000<ol0<ol000@co`000`000?ooooooo`1joooo002=oooo00?o09Woooooool03?oo
o`030000<ol0<ol000@co`020000Noooo`00SOooo`03o`2Ioooooooo00goool00`0003?o03?o0003
<ol000<0003oooooool0N_ooo`00SOooo`03o`2Ioooooooo00goool00`0003?o03?o0003<ol000<0
003oooooool0N_ooo`00SOooo`03o`2Ioooooooo00goool00`0003?o03?o0003<ol000<0003ooooo
ool0N_ooo`00SOooo`03o`2Ioooooooo00goool00`0003?o03?o0003<ol000<0003oooooool0N_oo
o`00SOooo`03o`2Ioooooooo00goool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00SOoo
o`03o`2Ioooooooo00goool00`0003?o03?o0003<ol00P0007_oool008goool00ol0VOooooooo`0=
oooo00<0000co`0co`000c?o00030000oooooooo07[oool008goool00ol0VOooooooo`0=oooo00<0
000co`0co`000c?o00030000oooooooo07[oool008goool00ol0VOooooooo`0>oooo00<0000co`0c
o`000S?o00030000oooooooo07[oool008goool00ol0VOooooooo`0>oooo00<0000co`0co`000S?o
00030000oooooooo07[oool008goool00ol0VOooooooo`0>oooo00<0000co`0co`000S?o00030000
oooooooo07[oool008goool00ol0VOooooooo`0>oooo00<0000co`0co`000S?o00030000oooooooo
07[oool008goool00ol0VOooooooo`0>oooo00<0000co`0co`000S?o0080001koooo002=oooo00?o
09Woooooool03_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo002=oooo00?o09Wooooo
ool03_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo002=oooo00?o09Woooooool03_oo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo002=oooo00?o09Woooooool03_ooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo002=oooo00?o09Woooooool03_ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo002=oooo00?o09Woooooool03_ooo`030000<ol0<ol0008co`02
0000Noooo`00SOooo`03o`2Ioooooooo00ooool01@0003?o03?o03?o0000001loooo002=oooo00?o
09Woooooool03oooo`050000<ol0<ol0<ol0000007coool008goool00ol0VOooooooo`0?oooo00D0
000co`0co`0co`000000O?ooo`00SOooo`03o`2Ioooooooo00_oool500000c?o00030000oooooooo
07[oool008goool00ol0VOooooooo`0;oooo00D0003oooooooooool000000c?o00030000oooooooo
07[oool008goool00ol0VOooooooo`0<oooo00@0003oooooool00003<ol00`0007[oool008goool0
0ol0VOooooooo`0=oooo00<0003oool000000c?o00030000oooooooo07[oool008goool00ol0VOoo
ooooo`0;oooo00<0003oooooool00P0000<co`000`000?ooooooo`1joooo002=oooo00?o09Wooooo
ool03?ooo`8000000oooo`0003?o0002<ol000<0003oooooool0N_ooo`00SOooo`03o`2Ioooooooo
00ooool01@0003?o03?o03?o0000001loooo002=oooo00?o09Woooooool04?ooo`040000<ol0<ol0
0000O?ooo`00SOooo`03o`2Ioooooooo013oool00`0003?o03?o00020000Noooo`00SOooo`03o`2I
oooooooo013oool0100003?o03?o000007coool008goool00ol0VOooooooo`0@oooo00@0000co`0c
o`00001loooo002=oooo00?o09Woooooool04?ooo`040000<ol0<ol00000O?ooo`00SOooo`03o`2I
oooooooo013oool0100003?o03?o000007coool008goool00ol0VOooooooo`0@oooo00@0000co`0c
o`00001loooo002=oooo00?o09Woooooool04?ooo`040000<ol0<ol00000O?ooo`00SOooo`03o`2I
oooooooo017oool0100003?o0000000007_oool008goool00ol0VOooooooo`0Aoooo00<0000co`00
0000O?ooo`00SOooo`03o`2Ioooooooo017oool00`0003?o0000001loooo002=oooo00?o09Wooooo
ool04Oooo`030000<ol0000007coool008goool00ol0VOooooooo`0Aoooo00<0000co`000000O?oo
o`00SOooo`03o`2Ioooooooo017oool00`0003?o0000001loooo002=oooo00?o09Woooooool04Ooo
o`040000<ol000000000Noooo`00SOooo`03o`2Ioooooooo017oool00`0003?o0000001loooo002=
oooo00?o09Woooooool04Oooo`030000<ol0000007coool008goool00ol0VOooooooo`0Aoooo00<0
000co`000000O?ooo`00SOooo`03o`2Ioooooooo017oool00`0003?o0000001loooo002=oooo00?o
09Woooooool04Oooo`030000<ol0000007coool008goool00ol0VOooooooo`0Aoooo00@0000co`00
0000001koooo002=oooo00?o09Woooooool04Oooo`030000<ol0000007coool008goool00ol0VOoo
ooooo`0Aoooo00<0000co`000000O?ooo`00SOooo`03o`2Ioooooooo017oool00`0003?o0000001l
oooo002=oooo00?o09Woooooool03?ooo`800003oooo00<0000co`000000O?ooo`00SOooo`03o`2I
oooooooo00_oool010000?ooooooo`0000;oool00`0003?o0000001loooo002=oooo00?o09Wooooo
ool03Oooo`060000oooooooooooo0000<ol00`0007[oool008goool00ol0VOooooooo`0>oooo00H0
003oooooool0000co`00001loooo002=oooo00?o09Woooooool02oooo`040000oooooooo00000_oo
o`030000<ol0000007coool008goool00ol0VOooooooo`0<oooo0P0000Coool20000O?ooo`00SOoo
o`03o`2Ioooooooo01;oool20000O?ooo`00SOooo`03o`2Ioooooooo01;oool20000O?ooo`00SOoo
o`03o`2Ioooooooo01;oool20000O?ooo`00SOooo`03o`2Ioooooooo01;oool30000Noooo`00SOoo
o`03o`2Ioooooooo01;oool20000O?ooo`00SOooo`03o`2Ioooooooo01;oool20000O?ooo`00SOoo
o`03o`2Ioooooooo01;oool20000O?ooo`00SOooo`03o`2Ioooooooo01;oool20000O?ooo`00SOoo
o`03o`2Ioooooooo01;oool20000O?ooo`00SOooo`03o`2Ioooooooo01;oool30000Noooo`00SOoo
o`03o`2Ioooooooo01;oool20000O?ooo`00SOooo`03o`2Ioooooooo01;oool20000O?ooo`00SOoo
o`03o`2Ioooooooo01;oool20000O?ooo`00SOooo`03o`2Ioooooooo01;oool20000O?ooo`00SOoo
o`03o`2Ioooooooo01;oool20000O?ooo`00SOooo`03o`2Ioooooooo01;oool30000Noooo`00SOoo
o`03o`2Ioooooooo01?oool00`000?ooooooo`1joooo002=oooo00?o09Woooooool04oooo`030000
oooooooo07[oool008goool00ol0VOooooooo`0Coooo00<0003oooooool0N_ooo`00SOooo`03o`2I
oooooooo01?oool00`000?ooooooo`1joooo002=oooo00?o09Woooooool04oooo`030000oooooooo
07[oool008goool00ol0VOooooooo`0Coooo0P0007_oool008goool00ol0VOooooooo`0Coooo00<0
003oooooool0N_ooo`00SOooo`03o`2Ioooooooo01?oool00`000?ooooooo`1joooo002=oooo00?o
09Woooooool04oooo`030000oooooooo07[oool008goool00ol0VOooooooo`0Coooo00<0003ooooo
ool0N_ooo`00SOooo`03o`2Ioooooooo00goool300000oooo`030000oooooooo07[oool008goool0
0ol0VOooooooo`0>oooo00<0003oooooool00_ooo`030000oooooooo07[oool008goool00ol0VOoo
ooooo`0;oooo1@0000?oool30000N_ooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000
oooo0000087oool009goool20000POooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<
oooo100000?oool200000oooo`D00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00<0003ooooo
ool02oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01Coool00`000?ooooooo`0:oooo00<0003oooooool00oooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500005?ooo`030000oooooooo00Woool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool2
00002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50007 .61803 L
s
0 .4 1 r
.02381 .12391 m
.04262 .12403 L
.06244 .12421 L
.07286 .12433 L
.08255 .12446 L
.09388 .12466 L
.10458 .12488 L
.125 .12543 L
.14357 .12615 L
.16355 .12724 L
.18199 .12865 L
.20071 .13065 L
.21136 .13212 L
.22134 .13378 L
.24158 .1382 L
.26011 .14391 L
.27909 .15208 L
.28984 .15809 L
.29982 .1648 L
.32034 .18298 L
.32939 .19337 L
.33433 .1998 L
.33895 .20633 L
.34013 .20809 L
.34125 .2098 L
.34255 .2098 L
.34373 .20977 L
.34897 .20965 L
.35819 .20941 L
.36829 .2091 L
.37901 .2087 L
.39892 .20773 L
.41734 .20648 L
.43681 .20465 L
.45509 .20229 L
.47528 .19871 L
.48422 .19672 L
.49378 .19425 L
.49642 .1935 L
.49772 .19312 L
.49892 .19276 L
.50001 .12361 L
.50116 .12361 L
.50233 .12361 L
.50359 .12361 L
.50476 .12361 L
.50583 .12361 L
.50691 .12361 L
.50793 .12361 L
.50911 .12361 L
Mistroke
.51021 .12361 L
.51142 .12361 L
.51271 .12361 L
.51339 .12361 L
.51411 .12361 L
.5154 .12361 L
.51611 .12361 L
.51678 .12361 L
.51752 .12361 L
.5183 .12361 L
.51898 .12361 L
.51972 .12361 L
.52042 .12361 L
.52106 .12361 L
.52228 .12361 L
.52357 .12361 L
.52473 .12361 L
.52598 .12361 L
.52717 .12361 L
.52825 .12361 L
.52945 .12361 L
.53076 .12361 L
.53143 .12361 L
.53213 .12361 L
.53341 .12361 L
.53464 .12361 L
.53535 .12361 L
.536 .12361 L
.5367 .12361 L
.53733 .12361 L
.53806 .12361 L
.53875 .12361 L
.53998 .12361 L
.54111 .12361 L
.54235 .12361 L
.54368 .12361 L
.54491 .12361 L
.54622 .12361 L
.5469 .12361 L
.54765 .12361 L
.54896 .12361 L
.54971 .12361 L
.55052 .12361 L
.55127 .12361 L
.55197 .12361 L
.55266 .12361 L
.55342 .12361 L
.55413 .12361 L
.55479 .12361 L
.55595 .12361 L
Mistroke
.5572 .12361 L
.55838 .12361 L
.55945 .12361 L
.56071 .12361 L
.56142 .12361 L
.56208 .12361 L
.56329 .12361 L
.56458 .12361 L
.56524 .12361 L
.56593 .12361 L
.56669 .12361 L
.56739 .12361 L
.56864 .12361 L
.56936 .12361 L
.57002 .12361 L
.57127 .12361 L
.57241 .12361 L
.57372 .12361 L
.57496 .12361 L
.5761 .12361 L
.57733 .12361 L
.57849 .12361 L
.57955 .12361 L
.58073 .12361 L
.58202 .12361 L
.58462 .12361 L
.59488 .12361 L
.61331 .12361 L
.65389 .12361 L
.69295 .12361 L
.73447 .12361 L
.77447 .12361 L
.81296 .12361 L
.8539 .12361 L
.89332 .12361 L
.93123 .12361 L
.97159 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00L0I_l0
0`00001Vo`1Vo`0706Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko00D0I_l2oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool002[oool00`000?ooooooo`0?oooo2@1Vo`koool00`000?ooooooo`0Uoooo00<0
003oooooool01_ooo`@00007<ol000<0I_lco`0co`004C?o00030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0003oooooool0:Oooo`00AOooo`H0I_lmoooo100000<co`000`1Voc?o03?o000A
<ol000<0003oooooool0N_ooo`00Boooo`@0I_lmoooo00@0000co`0co`00I_lC<ol000<0003ooooo
ool0N_ooo`00Coooo`80I_lloooo0P00000306Ko<ol0<ol0014co`000`000?ooooooo`1joooo001A
oooo0`1Voc_oool00`1Voc?o03?o000A<ol000<0003oooooool0N_ooo`00E?ooo`80I_lioooo00<0
I_l0000co`004C?o0080001koooo001Foooo0`1VocKoool0101Vooooo`000000010co`000`000?oo
ooooo`1joooo001Ioooo0P1VocCoool01@1Vooooooooooooo`00000?<ol000<0003oooooool0N_oo
o`00Foooo`0306Kooooooooo037oool01@1Vooooooooooooo`00000?<ol000<0003oooooool0N_oo
o`00G?ooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo00<0000co`0co`0033?o00030000
oooooooo07[oool005goool00`1Vooooooooo`0_oooo00<0I_ooooooool00_ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1joooo001Noooo0P1Vobooool00`1Vooooooooo`03oooo00<0000co`0c
o`002c?o0080001koooo001Poooo00<0I_ooooooool0;?ooo`0306Kooooooooo00?oool00`0003?o
03?o000;<ol000<0003oooooool0N_ooo`00HOooo`0306Kooooooooo02_oool00`1Vooooooooo`04
oooo00<0000co`0co`002S?o00030000oooooooo07[oool006;oool00`1Vooooooooo`0Zoooo00<0
I_ooooooool01?ooo`030000<ol0<ol000Xco`000`000?ooooooo`1joooo001Soooo00<0I_oooooo
ool0:Oooo`0306Kooooooooo00Goool00`0003?o03?o0009<ol000<0003oooooool0N_ooo`00I?oo
o`0306Kooooooooo02Koool306Ko1oooo`030000<ol0<ol000Tco`000`000?ooooooo`1joooo001T
oooo00<0I_ooooooool08?ooo`H0I_l2oooo00?o09Woooooool01_ooo`030000<ol0<ol000Pco`02
0000Noooo`00IOooo`0306Kooooooooo01[oool506Ko2?ooo`03o`2Ioooooooo00Koool00`0003?o
03?o0008<ol000<0003oooooool0N_ooo`00I_ooo`0306Kooooooooo00ooool:06Ko3Oooo`03o`2I
oooooooo00Koool00`0003?o03?o0008<ol000<0003oooooool0N_ooo`00I_oooa80I_lGoooo00?o
09Woooooool01oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo002?oooo00?o09Wooooo
ool01oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo002?oooo00?o09Woooooool01ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1joooo002?oooo00?o09Woooooool01oooo`030000
<ol0<ol000Lco`020000Noooo`00Soooo`03o`2Ioooooooo00Soool00`0003?o03?o0006<ol000<0
003oooooool0N_ooo`00Soooo`03o`2Ioooooooo00Soool00`0003?o03?o0006<ol000<0003ooooo
ool0N_ooo`00Soooo`03o`2Ioooooooo00Soool00`0003?o03?o0006<ol000<0003oooooool0N_oo
o`00Soooo`03o`2Ioooooooo00Soool00`0003?o03?o0006<ol000<0003oooooool0N_ooo`00Sooo
o`03o`2Ioooooooo00Woool500000c?o00030000oooooooo07[oool008ooool00ol0VOooooooo`09
oooo00<0000co`0000001C?o00030000oooooooo07[oool008ooool00ol0VOooooooo`09oooo00<0
000co`0000001C?o00<0001joooo002?oooo00?o09Woooooool02_ooo`800005<ol000<0003ooooo
ool0N_ooo`00Soooo`03o`2Ioooooooo00[oool200001C?o00030000oooooooo07[oool008ooool0
0ol0VOooooooo`0:oooo0P0000Dco`000`000?ooooooo`1joooo002?oooo00?o09Woooooool02_oo
o`030000<ol0<ol000@co`000`000?ooooooo`1joooo002?oooo00?o09Woooooool02_ooo`030000
<ol0<ol000@co`000`000?ooooooo`1joooo002?oooo00?o09Woooooool02_ooo`030000<ol0<ol0
00@co`020000Noooo`00Soooo`03o`2Ioooooooo00_oool00`0003?o03?o0003<ol000<0003ooooo
ool0N_ooo`00Soooo`03o`2Ioooooooo00_oool00`0003?o03?o0003<ol000<0003oooooool0N_oo
o`00Soooo`03o`2Ioooooooo00_oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Sooo
o`03o`2Ioooooooo00_oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Soooo`03o`2I
oooooooo00_oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Soooo`03o`2Ioooooooo
00_oool00`0003?o03?o0003<ol00P0007_oool008ooool00ol0VOooooooo`0;oooo00<0000co`0c
o`000c?o00030000oooooooo07[oool008ooool00ol0VOooooooo`0;oooo00<0000co`0co`000c?o
00030000oooooooo07[oool008ooool00ol0VOooooooo`0<oooo00<0000co`0co`000S?o00030000
oooooooo07[oool008ooool00ol0VOooooooo`0<oooo00<0000co`0co`000S?o00030000oooooooo
07[oool008ooool00ol0VOooooooo`0<oooo00<0000co`0co`000S?o00030000oooooooo07[oool0
08ooool00ol0VOooooooo`0<oooo00<0000co`0co`000S?o00030000oooooooo07[oool008ooool0
0ol0VOooooooo`0<oooo00<0000co`0co`000S?o0080001koooo002?oooo00?o09Woooooool03?oo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo002?oooo00?o09Woooooool03?ooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo002?oooo00?o09Woooooool03?ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo002?oooo00?o09Woooooool03?ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo002?oooo00?o09Woooooool03?ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo002?oooo00?o09Woooooool03?ooo`030000<ol0<ol0008co`020000Noooo`00Sooo
o`03o`2Ioooooooo00goool01@0003?o03?o03?o0000001loooo002?oooo00?o09Woooooool03Ooo
o`050000<ol0<ol0<ol0000007coool008ooool00ol0VOooooooo`0=oooo00D0000co`0co`0co`00
0000O?ooo`00Soooo`03o`2Ioooooooo00Woool500000c?o00030000oooooooo07[oool008ooool0
0ol0VOooooooo`09oooo00D0003oooooooooool000000c?o00030000oooooooo07[oool008ooool0
0ol0VOooooooo`0:oooo00@0003oooooool00003<ol00`0007[oool008ooool00ol0VOooooooo`0;
oooo00<0003oool000000c?o00030000oooooooo07[oool008ooool00ol0VOooooooo`09oooo00<0
003oooooool00P0000<co`000`000?ooooooo`1joooo002?oooo00?o09Woooooool02_ooo`800000
0oooo`0003?o0002<ol000<0003oooooool0N_ooo`00Soooo`03o`2Ioooooooo00goool01@0003?o
03?o03?o0000001loooo002?oooo00?o09Woooooool03_ooo`040000<ol0<ol00000O?ooo`00Sooo
o`03o`2Ioooooooo00koool00`0003?o03?o00020000Noooo`00Soooo`03o`2Ioooooooo00koool0
100003?o03?o000007coool008ooool00ol0VOooooooo`0>oooo00@0000co`0co`00001loooo002?
oooo00?o09Woooooool03_ooo`040000<ol0<ol00000O?ooo`00Soooo`03o`2Ioooooooo00koool0
100003?o03?o000007coool008ooool00ol0VOooooooo`0>oooo00@0000co`0co`00001loooo002?
oooo00?o09Woooooool03_ooo`040000<ol0<ol00000O?ooo`00Soooo`03o`2Ioooooooo00ooool0
100003?o0000000007_oool008ooool00ol0VOooooooo`0?oooo00<0000co`000000O?ooo`00Sooo
o`03o`2Ioooooooo00ooool00`0003?o0000001loooo002?oooo00?o09Woooooool03oooo`030000
<ol0000007coool008ooool00ol0VOooooooo`0?oooo00<0000co`000000O?ooo`00Soooo`03o`2I
oooooooo00ooool00`0003?o0000001loooo002?oooo00?o09Woooooool03oooo`040000<ol00000
0000Noooo`00Soooo`03o`2Ioooooooo00ooool00`0003?o0000001loooo002?oooo00?o09Wooooo
ool03oooo`030000<ol0000007coool008ooool00ol0VOooooooo`0?oooo00<0000co`000000O?oo
o`00Soooo`03o`2Ioooooooo00ooool00`0003?o0000001loooo002?oooo00?o09Woooooool03ooo
o`030000<ol0000007coool008ooool00ol0VOooooooo`0?oooo00@0000co`000000001koooo002?
oooo00?o09Woooooool03oooo`030000<ol0000007coool008ooool00ol0VOooooooo`0?oooo00<0
000co`000000O?ooo`00Soooo`03o`2Ioooooooo00ooool00`0003?o0000001loooo002?oooo00?o
09Woooooool02_ooo`800003oooo00<0000co`000000O?ooo`00Soooo`03o`2Ioooooooo00Woool0
10000?ooooooo`0000;oool00`0003?o0000001loooo002?oooo00?o09Woooooool02oooo`060000
oooooooooooo0000<ol00`0007[oool008ooool00ol0VOooooooo`0<oooo00H0003oooooool0000c
o`00001loooo002?oooo00?o09Woooooool02Oooo`040000oooooooo00000_ooo`030000<ol00000
07coool008ooool00ol0VOooooooo`0:oooo0P0000Coool20000O?ooo`00Soooo`03o`2Ioooooooo
013oool20000O?ooo`00Soooo`03o`2Ioooooooo013oool20000O?ooo`00Soooo`03o`2Ioooooooo
013oool20000O?ooo`00Soooo`03o`2Ioooooooo013oool30000Noooo`00Soooo`03o`2Ioooooooo
013oool20000O?ooo`00Soooo`03o`2Ioooooooo013oool20000O?ooo`00Soooo`03o`2Ioooooooo
013oool20000O?ooo`00Soooo`03o`2Ioooooooo013oool20000O?ooo`00Soooo`03o`2Ioooooooo
013oool20000O?ooo`00Soooo`03o`2Ioooooooo013oool30000Noooo`00Soooo`03o`2Ioooooooo
013oool20000O?ooo`00Soooo`03o`2Ioooooooo013oool20000O?ooo`00Soooo`03o`2Ioooooooo
013oool20000O?ooo`00Soooo`03o`2Ioooooooo013oool20000O?ooo`00Soooo`03o`2Ioooooooo
013oool20000O?ooo`00Soooo`03o`2Ioooooooo013oool30000Noooo`00Soooo`03o`2Ioooooooo
017oool00`000?ooooooo`1joooo002?oooo00?o09Woooooool04Oooo`030000oooooooo07[oool0
08ooool00ol0VOooooooo`0Aoooo00<0003oooooool0N_ooo`00Soooo`03o`2Ioooooooo017oool0
0`000?ooooooo`1joooo002?oooo00?o09Woooooool04Oooo`030000oooooooo07[oool008ooool0
0ol0VOooooooo`0Aoooo0P0007_oool008ooool00ol0VOooooooo`0Aoooo00<0003oooooool0N_oo
o`00Soooo`03o`2Ioooooooo017oool00`000?ooooooo`1joooo002?oooo00?o09Woooooool04Ooo
o`030000oooooooo07[oool008ooool00ol0VOooooooo`0Aoooo00<0003oooooool0N_ooo`00Sooo
o`03o`2Ioooooooo00_oool300000oooo`030000oooooooo07[oool008ooool00ol0VOooooooo`0<
oooo00<0003oooooool00_ooo`030000oooooooo07[oool008ooool00ol0VOooooooo`09oooo1@00
00?oool30000N_ooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000oooo0000087oool0
09goool20000POooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000
oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo
07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo100000?oool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400000oooo`030000oooooooo00[oool00`000?ooooooo`1k
oooo001joooo00<0003oooooool00_ooo`030000oooooooo01Coool00`000?ooooooo`0:oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000Doooo00<0003oooooool02?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo01Ooool200002Oooo`030000oooooooo07coool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49955 .12361 L
.50205 .12361 L
.50471 .12361 L
.50601 .12361 L
.50722 .12361 L
s
.50722 .12361 m
.50766 .61803 L
s
0 .4 1 r
.02381 .12387 m
.04262 .12397 L
.06244 .12413 L
.07286 .12423 L
.08255 .12435 L
.09388 .12452 L
.10458 .12471 L
.125 .12519 L
.14357 .12581 L
.16355 .12676 L
.18199 .12798 L
.20071 .12972 L
.21136 .13099 L
.22134 .13243 L
.24158 .13626 L
.26011 .14121 L
.27909 .1483 L
.28984 .15351 L
.29982 .15932 L
.32034 .17509 L
.33895 .19534 L
.34382 .20185 L
.34649 .20565 L
.34779 .20757 L
.34897 .20937 L
.35006 .20971 L
.35109 .20968 L
.35337 .20963 L
.35819 .20951 L
.36829 .20921 L
.37901 .20884 L
.39892 .20793 L
.41734 .20675 L
.43681 .20504 L
.45509 .20283 L
.47528 .19949 L
.49378 .19532 L
.49852 .19405 L
.50113 .19331 L
.50359 .19259 L
.50588 .19189 L
.50717 .19149 L
.50836 .12361 L
.50937 .12361 L
.51047 .12361 L
.51163 .12361 L
.51271 .12361 L
.51399 .12361 L
.51471 .12361 L
.51538 .12361 L
Mistroke
.51661 .12361 L
.51792 .12361 L
.51921 .12361 L
.52042 .12361 L
.52151 .12361 L
.52269 .12361 L
.52398 .12361 L
.52472 .12361 L
.5254 .12361 L
.52613 .12361 L
.52679 .12361 L
.52755 .12361 L
.52827 .12361 L
.52955 .12361 L
.53073 .12361 L
.53203 .12361 L
.53268 .12361 L
.53341 .12361 L
.53455 .12361 L
.53576 .12361 L
.53646 .12361 L
.5371 .12361 L
.53834 .12361 L
.53962 .12361 L
.54034 .12361 L
.54101 .12361 L
.54231 .12361 L
.54353 .12361 L
.54456 .12361 L
.54567 .12361 L
.54803 .12361 L
.54931 .12361 L
.55052 .12361 L
.55161 .12361 L
.55279 .12361 L
.55408 .12361 L
.55529 .12361 L
.55598 .12361 L
.55661 .12361 L
.55731 .12361 L
.55804 .12361 L
.55871 .12361 L
.55942 .12361 L
.56071 .12361 L
.5615 .12361 L
.56224 .12361 L
.5629 .12361 L
.56363 .12361 L
.56483 .12361 L
.56553 .12361 L
Mistroke
.56616 .12361 L
.56683 .12361 L
.56755 .12361 L
.56885 .12361 L
.57003 .12361 L
.57132 .12361 L
.57253 .12361 L
.57366 .12361 L
.57495 .12361 L
.5756 .12361 L
.57631 .12361 L
.57757 .12361 L
.57874 .12361 L
.57946 .12361 L
.58013 .12361 L
.5814 .12361 L
.58424 .12361 L
.5942 .12361 L
.61281 .12361 L
.65116 .12361 L
.69196 .12361 L
.73125 .12361 L
.76902 .12361 L
.80924 .12361 L
.84795 .12361 L
.88911 .12361 L
.92875 .12361 L
.96688 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool2
06Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0506Ko0_ooo`030000
oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oool0000040000003<ol00000<ol000Pco`000`0003?o001Vo`07
<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`0Eoooo000Zoooo00<0003oooooool03oooo`/0I_l<oooo00<0003oooooool09Ooo
o`030000oooooooo00Koool400002C?o000306Ko<ol0<ol000lco`000`000?ooooooo`0Uoooo00<0
003oooooool09_ooo`030000oooooooo02Woool004Ooool406Ko?Oooo`@00005<ol000<0I_lco`0c
o`003c?o00030000oooooooo07[oool004_oool506Ko??ooo`030000<ol0<ol0008co`000`1Voc?o
03?o000?<ol000<0003oooooool0N_ooo`00D?ooo`@0I_lioooo0P00008co`000`1Voc?o03?o000?
<ol000<0003oooooool0N_ooo`00E?ooo`80I_lioooo00<0000co`00I_l04C?o00030000oooooooo
07[oool005Koool306Ko=oooo`03000006Ko<ol0010co`020000Noooo`00FOooo`80I_lfoooo00<0
I_l0000co`003c?o00030000oooooooo07[oool005_oool206Ko=?ooo`0306Kooooo000000lco`00
0`000?ooooooo`1joooo001Moooo00<0I_ooooooool0<Oooo`0306Kooooo000000lco`000`000?oo
ooooo`1joooo001Noooo0P1Voc7oool0101Vooooooooo`0000hco`000`000?ooooooo`1joooo001P
oooo00<0I_ooooooool0;_ooo`0406Kooooooooo00003S?o00030000oooooooo07[oool0067oool0
0`1Vooooooooo`0]oooo00D0I_ooooooooooool000003C?o0080001koooo001Roooo00<0I_oooooo
ool0;?ooo`0506Kooooooooooooo000000dco`000`000?ooooooo`1joooo001Soooo00<0I_oooooo
ool0:oooo`0306Kooooooooo00;oool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00Hooo
o`0306Kooooooooo02_oool00`1Vooooooooo`02oooo00<0000co`0co`002S?o00030000oooooooo
07[oool006Coool00`1Vooooooooo`0Zoooo00<0I_ooooooool00oooo`030000<ol0<ol000Tco`00
0`000?ooooooo`1joooo001Uoooo00<0I_ooooooool09oooo`<0I_l5oooo00<0000co`0co`002C?o
00030000oooooooo07[oool006Koool00`1Vooooooooo`0Soooo0`1Vo`;oool00ol0VOooooooo`04
oooo00<0000co`0co`0023?o0080001koooo001Woooo00<0I_ooooooool06?ooo`X0I_l5oooo00?o
09Woooooool01?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1joooo001Xoooo00<0I_oooooo
ool03Oooo`X0I_l?oooo00?o09Woooooool01?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1j
oooo001Xoooo401VoaWoool00ol0VOooooooo`05oooo00<0000co`0co`001c?o00030000oooooooo
07[oool0097oool00ol0VOooooooo`05oooo00<0000co`0co`001c?o00030000oooooooo07[oool0
097oool00ol0VOooooooo`05oooo00<0000co`0co`001c?o00030000oooooooo07[oool0097oool0
0ol0VOooooooo`05oooo00<0000co`0co`001c?o0080001koooo002Aoooo00?o09Woooooool01_oo
o`030000<ol0<ol000Hco`000`000?ooooooo`1joooo002Aoooo00?o09Woooooool01_ooo`030000
<ol0<ol000Hco`000`000?ooooooo`1joooo002Aoooo00?o09Woooooool01_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`1joooo002Aoooo00?o09Woooooool01_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1joooo002Aoooo00?o09Woooooool01oooo`D00003<ol000<0003oooooool0N_oo
o`00TOooo`03o`2Ioooooooo00Ooool00`0003?o00000005<ol000<0003oooooool0N_ooo`00TOoo
o`03o`2Ioooooooo00Ooool00`0003?o00000005<ol00`0007[oool0097oool00ol0VOooooooo`08
oooo0P0000Dco`000`000?ooooooo`1joooo002Aoooo00?o09Woooooool02?ooo`800005<ol000<0
003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00Soool200001C?o00030000oooooooo07[oool0
097oool00ol0VOooooooo`08oooo00<0000co`0co`0013?o00030000oooooooo07[oool0097oool0
0ol0VOooooooo`08oooo00<0000co`0co`0013?o00030000oooooooo07[oool0097oool00ol0VOoo
ooooo`08oooo00<0000co`0co`0013?o0080001koooo002Aoooo00?o09Woooooool02Oooo`030000
<ol0<ol000<co`000`000?ooooooo`1joooo002Aoooo00?o09Woooooool02Oooo`030000<ol0<ol0
00<co`000`000?ooooooo`1joooo002Aoooo00?o09Woooooool02Oooo`030000<ol0<ol000<co`00
0`000?ooooooo`1joooo002Aoooo00?o09Woooooool02Oooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo002Aoooo00?o09Woooooool02Oooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo002Aoooo00?o09Woooooool02Oooo`030000<ol0<ol000<co`020000Noooo`00TOooo`03o`2I
oooooooo00Woool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00TOooo`03o`2Ioooooooo
00Woool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00[oool0
0`0003?o03?o0002<ol000<0003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00[oool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00[oool00`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00[oool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00[oool00`0003?o03?o0002<ol00P0007_oool0
097oool00ol0VOooooooo`0:oooo00<0000co`0co`000S?o00030000oooooooo07[oool0097oool0
0ol0VOooooooo`0:oooo00<0000co`0co`000S?o00030000oooooooo07[oool0097oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`000S?o00030000oooooooo07[oool0097oool00ol0VOooooooo`0:
oooo00<0000co`0co`000S?o00030000oooooooo07[oool0097oool00ol0VOooooooo`0:oooo00<0
000co`0co`000S?o00030000oooooooo07[oool0097oool00ol0VOooooooo`0:oooo00<0000co`0c
o`000S?o0080001koooo002Aoooo00?o09Woooooool02oooo`050000<ol0<ol0<ol0000007coool0
097oool00ol0VOooooooo`0;oooo00D0000co`0co`0co`000000O?ooo`00TOooo`03o`2Ioooooooo
00_oool01@0003?o03?o03?o0000001loooo002Aoooo00?o09Woooooool01oooo`D00003<ol000<0
003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00Ooool01@000?ooooooooooo`000003<ol000<0
003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00Soool010000?ooooooo`0000<co`030000N_oo
o`00TOooo`03o`2Ioooooooo00Woool00`000?ooo`000003<ol000<0003oooooool0N_ooo`00TOoo
o`03o`2Ioooooooo00Ooool00`000?ooooooo`0200000c?o00030000oooooooo07[oool0097oool0
0ol0VOooooooo`08oooo0P000003oooo0000<ol0008co`000`000?ooooooo`1joooo002Aoooo00?o
09Woooooool02oooo`050000<ol0<ol0<ol0000007coool0097oool00ol0VOooooooo`0<oooo00@0
000co`0co`00001loooo002Aoooo00?o09Woooooool03?ooo`030000<ol0<ol00080001koooo002A
oooo00?o09Woooooool03?ooo`040000<ol0<ol00000O?ooo`00TOooo`03o`2Ioooooooo00coool0
100003?o03?o000007coool0097oool00ol0VOooooooo`0<oooo00@0000co`0co`00001loooo002A
oooo00?o09Woooooool03?ooo`040000<ol0<ol00000O?ooo`00TOooo`03o`2Ioooooooo00coool0
100003?o03?o000007coool0097oool00ol0VOooooooo`0<oooo00@0000co`0co`00001loooo002A
oooo00?o09Woooooool03Oooo`040000<ol000000000Noooo`00TOooo`03o`2Ioooooooo00goool0
0`0003?o0000001loooo002Aoooo00?o09Woooooool03Oooo`030000<ol0000007coool0097oool0
0ol0VOooooooo`0=oooo00<0000co`000000O?ooo`00TOooo`03o`2Ioooooooo00goool00`0003?o
0000001loooo002Aoooo00?o09Woooooool03Oooo`030000<ol0000007coool0097oool00ol0VOoo
ooooo`0=oooo00@0000co`000000001koooo002Aoooo00?o09Woooooool03Oooo`030000<ol00000
07coool0097oool00ol0VOooooooo`0=oooo00<0000co`000000O?ooo`00TOooo`03o`2Ioooooooo
00goool00`0003?o0000001loooo002Aoooo00?o09Woooooool03Oooo`030000<ol0000007coool0
097oool00ol0VOooooooo`0=oooo00<0000co`000000O?ooo`00TOooo`03o`2Ioooooooo00goool0
100003?o0000000007_oool0097oool00ol0VOooooooo`0=oooo00<0000co`000000O?ooo`00TOoo
o`03o`2Ioooooooo00goool00`0003?o0000001loooo002Aoooo00?o09Woooooool03Oooo`030000
<ol0000007coool0097oool00ol0VOooooooo`08oooo0P0000?oool00`0003?o0000001loooo002A
oooo00?o09Woooooool01oooo`040000oooooooo00000_ooo`030000<ol0000007coool0097oool0
0ol0VOooooooo`09oooo00H0003oooooooooool0000co`030000N_ooo`00TOooo`03o`2Ioooooooo
00[oool01P000?ooooooo`0003?o000007coool0097oool00ol0VOooooooo`07oooo00@0003ooooo
ool00002oooo00<0000co`000000O?ooo`00TOooo`03o`2Ioooooooo00Soool200001?ooo`80001l
oooo002Aoooo00?o09Woooooool03_ooo`80001loooo002Aoooo00?o09Woooooool03_ooo`80001l
oooo002Aoooo00?o09Woooooool03_ooo`80001loooo002Aoooo00?o09Woooooool03_ooo`<0001k
oooo002Aoooo00?o09Woooooool03_ooo`80001loooo002Aoooo00?o09Woooooool03_ooo`80001l
oooo002Aoooo00?o09Woooooool03_ooo`80001loooo002Aoooo00?o09Woooooool03_ooo`80001l
oooo002Aoooo00?o09Woooooool03_ooo`80001loooo002Aoooo00?o09Woooooool03_ooo`<0001k
oooo002Aoooo00?o09Woooooool03_ooo`80001loooo002Aoooo00?o09Woooooool03_ooo`80001l
oooo002Aoooo00?o09Woooooool03_ooo`80001loooo002Aoooo00?o09Woooooool03_ooo`80001l
oooo002Aoooo00?o09Woooooool03_ooo`80001loooo002Aoooo00?o09Woooooool03_ooo`<0001k
oooo002Aoooo00?o09Woooooool03oooo`030000oooooooo07[oool0097oool00ol0VOooooooo`0?
oooo00<0003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00ooool00`000?ooooooo`1joooo002A
oooo00?o09Woooooool03oooo`030000oooooooo07[oool0097oool00ol0VOooooooo`0?oooo00<0
003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00ooool20000Noooo`00TOooo`03o`2Ioooooooo
00ooool00`000?ooooooo`1joooo002Aoooo00?o09Woooooool03oooo`030000oooooooo07[oool0
097oool00ol0VOooooooo`0?oooo00<0003oooooool0N_ooo`00TOooo`03o`2Ioooooooo00ooool0
0`000?ooooooo`1joooo002Aoooo00?o09Woooooool02Oooo`<00003oooo00<0003oooooool0N_oo
o`00TOooo`03o`2Ioooooooo00[oool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00TOoo
o`03o`2Ioooooooo00Ooool500000oooo`<0001joooo002Koooo00@0003oooooool00021oooo002L
oooo00<0003oool00000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00coool500000_ooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool0
0`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Soool300001?ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500005?ooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005oooo`030000oooooooo
00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05ooo
o`80000:oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49955 .12361 L
.50431 .12361 L
.5095 .12361 L
.51188 .12361 L
.51318 .12361 L
.51441 .12361 L
.51555 .12361 L
s
.51555 .12361 m
.51605 .61803 L
s
0 .4 1 r
.02381 .12383 m
.04262 .12392 L
.06244 .12406 L
.07286 .12415 L
.08255 .12425 L
.09388 .1244 L
.10458 .12456 L
.125 .12498 L
.14357 .12552 L
.16355 .12634 L
.18199 .1274 L
.20071 .1289 L
.21136 .13001 L
.22134 .13125 L
.24158 .13458 L
.26011 .13887 L
.27909 .14501 L
.28984 .14952 L
.29982 .15457 L
.32034 .16824 L
.33895 .18578 L
.34831 .19707 L
.35342 .20408 L
.3547 .20594 L
.35592 .20774 L
.35701 .20939 L
.35819 .20957 L
.35949 .20954 L
.36069 .20951 L
.36336 .20943 L
.36904 .20927 L
.37901 .20893 L
.39768 .20812 L
.41828 .20687 L
.43763 .20522 L
.45848 .20273 L
.47852 .1994 L
.48873 .19725 L
.49962 .19456 L
.50494 .19308 L
.50997 .19157 L
.51216 .19088 L
.51448 .19013 L
.51569 .18972 L
.51638 .12361 L
.51702 .12361 L
.51815 .12361 L
.51937 .12361 L
.52059 .12361 L
.52172 .12361 L
Mistroke
.52296 .12361 L
.52366 .12361 L
.52429 .12361 L
.52545 .12361 L
.5267 .12361 L
.52788 .12361 L
.52896 .12361 L
.52995 .12361 L
.531 .12361 L
.53215 .12361 L
.53323 .12361 L
.53444 .12361 L
.53559 .12361 L
.53661 .12361 L
.53773 .12361 L
.53895 .12361 L
.54007 .12361 L
.5413 .12361 L
.5426 .12361 L
.54373 .12361 L
.54478 .12361 L
.54593 .12361 L
.54716 .12361 L
.54786 .12361 L
.5485 .12361 L
.54921 .12361 L
.54996 .12361 L
.55122 .12361 L
.55194 .12361 L
.5526 .12361 L
.55384 .12361 L
.55516 .12361 L
.55638 .12361 L
.55755 .12361 L
.55875 .12361 L
.55943 .12361 L
.56008 .12361 L
.56137 .12361 L
.56204 .12361 L
.56277 .12361 L
.564 .12361 L
.56529 .12361 L
.56649 .12361 L
.56761 .12361 L
.56829 .12361 L
.56904 .12361 L
.56974 .12361 L
.57038 .12361 L
.57161 .12361 L
.5729 .12361 L
Mistroke
.57358 .12361 L
.5743 .12361 L
.5756 .12361 L
.57639 .12361 L
.57715 .12361 L
.57783 .12361 L
.57857 .12361 L
.57921 .12361 L
.5799 .12361 L
.58112 .12361 L
.58389 .12361 L
.58889 .12361 L
.59825 .12361 L
.61923 .12361 L
.65722 .12361 L
.69767 .12361 L
.7366 .12361 L
.77798 .12361 L
.81784 .12361 L
.85619 .12361 L
.89699 .12361 L
.93628 .12361 L
.97405 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool2
06Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0
I_l02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00050000<ol0<ol0<ol006Ko
00Dco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo01Goool002[oool00`000?ooooooo`0Doooo2P1Vo`Soool00`000?ooooooo`0U
oooo00<0003oooooool01_ooo`@0000;<ol000<0I_lco`0co`003C?o00030000oooooooo02Goool0
0`000?ooooooo`0Voooo00<0003oooooool0:Oooo`00Boooo`D0I_lhoooo100000Lco`000`1Voc?o
03?o000=<ol000<0003oooooool0N_ooo`00D?ooo`@0I_lhoooo00<0000co`0co`0013?o000306Ko
<ol0<ol000dco`000`000?ooooooo`1joooo001Doooo0P1VocOoool2000013?o000306Ko<ol0<ol0
00dco`000`000?ooooooo`1joooo001Foooo0`1VocKoool01@0003?o03?o03?o001Vo`0?<ol000<0
003oooooool0N_ooo`00FOooo`80I_leoooo00@0000co`0co`00I_l?<ol00P0007_oool005_oool2
06Ko=?ooo`8000000`1Voc?o03?o000=<ol000<0003oooooool0N_ooo`00GOooo`0306Kooooooooo
03?oool00`1Voc?o03?o000=<ol000<0003oooooool0N_ooo`00G_ooo`80I_lcoooo00<0I_lco`0c
o`003C?o00030000oooooooo07[oool0063oool00`1Vooooooooo`0`oooo00<0I_l0000co`003C?o
00030000oooooooo07[oool0067oool00`1Vooooooooo`0_oooo00<0I_l0000co`003C?o00030000
oooooooo07[oool006;oool00`1Vooooooooo`0^oooo00<0I_ooool000003C?o0080001koooo001S
oooo0P1Vobkoool00`1Vooooo`00000=<ol000<0003oooooool0N_ooo`00IOooo`0306Kooooooooo
02_oool0101Vooooooooo`0000`co`000`000?ooooooo`1joooo001Voooo00<0I_ooooooool0:_oo
o`0406Kooooooooo000033?o00030000oooooooo07[oool006Ooool00`1Vooooooooo`0Xoooo0P1V
o`?oool00`0003?o03?o0009<ol000<0003oooooool0N_ooo`00J?ooo`0306Kooooooooo02?oool4
06Ko00?ooooo09Woool00_ooo`030000<ol0<ol000Tco`000`000?ooooooo`1joooo001Yoooo00<0
I_ooooooool08?ooo`80I_l5oooo00?o09Woooooool00_ooo`030000<ol0<ol000Pco`020000Nooo
o`00JOooo`0306Kooooooooo01Koool:06Ko1oooo`03o`2Ioooooooo00;oool00`0003?o03?o0008
<ol000<0003oooooool0N_ooo`00J_ooo`0306Kooooooooo013oool506Ko4Oooo`03o`2Ioooooooo
00;oool00`0003?o03?o0008<ol000<0003oooooool0N_ooo`00J_oooa<0I_lFoooo00?o09Wooooo
ool00oooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo002Coooo00?o09Woooooool00ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1joooo002Coooo00?o09Woooooool00oooo`030000
<ol0<ol000Lco`000`000?ooooooo`1joooo002Coooo00?o09Woooooool00oooo`030000<ol0<ol0
00Lco`020000Noooo`00Toooo`03o`2Ioooooooo00Coool00`0003?o03?o0006<ol000<0003ooooo
ool0N_ooo`00Toooo`03o`2Ioooooooo00Coool00`0003?o03?o0006<ol000<0003oooooool0N_oo
o`00Toooo`03o`2Ioooooooo00Coool00`0003?o03?o0006<ol000<0003oooooool0N_ooo`00Tooo
o`03o`2Ioooooooo00Coool00`0003?o03?o0006<ol000<0003oooooool0N_ooo`00Toooo`03o`2I
oooooooo00Goool500000c?o00030000oooooooo07[oool009?oool00ol0VOooooooo`05oooo00<0
000co`0000001C?o00030000oooooooo07[oool009?oool00ol0VOooooooo`05oooo00<0000co`00
00001C?o00<0001joooo002Coooo00?o09Woooooool01_ooo`800005<ol000<0003oooooool0N_oo
o`00Toooo`03o`2Ioooooooo00Koool200001C?o00030000oooooooo07[oool009?oool00ol0VOoo
ooooo`06oooo0P0000Dco`000`000?ooooooo`1joooo002Coooo00?o09Woooooool01_ooo`030000
<ol0<ol000@co`000`000?ooooooo`1joooo002Coooo00?o09Woooooool01_ooo`030000<ol0<ol0
00@co`000`000?ooooooo`1joooo002Coooo00?o09Woooooool01_ooo`030000<ol0<ol000@co`02
0000Noooo`00Toooo`03o`2Ioooooooo00Ooool00`0003?o03?o0003<ol000<0003oooooool0N_oo
o`00Toooo`03o`2Ioooooooo00Ooool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Tooo
o`03o`2Ioooooooo00Ooool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Toooo`03o`2I
oooooooo00Ooool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Toooo`03o`2Ioooooooo
00Ooool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Toooo`03o`2Ioooooooo00Ooool0
0`0003?o03?o0003<ol00P0007_oool009?oool00ol0VOooooooo`07oooo00<0000co`0co`000c?o
00030000oooooooo07[oool009?oool00ol0VOooooooo`07oooo00<0000co`0co`000c?o00030000
oooooooo07[oool009?oool00ol0VOooooooo`08oooo00<0000co`0co`000S?o00030000oooooooo
07[oool009?oool00ol0VOooooooo`08oooo00<0000co`0co`000S?o00030000oooooooo07[oool0
09?oool00ol0VOooooooo`08oooo00<0000co`0co`000S?o00030000oooooooo07[oool009?oool0
0ol0VOooooooo`08oooo00<0000co`0co`000S?o00030000oooooooo07[oool009?oool00ol0VOoo
ooooo`08oooo00<0000co`0co`000S?o0080001koooo002Coooo00?o09Woooooool02?ooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo002Coooo00?o09Woooooool02?ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo002Coooo00?o09Woooooool02?ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo002Coooo00?o09Woooooool02?ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo002Coooo00?o09Woooooool02?ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo002Coooo00?o09Woooooool02?ooo`030000<ol0<ol0008co`020000Noooo`00Toooo`03o`2I
oooooooo00Woool01@0003?o03?o03?o0000001loooo002Coooo00?o09Woooooool02Oooo`050000
<ol0<ol0<ol0000007coool009?oool00ol0VOooooooo`09oooo00D0000co`0co`0co`000000O?oo
o`00Toooo`03o`2Ioooooooo00Goool500000c?o00030000oooooooo07[oool009?oool00ol0VOoo
ooooo`05oooo00D0003oooooooooool000000c?o00030000oooooooo07[oool009?oool00ol0VOoo
ooooo`06oooo00@0003oooooool00003<ol00`0007[oool009?oool00ol0VOooooooo`07oooo00<0
003oool000000c?o00030000oooooooo07[oool009?oool00ol0VOooooooo`05oooo00<0003ooooo
ool00P0000<co`000`000?ooooooo`1joooo002Coooo00?o09Woooooool01_ooo`8000000oooo`00
03?o0002<ol000<0003oooooool0N_ooo`00Toooo`03o`2Ioooooooo00Woool01@0003?o03?o03?o
0000001loooo002Coooo00?o09Woooooool02_ooo`040000<ol0<ol00000O?ooo`00Toooo`03o`2I
oooooooo00[oool00`0003?o03?o00020000Noooo`00Toooo`03o`2Ioooooooo00[oool0100003?o
03?o000007coool009?oool00ol0VOooooooo`0:oooo00@0000co`0co`00001loooo002Coooo00?o
09Woooooool02_ooo`040000<ol0<ol00000O?ooo`00Toooo`03o`2Ioooooooo00[oool0100003?o
03?o000007coool009?oool00ol0VOooooooo`0:oooo00@0000co`0co`00001loooo002Coooo00?o
09Woooooool02_ooo`040000<ol0<ol00000O?ooo`00Toooo`03o`2Ioooooooo00_oool0100003?o
0000000007_oool009?oool00ol0VOooooooo`0;oooo00<0000co`000000O?ooo`00Toooo`03o`2I
oooooooo00_oool00`0003?o0000001loooo002Coooo00?o09Woooooool02oooo`030000<ol00000
07coool009?oool00ol0VOooooooo`0;oooo00<0000co`000000O?ooo`00Toooo`03o`2Ioooooooo
00_oool00`0003?o0000001loooo002Coooo00?o09Woooooool02oooo`040000<ol000000000Nooo
o`00Toooo`03o`2Ioooooooo00_oool00`0003?o0000001loooo002Coooo00?o09Woooooool02ooo
o`030000<ol0000007coool009?oool00ol0VOooooooo`0;oooo00<0000co`000000O?ooo`00Tooo
o`03o`2Ioooooooo00_oool00`0003?o0000001loooo002Coooo00?o09Woooooool02oooo`030000
<ol0000007coool009?oool00ol0VOooooooo`0;oooo00@0000co`000000001koooo002Coooo00?o
09Woooooool02oooo`030000<ol0000007coool009?oool00ol0VOooooooo`0;oooo00<0000co`00
0000O?ooo`00Toooo`03o`2Ioooooooo00_oool00`0003?o0000001loooo002Coooo00?o09Wooooo
ool01_ooo`800003oooo00<0000co`000000O?ooo`00Toooo`03o`2Ioooooooo00Goool010000?oo
ooooo`0000;oool00`0003?o0000001loooo002Coooo00?o09Woooooool01oooo`060000oooooooo
oooo0000<ol00`0007[oool009?oool00ol0VOooooooo`08oooo00H0003oooooool0000co`00001l
oooo002Coooo00?o09Woooooool01Oooo`040000oooooooo00000_ooo`030000<ol0000007coool0
09?oool00ol0VOooooooo`06oooo0P0000Coool20000O?ooo`00Toooo`03o`2Ioooooooo00coool2
0000O?ooo`00Toooo`03o`2Ioooooooo00coool20000O?ooo`00Toooo`03o`2Ioooooooo00coool2
0000O?ooo`00Toooo`03o`2Ioooooooo00coool30000Noooo`00Toooo`03o`2Ioooooooo00coool2
0000O?ooo`00Toooo`03o`2Ioooooooo00coool20000O?ooo`00Toooo`03o`2Ioooooooo00coool2
0000O?ooo`00Toooo`03o`2Ioooooooo00coool20000O?ooo`00Toooo`03o`2Ioooooooo00coool2
0000O?ooo`00Toooo`03o`2Ioooooooo00coool30000Noooo`00Toooo`03o`2Ioooooooo00coool2
0000O?ooo`00Toooo`03o`2Ioooooooo00coool20000O?ooo`00Toooo`03o`2Ioooooooo00coool2
0000O?ooo`00Toooo`03o`2Ioooooooo00coool20000O?ooo`00Toooo`03o`2Ioooooooo00coool2
0000O?ooo`00Toooo`03o`2Ioooooooo00coool30000Noooo`00Toooo`03o`2Ioooooooo00goool0
0`000?ooooooo`1joooo002Coooo00?o09Woooooool03Oooo`030000oooooooo07[oool009?oool0
0ol0VOooooooo`0=oooo00<0003oooooool0N_ooo`00Toooo`03o`2Ioooooooo00goool00`000?oo
ooooo`1joooo002Coooo00?o09Woooooool03Oooo`030000oooooooo07[oool009?oool00ol0VOoo
ooooo`0=oooo0P0007_oool009?oool00ol0VOooooooo`0=oooo00<0003oooooool0N_ooo`00Tooo
o`03o`2Ioooooooo00goool00`000?ooooooo`1joooo002Coooo00?o09Woooooool03Oooo`030000
oooooooo07[oool009?oool00ol0VOooooooo`0=oooo00<0003oooooool0N_ooo`00Toooo`03o`2I
oooooooo00Ooool300000oooo`030000oooooooo07[oool009?oool00ol0VOooooooo`08oooo00<0
003oooooool00_ooo`030000oooooooo07[oool009?oool00ol0VOooooooo`05oooo1@0000?oool3
0000N_ooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000oooo0000087oool009goool2
0000POooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0001Coool00`000?ooooooo`08oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?oo
ooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.5095 .12361 L
.51441 .12361 L
.51896 .12361 L
.52148 .12361 L
.52221 .12361 L
.52289 .12361 L
s
.52289 .12361 m
.52341 .61803 L
s
0 .4 1 r
.02381 .1238 m
.04262 .12388 L
.06244 .124 L
.07286 .12408 L
.08255 .12417 L
.09388 .12429 L
.10458 .12443 L
.125 .1248 L
.14357 .12526 L
.16355 .12597 L
.18199 .12689 L
.20071 .12819 L
.21136 .12915 L
.22134 .13023 L
.24158 .13311 L
.26011 .13683 L
.27909 .14215 L
.28984 .14606 L
.29982 .15043 L
.32034 .16227 L
.33895 .17747 L
.3491 .18815 L
.35464 .19485 L
.35982 .20174 L
.36208 .20496 L
.36423 .20814 L
.36542 .20942 L
.36671 .20938 L
.36897 .20931 L
.37901 .20898 L
.39904 .20813 L
.41757 .20703 L
.43623 .2055 L
.45683 .20317 L
.47618 .20014 L
.49703 .19567 L
.50742 .19287 L
.51708 .18987 L
.51958 .18902 L
.52195 .1882 L
.52326 .18773 L
.52399 .12361 L
.52467 .12361 L
.52588 .12361 L
.52715 .12361 L
.52846 .12361 L
.52918 .12361 L
.52986 .12361 L
.5305 .12361 L
.53119 .12361 L
Mistroke
.5324 .12361 L
.53316 .12361 L
.53385 .12361 L
.53465 .12361 L
.5354 .12361 L
.53609 .12361 L
.53673 .12361 L
.53743 .12361 L
.53817 .12361 L
.5394 .12361 L
.54009 .12361 L
.54073 .12361 L
.5419 .12361 L
.54315 .12361 L
.54426 .12361 L
.5453 .12361 L
.54645 .12361 L
.54768 .12361 L
.54892 .12361 L
.54962 .12361 L
.55027 .12361 L
.55158 .12361 L
.55232 .12361 L
.55299 .12361 L
.55419 .12361 L
.55549 .12361 L
.55672 .12361 L
.55785 .12361 L
.55891 .12361 L
.56005 .12361 L
.56112 .12361 L
.5621 .12361 L
.56325 .12361 L
.5645 .12361 L
.56677 .12361 L
.5679 .12361 L
.56914 .12361 L
.57044 .12361 L
.57167 .12361 L
.5728 .12361 L
.57385 .12361 L
.57499 .12361 L
.5762 .12361 L
.57743 .12361 L
.57812 .12361 L
.57876 .12361 L
.57994 .12361 L
.58119 .12361 L
.58573 .12361 L
.59592 .12361 L
Mistroke
.61427 .12361 L
.65213 .12361 L
.69244 .12361 L
.73123 .12361 L
.77247 .12361 L
.8122 .12361 L
.85041 .12361 L
.89108 .12361 L
.93023 .12361 L
.97183 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Goool2
06Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0
I_l02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000<co`00
1@1Voc?o03?o03?o00000009<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo01Goool002[oool00`000?ooooooo`0Doooo2P1Vo`Soool00`000?ooooooo`0U
oooo00<0003oooooool01_ooo`@0000=<ol000<0I_lco`0co`002c?o00030000oooooooo02Goool0
0`000?ooooooo`0Voooo00<0003oooooool0:Oooo`00Boooo`D0I_lhoooo100000Tco`000`1Voc?o
03?o000;<ol000<0003oooooool0N_ooo`00D?ooo`D0I_lgoooo00<0000co`0co`001S?o000306Ko
<ol0<ol000/co`000`000?ooooooo`1joooo001Eoooo101VocCoool200001S?o000306Ko<ol0<ol0
00/co`000`000?ooooooo`1joooo001Ioooo0P1VocCoool00`0003?o03?o0003<ol000<0I_lco`0c
o`002c?o00030000oooooooo07[oool005_oool206Ko<oooo`030000<ol0<ol0008co`000`1Voc?o
03?o000;<ol00P0007_oool005goool206Ko<_ooo`800002<ol000<0I_lco`0co`002c?o00030000
oooooooo07[oool005ooool206Ko<_ooo`030000<ol006Ko00dco`000`000?ooooooo`1joooo001Q
oooo00<0I_ooooooool0;oooo`030000<ol006Ko00dco`000`000?ooooooo`1joooo001Roooo00<0
I_ooooooool0;oooo`03000006Ko<ol000`co`000`000?ooooooo`1joooo001Soooo0P1Vobooool0
0`00001Voc?o000<<ol000<0003oooooool0N_ooo`00IOooo`0306Kooooooooo02goool00`1Voc?o
03?o000;<ol00P0007_oool006Koool00`1Vooooooooo`0/oooo00<0I_lco`0co`002c?o00030000
oooooooo07[oool006Ooool00`1Vooooooooo`0[oooo00<0I_l0000co`002c?o00030000oooooooo
07[oool006Soool00`1Vooooooooo`0Zoooo00<0I_l0000co`002c?o00030000oooooooo07[oool0
06Woool00`1Vooooooooo`0Woooo0`1Vo`03oooo0000<ol000Xco`000`000?ooooooo`1joooo001Z
oooo00<0I_ooooooool08oooo`<0I_l2oooo00?o09Woool000002c?o00030000oooooooo07[oool0
06[oool00`1Vooooooooo`0Ooooo101Vo`Goool01?l0VOooooooo`0000Xco`020000Noooo`00Jooo
o`0306Kooooooooo01Woool506Ko2Oooo`04o`2Ioooooooo00002S?o00030000oooooooo07[oool0
06coool00`1Vooooooooo`0>oooo2P1Vo`koool01?l0VOooooooo`0000Xco`000`000?ooooooo`1j
oooo001]oooo401VoaSoool01Ol0VOooooooooooo`000009<ol000<0003oooooool0N_ooo`00UOoo
o`05o`2Ioooooooooooo000000Tco`000`000?ooooooo`1joooo002Eoooo00Go09Woooooooooool0
00002C?o00030000oooooooo07[oool009Goool01Ol0VOooooooooooo`000009<ol00P0007_oool0
09Goool00ol0VOooooooo`02oooo00<0000co`0co`001S?o00030000oooooooo07[oool009Goool0
0ol0VOooooooo`02oooo00<0000co`0co`001S?o00030000oooooooo07[oool009Goool00ol0VOoo
ooooo`02oooo00<0000co`0co`001S?o00030000oooooooo07[oool009Goool00ol0VOooooooo`02
oooo00<0000co`0co`001S?o00030000oooooooo07[oool009Goool00ol0VOooooooo`03oooo1@00
00<co`000`000?ooooooo`1joooo002Eoooo00?o09Woooooool00oooo`030000<ol0000000Dco`00
0`000?ooooooo`1joooo002Eoooo00?o09Woooooool00oooo`030000<ol0000000Dco`030000N_oo
o`00UOooo`03o`2Ioooooooo00Coool200001C?o00030000oooooooo07[oool009Goool00ol0VOoo
ooooo`04oooo0P0000Dco`000`000?ooooooo`1joooo002Eoooo00?o09Woooooool01?ooo`800005
<ol000<0003oooooool0N_ooo`00UOooo`03o`2Ioooooooo00Coool00`0003?o03?o0004<ol000<0
003oooooool0N_ooo`00UOooo`03o`2Ioooooooo00Coool00`0003?o03?o0004<ol000<0003ooooo
ool0N_ooo`00UOooo`03o`2Ioooooooo00Coool00`0003?o03?o0004<ol00P0007_oool009Goool0
0ol0VOooooooo`05oooo00<0000co`0co`000c?o00030000oooooooo07[oool009Goool00ol0VOoo
ooooo`05oooo00<0000co`0co`000c?o00030000oooooooo07[oool009Goool00ol0VOooooooo`05
oooo00<0000co`0co`000c?o00030000oooooooo07[oool009Goool00ol0VOooooooo`05oooo00<0
000co`0co`000c?o00030000oooooooo07[oool009Goool00ol0VOooooooo`05oooo00<0000co`0c
o`000c?o00030000oooooooo07[oool009Goool00ol0VOooooooo`05oooo00<0000co`0co`000c?o
0080001koooo002Eoooo00?o09Woooooool01Oooo`030000<ol0<ol000<co`000`000?ooooooo`1j
oooo002Eoooo00?o09Woooooool01Oooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo002E
oooo00?o09Woooooool01_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo002Eoooo00?o
09Woooooool01_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo002Eoooo00?o09Wooooo
ool01_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo002Eoooo00?o09Woooooool01_oo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo002Eoooo00?o09Woooooool01_ooo`030000
<ol0<ol0008co`020000Noooo`00UOooo`03o`2Ioooooooo00Koool00`0003?o03?o0002<ol000<0
003oooooool0N_ooo`00UOooo`03o`2Ioooooooo00Koool00`0003?o03?o0002<ol000<0003ooooo
ool0N_ooo`00UOooo`03o`2Ioooooooo00Koool00`0003?o03?o0002<ol000<0003oooooool0N_oo
o`00UOooo`03o`2Ioooooooo00Koool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00UOoo
o`03o`2Ioooooooo00Koool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00UOooo`03o`2I
oooooooo00Koool00`0003?o03?o0002<ol00P0007_oool009Goool00ol0VOooooooo`07oooo00D0
000co`0co`0co`000000O?ooo`00UOooo`03o`2Ioooooooo00Ooool01@0003?o03?o03?o0000001l
oooo002Eoooo00?o09Woooooool01oooo`050000<ol0<ol0<ol0000007coool009Goool00ol0VOoo
ooooo`03oooo1@0000<co`000`000?ooooooo`1joooo002Eoooo00?o09Woooooool00oooo`050000
oooooooooooo000000<co`000`000?ooooooo`1joooo002Eoooo00?o09Woooooool01?ooo`040000
oooooooo00000c?o00<0001joooo002Eoooo00?o09Woooooool01Oooo`030000oooo000000<co`00
0`000?ooooooo`1joooo002Eoooo00?o09Woooooool00oooo`030000oooooooo00800003<ol000<0
003oooooool0N_ooo`00UOooo`03o`2Ioooooooo00Coool2000000?oool0000co`000S?o00030000
oooooooo07[oool009Goool00ol0VOooooooo`07oooo00D0000co`0co`0co`000000O?ooo`00UOoo
o`03o`2Ioooooooo00Soool0100003?o03?o000007coool009Goool00ol0VOooooooo`08oooo00<0
000co`0co`000P0007_oool009Goool00ol0VOooooooo`08oooo00@0000co`0co`00001loooo002E
oooo00?o09Woooooool02?ooo`040000<ol0<ol00000O?ooo`00UOooo`03o`2Ioooooooo00Soool0
100003?o03?o000007coool009Goool00ol0VOooooooo`08oooo00@0000co`0co`00001loooo002E
oooo00?o09Woooooool02?ooo`040000<ol0<ol00000O?ooo`00UOooo`03o`2Ioooooooo00Soool0
100003?o03?o000007coool009Goool00ol0VOooooooo`09oooo00@0000co`000000001koooo002E
oooo00?o09Woooooool02Oooo`030000<ol0000007coool009Goool00ol0VOooooooo`09oooo00<0
000co`000000O?ooo`00UOooo`03o`2Ioooooooo00Woool00`0003?o0000001loooo002Eoooo00?o
09Woooooool02Oooo`030000<ol0000007coool009Goool00ol0VOooooooo`09oooo00<0000co`00
0000O?ooo`00UOooo`03o`2Ioooooooo00Woool0100003?o0000000007_oool009Goool00ol0VOoo
ooooo`09oooo00<0000co`000000O?ooo`00UOooo`03o`2Ioooooooo00Woool00`0003?o0000001l
oooo002Eoooo00?o09Woooooool02Oooo`030000<ol0000007coool009Goool00ol0VOooooooo`09
oooo00<0000co`000000O?ooo`00UOooo`03o`2Ioooooooo00Woool00`0003?o0000001loooo002E
oooo00?o09Woooooool02Oooo`040000<ol000000000Noooo`00UOooo`03o`2Ioooooooo00Woool0
0`0003?o0000001loooo002Eoooo00?o09Woooooool02Oooo`030000<ol0000007coool009Goool0
0ol0VOooooooo`09oooo00<0000co`000000O?ooo`00UOooo`03o`2Ioooooooo00Coool200000ooo
o`030000<ol0000007coool009Goool00ol0VOooooooo`03oooo00@0003oooooool00002oooo00<0
000co`000000O?ooo`00UOooo`03o`2Ioooooooo00Goool01P000?ooooooooooo`0003?o00<0001j
oooo002Eoooo00?o09Woooooool01_ooo`060000oooooooo0000<ol00000O?ooo`00UOooo`03o`2I
oooooooo00?oool010000?ooooooo`0000;oool00`0003?o0000001loooo002Eoooo00?o09Wooooo
ool01?ooo`800004oooo0P0007coool009Goool00ol0VOooooooo`0:oooo0P0007coool009Goool0
0ol0VOooooooo`0:oooo0P0007coool009Goool00ol0VOooooooo`0:oooo0P0007coool009Goool0
0ol0VOooooooo`0:oooo0`0007_oool009Goool00ol0VOooooooo`0:oooo0P0007coool009Goool0
0ol0VOooooooo`0:oooo0P0007coool009Goool00ol0VOooooooo`0:oooo0P0007coool009Goool0
0ol0VOooooooo`0:oooo0P0007coool009Goool00ol0VOooooooo`0:oooo0P0007coool009Goool0
0ol0VOooooooo`0:oooo0`0007_oool009Goool00ol0VOooooooo`0:oooo0P0007coool009Goool0
0ol0VOooooooo`0:oooo0P0007coool009Goool00ol0VOooooooo`0:oooo0P0007coool009Goool0
0ol0VOooooooo`0:oooo0P0007coool009Goool00ol0VOooooooo`0:oooo0P0007coool009Goool0
0ol0VOooooooo`0:oooo0`0007_oool009Goool00ol0VOooooooo`0;oooo00<0003oooooool0N_oo
o`00UOooo`03o`2Ioooooooo00_oool00`000?ooooooo`1joooo002Eoooo00?o09Woooooool02ooo
o`030000oooooooo07[oool009Goool00ol0VOooooooo`0;oooo00<0003oooooool0N_ooo`00UOoo
o`03o`2Ioooooooo00_oool00`000?ooooooo`1joooo002Eoooo00?o09Woooooool02oooo`80001k
oooo002Eoooo00?o09Woooooool02oooo`030000oooooooo07[oool009Goool00ol0VOooooooo`0;
oooo00<0003oooooool0N_ooo`00UOooo`03o`2Ioooooooo00_oool00`000?ooooooo`1joooo002E
oooo00?o09Woooooool02oooo`030000oooooooo07[oool009Goool00ol0VOooooooo`05oooo0`00
00?oool00`000?ooooooo`1joooo002Eoooo00?o09Woooooool01_ooo`030000oooooooo00;oool0
0`000?ooooooo`1joooo002Eoooo00?o09Woooooool00oooo`D00003oooo0`0007[oool009_oool0
10000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQ
oooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000Goool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02Oooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?oo
ooooo`09oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00005?ooo`030000oooooooo00[oool01@000?ooooooooooo`00001joooo001hoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool05oooo`800009oooo100000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.51896 .12361 L
.52455 .12361 L
.52731 .12361 L
.52865 .12361 L
.52986 .12361 L
.53105 .12361 L
s
.53105 .12361 m
.5315 .61803 L
s
0 .4 1 r
.02381 .12378 m
.04262 .12384 L
.06244 .12394 L
.07286 .12401 L
.08255 .12409 L
.09388 .1242 L
.10458 .12432 L
.125 .12464 L
.14357 .12504 L
.16355 .12565 L
.18199 .12645 L
.20071 .12758 L
.21136 .12841 L
.22134 .12934 L
.24158 .13183 L
.26011 .13505 L
.27909 .13966 L
.28984 .14305 L
.29982 .14683 L
.32034 .15708 L
.33895 .17025 L
.35982 .19125 L
.36897 .20324 L
.37148 .20688 L
.3722 .20796 L
.37288 .20899 L
.37416 .20916 L
.37537 .20912 L
.37649 .20908 L
.37901 .20899 L
.39776 .20821 L
.41757 .20705 L
.43623 .20553 L
.45683 .20321 L
.47618 .2002 L
.49703 .19576 L
.51708 .19 L
.52195 .18834 L
.52715 .18645 L
.52869 .18586 L
.53014 .1853 L
.53145 .18479 L
.53218 .12361 L
.53286 .12361 L
.53409 .12361 L
.53479 .12361 L
.53544 .12361 L
.53676 .12361 L
.5375 .12361 L
.53817 .12361 L
Mistroke
.53947 .12361 L
.54068 .12361 L
.54178 .12361 L
.54296 .12361 L
.54425 .12361 L
.5449 .12361 L
.54561 .12361 L
.54687 .12361 L
.54805 .12361 L
.54914 .12361 L
.5503 .12361 L
.55157 .12361 L
.55275 .12361 L
.55384 .12361 L
.55486 .12361 L
.55599 .12361 L
.5572 .12361 L
.55784 .12361 L
.55853 .12361 L
.55926 .12361 L
.55993 .12361 L
.56115 .12361 L
.56244 .12361 L
.56373 .12361 L
.56494 .12361 L
.56602 .12361 L
.56721 .12361 L
.56852 .12361 L
.56923 .12361 L
.56989 .12361 L
.57108 .12361 L
.57236 .12361 L
.57308 .12361 L
.57386 .12361 L
.57459 .12361 L
.57528 .12361 L
.57657 .12361 L
.57722 .12361 L
.57794 .12361 L
.57918 .12361 L
.58035 .12361 L
.58142 .12361 L
.58256 .12361 L
.58755 .12361 L
.59658 .12361 L
.61717 .12361 L
.65863 .12361 L
.69858 .12361 L
.73702 .12361 L
.77791 .12361 L
Mistroke
.81728 .12361 L
.85513 .12361 L
.89544 .12361 L
.93423 .12361 L
.97547 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooo`1Vo`0706Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`04
06Ko1?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Dco`00
0`1Voc?o00000009<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool002[oool00`000?ooooooo`0Hoooo2`1Vo`?oool00`000?ooooooo`0Uoooo00<0
003oooooool01_ooo`@0000?<ol000<0I_lco`0co`002C?o00030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0003oooooool0:Oooo`00D?ooo`D0I_lcoooo100000/co`000`1Voc?o03?o0009
<ol000<0003oooooool0N_ooo`00EOooo`@0I_lcoooo00<0000co`0co`0023?o000306Ko<ol0<ol0
00Tco`000`000?ooooooo`1joooo001Ioooo0P1Voc;oool2000023?o000306Ko<ol0<ol000Tco`00
0`000?ooooooo`1joooo001Koooo0P1Voc;oool00`0003?o03?o0005<ol000<0I_lco`0co`002C?o
00030000oooooooo07[oool005goool206Ko<Oooo`030000<ol0<ol000@co`000`1Voc?o03?o0009
<ol00P0007_oool005ooool206Ko<?ooo`800004<ol000<0I_lco`0co`002C?o00030000oooooooo
07[oool0067oool00`1Vooooooooo`0_oooo00D0000co`0co`0co`00I_l02c?o00030000oooooooo
07[oool006;oool206Ko;oooo`050000<ol0<ol0<ol006Ko00/co`000`000?ooooooo`1joooo001T
oooo0P1Vobkoool0100003?o03?o001Vo`/co`000`000?ooooooo`1joooo001Voooo00<0I_oooooo
ool0:oooo`040000<ol0<ol006Ko2c?o00030000oooooooo07[oool006Ooool00`1Vooooooooo`0[
oooo00<0000co`00I_l02c?o0080001koooo001Xoooo00<0I_ooooooool0:_ooo`030000<ol006Ko
00/co`000`000?ooooooo`1joooo001Xoooo00<0I_ooooooool0:oooo`03000006Ko<ol000Xco`00
0`000?ooooooo`1joooo001Yoooo00<0I_ooooooool0:_ooo`80I_l;<ol000<0003oooooool0N_oo
o`00J_ooo`0306Kooooooooo02Goool406Ko00?ooooo09Tco`002S?o00030000oooooooo07[oool0
06_oool00`1Vooooooooo`0Roooo0P1Vo`Goool00ol0VC?o03?o0009<ol000<0003oooooool0N_oo
o`00K?ooo`0306Kooooooooo01goool406Ko1oooo`03o`2I0000<ol000Tco`020000Noooo`00KOoo
o`0306Kooooooooo01Ooool506Ko2oooo`03o`2I0000<ol000Tco`000`000?ooooooo`1joooo001^
oooo00<0I_ooooooool03?ooo`X0I_l@oooo00?o09T0000co`002C?o00030000oooooooo07[oool0
06koool?06Ko6_ooo`03o`2Ioooo000000Tco`000`000?ooooooo`1joooo002Goooo00?o09Woool0
00002C?o00030000oooooooo07[oool009Ooool00ol0VOooo`000009<ol000<0003oooooool0N_oo
o`00Uoooo`03o`2Ioooo000000Tco`020000Noooo`00Uoooo`04o`2Ioooooooo000023?o00030000
oooooooo07[oool009Ooool01?l0VOooooooo`0000Pco`000`000?ooooooo`1joooo002Goooo00Co
09Woooooool00008<ol000<0003oooooool0N_ooo`00Uoooo`04o`2Ioooooooo000023?o00030000
oooooooo07[oool009Ooool01?l0VOooooooooooo`D00003<ol000<0003oooooool0N_ooo`00Uooo
o`07o`2Ioooooooooooo0000<ol0000000Dco`000`000?ooooooo`1joooo002Goooo00Oo09Wooooo
ooooool0000co`0000001C?o00<0001joooo002Goooo00?o09Woooooool00_ooo`800005<ol000<0
003oooooool0N_ooo`00Uoooo`03o`2Ioooooooo00;oool200001C?o00030000oooooooo07[oool0
09Ooool00ol0VOooooooo`02oooo0P0000Dco`000`000?ooooooo`1joooo002Goooo00?o09Wooooo
ool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`1joooo002Goooo00?o09Woooooool00_oo
o`030000<ol0<ol000@co`000`000?ooooooo`1joooo002Goooo00?o09Woooooool00_ooo`030000
<ol0<ol000@co`020000Noooo`00Uoooo`03o`2Ioooooooo00?oool00`0003?o03?o0003<ol000<0
003oooooool0N_ooo`00Uoooo`03o`2Ioooooooo00?oool00`0003?o03?o0003<ol000<0003ooooo
ool0N_ooo`00Uoooo`03o`2Ioooooooo00?oool00`0003?o03?o0003<ol000<0003oooooool0N_oo
o`00Uoooo`03o`2Ioooooooo00?oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Uooo
o`03o`2Ioooooooo00?oool00`0003?o03?o0003<ol000<0003oooooool0N_ooo`00Uoooo`03o`2I
oooooooo00?oool00`0003?o03?o0003<ol00P0007_oool009Ooool00ol0VOooooooo`03oooo00<0
000co`0co`000c?o00030000oooooooo07[oool009Ooool00ol0VOooooooo`03oooo00<0000co`0c
o`000c?o00030000oooooooo07[oool009Ooool00ol0VOooooooo`04oooo00<0000co`0co`000S?o
00030000oooooooo07[oool009Ooool00ol0VOooooooo`04oooo00<0000co`0co`000S?o00030000
oooooooo07[oool009Ooool00ol0VOooooooo`04oooo00<0000co`0co`000S?o00030000oooooooo
07[oool009Ooool00ol0VOooooooo`04oooo00<0000co`0co`000S?o00030000oooooooo07[oool0
09Ooool00ol0VOooooooo`04oooo00<0000co`0co`000S?o0080001koooo002Goooo00?o09Wooooo
ool01?ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo002Goooo00?o09Woooooool01?oo
o`030000<ol0<ol0008co`000`000?ooooooo`1joooo002Goooo00?o09Woooooool01?ooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo002Goooo00?o09Woooooool01?ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo002Goooo00?o09Woooooool01?ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo002Goooo00?o09Woooooool01?ooo`030000<ol0<ol0008co`020000Nooo
o`00Uoooo`03o`2Ioooooooo00Goool01@0003?o03?o03?o0000001loooo002Goooo00?o09Wooooo
ool01Oooo`050000<ol0<ol0<ol0000007coool009Ooool00ol0VOooooooo`05oooo00D0000co`0c
o`0co`000000O?ooo`00Uoooo`04o`2Ioooooooooooo1@0000<co`000`000?ooooooo`1joooo002G
oooo00Go09Woooooooooool000000oooo`050000<ol0<ol0<ol0000007coool009Ooool00ol0VOoo
ooooo`02oooo00@0003oooooool00003<ol00`0007[oool009Ooool00ol0VOooooooo`03oooo00<0
003oool000000c?o00030000oooooooo07[oool009Ooool01Ol0VOooooooooooo`000002oooo0P00
00<co`000`000?ooooooo`1joooo002Goooo00?o09Woooooool00_ooo`8000000oooo`0003?o0002
<ol000<0003oooooool0N_ooo`00Uoooo`03o`2Ioooooooo00Goool01@0003?o03?o03?o0000001l
oooo002Goooo00?o09Woooooool01_ooo`040000<ol0<ol00000O?ooo`00Uoooo`03o`2Ioooooooo
00Koool00`0003?o03?o00020000Noooo`00Uoooo`03o`2Ioooooooo00Koool0100003?o03?o0000
07coool009Ooool00ol0VOooooooo`06oooo00@0000co`0co`00001loooo002Goooo00?o09Wooooo
ool01_ooo`040000<ol0<ol00000O?ooo`00Uoooo`03o`2Ioooooooo00Koool0100003?o03?o0000
07coool009Ooool00ol0VOooooooo`06oooo00@0000co`0co`00001loooo002Goooo00?o09Wooooo
ool01_ooo`040000<ol0<ol00000O?ooo`00Uoooo`03o`2Ioooooooo00Ooool0100003?o00000000
07_oool009Ooool00ol0VOooooooo`07oooo00<0000co`000000O?ooo`00Uoooo`03o`2Ioooooooo
00Ooool00`0003?o0000001loooo002Goooo00?o09Woooooool01oooo`030000<ol0000007coool0
09Ooool00ol0VOooooooo`07oooo00<0000co`000000O?ooo`00Uoooo`03o`2Ioooooooo00Ooool0
0`0003?o0000001loooo002Goooo00?o09Woooooool01oooo`040000<ol000000000Noooo`00Uooo
o`03o`2Ioooooooo00Ooool00`0003?o0000001loooo002Goooo00?o09Woooooool01oooo`030000
<ol0000007coool009Ooool00ol0VOooooooo`07oooo00<0000co`000000O?ooo`00Uoooo`03o`2I
oooooooo00Ooool00`0003?o0000001loooo002Goooo00?o09Woooooool01oooo`030000<ol00000
07coool009Ooool00ol0VOooooooo`07oooo00@0000co`000000001koooo002Goooo00?o09Wooooo
ool01oooo`030000<ol0000007coool009Ooool00ol0VOooooooo`07oooo00<0000co`000000O?oo
o`00Uoooo`03o`2Ioooooooo00Ooool00`0003?o0000001loooo002Goooo00?o09Woooooool00_oo
o`800003oooo00<0000co`000000O?ooo`00Uoooo`05o`2Ioooooooooooo000000;oool01P000?oo
ooooo`0003?o000007coool009Ooool00ol0VOooooooo`03oooo00H0003oooooooooool0000co`03
0000N_ooo`00Uoooo`03o`2Ioooooooo00Coool01P000?ooooooo`0003?o000007coool009Ooool0
1Ol0VOooooooooooo`000002oooo00H0003oooooool0000co`00001loooo002Goooo00?o09Wooooo
ool00_ooo`800004oooo0P0007coool009Ooool00ol0VOooooooo`08oooo0P0007coool009Ooool0
0ol0VOooooooo`08oooo0P0007coool009Ooool00ol0VOooooooo`08oooo0P0007coool009Ooool0
0ol0VOooooooo`08oooo0`0007_oool009Ooool00ol0VOooooooo`08oooo0P0007coool009Ooool0
0ol0VOooooooo`08oooo0P0007coool009Ooool00ol0VOooooooo`08oooo0P0007coool009Ooool0
0ol0VOooooooo`08oooo0P0007coool009Ooool00ol0VOooooooo`08oooo0P0007coool009Ooool0
0ol0VOooooooo`08oooo0`0007_oool009Ooool00ol0VOooooooo`08oooo0P0007coool009Ooool0
0ol0VOooooooo`08oooo0P0007coool009Ooool00ol0VOooooooo`08oooo0P0007coool009Ooool0
0ol0VOooooooo`08oooo0P0007coool009Ooool00ol0VOooooooo`08oooo0P0007coool009Ooool0
0ol0VOooooooo`08oooo0`0007_oool009Ooool00ol0VOooooooo`09oooo00<0003oooooool0N_oo
o`00Uoooo`03o`2Ioooooooo00Woool00`000?ooooooo`1joooo002Goooo00?o09Woooooool02Ooo
o`030000oooooooo07[oool009Ooool00ol0VOooooooo`09oooo00<0003oooooool0N_ooo`00Uooo
o`03o`2Ioooooooo00Woool00`000?ooooooo`1joooo002Goooo00?o09Woooooool02Oooo`80001k
oooo002Goooo00?o09Woooooool02Oooo`030000oooooooo07[oool009Ooool00ol0VOooooooo`09
oooo00<0003oooooool0N_ooo`00Uoooo`03o`2Ioooooooo00Woool00`000?ooooooo`1joooo002G
oooo00?o09Woooooool02Oooo`030000oooooooo07[oool009Ooool00ol0VOooooooo`03oooo0`00
00?oool00`000?ooooooo`1joooo002Goooo00?o09Woooooool01?ooo`030000oooooooo00;oool0
0`000?ooooooo`1joooo002Goooo00Co09Woooooooooool500000oooo`<0001joooo002Koooo00@0
003oooooool00021oooo002Loooo00<0003oool00000POooo`00WOooo`800021oooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00coool500000_ooo`800003oooo0`0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?oo
o`030000oooooooo00Ooool300001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Goooo00<0003oooooool02?ooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool05oooo`80000:oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.51896 .12361 L
.52455 .12361 L
.52986 .12361 L
.53463 .12361 L
.53594 .12361 L
.53733 .12361 L
.53865 .12361 L
s
.53865 .12361 m
.53912 .61803 L
s
0 .4 1 r
.02381 .12375 m
.04262 .12381 L
.06244 .1239 L
.07286 .12396 L
.08255 .12403 L
.09388 .12412 L
.10458 .12423 L
.125 .1245 L
.14357 .12485 L
.16355 .12538 L
.18199 .12607 L
.20071 .12704 L
.21136 .12776 L
.22134 .12857 L
.24158 .13072 L
.26011 .13351 L
.27909 .13749 L
.28984 .14042 L
.29982 .1437 L
.32034 .15256 L
.33895 .16395 L
.35819 .18046 L
.36904 .19258 L
.37385 .19876 L
.3765 .20239 L
.37901 .206 L
.3802 .20775 L
.38145 .20887 L
.38211 .20885 L
.38283 .20882 L
.38411 .20877 L
.38875 .20858 L
.39784 .20816 L
.4185 .20692 L
.43785 .20529 L
.4587 .20284 L
.47875 .19955 L
.49984 .19479 L
.51959 .18878 L
.5284 .18553 L
.53304 .18367 L
.53558 .1826 L
.53795 .18157 L
.53921 .18101 L
.53992 .12361 L
.54056 .12361 L
.54126 .12361 L
.54203 .12361 L
.54276 .12361 L
.54343 .12361 L
Mistroke
.54471 .12361 L
.54587 .12361 L
.54652 .12361 L
.54721 .12361 L
.54848 .12361 L
.54968 .12361 L
.551 .12361 L
.55166 .12361 L
.55237 .12361 L
.55365 .12361 L
.55493 .12361 L
.55614 .12361 L
.55723 .12361 L
.55841 .12361 L
.55956 .12361 L
.56064 .12361 L
.56182 .12361 L
.5631 .12361 L
.56436 .12361 L
.565 .12361 L
.56569 .12361 L
.56693 .12361 L
.56807 .12361 L
.56924 .12361 L
.57034 .12361 L
.57239 .12361 L
.57354 .12361 L
.5746 .12361 L
.57575 .12361 L
.577 .12361 L
.57826 .12361 L
.57945 .12361 L
.58061 .12361 L
.58169 .12361 L
.58672 .12361 L
.5958 .12361 L
.61645 .12361 L
.65569 .12361 L
.69341 .12361 L
.73358 .12361 L
.77223 .12361 L
.81334 .12361 L
.85293 .12361 L
.89101 .12361 L
.93154 .12361 L
.97055 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
10000?ooooooooooo`H0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko
00H0I_l2oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`00:_ooo`030000oooooooo01[oool906Ko0oooo`030000oooooooo02Goool0
0`000?ooooooo`06oooo1000014co`000`1Voc?o03?o0007<ol000<0003oooooool09Oooo`030000
oooooooo02Koool00`000?ooooooo`0Yoooo001@oooo1@1Voc?oool400003C?o000306Ko<ol0<ol0
00Lco`000`000?ooooooo`1joooo001Eoooo101Voc?oool00`0003?o03?o000:<ol000<0I_lco`0c
o`001c?o00030000oooooooo07[oool005Woool406Ko<?ooo`80000:<ol000<0I_lco`0co`001c?o
00030000oooooooo07[oool005goool206Ko<?ooo`030000<ol0<ol000Lco`000`1Voc?o03?o0007
<ol000<0003oooooool0N_ooo`00Goooo`80I_l_oooo00<0000co`0co`001S?o000306Ko<ol0<ol0
00Lco`020000Noooo`00HOooo`0306Kooooooooo02goool200001S?o000306Ko<ol0<ol000Lco`00
0`000?ooooooo`1joooo001Roooo0P1Vobooool00`0003?o03?o0003<ol000<0I_lco`0co`001c?o
00030000oooooooo07[oool006Coool206Ko;Oooo`030000<ol0<ol000<co`000`1Voc?o03?o0007
<ol000<0003oooooool0N_ooo`00I_ooo`0306Kooooooooo02_oool00`0003?o03?o0002<ol000<0
I_lco`0co`001c?o00030000oooooooo07[oool006Ooool00`1Vooooooooo`0Zoooo00<0000co`0c
o`000S?o000306Ko<ol0<ol000Lco`000`000?ooooooo`1joooo001Xoooo0P1Vob_oool01@0003?o
03?o03?o001Vo`09<ol00P0007_oool006[oool00`1Vooooooooo`0Xoooo00D0000co`0co`0co`00
I_l02C?o00030000oooooooo07[oool006_oool00`1Vooooooooo`0Xoooo00@0000co`00I_l0I_l9
<ol000<0003oooooool0N_ooo`00K?ooo`0306Kooooooooo02Ooool206Ko00<co`3o09Tco`0023?o
00030000oooooooo07[oool006goool00`1Vooooooooo`0Roooo101Vo`04oooo0000<ol0o`2I2C?o
00030000oooooooo07[oool006koool00`1Vooooooooo`0Moooo101Vo`Goool00`0003?o0?l0V@09
<ol000<0003oooooool0N_ooo`00Koooo`0306Kooooooooo01[oool206Ko2_ooo`030000o`2I<ol0
00Pco`020000Noooo`00L?ooo`0306Kooooooooo00ooool:06Ko3?ooo`030000o`2I<ol000Pco`00
0`000?ooooooo`1joooo001`oooo00<0I_ooooooool02_ooo`D0I_lFoooo00<0003o09Tco`0023?o
00030000oooooooo07[oool0077oool<06Ko7?ooo`03o`2I<ol0<ol000Lco`000`000?ooooooo`1j
oooo002Ioooo00?o09Tco`0co`001c?o00030000oooooooo07[oool009Woool00ol0VC?o03?o0007
<ol000<0003oooooool0N_ooo`00VOooo`03o`2I<ol0<ol000Lco`020000Noooo`00VOooo`03o`2I
0000<ol000Lco`000`000?ooooooo`1joooo002Ioooo00?o09T0000co`001c?o00030000oooooooo
07[oool009Woool00ol0V@0003?o0007<ol000<0003oooooool0N_ooo`00VOooo`03o`2I0000<ol0
00Lco`000`000?ooooooo`1joooo002Ioooo00?o09Woool00000100000<co`000`000?ooooooo`1j
oooo002Ioooo00Go09Woool0000co`0000001C?o00030000oooooooo07[oool009Woool01Ol0VOoo
o`0003?o00000005<ol00`0007[oool009Woool00ol0VOooooooo`0200001C?o00030000oooooooo
07[oool009Woool00ol0VOooooooo`0200001C?o00030000oooooooo07[oool009Woool00ol0VOoo
ooooo`0200001C?o00030000oooooooo07[oool009Woool01?l0VOooooooo`0000Hco`000`000?oo
ooooo`1joooo002Ioooo00Co09Woooooool00006<ol000<0003oooooool0N_ooo`00VOooo`04o`2I
oooooooo00001S?o0080001koooo002Ioooo00Go09Woooooooooool000001C?o00030000oooooooo
07[oool009Woool01Ol0VOooooooooooo`000005<ol000<0003oooooool0N_ooo`00VOooo`05o`2I
oooooooooooo000000Dco`000`000?ooooooo`1joooo002Ioooo00Go09Woooooooooool000001C?o
00030000oooooooo07[oool009Woool01Ol0VOooooooooooo`000005<ol000<0003oooooool0N_oo
o`00VOooo`05o`2Ioooooooooooo000000Dco`020000Noooo`00VOooo`05o`2Ioooooooooooo0000
00Dco`000`000?ooooooo`1joooo002Ioooo00Go09Woooooooooool000001C?o00030000oooooooo
07[oool009Woool00ol0VOooooooo`02oooo00<0000co`0co`000S?o00030000oooooooo07[oool0
09Woool00ol0VOooooooo`02oooo00<0000co`0co`000S?o00030000oooooooo07[oool009Woool0
0ol0VOooooooo`02oooo00<0000co`0co`000S?o00030000oooooooo07[oool009Woool00ol0VOoo
ooooo`02oooo00<0000co`0co`000S?o00030000oooooooo07[oool009Woool00ol0VOooooooo`02
oooo00<0000co`0co`000S?o0080001koooo002Ioooo00?o09Woooooool00_ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo002Ioooo00?o09Woooooool00_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1joooo002Ioooo00?o09Woooooool00_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1joooo002Ioooo00?o09Woooooool00_ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo002Ioooo00?o09Woooooool00_ooo`030000<ol0<ol0008co`000`000?ooooooo`1joooo002I
oooo00?o09Woooooool00_ooo`030000<ol0<ol0008co`020000Noooo`00VOooo`03o`2Ioooooooo
00?oool01@0003?o03?o03?o0000001loooo002Ioooo00?o09Woooooool00oooo`050000<ol0<ol0
<ol0000007coool009Woool00ol0VOooooooo`03oooo00D0000co`0co`0co`000000O?ooo`00VOoo
o`03o`2Ioooo000000@00003<ol000<0003oooooool0N_ooo`00VOooo`03o`2Ioooo000000?oool0
1@0003?o03?o03?o0000001loooo002Ioooo00Co09Woooooool00002oooo00@0000co`0co`0co`03
0000N_ooo`00VOooo`07o`2Ioooooooooooo0000oooo000000<co`000`000?ooooooo`1joooo002I
oooo00?o09Woool000000_ooo`800003<ol000<0003oooooool0N_ooo`00VOooo`03o`2Ioooooooo
008000000oooo`0003?o0002<ol000<0003oooooool0N_ooo`00VOooo`03o`2Ioooooooo00?oool0
1@0003?o03?o03?o0000001loooo002Ioooo00?o09Woooooool01?ooo`040000<ol0<ol00000O?oo
o`00VOooo`03o`2Ioooooooo00Coool00`0003?o03?o00020000Noooo`00VOooo`03o`2Ioooooooo
00Coool0100003?o03?o000007coool009Woool00ol0VOooooooo`04oooo00@0000co`0co`00001l
oooo002Ioooo00?o09Woooooool01?ooo`040000<ol0<ol00000O?ooo`00VOooo`03o`2Ioooooooo
00Coool0100003?o03?o000007coool009Woool00ol0VOooooooo`04oooo00@0000co`0co`00001l
oooo002Ioooo00?o09Woooooool01?ooo`040000<ol0<ol00000O?ooo`00VOooo`03o`2Ioooooooo
00Goool0100003?o0000000007_oool009Woool00ol0VOooooooo`05oooo00<0000co`000000O?oo
o`00VOooo`03o`2Ioooooooo00Goool00`0003?o0000001loooo002Ioooo00?o09Woooooool01Ooo
o`030000<ol0000007coool009Woool00ol0VOooooooo`05oooo00<0000co`000000O?ooo`00VOoo
o`03o`2Ioooooooo00Goool00`0003?o0000001loooo002Ioooo00?o09Woooooool01Oooo`040000
<ol000000000Noooo`00VOooo`03o`2Ioooooooo00Goool00`0003?o0000001loooo002Ioooo00?o
09Woooooool01Oooo`030000<ol0000007coool009Woool00ol0VOooooooo`05oooo00<0000co`00
0000O?ooo`00VOooo`03o`2Ioooooooo00Goool00`0003?o0000001loooo002Ioooo00?o09Wooooo
ool01Oooo`030000<ol0000007coool009Woool00ol0VOooooooo`05oooo00@0000co`000000001k
oooo002Ioooo00?o09Woooooool01Oooo`030000<ol0000007coool009Woool00ol0VOooooooo`05
oooo00<0000co`000000O?ooo`00VOooo`03o`2Ioooooooo00Goool00`0003?o0000001loooo002I
oooo00?o09Woooooool00P0000?oool00`0003?o0000001loooo002Ioooo00?o09Woool000000_oo
o`060000oooooooo0000<ol00000O?ooo`00VOooo`05o`2Ioooooooooooo000000?oool00`0003?o
000000020000N_ooo`00VOooo`03o`2Ioooooooo00;oool01P000?ooooooo`0003?o000007coool0
09Woool00ol0VOooo`000002oooo00H0003oooooool0000co`00001loooo002Ioooo00?o09Wooooo
ool00P0000Coool20000O?ooo`00VOooo`03o`2Ioooooooo00Koool20000O?ooo`00VOooo`03o`2I
oooooooo00Koool20000O?ooo`00VOooo`03o`2Ioooooooo00Koool20000O?ooo`00VOooo`03o`2I
oooooooo00Koool30000Noooo`00VOooo`03o`2Ioooooooo00Koool20000O?ooo`00VOooo`03o`2I
oooooooo00Koool20000O?ooo`00VOooo`03o`2Ioooooooo00Koool20000O?ooo`00VOooo`03o`2I
oooooooo00Koool20000O?ooo`00VOooo`03o`2Ioooooooo00Koool20000O?ooo`00VOooo`03o`2I
oooooooo00Koool30000Noooo`00VOooo`03o`2Ioooooooo00Koool20000O?ooo`00VOooo`03o`2I
oooooooo00Koool20000O?ooo`00VOooo`03o`2Ioooooooo00Koool20000O?ooo`00VOooo`03o`2I
oooooooo00Koool20000O?ooo`00VOooo`03o`2Ioooooooo00Koool20000O?ooo`00VOooo`03o`2I
oooooooo00Koool30000Noooo`00VOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`1joooo002I
oooo00?o09Woooooool01oooo`030000oooooooo07[oool009Woool00ol0VOooooooo`07oooo00<0
003oooooool0N_ooo`00VOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`1joooo002Ioooo00?o
09Woooooool01oooo`030000oooooooo07[oool009Woool00ol0VOooooooo`07oooo0P0007_oool0
09Woool00ol0VOooooooo`07oooo00<0003oooooool0N_ooo`00VOooo`03o`2Ioooooooo00Ooool0
0`000?ooooooo`1joooo002Ioooo00?o09Woooooool01oooo`030000oooooooo07[oool009Woool0
0ol0VOooooooo`07oooo00<0003oooooool0N_ooo`00VOooo`04o`2Ioooooooooooo0`0000?oool0
0`000?ooooooo`1joooo002Ioooo00?o09Woooooool00_ooo`030000oooooooo00;oool00`000?oo
ooooo`1joooo002Ioooo00?o09Woool00000100000?oool30000N_ooo`00Voooo`040000oooooooo
0000POooo`00W?ooo`030000oooo0000087oool009goool20000POooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00005oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003ooooo
ool02?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Ooool0
0`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?oo
ooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53057 .12361 L
.53984 .12361 L
.54444 .12361 L
.54576 .12361 L
.54701 .12361 L
s
.54701 .12361 m
.54746 .61803 L
s
0 .4 1 r
.02381 .12373 m
.04262 .12378 L
.06244 .12386 L
.07286 .12391 L
.08255 .12397 L
.09388 .12405 L
.10458 .12414 L
.125 .12438 L
.14357 .12468 L
.16355 .12514 L
.18199 .12573 L
.20071 .12657 L
.21136 .1272 L
.22134 .12789 L
.24158 .12976 L
.26011 .13216 L
.27909 .1356 L
.28984 .13814 L
.29982 .14096 L
.32034 .14863 L
.33895 .15846 L
.35819 .17272 L
.36904 .18319 L
.37901 .19479 L
.38371 .20101 L
.3863 .20466 L
.38757 .20652 L
.38875 .20828 L
.38985 .20845 L
.39103 .20839 L
.3935 .20828 L
.39784 .20806 L
.4185 .20678 L
.43797 .20508 L
.45625 .20289 L
.47643 .19958 L
.49494 .19546 L
.51386 .1899 L
.52471 .18596 L
.53456 .18185 L
.5394 .17962 L
.54195 .1784 L
.54465 .17706 L
.54579 .17648 L
.54701 .17585 L
.54771 .12361 L
.54835 .12361 L
.54961 .12361 L
.55073 .12361 L
.55195 .12361 L
Mistroke
.5531 .12361 L
.55417 .12361 L
.55549 .12361 L
.55624 .12361 L
.55692 .12361 L
.55817 .12361 L
.55881 .12361 L
.5595 .12361 L
.56069 .12361 L
.5618 .12361 L
.56312 .12361 L
.56432 .12361 L
.56499 .12361 L
.5657 .12361 L
.56698 .12361 L
.56769 .12361 L
.56836 .12361 L
.56909 .12361 L
.56987 .12361 L
.57057 .12361 L
.57121 .12361 L
.57188 .12361 L
.57261 .12361 L
.57383 .12361 L
.57512 .12361 L
.57636 .12361 L
.57707 .12361 L
.57772 .12361 L
.57842 .12361 L
.57905 .12361 L
.57978 .12361 L
.58047 .12361 L
.58539 .12361 L
.59651 .12361 L
.61667 .12361 L
.65497 .12361 L
.69572 .12361 L
.73496 .12361 L
.77267 .12361 L
.81285 .12361 L
.8515 .12361 L
.89261 .12361 L
.9322 .12361 L
.97028 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`04oooo0`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0
I_l0201Vo`03000006Kooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Lco`00
0`0003?o001Vo`07<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool002[oool00`000?ooooooo`0Noooo1@1Vo`?oool00`000?ooooooo`0Uoooo00<0
003oooooool01_ooo`@0000C<ol000<0I_lco`0co`001C?o00030000oooooooo02Goool00`000?oo
ooooo`0Voooo00<0003oooooool0:Oooo`00D?ooo`T0I_l_oooo100000lco`000`1Voc?o03?o0005
<ol000<0003oooooool0N_ooo`00FOooo`80I_laoooo00<0000co`0co`0033?o000306Ko<ol0<ol0
00Dco`000`000?ooooooo`1joooo001Koooo0`1Vobooool2000033?o000306Ko<ol0<ol000Dco`00
0`000?ooooooo`1joooo001Noooo0P1Vobooool00`0003?o03?o0009<ol000<0I_lco`0co`001C?o
00030000oooooooo07[oool0063oool306Ko;Oooo`030000<ol0<ol000Pco`000`1Voc?o03?o0005
<ol00P0007_oool006?oool206Ko;?ooo`800008<ol000<0I_lco`0co`001C?o00030000oooooooo
07[oool006Goool206Ko;?ooo`030000<ol0<ol000Dco`000`1Voc?o03?o0005<ol000<0003ooooo
ool0N_ooo`00Ioooo`0306Kooooooooo02Woool00`0003?o03?o0005<ol000<0I_lco`0co`001C?o
00030000oooooooo07[oool006Soool206Ko:_ooo`030000<ol0<ol000@co`000`1Voc?o03?o0005
<ol000<0003oooooool0N_ooo`00J_ooo`0306Kooooooooo02Ooool00`0003?o03?o0004<ol000<0
I_lco`0co`001C?o00030000oooooooo07[oool006_oool00`1Vooooooooo`0Woooo00<0000co`0c
o`000c?o000306Ko<ol0<ol000Dco`020000Noooo`00K?ooo`0306Kooooooooo02Koool00`0003?o
03?o0002<ol00P1Vo`Lco`000`000?ooooooo`1joooo001]oooo00<0I_ooooooool09_ooo`060000
06Ko06Ko06Ko<ol0o`2I1c?o00030000oooooooo07[oool006koool00`1Vooooooooo`0Soooo0`1V
o`@co`000ol0VC?o03?o0005<ol000<0003oooooool0N_ooo`00Koooo`0306Kooooooooo023oool2
06Ko0oooo`050000<ol0<ol0<ol0o`2I00Lco`000`000?ooooooo`1joooo001`oooo00<0I_oooooo
ool07Oooo`80I_l5oooo00D0000co`0co`0co`3o09T01c?o00030000oooooooo07[oool0073oool0
0`1Vooooooooo`0Ioooo101Vo`Soool0100003?o03?o0?l0V@Lco`020000Noooo`00LOooo`0306Ko
oooooooo01?oool506Ko3?ooo`040000<ol0<ol0o`2I1c?o00030000oooooooo07[oool007;oool0
0`1Vooooooooo`03oooo3`1Voa7oool0100003?o03?o0?l0V@Lco`000`000?ooooooo`1joooo001c
oooo1@1Vob7oool00`0003?o0?l0V@07<ol000<0003oooooool0N_ooo`00VOooo`030000<ol0o`2I
00Lco`000`000?ooooooo`1joooo002Ioooo00<0000co`3o09T01c?o00030000oooooooo07[oool0
09Woool00`0003?o0?l0V@07<ol00P0007_oool009[oool00`000?l0VC?o0006<ol000<0003ooooo
ool0N_ooo`00V_ooo`030000o`2I<ol000Hco`000`000?ooooooo`1joooo002Joooo00<0003o09Tc
o`001S?o00030000oooooooo07[oool009[oool00`000?l0VC?o0006<ol000<0003oooooool0N_oo
o`00Voooo`D00003<ol000<0003oooooool0N_ooo`00Voooo`03o`2I<ol0000000Dco`000`000?oo
ooooo`1joooo002Koooo00?o09Tco`0000001C?o00<0001joooo002Koooo00?o09T0000000001C?o
00030000oooooooo07[oool009_oool00ol0V@0000000005<ol000<0003oooooool0N_ooo`00Vooo
o`03o`2I0000000000Dco`000`000?ooooooo`1joooo002Koooo00?o09T0000co`001C?o00030000
oooooooo07[oool009_oool00ol0V@0003?o0005<ol000<0003oooooool0N_ooo`00Voooo`03o`2I
0000<ol000Dco`020000Noooo`00Voooo`03o`2Ioooo000000Dco`000`000?ooooooo`1joooo002K
oooo00?o09Woool000001C?o00030000oooooooo07[oool009_oool00ol0VOooo`000005<ol000<0
003oooooool0N_ooo`00Voooo`03o`2Ioooo000000Dco`000`000?ooooooo`1joooo002Koooo00?o
09Woool000001C?o00030000oooooooo07[oool009_oool00ol0VOooo`000005<ol00P0007_oool0
09_oool00ol0VOooo`000005<ol000<0003oooooool0N_ooo`00Voooo`03o`2Ioooo000000Dco`00
0`000?ooooooo`1joooo002Koooo00Co09Woooooool00004<ol000<0003oooooool0N_ooo`00Vooo
o`04o`2Ioooooooo000013?o00030000oooooooo07[oool009_oool01?l0VOooooooo`0000@co`00
0`000?ooooooo`1joooo002Koooo00Co09Woooooool00004<ol000<0003oooooool0N_ooo`00Vooo
o`04o`2Ioooooooo000013?o0080001koooo002Koooo00Co09Woooooool00004<ol000<0003ooooo
ool0N_ooo`00Voooo`04o`2Ioooooooo000013?o00030000oooooooo07[oool009_oool01?l0VOoo
ooooo`0000@co`000`000?ooooooo`1joooo002Koooo00Co09Woooooool00004<ol000<0003ooooo
ool0N_ooo`00Voooo`04o`2Ioooooooo000013?o00030000oooooooo07[oool009_oool01?l0VOoo
ooooo`0000@co`020000Noooo`00Voooo`05o`2Ioooooooooooo000000<co`000`000?ooooooo`1j
oooo002Koooo00Go09Woooooooooool000000c?o00030000oooooooo07[oool009_oool01Ol0VOoo
ooooooooo`000003<ol000<0003oooooool0N_ooo`00Voooo`D00003<ol000<0003oooooool0N_oo
o`00Voooo`050000oooooooooooo000000<co`000`000?ooooooo`1joooo002Koooo00Go09T0003o
ooooool000000c?o00<0001joooo002Koooo00Go09Woool0003oool000000c?o00030000oooooooo
07[oool009_oool00`000?ooooooo`0200000c?o00030000oooooooo07[oool009_oool01Ol0V@00
00000?ooo`000003<ol000<0003oooooool0N_ooo`00Voooo`05o`2Ioooooooooooo000000<co`00
0`000?ooooooo`1joooo002Koooo00?o09Woooooool00_ooo`040000<ol0<ol00000O?ooo`00Vooo
o`03o`2Ioooooooo00;oool00`0003?o03?o00020000Noooo`00Voooo`03o`2Ioooooooo00;oool0
100003?o03?o000007coool009_oool00ol0VOooooooo`02oooo00@0000co`0co`00001loooo002K
oooo00?o09Woooooool00_ooo`040000<ol0<ol00000O?ooo`00Voooo`03o`2Ioooooooo00;oool0
100003?o03?o000007coool009_oool00ol0VOooooooo`02oooo00@0000co`0co`00001loooo002K
oooo00?o09Woooooool00_ooo`040000<ol0<ol00000O?ooo`00Voooo`03o`2Ioooooooo00?oool0
100003?o0000000007_oool009_oool00ol0VOooooooo`03oooo00<0000co`000000O?ooo`00Vooo
o`03o`2Ioooooooo00?oool00`0003?o0000001loooo002Koooo00?o09Woooooool00oooo`030000
<ol0000007coool009_oool00ol0VOooooooo`03oooo00<0000co`000000O?ooo`00Voooo`03o`2I
oooooooo00?oool00`0003?o0000001loooo002Koooo00?o09Woooooool00oooo`040000<ol00000
0000Noooo`00Voooo`03o`2Ioooooooo00?oool00`0003?o0000001loooo002Koooo00?o09Wooooo
ool00oooo`030000<ol0000007coool009_oool00ol0VOooooooo`03oooo00<0000co`000000O?oo
o`00Voooo`03o`2Ioooooooo00?oool00`0003?o0000001loooo002Koooo00?o09Woooooool00ooo
o`030000<ol0000007coool009_oool00ol0VOooooooo`03oooo00@0000co`000000001koooo002K
oooo00?o09Woooooool00oooo`030000<ol0000007coool009_oool00ol0VOooooooo`03oooo00<0
000co`000000O?ooo`00Voooo`03o`2Ioooooooo00?oool00`0003?o0000001loooo002Koooo00?o
09T0000000000oooo`030000<ol0000007coool009_oool010000?ooooooo`0000;oool00`0003?o
0000001loooo002Koooo00?o09Woool000000oooo`030000<ol000000080001joooo002Koooo00Co
09Woooooool00002oooo00<0000co`000000O?ooo`00Voooo`040000oooooooo00000_ooo`030000
<ol0000007coool009_oool00ol0V@0000000004oooo0P0007coool009_oool00ol0VOooooooo`04
oooo0P0007coool009_oool00ol0VOooooooo`04oooo0P0007coool009_oool00ol0VOooooooo`04
oooo0P0007coool009_oool00ol0VOooooooo`04oooo0`0007_oool009_oool00ol0VOooooooo`04
oooo0P0007coool009_oool00ol0VOooooooo`04oooo0P0007coool009_oool00ol0VOooooooo`04
oooo0P0007coool009_oool00ol0VOooooooo`04oooo0P0007coool009_oool00ol0VOooooooo`04
oooo0P0007coool009_oool00ol0VOooooooo`04oooo0`0007_oool009_oool00ol0VOooooooo`04
oooo0P0007coool009_oool00ol0VOooooooo`04oooo0P0007coool009_oool00ol0VOooooooo`04
oooo0P0007coool009_oool00ol0VOooooooo`04oooo0P0007coool009_oool00ol0VOooooooo`04
oooo0P0007coool009_oool00ol0VOooooooo`04oooo0`0007_oool009_oool00ol0VOooooooo`05
oooo00<0003oooooool0N_ooo`00Voooo`03o`2Ioooooooo00Goool00`000?ooooooo`1joooo002K
oooo00?o09Woooooool01Oooo`030000oooooooo07[oool009_oool00ol0VOooooooo`05oooo00<0
003oooooool0N_ooo`00Voooo`03o`2Ioooooooo00Goool00`000?ooooooo`1joooo002Koooo00?o
09Woooooool01Oooo`80001koooo002Koooo00?o09Woooooool01Oooo`030000oooooooo07[oool0
09_oool00ol0VOooooooo`05oooo00<0003oooooool0N_ooo`00Voooo`03o`2Ioooooooo00Goool0
0`000?ooooooo`1joooo002Koooo00?o09Woooooool01Oooo`030000oooooooo07[oool009_oool0
0ol0VOooo`00000200000oooo`030000oooooooo07[oool009_oool01?l0VOooooooo`0000Coool0
0`000?ooooooo`1joooo002Koooo1@0000?oool30000N_ooo`00Voooo`040000oooooooo0000POoo
o`00W?ooo`030000oooo0000087oool009goool20000POooo`00ooooob7oool00?oooolQoooo001i
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`0<oooo1@0000;oool200001Oooo`<00002oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005
oooo00<0003oooooool02_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Ooool500000oooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500005?ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005oooo`030000oooooooo00Soool0
0`000?ooo`000003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002ooo
o`800002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55195 .12361 L
.55338 .12361 L
.55408 .12361 L
.55472 .12361 L
s
.55472 .12361 m
.55523 .61803 L
s
0 .4 1 r
.02381 .12372 m
.04262 .12376 L
.06244 .12382 L
.07286 .12387 L
.08255 .12392 L
.09388 .12399 L
.10458 .12407 L
.125 .12427 L
.14357 .12453 L
.16355 .12493 L
.18199 .12544 L
.20071 .12617 L
.21136 .1267 L
.22134 .1273 L
.24158 .12891 L
.26011 .13099 L
.27909 .13396 L
.28984 .13614 L
.29982 .13858 L
.32034 .14519 L
.33895 .15367 L
.35819 .16598 L
.36904 .17501 L
.37901 .18501 L
.3881 .1958 L
.3931 .20254 L
.39429 .20423 L
.39556 .20608 L
.39664 .20768 L
.39784 .2079 L
.3985 .20787 L
.39922 .20783 L
.40052 .20775 L
.40343 .20758 L
.40853 .20726 L
.4185 .20655 L
.43854 .20469 L
.45964 .20192 L
.47938 .19831 L
.49775 .19378 L
.51821 .187 L
.5368 .17886 L
.54164 .17638 L
.54678 .17357 L
.55116 .17102 L
.55236 .17029 L
.55365 .1695 L
.55487 .16874 L
.55598 .12361 L
.55726 .12361 L
Mistroke
.55798 .12361 L
.55863 .12361 L
.55989 .12361 L
.56108 .12361 L
.56176 .12361 L
.56248 .12361 L
.56376 .12361 L
.56447 .12361 L
.56514 .12361 L
.56587 .12361 L
.56665 .12361 L
.56795 .12361 L
.56869 .12361 L
.56937 .12361 L
.57062 .12361 L
.57125 .12361 L
.57195 .12361 L
.57315 .12361 L
.57444 .12361 L
.57566 .12361 L
.57678 .12361 L
.57806 .12361 L
.57927 .12361 L
.58036 .12361 L
.58153 .12361 L
.58661 .12361 L
.59574 .12361 L
.61645 .12361 L
.65742 .12361 L
.69688 .12361 L
.73482 .12361 L
.77521 .12361 L
.81409 .12361 L
.85542 .12361 L
.89523 .12361 L
.93353 .12361 L
.97428 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<00000I_l0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`08
06Ko00<00000I_ooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00050000
<ol0<ol0<ol006Ko00Dco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`00:_ooo`030000oooooooo01koool806Ko00<00000I_ooool09Oooo`030000
oooooooo00Koool400005C?o000306Ko<ol0<ol000<co`000`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000oooooooo02Woool005Goool406Ko;oooo`@0000A<ol000<0I_lco`0co`000c?o
00030000oooooooo07[oool005Woool506Ko;_ooo`030000<ol0<ol000hco`000`1Voc?o03?o0003
<ol000<0003oooooool0N_ooo`00G_ooo`80I_l]oooo0P0000hco`000`1Voc?o03?o0003<ol000<0
003oooooool0N_ooo`00H?ooo`<0I_l/oooo00<0000co`0co`002c?o000306Ko<ol0<ol000<co`00
0`000?ooooooo`1joooo001Soooo0P1Vob_oool00`0003?o03?o000:<ol000<0I_lco`0co`000c?o
0080001koooo001Uoooo0P1Vob[oool200002S?o000306Ko<ol0<ol000<co`000`000?ooooooo`1j
oooo001Woooo0P1Vob[oool00`0003?o03?o0007<ol000<0I_lco`0co`000c?o00030000oooooooo
07[oool006Woool206Ko:?ooo`030000<ol0<ol000Lco`000`1Voc?o03?o0003<ol000<0003ooooo
ool0N_ooo`00Joooo`0306Kooooooooo02Koool00`0003?o03?o0006<ol000<0I_lco`0co`000c?o
00030000oooooooo07[oool006coool206Ko9_ooo`030000<ol0<ol000Dco`0206Ko1C?o00030000
oooooooo07[oool006koool00`1Vooooooooo`0Toooo00<0000co`0co`000c?o000306Ko<ol0o`2I
00Dco`020000Noooo`00Koooo`0306Kooooooooo02?oool00`0003?o03?o000306Ko0S?o0003o`2I
<ol0<ol000<co`000`000?ooooooo`1joooo001_oooo00<0I_ooooooool09?ooo`80I_l5<ol000?o
09Tco`0co`000c?o00030000oooooooo07[oool0073oool00`1Vooooooooo`0Poooo0`1Vo`030000
<ol0<ol000@co`000ol0VC?o03?o0003<ol000<0003oooooool0N_ooo`00LOooo`0306Kooooooooo
01coool306Ko1?ooo`030000<ol0<ol000<co`000ol0VC?o03?o0003<ol000<0003oooooool0N_oo
o`00L_ooo`0306Kooooooooo01Soool306Ko1oooo`030000<ol0<ol000<co`000ol0VC?o03?o0003
<ol000<0003oooooool0N_ooo`00Loooo`0306Kooooooooo01;oool506Ko2oooo`030000<ol0<ol0
008co`000ol0VC?o03?o0003<ol00P0007_oool007Coool00`1Vooooooooo`0<oooo1@1Voa3oool0
0`0003?o03?o0002<ol000?o09Tco`0co`000c?o00030000oooooooo07[oool007Coool00`1Voooo
ooooo`03oooo2@1VoaGoool00`0003?o03?o0002<ol000?o09Tco`0co`000c?o00030000oooooooo
07[oool007Goool506Ko7oooo`050000<ol0<ol0<ol0o`2I00Dco`000`000?ooooooo`1joooo002I
oooo00D0000co`0co`0co`3o09T01C?o00030000oooooooo07[oool009Woool01@0003?o03?o03?o
0?l0V@05<ol000<0003oooooool0N_ooo`00VOooo`050000<ol0<ol0<ol0o`2I00Dco`020000Nooo
o`00V_ooo`040000<ol0<ol0o`2I1C?o00030000oooooooo07[oool009[oool0100003?o03?o0?l0
V@Dco`000`000?ooooooo`1joooo002Joooo00@0000co`0co`3o09T5<ol000<0003oooooool0N_oo
o`00V_ooo`040000<ol0<ol0o`2I1C?o00030000oooooooo07[oool009_oool500000c?o00030000
oooooooo07[oool009_oool00`0003?o00000005<ol000<0003oooooool0N_ooo`00Voooo`030000
<ol0000000Dco`030000N_ooo`00W?ooo`800005<ol000<0003oooooool0N_ooo`00W?ooo`800005
<ol000<0003oooooool0N_ooo`00W?ooo`800005<ol000<0003oooooool0N_ooo`00W?ooo`030000
o`2I<ol000@co`000`000?ooooooo`1joooo002Loooo00<0003o09Tco`0013?o00030000oooooooo
07[oool009coool00`000?l0VC?o0004<ol00P0007_oool009goool00ol0VC?o03?o0003<ol000<0
003oooooool0N_ooo`00WOooo`03o`2I<ol0<ol000<co`000`000?ooooooo`1joooo002Moooo00?o
09Tco`0co`000c?o00030000oooooooo07[oool009goool00ol0VC?o03?o0003<ol000<0003ooooo
ool0N_ooo`00WOooo`03o`2I<ol0<ol000<co`000`000?ooooooo`1joooo002Moooo00?o09Tco`0c
o`000c?o0080001koooo002Moooo00?o09Tco`0co`000c?o00030000oooooooo07[oool009goool0
0ol0VC?o03?o0003<ol000<0003oooooool0N_ooo`00WOooo`03o`2I0000<ol000<co`000`000?oo
ooooo`1joooo002Moooo00?o09T0000co`000c?o00030000oooooooo07[oool009goool00ol0V@00
03?o0003<ol000<0003oooooool0N_ooo`00WOooo`03o`2I0000<ol000<co`000`000?ooooooo`1j
oooo002Moooo00?o09T0000co`000c?o0080001koooo002Moooo00?o09T0000co`000c?o00030000
oooooooo07[oool009goool00ol0V@0003?o0003<ol000<0003oooooool0N_ooo`00WOooo`03o`2I
0000<ol000<co`000`000?ooooooo`1joooo002Moooo00?o09T0000co`000c?o00030000oooooooo
07[oool009goool00ol0V@0003?o0003<ol000<0003oooooool0N_ooo`00WOooo`03o`2I0000<ol0
00<co`020000Noooo`00WOooo`03o`2Ioooo000000<co`000`000?ooooooo`1joooo002Moooo00?o
09Woool000000c?o00030000oooooooo07[oool009goool00ol0VOooo`000003<ol000<0003ooooo
ool0N_ooo`00Voooo`D00003<ol000<0003oooooool0N_ooo`00Voooo`050000ooooo`2Ioooo0000
00<co`000`000?ooooooo`1joooo002Loooo00@0003o09Woool00003<ol00`0007[oool009goool0
0`000?ooo`000003<ol000<0003oooooool0N_ooo`00Voooo`030000ooooo`2I00800003<ol000<0
003oooooool0N_ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003oooooool0N_ooo`00WOoo
o`03o`2Ioooo000000<co`000`000?ooooooo`1joooo002Moooo00Co09Woooooool00002<ol000<0
003oooooool0N_ooo`00WOooo`04o`2Ioooooooo00000S?o0080001koooo002Moooo00Co09Wooooo
ool00002<ol000<0003oooooool0N_ooo`00WOooo`04o`2Ioooooooo00000S?o00030000oooooooo
07[oool009goool01?l0VOooooooo`00008co`000`000?ooooooo`1joooo002Moooo00Co09Wooooo
ool00002<ol000<0003oooooool0N_ooo`00WOooo`04o`2Ioooooooo00000S?o00030000oooooooo
07[oool009goool01?l0VOooooooo`00008co`000`000?ooooooo`1joooo002Moooo00Ko09Wooooo
ooooool0000co`020000Noooo`00WOooo`07o`2Ioooooooooooo0000<ol0000007coool009goool0
1ol0VOooooooooooo`0003?o0000001loooo002Moooo00Oo09Woooooooooool0000co`000000O?oo
o`00WOooo`07o`2Ioooooooooooo0000<ol0000007coool009goool01ol0VOooooooooooo`0003?o
0000001loooo002Moooo00Ko09Woooooooooool0000co`020000Noooo`00WOooo`07o`2Ioooooooo
oooo0000<ol0000007coool009goool01ol0VOooooooooooo`0003?o0000001loooo002Moooo00Oo
09Woooooooooool0000co`000000O?ooo`00WOooo`07o`2Ioooooooooooo0000<ol0000007coool0
09goool01ol0VOooooooooooo`0003?o0000001loooo002Moooo00Ko09Woooooooooool0000co`02
0000Noooo`00WOooo`07o`2Ioooooooooooo0000<ol0000007coool009goool01ol0VOoooooooooo
o`0003?o0000001loooo002Moooo00Oo09Woooooooooool0000co`000000O?ooo`00W?ooo`800003
oooo00<0000co`000000O?ooo`00Voooo`040000ooooo`2I00000_ooo`030000<ol0000007coool0
09goool01P000?ooooooooooo`0003?o00<0001joooo002Moooo00Oo09T0003oooooool0000co`00
0000O?ooo`00Voooo`040000ooooo`2I00000_ooo`030000<ol0000007coool009coool200001?oo
o`80001loooo002Moooo00?o09Woooooool00_ooo`80001loooo002Moooo00?o09Woooooool00_oo
o`80001loooo002Moooo00?o09Woooooool00_ooo`80001loooo002Moooo00?o09Woooooool00_oo
o`<0001koooo002Moooo00?o09Woooooool00_ooo`80001loooo002Moooo00?o09Woooooool00_oo
o`80001loooo002Moooo00?o09Woooooool00_ooo`80001loooo002Moooo00?o09Woooooool00_oo
o`80001loooo002Moooo00?o09Woooooool00_ooo`80001loooo002Moooo00?o09Woooooool00_oo
o`<0001koooo002Moooo00?o09Woooooool00_ooo`80001loooo002Moooo00?o09Woooooool00_oo
o`80001loooo002Moooo00?o09Woooooool00_ooo`80001loooo002Moooo00?o09Woooooool00_oo
o`80001loooo002Moooo00?o09Woooooool00_ooo`80001loooo002Moooo00?o09Woooooool00_oo
o`<0001koooo002Moooo00?o09Woooooool00oooo`030000oooooooo07[oool009goool00ol0VOoo
ooooo`03oooo00<0003oooooool0N_ooo`00WOooo`03o`2Ioooooooo00?oool00`000?ooooooo`1j
oooo002Moooo00?o09Woooooool00oooo`030000oooooooo07[oool009goool00ol0VOooooooo`03
oooo00<0003oooooool0N_ooo`00WOooo`03o`2Ioooooooo00?oool20000Noooo`00WOooo`03o`2I
oooooooo00?oool00`000?ooooooo`1joooo002Moooo00?o09Woooooool00oooo`030000oooooooo
07[oool009goool00ol0VOooooooo`03oooo00<0003oooooool0N_ooo`00WOooo`03o`2Ioooooooo
00?oool00`000?ooooooo`1joooo002Moooo0`0000?oool00`000?ooooooo`1joooo002Moooo00?o
09T0003oool00oooo`030000oooooooo07[oool009_oool500000oooo`<0001joooo002Koooo00@0
003oooooool00021oooo002Loooo00<0003oool00000POooo`00WOooo`800021oooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00coool500000_ooo`800004oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02Ooo
o`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001Coool0
0`000?ooooooo`0:oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooooooo0000
01Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55436 .12361 L
.55712 .12361 L
.55972 .12361 L
.56092 .12361 L
.56218 .12361 L
.56285 .12361 L
s
.56285 .12361 m
.56314 .61803 L
s
0 .4 1 r
.02381 .1237 m
.04262 .12374 L
.06244 .12379 L
.07286 .12383 L
.08255 .12388 L
.09388 .12394 L
.10458 .124 L
.125 .12418 L
.14357 .1244 L
.16355 .12474 L
.18199 .12519 L
.20071 .12581 L
.21136 .12627 L
.22134 .12679 L
.24158 .12817 L
.26011 .12996 L
.27909 .13251 L
.28984 .13439 L
.29982 .13649 L
.32034 .14218 L
.33895 .14949 L
.35819 .16008 L
.36904 .16785 L
.37901 .17646 L
.38887 .18661 L
.3943 .19301 L
.39944 .19967 L
.40175 .20288 L
.40302 .20469 L
.40421 .20643 L
.4055 .2072 L
.40618 .20715 L
.40691 .2071 L
.40941 .20693 L
.4185 .20622 L
.43831 .20425 L
.45647 .20177 L
.4754 .19824 L
.4961 .19294 L
.51571 .18608 L
.53666 .17618 L
.5469 .17014 L
.55229 .16659 L
.558 .16252 L
.56041 .16069 L
.56174 .15966 L
.563 .15866 L
.56371 .12361 L
.56448 .12361 L
.56519 .12361 L
Mistroke
.56583 .12361 L
.5665 .12361 L
.56721 .12361 L
.56849 .12361 L
.56974 .12361 L
.57088 .12361 L
.57214 .12361 L
.57278 .12361 L
.57347 .12361 L
.57464 .12361 L
.5759 .12361 L
.57708 .12361 L
.57816 .12361 L
.57934 .12361 L
.58045 .12361 L
.58167 .12361 L
.58298 .12361 L
.5881 .12361 L
.59728 .12361 L
.61805 .12361 L
.65925 .12361 L
.69892 .12361 L
.73708 .12361 L
.7777 .12361 L
.81679 .12361 L
.85834 .12361 L
.89838 .12361 L
.9369 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<00000I_l0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`08
06Ko00<00000I_ooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000<co`001@1Voc?o03?o03?o00000009oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`00:_ooo`030000oooooooo01koool806Ko00<00000I_ooool09Oooo`030000
oooooooo00Koool400005c?o000506Ko<ol0<ol0<ol0000002Ooool00`000?ooooooo`0Voooo00<0
003oooooool0:Oooo`00EOooo`H0I_l]oooo100001<co`001@1Voc?o03?o03?o0000001loooo001K
oooo101Vobgoool00`0003?o03?o000@<ol000D0I_lco`0co`0co`000000O?ooo`00Goooo`@0I_lZ
oooo0P00010co`001@1Voc?o03?o03?o0000001loooo001Soooo0P1Vob[oool00`0003?o03?o000=
<ol000D0I_lco`0co`0co`000000O?ooo`00IOooo`80I_lYoooo00<0000co`0co`0033?o000406Ko
<ol0<ol0<ol00P0007_oool006Ooool206Ko:?ooo`80000<<ol000D0I_lco`0co`0co`000000O?oo
o`00JOooo`80I_lXoooo00<0000co`0co`002C?o000506Ko<ol0<ol0<ol0000007coool006_oool0
0`1Vooooooooo`0Uoooo00<0000co`0co`0023?o0080I_l3<ol000<0003oooooool0N_ooo`00K?oo
o`80I_lVoooo00<0000co`0co`001C?o0080I_l00c?o0?l0VC?o0002<ol000<0003oooooool0N_oo
o`00K_ooo`0306Kooooooooo02?oool00`0003?o03?o0004<ol000D0I_lco`0co`0co`3o09T00c?o
00030000oooooooo07[oool006ooool00`1Vooooooooo`0Soooo00@0000co`0co`0co`0206Ko13?o
0004o`2I<ol0<ol0<ol00P0007_oool0073oool00`1Vooooooooo`0Roooo00@0000co`00I_l0I_l6
<ol000Go09Tco`0co`0co`000000O?ooo`00LOooo`80I_lRoooo0P1Vo`Pco`001Ol0VC?o03?o03?o
0000001loooo001coooo00<0I_ooooooool07?ooo`<0I_l00oooo`0003?o0007<ol000Go09Tco`0c
o`0co`000000O?ooo`00Loooo`0306Kooooooooo01[oool206Ko1Oooo`030000<ol0<ol000Dco`00
1Ol0VC?o03?o03?o0000001loooo001doooo00<0I_ooooooool05Oooo`@0I_l7oooo00<0000co`0c
o`001C?o0005o`2I<ol0<ol0<ol0000007coool007Coool00`1Vooooooooo`0@oooo1@1Vo`coool0
0`0003?o03?o0004<ol000Co09Tco`0co`0co`020000Noooo`00MOooo`0306Kooooooooo00[oool5
06Ko4Oooo`030000<ol0<ol000@co`001Ol0VC?o03?o03?o0000001loooo001foooo0P1Vo`;oool8
06Ko5_ooo`030000<ol0<ol000@co`001Ol0VC?o03?o03?o0000001loooo001goooo0`1Voaooool0
0`0003?o03?o0003<ol000Go09Tco`0co`0co`000000O?ooo`00VOooo`030000<ol0<ol000<co`00
1Ol0VC?o03?o03?o0000001loooo002Ioooo00<0000co`0co`000c?o0005o`2I<ol0<ol0<ol00000
07coool009Woool00`0003?o03?o0003<ol000Co09Tco`0co`0co`020000Noooo`00V_ooo`030000
<ol0<ol0008co`001Ol0VC?o03?o03?o0000001loooo002Joooo00<0000co`0co`000S?o0005o`2I
<ol0<ol0<ol0000007coool009[oool00`0003?o03?o0002<ol000Go09Tco`0co`0co`000000O?oo
o`00V_ooo`030000<ol0<ol0008co`001Ol0VC?o03?o03?o0000001loooo002Koooo1@0000<co`00
0`000?ooooooo`1joooo002Koooo00D0000co`00000co`3o09T00c?o00030000oooooooo07[oool0
09_oool01@0003?o000003?o0?l0V@03<ol00`0007[oool009coool2000000<co`3o09Tco`000S?o
00030000oooooooo07[oool009coool2000000<co`3o09Tco`000S?o00030000oooooooo07[oool0
09coool2000000<co`3o09Tco`000S?o00030000oooooooo07[oool009coool0100003?o03?o0?l0
V@<co`000`000?ooooooo`1joooo002Loooo00@0000co`0co`3o09T3<ol000<0003oooooool0N_oo
o`00W?ooo`040000<ol0<ol0o`2I0c?o0080001koooo002Moooo00<0000co`3o09T00c?o00030000
oooooooo07[oool009goool00`0003?o0?l0V@03<ol000<0003oooooool0N_ooo`00WOooo`030000
<ol0o`2I00<co`000`000?ooooooo`1joooo002Moooo00<0000co`3o09T00c?o00030000oooooooo
07[oool009goool00`0003?o0?l0V@03<ol000<0003oooooool0N_ooo`00WOooo`030000<ol0o`2I
00<co`020000Noooo`00WOooo`030000<ol0o`2I00<co`000`000?ooooooo`1joooo002Moooo00<0
000co`3o09T00c?o00030000oooooooo07[oool009koool00`000?l0VC?o0002<ol000<0003ooooo
ool0N_ooo`00W_ooo`030000o`2I<ol0008co`000`000?ooooooo`1joooo002Noooo00<0003o09Tc
o`000S?o00030000oooooooo07[oool009koool00`000?l0VC?o0002<ol000<0003oooooool0N_oo
o`00W_ooo`030000o`2I<ol0008co`020000Noooo`00W_ooo`030000o`2I<ol0008co`000`000?oo
ooooo`1joooo002Noooo00<0003o09Tco`000S?o00030000oooooooo07[oool009koool00`000?l0
VC?o0002<ol000<0003oooooool0N_ooo`00W_ooo`030000o`2I<ol0008co`000`000?ooooooo`1j
oooo002Noooo00<0003o09Tco`000S?o00030000oooooooo07[oool009koool00`000?l0VC?o0002
<ol00P0007_oool009ooool01Ol0VC?o03?o03?o0000001loooo002Ooooo00Go09Tco`0co`0co`00
0000O?ooo`00Woooo`05o`2I<ol0<ol0<ol0000007coool009_oool4000000Go09Tco`0co`0co`00
0000O?ooo`00Voooo`050000ooooooooooooo`2I00<co`000`000?ooooooo`1joooo002Loooo00@0
003ooooooooo09T3<ol00`0007[oool009goool00`000?ooool0V@03<ol000<0003oooooool0N_oo
o`00Voooo`050000oooooooo0000o`2I00<co`000`000?ooooooo`1joooo002Loooo0P000003oooo
o`2I<ol0008co`000`000?ooooooo`1joooo002Ooooo00Go09Tco`0co`0co`000000O?ooo`00Wooo
o`05o`2I0000<ol0<ol0000007coool009ooool01?l0V@0003?o03?o0080001koooo002Ooooo00Go
09T0000co`0co`000000O?ooo`00Woooo`05o`2I0000<ol0<ol0000007coool009ooool01Ol0V@00
03?o03?o0000001loooo002Ooooo00Go09T0000co`0co`000000O?ooo`00Woooo`05o`2I0000<ol0
<ol0000007coool009ooool01Ol0V@0003?o03?o0000001loooo002Ooooo00Co09Woool0000co`02
0000Noooo`00Woooo`05o`2Ioooo0000<ol0000007coool009ooool01Ol0VOooo`0003?o0000001l
oooo002Ooooo00Go09Woool0000co`000000O?ooo`00Woooo`05o`2Ioooo0000<ol0000007coool0
09ooool01Ol0VOooo`0003?o0000001loooo002Ooooo00Co09Woool0000co`020000Noooo`00Wooo
o`05o`2Ioooo0000<ol0000007coool009ooool01Ol0VOooo`0003?o0000001loooo002Ooooo00Go
09Woool0000co`000000O?ooo`00Woooo`05o`2Ioooo0000<ol0000007coool009ooool01Ol0VOoo
o`0003?o0000001loooo002Ooooo00Co09Woool0000co`020000Noooo`00Woooo`05o`2Ioooo0000
<ol0000007coool009ooool01Ol0VOooo`0003?o0000001loooo002Ooooo00Go09Woool0000co`00
0000O?ooo`00W?ooo`8000001_ooool0VOooo`0003?o000007coool009_oool02@000?ooooooo`00
0?l0VOooo`0003?o0000001loooo002Moooo00H0003ooooo09Woool0000co`030000N_ooo`00W_oo
o`060000o`2Ioooo0000<ol00000O?ooo`00Voooo`090000oooooooo0000o`2Ioooo0000<ol00000
07coool009coool2000000Cooooo09Woooooool20000O?ooo`00Woooo`03o`2Ioooooooo0080001l
oooo002Ooooo00?o09Woooooool00P0007coool009ooool00ol0VOooooooo`020000O?ooo`00Wooo
o`03o`2Ioooooooo00<0001koooo002Ooooo00?o09Woooooool00P0007coool009ooool00ol0VOoo
ooooo`020000O?ooo`00Woooo`03o`2Ioooooooo0080001loooo002Ooooo00?o09Woooooool00P00
07coool009ooool00ol0VOooooooo`020000O?ooo`00Woooo`03o`2Ioooooooo00<0001koooo002O
oooo00?o09Woooooool00P0007coool009ooool00ol0VOooooooo`020000O?ooo`00Woooo`03o`2I
oooooooo0080001loooo002Ooooo00?o09Woooooool00P0007coool009ooool00ol0VOooooooo`02
0000O?ooo`00Woooo`03o`2Ioooooooo00<0001koooo002Ooooo00Go09Woooooooooool00000O?oo
o`00Woooo`05o`2Ioooooooooooo000007coool009ooool01Ol0VOooooooooooo`00001loooo002O
oooo00Go09Woooooooooool00000O?ooo`00Woooo`05o`2Ioooooooooooo000007coool009ooool0
1?l0VOooooooooooo`80001koooo002Ooooo00Go09Woooooooooool00000O?ooo`00Woooo`05o`2I
oooooooooooo000007coool009ooool01Ol0VOooooooooooo`00001loooo002Ooooo00Go09Wooooo
ooooool00000O?ooo`00WOooo`<00003oooo00<0003oooooool0N_ooo`00W_ooo`030000o`2Ioooo
00;oool00`000?ooooooo`1joooo002Koooo1@0000?oool30000N_ooo`00Voooo`040000oooooooo
0000POooo`00W?ooo`030000oooo0000087oool009goool20000POooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0<oooo1@0000;oool200000oooo`@00003oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00005oooo00<0003oooooool01oooo`030000oooooooo00Coool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`08oooo00<0003ooooo
ool01?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?ooo`030000oooooooo
00Woool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
01Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55972 .12361 L
.56446 .12361 L
.56706 .12361 L
.56834 .12361 L
.56951 .12361 L
.57063 .12361 L
s
.57063 .12361 m
.5711 .61803 L
s
0 .4 1 r
.02381 .12369 m
.04262 .12372 L
.06244 .12377 L
.07286 .1238 L
.08255 .12384 L
.09388 .12389 L
.10458 .12395 L
.125 .1241 L
.14357 .12429 L
.16355 .12458 L
.18199 .12496 L
.20071 .1255 L
.21136 .12589 L
.22134 .12634 L
.24158 .12753 L
.26011 .12906 L
.27909 .13125 L
.28984 .13287 L
.29982 .13467 L
.32034 .13955 L
.33895 .14582 L
.35819 .15491 L
.36904 .16158 L
.37901 .16897 L
.39944 .18889 L
.40456 .19513 L
.40941 .2016 L
.41152 .20459 L
.41259 .20614 L
.41376 .20622 L
.41503 .20611 L
.41623 .20601 L
.4185 .2058 L
.43683 .20384 L
.45647 .20094 L
.47666 .19678 L
.49516 .19156 L
.51408 .18439 L
.53479 .17374 L
.5544 .16004 L
.56004 .15525 L
.56537 .15031 L
.5677 .148 L
.56897 .1467 L
.57016 .14545 L
.57144 .12361 L
.57213 .12361 L
.57286 .12361 L
.57416 .12361 L
.57535 .12361 L
Mistroke
.57664 .12361 L
.57786 .12361 L
.57895 .12361 L
.58013 .12361 L
.58142 .12361 L
.58278 .12361 L
.58522 .12361 L
.59437 .12361 L
.61511 .12361 L
.65313 .12361 L
.69361 .12361 L
.73257 .12361 L
.77398 .12361 L
.81388 .12361 L
.85226 .12361 L
.8931 .12361 L
.93241 .12361 L
.97022 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00@0003oooooooooool606Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko
00P0I_l00`00001Vo`1Vo`0406Ko0oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Dco`000`1Voc?o00000009oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`00:_ooo`030000oooooooo02?oool306Ko00<00000I_l0I_l00`1Vob;oool0
0`000?ooooooo`06oooo100001Tco`000`1Voc?o0000000Woooo00<0003oooooool09_ooo`030000
oooooooo02Woool005Woool606Ko:Oooo`@0000E<ol000<0I_lco`000000O?ooo`00Goooo`@0I_lY
oooo00<0000co`0co`004S?o000306Ko<ol0000007coool006?oool206Ko:?ooo`80000B<ol000<0
I_lco`000000O?ooo`00IOooo`<0I_lWoooo00<0000co`0co`003S?o0080I_l00c?o00000?ooo`1k
oooo001Xoooo0P1VobKoool00`0003?o03?o000=<ol000<0I_oo09Tco`000P0007_oool006[oool2
06Ko9Oooo`80000;<ol00P1Vo`04<ol0o`2I<ol00000O?ooo`00K?ooo`80I_lUoooo00<0000co`0c
o`001c?o000706Ko<ol0<ol0<ol0o`2I<ol0000007coool006koool00`1Vooooooooo`0Roooo00<0
000co`0co`001c?o000706Ko<ol0<ol0<ol0o`2I<ol0000007coool006ooool00`1Vooooooooo`0R
oooo00<0000co`0co`0013?o0080I_l4<ol000?o09Tco`000000O?ooo`00L?ooo`0306Kooooooooo
027oool00`0003?o03?o0002<ol00P1Vo`Hco`000ol0VC?o0000001loooo001aoooo00<0I_oooooo
ool08Oooo`040000<ol0<ol006Ko23?o0004o`2I<ol000000000Noooo`00L_ooo`0306Kooooooooo
023oool00`00001Vo`1Vo`09<ol000?o09Tco`000000O?ooo`00Loooo`0306Kooooooooo01koool2
06Ko00<0000co`0co`0023?o0003o`2I<ol0000007coool007Coool00`1Vooooooooo`0Koooo0P1V
o`;oool00`0003?o03?o0008<ol000?o09Tco`000000O?ooo`00MOooo`0306Kooooooooo01Soool2
06Ko1Oooo`030000<ol0<ol000Lco`000ol0VC?o0000001loooo001foooo00<0I_ooooooool04ooo
o`@0I_l7oooo00<0000co`0co`001c?o0003o`2I<ol0000007coool007Ooool00`1Vooooooooo`0=
oooo1@1Vo`coool00`0003?o03?o0006<ol000Co09Tco`000000001koooo001hoooo00<0I_oooooo
ool01oooo`D0I_lAoooo00<0000co`0co`001S?o0003o`2I<ol0000007coool007Woool906Ko5_oo
o`030000<ol0<ol000Hco`000ol0VC?o0000001loooo002Ioooo00<0000co`0co`001C?o0003o`2I
<ol0000007coool009Woool00`0003?o03?o0005<ol000?o09Tco`000000O?ooo`00VOooo`030000
<ol0<ol000Dco`000ol0VC?o0000001loooo002Ioooo00<0000co`0co`001C?o0004o`2I<ol00000
0000Noooo`00V_ooo`030000<ol0<ol000@co`000ol0VC?o0000001loooo002Joooo00<0000co`0c
o`0013?o0003o`2I<ol0000007coool009[oool00`0003?o03?o0004<ol000?o09Tco`000000O?oo
o`00V_ooo`030000<ol0<ol000@co`000ol0VC?o0000001loooo002Koooo1@000004<ol0o`2I<ol0
0000O?ooo`00Voooo`030000<ol0000000<co`000ol0VC?o0000001loooo002Koooo00<0000co`00
00000c?o0003o`2I<ol000000080001joooo002Loooo0P0000<co`000ol0VC?o0000001loooo002L
oooo0P0000<co`000ol0VC?o0000001loooo002Loooo0P0000<co`000ol0VC?o0000001loooo002L
oooo00<0000co`0co`000S?o0003o`2I<ol0000007coool009coool00`0003?o03?o0002<ol000?o
09Tco`000000O?ooo`00W?ooo`030000<ol0<ol0008co`001?l0VC?o0000000007_oool009goool0
1`0003?o03?o03?o0?l0VC?o0000001loooo002Moooo00L0000co`0co`0co`3o09Tco`000000O?oo
o`00WOooo`070000<ol0<ol0<ol0o`2I<ol0000007coool009goool01`0003?o03?o03?o0?l0VC?o
0000001loooo002Moooo00L0000co`0co`0co`3o09Tco`000000O?ooo`00WOooo`060000<ol0<ol0
<ol0o`2I<ol00P0007_oool009goool01`0003?o03?o03?o0?l0VC?o0000001loooo002Moooo00L0
000co`0co`0co`3o09Tco`000000O?ooo`00W_ooo`060000<ol0<ol0o`2I<ol00000O?ooo`00W_oo
o`060000<ol0<ol0o`2I<ol00000O?ooo`00W_ooo`060000<ol0<ol0o`2I<ol00000O?ooo`00W_oo
o`060000<ol0<ol0o`2I<ol00000O?ooo`00W_ooo`050000<ol0<ol0o`2I<ol00080001koooo002N
oooo00H0000co`0co`3o09Tco`00001loooo002Noooo00H0000co`0co`3o09Tco`00001loooo002N
oooo00H0000co`0co`3o09Tco`00001loooo002Noooo00H0000co`0co`3o09Tco`00001loooo002N
oooo00H0000co`0co`3o09Tco`00001loooo002Noooo00D0000co`0co`3o09Tco`000P0007_oool0
09ooool01@0003?o0?l0VC?o0000001loooo002Ooooo00D0000co`3o09Tco`000000O?ooo`00Wooo
o`050000<ol0o`2I<ol0000007coool009_oool5000000@co`3o09Tco`00001loooo002Koooo00T0
003oooooooooool0000co`3o09Tco`000000O?ooo`00W?ooo`070000oooooooo0000<ol0o`2I<ol0
00<0001joooo002Moooo00L0003oool0000co`3o09Tco`000000O?ooo`00Voooo`030000oooooooo
0080000013?o0?l0VC?o000007coool009coool2000000Koool0000co`3o09Tco`00001loooo002O
oooo00D0000co`3o09Tco`000000O?ooo`00X?ooo`040000o`2I<ol00000O?ooo`00X?ooo`030000
o`2I<ol00080001koooo002Poooo00@0003o09Tco`00001loooo002Poooo00@0003o09Tco`00001l
oooo002Poooo00@0003o09Tco`00001loooo002Poooo00@0003o09Tco`00001loooo002Poooo00@0
003o09Tco`00001loooo002Poooo00@0003o09Tco`00001loooo002Qoooo00Co09Tco`000000001k
oooo002Qoooo00?o09Tco`000000O?ooo`00XOooo`03o`2I<ol0000007coool00:7oool00ol0VC?o
0000001loooo002Qoooo00?o09Tco`000000O?ooo`00XOooo`03o`2I<ol0000007coool00:7oool0
1?l0VC?o0000000007_oool00:7oool00ol0VC?o0000001loooo002Qoooo00?o09Tco`000000O?oo
o`00XOooo`03o`2I<ol0000007coool00:7oool00ol0VC?o0000001loooo002Qoooo00?o09Tco`00
0000O?ooo`00XOooo`04o`2I<ol000000000Noooo`00XOooo`03o`2I<ol0000007coool00:7oool0
0ol0VC?o0000001loooo002Qoooo00?o09Tco`000000O?ooo`00W?ooo`800003oooo00?o09Tco`00
0000O?ooo`00Voooo`040000oooooooo00000_ooo`03o`2I<ol0000007coool009goool01P000?oo
ooooooooool0VC?o00<0001joooo002Noooo00H0003ooooooooo09Tco`00001loooo002Koooo00@0
003oooooool00002oooo00?o09Tco`000000O?ooo`00W?ooo`800003oooo00?o09T000000000O?oo
o`00XOooo`03o`2I0000000007coool00:7oool00ol0V@000000001loooo002Qoooo00?o09T00000
0000O?ooo`00XOooo`04o`2I000000000000Noooo`00XOooo`03o`2I0000000007coool00:7oool0
0ol0V@000000001loooo002Qoooo00?o09T000000000O?ooo`00XOooo`03o`2I0000000007coool0
0:7oool00ol0V@000000001loooo002Qoooo00Co09T000000000001koooo002Qoooo00?o09T00000
0000O?ooo`00XOooo`03o`2I0000000007coool00:7oool00ol0V@000000001loooo002Qoooo00?o
09T000000000O?ooo`00XOooo`03o`2I0000000007coool00:7oool01?l0V@000000000007_oool0
0:7oool00ol0VOooo`00001loooo002Qoooo00?o09Woool00000O?ooo`00XOooo`03o`2Ioooo0000
07coool00:7oool00ol0VOooo`00001loooo002Qoooo00?o09Woool00000O?ooo`00XOooo`04o`2I
oooo00000000Noooo`00XOooo`03o`2Ioooo000007coool00:7oool00ol0VOooo`00001loooo002Q
oooo00?o09Woool00000O?ooo`00XOooo`03o`2Ioooo000007coool009goool3000000Cooooo09Wo
ool0001loooo002Noooo00H0003ooooooooo09Woool0001loooo002Koooo1@000003ooooo`2Ioooo
00<0001joooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool00000POooo`00WOoo
o`800021oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800003
oooo1@0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`09oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Doooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000005oooo`030000oooooooo00Woool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.56817 .12361 L
.57355 .12361 L
.57618 .12361 L
.57734 .12361 L
.57861 .12361 L
.57931 .12361 L
s
.57931 .12361 m
.57956 .61803 L
s
0 .4 1 r
.02381 .12368 m
.04262 .1237 L
.06244 .12374 L
.07286 .12377 L
.08255 .1238 L
.09388 .12385 L
.10458 .1239 L
.125 .12403 L
.14357 .12419 L
.16355 .12444 L
.18199 .12477 L
.20071 .12522 L
.21136 .12556 L
.22134 .12594 L
.24158 .12696 L
.26011 .12827 L
.27909 .13014 L
.28984 .13152 L
.29982 .13306 L
.32034 .13724 L
.33895 .1426 L
.35819 .15037 L
.36904 .15607 L
.37901 .16239 L
.39784 .17785 L
.40853 .18924 L
.41371 .19559 L
.4185 .20202 L
.41975 .20379 L
.42093 .20503 L
.42215 .2049 L
.42351 .20475 L
.42895 .20413 L
.43885 .20283 L
.45741 .19972 L
.47759 .19504 L
.4961 .18914 L
.51502 .18098 L
.53572 .16876 L
.55533 .15277 L
.56631 .14117 L
.57628 .12823 L
.57749 .12646 L
.57879 .1245 L
.58001 .12361 L
.58113 .12361 L
.58358 .12361 L
.58626 .12361 L
.59547 .12361 L
.61626 .12361 L
Mistroke
.65603 .12361 L
.69427 .12361 L
.73497 .12361 L
.77415 .12361 L
.81578 .12361 L
.8559 .12361 L
.89451 .12361 L
.93556 .12361 L
.9751 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00@0003oooooooooool606Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko
00P0I_l00`00001Vo`1Vo`0406Ko0oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`00:_ooo`030000oooooooo02?oool306Ko00<00000I_l0I_l01@1Vob3oool0
0`000?ooooooo`06oooo100001Xco`000`1Vo`000?ooo`0Voooo00<0003oooooool09_ooo`030000
oooooooo02Woool005_oool406Ko:Oooo`@0000E<ol000<0I_lco`000000O?ooo`00Goooo`D0I_lX
oooo00<0000co`0co`004S?o000306Ko<ol0000007coool006Coool406Ko9Oooo`80000A<ol000@0
I_lco`0co`00001loooo001Xoooo0P1VobGoool00`0003?o03?o000=<ol000D0I_lco`0co`0co`00
0000O?ooo`00J_ooo`80I_lToooo00<0000co`0co`002c?o000306Ko<ol0<ol0008co`020000Nooo
o`00K?ooo`80I_lSoooo0P0000Xco`000`1Voc?o03?o0003<ol000<0003oooooool0N_ooo`00K_oo
o`0306Kooooooooo02;oool00`0003?o03?o0006<ol000<0I_lco`0co`0013?o00030000oooooooo
07[oool006ooool206Ko8_ooo`030000<ol0<ol000@co`0206Ko1c?o00030000oooooooo07[oool0
077oool00`1Vooooooooo`0Poooo00<0000co`0co`000S?o000306Ko<ol0<ol000Lco`000`000?oo
ooooo`1joooo001boooo0P1Vob3oool01@0003?o03?o03?o001Vo`0:<ol000<0003oooooool0N_oo
o`00M?ooo`0306Kooooooooo01koool00`00001Vo`1Vo`0;<ol00P0007_oool007Goool00`1Voooo
ooooo`0Loooo0P1Vo`dco`000`000?ooooooo`1joooo001foooo00<0I_ooooooool06Oooo`80I_l2
oooo00<0000co`0co`002S?o00030000oooooooo07[oool007Ooool00`1Vooooooooo`0Foooo0P1V
o`Coool00`0003?o03?o000:<ol000<0003oooooool0N_ooo`00N?ooo`0306Kooooooooo01;oool3
06Ko1oooo`030000<ol0<ol000Tco`000`000?ooooooo`1joooo001hoooo00<0I_ooooooool04?oo
o`80I_l:oooo00<0000co`0co`002C?o00030000oooooooo07[oool007Woool00`1Vooooooooo`0;
oooo101Vo`goool00`0003?o03?o0008<ol00P0007_oool007[oool00`1Vooooooooo`02oooo201V
oa7oool00`0003?o03?o0008<ol000<0003oooooool0N_ooo`00Noooo`@0I_lIoooo00<0000co`0c
o`0023?o00030000oooooooo07[oool009Woool00`0003?o03?o0007<ol000<0003oooooool0N_oo
o`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`1joooo002Ioooo00<0000co`0co`001c?o
00030000oooooooo07[oool009Woool00`0003?o03?o0007<ol00P0007_oool009[oool00`0003?o
03?o0006<ol000<0003oooooool0N_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1j
oooo002Joooo00<0000co`0co`001S?o00030000oooooooo07[oool009[oool00`0003?o03?o0006
<ol000<0003oooooool0N_ooo`00Voooo`D00003<ol000<0003oooooool0N_ooo`00Voooo`030000
<ol0000000Dco`000`000?ooooooo`1joooo002Koooo00<0000co`0000001C?o00<0001joooo002L
oooo0P0000Dco`000`000?ooooooo`1joooo002Loooo0P0000Dco`000`000?ooooooo`1joooo002L
oooo0P0000Dco`000`000?ooooooo`1joooo002Loooo00<0000co`0co`0013?o00030000oooooooo
07[oool009coool00`0003?o03?o0004<ol000<0003oooooool0N_ooo`00W?ooo`030000<ol0<ol0
00@co`020000Noooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo002Moooo00<0
000co`0co`000c?o00030000oooooooo07[oool009goool00`0003?o03?o0003<ol000<0003ooooo
ool0N_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1joooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo07[oool009goool00`0003?o03?o0003<ol00P0007_oool009goool0
0`0003?o03?o0003<ol000<0003oooooool0N_ooo`00WOooo`030000<ol0<ol000<co`000`000?oo
ooooo`1joooo002Noooo00<0000co`0co`000S?o00030000oooooooo07[oool009koool00`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1j
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo07[oool009koool00`0003?o03?o0002
<ol00P0007_oool009koool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`1joooo002Noooo00<0000co`0co`000S?o00030000oooooooo
07[oool009koool00`0003?o03?o0002<ol000<0003oooooool0N_ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`1joooo002Noooo00<0000co`0co`000S?o0080001koooo002Ooooo00D0
000co`0co`0co`000000O?ooo`00Woooo`050000<ol0<ol0<ol0000007coool009ooool01@0003?o
03?o03?o0000001loooo002Koooo1@0000<co`000`000?ooooooo`1joooo002Koooo00D0003ooooo
ooooool000000c?o00030000oooooooo07[oool009coool010000?ooooooo`0000<co`030000N_oo
o`00WOooo`030000oooo000000<co`000`000?ooooooo`1joooo002Koooo00<0003oooooool00P00
00<co`000`000?ooooooo`1joooo002Loooo0P000003oooo0000<ol0008co`000`000?ooooooo`1j
oooo002Ooooo00D0000co`0co`0co`000000O?ooo`00X?ooo`040000<ol0<ol00000O?ooo`00X?oo
o`030000<ol0<ol00080001koooo002Poooo00@0000co`0co`00001loooo002Poooo00@0000co`0c
o`00001loooo002Poooo00@0000co`0co`00001loooo002Poooo00@0000co`0co`00001loooo002P
oooo00@0000co`0co`00001loooo002Poooo00@0000co`0co`00001loooo002Qoooo00@0000co`00
0000001koooo002Qoooo00<0000co`000000O?ooo`00XOooo`030000<ol0000007coool00:7oool0
0`0003?o0000001loooo002Qoooo00<0000co`000000O?ooo`00XOooo`030000<ol0000007coool0
0:7oool0100003?o0000000007_oool00:7oool00`0003?o0000001loooo002Qoooo00<0000co`00
0000O?ooo`00XOooo`030000<ol0000007coool00:7oool00`0003?o0000001loooo002Qoooo00<0
000co`000000O?ooo`00XOooo`040000<ol000000000Noooo`00XOooo`030000<ol0000007coool0
0:7oool00`0003?o0000001loooo002Qoooo00<0000co`000000O?ooo`00W?ooo`800003oooo00<0
000co`000000O?ooo`00Voooo`040000oooooooo00000_ooo`030000<ol0000007coool009goool0
1P000?ooooooooooo`0003?o00<0001joooo002Noooo00H0003oooooool0000co`00001loooo002K
oooo00@0003oooooool00002oooo00<0000co`000000O?ooo`00W?ooo`800004oooo0P0007coool0
0:;oool20000O?ooo`00X_ooo`80001loooo002Roooo0P0007coool00:;oool30000Noooo`00X_oo
o`80001loooo002Roooo0P0007coool00:;oool20000O?ooo`00X_ooo`80001loooo002Roooo0P00
07coool00:;oool30000Noooo`00X_ooo`80001loooo002Roooo0P0007coool00:;oool20000O?oo
o`00X_ooo`80001loooo002Roooo0P0007coool00:;oool30000Noooo`00Xoooo`030000oooooooo
07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000
oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo0P0007_oool00:?oool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool0
0`000?ooooooo`1joooo002Moooo0`0000?oool00`000?ooooooo`1joooo002Noooo00<0003ooooo
ool00_ooo`030000oooooooo07[oool009_oool500000oooo`<0001joooo002Koooo00@0003ooooo
ool00021oooo002Loooo00<0003oool00000POooo`00WOooo`800021oooo003ooooo8Oooo`00oooo
ob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo
00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00coool500000_ooo`800004oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005
oooo00<0003oooooool02?ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0
003oooooool05Oooo`030000oooooooo00Woool00`000?ooooooo`1joooo001koooo00<0003ooooo
ool01@0001Coool00`000?ooooooo`08oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000001Ooool00`000?ooooooo`08oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo
01Ooool200002Oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.56817 .12361 L
.57861 .12361 L
.58157 .12361 L
.58436 .12361 L
.58558 .12361 L
.58686 .12361 L
s
.58686 .12361 m
.58713 .61803 L
s
0 .4 1 r
.02381 .12367 m
.04262 .12369 L
.06244 .12372 L
.07286 .12375 L
.08255 .12377 L
.09388 .12381 L
.10458 .12385 L
.125 .12396 L
.14357 .1241 L
.16355 .12432 L
.18199 .12459 L
.20071 .12498 L
.21136 .12527 L
.22134 .12559 L
.24158 .12646 L
.26011 .12757 L
.27909 .12916 L
.28984 .13034 L
.29982 .13165 L
.32034 .1352 L
.33895 .13975 L
.35819 .14636 L
.36904 .15121 L
.37901 .15658 L
.39784 .16973 L
.40853 .17941 L
.4185 .19028 L
.42351 .19651 L
.42615 .20002 L
.42759 .20202 L
.4283 .20302 L
.42895 .20335 L
.43013 .20319 L
.4314 .20302 L
.4341 .20263 L
.43885 .2019 L
.45741 .19843 L
.47633 .19357 L
.49703 .18616 L
.51665 .1764 L
.5376 .16186 L
.55751 .14235 L
.56799 .12876 L
.5693 .12684 L
.57054 .12498 L
.57123 .12392 L
.57197 .12361 L
.57328 .12361 L
.57403 .12361 L
.57484 .12361 L
Mistroke
.5756 .12361 L
.57628 .12361 L
.57698 .12361 L
.57773 .12361 L
.57844 .12361 L
.57909 .12361 L
.5803 .12361 L
.58159 .12361 L
.58392 .12361 L
.58922 .12361 L
.5999 .12361 L
.61908 .12361 L
.66049 .12361 L
.70039 .12361 L
.73877 .12361 L
.7796 .12361 L
.81892 .12361 L
.85672 .12361 L
.89698 .12361 L
.93572 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01_ooo`0306Ko000006Ko00P0I_l00`00001Vo`1Vo`08
06Ko00<00000I_l0I_l01`1Vo`03000006Kooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Dco`001@1Voc?o00000?ooool0V@07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooo`1Vo`0906Ko7?ooo`030000
oooooooo00Koool4000063?o000606Ko<ol0<ol00000ooooo`2I9Oooo`030000oooooooo02Koool0
0`000?ooooooo`0Yoooo001Ooooo1@1VobCoool400004c?o000706Ko<ol0<ol0<ol00000ooooo`2I
07[oool006Coool406Ko9?ooo`030000<ol0<ol0010co`001`1Voc?o03?o03?o00000?ooool0V@1j
oooo001Xoooo0P1Vob?oool200003c?o000306Ko<ol0<ol0008co`000`000?ooool0V@1joooo001Z
oooo0`1Vob;oool00`0003?o03?o000;<ol000<0I_lco`0co`000c?o00030000ooooo`2I07[oool0
06goool206Ko8Oooo`030000<ol0<ol000Tco`000`1Voc?o03?o0004<ol00P000003o`2Ioooooooo
07Soool006ooool00`1Vooooooooo`0Ooooo0P0000Pco`000`1Voc?o03?o0005<ol000<0003ooooo
09T0N_ooo`00L?ooo`0306Kooooooooo023oool00`0003?o03?o0004<ol000<0I_lco`0co`001S?o
00030000ooooo`2I07[oool0077oool206Ko8?ooo`030000<ol0<ol000<co`000`1Voc?o03?o0007
<ol000<0003ooooo09T0N_ooo`00Loooo`80I_lOoooo00<0000co`0co`000P1Vo`Xco`000`000?oo
ool0V@1joooo001eoooo00<0I_ooooooool07?ooo`030000<ol006Ko00`co`000`000?ooool0V@1j
oooo001foooo00<0I_ooooooool06oooo`80I_l=<ol00P000003o`2Ioooooooo07Soool007Ooool0
0`1Vooooooooo`0Hoooo0P1Vo`03oooo0000<ol000`co`000`000?ooool0V@1joooo001hoooo00<0
I_ooooooool05Oooo`80I_l4oooo00<0000co`0co`002S?o00030000ooooo`2I07[oool007Woool0
0`1Vooooooooo`0Aoooo0`1Vo`Koool00`0003?o03?o000:<ol000<0003ooooo09T0N_ooo`00N_oo
o`0306Kooooooooo00koool206Ko2_ooo`030000<ol0<ol000Tco`000`000?ooool0V@1joooo001k
oooo00<0I_ooooooool02Oooo`@0I_l<oooo00<0000co`0co`002C?o00030000ooooo`2I07[oool0
07coool00`1Vooooooooo`03oooo1@1Voa7oool00`0003?o03?o0008<ol00P000003o`2Ioooooooo
07Soool007coool606Ko5_ooo`030000<ol0<ol000Pco`000`000?ooool0V@1joooo001moooo0P1V
oaWoool00`0003?o03?o0008<ol000<0003ooooo09T0N_ooo`00VOooo`030000<ol0<ol000Lco`00
0`000?ooool0V@1joooo002Ioooo00<0000co`0co`001c?o00030000ooooo`2I07[oool009Woool0
0`0003?o03?o0007<ol000<0003ooooo09T0N_ooo`00VOooo`030000<ol0<ol000Lco`02000000?o
09Woooooool0N?ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooool0V@1joooo002Joooo00<0
000co`0co`001S?o00030000ooooo`2I07[oool009[oool00`0003?o03?o0006<ol000<0003ooooo
09T0N_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooool0V@1joooo002Koooo1@0000<co`00
0`000?ooool0V@1joooo002Koooo00<0000co`0000001C?o00030000ooooo`2I07[oool009_oool0
0`0003?o00000005<ol00`0007[oool009coool200001C?o00030000ooooo`2I07[oool009coool2
00001C?o00030000ooooo`2I07[oool009coool200001C?o00030000ooooo`2I07[oool009coool0
0`0003?o03?o0004<ol000<0003ooooo09T0N_ooo`00W?ooo`030000<ol0<ol000@co`000`000?oo
ool0V@1joooo002Loooo00<0000co`0co`0013?o008000000ol0VOooooooo`1hoooo002Moooo00<0
000co`0co`000c?o00030000ooooo`2I07[oool009goool00`0003?o03?o0003<ol000<0003ooooo
09T0N_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooool0V@1joooo002Moooo00<0000co`0c
o`000c?o00030000ooooo`2I07[oool009goool00`0003?o03?o0003<ol000<0003ooooo09T0N_oo
o`00WOooo`030000<ol0<ol000<co`02000000?o09Woooooool0N?ooo`00WOooo`030000<ol0<ol0
00<co`000`000?ooool0V@1joooo002Moooo00<0000co`0co`000c?o00030000ooooo`2I07[oool0
09koool00`0003?o03?o0002<ol000<0003ooooo09T0N_ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooool0V@1joooo002Noooo00<0000co`0co`000S?o00030000ooooo`2I07[oool009koool0
0`0003?o03?o0002<ol000<0003ooooo09T0N_ooo`00W_ooo`030000<ol0<ol0008co`02000000?o
09Woooooool0N?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooool0V@1joooo002Noooo00<0
000co`0co`000S?o00030000ooooo`2I07[oool009koool00`0003?o03?o0002<ol000<0003ooooo
09T0N_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooool0V@1joooo002Noooo00<0000co`0c
o`000S?o00030000ooooo`2I07[oool009koool00`0003?o03?o0002<ol00P000003o`2Ioooooooo
07Soool009ooool01`0003?o03?o03?o00000?ooool0V@1joooo002Ooooo00L0000co`0co`0co`00
003ooooo09T0N_ooo`00Woooo`070000<ol0<ol0<ol00000ooooo`2I07[oool009_oool500000c?o
00030000ooooo`2I07[oool009_oool01@000?ooooooooooo`000003<ol000<0003ooooo09T0N_oo
o`00W?ooo`040000oooooooo00000c?o00<0001joooo002Moooo00<0003oool000000c?o00030000
ooooo`2I07[oool009_oool00`000?ooooooo`0200000c?o00030000ooooo`2I07[oool009coool2
000000?oool0000co`000S?o00030000ooooo`2I07[oool009ooool01`0003?o03?o03?o00000?oo
ool0V@1joooo002Poooo00H0000co`0co`00003ooooo09Ujoooo002Poooo00<0000co`0co`000P00
0003o`2Ioooooooo07Soool00:3oool01P0003?o03?o00000?ooool0VG[oool00:3oool01P0003?o
03?o00000?ooool0VG[oool00:3oool01P0003?o03?o00000?ooool0VG[oool00:3oool01P0003?o
03?o00000?ooool0VG[oool00:3oool01P0003?o03?o00000?ooool0VG[oool00:3oool01P0003?o
03?o00000?ooool0VG[oool00:7oool01@0003?o000000000?l0V@1joooo002Qoooo00D0000co`00
003ooooo09T0N_ooo`00XOooo`050000<ol00000ooooo`2I07[oool00:7oool01@0003?o00000?oo
ool0V@1joooo002Qoooo00D0000co`00003ooooo09T0N_ooo`00XOooo`050000<ol00000ooooo`2I
07[oool00:7oool01@0003?o000000000?l0V@1joooo002Qoooo00D0000co`00003ooooo09T0N_oo
o`00XOooo`050000<ol00000ooooo`2I07[oool00:7oool01@0003?o00000?ooool0V@1joooo002Q
oooo00D0000co`00003ooooo09T0N_ooo`00XOooo`050000<ol00000ooooo`2I07[oool00:7oool0
1@0003?o000000000?l0V@1joooo002Qoooo00D0000co`00003ooooo09T0N_ooo`00XOooo`050000
<ol00000ooooo`2I07[oool00:7oool01@0003?o00000?ooool0V@1joooo002Loooo0P0000?oool0
1@0003?o00000?ooool0V@1joooo002Koooo00@0003oooooool00002oooo00D0000co`00003ooooo
09T0N_ooo`00WOooo`060000oooooooooooo0000<ol00`0007[oool009koool020000?ooooooo`00
03?o00000?ooool0VG[oool009_oool010000?ooooooo`0000;oool01@0003?o00000?ooool0V@1j
oooo002Loooo0P0000Coool2000000?ooooo09Woool0NOooo`00X_ooo`8000000oooool0VOooo`1i
oooo002Roooo0P000003ooooo`2Ioooo07Woool00:;oool2000000?ooooo09Woool0NOooo`00X_oo
o`<000000ol0VOooooooo`1hoooo002Roooo0P000003ooooo`2Ioooo07Woool00:;oool2000000?o
oooo09Woool0NOooo`00X_ooo`8000000oooool0VOooo`1ioooo002Roooo0P000003ooooo`2Ioooo
07Woool00:;oool2000000?ooooo09Woool0NOooo`00X_ooo`<000000ol0VOooooooo`1hoooo002R
oooo0P000003ooooo`2Ioooo07Woool00:;oool2000000?ooooo09Woool0NOooo`00X_ooo`800000
0oooool0VOooo`1ioooo002Roooo0P000003ooooo`2Ioooo07Woool00:;oool2000000?ooooo09Wo
ool0NOooo`00X_ooo`<000000ol0VOooooooo`1hoooo002Soooo00<0003ooooo09T0N_ooo`00Xooo
o`030000ooooo`2I07[oool00:?oool00`000?ooool0V@1joooo002Soooo00<0003ooooo09T0N_oo
o`00Xoooo`030000ooooo`2I07[oool00:?oool2000000?o09Woooooool0N?ooo`00Xoooo`030000
ooooo`2I07[oool00:?oool00`000?ooool0V@1joooo002Soooo00<0003ooooo09T0N_ooo`00Xooo
o`030000ooooo`2I07[oool009goool300000oooo`030000ooooo`2I07[oool009koool00`000?oo
ooooo`02oooo00<0003ooooo09T0N_ooo`00Voooo`D00003oooo0`0007[oool009_oool010000?oo
ooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool300001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400000oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1h
oooo001goooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Woool3
00001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500004_ooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.57861 .12361 L
.58392 .12361 L
.58957 .12361 L
.59232 .12361 L
.59367 .12361 L
.59491 .12361 L
s
.59491 .12361 m
.59536 .61803 L
s
0 .4 1 r
.02381 .12366 m
.04262 .12368 L
.06244 .12371 L
.07286 .12373 L
.08255 .12375 L
.09388 .12378 L
.10458 .12382 L
.125 .12391 L
.14357 .12403 L
.16355 .12421 L
.18199 .12444 L
.20071 .12477 L
.21136 .12501 L
.22134 .12528 L
.24158 .12601 L
.26011 .12695 L
.27909 .1283 L
.28984 .12929 L
.29982 .13039 L
.32034 .13339 L
.33895 .13723 L
.35819 .14281 L
.36904 .1469 L
.37901 .15144 L
.39784 .16253 L
.40853 .1707 L
.4185 .17988 L
.42895 .19141 L
.43145 .1945 L
.4341 .19793 L
.43518 .19939 L
.43636 .20099 L
.43765 .201 L
.43885 .20079 L
.44774 .19907 L
.45741 .19688 L
.47745 .19101 L
.49855 .18226 L
.51829 .17076 L
.53666 .15603 L
.55539 .13521 L
.56053 .12808 L
.56177 .12623 L
.56246 .12519 L
.56311 .12419 L
.56388 .12361 L
.56459 .12361 L
.56524 .12361 L
.56596 .12361 L
.56725 .12361 L
Mistroke
.56841 .12361 L
.56906 .12361 L
.56975 .12361 L
.57102 .12361 L
.57221 .12361 L
.57346 .12361 L
.57453 .12361 L
.5757 .12361 L
.57639 .12361 L
.57714 .12361 L
.57784 .12361 L
.5785 .12361 L
.57973 .12361 L
.58104 .12361 L
.58675 .12361 L
.59705 .12361 L
.6172 .12361 L
.655 .12361 L
.69526 .12361 L
.734 .12361 L
.77519 .12361 L
.81487 .12361 L
.85303 .12361 L
.89364 .12361 L
.93274 .12361 L
.97429 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01_ooo`0306Ko000006Ko00P0I_l00`00001Vo`1Vo`08
06Ko00<00000I_l0I_l01`1Vo`03000006Kooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000<co`001@1Voc?o03?o03?o00000003oooo00?o09Woooooool00oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0003oool0
I_l02@1Voacoool00`000?ooooooo`06oooo100001Hco`000`1Voc?o03?o0002<ol000D0003ooooo
oooooooo09T08oooo`030000oooooooo02Koool00`000?ooooooo`0Yoooo001Ooooo1@1VobCoool4
00004C?o000306Ko<ol0<ol000<co`001@000?ooooooooooool0V@1hoooo001Toooo1@1Vob?oool0
0`0003?o03?o000=<ol000<0I_lco`0co`0013?o00050000ooooooooooooo`2I07Soool006Woool4
06Ko8?ooo`80000<<ol000<0I_lco`0co`001C?o00050000ooooooooooooo`2I07Soool006goool2
06Ko8?ooo`030000<ol0<ol000Pco`000`1Voc?o03?o0006<ol000D0003ooooooooooooo09T0N?oo
o`00Koooo`80I_lOoooo00<0000co`0co`001c?o000306Ko<ol0<ol000Hco`0200000_ooo`03o`2I
oooooooo07Koool0077oool206Ko7_ooo`800006<ol000<0I_lco`0co`001c?o00050000oooooooo
ooooo`2I07Soool007?oool206Ko7_ooo`030000<ol0<ol0008co`000`1Voc?o03?o0008<ol000D0
003ooooooooooooo09T0N?ooo`00MOooo`0306Kooooooooo01_oool01@0003?o03?o03?o001Vo`0;
<ol000D0003ooooooooooooo09T0N?ooo`00M_ooo`80I_lLoooo00<00000I_l0I_l033?o00050000
ooooooooooooo`2I07Soool007Soool00`1Vooooooooo`0Ioooo00<0I_lco`0co`0033?o00050000
ooooooooooooo`2I07Soool007Woool00`1Vooooooooo`0Foooo0P1Vo`03oooo0000<ol000`co`02
00000_ooo`03o`2Ioooooooo07Koool007Woool00`1Vooooooooo`0Doooo0P1Vo`?oool00`0003?o
03?o000;<ol000D0003ooooooooooooo09T0N?ooo`00N_ooo`0306Kooooooooo017oool206Ko1_oo
o`030000<ol0<ol000Xco`001@000?ooooooooooool0V@1hoooo001koooo00<0I_ooooooool03Ooo
o`<0I_l8oooo00<0000co`0co`002S?o00050000ooooooooooooo`2I07Soool007coool00`1Voooo
ooooo`09oooo0`1Vo`coool00`0003?o03?o0009<ol000D0003ooooooooooooo09T0N?ooo`00OOoo
o`80I_l7oooo0P1Vo`ooool00`0003?o03?o0009<ol000D0003ooooooooooooo09T0N?ooo`00O_oo
o`0306Kooooooooo00?oool206Ko4_ooo`030000<ol0<ol000Pco`0200000_ooo`03o`2Ioooooooo
07Koool007ooool506Ko5?ooo`030000<ol0<ol000Pco`001@000?ooooooooooool0V@1hoooo002H
oooo00<0000co`0co`0023?o00050000ooooooooooooo`2I07Soool009Woool00`0003?o03?o0007
<ol000D0003ooooooooooooo09T0N?ooo`00VOooo`030000<ol0<ol000Lco`001@000?oooooooooo
ool0V@1hoooo002Ioooo00<0000co`0co`001c?o00050000ooooooooooooo`2I07Soool009Woool0
0`0003?o03?o0007<ol00P0000;oool00ol0VOooooooo`1foooo002Joooo00<0000co`0co`001S?o
00050000ooooooooooooo`2I07Soool009[oool00`0003?o03?o0006<ol000D0003ooooooooooooo
09T0N?ooo`00V_ooo`030000<ol0<ol000Hco`001@000?ooooooooooool0V@1hoooo002Joooo00<0
000co`0co`001S?o00050000ooooooooooooo`2I07Soool009_oool500000c?o00050000oooooooo
ooooo`2I07Soool009_oool00`0003?o00000005<ol000D0003ooooooooooooo09T0N?ooo`00Vooo
o`030000<ol0000000Dco`03000000?ooooo09Woool0Moooo`00W?ooo`800005<ol000D0003ooooo
oooooooo09T0N?ooo`00W?ooo`800005<ol000D0003ooooooooooooo09T0N?ooo`00W?ooo`800005
<ol000D0003ooooooooooooo09T0N?ooo`00W?ooo`030000<ol0<ol000@co`001@000?oooooooooo
ool0V@1hoooo002Loooo00<0000co`0co`0013?o00050000ooooooooooooo`2I07Soool009coool0
0`0003?o03?o0004<ol00P0000;oool00ol0VOooooooo`1foooo002Moooo00<0000co`0co`000c?o
00050000ooooooooooooo`2I07Soool009goool00`0003?o03?o0003<ol000D0003ooooooooooooo
09T0N?ooo`00WOooo`030000<ol0<ol000<co`001@000?ooooooooooool0V@1hoooo002Moooo00<0
000co`0co`000c?o00050000ooooooooooooo`2I07Soool009goool00`0003?o03?o0003<ol000D0
003ooooooooooooo09T0N?ooo`00WOooo`030000<ol0<ol000<co`0200000_ooo`03o`2Ioooooooo
07Koool009goool00`0003?o03?o0003<ol000D0003ooooooooooooo09T0N?ooo`00WOooo`030000
<ol0<ol000<co`001@000?ooooooooooool0V@1hoooo002Noooo00<0000co`0co`000S?o00050000
ooooooooooooo`2I07Soool009koool00`0003?o03?o0002<ol000D0003ooooooooooooo09T0N?oo
o`00W_ooo`030000<ol0<ol0008co`001@000?ooooooooooool0V@1hoooo002Noooo00<0000co`0c
o`000S?o00050000ooooooooooooo`2I07Soool009koool00`0003?o03?o0002<ol00P0000;oool0
0ol0VOooooooo`1foooo002Noooo00<0000co`0co`000S?o00050000ooooooooooooo`2I07Soool0
09koool00`0003?o03?o0002<ol000D0003ooooooooooooo09T0N?ooo`00W_ooo`030000<ol0<ol0
008co`001@000?ooooooooooool0V@1hoooo002Noooo00<0000co`0co`000S?o00050000oooooooo
ooooo`2I07Soool009koool00`0003?o03?o0002<ol000D0003ooooooooooooo09T0N?ooo`00W_oo
o`030000<ol0<ol0008co`0200000_ooo`03o`2Ioooooooo07Koool009ooool01@0003?o03?o03?o
00000003oooo00?o09Woooooool0M_ooo`00Woooo`050000<ol0<ol0<ol0000000?oool00ol0VOoo
ooooo`1foooo002Ooooo00D0000co`0co`0co`0000000oooo`03o`2Ioooooooo07Koool009_oool5
00000c?o00050000ooooooooooooo`2I07Soool009_oool01@000?ooooooooooo`000003<ol000D0
003ooooooooooooo09T0N?ooo`00W?ooo`040000oooooooo00000c?o00<000000oooool0VOooo`1g
oooo002Moooo00<0003oool000000c?o00050000ooooooooooooo`2I07Soool009_oool00`000?oo
ooooo`0200000c?o00050000ooooooooooooo`2I07Soool009coool2000000?oool0000co`000S?o
00050000ooooooooooooo`2I07Soool009ooool01@0003?o03?o03?o00000003oooo00?o09Wooooo
ool0M_ooo`00X?ooo`040000<ol0<ol000000oooo`03o`2Ioooooooo07Koool00:3oool00`0003?o
03?o000200000_ooo`03o`2Ioooooooo07Koool00:3oool0100003?o03?o000000?oool00ol0VOoo
ooooo`1foooo002Poooo00@0000co`0co`000003oooo00?o09Woooooool0M_ooo`00X?ooo`040000
<ol0<ol000000oooo`03o`2Ioooooooo07Koool00:3oool0100003?o03?o000000?oool00ol0VOoo
ooooo`1foooo002Poooo00@0000co`0co`000003oooo00?o09Woooooool0M_ooo`00X?ooo`040000
<ol0<ol000000oooo`03o`2Ioooooooo07Koool00:7oool0100003?o0000000000;oool00ol0VOoo
ooooo`1foooo002Qoooo00<0000co`0000000oooo`03o`2Ioooooooo07Koool00:7oool00`0003?o
00000003oooo00?o09Woooooool0M_ooo`00XOooo`030000<ol0000000?oool00ol0VOooooooo`1f
oooo002Qoooo00<0000co`0000000oooo`03o`2Ioooooooo07Koool00:7oool00`0003?o00000003
oooo00?o09Woooooool0M_ooo`00XOooo`040000<ol0000000000_ooo`03o`2Ioooooooo07Koool0
0:7oool00`0003?o00000003oooo00?o09Woooooool0M_ooo`00XOooo`030000<ol0000000?oool0
0ol0VOooooooo`1foooo002Qoooo00<0000co`0000000oooo`03o`2Ioooooooo07Koool00:7oool0
0`0003?o00000003oooo00?o09Woooooool0M_ooo`00XOooo`030000<ol0000000?oool00ol0VOoo
ooooo`1foooo002Qoooo00@0000co`0000000002oooo00?o09Woooooool0M_ooo`00XOooo`030000
<ol0000000?oool00ol0VOooooooo`1foooo002Qoooo00<0000co`0000000oooo`03o`2Ioooooooo
07Koool00:7oool00`0003?o00000003oooo00?o09Woooooool0M_ooo`00W?ooo`800003oooo00<0
000co`0000000oooo`03o`2Ioooooooo07Koool009_oool010000?ooooooo`0000;oool00`0003?o
00000003oooo00?o09Woooooool0M_ooo`00WOooo`060000oooooooooooo0000<ol00`000003oooo
o`2Ioooo07Ooool009koool01P000?ooooooo`0003?o000000?oool00ol0VOooooooo`1foooo002K
oooo00@0003oooooool00002oooo00<0000co`0000000oooo`03o`2Ioooooooo07Koool009coool2
00001?ooo`800003oooo00?o09Woooooool0M_ooo`00X_ooo`800003oooo00?o09Woooooool0M_oo
o`00X_ooo`800003oooo00?o09Woooooool0M_ooo`00X_ooo`800003oooo00?o09Woooooool0M_oo
o`00X_ooo`<00002oooo00?o09Woooooool0M_ooo`00X_ooo`800003oooo00?o09Woooooool0M_oo
o`00X_ooo`800003oooo00?o09Woooooool0M_ooo`00X_ooo`800003oooo00?o09Woooooool0M_oo
o`00X_ooo`800003oooo00?o09Woooooool0M_ooo`00X_ooo`800003oooo00?o09Woooooool0M_oo
o`00X_ooo`<00002oooo00?o09Woooooool0M_ooo`00X_ooo`800003oooo00?o09Woooooool0M_oo
o`00X_ooo`800003oooo00?o09Woooooool0M_ooo`00X_ooo`800003oooo00?o09Woooooool0M_oo
o`00X_ooo`800003oooo00?o09Woooooool0M_ooo`00X_ooo`800003oooo00?o09Woooooool0M_oo
o`00X_ooo`<00002oooo00?o09Woooooool0M_ooo`00Xoooo`050000ooooooooooooo`2I07Soool0
0:?oool01@000?ooooooooooool0V@1hoooo002Soooo00D0003ooooooooooooo09T0N?ooo`00Xooo
o`050000ooooooooooooo`2I07Soool00:?oool01@000?ooooooooooool0V@1hoooo002Soooo0P00
00;oool00ol0VOooooooo`1foooo002Soooo00D0003ooooooooooooo09T0N?ooo`00Xoooo`050000
ooooooooooooo`2I07Soool00:?oool01@000?ooooooooooool0V@1hoooo002Soooo00D0003ooooo
oooooooo09T0N?ooo`00WOooo`<00003oooo00D0003ooooooooooooo09T0N?ooo`00W_ooo`030000
oooooooo00;oool01@000?ooooooooooool0V@1hoooo002Koooo1@0000?oool3000000?ooooo09Wo
ool0Moooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000oooo0000087oool009goool2
0000POooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000Boooo00@0003oooooool00009oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000ooo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59405 .12361 L
.59698 .12361 L
.59975 .12361 L
.60102 .12361 L
.60237 .12361 L
.60307 .12361 L
s
.60307 .12361 m
.60338 .61803 L
s
0 .4 1 r
.02381 .12365 m
.04262 .12366 L
.06244 .12369 L
.07286 .12371 L
.08255 .12372 L
.09388 .12375 L
.10458 .12378 L
.125 .12386 L
.14357 .12396 L
.16355 .12411 L
.18199 .1243 L
.20071 .12458 L
.21136 .12478 L
.22134 .12501 L
.24158 .12561 L
.26011 .1264 L
.27909 .12752 L
.28984 .12835 L
.29982 .12927 L
.32034 .13178 L
.33895 .13499 L
.35819 .13964 L
.36904 .14306 L
.37901 .14685 L
.39784 .15612 L
.40853 .16294 L
.4185 .1706 L
.43714 .18914 L
.44224 .1954 L
.44348 .19701 L
.44418 .19793 L
.44482 .1982 L
.44554 .19804 L
.44629 .19786 L
.44767 .19754 L
.45741 .19504 L
.46755 .19195 L
.47865 .1879 L
.49877 .17828 L
.51838 .16515 L
.53933 .14523 L
.54957 .13238 L
.55238 .12839 L
.55392 .12612 L
.55467 .12498 L
.55535 .12392 L
.55657 .12361 L
.55789 .12361 L
.55857 .12361 L
.55932 .12361 L
Mistroke
.56002 .12361 L
.56068 .12361 L
.56195 .12361 L
.56266 .12361 L
.56332 .12361 L
.56453 .12361 L
.5658 .12361 L
.56695 .12361 L
.56801 .12361 L
.56918 .12361 L
.57044 .12361 L
.57113 .12361 L
.57178 .12361 L
.57248 .12361 L
.57323 .12361 L
.57449 .12361 L
.57521 .12361 L
.57588 .12361 L
.57712 .12361 L
.57826 .12361 L
.57951 .12361 L
.58083 .12361 L
.61899 .12361 L
.6596 .12361 L
.6987 .12361 L
.74025 .12361 L
.78029 .12361 L
.8188 .12361 L
.85977 .12361 L
.89923 .12361 L
.93717 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooooooo1P1Vo`03000006Ko06Ko
00P0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0I_l00`1Vo`Coool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
00050000<ol0<ol0<ol006Ko00Dco`000`000?ooooooo`03oooo00Go09Woooooooooool000002Ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`03
oooo2`1VoaOoool00`000?ooooooo`06oooo100001@co`000`1Voc?o03?o0004<ol000<0003ooooo
ool00oooo`03o`2Ioooooooo01ooool00`000?ooooooo`0Voooo00<0003oooooool0:Oooo`00I?oo
o`D0I_lOoooo1000010co`000`1Voc?o03?o0004<ol000<0003oooooool00oooo`03o`2Ioooooooo
07Coool006Woool406Ko7oooo`030000<ol0<ol000`co`000`1Voc?o03?o0005<ol000<0003ooooo
ool00oooo`03o`2Ioooooooo07Coool006goool206Ko7_ooo`80000;<ol000<0I_lco`0co`001S?o
00030000oooooooo00?oool00ol0VOooooooo`1doooo001_oooo0P1Voakoool00`0003?o03?o0007
<ol000<0I_lco`0co`001c?o00030000oooooooo00?oool00ol0VOooooooo`1doooo001aoooo0P1V
oagoool00`0003?o03?o0005<ol000<0I_lco`0co`0023?o00800004oooo00?o09Woooooool0M?oo
o`00Loooo`80I_lLoooo0P0000@co`000`1Voc?o03?o0009<ol000<0003oooooool00oooo`03o`2I
oooooooo07Coool007Goool206Ko7?ooo`040000<ol0<ol006Ko33?o00030000oooooooo00?oool0
0ol0VOooooooo`1doooo001goooo0P1Voa[oool00`0003?o001Vo`0=<ol000<0003oooooool00ooo
o`03o`2Ioooooooo07Coool007Woool00`1Vooooooooo`0Hoooo00<0I_lco`0co`0033?o00030000
oooooooo00?oool00ol0VOooooooo`1doooo001joooo00<0I_ooooooool05Oooo`80I_l00`0003?o
03?o000<<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool007_oool00`1Vooooooooo`0B
oooo0P1Vo`?oool00`0003?o03?o000;<ol00P0000Coool00ol0VOooooooo`1doooo001loooo00<0
I_ooooooool04?ooo`0306Kooooooooo00?oool00`0003?o03?o000;<ol000<0003oooooool00ooo
o`03o`2Ioooooooo07Coool007goool00`1Vooooooooo`0=oooo0P1Vo`Ooool00`0003?o03?o000:
<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool007koool00`1Vooooooooo`0:oooo0P1V
o`Woool00`0003?o03?o000:<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool007ooool0
0`1Vooooooooo`07oooo0P1Vo`coool00`0003?o03?o0009<ol000<0003oooooool00oooo`03o`2I
oooooooo07Coool007ooool00`1Vooooooooo`04oooo0`1Vo`koool00`0003?o03?o0009<ol000<0
003oooooool00oooo`03o`2Ioooooooo07Coool0083oool606Ko4_ooo`030000<ol0<ol000Pco`02
00001?ooo`03o`2Ioooooooo07Coool009Soool00`0003?o03?o0008<ol000<0003oooooool00ooo
o`03o`2Ioooooooo07Coool009Soool00`0003?o03?o0008<ol000<0003oooooool00oooo`03o`2I
oooooooo07Coool009Woool00`0003?o03?o0007<ol000<0003oooooool00oooo`03o`2Ioooooooo
07Coool009Woool00`0003?o03?o0007<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool0
09Woool00`0003?o03?o0007<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool009Woool0
0`0003?o03?o0007<ol00P0000Coool00ol0VOooooooo`1doooo002Joooo00<0000co`0co`001S?o
00030000oooooooo00?oool00ol0VOooooooo`1doooo002Joooo00<0000co`0co`001S?o00030000
oooooooo00?oool00ol0VOooooooo`1doooo002Joooo00<0000co`0co`001S?o00030000oooooooo
00?oool00ol0VOooooooo`1doooo002Joooo00<0000co`0co`001S?o00030000oooooooo00?oool0
0ol0VOooooooo`1doooo002Koooo1@0000<co`000`000?ooooooo`03oooo00?o09Woooooool0M?oo
o`00Voooo`030000<ol0000000Dco`000`000?ooooooo`03oooo00?o09Woooooool0M?ooo`00Vooo
o`030000<ol0000000Dco`0300000oooo`03o`2Ioooooooo07Coool009coool200001C?o00030000
oooooooo00?oool00ol0VOooooooo`1doooo002Loooo0P0000Dco`000`000?ooooooo`03oooo00?o
09Woooooool0M?ooo`00W?ooo`800005<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool0
09coool00`0003?o03?o0004<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool009coool0
0`0003?o03?o0004<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool009coool00`0003?o
03?o0004<ol00P0000Coool00ol0VOooooooo`1doooo002Moooo00<0000co`0co`000c?o00030000
oooooooo00?oool00ol0VOooooooo`1doooo002Moooo00<0000co`0co`000c?o00030000oooooooo
00?oool00ol0VOooooooo`1doooo002Moooo00<0000co`0co`000c?o00030000oooooooo00?oool0
0ol0VOooooooo`1doooo002Moooo00<0000co`0co`000c?o00030000oooooooo00?oool00ol0VOoo
ooooo`1doooo002Moooo00<0000co`0co`000c?o00030000oooooooo00?oool00ol0VOooooooo`1d
oooo002Moooo00<0000co`0co`000c?o00800004oooo00?o09Woooooool0M?ooo`00WOooo`030000
<ol0<ol000<co`000`000?ooooooo`03oooo00?o09Woooooool0M?ooo`00WOooo`030000<ol0<ol0
00<co`000`000?ooooooo`03oooo00?o09Woooooool0M?ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`03oooo00?o09Woooooool0M?ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`03oooo00?o09Woooooool0M?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`03
oooo00?o09Woooooool0M?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`03oooo00?o
09Woooooool0M?ooo`00W_ooo`030000<ol0<ol0008co`0200001?ooo`03o`2Ioooooooo07Coool0
09koool00`0003?o03?o0002<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool009koool0
0`0003?o03?o0002<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool009koool00`0003?o
03?o0002<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool009koool00`0003?o03?o0002
<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool009koool00`0003?o03?o0002<ol000<0
003oooooool00oooo`03o`2Ioooooooo07Coool009koool00`0003?o03?o0002<ol00P0000Coool0
0ol0VOooooooo`1doooo002Ooooo00D0000co`0co`0co`0000001Oooo`03o`2Ioooooooo07Coool0
09ooool01@0003?o03?o03?o00000005oooo00?o09Woooooool0M?ooo`00Woooo`050000<ol0<ol0
<ol0000000Goool00ol0VOooooooo`1doooo002Koooo1@0000<co`000`000?ooooooo`03oooo00?o
09Woooooool0M?ooo`00Voooo`050000oooooooooooo000000<co`000`000?ooooooo`03oooo00?o
09Woooooool0M?ooo`00W?ooo`040000oooooooo00000c?o00<00003oooo00?o09Woooooool0M?oo
o`00WOooo`030000oooo000000<co`000`000?ooooooo`03oooo00?o09Woooooool0M?ooo`00Vooo
o`030000oooooooo00800003<ol000<0003oooooool00oooo`03o`2Ioooooooo07Coool009coool2
000000?oool0000co`000S?o00030000oooooooo00?oool00ol0VOooooooo`1doooo002Ooooo00D0
000co`0co`0co`0000001Oooo`03o`2Ioooooooo07Coool00:3oool0100003?o03?o000000Goool0
0ol0VOooooooo`1doooo002Poooo00<0000co`0co`000P0000Coool00ol0VOooooooo`1doooo002P
oooo00@0000co`0co`000005oooo00?o09Woooooool0M?ooo`00X?ooo`040000<ol0<ol000001Ooo
o`03o`2Ioooooooo07Coool00:3oool0100003?o03?o000000Goool00ol0VOooooooo`1doooo002P
oooo00@0000co`0co`000005oooo00?o09Woooooool0M?ooo`00X?ooo`040000<ol0<ol000001Ooo
o`03o`2Ioooooooo07Coool00:3oool0100003?o03?o000000Goool00ol0VOooooooo`1doooo002Q
oooo00@0000co`0000000004oooo00?o09Woooooool0M?ooo`00XOooo`030000<ol0000000Goool0
0ol0VOooooooo`1doooo002Qoooo00<0000co`0000001Oooo`03o`2Ioooooooo07Coool00:7oool0
0`0003?o00000005oooo00?o09Woooooool0M?ooo`00XOooo`030000<ol0000000Goool00ol0VOoo
ooooo`1doooo002Qoooo00<0000co`0000001Oooo`03o`2Ioooooooo07Coool00:7oool0100003?o
0000000000Coool00ol0VOooooooo`1doooo002Qoooo00<0000co`0000001Oooo`03o`2Ioooooooo
07Coool00:7oool00`0003?o00000005oooo00?o09Woooooool0M?ooo`00XOooo`030000<ol00000
00Goool00ol0VOooooooo`1doooo002Qoooo00<0000co`0000001Oooo`03o`2Ioooooooo07Coool0
0:7oool00`0003?o00000005oooo00?o09Woooooool0M?ooo`00XOooo`040000<ol0000000001?oo
o`03o`2Ioooooooo07Coool00:7oool00`0003?o00000005oooo00?o09Woooooool0M?ooo`00XOoo
o`030000<ol0000000Goool00ol0VOooooooo`1doooo002Qoooo00<0000co`0000001Oooo`03o`2I
oooooooo07Coool009coool200000oooo`030000<ol0000000Goool00ol0VOooooooo`1doooo002K
oooo00@0003oooooool00002oooo00<0000co`0000001Oooo`03o`2Ioooooooo07Coool009goool0
1P000?ooooooooooo`0003?o00<00003oooo00?o09Woooooool0M?ooo`00W_ooo`060000oooooooo
0000<ol000001Oooo`03o`2Ioooooooo07Coool009_oool010000?ooooooo`0000;oool00`0003?o
00000005oooo00?o09Woooooool0M?ooo`00W?ooo`800004oooo0P0000Goool00ol0VOooooooo`1d
oooo002Roooo0P0000Goool00ol0VOooooooo`1doooo002Roooo0P0000Goool00ol0VOooooooo`1d
oooo002Roooo0P0000Goool00ol0VOooooooo`1doooo002Roooo0`0000Coool00ol0VOooooooo`1d
oooo002Roooo0P0000Goool00ol0VOooooooo`1doooo002Roooo0P0000Goool00ol0VOooooooo`1d
oooo002Roooo0P0000Goool00ol0VOooooooo`1doooo002Roooo0P0000Goool00ol0VOooooooo`1d
oooo002Roooo0P0000Goool00ol0VOooooooo`1doooo002Roooo0`0000Coool00ol0VOooooooo`1d
oooo002Roooo0P0000Goool00ol0VOooooooo`1doooo002Roooo0P0000Goool00ol0VOooooooo`1d
oooo002Roooo0P0000Goool00ol0VOooooooo`1doooo002Roooo0P0000Goool00ol0VOooooooo`1d
oooo002Roooo0P0000Goool00ol0VOooooooo`1doooo002Roooo0`0000Coool00ol0VOooooooo`1d
oooo002Soooo00<0003oooooool00oooo`03o`2Ioooooooo07Coool00:?oool00`000?ooooooo`03
oooo00?o09Woooooool0M?ooo`00Xoooo`030000oooooooo00?oool00ol0VOooooooo`1doooo002S
oooo00<0003oooooool00oooo`03o`2Ioooooooo07Coool00:?oool00`000?ooooooo`03oooo00?o
09Woooooool0M?ooo`00Xoooo`800004oooo00?o09Woooooool0M?ooo`00Xoooo`030000oooooooo
00?oool00ol0VOooooooo`1doooo002Soooo00<0003oooooool00oooo`03o`2Ioooooooo07Coool0
0:?oool00`000?ooooooo`03oooo00?o09Woooooool0M?ooo`00Xoooo`030000oooooooo00?oool0
0ol0VOooooooo`1doooo002Moooo0`0000?oool00`000?ooooooo`03oooo00?o09Woooooool0M?oo
o`00W_ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00?o09Woooooool0M?ooo`00Vooo
o`D00003oooo0`0000?oool00ol0VOooooooo`1doooo002Koooo00@0003oooooool00021oooo002L
oooo00<0003oool00000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00goool200001?ooo`800005oooo00<0003oooooool00_ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00000oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?oo
ooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003ooooo
ool0000;oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooooooo000001Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool05oooo`800009oooo100000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59975 .12361 L
.60479 .12361 L
.60756 .12361 L
.60891 .12361 L
.61016 .12361 L
s
.61016 .12361 m
.61064 .61803 L
s
0 .4 1 r
.02381 .12364 m
.04262 .12365 L
.06244 .12367 L
.07286 .12369 L
.08255 .1237 L
.09388 .12373 L
.10458 .12375 L
.125 .12381 L
.14357 .12389 L
.16355 .12402 L
.18199 .12418 L
.20071 .1244 L
.21136 .12457 L
.22134 .12476 L
.24158 .12526 L
.26011 .1259 L
.27909 .12683 L
.28984 .12751 L
.29982 .12827 L
.32034 .13033 L
.33895 .13297 L
.35819 .1368 L
.36904 .13961 L
.37901 .14273 L
.39784 .15035 L
.40853 .15597 L
.4185 .16227 L
.43714 .17752 L
.44697 .18787 L
.44936 .19068 L
.45061 .1922 L
.45193 .19384 L
.45264 .19433 L
.45341 .1941 L
.45476 .1937 L
.45741 .19287 L
.46844 .18901 L
.47865 .18472 L
.49877 .17372 L
.51838 .15861 L
.52936 .14761 L
.53933 .13552 L
.54418 .12878 L
.54546 .1269 L
.54616 .12584 L
.54683 .12482 L
.54813 .12361 L
.54931 .12361 L
.5504 .12361 L
.55141 .12361 L
Mistroke
.55252 .12361 L
.5537 .12361 L
.555 .12361 L
.55623 .12361 L
.55733 .12361 L
.55852 .12361 L
.55982 .12361 L
.56103 .12361 L
.56173 .12361 L
.56237 .12361 L
.5631 .12361 L
.56379 .12361 L
.56509 .12361 L
.56574 .12361 L
.56646 .12361 L
.56724 .12361 L
.56796 .12361 L
.56863 .12361 L
.56936 .12361 L
.57057 .12361 L
.57125 .12361 L
.57189 .12361 L
.57318 .12361 L
.5739 .12361 L
.57455 .12361 L
.57573 .12361 L
.577 .12361 L
.57821 .12361 L
.57931 .12361 L
.58047 .12361 L
.58172 .12361 L
.584 .12361 L
.58663 .12361 L
.58903 .12361 L
.59812 .12361 L
.61877 .12361 L
.65952 .12361 L
.69875 .12361 L
.73647 .12361 L
.77664 .12361 L
.8153 .12361 L
.85641 .12361 L
.896 .12361 L
.93407 .12361 L
.9746 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooooooo1P1Vo`03000006Ko06Ko
00P0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0I_l01@1Vo`;oool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
0003000006Ko06Ko00Lco`000`000?ooooooo`05oooo00?o09Woool000002Oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`05oooo2@1VoaOoool0
0`000?ooooooo`06oooo1000018co`000`1Voc?o03?o0006<ol000<0003oooooool01Oooo`03o`2I
oooooooo01goool00`000?ooooooo`0Voooo00<0003oooooool0:Oooo`00I?ooo`D0I_lOoooo1000
00dco`000`1Voc?o03?o0007<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool006Woool6
06Ko7Oooo`030000<ol0<ol000Tco`000`1Voc?o03?o0008<ol000<0003oooooool01Oooo`03o`2I
oooooooo07;oool006ooool306Ko6oooo`800008<ol000<0I_lco`0co`002C?o00030000oooooooo
00Goool00ol0VOooooooo`1boooo001boooo0P1Voa_oool00`0003?o03?o0004<ol000<0I_lco`0c
o`002S?o00030000oooooooo00Goool00ol0VOooooooo`1boooo001doooo0P1Voa[oool00`0003?o
03?o0002<ol000<0I_lco`0co`002c?o00800006oooo00?o09Woooooool0L_ooo`00M_ooo`80I_lI
oooo0P00008co`000`1Voc?o03?o000;<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool0
07Soool00`1Vooooooooo`0Hoooo00<00000I_lco`003C?o00030000oooooooo00Goool00ol0VOoo
ooooo`1boooo001ioooo0P1VoaSoool00`1Voc?o03?o000=<ol000<0003oooooool01Oooo`03o`2I
oooooooo07;oool007_oool00`1Vooooooooo`0Coooo0P1Vo`03oooo0000<ol000dco`000`000?oo
ooooo`05oooo00?o09Woooooool0L_ooo`00O?ooo`80I_lBoooo00D0I_ooooooooooool000003S?o
00030000oooooooo00Goool00ol0VOooooooo`1boooo001noooo00<0I_ooooooool03_ooo`0306Ko
oooooooo00?oool00`0003?o03?o000;<ol00P0000Koool00ol0VOooooooo`1boooo001ooooo00<0
I_ooooooool02oooo`80I_l6oooo00<0000co`0co`002c?o00030000oooooooo00Goool00ol0VOoo
ooooo`1boooo0020oooo00<0I_ooooooool02?ooo`80I_l9oooo00<0000co`0co`002S?o00030000
oooooooo00Goool00ol0VOooooooo`1boooo0021oooo00<0I_ooooooool01Oooo`80I_l;oooo00<0
000co`0co`002S?o00030000oooooooo00Goool00ol0VOooooooo`1boooo0022oooo00@0I_oooooo
ooooool306Ko3_ooo`030000<ol0<ol000Tco`000`000?ooooooo`05oooo00?o09Woooooool0L_oo
o`00P_ooo`@0I_lAoooo00<0000co`0co`002C?o00030000oooooooo00Goool00ol0VOooooooo`1b
oooo002Hoooo00<0000co`0co`0023?o00800006oooo00?o09Woooooool0L_ooo`00V?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`05oooo00?o09Woooooool0L_ooo`00V?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`05oooo00?o09Woooooool0L_ooo`00VOooo`030000<ol0<ol000Lco`00
0`000?ooooooo`05oooo00?o09Woooooool0L_ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`05oooo00?o09Woooooool0L_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`05
oooo00?o09Woooooool0L_ooo`00VOooo`030000<ol0<ol000Lco`0200001_ooo`03o`2Ioooooooo
07;oool009[oool00`0003?o03?o0006<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool0
09[oool00`0003?o03?o0006<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool009[oool0
0`0003?o03?o0006<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool009[oool00`0003?o
03?o0006<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool009_oool500000c?o00030000
oooooooo00Goool00ol0VOooooooo`1boooo002Koooo00<0000co`0000001C?o00030000oooooooo
00Goool00ol0VOooooooo`1boooo002Koooo00<0000co`0000001C?o00<00005oooo00?o09Wooooo
ool0L_ooo`00W?ooo`800005<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool009coool2
00001C?o00030000oooooooo00Goool00ol0VOooooooo`1boooo002Loooo0P0000Dco`000`000?oo
ooooo`05oooo00?o09Woooooool0L_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`05
oooo00?o09Woooooool0L_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`05oooo00?o
09Woooooool0L_ooo`00W?ooo`030000<ol0<ol000@co`0200001_ooo`03o`2Ioooooooo07;oool0
09goool00`0003?o03?o0003<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool009goool0
0`0003?o03?o0003<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool009goool00`0003?o
03?o0003<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool009goool00`0003?o03?o0003
<ol000<0003oooooool01Oooo`03o`2Ioooooooo07;oool009goool00`0003?o03?o0003<ol000<0
003oooooool01Oooo`03o`2Ioooooooo07;oool009goool00`0003?o03?o0003<ol00P0000Koool0
0ol0VOooooooo`1boooo002Moooo00<0000co`0co`000c?o00030000oooooooo00Goool00ol0VOoo
ooooo`1boooo002Moooo00<0000co`0co`000c?o00030000oooooooo00Goool00ol0VOooooooo`1b
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo00Goool00ol0VOooooooo`1boooo002N
oooo00<0000co`0co`000S?o00030000oooooooo00Goool00ol0VOooooooo`1boooo002Noooo00<0
000co`0co`000S?o00030000oooooooo00Goool00ol0VOooooooo`1boooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo00Goool00ol0VOooooooo`1boooo002Noooo00<0000co`0co`000S?o
00800006oooo00?o09Woooooool0L_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`05
oooo00?o09Woooooool0L_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`05oooo00?o
09Woooooool0L_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`05oooo00?o09Wooooo
ool0L_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`05oooo00?o09Woooooool0L_oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`05oooo00?o09Woooooool0L_ooo`00W_oo
o`030000<ol0<ol0008co`0200001_ooo`03o`2Ioooooooo07;oool009ooool01@0003?o03?o03?o
00000007oooo00?o09Woooooool0L_ooo`00Woooo`050000<ol0<ol0<ol0000000Ooool00ol0VOoo
ooooo`1boooo002Ooooo00D0000co`0co`0co`0000001oooo`03o`2Ioooooooo07;oool009_oool5
00000c?o00030000oooooooo00Goool00ol0VOooooooo`1boooo002Koooo00D0003oooooooooool0
00000c?o00030000oooooooo00Goool00ol0VOooooooo`1boooo002Loooo00@0003oooooool00003
<ol00`0000Goool00ol0VOooooooo`1boooo002Moooo00<0003oool000000c?o00030000oooooooo
00Goool00ol0VOooooooo`1boooo002Koooo00<0003oooooool00P0000<co`000`000?ooooooo`05
oooo00?o09Woooooool0L_ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003oooooool01Ooo
o`03o`2Ioooooooo07;oool009ooool01@0003?o03?o03?o00000007oooo00?o09Woooooool0L_oo
o`00X?ooo`040000<ol0<ol000001oooo`03o`2Ioooooooo07;oool00:3oool00`0003?o03?o0002
00001_ooo`03o`2Ioooooooo07;oool00:3oool0100003?o03?o000000Ooool00ol0VOooooooo`1b
oooo002Poooo00@0000co`0co`000007oooo00?o09Woooooool0L_ooo`00X?ooo`040000<ol0<ol0
00001oooo`03o`2Ioooooooo07;oool00:3oool0100003?o03?o000000Ooool00ol0VOooooooo`1b
oooo002Poooo00@0000co`0co`000007oooo00?o09Woooooool0L_ooo`00X?ooo`040000<ol0<ol0
00001oooo`03o`2Ioooooooo07;oool00:7oool0100003?o0000000000Koool00ol0VOooooooo`1b
oooo002Qoooo00<0000co`0000001oooo`03o`2Ioooooooo07;oool00:7oool00`0003?o00000007
oooo00?o09Woooooool0L_ooo`00XOooo`030000<ol0000000Ooool00ol0VOooooooo`1boooo002Q
oooo00<0000co`0000001oooo`03o`2Ioooooooo07;oool00:7oool00`0003?o00000007oooo00?o
09Woooooool0L_ooo`00XOooo`040000<ol0000000001_ooo`03o`2Ioooooooo07;oool00:7oool0
0`0003?o00000007oooo00?o09Woooooool0L_ooo`00XOooo`030000<ol0000000Ooool00ol0VOoo
ooooo`1boooo002Qoooo00<0000co`0000001oooo`03o`2Ioooooooo07;oool00:7oool00`0003?o
00000007oooo00?o09Woooooool0L_ooo`00XOooo`030000<ol0000000Ooool00ol0VOooooooo`1b
oooo002Qoooo00@0000co`0000000006oooo00?o09Woooooool0L_ooo`00XOooo`030000<ol00000
00Ooool00ol0VOooooooo`1boooo002Qoooo00<0000co`0000001oooo`03o`2Ioooooooo07;oool0
0:7oool00`0003?o00000007oooo00?o09Woooooool0L_ooo`00W?ooo`800003oooo00<0000co`00
00001oooo`03o`2Ioooooooo07;oool009_oool010000?ooooooo`0000;oool00`0003?o00000007
oooo00?o09Woooooool0L_ooo`00WOooo`060000oooooooooooo0000<ol00`0000Goool00ol0VOoo
ooooo`1boooo002Noooo00H0003oooooool0000co`000007oooo00?o09Woooooool0L_ooo`00Vooo
o`040000oooooooo00000_ooo`030000<ol0000000Ooool00ol0VOooooooo`1boooo002Loooo0P00
00Coool200001oooo`03o`2Ioooooooo07;oool00:;oool200001oooo`03o`2Ioooooooo07;oool0
0:;oool200001oooo`03o`2Ioooooooo07;oool00:;oool200001oooo`03o`2Ioooooooo07;oool0
0:;oool300001_ooo`03o`2Ioooooooo07;oool00:;oool200001oooo`03o`2Ioooooooo07;oool0
0:;oool200001oooo`03o`2Ioooooooo07;oool00:;oool200001oooo`03o`2Ioooooooo07;oool0
0:;oool200001oooo`03o`2Ioooooooo07;oool00:;oool200001oooo`03o`2Ioooooooo07;oool0
0:;oool300001_ooo`03o`2Ioooooooo07;oool00:;oool200001oooo`03o`2Ioooooooo07;oool0
0:;oool200001oooo`03o`2Ioooooooo07;oool00:;oool200001oooo`03o`2Ioooooooo07;oool0
0:;oool200001oooo`03o`2Ioooooooo07;oool00:;oool200001oooo`03o`2Ioooooooo07;oool0
0:;oool300001_ooo`03o`2Ioooooooo07;oool00:?oool00`000?ooooooo`05oooo00?o09Wooooo
ool0L_ooo`00Xoooo`030000oooooooo00Goool00ol0VOooooooo`1boooo002Soooo00<0003ooooo
ool01Oooo`03o`2Ioooooooo07;oool00:?oool00`000?ooooooo`05oooo00?o09Woooooool0L_oo
o`00Xoooo`030000oooooooo00Goool00ol0VOooooooo`1boooo002Soooo0P0000Koool00ol0VOoo
ooooo`1boooo002Soooo00<0003oooooool01Oooo`03o`2Ioooooooo07;oool00:?oool00`000?oo
ooooo`05oooo00?o09Woooooool0L_ooo`00Xoooo`030000oooooooo00Goool00ol0VOooooooo`1b
oooo002Soooo00<0003oooooool01Oooo`03o`2Ioooooooo07;oool009goool300000oooo`030000
oooooooo00Goool00ol0VOooooooo`1boooo002Noooo00<0003oooooool00_ooo`030000oooooooo
00Goool00ol0VOooooooo`1boooo002Koooo1@0000?oool300001Oooo`03o`2Ioooooooo07;oool0
09_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool300001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500004_ooo`040000oooooooo00002?ooo`<00004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59975 .12361 L
.60479 .12361 L
.61016 .12361 L
.61278 .12361 L
.61524 .12361 L
.61745 .12361 L
.61869 .12361 L
s
.61869 .12361 m
.61915 .61803 L
s
0 .4 1 r
.02381 .12363 m
.04262 .12365 L
.06244 .12366 L
.07286 .12367 L
.08255 .12368 L
.09388 .1237 L
.10458 .12372 L
.125 .12377 L
.14357 .12384 L
.16355 .12394 L
.18199 .12407 L
.20071 .12425 L
.21136 .12438 L
.22134 .12453 L
.24158 .12494 L
.26011 .12546 L
.27909 .1262 L
.28984 .12675 L
.29982 .12736 L
.32034 .12901 L
.33895 .13114 L
.35819 .13422 L
.36904 .13648 L
.37901 .13899 L
.39784 .14512 L
.40853 .14964 L
.4185 .15471 L
.43885 .16833 L
.44785 .17613 L
.45278 .18097 L
.45741 .18592 L
.45851 .18717 L
.45968 .1885 L
.46095 .18901 L
.46212 .18855 L
.46732 .18641 L
.4765 .18212 L
.48653 .17658 L
.49726 .16948 L
.517 .1524 L
.52655 .14171 L
.53536 .13006 L
.53793 .12628 L
.53919 .12437 L
.54034 .12361 L
.54155 .12361 L
.54285 .12361 L
.54354 .12361 L
.54428 .12361 L
.54498 .12361 L
Mistroke
.54561 .12361 L
.54628 .12361 L
.54701 .12361 L
.54833 .12361 L
.54909 .12361 L
.54988 .12361 L
.55056 .12361 L
.5513 .12361 L
.55201 .12361 L
.55265 .12361 L
.5534 .12361 L
.5541 .12361 L
.55535 .12361 L
.55606 .12361 L
.55671 .12361 L
.55787 .12361 L
.55911 .12361 L
.56029 .12361 L
.56136 .12361 L
.56256 .12361 L
.56386 .12361 L
.56452 .12361 L
.56522 .12361 L
.56649 .12361 L
.56719 .12361 L
.56783 .12361 L
.56854 .12361 L
.56929 .12361 L
.57054 .12361 L
.57126 .12361 L
.57193 .12361 L
.57317 .12361 L
.57431 .12361 L
.57562 .12361 L
.57686 .12361 L
.578 .12361 L
.57922 .12361 L
.58038 .12361 L
.58144 .12361 L
.5865 .12361 L
.59675 .12361 L
.61516 .12361 L
.65475 .12361 L
.69283 .12361 L
.73336 .12361 L
.77237 .12361 L
.81383 .12361 L
.85378 .12361 L
.89222 .12361 L
.9331 .12361 L
Mistroke
.97248 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Goool206Ko00<00000I_l0
I_l0201Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0706Ko00<00000I_ooool01oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0003oooooool02Oooo`X0I_lBoooo00<0
003oooooool01_ooo`@0000@<ol000<0I_lco`0co`0023?o00030000oooooooo00Ooool00ol0VOoo
ooooo`0Koooo00<0003oooooool09_ooo`030000oooooooo02Woool006Woool406Ko6oooo`@0000;
<ol000<0I_lco`0co`002C?o00030000oooooooo00Ooool00ol0VOooooooo`1`oooo001]oooo1@1V
oa[oool00`0003?o03?o0008<ol000<0I_lco`0co`002C?o00030000oooooooo00Ooool00ol0VOoo
ooooo`1`oooo001boooo0P1VoaWoool200001c?o000306Ko<ol0<ol000Xco`000`000?ooooooo`07
oooo00?o09Woooooool0L?ooo`00M?ooo`<0I_lHoooo00<0000co`0co`000c?o000306Ko<ol0<ol0
00/co`000`000?ooooooo`07oooo00?o09Woooooool0L?ooo`00Moooo`80I_lGoooo00D0000co`0c
o`0co`00I_l03S?o00800008oooo00?o09Woooooool0L?ooo`00NOooo`80I_lFoooo0P00000306Ko
<ol0<ol000dco`000`000?ooooooo`07oooo00?o09Woooooool0L?ooo`00Noooo`0306Kooooooooo
01Coool00`1Vo`0003?o000><ol000<0003oooooool01oooo`03o`2Ioooooooo073oool007coool2
06Ko4_ooo`80I_l00oooo`0003?o000><ol000<0003oooooool01oooo`03o`2Ioooooooo073oool0
07koool00`1Vooooooooo`0>oooo00<0I_ooooooool00_ooo`030000<ol0<ol000`co`000`000?oo
ooooo`07oooo00?o09Woooooool0L?ooo`00Ooooo`0306Kooooooooo00coool00`1Vooooooooo`03
oooo00<0000co`0co`0033?o00030000oooooooo00Ooool00ol0VOooooooo`1`oooo0020oooo0P1V
o`_oool00`1Vooooooooo`05oooo00<0000co`0co`002c?o00800008oooo00?o09Woooooool0L?oo
o`00P_ooo`0306Kooooooooo00Koool206Ko2?ooo`030000<ol0<ol000/co`000`000?ooooooo`07
oooo00?o09Woooooool0L?ooo`00Poooo`0306Kooooooooo00?oool206Ko2oooo`030000<ol0<ol0
00Xco`000`000?ooooooo`07oooo00?o09Woooooool0L?ooo`00Q?ooo`0306Kooooooooo0080I_l=
oooo00<0000co`0co`002S?o00030000oooooooo00Ooool00ol0VOooooooo`1`oooo0024oooo0`1V
oa3oool00`0003?o03?o0009<ol000<0003oooooool01oooo`03o`2Ioooooooo073oool009Ooool0
0`0003?o03?o0009<ol000<0003oooooool01oooo`03o`2Ioooooooo073oool009Soool00`0003?o
03?o0008<ol00P0000Soool00ol0VOooooooo`1`oooo002Hoooo00<0000co`0co`0023?o00030000
oooooooo00Ooool00ol0VOooooooo`1`oooo002Hoooo00<0000co`0co`0023?o00030000oooooooo
00Ooool00ol0VOooooooo`1`oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo00Ooool0
0ol0VOooooooo`1`oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo00Ooool00ol0VOoo
ooooo`1`oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo00Ooool00ol0VOooooooo`1`
oooo002Ioooo00<0000co`0co`001c?o00800008oooo00?o09Woooooool0L?ooo`00V_ooo`030000
<ol0<ol000Hco`000`000?ooooooo`07oooo00?o09Woooooool0L?ooo`00V_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`07oooo00?o09Woooooool0L?ooo`00V_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`07oooo00?o09Woooooool0L?ooo`00V_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`07oooo00?o09Woooooool0L?ooo`00Voooo`D00003<ol000<0003oooooool01oooo`03o`2I
oooooooo073oool009_oool00`0003?o00000005<ol000<0003oooooool01oooo`03o`2Ioooooooo
073oool009_oool00`0003?o00000005<ol00`0000Ooool00ol0VOooooooo`1`oooo002Loooo0P00
00Dco`000`000?ooooooo`07oooo00?o09Woooooool0L?ooo`00W?ooo`800005<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo073oool009coool200001C?o00030000oooooooo00Ooool00ol0VOoo
ooooo`1`oooo002Loooo00<0000co`0co`0013?o00030000oooooooo00Ooool00ol0VOooooooo`1`
oooo002Loooo00<0000co`0co`0013?o00030000oooooooo00Ooool00ol0VOooooooo`1`oooo002L
oooo00<0000co`0co`0013?o00800008oooo00?o09Woooooool0L?ooo`00WOooo`030000<ol0<ol0
00<co`000`000?ooooooo`07oooo00?o09Woooooool0L?ooo`00WOooo`030000<ol0<ol000<co`00
0`000?ooooooo`07oooo00?o09Woooooool0L?ooo`00WOooo`030000<ol0<ol000<co`000`000?oo
ooooo`07oooo00?o09Woooooool0L?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`07
oooo00?o09Woooooool0L?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`07oooo00?o
09Woooooool0L?ooo`00WOooo`030000<ol0<ol000<co`0200002?ooo`03o`2Ioooooooo073oool0
09goool00`0003?o03?o0003<ol000<0003oooooool01oooo`03o`2Ioooooooo073oool009goool0
0`0003?o03?o0003<ol000<0003oooooool01oooo`03o`2Ioooooooo073oool009koool00`0003?o
03?o0002<ol000<0003oooooool01oooo`03o`2Ioooooooo073oool009koool00`0003?o03?o0002
<ol000<0003oooooool01oooo`03o`2Ioooooooo073oool009koool00`0003?o03?o0002<ol000<0
003oooooool01oooo`03o`2Ioooooooo073oool009koool00`0003?o03?o0002<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo073oool009koool00`0003?o03?o0002<ol00P0000Soool00ol0VOoo
ooooo`1`oooo002Noooo00<0000co`0co`000S?o00030000oooooooo00Ooool00ol0VOooooooo`1`
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo00Ooool00ol0VOooooooo`1`oooo002N
oooo00<0000co`0co`000S?o00030000oooooooo00Ooool00ol0VOooooooo`1`oooo002Noooo00<0
000co`0co`000S?o00030000oooooooo00Ooool00ol0VOooooooo`1`oooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo00Ooool00ol0VOooooooo`1`oooo002Noooo00<0000co`0co`000S?o
00800008oooo00?o09Woooooool0L?ooo`00Woooo`050000<ol0<ol0<ol0000000Woool00ol0VOoo
ooooo`1`oooo002Ooooo00D0000co`0co`0co`0000002Oooo`03o`2Ioooooooo073oool009ooool0
1@0003?o03?o03?o00000009oooo00?o09Woooooool0L?ooo`00Voooo`D00003<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo073oool009_oool01@000?ooooooooooo`000003<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo073oool009coool010000?ooooooo`0000<co`0300001oooo`03o`2I
oooooooo073oool009goool00`000?ooo`000003<ol000<0003oooooool01oooo`03o`2Ioooooooo
073oool009_oool00`000?ooooooo`0200000c?o00030000oooooooo00Ooool00ol0VOooooooo`1`
oooo002Loooo0P000003oooo0000<ol0008co`000`000?ooooooo`07oooo00?o09Woooooool0L?oo
o`00Woooo`050000<ol0<ol0<ol0000000Woool00ol0VOooooooo`1`oooo002Poooo00@0000co`0c
o`000009oooo00?o09Woooooool0L?ooo`00X?ooo`030000<ol0<ol000800008oooo00?o09Wooooo
ool0L?ooo`00X?ooo`040000<ol0<ol000002Oooo`03o`2Ioooooooo073oool00:3oool0100003?o
03?o000000Woool00ol0VOooooooo`1`oooo002Poooo00@0000co`0co`000009oooo00?o09Wooooo
ool0L?ooo`00X?ooo`040000<ol0<ol000002Oooo`03o`2Ioooooooo073oool00:3oool0100003?o
03?o000000Woool00ol0VOooooooo`1`oooo002Poooo00@0000co`0co`000009oooo00?o09Wooooo
ool0L?ooo`00XOooo`040000<ol0000000002?ooo`03o`2Ioooooooo073oool00:7oool00`0003?o
00000009oooo00?o09Woooooool0L?ooo`00XOooo`030000<ol0000000Woool00ol0VOooooooo`1`
oooo002Qoooo00<0000co`0000002Oooo`03o`2Ioooooooo073oool00:7oool00`0003?o00000009
oooo00?o09Woooooool0L?ooo`00XOooo`030000<ol0000000Woool00ol0VOooooooo`1`oooo002Q
oooo00@0000co`0000000008oooo00?o09Woooooool0L?ooo`00XOooo`030000<ol0000000Woool0
0ol0VOooooooo`1`oooo002Qoooo00<0000co`0000002Oooo`03o`2Ioooooooo073oool00:7oool0
0`0003?o00000009oooo00?o09Woooooool0L?ooo`00XOooo`030000<ol0000000Woool00ol0VOoo
ooooo`1`oooo002Qoooo00<0000co`0000002Oooo`03o`2Ioooooooo073oool00:7oool0100003?o
0000000000Soool00ol0VOooooooo`1`oooo002Qoooo00<0000co`0000002Oooo`03o`2Ioooooooo
073oool00:7oool00`0003?o00000009oooo00?o09Woooooool0L?ooo`00XOooo`030000<ol00000
00Woool00ol0VOooooooo`1`oooo002Loooo0P0000?oool00`0003?o00000009oooo00?o09Wooooo
ool0L?ooo`00Voooo`040000oooooooo00000_ooo`030000<ol0000000Woool00ol0VOooooooo`1`
oooo002Moooo00H0003oooooooooool0000co`0300001oooo`03o`2Ioooooooo073oool009koool0
1P000?ooooooo`0003?o000000Woool00ol0VOooooooo`1`oooo002Koooo00@0003oooooool00002
oooo00<0000co`0000002Oooo`03o`2Ioooooooo073oool009coool200001?ooo`800009oooo00?o
09Woooooool0L?ooo`00X_ooo`800009oooo00?o09Woooooool0L?ooo`00X_ooo`800009oooo00?o
09Woooooool0L?ooo`00X_ooo`800009oooo00?o09Woooooool0L?ooo`00X_ooo`<00008oooo00?o
09Woooooool0L?ooo`00X_ooo`800009oooo00?o09Woooooool0L?ooo`00X_ooo`800009oooo00?o
09Woooooool0L?ooo`00X_ooo`800009oooo00?o09Woooooool0L?ooo`00X_ooo`800009oooo00?o
09Woooooool0L?ooo`00X_ooo`800009oooo00?o09Woooooool0L?ooo`00X_ooo`<00008oooo00?o
09Woooooool0L?ooo`00X_ooo`800009oooo00?o09Woooooool0L?ooo`00X_ooo`800009oooo00?o
09Woooooool0L?ooo`00X_ooo`800009oooo00?o09Woooooool0L?ooo`00X_ooo`800009oooo00?o
09Woooooool0L?ooo`00X_ooo`800009oooo00?o09Woooooool0L?ooo`00X_ooo`<00008oooo00?o
09Woooooool0L?ooo`00Xoooo`030000oooooooo00Ooool00ol0VOooooooo`1`oooo002Soooo00<0
003oooooool01oooo`03o`2Ioooooooo073oool00:?oool00`000?ooooooo`07oooo00?o09Wooooo
ool0L?ooo`00Xoooo`030000oooooooo00Ooool00ol0VOooooooo`1`oooo002Soooo00<0003ooooo
ool01oooo`03o`2Ioooooooo073oool00:?oool200002?ooo`03o`2Ioooooooo073oool00:?oool0
0`000?ooooooo`07oooo00?o09Woooooool0L?ooo`00Xoooo`030000oooooooo00Ooool00ol0VOoo
ooooo`1`oooo002Soooo00<0003oooooool01oooo`03o`2Ioooooooo073oool00:?oool00`000?oo
ooooo`07oooo00?o09Woooooool0L?ooo`00WOooo`<00003oooo00<0003oooooool01oooo`03o`2I
oooooooo073oool009koool00`000?ooooooo`02oooo00<0003oooooool01oooo`03o`2Ioooooooo
073oool009_oool500000oooo`<00007oooo00?o09Woooooool0L?ooo`00Voooo`040000oooooooo
0000POooo`00W?ooo`030000oooo0000087oool009goool20000POooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500004_ooo`040000
oooooooo00002Oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
01Goool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61445 .12361 L
.61984 .12361 L
.62236 .12361 L
.62502 .12361 L
.6257 .12361 L
.62642 .12361 L
s
.62642 .12361 m
.62673 .61803 L
s
0 .4 1 r
.02381 .12363 m
.04262 .12364 L
.06244 .12365 L
.07286 .12366 L
.08255 .12367 L
.09388 .12368 L
.10458 .1237 L
.125 .12374 L
.14357 .12379 L
.16355 .12386 L
.18199 .12396 L
.20071 .12411 L
.21136 .12421 L
.22134 .12433 L
.24158 .12464 L
.26011 .12504 L
.27909 .12562 L
.28984 .12605 L
.29982 .12652 L
.32034 .12781 L
.33895 .12946 L
.35819 .13185 L
.36904 .13361 L
.37901 .13556 L
.39784 .14032 L
.40853 .14383 L
.4185 .14777 L
.43885 .15835 L
.45741 .17202 L
.46222 .17638 L
.46485 .17893 L
.46614 .18022 L
.46732 .18143 L
.46835 .18236 L
.46942 .18181 L
.47168 .18063 L
.4765 .17795 L
.48653 .17158 L
.49726 .16342 L
.517 .14369 L
.52164 .13795 L
.52655 .13131 L
.52858 .1284 L
.53075 .12515 L
.53199 .12361 L
.53313 .12361 L
.53428 .12361 L
.53536 .12361 L
.5366 .12361 L
.53791 .12361 L
Mistroke
.53914 .12361 L
.54026 .12361 L
.54095 .12361 L
.54159 .12361 L
.54228 .12361 L
.54302 .12361 L
.54425 .12361 L
.54495 .12361 L
.54561 .12361 L
.5463 .12361 L
.54705 .12361 L
.54776 .12361 L
.54841 .12361 L
.54965 .12361 L
.55097 .12361 L
.55165 .12361 L
.55238 .12361 L
.5537 .12361 L
.55447 .12361 L
.55527 .12361 L
.55596 .12361 L
.55671 .12361 L
.55736 .12361 L
.55807 .12361 L
.55936 .12361 L
.56061 .12361 L
.56176 .12361 L
.56301 .12361 L
.56372 .12361 L
.56438 .12361 L
.56508 .12361 L
.56572 .12361 L
.56646 .12361 L
.56716 .12361 L
.56833 .12361 L
.56957 .12361 L
.57063 .12361 L
.5718 .12361 L
.57306 .12361 L
.57376 .12361 L
.57441 .12361 L
.5756 .12361 L
.57686 .12361 L
.57809 .12361 L
.57879 .12361 L
.57943 .12361 L
.58061 .12361 L
.58185 .12361 L
.58639 .12361 L
.59658 .12361 L
Mistroke
.61494 .12361 L
.65279 .12361 L
.6931 .12361 L
.73189 .12361 L
.77314 .12361 L
.81287 .12361 L
.85108 .12361 L
.89174 .12361 L
.93089 .12361 L
.9725 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
06Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0406Ko0oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Dco`00
0`1Voc?o00000009<ol000<0003oooooool01oooo`030000ooooo`2I00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0003oooooool03_ooo`T0I_l>oooo00<0
003oooooool01_ooo`@0000><ol000<0I_lco`0co`002S?o00030000oooooooo00Woool00ol0VOoo
ooooo`0Ioooo00<0003oooooool09_ooo`030000oooooooo02Woool006goool506Ko5_ooo`@00009
<ol000<0I_lco`0co`002c?o00030000oooooooo00Woool00ol0VOooooooo`1^oooo001boooo0P1V
oaSoool00`0003?o03?o0005<ol000<0I_lco`0co`0033?o00030000oooooooo00Woool00ol0VOoo
ooooo`1^oooo001doooo0`1VoaKoool2000013?o000306Ko<ol0<ol000dco`000`000?ooooooo`09
oooo00?o09Woooooool0K_ooo`00Moooo`80I_lFoooo00@0000co`0co`00I_l@<ol000<0003ooooo
ool02Oooo`03o`2Ioooooooo06koool007Woool306Ko5?ooo`03000006Ko<ol0010co`0200002_oo
o`03o`2Ioooooooo06koool007coool206Ko4_ooo`0306Ko00000000010co`000`000?ooooooo`09
oooo00?o09Woooooool0K_ooo`00O_ooo`80I_l?oooo00D0I_ooooooooooool000003c?o00030000
oooooooo00Woool00ol0VOooooooo`1^oooo0020oooo00<0I_ooooooool02oooo`0306Kooooooooo
00;oool00`0003?o03?o000=<ol000<0003oooooool02Oooo`03o`2Ioooooooo06koool0087oool2
06Ko2_ooo`0306Kooooooooo00Coool00`0003?o03?o000<<ol000<0003oooooool02Oooo`03o`2I
oooooooo06koool008?oool00`1Vooooooooo`07oooo00<0I_ooooooool01?ooo`030000<ol0<ol0
00`co`000`000?ooooooo`09oooo00?o09Woooooool0K_ooo`00Q?ooo`0306Kooooooooo00Coool2
06Ko2?ooo`030000<ol0<ol000/co`0200002_ooo`03o`2Ioooooooo06koool008Goool206Ko0_oo
o`80I_l:oooo00<0000co`0co`002c?o00030000oooooooo00Woool00ol0VOooooooo`1^oooo0026
oooo0`1Vo`goool00`0003?o03?o000:<ol000<0003oooooool02Oooo`03o`2Ioooooooo06koool0
09Koool00`0003?o03?o000:<ol000<0003oooooool02Oooo`03o`2Ioooooooo06koool009Ooool0
0`0003?o03?o0009<ol000<0003oooooool02Oooo`03o`2Ioooooooo06koool009Ooool00`0003?o
03?o0009<ol000<0003oooooool02Oooo`03o`2Ioooooooo06koool009Soool00`0003?o03?o0008
<ol00P0000[oool00ol0VOooooooo`1^oooo002Hoooo00<0000co`0co`0023?o00030000oooooooo
00Woool00ol0VOooooooo`1^oooo002Hoooo00<0000co`0co`0023?o00030000oooooooo00Woool0
0ol0VOooooooo`1^oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo00Woool00ol0VOoo
ooooo`1^oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo00Woool00ol0VOooooooo`1^
oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo00Woool00ol0VOooooooo`1^oooo002I
oooo00<0000co`0co`001c?o0080000:oooo00?o09Woooooool0K_ooo`00V_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`09oooo00?o09Woooooool0K_ooo`00V_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`09oooo00?o09Woooooool0K_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`09oooo00?o09Woooooool0K_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`09
oooo00?o09Woooooool0K_ooo`00Voooo`D00003<ol000<0003oooooool02Oooo`03o`2Ioooooooo
06koool009_oool00`0003?o00000005<ol000<0003oooooool02Oooo`03o`2Ioooooooo06koool0
09_oool00`0003?o00000005<ol00`0000Woool00ol0VOooooooo`1^oooo002Loooo0P0000Dco`00
0`000?ooooooo`09oooo00?o09Woooooool0K_ooo`00W?ooo`800005<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo06koool009coool200001C?o00030000oooooooo00Woool00ol0VOooooooo`1^
oooo002Loooo00<0000co`0co`0013?o00030000oooooooo00Woool00ol0VOooooooo`1^oooo002L
oooo00<0000co`0co`0013?o00030000oooooooo00Woool00ol0VOooooooo`1^oooo002Loooo00<0
000co`0co`0013?o0080000:oooo00?o09Woooooool0K_ooo`00WOooo`030000<ol0<ol000<co`00
0`000?ooooooo`09oooo00?o09Woooooool0K_ooo`00WOooo`030000<ol0<ol000<co`000`000?oo
ooooo`09oooo00?o09Woooooool0K_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`09
oooo00?o09Woooooool0K_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`09oooo00?o
09Woooooool0K_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`09oooo00?o09Wooooo
ool0K_ooo`00WOooo`030000<ol0<ol000<co`0200002_ooo`03o`2Ioooooooo06koool009goool0
0`0003?o03?o0003<ol000<0003oooooool02Oooo`03o`2Ioooooooo06koool009goool00`0003?o
03?o0003<ol000<0003oooooool02Oooo`03o`2Ioooooooo06koool009koool00`0003?o03?o0002
<ol000<0003oooooool02Oooo`03o`2Ioooooooo06koool009koool00`0003?o03?o0002<ol000<0
003oooooool02Oooo`03o`2Ioooooooo06koool009koool00`0003?o03?o0002<ol000<0003ooooo
ool02Oooo`03o`2Ioooooooo06koool009koool00`0003?o03?o0002<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo06koool009koool00`0003?o03?o0002<ol00P0000[oool00ol0VOooooooo`1^
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo00Woool00ol0VOooooooo`1^oooo002N
oooo00<0000co`0co`000S?o00030000oooooooo00Woool00ol0VOooooooo`1^oooo002Noooo00<0
000co`0co`000S?o00030000oooooooo00Woool00ol0VOooooooo`1^oooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo00Woool00ol0VOooooooo`1^oooo002Noooo00<0000co`0co`000S?o
00030000oooooooo00Woool00ol0VOooooooo`1^oooo002Noooo00<0000co`0co`000S?o0080000:
oooo00?o09Woooooool0K_ooo`00Woooo`050000<ol0<ol0<ol0000000_oool00ol0VOooooooo`1^
oooo002Ooooo00D0000co`0co`0co`0000002oooo`03o`2Ioooooooo06koool009ooool01@0003?o
03?o03?o0000000;oooo00?o09Woooooool0K_ooo`00Voooo`D00003<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo06koool009_oool01@000?ooooooooooo`000003<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo06koool009coool010000?ooooooo`0000<co`0300002Oooo`03o`2Ioooooooo
06koool009goool00`000?ooo`000003<ol000<0003oooooool02Oooo`03o`2Ioooooooo06koool0
09_oool00`000?ooooooo`0200000c?o00030000oooooooo00Woool00ol0VOooooooo`1^oooo002L
oooo0P000003oooo0000<ol0008co`000`000?ooooooo`09oooo00?o09Woooooool0K_ooo`00Wooo
o`050000<ol0<ol0<ol0000000_oool00ol0VOooooooo`1^oooo002Poooo00@0000co`0co`00000;
oooo00?o09Woooooool0K_ooo`00X?ooo`030000<ol0<ol00080000:oooo00?o09Woooooool0K_oo
o`00X?ooo`040000<ol0<ol000002oooo`03o`2Ioooooooo06koool00:3oool0100003?o03?o0000
00_oool00ol0VOooooooo`1^oooo002Poooo00@0000co`0co`00000;oooo00?o09Woooooool0K_oo
o`00X?ooo`040000<ol0<ol000002oooo`03o`2Ioooooooo06koool00:3oool0100003?o03?o0000
00_oool00ol0VOooooooo`1^oooo002Poooo00@0000co`0co`00000;oooo00?o09Woooooool0K_oo
o`00XOooo`040000<ol0000000002_ooo`03o`2Ioooooooo06koool00:7oool00`0003?o0000000;
oooo00?o09Woooooool0K_ooo`00XOooo`030000<ol0000000_oool00ol0VOooooooo`1^oooo002Q
oooo00<0000co`0000002oooo`03o`2Ioooooooo06koool00:7oool00`0003?o0000000;oooo00?o
09Woooooool0K_ooo`00XOooo`030000<ol0000000_oool00ol0VOooooooo`1^oooo002Qoooo00@0
000co`000000000:oooo00?o09Woooooool0K_ooo`00XOooo`030000<ol0000000_oool00ol0VOoo
ooooo`1^oooo002Qoooo00<0000co`0000002oooo`03o`2Ioooooooo06koool00:7oool00`0003?o
0000000;oooo00?o09Woooooool0K_ooo`00XOooo`030000<ol0000000_oool00ol0VOooooooo`1^
oooo002Qoooo00<0000co`0000002oooo`03o`2Ioooooooo06koool00:7oool0100003?o00000000
00[oool00ol0VOooooooo`1^oooo002Qoooo00<0000co`0000002oooo`03o`2Ioooooooo06koool0
0:7oool00`0003?o0000000;oooo00?o09Woooooool0K_ooo`00XOooo`030000<ol0000000_oool0
0ol0VOooooooo`1^oooo002Loooo0P0000?oool00`0003?o0000000;oooo00?o09Woooooool0K_oo
o`00Voooo`040000oooooooo00000_ooo`030000<ol0000000_oool00ol0VOooooooo`1^oooo002M
oooo00H0003oooooooooool0000co`0300002Oooo`03o`2Ioooooooo06koool009koool01P000?oo
ooooo`0003?o000000_oool00ol0VOooooooo`1^oooo002Koooo00@0003oooooool00002oooo00<0
000co`0000002oooo`03o`2Ioooooooo06koool009coool200001?ooo`80000;oooo00?o09Wooooo
ool0K_ooo`00X_ooo`80000;oooo00?o09Woooooool0K_ooo`00X_ooo`80000;oooo00?o09Wooooo
ool0K_ooo`00X_ooo`80000;oooo00?o09Woooooool0K_ooo`00X_ooo`<0000:oooo00?o09Wooooo
ool0K_ooo`00X_ooo`80000;oooo00?o09Woooooool0K_ooo`00X_ooo`80000;oooo00?o09Wooooo
ool0K_ooo`00X_ooo`80000;oooo00?o09Woooooool0K_ooo`00X_ooo`80000;oooo00?o09Wooooo
ool0K_ooo`00X_ooo`80000;oooo00?o09Woooooool0K_ooo`00X_ooo`<0000:oooo00?o09Wooooo
ool0K_ooo`00X_ooo`80000;oooo00?o09Woooooool0K_ooo`00X_ooo`80000;oooo00?o09Wooooo
ool0K_ooo`00X_ooo`80000;oooo00?o09Woooooool0K_ooo`00X_ooo`80000;oooo00?o09Wooooo
ool0K_ooo`00X_ooo`80000;oooo00?o09Woooooool0K_ooo`00X_ooo`<0000:oooo00?o09Wooooo
ool0K_ooo`00Xoooo`030000oooooooo00Woool00ol0VOooooooo`1^oooo002Soooo00<0003ooooo
ool02Oooo`03o`2Ioooooooo06koool00:?oool00`000?ooooooo`09oooo00?o09Woooooool0K_oo
o`00Xoooo`030000oooooooo00Woool00ol0VOooooooo`1^oooo002Soooo00<0003oooooool02Ooo
o`03o`2Ioooooooo06koool00:?oool200002_ooo`03o`2Ioooooooo06koool00:?oool00`000?oo
ooooo`09oooo00?o09Woooooool0K_ooo`00Xoooo`030000oooooooo00Woool00ol0VOooooooo`1^
oooo002Soooo00<0003oooooool02Oooo`03o`2Ioooooooo06koool00:?oool00`000?ooooooo`09
oooo00?o09Woooooool0K_ooo`00WOooo`<00003oooo00<0003oooooool02Oooo`03o`2Ioooooooo
06koool009koool00`000?ooooooo`02oooo00<0003oooooool02Oooo`03o`2Ioooooooo06koool0
09_oool500000oooo`<00009oooo00?o09Woooooool0K_ooo`00Voooo`040000oooooooo0000POoo
o`00W?ooo`030000oooo0000087oool009goool20000POooo`00ooooob7oool00?oooolQoooo001i
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`0=oooo0P0000Coool200001Oooo`<00002oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003
oooo00@0003oooooool0000;oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool00008oooo1@0000?oool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo
00002Oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05ooo
o`80000;oooo0P0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61984 .12361 L
.6254 .12361 L
.62812 .12361 L
.63064 .12361 L
.63292 .12361 L
.63407 .12361 L
s
.63407 .12361 m
.63458 .61803 L
s
0 .4 1 r
.02381 .12362 m
.04262 .12363 L
.06244 .12364 L
.07286 .12364 L
.08255 .12365 L
.09388 .12366 L
.10458 .12367 L
.125 .1237 L
.14357 .12374 L
.16355 .1238 L
.18199 .12387 L
.20071 .12397 L
.21136 .12405 L
.22134 .12413 L
.24158 .12436 L
.26011 .12466 L
.27909 .12508 L
.28984 .12539 L
.29982 .12574 L
.32034 .12669 L
.33895 .1279 L
.35819 .12965 L
.36904 .13094 L
.37901 .13237 L
.39784 .13586 L
.40853 .13843 L
.4185 .14132 L
.43885 .14908 L
.45741 .1591 L
.46666 .16549 L
.47173 .16948 L
.47422 .17158 L
.47531 .17252 L
.4765 .1731 L
.4777 .17229 L
.47896 .17142 L
.48162 .16952 L
.48728 .16518 L
.49726 .15637 L
.50819 .14475 L
.51356 .13815 L
.51851 .13147 L
.52083 .12812 L
.52301 .12485 L
.5241 .12361 L
.52528 .12361 L
.52658 .12361 L
.52777 .12361 L
.52905 .12361 L
.53024 .12361 L
Mistroke
.53154 .12361 L
.53227 .12361 L
.53293 .12361 L
.53414 .12361 L
.53545 .12361 L
.53668 .12361 L
.53782 .12361 L
.539 .12361 L
.54008 .12361 L
.54133 .12361 L
.54251 .12361 L
.5436 .12361 L
.5446 .12361 L
.54571 .12361 L
.54688 .12361 L
.54805 .12361 L
.54932 .12361 L
.55051 .12361 L
.55161 .12361 L
.55282 .12361 L
.55351 .12361 L
.55415 .12361 L
.55544 .12361 L
.55616 .12361 L
.55682 .12361 L
.55807 .12361 L
.5587 .12361 L
.5594 .12361 L
.56062 .12361 L
.56177 .12361 L
.56246 .12361 L
.56312 .12361 L
.56436 .12361 L
.56505 .12361 L
.5657 .12361 L
.56638 .12361 L
.56713 .12361 L
.5683 .12361 L
.56955 .12361 L
.57072 .12361 L
.57179 .12361 L
.57297 .12361 L
.57426 .12361 L
.57492 .12361 L
.57561 .12361 L
.57686 .12361 L
.57807 .12361 L
.57875 .12361 L
.57939 .12361 L
.58071 .12361 L
Mistroke
.58214 .12361 L
.58712 .12361 L
.59645 .12361 L
.61739 .12361 L
.65863 .12361 L
.69836 .12361 L
.73658 .12361 L
.77724 .12361 L
.81639 .12361 L
.85799 .12361 L
.89808 .12361 L
.93665 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`04
oooo101Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0I_l01`1Vo`030000
06Kooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000<co`00
1@1Voc?o03?o03?o00000009<ol000<0003oooooool01oooo`050000ooooooooooooo`2I00Goool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0003oooooool04ooo
o`H0I_l<oooo00<0003oooooool01_ooo`@0000<<ol000<0I_lco`0co`0033?o00030000oooooooo
00_oool00ol0VOooooooo`0Goooo00<0003oooooool09_ooo`030000oooooooo02Woool006ooool4
06Ko5Oooo`@00007<ol000<0I_lco`0co`003C?o00030000oooooooo00_oool00ol0VOooooooo`1/
oooo001coooo1P1Voa?oool00`0003?o03?o0003<ol000<0I_lco`0co`003S?o00030000oooooooo
00_oool00ol0VOooooooo`1/oooo001ioooo0`1Voa7oool200000S?o000306Ko<ol0<ol000lco`00
0`000?ooooooo`0;oooo00?o09Woooooool0K?ooo`00O?ooo`80I_lAoooo00<0000co`00I_l04C?o
00030000oooooooo00_oool00ol0VOooooooo`1/oooo001noooo0`1Vo`ooool00`1Voc?o03?o000@
<ol00P0000coool00ol0VOooooooo`1/oooo0021oooo0P1Vo`coool0101Vooooo`000000010co`00
0`000?ooooooo`0;oooo00?o09Woooooool0K?ooo`00Poooo`80I_l9oooo00<0I_ooooooool00_oo
o`030000<ol0<ol000dco`000`000?ooooooo`0;oooo00?o09Woooooool0K?ooo`00QOooo`80I_l6
oooo00<0I_ooooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`0;oooo00?o09Wooooo
ool0K?ooo`00Qoooo`0306Kooooooooo00;oool00`1Vooooooooo`05oooo00<0000co`0co`0033?o
00030000oooooooo00_oool00ol0VOooooooo`1/oooo0028oooo00@0I_ooool0I_l0I_l8oooo00<0
000co`0co`0033?o00030000oooooooo00_oool00ol0VOooooooo`1/oooo0028oooo0`1Vo`[oool0
0`0003?o03?o000;<ol00P0000coool00ol0VOooooooo`1/oooo002Eoooo00<0000co`0co`002c?o
00030000oooooooo00_oool00ol0VOooooooo`1/oooo002Foooo00<0000co`0co`002S?o00030000
oooooooo00_oool00ol0VOooooooo`1/oooo002Foooo00<0000co`0co`002S?o00030000oooooooo
00_oool00ol0VOooooooo`1/oooo002Goooo00<0000co`0co`002C?o00030000oooooooo00_oool0
0ol0VOooooooo`1/oooo002Goooo00<0000co`0co`002C?o00030000oooooooo00_oool00ol0VOoo
ooooo`1/oooo002Hoooo00<0000co`0co`0023?o0080000<oooo00?o09Woooooool0K?ooo`00V?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`0;oooo00?o09Woooooool0K?ooo`00V?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`0;oooo00?o09Woooooool0K?ooo`00VOooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0;oooo00?o09Woooooool0K?ooo`00VOooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0;oooo00?o09Woooooool0K?ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0;oooo00?o09Woooooool0K?ooo`00VOooo`030000<ol0<ol000Lco`0200003?ooo`03o`2I
oooooooo06coool009[oool00`0003?o03?o0006<ol000<0003oooooool02oooo`03o`2Ioooooooo
06coool009[oool00`0003?o03?o0006<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool0
09[oool00`0003?o03?o0006<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool009[oool0
0`0003?o03?o0006<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool009_oool500000c?o
00030000oooooooo00_oool00ol0VOooooooo`1/oooo002Koooo00<0000co`0000001C?o00030000
oooooooo00_oool00ol0VOooooooo`1/oooo002Koooo00<0000co`0000001C?o00<0000;oooo00?o
09Woooooool0K?ooo`00W?ooo`800005<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool0
09coool200001C?o00030000oooooooo00_oool00ol0VOooooooo`1/oooo002Loooo0P0000Dco`00
0`000?ooooooo`0;oooo00?o09Woooooool0K?ooo`00W?ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0;oooo00?o09Woooooool0K?ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0;
oooo00?o09Woooooool0K?ooo`00W?ooo`030000<ol0<ol000@co`0200003?ooo`03o`2Ioooooooo
06coool009goool00`0003?o03?o0003<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool0
09goool00`0003?o03?o0003<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool009goool0
0`0003?o03?o0003<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool009goool00`0003?o
03?o0003<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool009goool00`0003?o03?o0003
<ol000<0003oooooool02oooo`03o`2Ioooooooo06coool009goool00`0003?o03?o0003<ol00P00
00coool00ol0VOooooooo`1/oooo002Moooo00<0000co`0co`000c?o00030000oooooooo00_oool0
0ol0VOooooooo`1/oooo002Moooo00<0000co`0co`000c?o00030000oooooooo00_oool00ol0VOoo
ooooo`1/oooo002Noooo00<0000co`0co`000S?o00030000oooooooo00_oool00ol0VOooooooo`1/
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo00_oool00ol0VOooooooo`1/oooo002N
oooo00<0000co`0co`000S?o00030000oooooooo00_oool00ol0VOooooooo`1/oooo002Noooo00<0
000co`0co`000S?o00030000oooooooo00_oool00ol0VOooooooo`1/oooo002Noooo00<0000co`0c
o`000S?o0080000<oooo00?o09Woooooool0K?ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0;oooo00?o09Woooooool0K?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0;
oooo00?o09Woooooool0K?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0;oooo00?o
09Woooooool0K?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0;oooo00?o09Wooooo
ool0K?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0;oooo00?o09Woooooool0K?oo
o`00W_ooo`030000<ol0<ol0008co`0200003?ooo`03o`2Ioooooooo06coool009ooool01@0003?o
03?o03?o0000000=oooo00?o09Woooooool0K?ooo`00Woooo`050000<ol0<ol0<ol0000000goool0
0ol0VOooooooo`1/oooo002Ooooo00D0000co`0co`0co`0000003Oooo`03o`2Ioooooooo06coool0
09_oool500000c?o00030000oooooooo00_oool00ol0VOooooooo`1/oooo002Koooo00D0003ooooo
ooooool000000c?o00030000oooooooo00_oool00ol0VOooooooo`1/oooo002Loooo00@0003ooooo
ool00003<ol00`0000_oool00ol0VOooooooo`1/oooo002Moooo00<0003oool000000c?o00030000
oooooooo00_oool00ol0VOooooooo`1/oooo002Koooo00<0003oooooool00P0000<co`000`000?oo
ooooo`0;oooo00?o09Woooooool0K?ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo06coool009ooool01@0003?o03?o03?o0000000=oooo00?o09Wooooo
ool0K?ooo`00X?ooo`040000<ol0<ol000003Oooo`03o`2Ioooooooo06coool00:3oool00`0003?o
03?o000200003?ooo`03o`2Ioooooooo06coool00:3oool0100003?o03?o000000goool00ol0VOoo
ooooo`1/oooo002Poooo00@0000co`0co`00000=oooo00?o09Woooooool0K?ooo`00X?ooo`040000
<ol0<ol000003Oooo`03o`2Ioooooooo06coool00:3oool0100003?o03?o000000goool00ol0VOoo
ooooo`1/oooo002Poooo00@0000co`0co`00000=oooo00?o09Woooooool0K?ooo`00X?ooo`040000
<ol0<ol000003Oooo`03o`2Ioooooooo06coool00:7oool0100003?o0000000000coool00ol0VOoo
ooooo`1/oooo002Qoooo00<0000co`0000003Oooo`03o`2Ioooooooo06coool00:7oool00`0003?o
0000000=oooo00?o09Woooooool0K?ooo`00XOooo`030000<ol0000000goool00ol0VOooooooo`1/
oooo002Qoooo00<0000co`0000003Oooo`03o`2Ioooooooo06coool00:7oool00`0003?o0000000=
oooo00?o09Woooooool0K?ooo`00XOooo`040000<ol0000000003?ooo`03o`2Ioooooooo06coool0
0:7oool00`0003?o0000000=oooo00?o09Woooooool0K?ooo`00XOooo`030000<ol0000000goool0
0ol0VOooooooo`1/oooo002Qoooo00<0000co`0000003Oooo`03o`2Ioooooooo06coool00:7oool0
0`0003?o0000000=oooo00?o09Woooooool0K?ooo`00XOooo`030000<ol0000000goool00ol0VOoo
ooooo`1/oooo002Qoooo00@0000co`000000000<oooo00?o09Woooooool0K?ooo`00XOooo`030000
<ol0000000goool00ol0VOooooooo`1/oooo002Qoooo00<0000co`0000003Oooo`03o`2Ioooooooo
06coool00:7oool00`0003?o0000000=oooo00?o09Woooooool0K?ooo`00W?ooo`800003oooo00<0
000co`0000003Oooo`03o`2Ioooooooo06coool009_oool010000?ooooooo`0000;oool00`0003?o
0000000=oooo00?o09Woooooool0K?ooo`00WOooo`060000oooooooooooo0000<ol00`0000_oool0
0ol0VOooooooo`1/oooo002Noooo00H0003oooooool0000co`00000=oooo00?o09Woooooool0K?oo
o`00Voooo`040000oooooooo00000_ooo`030000<ol0000000goool00ol0VOooooooo`1/oooo002L
oooo0P0000Coool200003Oooo`03o`2Ioooooooo06coool00:;oool200003Oooo`03o`2Ioooooooo
06coool00:;oool200003Oooo`03o`2Ioooooooo06coool00:;oool200003Oooo`03o`2Ioooooooo
06coool00:;oool300003?ooo`03o`2Ioooooooo06coool00:;oool200003Oooo`03o`2Ioooooooo
06coool00:;oool200003Oooo`03o`2Ioooooooo06coool00:;oool200003Oooo`03o`2Ioooooooo
06coool00:;oool200003Oooo`03o`2Ioooooooo06coool00:;oool200003Oooo`03o`2Ioooooooo
06coool00:;oool300003?ooo`03o`2Ioooooooo06coool00:;oool200003Oooo`03o`2Ioooooooo
06coool00:;oool200003Oooo`03o`2Ioooooooo06coool00:;oool200003Oooo`03o`2Ioooooooo
06coool00:;oool200003Oooo`03o`2Ioooooooo06coool00:;oool200003Oooo`03o`2Ioooooooo
06coool00:;oool300003?ooo`03o`2Ioooooooo06coool00:?oool00`000?ooooooo`0;oooo00?o
09Woooooool0K?ooo`00Xoooo`030000oooooooo00_oool00ol0VOooooooo`1/oooo002Soooo00<0
003oooooool02oooo`03o`2Ioooooooo06coool00:?oool00`000?ooooooo`0;oooo00?o09Wooooo
ool0K?ooo`00Xoooo`030000oooooooo00_oool00ol0VOooooooo`1/oooo002Soooo0P0000coool0
0ol0VOooooooo`1/oooo002Soooo00<0003oooooool02oooo`03o`2Ioooooooo06coool00:?oool0
0`000?ooooooo`0;oooo00?o09Woooooool0K?ooo`00Xoooo`030000oooooooo00_oool00ol0VOoo
ooooo`1/oooo002Soooo00<0003oooooool02oooo`03o`2Ioooooooo06coool009goool300000ooo
o`030000oooooooo00_oool00ol0VOooooooo`1/oooo002Noooo00<0003oooooool00_ooo`030000
oooooooo00_oool00ol0VOooooooo`1/oooo002Koooo1@0000?oool300002oooo`03o`2Ioooooooo
06coool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00
087oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1i
oooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0001;oool010000?ooooooo`0000_oool01@000?ooooooooooo`00001joooo001h
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.63527 .12361 L
.63796 .12361 L
.64043 .12361 L
.64164 .12361 L
.64277 .12361 L
s
.64277 .12361 m
.64324 .61803 L
s
0 .4 1 r
.02381 .12362 m
.04262 .12362 L
.06244 .12363 L
.07286 .12363 L
.08255 .12364 L
.09388 .12364 L
.10458 .12365 L
.125 .12367 L
.14357 .12369 L
.16355 .12373 L
.18199 .12378 L
.20071 .12385 L
.21136 .1239 L
.22134 .12395 L
.24158 .1241 L
.26011 .1243 L
.27909 .12457 L
.28984 .12478 L
.29982 .12501 L
.32034 .12563 L
.33895 .12642 L
.35819 .12757 L
.36904 .12842 L
.37901 .12935 L
.39784 .13164 L
.40853 .13333 L
.4185 .13522 L
.43885 .14031 L
.45741 .14688 L
.46666 .15107 L
.4765 .15638 L
.48162 .15954 L
.48303 .16046 L
.48382 .16099 L
.48454 .16084 L
.48518 .16027 L
.48587 .15964 L
.48728 .15835 L
.49726 .14819 L
.50734 .1359 L
.5123 .129 L
.51447 .12576 L
.51571 .12386 L
.51687 .12361 L
.5181 .12361 L
.51879 .12361 L
.51942 .12361 L
.52009 .12361 L
.52081 .12361 L
.52213 .12361 L
Mistroke
.52289 .12361 L
.52357 .12361 L
.52436 .12361 L
.5251 .12361 L
.52642 .12361 L
.52716 .12361 L
.52784 .12361 L
.52904 .12361 L
.53016 .12361 L
.53138 .12361 L
.5327 .12361 L
.53387 .12361 L
.53513 .12361 L
.53586 .12361 L
.53652 .12361 L
.53782 .12361 L
.53907 .12361 L
.54039 .12361 L
.54169 .12361 L
.54243 .12361 L
.54312 .12361 L
.54436 .12361 L
.54549 .12361 L
.54679 .12361 L
.54802 .12361 L
.54871 .12361 L
.54936 .12361 L
.55004 .12361 L
.55079 .12361 L
.55202 .12361 L
.55334 .12361 L
.55408 .12361 L
.55488 .12361 L
.55564 .12361 L
.55635 .12361 L
.55698 .12361 L
.55768 .12361 L
.55841 .12361 L
.5591 .12361 L
.56027 .12361 L
.56156 .12361 L
.5622 .12361 L
.5629 .12361 L
.56415 .12361 L
.5654 .12361 L
.56657 .12361 L
.56763 .12361 L
.56878 .12361 L
.57004 .12361 L
.57076 .12361 L
Mistroke
.57142 .12361 L
.57212 .12361 L
.57286 .12361 L
.57356 .12361 L
.57422 .12361 L
.57546 .12361 L
.57661 .12361 L
.57788 .12361 L
.57859 .12361 L
.57923 .12361 L
.58043 .12361 L
.58156 .12361 L
.58411 .12361 L
.58926 .12361 L
.59849 .12361 L
.61932 .12361 L
.65824 .12361 L
.69963 .12361 L
.73949 .12361 L
.77784 .12361 L
.81864 .12361 L
.85793 .12361 L
.8957 .12361 L
.93592 .12361 L
.97463 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oool0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0
I_l00`1Vo`Coool00`000?ooo`00000@000000<co`00000co`0023?o00050000<ol0<ol0<ol006Ko
00Dco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00?oool01Ol0VOoo
ooooooooo`000009oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0003oooooool05ooo
o`X0I_l4oooo00<0003oooooool01_ooo`@0000:<ol000<0I_lco`0co`003S?o00030000oooooooo
00goool00ol0VOooooooo`0Eoooo00<0003oooooool09_ooo`030000oooooooo02Woool007Ooool5
06Ko3?ooo`@00005<ol000<0I_lco`0co`003c?o00030000oooooooo00goool00ol0VOooooooo`1Z
oooo001loooo0P1Vo`koool00`0003?o03?o0002<ol000<0I_lco`0co`003c?o00030000oooooooo
00goool00ol0VOooooooo`1Zoooo001noooo101Vo`_oool2000000<co`00I_lco`004C?o00030000
oooooooo00goool00ol0VOooooooo`1Zoooo0022oooo101Vo`Woool00`1Voc?o03?o000A<ol000<0
003oooooool03Oooo`03o`2Ioooooooo06[oool008Koool206Ko1_ooo`0306Kooooo0000018co`02
00003_ooo`03o`2Ioooooooo06[oool008Soool00`1Vooooooooo`02oooo00@0I_ooooooooooool2
000043?o00030000oooooooo00goool00ol0VOooooooo`1Zoooo0029oooo00@0I_ooooooool0I_l6
oooo00<0000co`0co`003C?o00030000oooooooo00goool00ol0VOooooooo`1Zoooo002:oooo0P1V
o`Ooool00`0003?o03?o000=<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009Coool0
0`0003?o03?o000<<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009Coool00`0003?o
03?o000<<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009Goool00`0003?o03?o000;
<ol00P0000koool00ol0VOooooooo`1Zoooo002Eoooo00<0000co`0co`002c?o00030000oooooooo
00goool00ol0VOooooooo`1Zoooo002Foooo00<0000co`0co`002S?o00030000oooooooo00goool0
0ol0VOooooooo`1Zoooo002Foooo00<0000co`0co`002S?o00030000oooooooo00goool00ol0VOoo
ooooo`1Zoooo002Goooo00<0000co`0co`002C?o00030000oooooooo00goool00ol0VOooooooo`1Z
oooo002Goooo00<0000co`0co`002C?o00030000oooooooo00goool00ol0VOooooooo`1Zoooo002H
oooo00<0000co`0co`0023?o0080000>oooo00?o09Woooooool0J_ooo`00V?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0=oooo00?o09Woooooool0J_ooo`00V?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0=oooo00?o09Woooooool0J_ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0=oooo00?o09Woooooool0J_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0=
oooo00?o09Woooooool0J_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0=oooo00?o
09Woooooool0J_ooo`00VOooo`030000<ol0<ol000Lco`0200003_ooo`03o`2Ioooooooo06[oool0
09[oool00`0003?o03?o0006<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009[oool0
0`0003?o03?o0006<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009[oool00`0003?o
03?o0006<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009[oool00`0003?o03?o0006
<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009_oool500000c?o00030000oooooooo
00goool00ol0VOooooooo`1Zoooo002Koooo00<0000co`0000001C?o00030000oooooooo00goool0
0ol0VOooooooo`1Zoooo002Koooo00<0000co`0000001C?o00<0000=oooo00?o09Woooooool0J_oo
o`00W?ooo`800005<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009coool200001C?o
00030000oooooooo00goool00ol0VOooooooo`1Zoooo002Loooo0P0000Dco`000`000?ooooooo`0=
oooo00?o09Woooooool0J_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0=oooo00?o
09Woooooool0J_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0=oooo00?o09Wooooo
ool0J_ooo`00W?ooo`030000<ol0<ol000@co`0200003_ooo`03o`2Ioooooooo06[oool009goool0
0`0003?o03?o0003<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009goool00`0003?o
03?o0003<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009goool00`0003?o03?o0003
<ol000<0003oooooool03Oooo`03o`2Ioooooooo06[oool009goool00`0003?o03?o0003<ol000<0
003oooooool03Oooo`03o`2Ioooooooo06[oool009goool00`0003?o03?o0003<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo06[oool009goool00`0003?o03?o0003<ol00P0000koool00ol0VOoo
ooooo`1Zoooo002Moooo00<0000co`0co`000c?o00030000oooooooo00goool00ol0VOooooooo`1Z
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo00goool00ol0VOooooooo`1Zoooo002N
oooo00<0000co`0co`000S?o00030000oooooooo00goool00ol0VOooooooo`1Zoooo002Noooo00<0
000co`0co`000S?o00030000oooooooo00goool00ol0VOooooooo`1Zoooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo00goool00ol0VOooooooo`1Zoooo002Noooo00<0000co`0co`000S?o
00030000oooooooo00goool00ol0VOooooooo`1Zoooo002Noooo00<0000co`0co`000S?o0080000>
oooo00?o09Woooooool0J_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0=oooo00?o
09Woooooool0J_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0=oooo00?o09Wooooo
ool0J_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0=oooo00?o09Woooooool0J_oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0=oooo00?o09Woooooool0J_ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`0=oooo00?o09Woooooool0J_ooo`00W_ooo`030000
<ol0<ol0008co`0200003_ooo`03o`2Ioooooooo06[oool009ooool01@0003?o03?o03?o0000000?
oooo00?o09Woooooool0J_ooo`00Woooo`050000<ol0<ol0<ol0000000ooool00ol0VOooooooo`1Z
oooo002Ooooo00D0000co`0co`0co`0000003oooo`03o`2Ioooooooo06[oool009_oool500000c?o
00030000oooooooo00goool00ol0VOooooooo`1Zoooo002Koooo00D0003oooooooooool000000c?o
00030000oooooooo00goool00ol0VOooooooo`1Zoooo002Loooo00@0003oooooool00003<ol00`00
00goool00ol0VOooooooo`1Zoooo002Moooo00<0003oool000000c?o00030000oooooooo00goool0
0ol0VOooooooo`1Zoooo002Koooo00<0003oooooool00P0000<co`000`000?ooooooo`0=oooo00?o
09Woooooool0J_ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003oooooool03Oooo`03o`2I
oooooooo06[oool009ooool01@0003?o03?o03?o0000000?oooo00?o09Woooooool0J_ooo`00X?oo
o`040000<ol0<ol000003oooo`03o`2Ioooooooo06[oool00:3oool00`0003?o03?o000200003_oo
o`03o`2Ioooooooo06[oool00:3oool0100003?o03?o000000ooool00ol0VOooooooo`1Zoooo002P
oooo00@0000co`0co`00000?oooo00?o09Woooooool0J_ooo`00X?ooo`040000<ol0<ol000003ooo
o`03o`2Ioooooooo06[oool00:3oool0100003?o03?o000000ooool00ol0VOooooooo`1Zoooo002P
oooo00@0000co`0co`00000?oooo00?o09Woooooool0J_ooo`00X?ooo`040000<ol0<ol000003ooo
o`03o`2Ioooooooo06[oool00:7oool0100003?o0000000000koool00ol0VOooooooo`1Zoooo002Q
oooo00<0000co`0000003oooo`03o`2Ioooooooo06[oool00:7oool00`0003?o0000000?oooo00?o
09Woooooool0J_ooo`00XOooo`030000<ol0000000ooool00ol0VOooooooo`1Zoooo002Qoooo00<0
000co`0000003oooo`03o`2Ioooooooo06[oool00:7oool00`0003?o0000000?oooo00?o09Wooooo
ool0J_ooo`00XOooo`040000<ol0000000003_ooo`03o`2Ioooooooo06[oool00:7oool00`0003?o
0000000?oooo00?o09Woooooool0J_ooo`00XOooo`030000<ol0000000ooool00ol0VOooooooo`1Z
oooo002Qoooo00<0000co`0000003oooo`03o`2Ioooooooo06[oool00:7oool00`0003?o0000000?
oooo00?o09Woooooool0J_ooo`00XOooo`030000<ol0000000ooool00ol0VOooooooo`1Zoooo002Q
oooo00@0000co`000000000>oooo00?o09Woooooool0J_ooo`00XOooo`030000<ol0000000ooool0
0ol0VOooooooo`1Zoooo002Qoooo00<0000co`0000003oooo`03o`2Ioooooooo06[oool00:7oool0
0`0003?o0000000?oooo00?o09Woooooool0J_ooo`00W?ooo`800003oooo00<0000co`0000003ooo
o`03o`2Ioooooooo06[oool009_oool010000?ooooooo`0000;oool00`0003?o0000000?oooo00?o
09Woooooool0J_ooo`00WOooo`060000oooooooooooo0000<ol00`0000goool00ol0VOooooooo`1Z
oooo002Noooo00H0003oooooool0000co`00000?oooo00?o09Woooooool0J_ooo`00Voooo`040000
oooooooo00000_ooo`030000<ol0000000ooool00ol0VOooooooo`1Zoooo002Loooo0P0000Coool2
00003oooo`03o`2Ioooooooo06[oool00:;oool200003oooo`03o`2Ioooooooo06[oool00:;oool2
00003oooo`03o`2Ioooooooo06[oool00:;oool200003oooo`03o`2Ioooooooo06[oool00:;oool3
00003_ooo`03o`2Ioooooooo06[oool00:;oool200003oooo`03o`2Ioooooooo06[oool00:;oool2
00003oooo`03o`2Ioooooooo06[oool00:;oool200003oooo`03o`2Ioooooooo06[oool00:;oool2
00003oooo`03o`2Ioooooooo06[oool00:;oool200003oooo`03o`2Ioooooooo06[oool00:;oool3
00003_ooo`03o`2Ioooooooo06[oool00:;oool200003oooo`03o`2Ioooooooo06[oool00:;oool2
00003oooo`03o`2Ioooooooo06[oool00:;oool200003oooo`03o`2Ioooooooo06[oool00:;oool2
00003oooo`03o`2Ioooooooo06[oool00:;oool200003oooo`03o`2Ioooooooo06[oool00:;oool3
00003_ooo`03o`2Ioooooooo06[oool00:?oool00`000?ooooooo`0=oooo00?o09Woooooool0J_oo
o`00Xoooo`030000oooooooo00goool00ol0VOooooooo`1Zoooo002Soooo00<0003oooooool03Ooo
o`03o`2Ioooooooo06[oool00:?oool00`000?ooooooo`0=oooo00?o09Woooooool0J_ooo`00Xooo
o`030000oooooooo00goool00ol0VOooooooo`1Zoooo002Soooo0P0000koool00ol0VOooooooo`1Z
oooo002Soooo00<0003oooooool03Oooo`03o`2Ioooooooo06[oool00:?oool00`000?ooooooo`0=
oooo00?o09Woooooool0J_ooo`00Xoooo`030000oooooooo00goool00ol0VOooooooo`1Zoooo002S
oooo00<0003oooooool03Oooo`03o`2Ioooooooo06[oool009goool300000oooo`030000oooooooo
00goool00ol0VOooooooo`1Zoooo002Noooo00<0003oooooool00_ooo`030000oooooooo00goool0
0ol0VOooooooo`1Zoooo002Koooo1@0000?oool300003Oooo`03o`2Ioooooooo06[oool009_oool0
10000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQ
oooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool400000oooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool400000oooo`040000oooooooo00002?ooo`030000oooooooo00Coool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`00
00Woool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000B
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.64043 .12361 L
.64559 .12361 L
.64812 .12361 L
.64923 .12361 L
.65045 .12361 L
s
.65045 .12361 m
.65089 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12362 L
.07286 .12362 L
.08255 .12362 L
.09388 .12362 L
.10458 .12363 L
.125 .12364 L
.14357 .12365 L
.16355 .12367 L
.18199 .12369 L
.20071 .12373 L
.21136 .12375 L
.22134 .12378 L
.24158 .12385 L
.26011 .12395 L
.27909 .12409 L
.28984 .12419 L
.29982 .1243 L
.32034 .12461 L
.33895 .125 L
.35819 .12557 L
.36904 .12599 L
.37901 .12645 L
.39784 .12758 L
.40853 .12842 L
.4185 .12936 L
.43885 .13187 L
.45741 .13513 L
.4765 .13983 L
.48172 .14143 L
.48728 .14331 L
.48956 .14414 L
.49076 .14458 L
.49202 .14507 L
.49269 .14434 L
.49343 .14347 L
.49472 .1419 L
.49726 .13872 L
.50254 .13161 L
.50514 .12786 L
.50628 .12615 L
.50753 .12424 L
.50865 .12361 L
.50971 .12361 L
.51089 .12361 L
.51201 .12361 L
.51323 .12361 L
.51435 .12361 L
.51555 .12361 L
Mistroke
.51687 .12361 L
.51755 .12361 L
.51829 .12361 L
.51899 .12361 L
.51963 .12361 L
.52085 .12361 L
.52213 .12361 L
.5228 .12361 L
.52352 .12361 L
.52481 .12361 L
.52559 .12361 L
.52634 .12361 L
.52701 .12361 L
.52774 .12361 L
.52895 .12361 L
.52963 .12361 L
.53028 .12361 L
.53158 .12361 L
.53231 .12361 L
.53298 .12361 L
.5341 .12361 L
.53534 .12361 L
.53662 .12361 L
.53782 .12361 L
.5391 .12361 L
.53974 .12361 L
.54045 .12361 L
.54171 .12361 L
.54288 .12361 L
.54359 .12361 L
.54427 .12361 L
.54553 .12361 L
.54623 .12361 L
.54689 .12361 L
.5476 .12361 L
.54837 .12361 L
.54954 .12361 L
.5508 .12361 L
.552 .12361 L
.55309 .12361 L
.55431 .12361 L
.55499 .12361 L
.55564 .12361 L
.55693 .12361 L
.55765 .12361 L
.55831 .12361 L
.55947 .12361 L
.5607 .12361 L
.56175 .12361 L
.5629 .12361 L
Mistroke
.56414 .12361 L
.56484 .12361 L
.56547 .12361 L
.56671 .12361 L
.56788 .12361 L
.56997 .12361 L
.57114 .12361 L
.5722 .12361 L
.57346 .12361 L
.57464 .12361 L
.57574 .12361 L
.57691 .12361 L
.57816 .12361 L
.57929 .12361 L
.5806 .12361 L
.58184 .12361 L
.58643 .12361 L
.59687 .12361 L
.61794 .12361 L
.65629 .12361 L
.69709 .12361 L
.73638 .12361 L
.77415 .12361 L
.81437 .12361 L
.85308 .12361 L
.89424 .12361 L
.93388 .12361 L
.97201 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooo06Ko00L0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0
I_l01`1Vo`03000006Ko06Ko00<0I_l=000000<co`00000co`0023?o0003000006Ko06Ko00Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Goool00ol0VOooo`000009
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0003oooooool08Oooo`@0I_l00`00001V
o`1Vo`0406Ko0_ooo`@00008<ol000<0I_lco`0co`0043?o00030000oooooooo00ooool00ol0VOoo
ooooo`0Coooo00<0003oooooool09_ooo`030000oooooooo02Woool008;oool406Ko0_ooo`@00003
<ol000<0I_lco`0co`004C?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo0026oooo0P1V
o`Coool00`0003?o001Vo`0D<ol000<0003oooooool03oooo`03o`2Ioooooooo06Soool008Soool7
06Ko53?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002<oooo0P1Vo`03oooo0000<ol0
018co`000`000?ooooooo`0?oooo00?o09Woooooool0J?ooo`00T?ooo`030000<ol0<ol0010co`02
00004?ooo`03o`2Ioooooooo06Soool0097oool2000043?o00030000oooooooo00ooool00ol0VOoo
ooooo`1Xoooo002Coooo00<0000co`0co`003C?o00030000oooooooo00ooool00ol0VOooooooo`1X
oooo002Coooo00<0000co`0co`003C?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002D
oooo00<0000co`0co`0033?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Doooo00<0
000co`0co`0033?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Eoooo00<0000co`0c
o`002c?o0080000@oooo00?o09Woooooool0J?ooo`00UOooo`030000<ol0<ol000/co`000`000?oo
ooooo`0?oooo00?o09Woooooool0J?ooo`00U_ooo`030000<ol0<ol000Xco`000`000?ooooooo`0?
oooo00?o09Woooooool0J?ooo`00U_ooo`030000<ol0<ol000Xco`000`000?ooooooo`0?oooo00?o
09Woooooool0J?ooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`0?oooo00?o09Wooooo
ool0J?ooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`0?oooo00?o09Woooooool0J?oo
o`00V?ooo`030000<ol0<ol000Pco`0200004?ooo`03o`2Ioooooooo06Soool009Soool00`0003?o
03?o0008<ol000<0003oooooool03oooo`03o`2Ioooooooo06Soool009Soool00`0003?o03?o0008
<ol000<0003oooooool03oooo`03o`2Ioooooooo06Soool009Woool00`0003?o03?o0007<ol000<0
003oooooool03oooo`03o`2Ioooooooo06Soool009Woool00`0003?o03?o0007<ol000<0003ooooo
ool03oooo`03o`2Ioooooooo06Soool009Woool00`0003?o03?o0007<ol000<0003oooooool03ooo
o`03o`2Ioooooooo06Soool009Woool00`0003?o03?o0007<ol00P00013oool00ol0VOooooooo`1X
oooo002Joooo00<0000co`0co`001S?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002J
oooo00<0000co`0co`001S?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Joooo00<0
000co`0co`001S?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Joooo00<0000co`0c
o`001S?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Koooo1@0000<co`000`000?oo
ooooo`0?oooo00?o09Woooooool0J?ooo`00Voooo`030000<ol0000000Dco`000`000?ooooooo`0?
oooo00?o09Woooooool0J?ooo`00Voooo`030000<ol0000000Dco`0300003oooo`03o`2Ioooooooo
06Soool009coool200001C?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Loooo0P00
00Dco`000`000?ooooooo`0?oooo00?o09Woooooool0J?ooo`00W?ooo`800005<ol000<0003ooooo
ool03oooo`03o`2Ioooooooo06Soool009coool00`0003?o03?o0004<ol000<0003oooooool03ooo
o`03o`2Ioooooooo06Soool009coool00`0003?o03?o0004<ol000<0003oooooool03oooo`03o`2I
oooooooo06Soool009coool00`0003?o03?o0004<ol00P00013oool00ol0VOooooooo`1Xoooo002M
oooo00<0000co`0co`000c?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Moooo00<0
000co`0co`000c?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Moooo00<0000co`0co`000c?o
00030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Moooo00<0000co`0co`000c?o00030000
oooooooo00ooool00ol0VOooooooo`1Xoooo002Moooo00<0000co`0co`000c?o0080000@oooo00?o
09Woooooool0J?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0?oooo00?o09Wooooo
ool0J?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0?oooo00?o09Woooooool0J?oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0?oooo00?o09Woooooool0J?ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`0?oooo00?o09Woooooool0J?ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`0?oooo00?o09Woooooool0J?ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`0?oooo00?o09Woooooool0J?ooo`00W_ooo`030000<ol0<ol0008co`02
00004?ooo`03o`2Ioooooooo06Soool009koool00`0003?o03?o0002<ol000<0003oooooool03ooo
o`03o`2Ioooooooo06Soool009koool00`0003?o03?o0002<ol000<0003oooooool03oooo`03o`2I
oooooooo06Soool009koool00`0003?o03?o0002<ol000<0003oooooool03oooo`03o`2Ioooooooo
06Soool009koool00`0003?o03?o0002<ol000<0003oooooool03oooo`03o`2Ioooooooo06Soool0
09koool00`0003?o03?o0002<ol000<0003oooooool03oooo`03o`2Ioooooooo06Soool009koool0
0`0003?o03?o0002<ol00P00013oool00ol0VOooooooo`1Xoooo002Ooooo00D0000co`0co`0co`00
00004Oooo`03o`2Ioooooooo06Soool009ooool01@0003?o03?o03?o0000000Aoooo00?o09Wooooo
ool0J?ooo`00Woooo`050000<ol0<ol0<ol00000017oool00ol0VOooooooo`1Xoooo002Koooo1@00
00<co`000`000?ooooooo`0?oooo00?o09Woooooool0J?ooo`00Voooo`050000oooooooooooo0000
00<co`000`000?ooooooo`0?oooo00?o09Woooooool0J?ooo`00W?ooo`040000oooooooo00000c?o
00<0000?oooo00?o09Woooooool0J?ooo`00WOooo`030000oooo000000<co`000`000?ooooooo`0?
oooo00?o09Woooooool0J?ooo`00Voooo`030000oooooooo00800003<ol000<0003oooooool03ooo
o`03o`2Ioooooooo06Soool009coool2000000?oool0000co`000S?o00030000oooooooo00ooool0
0ol0VOooooooo`1Xoooo002Ooooo00D0000co`0co`0co`0000004Oooo`03o`2Ioooooooo06Soool0
0:3oool0100003?o03?o0000017oool00ol0VOooooooo`1Xoooo002Poooo00<0000co`0co`000P00
013oool00ol0VOooooooo`1Xoooo002Poooo00@0000co`0co`00000Aoooo00?o09Woooooool0J?oo
o`00X?ooo`040000<ol0<ol000004Oooo`03o`2Ioooooooo06Soool00:3oool0100003?o03?o0000
017oool00ol0VOooooooo`1Xoooo002Poooo00@0000co`0co`00000Aoooo00?o09Woooooool0J?oo
o`00X?ooo`040000<ol0<ol000004Oooo`03o`2Ioooooooo06Soool00:3oool0100003?o03?o0000
017oool00ol0VOooooooo`1Xoooo002Qoooo00@0000co`000000000@oooo00?o09Woooooool0J?oo
o`00XOooo`030000<ol00000017oool00ol0VOooooooo`1Xoooo002Qoooo00<0000co`0000004Ooo
o`03o`2Ioooooooo06Soool00:7oool00`0003?o0000000Aoooo00?o09Woooooool0J?ooo`00XOoo
o`030000<ol00000017oool00ol0VOooooooo`1Xoooo002Qoooo00<0000co`0000004Oooo`03o`2I
oooooooo06Soool00:7oool0100003?o00000000013oool00ol0VOooooooo`1Xoooo002Qoooo00<0
000co`0000004Oooo`03o`2Ioooooooo06Soool00:7oool00`0003?o0000000Aoooo00?o09Wooooo
ool0J?ooo`00XOooo`030000<ol00000017oool00ol0VOooooooo`1Xoooo002Qoooo00<0000co`00
00004Oooo`03o`2Ioooooooo06Soool00:7oool00`0003?o0000000Aoooo00?o09Woooooool0J?oo
o`00XOooo`040000<ol0000000004?ooo`03o`2Ioooooooo06Soool00:7oool00`0003?o0000000A
oooo00?o09Woooooool0J?ooo`00XOooo`030000<ol00000017oool00ol0VOooooooo`1Xoooo002Q
oooo00<0000co`0000004Oooo`03o`2Ioooooooo06Soool009coool200000oooo`030000<ol00000
017oool00ol0VOooooooo`1Xoooo002Koooo00@0003oooooool00002oooo00<0000co`0000004Ooo
o`03o`2Ioooooooo06Soool009goool01P000?ooooooooooo`0003?o00<0000?oooo00?o09Wooooo
ool0J?ooo`00W_ooo`060000oooooooo0000<ol000004Oooo`03o`2Ioooooooo06Soool009_oool0
10000?ooooooo`0000;oool00`0003?o0000000Aoooo00?o09Woooooool0J?ooo`00W?ooo`800004
oooo0P00017oool00ol0VOooooooo`1Xoooo002Roooo0P00017oool00ol0VOooooooo`1Xoooo002R
oooo0P00017oool00ol0VOooooooo`1Xoooo002Roooo0P00017oool00ol0VOooooooo`1Xoooo002R
oooo0`00013oool00ol0VOooooooo`1Xoooo002Roooo0P00017oool00ol0VOooooooo`1Xoooo002R
oooo0P00017oool00ol0VOooooooo`1Xoooo002Roooo0P00017oool00ol0VOooooooo`1Xoooo002R
oooo0P00017oool00ol0VOooooooo`1Xoooo002Roooo0P00017oool00ol0VOooooooo`1Xoooo002R
oooo0`00013oool00ol0VOooooooo`1Xoooo002Roooo0P00017oool00ol0VOooooooo`1Xoooo002R
oooo0P00017oool00ol0VOooooooo`1Xoooo002Roooo0P00017oool00ol0VOooooooo`1Xoooo002R
oooo0P00017oool00ol0VOooooooo`1Xoooo002Roooo0P00017oool00ol0VOooooooo`1Xoooo002R
oooo0`00013oool00ol0VOooooooo`1Xoooo002Soooo00<0003oooooool03oooo`03o`2Ioooooooo
06Soool00:?oool00`000?ooooooo`0?oooo00?o09Woooooool0J?ooo`00Xoooo`030000oooooooo
00ooool00ol0VOooooooo`1Xoooo002Soooo00<0003oooooool03oooo`03o`2Ioooooooo06Soool0
0:?oool00`000?ooooooo`0?oooo00?o09Woooooool0J?ooo`00Xoooo`80000@oooo00?o09Wooooo
ool0J?ooo`00Xoooo`030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Soooo00<0003ooooo
ool03oooo`03o`2Ioooooooo06Soool00:?oool00`000?ooooooo`0?oooo00?o09Woooooool0J?oo
o`00Xoooo`030000oooooooo00ooool00ol0VOooooooo`1Xoooo002Moooo0`0000?oool00`000?oo
ooooo`0?oooo00?o09Woooooool0J?ooo`00W_ooo`030000oooooooo00;oool00`000?ooooooo`0?
oooo00?o09Woooooool0J?ooo`00Voooo`D00003oooo0`0000ooool00ol0VOooooooo`1Xoooo002K
oooo00@0003oooooool00021oooo002Loooo00<0003oool00000POooo`00WOooo`800021oooo003o
oooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?oo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo1@0000;oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003ooooo
ool0000:oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00004_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?oo
ooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.64043 .12361 L
.64559 .12361 L
.65045 .12361 L
.65482 .12361 L
.65602 .12361 L
.65728 .12361 L
.65836 .12361 L
s
.65836 .12361 m
.65883 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_oo
o`@0000K<ol000<0003oooooool04Oooo`03o`2Ioooooooo017oool00`000?ooooooo`0Voooo00<0
003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool0
08coool00`0003?o03?o000D<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool008goool2
000053?o00030000oooooooo017oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`004C?o
00030000oooooooo017oool00ol0VOooooooo`1Voooo002@oooo00<0000co`0co`0043?o0080000B
oooo00?o09Woooooool0I_ooo`00TOooo`80000@<ol000<0003oooooool04Oooo`03o`2Ioooooooo
06Koool009?oool00`0003?o03?o000=<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool0
09?oool00`0003?o03?o000=<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009Coool0
0`0003?o03?o000<<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009Coool00`0003?o
03?o000<<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009Goool00`0003?o03?o000;
<ol00P0001;oool00ol0VOooooooo`1Voooo002Eoooo00<0000co`0co`002c?o00030000oooooooo
017oool00ol0VOooooooo`1Voooo002Foooo00<0000co`0co`002S?o00030000oooooooo017oool0
0ol0VOooooooo`1Voooo002Foooo00<0000co`0co`002S?o00030000oooooooo017oool00ol0VOoo
ooooo`1Voooo002Goooo00<0000co`0co`002C?o00030000oooooooo017oool00ol0VOooooooo`1V
oooo002Goooo00<0000co`0co`002C?o00030000oooooooo017oool00ol0VOooooooo`1Voooo002H
oooo00<0000co`0co`0023?o0080000Boooo00?o09Woooooool0I_ooo`00V?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0Aoooo00?o09Woooooool0I_ooo`00V?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0Aoooo00?o09Woooooool0I_ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Aoooo00?o09Woooooool0I_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0A
oooo00?o09Woooooool0I_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0Aoooo00?o
09Woooooool0I_ooo`00VOooo`030000<ol0<ol000Lco`0200004_ooo`03o`2Ioooooooo06Koool0
09[oool00`0003?o03?o0006<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009[oool0
0`0003?o03?o0006<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009[oool00`0003?o
03?o0006<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009[oool00`0003?o03?o0006
<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009_oool500000c?o00030000oooooooo
017oool00ol0VOooooooo`1Voooo002Koooo00<0000co`0000001C?o00030000oooooooo017oool0
0ol0VOooooooo`1Voooo002Koooo00<0000co`0000001C?o00<0000Aoooo00?o09Woooooool0I_oo
o`00W?ooo`800005<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009coool200001C?o
00030000oooooooo017oool00ol0VOooooooo`1Voooo002Loooo0P0000Dco`000`000?ooooooo`0A
oooo00?o09Woooooool0I_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0Aoooo00?o
09Woooooool0I_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0Aoooo00?o09Wooooo
ool0I_ooo`00W?ooo`030000<ol0<ol000@co`0200004_ooo`03o`2Ioooooooo06Koool009goool0
0`0003?o03?o0003<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009goool00`0003?o
03?o0003<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009goool00`0003?o03?o0003
<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool009goool00`0003?o03?o0003<ol000<0
003oooooool04Oooo`03o`2Ioooooooo06Koool009goool00`0003?o03?o0003<ol000<0003ooooo
ool04Oooo`03o`2Ioooooooo06Koool009goool00`0003?o03?o0003<ol00P0001;oool00ol0VOoo
ooooo`1Voooo002Moooo00<0000co`0co`000c?o00030000oooooooo017oool00ol0VOooooooo`1V
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo017oool00ol0VOooooooo`1Voooo002N
oooo00<0000co`0co`000S?o00030000oooooooo017oool00ol0VOooooooo`1Voooo002Noooo00<0
000co`0co`000S?o00030000oooooooo017oool00ol0VOooooooo`1Voooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo017oool00ol0VOooooooo`1Voooo002Noooo00<0000co`0co`000S?o
00030000oooooooo017oool00ol0VOooooooo`1Voooo002Noooo00<0000co`0co`000S?o0080000B
oooo00?o09Woooooool0I_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Aoooo00?o
09Woooooool0I_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Aoooo00?o09Wooooo
ool0I_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Aoooo00?o09Woooooool0I_oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Aoooo00?o09Woooooool0I_ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`0Aoooo00?o09Woooooool0I_ooo`00W_ooo`030000
<ol0<ol0008co`0200004_ooo`03o`2Ioooooooo06Koool009ooool01@0003?o03?o03?o0000000C
oooo00?o09Woooooool0I_ooo`00Woooo`050000<ol0<ol0<ol0000001?oool00ol0VOooooooo`1V
oooo002Ooooo00D0000co`0co`0co`0000004oooo`03o`2Ioooooooo06Koool009_oool500000c?o
00030000oooooooo017oool00ol0VOooooooo`1Voooo002Koooo00D0003oooooooooool000000c?o
00030000oooooooo017oool00ol0VOooooooo`1Voooo002Loooo00@0003oooooool00003<ol00`00
017oool00ol0VOooooooo`1Voooo002Moooo00<0003oool000000c?o00030000oooooooo017oool0
0ol0VOooooooo`1Voooo002Koooo00<0003oooooool00P0000<co`000`000?ooooooo`0Aoooo00?o
09Woooooool0I_ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003oooooool04Oooo`03o`2I
oooooooo06Koool009ooool01@0003?o03?o03?o0000000Coooo00?o09Woooooool0I_ooo`00X?oo
o`040000<ol0<ol000004oooo`03o`2Ioooooooo06Koool00:3oool00`0003?o03?o000200004_oo
o`03o`2Ioooooooo06Koool00:3oool0100003?o03?o000001?oool00ol0VOooooooo`1Voooo002P
oooo00@0000co`0co`00000Coooo00?o09Woooooool0I_ooo`00X?ooo`040000<ol0<ol000004ooo
o`03o`2Ioooooooo06Koool00:3oool0100003?o03?o000001?oool00ol0VOooooooo`1Voooo002P
oooo00@0000co`0co`00000Coooo00?o09Woooooool0I_ooo`00X?ooo`040000<ol0<ol000004ooo
o`03o`2Ioooooooo06Koool00:7oool0100003?o0000000001;oool00ol0VOooooooo`1Voooo002Q
oooo00<0000co`0000004oooo`03o`2Ioooooooo06Koool00:7oool00`0003?o0000000Coooo00?o
09Woooooool0I_ooo`00XOooo`030000<ol0000001?oool00ol0VOooooooo`1Voooo002Qoooo00<0
000co`0000004oooo`03o`2Ioooooooo06Koool00:7oool00`0003?o0000000Coooo00?o09Wooooo
ool0I_ooo`00XOooo`040000<ol0000000004_ooo`03o`2Ioooooooo06Koool00:7oool00`0003?o
0000000Coooo00?o09Woooooool0I_ooo`00XOooo`030000<ol0000001?oool00ol0VOooooooo`1V
oooo002Qoooo00<0000co`0000004oooo`03o`2Ioooooooo06Koool00:7oool00`0003?o0000000C
oooo00?o09Woooooool0I_ooo`00XOooo`030000<ol0000001?oool00ol0VOooooooo`1Voooo002Q
oooo00@0000co`000000000Boooo00?o09Woooooool0I_ooo`00XOooo`030000<ol0000001?oool0
0ol0VOooooooo`1Voooo002Qoooo00<0000co`0000004oooo`03o`2Ioooooooo06Koool00:7oool0
0`0003?o0000000Coooo00?o09Woooooool0I_ooo`00W?ooo`800003oooo00<0000co`0000004ooo
o`03o`2Ioooooooo06Koool009_oool010000?ooooooo`0000;oool00`0003?o0000000Coooo00?o
09Woooooool0I_ooo`00WOooo`060000oooooooooooo0000<ol00`00017oool00ol0VOooooooo`1V
oooo002Noooo00H0003oooooool0000co`00000Coooo00?o09Woooooool0I_ooo`00Voooo`040000
oooooooo00000_ooo`030000<ol0000001?oool00ol0VOooooooo`1Voooo002Loooo0P0000Coool2
00004oooo`03o`2Ioooooooo06Koool00:;oool200004oooo`03o`2Ioooooooo06Koool00:;oool2
00004oooo`03o`2Ioooooooo06Koool00:;oool200004oooo`03o`2Ioooooooo06Koool00:;oool3
00004_ooo`03o`2Ioooooooo06Koool00:;oool200004oooo`03o`2Ioooooooo06Koool00:;oool2
00004oooo`03o`2Ioooooooo06Koool00:;oool200004oooo`03o`2Ioooooooo06Koool00:;oool2
00004oooo`03o`2Ioooooooo06Koool00:;oool200004oooo`03o`2Ioooooooo06Koool00:;oool3
00004_ooo`03o`2Ioooooooo06Koool00:;oool200004oooo`03o`2Ioooooooo06Koool00:;oool2
00004oooo`03o`2Ioooooooo06Koool00:;oool200004oooo`03o`2Ioooooooo06Koool00:;oool2
00004oooo`03o`2Ioooooooo06Koool00:;oool200004oooo`03o`2Ioooooooo06Koool00:;oool3
00004_ooo`03o`2Ioooooooo06Koool00:?oool00`000?ooooooo`0Aoooo00?o09Woooooool0I_oo
o`00Xoooo`030000oooooooo017oool00ol0VOooooooo`1Voooo002Soooo00<0003oooooool04Ooo
o`03o`2Ioooooooo06Koool00:?oool00`000?ooooooo`0Aoooo00?o09Woooooool0I_ooo`00Xooo
o`030000oooooooo017oool00ol0VOooooooo`1Voooo002Soooo0P0001;oool00ol0VOooooooo`1V
oooo002Soooo00<0003oooooool04Oooo`03o`2Ioooooooo06Koool00:?oool00`000?ooooooo`0A
oooo00?o09Woooooool0I_ooo`00Xoooo`030000oooooooo017oool00ol0VOooooooo`1Voooo002S
oooo00<0003oooooool04Oooo`03o`2Ioooooooo06Koool009goool300000oooo`030000oooooooo
017oool00ol0VOooooooo`1Voooo002Noooo00<0003oooooool00_ooo`030000oooooooo017oool0
0ol0VOooooooo`1Voooo002Koooo1@0000?oool300004Oooo`03o`2Ioooooooo06Koool009_oool0
10000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQ
oooo003ooooo8Oooo`00Ooooo`030000oooooooo01coool00`000?ooooooo`1ooooo001noooo00<0
003oooooool02?ooo`030000oooooooo01?oool00`000?ooooooo`1noooo001noooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Coool00`000?ooooooo`1n
oooo001noooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool00009oooo00<0003oooooool0O_ooo`00OOooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0003oooooool0000:oooo00<0003oooooool0OOooo`00O_ooo`030000
oooooooo00D0000<oooo00@0003oooooool00009oooo00<0003oooooool0O_ooo`00O_ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`1noooo001ooooo00<0
003oooooool04Oooo`800009oooo00<0003oooooool0Ooooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66177 .12361 L
.66412 .12361 L
.66534 .12361 L
.66604 .12361 L
s
.66604 .12361 m
.6663 .61803 L
s
0 .4 1 r
.02381 .1236 m
.04262 .1236 L
.06244 .1236 L
.07286 .12359 L
.08255 .12359 L
.09388 .12359 L
.10458 .12359 L
.125 .12358 L
.14357 .12356 L
.16355 .12355 L
.18199 .12352 L
.20071 .12349 L
.21136 .12346 L
.22134 .12344 L
.24158 .12336 L
.26011 .12327 L
.27909 .12313 L
.28984 .12303 L
.29982 .12291 L
.32034 .12261 L
.33895 .12221 L
.35819 .12164 L
.36904 .12123 L
.37901 .12076 L
.39784 .11963 L
.40853 .11879 L
.4185 .11786 L
.43885 .11534 L
.45741 .11209 L
.4765 .10738 L
.48172 .10578 L
.48728 .10391 L
.48956 .10308 L
.49076 .10263 L
.49202 .10214 L
.49269 .10287 L
.49343 .10374 L
.49472 .10531 L
.49726 .10849 L
.50254 .1156 L
.50514 .11936 L
.50628 .12106 L
.50753 .12298 L
.50865 .12361 L
.50971 .12361 L
.51089 .12361 L
.51201 .12361 L
.51323 .12361 L
.51435 .12361 L
.51555 .12361 L
Mistroke
.51687 .12361 L
.51755 .12361 L
.51829 .12361 L
.51894 .12361 L
.51963 .12361 L
.52093 .12361 L
.52213 .12361 L
.5228 .12361 L
.52352 .12361 L
.52481 .12361 L
.52559 .12361 L
.52634 .12361 L
.52701 .12361 L
.52774 .12361 L
.52895 .12361 L
.52963 .12361 L
.53028 .12361 L
.53158 .12361 L
.53231 .12361 L
.53298 .12361 L
.5341 .12361 L
.53534 .12361 L
.53662 .12361 L
.53782 .12361 L
.5391 .12361 L
.53974 .12361 L
.54045 .12361 L
.54171 .12361 L
.54288 .12361 L
.54359 .12361 L
.54427 .12361 L
.54553 .12361 L
.54623 .12361 L
.54689 .12361 L
.5476 .12361 L
.54837 .12361 L
.54954 .12361 L
.5508 .12361 L
.552 .12361 L
.55309 .12361 L
.5558 .12361 L
.55712 .12361 L
.55831 .12361 L
.55939 .12361 L
.5604 .12361 L
.56148 .12361 L
.56264 .12361 L
.56383 .12361 L
.5651 .12361 L
.56618 .12361 L
Mistroke
.56737 .12361 L
.56851 .12361 L
.56958 .12361 L
.57082 .12361 L
.57193 .12361 L
.57318 .12361 L
.57387 .12361 L
.57452 .12361 L
.57568 .12361 L
.57691 .12361 L
.5782 .12361 L
.57939 .12361 L
.58071 .12361 L
.58212 .12361 L
.58706 .12361 L
.59634 .12361 L
.61722 .12361 L
.6586 .12361 L
.69847 .12361 L
.73682 .12361 L
.77762 .12361 L
.81691 .12361 L
.85468 .12361 L
.8949 .12361 L
.93361 .12361 L
.97477 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo02?oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0Voooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200009Ooo
o`80000Toooo0P0002Goool20000:?ooo`80000Zoooo002<oooo0P1VoaGoool00`000?ooooooo`1j
oooo0027oooo1@1Vo`;oool00`1Vooooooooo`0Boooo00<0003oooooool0N_ooo`00P_ooo`D0I_l7
oooo00<0I_ooooooool04_ooo`030000oooooooo07[oool007goool506Ko3Oooo`80I_lBoooo00<0
003oooooool0N_ooo`00Loooo`X0I_lCoooo00<0I_ooooooool04?ooo`030000oooooooo07[oool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooo000001000000
0c?o000003?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07
oooo00<0003oooooool01oooo`030000ooooo`2I00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo
02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool04ooo
o`03o`2Ioooooooo00ooool00`000?ooooooo`0Voooo00<0003oooooool0:Oooo`00R?ooo`@0000G
<ol000<0003oooooool04oooo`03o`2Ioooooooo06Coool008coool00`0003?o03?o000D<ol000<0
003oooooool04oooo`03o`2Ioooooooo06Coool008goool2000053?o00030000oooooooo01?oool0
0ol0VOooooooo`1Toooo002?oooo00<0000co`0co`004C?o00030000oooooooo01?oool00ol0VOoo
ooooo`1Toooo002@oooo00<0000co`0co`0043?o0080000Doooo00?o09Woooooool0I?ooo`00TOoo
o`80000@<ol000<0003oooooool04oooo`03o`2Ioooooooo06Coool009?oool00`0003?o03?o000=
<ol000<0003oooooool04oooo`03o`2Ioooooooo06Coool009?oool00`0003?o03?o000=<ol000<0
003oooooool04oooo`03o`2Ioooooooo06Coool009Coool00`0003?o03?o000<<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo06Coool009Coool00`0003?o03?o000<<ol000<0003oooooool04ooo
o`03o`2Ioooooooo06Coool009Goool00`0003?o03?o000;<ol00P0001Coool00ol0VOooooooo`1T
oooo002Eoooo00<0000co`0co`002c?o00030000oooooooo01?oool00ol0VOooooooo`1Toooo002F
oooo00<0000co`0co`002S?o00030000oooooooo01?oool00ol0VOooooooo`1Toooo002Foooo00<0
000co`0co`002S?o00030000oooooooo01?oool00ol0VOooooooo`1Toooo002Goooo00<0000co`0c
o`002C?o00030000oooooooo01?oool00ol0VOooooooo`1Toooo002Goooo00<0000co`0co`002C?o
00030000oooooooo01?oool00ol0VOooooooo`1Toooo002Hoooo00<0000co`0co`0023?o0080000D
oooo00?o09Woooooool0I?ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0Coooo00?o
09Woooooool0I?ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0Coooo00?o09Wooooo
ool0I?ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0Coooo00?o09Woooooool0I?oo
o`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00VOoo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00VOooo`030000
<ol0<ol000Lco`0200005?ooo`03o`2Ioooooooo06Coool009[oool00`0003?o03?o0006<ol000<0
003oooooool04oooo`03o`2Ioooooooo06Coool009[oool00`0003?o03?o0006<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo06Coool009[oool00`0003?o03?o0006<ol000<0003oooooool04ooo
o`03o`2Ioooooooo06Coool009[oool00`0003?o03?o0006<ol000<0003oooooool04oooo`03o`2I
oooooooo06Coool009_oool500000c?o00030000oooooooo01?oool00ol0VOooooooo`1Toooo002K
oooo00<0000co`0000001C?o00030000oooooooo01?oool00ol0VOooooooo`1Toooo002Koooo00<0
000co`0000001C?o00<0000Coooo00?o09Woooooool0I?ooo`00W?ooo`800005<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo06Coool009coool200001C?o00030000oooooooo01?oool00ol0VOoo
ooooo`1Toooo002Loooo0P0000Dco`000`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00W?oo
o`030000<ol0<ol000@co`000`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00W?ooo`030000
<ol0<ol000@co`000`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00W?ooo`030000<ol0<ol0
00@co`0200005?ooo`03o`2Ioooooooo06Coool009goool00`0003?o03?o0003<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo06Coool009goool00`0003?o03?o0003<ol000<0003oooooool04ooo
o`03o`2Ioooooooo06Coool009goool00`0003?o03?o0003<ol000<0003oooooool04oooo`03o`2I
oooooooo06Coool009goool00`0003?o03?o0003<ol000<0003oooooool04oooo`03o`2Ioooooooo
06Coool009goool00`0003?o03?o0003<ol000<0003oooooool04oooo`03o`2Ioooooooo06Coool0
09goool00`0003?o03?o0003<ol00P0001Coool00ol0VOooooooo`1Toooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo01?oool00ol0VOooooooo`1Toooo002Moooo00<0000co`0co`000c?o
00030000oooooooo01?oool00ol0VOooooooo`1Toooo002Noooo00<0000co`0co`000S?o00030000
oooooooo01?oool00ol0VOooooooo`1Toooo002Noooo00<0000co`0co`000S?o00030000oooooooo
01?oool00ol0VOooooooo`1Toooo002Noooo00<0000co`0co`000S?o00030000oooooooo01?oool0
0ol0VOooooooo`1Toooo002Noooo00<0000co`0co`000S?o00030000oooooooo01?oool00ol0VOoo
ooooo`1Toooo002Noooo00<0000co`0co`000S?o0080000Doooo00?o09Woooooool0I?ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0Coooo00?o09Woooooool0I?ooo`00W_ooo`030000<ol0<ol0008co`0200005?ooo`03o`2I
oooooooo06Coool009ooool01@0003?o03?o03?o0000000Eoooo00?o09Woooooool0I?ooo`00Wooo
o`050000<ol0<ol0<ol0000001Goool00ol0VOooooooo`1Toooo002Ooooo00D0000co`0co`0co`00
00005Oooo`03o`2Ioooooooo06Coool009_oool500000c?o00030000oooooooo01?oool00ol0VOoo
ooooo`1Toooo002Koooo00D0003oooooooooool000000c?o00030000oooooooo01?oool00ol0VOoo
ooooo`1Toooo002Loooo00@0003oooooool00003<ol00`0001?oool00ol0VOooooooo`1Toooo002M
oooo00<0003oool000000c?o00030000oooooooo01?oool00ol0VOooooooo`1Toooo002Koooo00<0
003oooooool00P0000<co`000`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00W?ooo`800000
0oooo`0003?o0002<ol000<0003oooooool04oooo`03o`2Ioooooooo06Coool009ooool01@0003?o
03?o03?o0000000Eoooo00?o09Woooooool0I?ooo`00X?ooo`040000<ol0<ol000005Oooo`03o`2I
oooooooo06Coool00:3oool00`0003?o03?o000200005?ooo`03o`2Ioooooooo06Coool00:3oool0
100003?o03?o000001Goool00ol0VOooooooo`1Toooo002Poooo00@0000co`0co`00000Eoooo00?o
09Woooooool0I?ooo`00X?ooo`040000<ol0<ol000005Oooo`03o`2Ioooooooo06Coool00:3oool0
100003?o03?o000001Goool00ol0VOooooooo`1Toooo002Poooo00@0000co`0co`00000Eoooo00?o
09Woooooool0I?ooo`00X?ooo`040000<ol0<ol000005Oooo`03o`2Ioooooooo06Coool00:7oool0
100003?o0000000001Coool00ol0VOooooooo`1Toooo002Qoooo00<0000co`0000005Oooo`03o`2I
oooooooo06Coool00:7oool00`0003?o0000000Eoooo00?o09Woooooool0I?ooo`00XOooo`030000
<ol0000001Goool00ol0VOooooooo`1Toooo002Qoooo00<0000co`0000005Oooo`03o`2Ioooooooo
06Coool00:7oool00`0003?o0000000Eoooo00?o09Woooooool0I?ooo`00XOooo`040000<ol00000
00005?ooo`03o`2Ioooooooo06Coool00:7oool00`0003?o0000000Eoooo00?o09Woooooool0I?oo
o`00XOooo`030000<ol0000001Goool00ol0VOooooooo`1Toooo002Qoooo00<0000co`0000005Ooo
o`03o`2Ioooooooo06Coool00:7oool00`0003?o0000000Eoooo00?o09Woooooool0I?ooo`00XOoo
o`030000<ol0000001Goool00ol0VOooooooo`1Toooo002Qoooo00@0000co`000000000Doooo00?o
09Woooooool0I?ooo`00XOooo`030000<ol0000001Goool00ol0VOooooooo`1Toooo002Qoooo00<0
000co`0000005Oooo`03o`2Ioooooooo06Coool00:7oool00`0003?o0000000Eoooo00?o09Wooooo
ool0I?ooo`00W?ooo`800003oooo00<0000co`0000005Oooo`03o`2Ioooooooo06Coool009_oool0
10000?ooooooo`0000;oool00`0003?o0000000Eoooo00?o09Woooooool0I?ooo`00WOooo`060000
oooooooooooo0000<ol00`0001?oool00ol0VOooooooo`1Toooo002Noooo00H0003oooooool0000c
o`00000Eoooo00?o09Woooooool0I?ooo`00Voooo`040000oooooooo00000_ooo`030000<ol00000
01Goool00ol0VOooooooo`1Toooo002Loooo0P0000Coool200005Oooo`03o`2Ioooooooo06Coool0
0:;oool200005Oooo`03o`2Ioooooooo06Coool00:;oool200005Oooo`03o`2Ioooooooo06Coool0
0:;oool200005Oooo`03o`2Ioooooooo06Coool00:;oool300005?ooo`03o`2Ioooooooo06Coool0
0:;oool200005Oooo`03o`2Ioooooooo06Coool00:;oool200005Oooo`03o`2Ioooooooo06Coool0
0:;oool200005Oooo`03o`2Ioooooooo06Coool00:;oool200005Oooo`03o`2Ioooooooo06Coool0
0:;oool200005Oooo`03o`2Ioooooooo06Coool00:;oool300005?ooo`03o`2Ioooooooo06Coool0
0:;oool200005Oooo`03o`2Ioooooooo06Coool00:;oool200005Oooo`03o`2Ioooooooo06Coool0
0:;oool200005Oooo`03o`2Ioooooooo06Coool00:;oool200005Oooo`03o`2Ioooooooo06Coool0
0:;oool200005Oooo`03o`2Ioooooooo06Coool00:;oool300005?ooo`03o`2Ioooooooo06Coool0
0:?oool00`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00Xoooo`030000oooooooo01?oool0
0ol0VOooooooo`1Toooo002Soooo00<0003oooooool04oooo`03o`2Ioooooooo06Coool00:?oool0
0`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00Xoooo`030000oooooooo01?oool00ol0VOoo
ooooo`1Toooo002Soooo0P0001Coool00ol0VOooooooo`1Toooo002Soooo00<0003oooooool04ooo
o`03o`2Ioooooooo06Coool00:?oool00`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00Xooo
o`030000oooooooo01?oool00ol0VOooooooo`1Toooo002Soooo00<0003oooooool04oooo`03o`2I
oooooooo06Coool009goool300000oooo`030000oooooooo01?oool00ol0VOooooooo`1Toooo002N
oooo00<0003oooooool00_ooo`030000oooooooo01?oool00ol0VOooooooo`1Toooo002Koooo1@00
00?oool300004oooo`03o`2Ioooooooo06Coool009_oool010000?ooooooo`00087oool009coool0
0`000?ooo`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000
oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo
01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004oooo0P0000?oool500000_ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500003?ooo`040000oooooooo00002_ooo`030000oooooooo
00;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo
00002_ooo`030000oooooooo00;oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Ooo
o`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66412 .12361 L
.66906 .12361 L
.67133 .12361 L
.67257 .12361 L
.67373 .12361 L
s
.67373 .12361 m
.67413 .61803 L
s
0 .4 1 r
.02381 .1236 m
.04262 .12359 L
.06244 .12359 L
.07286 .12358 L
.08255 .12358 L
.09388 .12357 L
.10458 .12356 L
.125 .12354 L
.14357 .12352 L
.16355 .12348 L
.18199 .12344 L
.20071 .12337 L
.21136 .12332 L
.22134 .12326 L
.24158 .12311 L
.26011 .12292 L
.27909 .12264 L
.28984 .12243 L
.29982 .12221 L
.32034 .12159 L
.33895 .12079 L
.35819 .11964 L
.36904 .1188 L
.37901 .11786 L
.39784 .11557 L
.40853 .11389 L
.4185 .11199 L
.43885 .10691 L
.45741 .10034 L
.46666 .09614 L
.4765 .09084 L
.48162 .08767 L
.48303 .08675 L
.48382 .08622 L
.48454 .08638 L
.48518 .08694 L
.48587 .08757 L
.48728 .08886 L
.49726 .09902 L
.50734 .11131 L
.5123 .11822 L
.51447 .12145 L
.51571 .12335 L
.51687 .12361 L
.5181 .12361 L
.51879 .12361 L
.51942 .12361 L
.52009 .12361 L
.52081 .12361 L
.52213 .12361 L
Mistroke
.52289 .12361 L
.52357 .12361 L
.52436 .12361 L
.5251 .12361 L
.52642 .12361 L
.52716 .12361 L
.52784 .12361 L
.52904 .12361 L
.53016 .12361 L
.53138 .12361 L
.5327 .12361 L
.53336 .12361 L
.53407 .12361 L
.53538 .12361 L
.53665 .12361 L
.53782 .12361 L
.53896 .12361 L
.54016 .12361 L
.54136 .12361 L
.54268 .12361 L
.54382 .12361 L
.54504 .12361 L
.5462 .12361 L
.54724 .12361 L
.54789 .12361 L
.54858 .12361 L
.54981 .12361 L
.55049 .12361 L
.55113 .12361 L
.55184 .12361 L
.55259 .12361 L
.55324 .12361 L
.55394 .12361 L
.55522 .12361 L
.55647 .12361 L
.55763 .12361 L
.55883 .12361 L
.56013 .12361 L
.56135 .12361 L
.56247 .12361 L
.56371 .12361 L
.56442 .12361 L
.56507 .12361 L
.56577 .12361 L
.5664 .12361 L
.56713 .12361 L
.56782 .12361 L
.56913 .12361 L
.56985 .12361 L
.57052 .12361 L
Mistroke
.57171 .12361 L
.57301 .12361 L
.57374 .12361 L
.57443 .12361 L
.57573 .12361 L
.57645 .12361 L
.57713 .12361 L
.57786 .12361 L
.57865 .12361 L
.57989 .12361 L
.5806 .12361 L
.58126 .12361 L
.58401 .12361 L
.58895 .12361 L
.60008 .12361 L
.62025 .12361 L
.65918 .12361 L
.70056 .12361 L
.74043 .12361 L
.77878 .12361 L
.81958 .12361 L
.85887 .12361 L
.89664 .12361 L
.93686 .12361 L
.97557 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool00:?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool4
00008oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool08_ooo`030000oooooooo02Coool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500009?ooo`030000
oooooooo00[oool206Ko5oooo`030000oooooooo02Coool00`000?ooooooo`0Uoooo1@0002Woool0
02Goool400000_ooo`<0000Poooo100000;oool010000?ooooooo`0001koool400001?ooo`030000
oooooooo00Soool0101Vooooooooo`1VoaKoool00`000?ooooooo`0Uoooo00<0003oooooool09?oo
o`040000oooooooo0000:_ooo`00;?ooo`030000oooooooo02Koool00`000?ooo`00000Toooo00@0
003oooooool00007oooo0P1Vo`Coool00`1Vooooooooo`0Coooo00<0003oooooool08oooo`040000
oooooooo00009_ooo`030000oooo000002[oool002coool300009oooo`80000Uoooo0P0000Koool2
06Ko1oooo`0306Kooooooooo01;oool200009Oooo`80000Xoooo0P0002[oool008;oool306Ko2_oo
o`0306Kooooooooo017oool00`000?ooooooo`1joooo001moooo1@1Vo`koool00`1Vooooooooo`0@
oooo00<0003oooooool0N_ooo`00N_ooo`<0I_lDoooo00<0I_ooooooool03oooo`030000oooooooo
07[oool007?oool706Ko5oooo`0306Kooooooooo00ooool00`000?ooooooo`1joooo001Yoooo2P1V
oaooool00`1Vooooooooo`0>oooo00<0003oooooool0N_ooo`004?ooool0000Aoooo000Foooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oool0000040000003<ol00000<ol000Pco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00D0
003ooooooooooooo09T01Oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`0Eoooo000Zoooo00<0003oooooool09_ooo`030000oooooooo
02Goool00`000?ooooooo`06oooo100001/co`000`000?ooooooo`0Eoooo00?o09Woooooool03Ooo
o`030000oooooooo02Koool00`000?ooooooo`0Yoooo0028oooo100001Lco`000`000?ooooooo`0E
oooo00?o09Woooooool0H_ooo`00S?ooo`030000<ol0<ol001@co`000`000?ooooooo`0Eoooo00?o
09Woooooool0H_ooo`00SOooo`80000D<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool0
08ooool00`0003?o03?o000A<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool0093oool0
0`0003?o03?o000@<ol00P0001Koool00ol0VOooooooo`1Roooo002Aoooo0P00010co`000`000?oo
ooooo`0Eoooo00?o09Woooooool0H_ooo`00Toooo`030000<ol0<ol000dco`000`000?ooooooo`0E
oooo00?o09Woooooool0H_ooo`00Toooo`030000<ol0<ol000dco`000`000?ooooooo`0Eoooo00?o
09Woooooool0H_ooo`00U?ooo`030000<ol0<ol000`co`000`000?ooooooo`0Eoooo00?o09Wooooo
ool0H_ooo`00U?ooo`030000<ol0<ol000`co`000`000?ooooooo`0Eoooo00?o09Woooooool0H_oo
o`00UOooo`030000<ol0<ol000/co`0200005_ooo`03o`2Ioooooooo06;oool009Goool00`0003?o
03?o000;<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool009Koool00`0003?o03?o000:
<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool009Koool00`0003?o03?o000:<ol000<0
003oooooool05Oooo`03o`2Ioooooooo06;oool009Ooool00`0003?o03?o0009<ol000<0003ooooo
ool05Oooo`03o`2Ioooooooo06;oool009Ooool00`0003?o03?o0009<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo06;oool009Soool00`0003?o03?o0008<ol00P0001Koool00ol0VOooooooo`1R
oooo002Hoooo00<0000co`0co`0023?o00030000oooooooo01Goool00ol0VOooooooo`1Roooo002H
oooo00<0000co`0co`0023?o00030000oooooooo01Goool00ol0VOooooooo`1Roooo002Ioooo00<0
000co`0co`001c?o00030000oooooooo01Goool00ol0VOooooooo`1Roooo002Ioooo00<0000co`0c
o`001c?o00030000oooooooo01Goool00ol0VOooooooo`1Roooo002Ioooo00<0000co`0co`001c?o
00030000oooooooo01Goool00ol0VOooooooo`1Roooo002Ioooo00<0000co`0co`001c?o0080000F
oooo00?o09Woooooool0H_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`0Eoooo00?o
09Woooooool0H_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`0Eoooo00?o09Wooooo
ool0H_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`0Eoooo00?o09Woooooool0H_oo
o`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`0Eoooo00?o09Woooooool0H_ooo`00Vooo
o`D00003<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool009_oool00`0003?o00000005
<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool009_oool00`0003?o00000005<ol00`00
01Goool00ol0VOooooooo`1Roooo002Loooo0P0000Dco`000`000?ooooooo`0Eoooo00?o09Wooooo
ool0H_ooo`00W?ooo`800005<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool009coool2
00001C?o00030000oooooooo01Goool00ol0VOooooooo`1Roooo002Loooo00<0000co`0co`0013?o
00030000oooooooo01Goool00ol0VOooooooo`1Roooo002Loooo00<0000co`0co`0013?o00030000
oooooooo01Goool00ol0VOooooooo`1Roooo002Loooo00<0000co`0co`0013?o0080000Foooo00?o
09Woooooool0H_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0Eoooo00?o09Wooooo
ool0H_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0Eoooo00?o09Woooooool0H_oo
o`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0Eoooo00?o09Woooooool0H_ooo`00WOoo
o`030000<ol0<ol000<co`000`000?ooooooo`0Eoooo00?o09Woooooool0H_ooo`00WOooo`030000
<ol0<ol000<co`000`000?ooooooo`0Eoooo00?o09Woooooool0H_ooo`00WOooo`030000<ol0<ol0
00<co`0200005_ooo`03o`2Ioooooooo06;oool009goool00`0003?o03?o0003<ol000<0003ooooo
ool05Oooo`03o`2Ioooooooo06;oool009goool00`0003?o03?o0003<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo06;oool009koool00`0003?o03?o0002<ol000<0003oooooool05Oooo`03o`2I
oooooooo06;oool009koool00`0003?o03?o0002<ol000<0003oooooool05Oooo`03o`2Ioooooooo
06;oool009koool00`0003?o03?o0002<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool0
09koool00`0003?o03?o0002<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool009koool0
0`0003?o03?o0002<ol00P0001Koool00ol0VOooooooo`1Roooo002Noooo00<0000co`0co`000S?o
00030000oooooooo01Goool00ol0VOooooooo`1Roooo002Noooo00<0000co`0co`000S?o00030000
oooooooo01Goool00ol0VOooooooo`1Roooo002Noooo00<0000co`0co`000S?o00030000oooooooo
01Goool00ol0VOooooooo`1Roooo002Noooo00<0000co`0co`000S?o00030000oooooooo01Goool0
0ol0VOooooooo`1Roooo002Noooo00<0000co`0co`000S?o00030000oooooooo01Goool00ol0VOoo
ooooo`1Roooo002Noooo00<0000co`0co`000S?o0080000Foooo00?o09Woooooool0H_ooo`00Wooo
o`050000<ol0<ol0<ol0000001Ooool00ol0VOooooooo`1Roooo002Ooooo00D0000co`0co`0co`00
00005oooo`03o`2Ioooooooo06;oool009ooool01@0003?o03?o03?o0000000Goooo00?o09Wooooo
ool0H_ooo`00Voooo`D00003<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool009_oool0
1@000?ooooooooooo`000003<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool009coool0
10000?ooooooo`0000<co`0300005Oooo`03o`2Ioooooooo06;oool009goool00`000?ooo`000003
<ol000<0003oooooool05Oooo`03o`2Ioooooooo06;oool009_oool00`000?ooooooo`0200000c?o
00030000oooooooo01Goool00ol0VOooooooo`1Roooo002Loooo0P000003oooo0000<ol0008co`00
0`000?ooooooo`0Eoooo00?o09Woooooool0H_ooo`00Woooo`050000<ol0<ol0<ol0000001Ooool0
0ol0VOooooooo`1Roooo002Poooo00@0000co`0co`00000Goooo00?o09Woooooool0H_ooo`00X?oo
o`030000<ol0<ol00080000Foooo00?o09Woooooool0H_ooo`00X?ooo`040000<ol0<ol000005ooo
o`03o`2Ioooooooo06;oool00:3oool0100003?o03?o000001Ooool00ol0VOooooooo`1Roooo002P
oooo00@0000co`0co`00000Goooo00?o09Woooooool0H_ooo`00X?ooo`040000<ol0<ol000005ooo
o`03o`2Ioooooooo06;oool00:3oool0100003?o03?o000001Ooool00ol0VOooooooo`1Roooo002P
oooo00@0000co`0co`00000Goooo00?o09Woooooool0H_ooo`00XOooo`040000<ol0000000005_oo
o`03o`2Ioooooooo06;oool00:7oool00`0003?o0000000Goooo00?o09Woooooool0H_ooo`00XOoo
o`030000<ol0000001Ooool00ol0VOooooooo`1Roooo002Qoooo00<0000co`0000005oooo`03o`2I
oooooooo06;oool00:7oool00`0003?o0000000Goooo00?o09Woooooool0H_ooo`00XOooo`030000
<ol0000001Ooool00ol0VOooooooo`1Roooo002Qoooo00@0000co`000000000Foooo00?o09Wooooo
ool0H_ooo`00XOooo`030000<ol0000001Ooool00ol0VOooooooo`1Roooo002Qoooo00<0000co`00
00005oooo`03o`2Ioooooooo06;oool00:7oool00`0003?o0000000Goooo00?o09Woooooool0H_oo
o`00XOooo`030000<ol0000001Ooool00ol0VOooooooo`1Roooo002Qoooo00<0000co`0000005ooo
o`03o`2Ioooooooo06;oool00:7oool0100003?o0000000001Koool00ol0VOooooooo`1Roooo002Q
oooo00<0000co`0000005oooo`03o`2Ioooooooo06;oool00:7oool00`0003?o0000000Goooo00?o
09Woooooool0H_ooo`00XOooo`030000<ol0000001Ooool00ol0VOooooooo`1Roooo002Loooo0P00
00?oool00`0003?o0000000Goooo00?o09Woooooool0H_ooo`00Voooo`040000oooooooo00000_oo
o`030000<ol0000001Ooool00ol0VOooooooo`1Roooo002Moooo00H0003oooooooooool0000co`03
00005Oooo`03o`2Ioooooooo06;oool009koool01P000?ooooooo`0003?o000001Ooool00ol0VOoo
ooooo`1Roooo002Koooo00@0003oooooool00002oooo00<0000co`0000005oooo`03o`2Ioooooooo
06;oool009coool200001?ooo`80000Goooo00?o09Woooooool0H_ooo`00X_ooo`80000Goooo00?o
09Woooooool0H_ooo`00X_ooo`80000Goooo00?o09Woooooool0H_ooo`00X_ooo`80000Goooo00?o
09Woooooool0H_ooo`00X_ooo`<0000Foooo00?o09Woooooool0H_ooo`00X_ooo`80000Goooo00?o
09Woooooool0H_ooo`00X_ooo`80000Goooo00?o09Woooooool0H_ooo`00X_ooo`80000Goooo00?o
09Woooooool0H_ooo`00X_ooo`80000Goooo00?o09Woooooool0H_ooo`00X_ooo`80000Goooo00?o
09Woooooool0H_ooo`00X_ooo`<0000Foooo00?o09Woooooool0H_ooo`00X_ooo`80000Goooo00?o
09Woooooool0H_ooo`00X_ooo`80000Goooo00?o09Woooooool0H_ooo`00X_ooo`80000Goooo00?o
09Woooooool0H_ooo`00X_ooo`80000Goooo00?o09Woooooool0H_ooo`00X_ooo`80000Goooo00?o
09Woooooool0H_ooo`00X_ooo`<0000Foooo00?o09Woooooool0H_ooo`00Xoooo`030000oooooooo
01Goool00ol0VOooooooo`1Roooo002Soooo00<0003oooooool05Oooo`03o`2Ioooooooo06;oool0
0:?oool00`000?ooooooo`0Eoooo00?o09Woooooool0H_ooo`00Xoooo`030000oooooooo01Goool0
0ol0VOooooooo`1Roooo002Soooo00<0003oooooool05Oooo`03o`2Ioooooooo06;oool00:?oool2
00005_ooo`03o`2Ioooooooo06;oool00:?oool00`000?ooooooo`0Eoooo00?o09Woooooool0H_oo
o`00Xoooo`030000oooooooo01Goool00ol0VOooooooo`1Roooo002Soooo00<0003oooooool05Ooo
o`03o`2Ioooooooo06;oool00:?oool00`000?ooooooo`0Eoooo00?o09Woooooool0H_ooo`00WOoo
o`<00003oooo00<0003oooooool05Oooo`03o`2Ioooooooo06;oool009koool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`03o`2Ioooooooo06;oool009_oool500000oooo`<0000Eoooo00?o
09Woooooool0H_ooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000oooo0000087oool0
09goool20000POooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000
oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo
07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool2
00000oooo`@00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`030000oooooooo
00Coool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0N_ooo`00Noooo`030000
oooooooo00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo
07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003
oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.66906 .12361 L
.67373 .12361 L
.67803 .12361 L
.68044 .12361 L
.68166 .12361 L
.68235 .12361 L
s
.68235 .12361 m
.68261 .61803 L
s
0 .4 1 r
.02381 .12359 m
.04262 .12358 L
.06244 .12358 L
.07286 .12357 L
.08255 .12356 L
.09388 .12355 L
.10458 .12354 L
.125 .12351 L
.14357 .12347 L
.16355 .12342 L
.18199 .12335 L
.20071 .12324 L
.21136 .12317 L
.22134 .12308 L
.24158 .12285 L
.26011 .12255 L
.27909 .12213 L
.28984 .12182 L
.29982 .12147 L
.32034 .12053 L
.33895 .11932 L
.35819 .11756 L
.36904 .11627 L
.37901 .11485 L
.39784 .11135 L
.40853 .10878 L
.4185 .10589 L
.43885 .09814 L
.45741 .08812 L
.46666 .08172 L
.47173 .07773 L
.47422 .07564 L
.47531 .07469 L
.4765 .07411 L
.4777 .07492 L
.47896 .07579 L
.48162 .07769 L
.48728 .08204 L
.49726 .09084 L
.50819 .10246 L
.51356 .10906 L
.51851 .11574 L
.52083 .1191 L
.52301 .12237 L
.5241 .12361 L
.52528 .12361 L
.52658 .12361 L
.52777 .12361 L
.52905 .12361 L
.53024 .12361 L
Mistroke
.53154 .12361 L
.53227 .12361 L
.53293 .12361 L
.53414 .12361 L
.53545 .12361 L
.53668 .12361 L
.53782 .12361 L
.539 .12361 L
.54008 .12361 L
.54133 .12361 L
.54251 .12361 L
.5436 .12361 L
.5446 .12361 L
.54571 .12361 L
.54688 .12361 L
.54805 .12361 L
.54932 .12361 L
.55051 .12361 L
.55161 .12361 L
.55282 .12361 L
.55351 .12361 L
.55415 .12361 L
.55544 .12361 L
.55616 .12361 L
.55682 .12361 L
.55807 .12361 L
.5587 .12361 L
.5594 .12361 L
.56062 .12361 L
.56177 .12361 L
.56246 .12361 L
.56312 .12361 L
.56436 .12361 L
.56505 .12361 L
.56569 .12361 L
.56639 .12361 L
.56713 .12361 L
.56936 .12361 L
.57053 .12361 L
.57176 .12361 L
.57241 .12361 L
.57313 .12361 L
.57439 .12361 L
.57567 .12361 L
.57686 .12361 L
.57813 .12361 L
.57878 .12361 L
.57948 .12361 L
.58073 .12361 L
.5819 .12361 L
Mistroke
.58737 .12361 L
.59729 .12361 L
.61587 .12361 L
.65467 .12361 L
.69591 .12361 L
.73564 .12361 L
.77385 .12361 L
.81452 .12361 L
.85367 .12361 L
.89527 .12361 L
.93536 .12361 L
.97393 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0003oooooool0N_oo
o`00Xoooo`030000oooooooo07[oool008Soool306Ko6?ooo`80001koooo000[oooo0`0002Soool3
00008oooo`@00008oooo00<0I_ooool0I_l06?ooo`030000oooooooo02?oool400009oooo`<0000Y
oooo000[oooo00@0003oooooool0000Xoooo00<0003oooooool08_ooo`030000oooooooo00Ooool2
06Ko0oooo`80I_lFoooo00<0003oooooool08oooo`030000oooooooo02Woool00`000?ooooooo`0X
oooo000[oooo00@0003oooooool0000Uoooo1@0002Coool00`000?ooooooo`04oooo0P1Vo`Ooool0
0`1Vooooooooo`0Coooo00<0003oooooool09?ooo`030000oooooooo02Goool50000:Oooo`009Ooo
o`@00002oooo0`00023oool400000_ooo`040000oooooooo00007_ooo`@00004oooo00@0003ooooo
ooooool206Ko2_ooo`0306Kooooooooo01;oool00`000?ooooooo`0Uoooo00<0003oooooool09?oo
o`040000oooooooo0000:_ooo`00;?ooo`030000oooooooo02Koool00`000?ooo`00000Toooo00@0
003oooooool0000206Ko3Oooo`0306Kooooooooo017oool00`000?ooooooo`0Soooo00@0003ooooo
ool0000Voooo00<0003oool00000:_ooo`00;?ooo`<0000Woooo0P0002Goool2000000<0I_oooooo
ool03_ooo`0306Kooooooooo013oool200009Oooo`80000Xoooo0P0002[oool007coool206Ko4ooo
o`0306Kooooooooo00ooool00`000?ooooooo`1joooo001joooo0P1VoaGoool00`1Vooooooooo`0?
oooo00<0003oooooool0N_ooo`00Loooo`L0I_lHoooo00<0I_ooooooool03_ooo`030000oooooooo
07[oool0073oool306Ko8?ooo`80I_l>oooo00<0003oooooool0N_ooo`00I?ooo``0I_lToooo00<0
I_ooooooool03?ooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00?oool01Ol0VOooooooooooo`000009oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0
003oooooool01_ooo`@0000K<ol000<0003oooooool05oooo`03o`2Ioooooooo00_oool00`000?oo
ooooo`0Voooo00<0003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool05oooo`03o`2I
oooooooo063oool008coool00`0003?o03?o000D<ol000<0003oooooool05oooo`03o`2Ioooooooo
063oool008goool2000053?o00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002?oooo00<0
000co`0co`004C?o00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002@oooo00<0000co`0c
o`0043?o0080000Hoooo00?o09Woooooool0H?ooo`00TOooo`80000@<ol000<0003oooooool05ooo
o`03o`2Ioooooooo063oool009?oool00`0003?o03?o000=<ol000<0003oooooool05oooo`03o`2I
oooooooo063oool009?oool00`0003?o03?o000=<ol000<0003oooooool05oooo`03o`2Ioooooooo
063oool009Coool00`0003?o03?o000<<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool0
09Coool00`0003?o03?o000<<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool009Goool0
0`0003?o03?o000;<ol00P0001Soool00ol0VOooooooo`1Poooo002Eoooo00<0000co`0co`002c?o
00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002Foooo00<0000co`0co`002S?o00030000
oooooooo01Ooool00ol0VOooooooo`1Poooo002Foooo00<0000co`0co`002S?o00030000oooooooo
01Ooool00ol0VOooooooo`1Poooo002Goooo00<0000co`0co`002C?o00030000oooooooo01Ooool0
0ol0VOooooooo`1Poooo002Goooo00<0000co`0co`002C?o00030000oooooooo01Ooool00ol0VOoo
ooooo`1Poooo002Hoooo00<0000co`0co`0023?o0080000Hoooo00?o09Woooooool0H?ooo`00V?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`0Goooo00?o09Woooooool0H?ooo`00V?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`0Goooo00?o09Woooooool0H?ooo`00VOooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Goooo00?o09Woooooool0H?ooo`00VOooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Goooo00?o09Woooooool0H?ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Goooo00?o09Woooooool0H?ooo`00VOooo`030000<ol0<ol000Lco`0200006?ooo`03o`2I
oooooooo063oool009[oool00`0003?o03?o0006<ol000<0003oooooool05oooo`03o`2Ioooooooo
063oool009[oool00`0003?o03?o0006<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool0
09[oool00`0003?o03?o0006<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool009[oool0
0`0003?o03?o0006<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool009_oool500000c?o
00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002Koooo00<0000co`0000001C?o00030000
oooooooo01Ooool00ol0VOooooooo`1Poooo002Koooo00<0000co`0000001C?o00<0000Goooo00?o
09Woooooool0H?ooo`00W?ooo`800005<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool0
09coool200001C?o00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002Loooo0P0000Dco`00
0`000?ooooooo`0Goooo00?o09Woooooool0H?ooo`00W?ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0Goooo00?o09Woooooool0H?ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0G
oooo00?o09Woooooool0H?ooo`00W?ooo`030000<ol0<ol000@co`0200006?ooo`03o`2Ioooooooo
063oool009goool00`0003?o03?o0003<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool0
09goool00`0003?o03?o0003<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool009goool0
0`0003?o03?o0003<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool009goool00`0003?o
03?o0003<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool009goool00`0003?o03?o0003
<ol000<0003oooooool05oooo`03o`2Ioooooooo063oool009goool00`0003?o03?o0003<ol00P00
01Soool00ol0VOooooooo`1Poooo002Moooo00<0000co`0co`000c?o00030000oooooooo01Ooool0
0ol0VOooooooo`1Poooo002Moooo00<0000co`0co`000c?o00030000oooooooo01Ooool00ol0VOoo
ooooo`1Poooo002Noooo00<0000co`0co`000S?o00030000oooooooo01Ooool00ol0VOooooooo`1P
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002N
oooo00<0000co`0co`000S?o00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002Noooo00<0
000co`0co`000S?o00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002Noooo00<0000co`0c
o`000S?o0080000Hoooo00?o09Woooooool0H?ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0Goooo00?o09Woooooool0H?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0G
oooo00?o09Woooooool0H?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Goooo00?o
09Woooooool0H?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Goooo00?o09Wooooo
ool0H?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Goooo00?o09Woooooool0H?oo
o`00W_ooo`030000<ol0<ol0008co`0200006?ooo`03o`2Ioooooooo063oool009ooool01@0003?o
03?o03?o0000000Ioooo00?o09Woooooool0H?ooo`00Woooo`050000<ol0<ol0<ol0000001Woool0
0ol0VOooooooo`1Poooo002Ooooo00D0000co`0co`0co`0000006Oooo`03o`2Ioooooooo063oool0
09_oool500000c?o00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002Koooo00D0003ooooo
ooooool000000c?o00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002Loooo00@0003ooooo
ool00003<ol00`0001Ooool00ol0VOooooooo`1Poooo002Moooo00<0003oool000000c?o00030000
oooooooo01Ooool00ol0VOooooooo`1Poooo002Koooo00<0003oooooool00P0000<co`000`000?oo
ooooo`0Goooo00?o09Woooooool0H?ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003ooooo
ool05oooo`03o`2Ioooooooo063oool009ooool01@0003?o03?o03?o0000000Ioooo00?o09Wooooo
ool0H?ooo`00X?ooo`040000<ol0<ol000006Oooo`03o`2Ioooooooo063oool00:3oool00`0003?o
03?o000200006?ooo`03o`2Ioooooooo063oool00:3oool0100003?o03?o000001Woool00ol0VOoo
ooooo`1Poooo002Poooo00@0000co`0co`00000Ioooo00?o09Woooooool0H?ooo`00X?ooo`040000
<ol0<ol000006Oooo`03o`2Ioooooooo063oool00:3oool0100003?o03?o000001Woool00ol0VOoo
ooooo`1Poooo002Poooo00@0000co`0co`00000Ioooo00?o09Woooooool0H?ooo`00X?ooo`040000
<ol0<ol000006Oooo`03o`2Ioooooooo063oool00:7oool0100003?o0000000001Soool00ol0VOoo
ooooo`1Poooo002Qoooo00<0000co`0000006Oooo`03o`2Ioooooooo063oool00:7oool00`0003?o
0000000Ioooo00?o09Woooooool0H?ooo`00XOooo`030000<ol0000001Woool00ol0VOooooooo`1P
oooo002Qoooo00<0000co`0000006Oooo`03o`2Ioooooooo063oool00:7oool00`0003?o0000000I
oooo00?o09Woooooool0H?ooo`00XOooo`040000<ol0000000006?ooo`03o`2Ioooooooo063oool0
0:7oool00`0003?o0000000Ioooo00?o09Woooooool0H?ooo`00XOooo`030000<ol0000001Woool0
0ol0VOooooooo`1Poooo002Qoooo00<0000co`0000006Oooo`03o`2Ioooooooo063oool00:7oool0
0`0003?o0000000Ioooo00?o09Woooooool0H?ooo`00XOooo`030000<ol0000001Woool00ol0VOoo
ooooo`1Poooo002Qoooo00@0000co`000000000Hoooo00?o09Woooooool0H?ooo`00XOooo`030000
<ol0000001Woool00ol0VOooooooo`1Poooo002Qoooo00<0000co`0000006Oooo`03o`2Ioooooooo
063oool00:7oool00`0003?o0000000Ioooo00?o09Woooooool0H?ooo`00W?ooo`800003oooo00<0
000co`0000006Oooo`03o`2Ioooooooo063oool009_oool010000?ooooooo`0000;oool00`0003?o
0000000Ioooo00?o09Woooooool0H?ooo`00WOooo`060000oooooooooooo0000<ol00`0001Ooool0
0ol0VOooooooo`1Poooo002Noooo00H0003oooooool0000co`00000Ioooo00?o09Woooooool0H?oo
o`00Voooo`040000oooooooo00000_ooo`030000<ol0000001Woool00ol0VOooooooo`1Poooo002L
oooo0P0000Coool200006Oooo`03o`2Ioooooooo063oool00:;oool200006Oooo`03o`2Ioooooooo
063oool00:;oool200006Oooo`03o`2Ioooooooo063oool00:;oool200006Oooo`03o`2Ioooooooo
063oool00:;oool300006?ooo`03o`2Ioooooooo063oool00:;oool200006Oooo`03o`2Ioooooooo
063oool00:;oool200006Oooo`03o`2Ioooooooo063oool00:;oool200006Oooo`03o`2Ioooooooo
063oool00:;oool200006Oooo`03o`2Ioooooooo063oool00:;oool200006Oooo`03o`2Ioooooooo
063oool00:;oool300006?ooo`03o`2Ioooooooo063oool00:;oool200006Oooo`03o`2Ioooooooo
063oool00:;oool200006Oooo`03o`2Ioooooooo063oool00:;oool200006Oooo`03o`2Ioooooooo
063oool00:;oool200006Oooo`03o`2Ioooooooo063oool00:;oool200006Oooo`03o`2Ioooooooo
063oool00:;oool300006?ooo`03o`2Ioooooooo063oool00:?oool00`000?ooooooo`0Goooo00?o
09Woooooool0H?ooo`00Xoooo`030000oooooooo01Ooool00ol0VOooooooo`1Poooo002Soooo00<0
003oooooool05oooo`03o`2Ioooooooo063oool00:?oool00`000?ooooooo`0Goooo00?o09Wooooo
ool0H?ooo`00Xoooo`030000oooooooo01Ooool00ol0VOooooooo`1Poooo002Soooo0P0001Soool0
0ol0VOooooooo`1Poooo002Soooo00<0003oooooool05oooo`03o`2Ioooooooo063oool00:?oool0
0`000?ooooooo`0Goooo00?o09Woooooool0H?ooo`00Xoooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1Poooo002Soooo00<0003oooooool05oooo`03o`2Ioooooooo063oool009goool300000ooo
o`030000oooooooo01Ooool00ol0VOooooooo`1Poooo002Noooo00<0003oooooool00_ooo`030000
oooooooo01Ooool00ol0VOooooooo`1Poooo002Koooo1@0000?oool300005oooo`03o`2Ioooooooo
063oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00
087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Coool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000<oooo00@0003oooooool0000;oooo00D0003oooooooooool00000OOooo`00Noooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1l
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.67803 .12361 L
.68335 .12361 L
.68596 .12361 L
.68711 .12361 L
.68837 .12361 L
.6895 .12361 L
s
.6895 .12361 m
.68992 .61803 L
s
0 .4 1 r
.02381 .12359 m
.04262 .12358 L
.06244 .12356 L
.07286 .12356 L
.08255 .12355 L
.09388 .12353 L
.10458 .12352 L
.125 .12348 L
.14357 .12343 L
.16355 .12335 L
.18199 .12325 L
.20071 .12311 L
.21136 .123 L
.22134 .12289 L
.24158 .12257 L
.26011 .12217 L
.27909 .12159 L
.28984 .12117 L
.29982 .12069 L
.32034 .11941 L
.33895 .11775 L
.35819 .11536 L
.36904 .1136 L
.37901 .11166 L
.39784 .10689 L
.40853 .10338 L
.4185 .09944 L
.43885 .08886 L
.45741 .07519 L
.46222 .07084 L
.46485 .06829 L
.46614 .06699 L
.46732 .06578 L
.46835 .06485 L
.46942 .0654 L
.47168 .06658 L
.4765 .06926 L
.48653 .07563 L
.49726 .08379 L
.517 .10352 L
.52164 .10927 L
.52655 .1159 L
.52858 .11881 L
.53075 .12207 L
.53199 .12361 L
.53313 .12361 L
.53428 .12361 L
.53536 .12361 L
.5366 .12361 L
.53791 .12361 L
Mistroke
.53914 .12361 L
.54026 .12361 L
.54095 .12361 L
.54159 .12361 L
.54228 .12361 L
.54302 .12361 L
.54425 .12361 L
.54495 .12361 L
.54561 .12361 L
.5463 .12361 L
.54705 .12361 L
.54776 .12361 L
.54841 .12361 L
.54965 .12361 L
.55097 .12361 L
.55165 .12361 L
.55238 .12361 L
.5537 .12361 L
.55447 .12361 L
.55527 .12361 L
.55596 .12361 L
.55671 .12361 L
.55736 .12361 L
.55807 .12361 L
.55936 .12361 L
.56061 .12361 L
.56176 .12361 L
.56301 .12361 L
.56372 .12361 L
.56438 .12361 L
.56508 .12361 L
.56572 .12361 L
.56646 .12361 L
.56716 .12361 L
.56833 .12361 L
.56957 .12361 L
.57063 .12361 L
.5718 .12361 L
.57306 .12361 L
.57376 .12361 L
.57441 .12361 L
.5756 .12361 L
.57686 .12361 L
.57809 .12361 L
.57879 .12361 L
.57943 .12361 L
.58061 .12361 L
.58185 .12361 L
.58639 .12361 L
.59658 .12361 L
Mistroke
.61494 .12361 L
.65279 .12361 L
.6931 .12361 L
.73189 .12361 L
.77314 .12361 L
.81287 .12361 L
.85108 .12361 L
.89174 .12361 L
.93089 .12361 L
.9725 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Xooo
o`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo0026oooo0`1Voa[oool00`000?oo
ooooo`1joooo0025oooo00@0I_ooooooooooool206Ko6?ooo`030000oooooooo07[oool008Coool0
0`1Vooooooooo`04oooo0P1VoaKoool20000Noooo`00:oooo`<0000Xoooo0`0002?oool400000ooo
o`0306Kooooooooo00Ooool00`1Vooooooooo`0Coooo00<0003oooooool08oooo`@0000Woooo0`00
02Woool002_oool010000?ooooooo`0002Soool00`000?ooooooo`0Roooo00<0003oooooool00_oo
o`80I_l;oooo00<0I_ooooooool04_ooo`030000oooooooo02?oool00`000?ooooooo`0Yoooo00<0
003oooooool0:?ooo`00:oooo`040000oooooooo00009Oooo`D0000Toooo00@0003oooooool0I_l>
oooo00<0I_ooooooool04Oooo`030000oooooooo02Coool00`000?ooooooo`0Uoooo1@0002Woool0
02Goool400000_ooo`<0000Poooo100000;oool010000?ooooooo`0001koool400001?ooo`030000
06Kooooo00ooool00`1Vooooooooo`0@oooo00<0003oooooool09Oooo`030000oooooooo02Coool0
10000?ooooooo`0002[oool002coool00`000?ooooooo`0Voooo00<0003oool000009?ooo`040000
06Kooooo00004Oooo`0306Kooooooooo00ooool00`000?ooooooo`0Soooo00@0003oooooool0000V
oooo00<0003oool00000:_ooo`00;?ooo`<0000Woooo0P0002;oool206Ko00?oool0000000004ooo
o`0306Kooooooooo00koool200009Oooo`80000Xoooo0P0002[oool007Ooool306Ko6Oooo`0306Ko
oooooooo00goool00`000?ooooooo`1joooo001coooo101Voacoool00`1Vooooooooo`0=oooo00<0
003oooooool0N_ooo`00L?ooo`<0I_lQoooo00<0I_ooooooool03?ooo`030000oooooooo07[oool0
06Woool706Ko9Oooo`80I_l<oooo00<0003oooooool0N_ooo`00Goooo`X0I_l]oooo00<0I_oooooo
ool02_ooo`030000oooooooo07[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Goool0
0ol0VOooo`000009oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_oo
o`@0000K<ol000<0003oooooool06Oooo`03o`2Ioooooooo00Woool00`000?ooooooo`0Voooo00<0
003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool0
08coool00`0003?o03?o000D<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool008goool2
000053?o00030000oooooooo01Woool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`004C?o
00030000oooooooo01Woool00ol0VOooooooo`1Noooo002@oooo00<0000co`0co`0043?o0080000J
oooo00?o09Woooooool0G_ooo`00TOooo`80000@<ol000<0003oooooool06Oooo`03o`2Ioooooooo
05koool009?oool00`0003?o03?o000=<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool0
09?oool00`0003?o03?o000=<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009Coool0
0`0003?o03?o000<<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009Coool00`0003?o
03?o000<<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009Goool00`0003?o03?o000;
<ol00P0001[oool00ol0VOooooooo`1Noooo002Eoooo00<0000co`0co`002c?o00030000oooooooo
01Woool00ol0VOooooooo`1Noooo002Foooo00<0000co`0co`002S?o00030000oooooooo01Woool0
0ol0VOooooooo`1Noooo002Foooo00<0000co`0co`002S?o00030000oooooooo01Woool00ol0VOoo
ooooo`1Noooo002Goooo00<0000co`0co`002C?o00030000oooooooo01Woool00ol0VOooooooo`1N
oooo002Goooo00<0000co`0co`002C?o00030000oooooooo01Woool00ol0VOooooooo`1Noooo002H
oooo00<0000co`0co`0023?o0080000Joooo00?o09Woooooool0G_ooo`00V?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0Ioooo00?o09Woooooool0G_ooo`00V?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0Ioooo00?o09Woooooool0G_ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Ioooo00?o09Woooooool0G_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0I
oooo00?o09Woooooool0G_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0Ioooo00?o
09Woooooool0G_ooo`00VOooo`030000<ol0<ol000Lco`0200006_ooo`03o`2Ioooooooo05koool0
09[oool00`0003?o03?o0006<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009[oool0
0`0003?o03?o0006<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009[oool00`0003?o
03?o0006<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009[oool00`0003?o03?o0006
<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009_oool500000c?o00030000oooooooo
01Woool00ol0VOooooooo`1Noooo002Koooo00<0000co`0000001C?o00030000oooooooo01Woool0
0ol0VOooooooo`1Noooo002Koooo00<0000co`0000001C?o00<0000Ioooo00?o09Woooooool0G_oo
o`00W?ooo`800005<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009coool200001C?o
00030000oooooooo01Woool00ol0VOooooooo`1Noooo002Loooo0P0000Dco`000`000?ooooooo`0I
oooo00?o09Woooooool0G_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0Ioooo00?o
09Woooooool0G_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0Ioooo00?o09Wooooo
ool0G_ooo`00W?ooo`030000<ol0<ol000@co`0200006_ooo`03o`2Ioooooooo05koool009goool0
0`0003?o03?o0003<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009goool00`0003?o
03?o0003<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009goool00`0003?o03?o0003
<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool009goool00`0003?o03?o0003<ol000<0
003oooooool06Oooo`03o`2Ioooooooo05koool009goool00`0003?o03?o0003<ol000<0003ooooo
ool06Oooo`03o`2Ioooooooo05koool009goool00`0003?o03?o0003<ol00P0001[oool00ol0VOoo
ooooo`1Noooo002Moooo00<0000co`0co`000c?o00030000oooooooo01Woool00ol0VOooooooo`1N
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo01Woool00ol0VOooooooo`1Noooo002N
oooo00<0000co`0co`000S?o00030000oooooooo01Woool00ol0VOooooooo`1Noooo002Noooo00<0
000co`0co`000S?o00030000oooooooo01Woool00ol0VOooooooo`1Noooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo01Woool00ol0VOooooooo`1Noooo002Noooo00<0000co`0co`000S?o
00030000oooooooo01Woool00ol0VOooooooo`1Noooo002Noooo00<0000co`0co`000S?o0080000J
oooo00?o09Woooooool0G_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Ioooo00?o
09Woooooool0G_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Ioooo00?o09Wooooo
ool0G_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Ioooo00?o09Woooooool0G_oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Ioooo00?o09Woooooool0G_ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`0Ioooo00?o09Woooooool0G_ooo`00W_ooo`030000
<ol0<ol0008co`0200006_ooo`03o`2Ioooooooo05koool009ooool01@0003?o03?o03?o0000000K
oooo00?o09Woooooool0G_ooo`00Woooo`050000<ol0<ol0<ol0000001_oool00ol0VOooooooo`1N
oooo002Ooooo00D0000co`0co`0co`0000006oooo`03o`2Ioooooooo05koool009_oool500000c?o
00030000oooooooo01Woool00ol0VOooooooo`1Noooo002Koooo00D0003oooooooooool000000c?o
00030000oooooooo01Woool00ol0VOooooooo`1Noooo002Loooo00@0003oooooool00003<ol00`00
01Woool00ol0VOooooooo`1Noooo002Moooo00<0003oool000000c?o00030000oooooooo01Woool0
0ol0VOooooooo`1Noooo002Koooo00<0003oooooool00P0000<co`000`000?ooooooo`0Ioooo00?o
09Woooooool0G_ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003oooooool06Oooo`03o`2I
oooooooo05koool009ooool01@0003?o03?o03?o0000000Koooo00?o09Woooooool0G_ooo`00X?oo
o`040000<ol0<ol000006oooo`03o`2Ioooooooo05koool00:3oool00`0003?o03?o000200006_oo
o`03o`2Ioooooooo05koool00:3oool0100003?o03?o000001_oool00ol0VOooooooo`1Noooo002P
oooo00@0000co`0co`00000Koooo00?o09Woooooool0G_ooo`00X?ooo`040000<ol0<ol000006ooo
o`03o`2Ioooooooo05koool00:3oool0100003?o03?o000001_oool00ol0VOooooooo`1Noooo002P
oooo00@0000co`0co`00000Koooo00?o09Woooooool0G_ooo`00X?ooo`040000<ol0<ol000006ooo
o`03o`2Ioooooooo05koool00:7oool0100003?o0000000001[oool00ol0VOooooooo`1Noooo002Q
oooo00<0000co`0000006oooo`03o`2Ioooooooo05koool00:7oool00`0003?o0000000Koooo00?o
09Woooooool0G_ooo`00XOooo`030000<ol0000001_oool00ol0VOooooooo`1Noooo002Qoooo00<0
000co`0000006oooo`03o`2Ioooooooo05koool00:7oool00`0003?o0000000Koooo00?o09Wooooo
ool0G_ooo`00XOooo`040000<ol0000000006_ooo`03o`2Ioooooooo05koool00:7oool00`0003?o
0000000Koooo00?o09Woooooool0G_ooo`00XOooo`030000<ol0000001_oool00ol0VOooooooo`1N
oooo002Qoooo00<0000co`0000006oooo`03o`2Ioooooooo05koool00:7oool00`0003?o0000000K
oooo00?o09Woooooool0G_ooo`00XOooo`030000<ol0000001_oool00ol0VOooooooo`1Noooo002Q
oooo00@0000co`000000000Joooo00?o09Woooooool0G_ooo`00XOooo`030000<ol0000001_oool0
0ol0VOooooooo`1Noooo002Qoooo00<0000co`0000006oooo`03o`2Ioooooooo05koool00:7oool0
0`0003?o0000000Koooo00?o09Woooooool0G_ooo`00W?ooo`800003oooo00<0000co`0000006ooo
o`03o`2Ioooooooo05koool009_oool010000?ooooooo`0000;oool00`0003?o0000000Koooo00?o
09Woooooool0G_ooo`00WOooo`060000oooooooooooo0000<ol00`0001Woool00ol0VOooooooo`1N
oooo002Noooo00H0003oooooool0000co`00000Koooo00?o09Woooooool0G_ooo`00Voooo`040000
oooooooo00000_ooo`030000<ol0000001_oool00ol0VOooooooo`1Noooo002Loooo0P0000Coool2
00006oooo`03o`2Ioooooooo05koool00:;oool200006oooo`03o`2Ioooooooo05koool00:;oool2
00006oooo`03o`2Ioooooooo05koool00:;oool200006oooo`03o`2Ioooooooo05koool00:;oool3
00006_ooo`03o`2Ioooooooo05koool00:;oool200006oooo`03o`2Ioooooooo05koool00:;oool2
00006oooo`03o`2Ioooooooo05koool00:;oool200006oooo`03o`2Ioooooooo05koool00:;oool2
00006oooo`03o`2Ioooooooo05koool00:;oool200006oooo`03o`2Ioooooooo05koool00:;oool3
00006_ooo`03o`2Ioooooooo05koool00:;oool200006oooo`03o`2Ioooooooo05koool00:;oool2
00006oooo`03o`2Ioooooooo05koool00:;oool200006oooo`03o`2Ioooooooo05koool00:;oool2
00006oooo`03o`2Ioooooooo05koool00:;oool200006oooo`03o`2Ioooooooo05koool00:;oool3
00006_ooo`03o`2Ioooooooo05koool00:?oool00`000?ooooooo`0Ioooo00?o09Woooooool0G_oo
o`00Xoooo`030000oooooooo01Woool00ol0VOooooooo`1Noooo002Soooo00<0003oooooool06Ooo
o`03o`2Ioooooooo05koool00:?oool00`000?ooooooo`0Ioooo00?o09Woooooool0G_ooo`00Xooo
o`030000oooooooo01Woool00ol0VOooooooo`1Noooo002Soooo0P0001[oool00ol0VOooooooo`1N
oooo002Soooo00<0003oooooool06Oooo`03o`2Ioooooooo05koool00:?oool00`000?ooooooo`0I
oooo00?o09Woooooool0G_ooo`00Xoooo`030000oooooooo01Woool00ol0VOooooooo`1Noooo002S
oooo00<0003oooooool06Oooo`03o`2Ioooooooo05koool009goool300000oooo`030000oooooooo
01Woool00ol0VOooooooo`1Noooo002Noooo00<0003oooooool00_ooo`030000oooooooo01Woool0
0ol0VOooooooo`1Noooo002Koooo1@0000?oool300006Oooo`03o`2Ioooooooo05koool009_oool0
10000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQ
oooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0
003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Goool300000_ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool010000?ooooooo`0000_oool01@000?ooooooooooo`00001moooo001joooo00<0
003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool500000oooo`030000
oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0
003oooooool00009oooo00<0003oool000000oooo`030000oooooooo07_oool007coool00`000?oo
ooooo`0Aoooo0P0000_oool200000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.6883 .12361 L
.69289 .12361 L
.6954 .12361 L
.69662 .12361 L
.69774 .12361 L
s
.69774 .12361 m
.69822 .61803 L
s
0 .4 1 r
.02381 .12358 m
.04262 .12357 L
.06244 .12355 L
.07286 .12354 L
.08255 .12353 L
.09388 .12351 L
.10458 .12349 L
.125 .12344 L
.14357 .12338 L
.16355 .12328 L
.18199 .12315 L
.20071 .12297 L
.21136 .12283 L
.22134 .12268 L
.24158 .12228 L
.26011 .12176 L
.27909 .12101 L
.28984 .12047 L
.29982 .11986 L
.32034 .1182 L
.33895 .11608 L
.35819 .11299 L
.36904 .11073 L
.37901 .10823 L
.39784 .10209 L
.40853 .09758 L
.4185 .09251 L
.43885 .07888 L
.44785 .07108 L
.45278 .06624 L
.45741 .06129 L
.45851 .06005 L
.45968 .05871 L
.46095 .05821 L
.46212 .05866 L
.46732 .06081 L
.4765 .06509 L
.48653 .07064 L
.49726 .07773 L
.517 .09482 L
.52655 .1055 L
.53536 .11715 L
.53793 .12093 L
.53919 .12285 L
.54034 .12361 L
.54155 .12361 L
.54285 .12361 L
.54354 .12361 L
.54428 .12361 L
.54498 .12361 L
Mistroke
.54561 .12361 L
.54628 .12361 L
.54701 .12361 L
.54833 .12361 L
.54909 .12361 L
.54988 .12361 L
.55056 .12361 L
.5513 .12361 L
.55201 .12361 L
.55265 .12361 L
.5534 .12361 L
.5541 .12361 L
.55535 .12361 L
.55606 .12361 L
.55671 .12361 L
.55787 .12361 L
.55911 .12361 L
.56029 .12361 L
.56136 .12361 L
.56256 .12361 L
.56386 .12361 L
.56452 .12361 L
.56522 .12361 L
.56649 .12361 L
.56719 .12361 L
.56783 .12361 L
.56854 .12361 L
.56929 .12361 L
.57054 .12361 L
.57126 .12361 L
.57193 .12361 L
.57317 .12361 L
.57431 .12361 L
.57562 .12361 L
.57686 .12361 L
.578 .12361 L
.57922 .12361 L
.58038 .12361 L
.58144 .12361 L
.5865 .12361 L
.59675 .12361 L
.61516 .12361 L
.65475 .12361 L
.69283 .12361 L
.73336 .12361 L
.77237 .12361 L
.81383 .12361 L
.85378 .12361 L
.89222 .12361 L
.9331 .12361 L
Mistroke
.97248 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Xoooo`80001koooo002Soooo00<0003oooooool0N_ooo`00Q?oo
o`@0I_lKoooo00<0003oooooool0N_ooo`00Q?ooo`0506Kooooooooooooo06Ko01[oool00`000?oo
ooooo`1joooo0023oooo00<0I_ooooooool00oooo`80I_lHoooo00<0003oooooool0N_ooo`00P_oo
o`0306Kooooooooo00Koool206Ko5_ooo`030000oooooooo07[oool0083oool206Ko2oooo`0306Ko
oooooooo01?oool20000Noooo`00:oooo`<0000Xoooo0`0002?oool400003_ooo`0306Kooooooooo
01;oool00`000?ooooooo`0Soooo100002Ooool30000:Oooo`00:oooo`040000oooooooo0000:?oo
o`030000oooooooo02;oool00`000?ooo`1Vo`0@oooo00<0I_ooooooool04Oooo`030000oooooooo
02?oool00`000?ooooooo`0Yoooo00<0003oooooool0:?ooo`00:oooo`040000oooooooo00009Ooo
o`D0000Soooo00<0I_l0003oool04Oooo`80I_lAoooo00<0003oooooool09?ooo`030000oooooooo
02Goool50000:Oooo`009Oooo`@00002oooo0`00023oool400000_ooo`040000oooooooo00007_oo
o`@000001Oooo`1Vooooooooo`00000Coooo00<0I_ooooooool03_ooo`030000oooooooo02Goool0
0`000?ooooooo`0Toooo00@0003oooooool0000Zoooo000/oooo00<0003oooooool09_ooo`030000
oooo000002;oool00`1Vooooo`000002oooo00<0003oooooool04Oooo`0306Kooooooooo00goool0
0`000?ooooooo`0Soooo00@0003oooooool0000Voooo00<0003oool00000:_ooo`00;?ooo`<0000W
oooo0P0001ooool306Ko0oooo`80000Eoooo00<0I_ooooooool03?ooo`80000Uoooo0P0002Soool2
0000:_ooo`00M?ooo`<0I_lNoooo00<0I_ooooooool02oooo`030000oooooooo07[oool007;oool2
06Ko8_ooo`0306Kooooooooo00[oool00`000?ooooooo`1joooo001]oooo1@1VobGoool00`1Voooo
ooooo`09oooo00<0003oooooool0N_ooo`00I?ooo`T0I_lZoooo00<0I_ooooooool02Oooo`030000
oooooooo07[oool005coool806Ko=?ooo`0306Kooooooooo00Soool00`000?ooooooo`1joooo000@
ooooo`00017oool001Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`00000@000000<c
o`00000co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0V
oooo00<0003oooooool09Oooo`030000oooooooo00Koool400006c?o00030000oooooooo01_oool0
0ol0VOooooooo`07oooo00<0003oooooool09_ooo`030000oooooooo02Woool008Soool400005c?o
00030000oooooooo01_oool00ol0VOooooooo`1Loooo002<oooo00<0000co`0co`0053?o00030000
oooooooo01_oool00ol0VOooooooo`1Loooo002=oooo0P0001@co`000`000?ooooooo`0Koooo00?o
09Woooooool0G?ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Koooo00?o09Wooooo
ool0G?ooo`00T?ooo`030000<ol0<ol0010co`0200007?ooo`03o`2Ioooooooo05coool0097oool2
000043?o00030000oooooooo01_oool00ol0VOooooooo`1Loooo002Coooo00<0000co`0co`003C?o
00030000oooooooo01_oool00ol0VOooooooo`1Loooo002Coooo00<0000co`0co`003C?o00030000
oooooooo01_oool00ol0VOooooooo`1Loooo002Doooo00<0000co`0co`0033?o00030000oooooooo
01_oool00ol0VOooooooo`1Loooo002Doooo00<0000co`0co`0033?o00030000oooooooo01_oool0
0ol0VOooooooo`1Loooo002Eoooo00<0000co`0co`002c?o0080000Loooo00?o09Woooooool0G?oo
o`00UOooo`030000<ol0<ol000/co`000`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00U_oo
o`030000<ol0<ol000Xco`000`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00U_ooo`030000
<ol0<ol000Xco`000`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00Uoooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00Uoooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00V?ooo`030000<ol0<ol000Pco`0200007?oo
o`03o`2Ioooooooo05coool009Soool00`0003?o03?o0008<ol000<0003oooooool06oooo`03o`2I
oooooooo05coool009Soool00`0003?o03?o0008<ol000<0003oooooool06oooo`03o`2Ioooooooo
05coool009Woool00`0003?o03?o0007<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool0
09Woool00`0003?o03?o0007<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool009Woool0
0`0003?o03?o0007<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool009Woool00`0003?o
03?o0007<ol00P0001coool00ol0VOooooooo`1Loooo002Joooo00<0000co`0co`001S?o00030000
oooooooo01_oool00ol0VOooooooo`1Loooo002Joooo00<0000co`0co`001S?o00030000oooooooo
01_oool00ol0VOooooooo`1Loooo002Joooo00<0000co`0co`001S?o00030000oooooooo01_oool0
0ol0VOooooooo`1Loooo002Joooo00<0000co`0co`001S?o00030000oooooooo01_oool00ol0VOoo
ooooo`1Loooo002Koooo1@0000<co`000`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00Vooo
o`030000<ol0000000Dco`000`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00Voooo`030000
<ol0000000Dco`0300006oooo`03o`2Ioooooooo05coool009coool200001C?o00030000oooooooo
01_oool00ol0VOooooooo`1Loooo002Loooo0P0000Dco`000`000?ooooooo`0Koooo00?o09Wooooo
ool0G?ooo`00W?ooo`800005<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool009coool0
0`0003?o03?o0004<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool009coool00`0003?o
03?o0004<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool009coool00`0003?o03?o0004
<ol00P0001coool00ol0VOooooooo`1Loooo002Moooo00<0000co`0co`000c?o00030000oooooooo
01_oool00ol0VOooooooo`1Loooo002Moooo00<0000co`0co`000c?o00030000oooooooo01_oool0
0ol0VOooooooo`1Loooo002Moooo00<0000co`0co`000c?o00030000oooooooo01_oool00ol0VOoo
ooooo`1Loooo002Moooo00<0000co`0co`000c?o00030000oooooooo01_oool00ol0VOooooooo`1L
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo01_oool00ol0VOooooooo`1Loooo002M
oooo00<0000co`0co`000c?o0080000Loooo00?o09Woooooool0G?ooo`00WOooo`030000<ol0<ol0
00<co`000`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00WOooo`030000<ol0<ol000<co`00
0`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0Koooo00?o09Woooooool0G?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0K
oooo00?o09Woooooool0G?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Koooo00?o
09Woooooool0G?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Koooo00?o09Wooooo
ool0G?ooo`00W_ooo`030000<ol0<ol0008co`0200007?ooo`03o`2Ioooooooo05coool009koool0
0`0003?o03?o0002<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool009koool00`0003?o
03?o0002<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool009koool00`0003?o03?o0002
<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool009koool00`0003?o03?o0002<ol000<0
003oooooool06oooo`03o`2Ioooooooo05coool009koool00`0003?o03?o0002<ol000<0003ooooo
ool06oooo`03o`2Ioooooooo05coool009koool00`0003?o03?o0002<ol00P0001coool00ol0VOoo
ooooo`1Loooo002Ooooo00D0000co`0co`0co`0000007Oooo`03o`2Ioooooooo05coool009ooool0
1@0003?o03?o03?o0000000Moooo00?o09Woooooool0G?ooo`00Woooo`050000<ol0<ol0<ol00000
01goool00ol0VOooooooo`1Loooo002Koooo1@0000<co`000`000?ooooooo`0Koooo00?o09Wooooo
ool0G?ooo`00Voooo`050000oooooooooooo000000<co`000`000?ooooooo`0Koooo00?o09Wooooo
ool0G?ooo`00W?ooo`040000oooooooo00000c?o00<0000Koooo00?o09Woooooool0G?ooo`00WOoo
o`030000oooo000000<co`000`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00Voooo`030000
oooooooo00800003<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool009coool2000000?o
ool0000co`000S?o00030000oooooooo01_oool00ol0VOooooooo`1Loooo002Ooooo00D0000co`0c
o`0co`0000007Oooo`03o`2Ioooooooo05coool00:3oool0100003?o03?o000001goool00ol0VOoo
ooooo`1Loooo002Poooo00<0000co`0co`000P0001coool00ol0VOooooooo`1Loooo002Poooo00@0
000co`0co`00000Moooo00?o09Woooooool0G?ooo`00X?ooo`040000<ol0<ol000007Oooo`03o`2I
oooooooo05coool00:3oool0100003?o03?o000001goool00ol0VOooooooo`1Loooo002Poooo00@0
000co`0co`00000Moooo00?o09Woooooool0G?ooo`00X?ooo`040000<ol0<ol000007Oooo`03o`2I
oooooooo05coool00:3oool0100003?o03?o000001goool00ol0VOooooooo`1Loooo002Qoooo00@0
000co`000000000Loooo00?o09Woooooool0G?ooo`00XOooo`030000<ol0000001goool00ol0VOoo
ooooo`1Loooo002Qoooo00<0000co`0000007Oooo`03o`2Ioooooooo05coool00:7oool00`0003?o
0000000Moooo00?o09Woooooool0G?ooo`00XOooo`030000<ol0000001goool00ol0VOooooooo`1L
oooo002Qoooo00<0000co`0000007Oooo`03o`2Ioooooooo05coool00:7oool0100003?o00000000
01coool00ol0VOooooooo`1Loooo002Qoooo00<0000co`0000007Oooo`03o`2Ioooooooo05coool0
0:7oool00`0003?o0000000Moooo00?o09Woooooool0G?ooo`00XOooo`030000<ol0000001goool0
0ol0VOooooooo`1Loooo002Qoooo00<0000co`0000007Oooo`03o`2Ioooooooo05coool00:7oool0
0`0003?o0000000Moooo00?o09Woooooool0G?ooo`00XOooo`040000<ol0000000007?ooo`03o`2I
oooooooo05coool00:7oool00`0003?o0000000Moooo00?o09Woooooool0G?ooo`00XOooo`030000
<ol0000001goool00ol0VOooooooo`1Loooo002Qoooo00<0000co`0000007Oooo`03o`2Ioooooooo
05coool009coool200000oooo`030000<ol0000001goool00ol0VOooooooo`1Loooo002Koooo00@0
003oooooool00002oooo00<0000co`0000007Oooo`03o`2Ioooooooo05coool009goool01P000?oo
ooooooooo`0003?o00<0000Koooo00?o09Woooooool0G?ooo`00W_ooo`060000oooooooo0000<ol0
00007Oooo`03o`2Ioooooooo05coool009_oool010000?ooooooo`0000;oool00`0003?o0000000M
oooo00?o09Woooooool0G?ooo`00W?ooo`800004oooo0P0001goool00ol0VOooooooo`1Loooo002R
oooo0P0001goool00ol0VOooooooo`1Loooo002Roooo0P0001goool00ol0VOooooooo`1Loooo002R
oooo0P0001goool00ol0VOooooooo`1Loooo002Roooo0`0001coool00ol0VOooooooo`1Loooo002R
oooo0P0001goool00ol0VOooooooo`1Loooo002Roooo0P0001goool00ol0VOooooooo`1Loooo002R
oooo0P0001goool00ol0VOooooooo`1Loooo002Roooo0P0001goool00ol0VOooooooo`1Loooo002R
oooo0P0001goool00ol0VOooooooo`1Loooo002Roooo0`0001coool00ol0VOooooooo`1Loooo002R
oooo0P0001goool00ol0VOooooooo`1Loooo002Roooo0P0001goool00ol0VOooooooo`1Loooo002R
oooo0P0001goool00ol0VOooooooo`1Loooo002Roooo0P0001goool00ol0VOooooooo`1Loooo002R
oooo0P0001goool00ol0VOooooooo`1Loooo002Roooo0`0001coool00ol0VOooooooo`1Loooo002S
oooo00<0003oooooool06oooo`03o`2Ioooooooo05coool00:?oool00`000?ooooooo`0Koooo00?o
09Woooooool0G?ooo`00Xoooo`030000oooooooo01_oool00ol0VOooooooo`1Loooo002Soooo00<0
003oooooool06oooo`03o`2Ioooooooo05coool00:?oool00`000?ooooooo`0Koooo00?o09Wooooo
ool0G?ooo`00Xoooo`80000Loooo00?o09Woooooool0G?ooo`00Xoooo`030000oooooooo01_oool0
0ol0VOooooooo`1Loooo002Soooo00<0003oooooool06oooo`03o`2Ioooooooo05coool00:?oool0
0`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00Xoooo`030000oooooooo01_oool00ol0VOoo
ooooo`1Loooo002Moooo0`0000?oool00`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00W_oo
o`030000oooooooo00;oool00`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00Voooo`D00003
oooo0`0001_oool00ol0VOooooooo`1Loooo002Koooo00@0003oooooool00021oooo002Loooo00<0
003oool00000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007coool00`000?oo
ooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0I
oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500003?ooo`040000oooooooo00002Oooo`800004oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Woool0
0`000?ooooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_oo
o`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.6883 .12361 L
.69774 .12361 L
.7003 .12361 L
.70301 .12361 L
.70413 .12361 L
.70533 .12361 L
s
.70533 .12361 m
.70585 .61803 L
s
0 .4 1 r
.02381 .12357 m
.04262 .12356 L
.06244 .12354 L
.07286 .12353 L
.08255 .12351 L
.09388 .12349 L
.10458 .12346 L
.125 .1234 L
.14357 .12332 L
.16355 .1232 L
.18199 .12304 L
.20071 .12281 L
.21136 .12264 L
.22134 .12246 L
.24158 .12196 L
.26011 .12131 L
.27909 .12038 L
.28984 .1197 L
.29982 .11894 L
.32034 .11689 L
.33895 .11424 L
.35819 .11041 L
.36904 .1076 L
.37901 .10449 L
.39784 .09686 L
.40853 .09125 L
.4185 .08495 L
.43714 .06969 L
.44697 .05934 L
.44936 .05654 L
.45061 .05502 L
.45193 .05338 L
.45264 .05288 L
.45341 .05311 L
.45476 .05352 L
.45741 .05434 L
.46844 .0582 L
.47865 .06249 L
.49877 .0735 L
.51838 .0886 L
.52936 .09961 L
.53933 .11169 L
.54418 .11843 L
.54546 .12031 L
.54616 .12137 L
.54683 .12239 L
.54813 .12361 L
.54931 .12361 L
.5504 .12361 L
.55141 .12361 L
Mistroke
.55252 .12361 L
.5537 .12361 L
.555 .12361 L
.55623 .12361 L
.55733 .12361 L
.55852 .12361 L
.55982 .12361 L
.56103 .12361 L
.56173 .12361 L
.56237 .12361 L
.5631 .12361 L
.56379 .12361 L
.56446 .12361 L
.56518 .12361 L
.56646 .12361 L
.56717 .12361 L
.56784 .12361 L
.56857 .12361 L
.56936 .12361 L
.57057 .12361 L
.57125 .12361 L
.57189 .12361 L
.57318 .12361 L
.57384 .12361 L
.57455 .12361 L
.57584 .12361 L
.57705 .12361 L
.57823 .12361 L
.57931 .12361 L
.58057 .12361 L
.58177 .12361 L
.584 .12361 L
.58903 .12361 L
.59812 .12361 L
.61877 .12361 L
.65707 .12361 L
.69782 .12361 L
.73705 .12361 L
.77477 .12361 L
.81494 .12361 L
.8536 .12361 L
.8947 .12361 L
.93429 .12361 L
.97237 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002S
oooo00<0003oooooool0N_ooo`00Poooo`0306Kooooooooo01goool20000Noooo`00P_ooo`@0I_lM
oooo00<0003oooooool0N_ooo`00P_ooo`0406Kooooooooooooo0`1Voa[oool00`000?ooooooo`1j
oooo0021oooo00<0I_ooooooool01Oooo`80I_lHoooo00<0003oooooool0N_ooo`00P?ooo`0306Ko
oooooooo00Soool206Ko5_ooo`030000oooooooo07[oool007ooool00`1Vooooooooo`0;oooo0P1V
oaCoool00`000?ooooooo`1joooo001noooo00<0I_ooooooool03_ooo`0306Kooooooooo017oool2
0000Noooo`00:oooo`<0000Xoooo0`0002?oool400004?ooo`0306Kooooooooo013oool00`000?oo
ooooo`0Soooo100002Ooool30000:Oooo`00:oooo`040000oooooooo0000:?ooo`030000oooooooo
027oool00`1Vo`000?ooo`0Coooo0P1Voa3oool00`000?ooooooo`0Soooo00<0003oooooool0:Ooo
o`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500008Oooo`0406Kooooooooo
00005Oooo`0306Kooooooooo00goool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Y
oooo000Uoooo100000;oool300008?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool0
0`000?ooooooo`0Coooo00<0I_ooooooool03?ooo`030000oooooooo02Goool00`000?ooooooo`0T
oooo00@0003oooooool0000Zoooo000/oooo00<0003oooooool09_ooo`030000oooo000001koool2
06Ko1?ooo`040000oooooooo00005Oooo`0306Kooooooooo00_oool00`000?ooooooo`0Soooo00@0
003oooooool0000Voooo00<0003oool00000:_ooo`00;?ooo`<0000Woooo0P0001coool206Ko1ooo
o`80000Goooo00<0I_ooooooool02_ooo`80000Uoooo0P0002Soool20000:_ooo`00L_ooo`80I_lS
oooo00<0I_ooooooool02Oooo`030000oooooooo07[oool006goool506Ko9_ooo`0306Kooooooooo
00Soool00`000?ooooooo`1joooo001Yoooo101Vobcoool00`1Vooooooooo`07oooo00<0003ooooo
ool0N_ooo`00I?ooo`D0I_l`oooo00<0I_ooooooool01oooo`030000oooooooo07[oool005Woool;
06Ko=_ooo`0306Kooooooooo00Koool00`000?ooooooo`1joooo000@ooooo`00017oool001Koool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003ooooo09T01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0003oooooool09Ooo
o`030000oooooooo00Koool400006c?o00030000oooooooo01goool00ol0VOooooooo`05oooo00<0
003oooooool09_ooo`030000oooooooo02Woool008Soool400005c?o00030000oooooooo01goool0
0ol0VOooooooo`1Joooo002<oooo00<0000co`0co`0053?o00030000oooooooo01goool00ol0VOoo
ooooo`1Joooo002=oooo0P0001@co`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00T?ooo`030000
<ol0<ol0010co`0200007_ooo`03o`2Ioooooooo05[oool0097oool2000043?o00030000oooooooo
01goool00ol0VOooooooo`1Joooo002Coooo00<0000co`0co`003C?o00030000oooooooo01goool0
0ol0VOooooooo`1Joooo002Coooo00<0000co`0co`003C?o00030000oooooooo01goool00ol0VOoo
ooooo`1Joooo002Doooo00<0000co`0co`0033?o00030000oooooooo01goool00ol0VOooooooo`1J
oooo002Doooo00<0000co`0co`0033?o00030000oooooooo01goool00ol0VOooooooo`1Joooo002E
oooo00<0000co`0co`002c?o0080000Noooo00?o09Woooooool0F_ooo`00UOooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00U_ooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00U_ooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Moooo00?o09Woooooool0F_ooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`0M
oooo00?o09Woooooool0F_ooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`0Moooo00?o
09Woooooool0F_ooo`00V?ooo`030000<ol0<ol000Pco`0200007_ooo`03o`2Ioooooooo05[oool0
09Soool00`0003?o03?o0008<ol000<0003oooooool07Oooo`03o`2Ioooooooo05[oool009Soool0
0`0003?o03?o0008<ol000<0003oooooool07Oooo`03o`2Ioooooooo05[oool009Woool00`0003?o
03?o0007<ol000<0003oooooool07Oooo`03o`2Ioooooooo05[oool009Woool00`0003?o03?o0007
<ol000<0003oooooool07Oooo`03o`2Ioooooooo05[oool009Woool00`0003?o03?o0007<ol000<0
003oooooool07Oooo`03o`2Ioooooooo05[oool009Woool00`0003?o03?o0007<ol00P0001koool0
0ol0VOooooooo`1Joooo002Joooo00<0000co`0co`001S?o00030000oooooooo01goool00ol0VOoo
ooooo`1Joooo002Joooo00<0000co`0co`001S?o00030000oooooooo01goool00ol0VOooooooo`1J
oooo002Joooo00<0000co`0co`001S?o00030000oooooooo01goool00ol0VOooooooo`1Joooo002J
oooo00<0000co`0co`001S?o00030000oooooooo01goool00ol0VOooooooo`1Joooo002Koooo1@00
00<co`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Voooo`030000<ol0000000Dco`00
0`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Voooo`030000<ol0000000Dco`0300007Ooo
o`03o`2Ioooooooo05[oool009coool200001C?o00030000oooooooo01goool00ol0VOooooooo`1J
oooo002Loooo0P0000Dco`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00W?ooo`800005
<ol000<0003oooooool07Oooo`03o`2Ioooooooo05[oool009coool00`0003?o03?o0004<ol000<0
003oooooool07Oooo`03o`2Ioooooooo05[oool009coool00`0003?o03?o0004<ol000<0003ooooo
ool07Oooo`03o`2Ioooooooo05[oool009coool00`0003?o03?o0004<ol00P0001koool00ol0VOoo
ooooo`1Joooo002Moooo00<0000co`0co`000c?o00030000oooooooo01goool00ol0VOooooooo`1J
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo01goool00ol0VOooooooo`1Joooo002M
oooo00<0000co`0co`000c?o00030000oooooooo01goool00ol0VOooooooo`1Joooo002Moooo00<0
000co`0co`000c?o00030000oooooooo01goool00ol0VOooooooo`1Joooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo01goool00ol0VOooooooo`1Joooo002Moooo00<0000co`0co`000c?o
0080000Noooo00?o09Woooooool0F_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0M
oooo00?o09Woooooool0F_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0Moooo00?o
09Woooooool0F_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Moooo00?o09Wooooo
ool0F_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Moooo00?o09Woooooool0F_oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00W_ooo`030000
<ol0<ol0008co`0200007_ooo`03o`2Ioooooooo05[oool009koool00`0003?o03?o0002<ol000<0
003oooooool07Oooo`03o`2Ioooooooo05[oool009koool00`0003?o03?o0002<ol000<0003ooooo
ool07Oooo`03o`2Ioooooooo05[oool009koool00`0003?o03?o0002<ol000<0003oooooool07Ooo
o`03o`2Ioooooooo05[oool009koool00`0003?o03?o0002<ol000<0003oooooool07Oooo`03o`2I
oooooooo05[oool009koool00`0003?o03?o0002<ol000<0003oooooool07Oooo`03o`2Ioooooooo
05[oool009koool00`0003?o03?o0002<ol00P0001koool00ol0VOooooooo`1Joooo002Ooooo00D0
000co`0co`0co`0000007oooo`03o`2Ioooooooo05[oool009ooool01@0003?o03?o03?o0000000O
oooo00?o09Woooooool0F_ooo`00Woooo`050000<ol0<ol0<ol0000001ooool00ol0VOooooooo`1J
oooo002Koooo1@0000<co`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Voooo`050000
oooooooooooo000000<co`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00W?ooo`040000
oooooooo00000c?o00<0000Moooo00?o09Woooooool0F_ooo`00WOooo`030000oooo000000<co`00
0`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Voooo`030000oooooooo00800003<ol000<0
003oooooool07Oooo`03o`2Ioooooooo05[oool009coool2000000?oool0000co`000S?o00030000
oooooooo01goool00ol0VOooooooo`1Joooo002Ooooo00D0000co`0co`0co`0000007oooo`03o`2I
oooooooo05[oool00:3oool0100003?o03?o000001ooool00ol0VOooooooo`1Joooo002Poooo00<0
000co`0co`000P0001koool00ol0VOooooooo`1Joooo002Poooo00@0000co`0co`00000Ooooo00?o
09Woooooool0F_ooo`00X?ooo`040000<ol0<ol000007oooo`03o`2Ioooooooo05[oool00:3oool0
100003?o03?o000001ooool00ol0VOooooooo`1Joooo002Poooo00@0000co`0co`00000Ooooo00?o
09Woooooool0F_ooo`00X?ooo`040000<ol0<ol000007oooo`03o`2Ioooooooo05[oool00:3oool0
100003?o03?o000001ooool00ol0VOooooooo`1Joooo002Qoooo00@0000co`000000000Noooo00?o
09Woooooool0F_ooo`00XOooo`030000<ol0000001ooool00ol0VOooooooo`1Joooo002Qoooo00<0
000co`0000007oooo`03o`2Ioooooooo05[oool00:7oool00`0003?o0000000Ooooo00?o09Wooooo
ool0F_ooo`00XOooo`030000<ol0000001ooool00ol0VOooooooo`1Joooo002Qoooo00<0000co`00
00007oooo`03o`2Ioooooooo05[oool00:7oool0100003?o0000000001koool00ol0VOooooooo`1J
oooo002Qoooo00<0000co`0000007oooo`03o`2Ioooooooo05[oool00:7oool00`0003?o0000000O
oooo00?o09Woooooool0F_ooo`00XOooo`030000<ol0000001ooool00ol0VOooooooo`1Joooo002Q
oooo00<0000co`0000007oooo`03o`2Ioooooooo05[oool00:7oool00`0003?o0000000Ooooo00?o
09Woooooool0F_ooo`00XOooo`040000<ol0000000007_ooo`03o`2Ioooooooo05[oool00:7oool0
0`0003?o0000000Ooooo00?o09Woooooool0F_ooo`00XOooo`030000<ol0000001ooool00ol0VOoo
ooooo`1Joooo002Qoooo00<0000co`0000007oooo`03o`2Ioooooooo05[oool009coool200000ooo
o`030000<ol0000001ooool00ol0VOooooooo`1Joooo002Koooo00@0003oooooool00002oooo00<0
000co`0000007oooo`03o`2Ioooooooo05[oool009goool01P000?ooooooooooo`0003?o00<0000M
oooo00?o09Woooooool0F_ooo`00W_ooo`060000oooooooo0000<ol000007oooo`03o`2Ioooooooo
05[oool009_oool010000?ooooooo`0000;oool00`0003?o0000000Ooooo00?o09Woooooool0F_oo
o`00W?ooo`800004oooo0P0001ooool00ol0VOooooooo`1Joooo002Roooo0P0001ooool00ol0VOoo
ooooo`1Joooo002Roooo0P0001ooool00ol0VOooooooo`1Joooo002Roooo0P0001ooool00ol0VOoo
ooooo`1Joooo002Roooo0`0001koool00ol0VOooooooo`1Joooo002Roooo0P0001ooool00ol0VOoo
ooooo`1Joooo002Roooo0P0001ooool00ol0VOooooooo`1Joooo002Roooo0P0001ooool00ol0VOoo
ooooo`1Joooo002Roooo0P0001ooool00ol0VOooooooo`1Joooo002Roooo0P0001ooool00ol0VOoo
ooooo`1Joooo002Roooo0`0001koool00ol0VOooooooo`1Joooo002Roooo0P0001ooool00ol0VOoo
ooooo`1Joooo002Roooo0P0001ooool00ol0VOooooooo`1Joooo002Roooo0P0001ooool00ol0VOoo
ooooo`1Joooo002Roooo0P0001ooool00ol0VOooooooo`1Joooo002Roooo0P0001ooool00ol0VOoo
ooooo`1Joooo002Roooo0`0001koool00ol0VOooooooo`1Joooo002Soooo00<0003oooooool07Ooo
o`03o`2Ioooooooo05[oool00:?oool00`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Xooo
o`030000oooooooo01goool00ol0VOooooooo`1Joooo002Soooo00<0003oooooool07Oooo`03o`2I
oooooooo05[oool00:?oool00`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Xoooo`80000N
oooo00?o09Woooooool0F_ooo`00Xoooo`030000oooooooo01goool00ol0VOooooooo`1Joooo002S
oooo00<0003oooooool07Oooo`03o`2Ioooooooo05[oool00:?oool00`000?ooooooo`0Moooo00?o
09Woooooool0F_ooo`00Xoooo`030000oooooooo01goool00ol0VOooooooo`1Joooo002Moooo0`00
00?oool00`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00W_ooo`030000oooooooo00;oool0
0`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Voooo`D00003oooo0`0001goool00ol0VOoo
ooooo`1Joooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool00000POooo`00WOoo
o`800021oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Nooo
o`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003
oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0N_ooo`00Noooo`030000
oooooooo00D0000<oooo00@0003oooooool00008oooo0`0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000003oooo`040000oooooooo00002Oooo`030000oooooooo00?oool0
0`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0`0000;oool00`000?oo
ooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.69774 .12361 L
.7026 .12361 L
.70787 .12361 L
.71028 .12361 L
.7116 .12361 L
.71284 .12361 L
.71389 .12361 L
s
.71389 .12361 m
.71434 .61803 L
s
0 .4 1 r
.02381 .12357 m
.04262 .12355 L
.06244 .12352 L
.07286 .12351 L
.08255 .12349 L
.09388 .12346 L
.10458 .12343 L
.125 .12336 L
.14357 .12326 L
.16355 .12311 L
.18199 .12291 L
.20071 .12264 L
.21136 .12244 L
.22134 .12221 L
.24158 .1216 L
.26011 .12081 L
.27909 .11969 L
.28984 .11886 L
.29982 .11794 L
.32034 .11544 L
.33895 .11223 L
.35819 .10757 L
.36904 .10415 L
.37901 .10036 L
.39784 .0911 L
.40853 .08427 L
.4185 .07661 L
.43714 .05807 L
.44224 .05181 L
.44348 .0502 L
.44418 .04928 L
.44482 .04902 L
.44554 .04918 L
.44629 .04935 L
.44767 .04967 L
.45741 .05217 L
.46755 .05526 L
.47865 .05932 L
.49877 .06893 L
.51838 .08206 L
.53933 .10198 L
.54957 .11483 L
.55238 .11882 L
.55392 .1211 L
.55467 .12223 L
.55535 .12329 L
.55657 .12361 L
.55789 .12361 L
.55857 .12361 L
.55932 .12361 L
Mistroke
.56002 .12361 L
.56068 .12361 L
.56195 .12361 L
.56266 .12361 L
.56332 .12361 L
.56453 .12361 L
.5658 .12361 L
.56695 .12361 L
.56801 .12361 L
.57044 .12361 L
.57167 .12361 L
.57237 .12361 L
.57302 .12361 L
.5742 .12361 L
.57546 .12361 L
.57615 .12361 L
.57679 .12361 L
.5775 .12361 L
.57827 .12361 L
.57892 .12361 L
.57961 .12361 L
.58083 .12361 L
.61899 .12361 L
.6596 .12361 L
.6987 .12361 L
.74025 .12361 L
.78029 .12361 L
.8188 .12361 L
.85977 .12361 L
.89923 .12361 L
.93717 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo0021
oooo00<0I_ooooooool07oooo`030000oooooooo07[oool0083oool606Ko7Oooo`80001koooo001o
oooo00<0I_ooooooool01?ooo`<0I_lJoooo00<0003oooooool0N_ooo`00Ooooo`0306Kooooooooo
00Ooool206Ko6?ooo`030000oooooooo07[oool007koool00`1Vooooooooo`0:oooo0P1VoaKoool0
0`000?ooooooo`1joooo001loooo0P1Vo`ooool206Ko5?ooo`030000oooooooo07[oool007_oool0
0`1Vooooooooo`0Aoooo00<0I_ooooooool04Oooo`030000oooooooo07[oool007[oool00`1Voooo
ooooo`0Coooo0P1Voa7oool20000Noooo`00:oooo`<0000Xoooo0`00023oool00`1Vooooooooo`04
00004_ooo`80I_l?oooo00<0003oooooool08oooo`@0000Woooo0`0002Woool002_oool010000?oo
ooooo`0002Soool00`000?ooooooo`0Noooo00D0I_ooooooooooool000005oooo`0306Kooooooooo
00coool00`000?ooooooo`0Soooo00<0003oooooool0:Oooo`030000oooooooo02Soool002_oool0
10000?ooooooo`0002Goool500007Oooo`80I_l5oooo00<0003oooooool05Oooo`0306Kooooooooo
00_oool00`000?ooooooo`0Toooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo100000;oool3
00008?ooo`@00002oooo00@0003oooooool0000Moooo00<0I_l0000000000P0000Coool00`000?oo
ooooo`0Eoooo00<0I_ooooooool02_ooo`030000oooooooo02Goool00`000?ooooooo`0Toooo00@0
003oooooool0000Zoooo000/oooo00<0003oooooool09_ooo`030000oooo000001_oool206Ko1ooo
o`040000oooooooo00005oooo`0306Kooooooooo00Woool00`000?ooooooo`0Soooo00@0003ooooo
ool0000Voooo00<0003oool00000:_ooo`00;?ooo`<0000Woooo0P0001Woool206Ko2_ooo`80000I
oooo00<0I_ooooooool02?ooo`80000Uoooo0P0002Soool20000:_ooo`00KOooo`@0I_lXoooo00<0
I_ooooooool01oooo`030000oooooooo07[oool006[oool306Ko;Oooo`0306Kooooooooo00Koool0
0`000?ooooooo`1joooo001Xoooo0P1Voc7oool00`1Vooooooooo`05oooo00<0003oooooool0N_oo
o`00Goooo`T0I_ldoooo00<0I_ooooooool01?ooo`030000oooooooo07[oool005Goool:06Ko?Ooo
o`0306Kooooooooo00Coool00`000?ooooooo`1joooo000@ooooo`00017oool001Koool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00D0003ooooooooooooo09T01Oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0003oooooool09Ooo
o`030000oooooooo00Koool400006c?o00030000oooooooo01ooool00ol0VOooooooo`03oooo00<0
003oooooool09_ooo`030000oooooooo02Woool008Soool400005c?o00030000oooooooo01ooool0
0ol0VOooooooo`1Hoooo002<oooo00<0000co`0co`0053?o00030000oooooooo01ooool00ol0VOoo
ooooo`1Hoooo002=oooo0P0001@co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00T?ooo`030000
<ol0<ol0010co`0200008?ooo`03o`2Ioooooooo05Soool0097oool2000043?o00030000oooooooo
01ooool00ol0VOooooooo`1Hoooo002Coooo00<0000co`0co`003C?o00030000oooooooo01ooool0
0ol0VOooooooo`1Hoooo002Coooo00<0000co`0co`003C?o00030000oooooooo01ooool00ol0VOoo
ooooo`1Hoooo002Doooo00<0000co`0co`0033?o00030000oooooooo01ooool00ol0VOooooooo`1H
oooo002Doooo00<0000co`0co`0033?o00030000oooooooo01ooool00ol0VOooooooo`1Hoooo002E
oooo00<0000co`0co`002c?o0080000Poooo00?o09Woooooool0F?ooo`00UOooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00U_ooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00U_ooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Ooooo00?o09Woooooool0F?ooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`0O
oooo00?o09Woooooool0F?ooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`0Ooooo00?o
09Woooooool0F?ooo`00V?ooo`030000<ol0<ol000Pco`0200008?ooo`03o`2Ioooooooo05Soool0
09Soool00`0003?o03?o0008<ol000<0003oooooool07oooo`03o`2Ioooooooo05Soool009Soool0
0`0003?o03?o0008<ol000<0003oooooool07oooo`03o`2Ioooooooo05Soool009Woool00`0003?o
03?o0007<ol000<0003oooooool07oooo`03o`2Ioooooooo05Soool009Woool00`0003?o03?o0007
<ol000<0003oooooool07oooo`03o`2Ioooooooo05Soool009Woool00`0003?o03?o0007<ol000<0
003oooooool07oooo`03o`2Ioooooooo05Soool009Woool00`0003?o03?o0007<ol00P00023oool0
0ol0VOooooooo`1Hoooo002Joooo00<0000co`0co`001S?o00030000oooooooo01ooool00ol0VOoo
ooooo`1Hoooo002Joooo00<0000co`0co`001S?o00030000oooooooo01ooool00ol0VOooooooo`1H
oooo002Joooo00<0000co`0co`001S?o00030000oooooooo01ooool00ol0VOooooooo`1Hoooo002J
oooo00<0000co`0co`001S?o00030000oooooooo01ooool00ol0VOooooooo`1Hoooo002Koooo1@00
00<co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00Voooo`030000<ol0000000Dco`00
0`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00Voooo`030000<ol0000000Dco`0300007ooo
o`03o`2Ioooooooo05Soool009coool200001C?o00030000oooooooo01ooool00ol0VOooooooo`1H
oooo002Loooo0P0000Dco`000`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00W?ooo`800005
<ol000<0003oooooool07oooo`03o`2Ioooooooo05Soool009coool00`0003?o03?o0004<ol000<0
003oooooool07oooo`03o`2Ioooooooo05Soool009coool00`0003?o03?o0004<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo05Soool009coool00`0003?o03?o0004<ol00P00023oool00ol0VOoo
ooooo`1Hoooo002Moooo00<0000co`0co`000c?o00030000oooooooo01ooool00ol0VOooooooo`1H
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo01ooool00ol0VOooooooo`1Hoooo002M
oooo00<0000co`0co`000c?o00030000oooooooo01ooool00ol0VOooooooo`1Hoooo002Moooo00<0
000co`0co`000c?o00030000oooooooo01ooool00ol0VOooooooo`1Hoooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo01ooool00ol0VOooooooo`1Hoooo002Moooo00<0000co`0co`000c?o
0080000Poooo00?o09Woooooool0F?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0O
oooo00?o09Woooooool0F?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0Ooooo00?o
09Woooooool0F?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Ooooo00?o09Wooooo
ool0F?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00W_ooo`030000
<ol0<ol0008co`0200008?ooo`03o`2Ioooooooo05Soool009koool00`0003?o03?o0002<ol000<0
003oooooool07oooo`03o`2Ioooooooo05Soool009koool00`0003?o03?o0002<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo05Soool009koool00`0003?o03?o0002<ol000<0003oooooool07ooo
o`03o`2Ioooooooo05Soool009koool00`0003?o03?o0002<ol000<0003oooooool07oooo`03o`2I
oooooooo05Soool009koool00`0003?o03?o0002<ol000<0003oooooool07oooo`03o`2Ioooooooo
05Soool009koool00`0003?o03?o0002<ol00P00023oool00ol0VOooooooo`1Hoooo002Ooooo00D0
000co`0co`0co`0000008Oooo`03o`2Ioooooooo05Soool009ooool01@0003?o03?o03?o0000000Q
oooo00?o09Woooooool0F?ooo`00Woooo`050000<ol0<ol0<ol00000027oool00ol0VOooooooo`1H
oooo002Koooo1@0000<co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00Voooo`050000
oooooooooooo000000<co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00W?ooo`040000
oooooooo00000c?o00<0000Ooooo00?o09Woooooool0F?ooo`00WOooo`030000oooo000000<co`00
0`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00Voooo`030000oooooooo00800003<ol000<0
003oooooool07oooo`03o`2Ioooooooo05Soool009coool2000000?oool0000co`000S?o00030000
oooooooo01ooool00ol0VOooooooo`1Hoooo002Ooooo00D0000co`0co`0co`0000008Oooo`03o`2I
oooooooo05Soool00:3oool0100003?o03?o0000027oool00ol0VOooooooo`1Hoooo002Poooo00<0
000co`0co`000P00023oool00ol0VOooooooo`1Hoooo002Poooo00@0000co`0co`00000Qoooo00?o
09Woooooool0F?ooo`00X?ooo`040000<ol0<ol000008Oooo`03o`2Ioooooooo05Soool00:3oool0
100003?o03?o0000027oool00ol0VOooooooo`1Hoooo002Poooo00@0000co`0co`00000Qoooo00?o
09Woooooool0F?ooo`00X?ooo`040000<ol0<ol000008Oooo`03o`2Ioooooooo05Soool00:3oool0
100003?o03?o0000027oool00ol0VOooooooo`1Hoooo002Qoooo00@0000co`000000000Poooo00?o
09Woooooool0F?ooo`00XOooo`030000<ol00000027oool00ol0VOooooooo`1Hoooo002Qoooo00<0
000co`0000008Oooo`03o`2Ioooooooo05Soool00:7oool00`0003?o0000000Qoooo00?o09Wooooo
ool0F?ooo`00XOooo`030000<ol00000027oool00ol0VOooooooo`1Hoooo002Qoooo00<0000co`00
00008Oooo`03o`2Ioooooooo05Soool00:7oool0100003?o00000000023oool00ol0VOooooooo`1H
oooo002Qoooo00<0000co`0000008Oooo`03o`2Ioooooooo05Soool00:7oool00`0003?o0000000Q
oooo00?o09Woooooool0F?ooo`00XOooo`030000<ol00000027oool00ol0VOooooooo`1Hoooo002Q
oooo00<0000co`0000008Oooo`03o`2Ioooooooo05Soool00:7oool00`0003?o0000000Qoooo00?o
09Woooooool0F?ooo`00XOooo`040000<ol0000000008?ooo`03o`2Ioooooooo05Soool00:7oool0
0`0003?o0000000Qoooo00?o09Woooooool0F?ooo`00XOooo`030000<ol00000027oool00ol0VOoo
ooooo`1Hoooo002Qoooo00<0000co`0000008Oooo`03o`2Ioooooooo05Soool009coool200000ooo
o`030000<ol00000027oool00ol0VOooooooo`1Hoooo002Koooo00@0003oooooool00002oooo00<0
000co`0000008Oooo`03o`2Ioooooooo05Soool009goool01P000?ooooooooooo`0003?o00<0000O
oooo00?o09Woooooool0F?ooo`00W_ooo`060000oooooooo0000<ol000008Oooo`03o`2Ioooooooo
05Soool009_oool010000?ooooooo`0000;oool00`0003?o0000000Qoooo00?o09Woooooool0F?oo
o`00W?ooo`800004oooo0P00027oool00ol0VOooooooo`1Hoooo002Roooo0P00027oool00ol0VOoo
ooooo`1Hoooo002Roooo0P00027oool00ol0VOooooooo`1Hoooo002Roooo0P00027oool00ol0VOoo
ooooo`1Hoooo002Roooo0`00023oool00ol0VOooooooo`1Hoooo002Roooo0P00027oool00ol0VOoo
ooooo`1Hoooo002Roooo0P00027oool00ol0VOooooooo`1Hoooo002Roooo0P00027oool00ol0VOoo
ooooo`1Hoooo002Roooo0P00027oool00ol0VOooooooo`1Hoooo002Roooo0P00027oool00ol0VOoo
ooooo`1Hoooo002Roooo0`00023oool00ol0VOooooooo`1Hoooo002Roooo0P00027oool00ol0VOoo
ooooo`1Hoooo002Roooo0P00027oool00ol0VOooooooo`1Hoooo002Roooo0P00027oool00ol0VOoo
ooooo`1Hoooo002Roooo0P00027oool00ol0VOooooooo`1Hoooo002Roooo0P00027oool00ol0VOoo
ooooo`1Hoooo002Roooo0`00023oool00ol0VOooooooo`1Hoooo002Soooo00<0003oooooool07ooo
o`03o`2Ioooooooo05Soool00:?oool00`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00Xooo
o`030000oooooooo01ooool00ol0VOooooooo`1Hoooo002Soooo00<0003oooooool07oooo`03o`2I
oooooooo05Soool00:?oool00`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00Xoooo`80000P
oooo00?o09Woooooool0F?ooo`00Xoooo`030000oooooooo01ooool00ol0VOooooooo`1Hoooo002S
oooo00<0003oooooool07oooo`03o`2Ioooooooo05Soool00:?oool00`000?ooooooo`0Ooooo00?o
09Woooooool0F?ooo`00Xoooo`030000oooooooo01ooool00ol0VOooooooo`1Hoooo002Moooo0`00
00?oool00`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00W_ooo`030000oooooooo00;oool0
0`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00Voooo`D00003oooo0`0001ooool00ol0VOoo
ooooo`1Hoooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool00000POooo`00WOoo
o`800021oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Nooo
o`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800005
oooo00<0003oooooool00_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002oooo`050000oooooooooooo000007goool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002Oooo`@00002oooo00<0
003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.70787 .12361 L
.71284 .12361 L
.71741 .12361 L
.71998 .12361 L
.72127 .12361 L
.72201 .12361 L
s
.72201 .12361 m
.72228 .61803 L
s
0 .4 1 r
.02381 .12356 m
.04262 .12354 L
.06244 .12351 L
.07286 .12349 L
.08255 .12347 L
.09388 .12343 L
.10458 .1234 L
.125 .12331 L
.14357 .12319 L
.16355 .12301 L
.18199 .12278 L
.20071 .12245 L
.21136 .1222 L
.22134 .12193 L
.24158 .1212 L
.26011 .12026 L
.27909 .11892 L
.28984 .11793 L
.29982 .11682 L
.32034 .11383 L
.33895 .10998 L
.35819 .1044 L
.36904 .10031 L
.37901 .09578 L
.39784 .08468 L
.40853 .07651 L
.4185 .06734 L
.42895 .0558 L
.43145 .05272 L
.4341 .04928 L
.43518 .04782 L
.43636 .04622 L
.43765 .04621 L
.43885 .04642 L
.44774 .04814 L
.45741 .05033 L
.47745 .05621 L
.49855 .06495 L
.51829 .07645 L
.53666 .09118 L
.55539 .11201 L
.56053 .11913 L
.56177 .12098 L
.56246 .12202 L
.56311 .12302 L
.56388 .12361 L
.56459 .12361 L
.56524 .12361 L
.56596 .12361 L
.56725 .12361 L
Mistroke
.56841 .12361 L
.56906 .12361 L
.56975 .12361 L
.57102 .12361 L
.57221 .12361 L
.57346 .12361 L
.57453 .12361 L
.5757 .12361 L
.57639 .12361 L
.57714 .12361 L
.57784 .12361 L
.5785 .12361 L
.57973 .12361 L
.58104 .12361 L
.58675 .12361 L
.59705 .12361 L
.6172 .12361 L
.655 .12361 L
.69526 .12361 L
.734 .12361 L
.77519 .12361 L
.81487 .12361 L
.85303 .12361 L
.89364 .12361 L
.93274 .12361 L
.97429 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001o
oooo101Vob3oool00`000?ooooooo`1joooo001noooo00<0I_ooooooool00_ooo`@0I_lLoooo0P00
07_oool007goool00`1Vooooooooo`07oooo0`1VoaWoool00`000?ooooooo`1joooo001loooo00<0
I_ooooooool02oooo`80I_lGoooo00<0003oooooool0N_ooo`00Noooo`0306Kooooooooo00koool2
06Ko5Oooo`030000oooooooo07[oool007[oool00`1Vooooooooo`0Aoooo0`1Voa;oool00`000?oo
ooooo`1joooo001ioooo00<0I_ooooooool05Oooo`80I_l@oooo00<0003oooooool0N_ooo`00N?oo
o`0306Kooooooooo01Soool206Ko3_ooo`80001koooo000[oooo0`0002Soool300007_ooo`0306Ko
oooooooo00;oool400005Oooo`0306Kooooooooo00_oool00`000?ooooooo`0Soooo100002Ooool3
0000:Oooo`00:oooo`040000oooooooo0000:?ooo`030000oooooooo01coool00`1Vooooooooo`03
oooo00<0003oooooool05oooo`0306Kooooooooo00[oool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500006oooo`80I_l7
oooo00<0003oooooool05oooo`0306Kooooooooo00Woool00`000?ooooooo`0Toooo00<0003ooooo
ool09Oooo`D0000Yoooo000Uoooo100000;oool300008?ooo`@00002oooo00@0003oooooool0000J
oooo0P1Vo`;oool400001?ooo`030000oooooooo01Ooool00`1Vooooooooo`08oooo00<0003ooooo
ool09Oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool00`000?ooooooo`0V
oooo00<0003oool000006?ooo`80I_l:oooo00@0003oooooool0000Ioooo00<0I_ooooooool01ooo
o`030000oooooooo02?oool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`00
02Ooool200005_ooo`80I_l=oooo0P0001_oool00`1Vooooooooo`06oooo0P0002Goool20000:?oo
o`80000Zoooo001/oooo0P1Vobgoool00`1Vooooooooo`05oooo00<0003oooooool0N_ooo`00JOoo
o`<0I_l`oooo00<0I_ooooooool01?ooo`030000oooooooo07[oool006Coool506Ko=?ooo`0306Ko
oooooooo00?oool00`000?ooooooo`1joooo001Ooooo1@1VocWoool00`1Vooooooooo`03oooo00<0
003oooooool0N_ooo`00EOooo`X0I_looooo00<0I_ooooooool00_ooo`030000oooooooo07[oool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooo000001000000
0c?o000003?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`03oooo00Go09Wooooo
ooooool000002Oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000
oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_ooo`@0000K<ol000<0003ooooo
ool08Oooo`05o`2Ioooooooooooo000002Soool00`000?ooooooo`0Yoooo0028oooo100001Lco`00
0`000?ooooooo`0Qoooo00?o09Woooooool0E_ooo`00S?ooo`030000<ol0<ol001@co`000`000?oo
ooooo`0Qoooo00?o09Woooooool0E_ooo`00SOooo`80000D<ol000<0003oooooool08Oooo`03o`2I
oooooooo05Koool008ooool00`0003?o03?o000A<ol000<0003oooooool08Oooo`03o`2Ioooooooo
05Koool0093oool00`0003?o03?o000@<ol00P0002;oool00ol0VOooooooo`1Foooo002Aoooo0P00
010co`000`000?ooooooo`0Qoooo00?o09Woooooool0E_ooo`00Toooo`030000<ol0<ol000dco`00
0`000?ooooooo`0Qoooo00?o09Woooooool0E_ooo`00Toooo`030000<ol0<ol000dco`000`000?oo
ooooo`0Qoooo00?o09Woooooool0E_ooo`00U?ooo`030000<ol0<ol000`co`000`000?ooooooo`0Q
oooo00?o09Woooooool0E_ooo`00U?ooo`030000<ol0<ol000`co`000`000?ooooooo`0Qoooo00?o
09Woooooool0E_ooo`00UOooo`030000<ol0<ol000/co`0200008_ooo`03o`2Ioooooooo05Koool0
09Goool00`0003?o03?o000;<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool009Koool0
0`0003?o03?o000:<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool009Koool00`0003?o
03?o000:<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool009Ooool00`0003?o03?o0009
<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool009Ooool00`0003?o03?o0009<ol000<0
003oooooool08Oooo`03o`2Ioooooooo05Koool009Soool00`0003?o03?o0008<ol00P0002;oool0
0ol0VOooooooo`1Foooo002Hoooo00<0000co`0co`0023?o00030000oooooooo027oool00ol0VOoo
ooooo`1Foooo002Hoooo00<0000co`0co`0023?o00030000oooooooo027oool00ol0VOooooooo`1F
oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo027oool00ol0VOooooooo`1Foooo002I
oooo00<0000co`0co`001c?o00030000oooooooo027oool00ol0VOooooooo`1Foooo002Ioooo00<0
000co`0co`001c?o00030000oooooooo027oool00ol0VOooooooo`1Foooo002Ioooo00<0000co`0c
o`001c?o0080000Roooo00?o09Woooooool0E_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0Qoooo00?o09Woooooool0E_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`0Q
oooo00?o09Woooooool0E_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`0Qoooo00?o
09Woooooool0E_ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`0Qoooo00?o09Wooooo
ool0E_ooo`00Voooo`D00003<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool009_oool0
0`0003?o00000005<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool009_oool00`0003?o
00000005<ol00`00027oool00ol0VOooooooo`1Foooo002Loooo0P0000Dco`000`000?ooooooo`0Q
oooo00?o09Woooooool0E_ooo`00W?ooo`800005<ol000<0003oooooool08Oooo`03o`2Ioooooooo
05Koool009coool200001C?o00030000oooooooo027oool00ol0VOooooooo`1Foooo002Loooo00<0
000co`0co`0013?o00030000oooooooo027oool00ol0VOooooooo`1Foooo002Loooo00<0000co`0c
o`0013?o00030000oooooooo027oool00ol0VOooooooo`1Foooo002Loooo00<0000co`0co`0013?o
0080000Roooo00?o09Woooooool0E_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0Q
oooo00?o09Woooooool0E_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0Qoooo00?o
09Woooooool0E_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0Qoooo00?o09Wooooo
ool0E_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0Qoooo00?o09Woooooool0E_oo
o`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0Qoooo00?o09Woooooool0E_ooo`00WOoo
o`030000<ol0<ol000<co`0200008_ooo`03o`2Ioooooooo05Koool009goool00`0003?o03?o0003
<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool009goool00`0003?o03?o0003<ol000<0
003oooooool08Oooo`03o`2Ioooooooo05Koool009koool00`0003?o03?o0002<ol000<0003ooooo
ool08Oooo`03o`2Ioooooooo05Koool009koool00`0003?o03?o0002<ol000<0003oooooool08Ooo
o`03o`2Ioooooooo05Koool009koool00`0003?o03?o0002<ol000<0003oooooool08Oooo`03o`2I
oooooooo05Koool009koool00`0003?o03?o0002<ol000<0003oooooool08Oooo`03o`2Ioooooooo
05Koool009koool00`0003?o03?o0002<ol00P0002;oool00ol0VOooooooo`1Foooo002Noooo00<0
000co`0co`000S?o00030000oooooooo027oool00ol0VOooooooo`1Foooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo027oool00ol0VOooooooo`1Foooo002Noooo00<0000co`0co`000S?o
00030000oooooooo027oool00ol0VOooooooo`1Foooo002Noooo00<0000co`0co`000S?o00030000
oooooooo027oool00ol0VOooooooo`1Foooo002Noooo00<0000co`0co`000S?o00030000oooooooo
027oool00ol0VOooooooo`1Foooo002Noooo00<0000co`0co`000S?o0080000Roooo00?o09Wooooo
ool0E_ooo`00Woooo`050000<ol0<ol0<ol0000002?oool00ol0VOooooooo`1Foooo002Ooooo00D0
000co`0co`0co`0000008oooo`03o`2Ioooooooo05Koool009ooool01@0003?o03?o03?o0000000S
oooo00?o09Woooooool0E_ooo`00Voooo`D00003<ol000<0003oooooool08Oooo`03o`2Ioooooooo
05Koool009_oool01@000?ooooooooooo`000003<ol000<0003oooooool08Oooo`03o`2Ioooooooo
05Koool009coool010000?ooooooo`0000<co`0300008Oooo`03o`2Ioooooooo05Koool009goool0
0`000?ooo`000003<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Koool009_oool00`000?oo
ooooo`0200000c?o00030000oooooooo027oool00ol0VOooooooo`1Foooo002Loooo0P000003oooo
0000<ol0008co`000`000?ooooooo`0Qoooo00?o09Woooooool0E_ooo`00Woooo`050000<ol0<ol0
<ol0000002?oool00ol0VOooooooo`1Foooo002Poooo00@0000co`0co`00000Soooo00?o09Wooooo
ool0E_ooo`00X?ooo`030000<ol0<ol00080000Roooo00?o09Woooooool0E_ooo`00X?ooo`040000
<ol0<ol000008oooo`03o`2Ioooooooo05Koool00:3oool0100003?o03?o000002?oool00ol0VOoo
ooooo`1Foooo002Poooo00@0000co`0co`00000Soooo00?o09Woooooool0E_ooo`00X?ooo`040000
<ol0<ol000008oooo`03o`2Ioooooooo05Koool00:3oool0100003?o03?o000002?oool00ol0VOoo
ooooo`1Foooo002Poooo00@0000co`0co`00000Soooo00?o09Woooooool0E_ooo`00XOooo`040000
<ol0000000008_ooo`03o`2Ioooooooo05Koool00:7oool00`0003?o0000000Soooo00?o09Wooooo
ool0E_ooo`00XOooo`030000<ol0000002?oool00ol0VOooooooo`1Foooo002Qoooo00<0000co`00
00008oooo`03o`2Ioooooooo05Koool00:7oool00`0003?o0000000Soooo00?o09Woooooool0E_oo
o`00XOooo`030000<ol0000002?oool00ol0VOooooooo`1Foooo002Qoooo00@0000co`000000000R
oooo00?o09Woooooool0E_ooo`00XOooo`030000<ol0000002?oool00ol0VOooooooo`1Foooo002Q
oooo00<0000co`0000008oooo`03o`2Ioooooooo05Koool00:7oool00`0003?o0000000Soooo00?o
09Woooooool0E_ooo`00XOooo`030000<ol0000002?oool00ol0VOooooooo`1Foooo002Qoooo00<0
000co`0000008oooo`03o`2Ioooooooo05Koool00:7oool0100003?o0000000002;oool00ol0VOoo
ooooo`1Foooo002Qoooo00<0000co`0000008oooo`03o`2Ioooooooo05Koool00:7oool00`0003?o
0000000Soooo00?o09Woooooool0E_ooo`00XOooo`030000<ol0000002?oool00ol0VOooooooo`1F
oooo002Loooo0P0000?oool00`0003?o0000000Soooo00?o09Woooooool0E_ooo`00Voooo`040000
oooooooo00000_ooo`030000<ol0000002?oool00ol0VOooooooo`1Foooo002Moooo00H0003ooooo
ooooool0000co`0300008Oooo`03o`2Ioooooooo05Koool009koool01P000?ooooooo`0003?o0000
02?oool00ol0VOooooooo`1Foooo002Koooo00@0003oooooool00002oooo00<0000co`0000008ooo
o`03o`2Ioooooooo05Koool009coool200001?ooo`80000Soooo00?o09Woooooool0E_ooo`00X_oo
o`80000Soooo00?o09Woooooool0E_ooo`00X_ooo`80000Soooo00?o09Woooooool0E_ooo`00X_oo
o`80000Soooo00?o09Woooooool0E_ooo`00X_ooo`<0000Roooo00?o09Woooooool0E_ooo`00X_oo
o`80000Soooo00?o09Woooooool0E_ooo`00X_ooo`80000Soooo00?o09Woooooool0E_ooo`00X_oo
o`80000Soooo00?o09Woooooool0E_ooo`00X_ooo`80000Soooo00?o09Woooooool0E_ooo`00X_oo
o`80000Soooo00?o09Woooooool0E_ooo`00X_ooo`<0000Roooo00?o09Woooooool0E_ooo`00X_oo
o`80000Soooo00?o09Woooooool0E_ooo`00X_ooo`80000Soooo00?o09Woooooool0E_ooo`00X_oo
o`80000Soooo00?o09Woooooool0E_ooo`00X_ooo`80000Soooo00?o09Woooooool0E_ooo`00X_oo
o`80000Soooo00?o09Woooooool0E_ooo`00X_ooo`<0000Roooo00?o09Woooooool0E_ooo`00Xooo
o`030000oooooooo027oool00ol0VOooooooo`1Foooo002Soooo00<0003oooooool08Oooo`03o`2I
oooooooo05Koool00:?oool00`000?ooooooo`0Qoooo00?o09Woooooool0E_ooo`00Xoooo`030000
oooooooo027oool00ol0VOooooooo`1Foooo002Soooo00<0003oooooool08Oooo`03o`2Ioooooooo
05Koool00:?oool200008_ooo`03o`2Ioooooooo05Koool00:?oool00`000?ooooooo`0Qoooo00?o
09Woooooool0E_ooo`00Xoooo`030000oooooooo027oool00ol0VOooooooo`1Foooo002Soooo00<0
003oooooool08Oooo`03o`2Ioooooooo05Koool00:?oool00`000?ooooooo`0Qoooo00?o09Wooooo
ool0E_ooo`00WOooo`<00003oooo00<0003oooooool08Oooo`03o`2Ioooooooo05Koool009koool0
0`000?ooooooo`02oooo00<0003oooooool08Oooo`03o`2Ioooooooo05Koool009_oool500000ooo
o`<0000Qoooo00?o09Woooooool0E_ooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000
oooo0000087oool009goool20000POooo`00ooooob7oool00?oooolQoooo001loooo00<0003ooooo
ool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Ooo
o`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500003?ooo`040000oooooooo00002Oooo`800004oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:
oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71741 .12361 L
.72307 .12361 L
.72585 .12361 L
.72707 .12361 L
.72841 .12361 L
.72961 .12361 L
s
.72961 .12361 m
.73006 .61803 L
s
0 .4 1 r
.02381 .12355 m
.04262 .12352 L
.06244 .12349 L
.07286 .12347 L
.08255 .12344 L
.09388 .1234 L
.10458 .12336 L
.125 .12325 L
.14357 .12311 L
.16355 .1229 L
.18199 .12262 L
.20071 .12223 L
.21136 .12194 L
.22134 .12162 L
.24158 .12076 L
.26011 .11964 L
.27909 .11805 L
.28984 .11688 L
.29982 .11557 L
.32034 .11202 L
.33895 .10746 L
.35819 .10085 L
.36904 .096 L
.37901 .09063 L
.39784 .07748 L
.40853 .0678 L
.4185 .05693 L
.42351 .05071 L
.42615 .04719 L
.42759 .04519 L
.4283 .04419 L
.42895 .04386 L
.43013 .04402 L
.4314 .0442 L
.4341 .04458 L
.43885 .04531 L
.45741 .04878 L
.47633 .05365 L
.49703 .06105 L
.51665 .07082 L
.5376 .08535 L
.55751 .10487 L
.56799 .11846 L
.5693 .12037 L
.57054 .12224 L
.57123 .12329 L
.57197 .12361 L
.57328 .12361 L
.57403 .12361 L
.57484 .12361 L
Mistroke
.5756 .12361 L
.57628 .12361 L
.57698 .12361 L
.57773 .12361 L
.57844 .12361 L
.57909 .12361 L
.5803 .12361 L
.58159 .12361 L
.58392 .12361 L
.58922 .12361 L
.5999 .12361 L
.61908 .12361 L
.66049 .12361 L
.70039 .12361 L
.73877 .12361 L
.7796 .12361 L
.81892 .12361 L
.85672 .12361 L
.89698 .12361 L
.93572 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool007goool206Ko9?ooo`030000oooooooo
07[oool007coool206Ko00?oool0I_l0I_l01@1Voagoool00`000?ooooooo`1joooo001loooo00<0
I_ooooooool01oooo`80I_lKoooo0P0007_oool007[oool206Ko3?ooo`<0I_lHoooo00<0003ooooo
ool0N_ooo`00NOooo`0306Kooooooooo00ooool206Ko5_ooo`030000oooooooo07[oool007Woool0
0`1Vooooooooo`0Aoooo0`1Voa?oool00`000?ooooooo`1joooo001hoooo00<0I_ooooooool05Ooo
o`80I_lAoooo00<0003oooooool0N_ooo`00Moooo`0306Kooooooooo01Soool206Ko3oooo`030000
oooooooo07[oool007Koool00`1Vooooooooo`0Koooo0P1Vo`goool20000Noooo`00:oooo`<0000X
oooo0`0001coool00`1Vooooooooo`04oooo100001Koool00`1Vooooooooo`0:oooo00<0003ooooo
ool08oooo`@0000Woooo0`0002Woool002_oool010000?ooooooo`0002Soool00`000?ooooooo`0I
oooo0P1Vo`Ooool00`000?ooooooo`0Hoooo0P1Vo`[oool00`000?ooooooo`0Soooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool500006?ooo`80I_l:
oooo00<0003oooooool06Oooo`0306Kooooooooo00Ooool00`000?ooooooo`0Toooo00<0003ooooo
ool09Oooo`D0000Yoooo000Uoooo100000;oool300008?ooo`@00002oooo00@0003oooooool0000H
oooo00<0I_ooooooool00oooo`@00004oooo00<0003oooooool06Oooo`0306Kooooooooo00Koool0
0`000?ooooooo`0Uoooo00<0003oooooool09?ooo`040000oooooooo0000:_ooo`00;?ooo`030000
oooooooo02Koool00`000?ooo`00000Foooo0P1Vo`coool010000?ooooooo`0001_oool00`1Voooo
ooooo`05oooo00<0003oooooool08oooo`040000oooooooo00009_ooo`030000oooo000002[oool0
02coool300009oooo`80000Doooo0P1Vo`ooool200007Oooo`0306Kooooooooo00Coool200009Ooo
o`80000Xoooo0P0002[oool006Woool306Ko<Oooo`0306Kooooooooo00?oool00`000?ooooooo`1j
oooo001Toooo1@1VocGoool00`1Vooooooooo`02oooo00<0003oooooool0N_ooo`00Goooo`D0I_lk
oooo00D0I_ooooooooooool00000O?ooo`00G?ooo`<0I_m0oooo00D0I_ooooooooooool00000O?oo
o`00D?ooo``0I_m4oooo00@0I_ooooooool0001loooo000@ooooo`00017oool001Koool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01Oooo`03o`2Ioooo000000Woool00`000?ooooooo`07oooo00<0
003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000
oooooooo00Koool400006c?o00030000oooooooo02?oool00ol0VOooo`00000Xoooo00<0003ooooo
ool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool008coool0
0`0003?o03?o000D<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool008goool2000053?o
00030000oooooooo02?oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`004C?o00030000
oooooooo02?oool00ol0VOooooooo`1Doooo002@oooo00<0000co`0co`0043?o0080000Toooo00?o
09Woooooool0E?ooo`00TOooo`80000@<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool0
09?oool00`0003?o03?o000=<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool009?oool0
0`0003?o03?o000=<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool009Coool00`0003?o
03?o000<<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool009Coool00`0003?o03?o000<
<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool009Goool00`0003?o03?o000;<ol00P00
02Coool00ol0VOooooooo`1Doooo002Eoooo00<0000co`0co`002c?o00030000oooooooo02?oool0
0ol0VOooooooo`1Doooo002Foooo00<0000co`0co`002S?o00030000oooooooo02?oool00ol0VOoo
ooooo`1Doooo002Foooo00<0000co`0co`002S?o00030000oooooooo02?oool00ol0VOooooooo`1D
oooo002Goooo00<0000co`0co`002C?o00030000oooooooo02?oool00ol0VOooooooo`1Doooo002G
oooo00<0000co`0co`002C?o00030000oooooooo02?oool00ol0VOooooooo`1Doooo002Hoooo00<0
000co`0co`0023?o0080000Toooo00?o09Woooooool0E?ooo`00V?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0Soooo00?o09Woooooool0E?ooo`00V?ooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0Soooo00?o09Woooooool0E?ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0S
oooo00?o09Woooooool0E?ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0Soooo00?o
09Woooooool0E?ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0Soooo00?o09Wooooo
ool0E?ooo`00VOooo`030000<ol0<ol000Lco`0200009?ooo`03o`2Ioooooooo05Coool009[oool0
0`0003?o03?o0006<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool009[oool00`0003?o
03?o0006<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool009[oool00`0003?o03?o0006
<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool009[oool00`0003?o03?o0006<ol000<0
003oooooool08oooo`03o`2Ioooooooo05Coool009_oool500000c?o00030000oooooooo02?oool0
0ol0VOooooooo`1Doooo002Koooo00<0000co`0000001C?o00030000oooooooo02?oool00ol0VOoo
ooooo`1Doooo002Koooo00<0000co`0000001C?o00<0000Soooo00?o09Woooooool0E?ooo`00W?oo
o`800005<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool009coool200001C?o00030000
oooooooo02?oool00ol0VOooooooo`1Doooo002Loooo0P0000Dco`000`000?ooooooo`0Soooo00?o
09Woooooool0E?ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0Soooo00?o09Wooooo
ool0E?ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0Soooo00?o09Woooooool0E?oo
o`00W?ooo`030000<ol0<ol000@co`0200009?ooo`03o`2Ioooooooo05Coool009goool00`0003?o
03?o0003<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool009goool00`0003?o03?o0003
<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool009goool00`0003?o03?o0003<ol000<0
003oooooool08oooo`03o`2Ioooooooo05Coool009goool00`0003?o03?o0003<ol000<0003ooooo
ool08oooo`03o`2Ioooooooo05Coool009goool00`0003?o03?o0003<ol000<0003oooooool08ooo
o`03o`2Ioooooooo05Coool009goool00`0003?o03?o0003<ol00P0002Coool00ol0VOooooooo`1D
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo02?oool00ol0VOooooooo`1Doooo002M
oooo00<0000co`0co`000c?o00030000oooooooo02?oool00ol0VOooooooo`1Doooo002Noooo00<0
000co`0co`000S?o00030000oooooooo02?oool00ol0VOooooooo`1Doooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo02?oool00ol0VOooooooo`1Doooo002Noooo00<0000co`0co`000S?o
00030000oooooooo02?oool00ol0VOooooooo`1Doooo002Noooo00<0000co`0co`000S?o00030000
oooooooo02?oool00ol0VOooooooo`1Doooo002Noooo00<0000co`0co`000S?o0080000Toooo00?o
09Woooooool0E?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Soooo00?o09Wooooo
ool0E?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Soooo00?o09Woooooool0E?oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Soooo00?o09Woooooool0E?ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`0Soooo00?o09Woooooool0E?ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`0Soooo00?o09Woooooool0E?ooo`00W_ooo`030000<ol0<ol0
008co`0200009?ooo`03o`2Ioooooooo05Coool009ooool01@0003?o03?o03?o0000000Uoooo00?o
09Woooooool0E?ooo`00Woooo`050000<ol0<ol0<ol0000002Goool00ol0VOooooooo`1Doooo002O
oooo00D0000co`0co`0co`0000009Oooo`03o`2Ioooooooo05Coool009_oool500000c?o00030000
oooooooo02?oool00ol0VOooooooo`1Doooo002Koooo00D0003oooooooooool000000c?o00030000
oooooooo02?oool00ol0VOooooooo`1Doooo002Loooo00@0003oooooool00003<ol00`0002?oool0
0ol0VOooooooo`1Doooo002Moooo00<0003oool000000c?o00030000oooooooo02?oool00ol0VOoo
ooooo`1Doooo002Koooo00<0003oooooool00P0000<co`000`000?ooooooo`0Soooo00?o09Wooooo
ool0E?ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003oooooool08oooo`03o`2Ioooooooo
05Coool009ooool01@0003?o03?o03?o0000000Uoooo00?o09Woooooool0E?ooo`00X?ooo`040000
<ol0<ol000009Oooo`03o`2Ioooooooo05Coool00:3oool00`0003?o03?o000200009?ooo`03o`2I
oooooooo05Coool00:3oool0100003?o03?o000002Goool00ol0VOooooooo`1Doooo002Poooo00@0
000co`0co`00000Uoooo00?o09Woooooool0E?ooo`00X?ooo`040000<ol0<ol000009Oooo`03o`2I
oooooooo05Coool00:3oool0100003?o03?o000002Goool00ol0VOooooooo`1Doooo002Poooo00@0
000co`0co`00000Uoooo00?o09Woooooool0E?ooo`00X?ooo`040000<ol0<ol000009Oooo`03o`2I
oooooooo05Coool00:7oool0100003?o0000000002Coool00ol0VOooooooo`1Doooo002Qoooo00<0
000co`0000009Oooo`03o`2Ioooooooo05Coool00:7oool00`0003?o0000000Uoooo00?o09Wooooo
ool0E?ooo`00XOooo`030000<ol0000002Goool00ol0VOooooooo`1Doooo002Qoooo00<0000co`00
00009Oooo`03o`2Ioooooooo05Coool00:7oool00`0003?o0000000Uoooo00?o09Woooooool0E?oo
o`00XOooo`040000<ol0000000009?ooo`03o`2Ioooooooo05Coool00:7oool00`0003?o0000000U
oooo00?o09Woooooool0E?ooo`00XOooo`030000<ol0000002Goool00ol0VOooooooo`1Doooo002Q
oooo00<0000co`0000009Oooo`03o`2Ioooooooo05Coool00:7oool00`0003?o0000000Uoooo00?o
09Woooooool0E?ooo`00XOooo`030000<ol0000002Goool00ol0VOooooooo`1Doooo002Qoooo00@0
000co`000000000Toooo00?o09Woooooool0E?ooo`00XOooo`030000<ol0000002Goool00ol0VOoo
ooooo`1Doooo002Qoooo00<0000co`0000009Oooo`03o`2Ioooooooo05Coool00:7oool00`0003?o
0000000Uoooo00?o09Woooooool0E?ooo`00W?ooo`800003oooo00<0000co`0000009Oooo`03o`2I
oooooooo05Coool009_oool010000?ooooooo`0000;oool00`0003?o0000000Uoooo00?o09Wooooo
ool0E?ooo`00WOooo`060000oooooooooooo0000<ol00`0002?oool00ol0VOooooooo`1Doooo002N
oooo00H0003oooooool0000co`00000Uoooo00?o09Woooooool0E?ooo`00Voooo`040000oooooooo
00000_ooo`030000<ol0000002Goool00ol0VOooooooo`1Doooo002Loooo0P0000Coool200009Ooo
o`03o`2Ioooooooo05Coool00:;oool200009Oooo`03o`2Ioooooooo05Coool00:;oool200009Ooo
o`03o`2Ioooooooo05Coool00:;oool200009Oooo`03o`2Ioooooooo05Coool00:;oool300009?oo
o`03o`2Ioooooooo05Coool00:;oool200009Oooo`03o`2Ioooooooo05Coool00:;oool200009Ooo
o`03o`2Ioooooooo05Coool00:;oool200009Oooo`03o`2Ioooooooo05Coool00:;oool200009Ooo
o`03o`2Ioooooooo05Coool00:;oool200009Oooo`03o`2Ioooooooo05Coool00:;oool300009?oo
o`03o`2Ioooooooo05Coool00:;oool200009Oooo`03o`2Ioooooooo05Coool00:;oool200009Ooo
o`03o`2Ioooooooo05Coool00:;oool200009Oooo`03o`2Ioooooooo05Coool00:;oool200009Ooo
o`03o`2Ioooooooo05Coool00:;oool200009Oooo`03o`2Ioooooooo05Coool00:;oool300009?oo
o`03o`2Ioooooooo05Coool00:?oool00`000?ooooooo`0Soooo00?o09Woooooool0E?ooo`00Xooo
o`030000oooooooo02?oool00ol0VOooooooo`1Doooo002Soooo00<0003oooooool08oooo`03o`2I
oooooooo05Coool00:?oool00`000?ooooooo`0Soooo00?o09Woooooool0E?ooo`00Xoooo`030000
oooooooo02?oool00ol0VOooooooo`1Doooo002Soooo0P0002Coool00ol0VOooooooo`1Doooo002S
oooo00<0003oooooool08oooo`03o`2Ioooooooo05Coool00:?oool00`000?ooooooo`0Soooo00?o
09Woooooool0E?ooo`00Xoooo`030000oooooooo02?oool00ol0VOooooooo`1Doooo002Soooo00<0
003oooooool08oooo`03o`2Ioooooooo05Coool009goool300000oooo`030000oooooooo02?oool0
0ol0VOooooooo`1Doooo002Noooo00<0003oooooool00_ooo`030000oooooooo02?oool00ol0VOoo
ooooo`1Doooo002Koooo1@0000?oool300008oooo`03o`2Ioooooooo05Coool009_oool010000?oo
ooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQoooo003o
oooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003ooooo
ool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool300001?ooo`030000oooooooo
07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_oo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00009oooo0`0000Coool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool0
0`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo07coool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71741 .12361 L
.72307 .12361 L
.72841 .12361 L
.7332 .12361 L
.73451 .12361 L
.7359 .12361 L
.73708 .12361 L
s
.73708 .12361 m
.7376 .61803 L
s
0 .4 1 r
.02381 .12354 m
.04262 .12351 L
.06244 .12347 L
.07286 .12344 L
.08255 .12341 L
.09388 .12337 L
.10458 .12332 L
.125 .12319 L
.14357 .12302 L
.16355 .12277 L
.18199 .12245 L
.20071 .12199 L
.21136 .12165 L
.22134 .12127 L
.24158 .12026 L
.26011 .11895 L
.27909 .11707 L
.28984 .11569 L
.29982 .11415 L
.32034 .10998 L
.33895 .10462 L
.35819 .09685 L
.36904 .09114 L
.37901 .08483 L
.39784 .06936 L
.40853 .05798 L
.41371 .05162 L
.4185 .0452 L
.41975 .04343 L
.42093 .04219 L
.42215 .04232 L
.42351 .04246 L
.42895 .04309 L
.43885 .04439 L
.45741 .0475 L
.47759 .05218 L
.4961 .05808 L
.51502 .06623 L
.53572 .07845 L
.55533 .09444 L
.56631 .10604 L
.57628 .11898 L
.57749 .12075 L
.57879 .12271 L
.58001 .12361 L
.58113 .12361 L
.58358 .12361 L
.58626 .12361 L
.59547 .12361 L
.61626 .12361 L
Mistroke
.65603 .12361 L
.69427 .12361 L
.73497 .12361 L
.77415 .12361 L
.81578 .12361 L
.8559 .12361 L
.89451 .12361 L
.93556 .12361 L
.9751 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool007_oool706Ko8Oooo`030000oooooooo
07[oool007[oool00`1Vooooooooo`05oooo1@1Voacoool00`000?ooooooo`1joooo001ioooo00<0
I_ooooooool02oooo`@0I_lHoooo0P0007_oool007Soool00`1Vooooooooo`0@oooo0P1VoaKoool0
0`000?ooooooo`1joooo001hoooo00<0I_ooooooool04_ooo`<0I_lCoooo00<0003oooooool0N_oo
o`00Moooo`0306Kooooooooo01Koool206Ko4Oooo`030000oooooooo07[oool007Koool00`1Voooo
ooooo`0Ioooo0P1Vo`ooool00`000?ooooooo`1joooo001eoooo00<0I_ooooooool07?ooo`80I_l=
oooo00<0003oooooool0N_ooo`00M?ooo`0306Kooooooooo01ooool206Ko2oooo`80001koooo000[
oooo0`0002Soool300006Oooo`80I_l8oooo100001Soool00`1Vooooooooo`08oooo00<0003ooooo
ool08oooo`@0000Woooo0`0002Woool002_oool010000?ooooooo`0002Soool00`000?ooooooo`0G
oooo00<0I_ooooooool02?ooo`030000oooooooo01[oool00`1Vooooooooo`07oooo00<0003ooooo
ool08oooo`030000oooooooo02Woool00`000?ooooooo`0Xoooo000[oooo00@0003oooooool0000U
oooo1@0001Ooool00`1Vooooooooo`0:oooo00<0003oooooool06_ooo`80I_l7oooo00<0003ooooo
ool09?ooo`030000oooooooo02Goool50000:Oooo`009Oooo`@00002oooo0`00023oool400000_oo
o`040000oooooooo00005_ooo`80I_l6oooo100000Coool00`000?ooooooo`0Koooo00<0I_oooooo
ool01?ooo`030000oooooooo02Goool00`000?ooooooo`0Toooo00@0003oooooool0000Zoooo000/
oooo00<0003oooooool09_ooo`030000oooo000001Coool206Ko3_ooo`040000oooooooo00007Ooo
o`0306Kooooooooo00?oool00`000?ooooooo`0Soooo00@0003oooooool0000Voooo00<0003oool0
0000:_ooo`00;?ooo`<0000Woooo0P0001;oool206Ko4Oooo`80000Ooooo00<0I_ooooooool00_oo
o`80000Uoooo0P0002Soool20000:_ooo`00J?ooo`80I_leoooo00D0I_ooooooooooool00000O?oo
o`00I?ooo`@0I_lhoooo00@0I_ooooooool0001loooo001Ooooo1@1Vocgoool00`1Vooooo`00001l
oooo001Ioooo1P1Vod;oool00`1Vooooo`00001loooo001@oooo2@1VodWoool00`1Vo`000?ooo`1k
oooo000@ooooo`00017oool001Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`00000@
000000<co`00000co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool002[oool00`000?oo
ooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo00Koool400006c?o00030000oooooooo
02Goool00`000?ooooooo`0Voooo00<0003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003ooooo
ool09Oooo`03o`2Ioooooooo05;oool008coool00`0003?o03?o000D<ol000<0003oooooool09Ooo
o`03o`2Ioooooooo05;oool008goool2000053?o00030000oooooooo02Goool00ol0VOooooooo`1B
oooo002?oooo00<0000co`0co`004C?o00030000oooooooo02Goool00ol0VOooooooo`1Boooo002@
oooo00<0000co`0co`0043?o0080000Voooo00?o09Woooooool0D_ooo`00TOooo`80000@<ol000<0
003oooooool09Oooo`03o`2Ioooooooo05;oool009?oool00`0003?o03?o000=<ol000<0003ooooo
ool09Oooo`03o`2Ioooooooo05;oool009?oool00`0003?o03?o000=<ol000<0003oooooool09Ooo
o`03o`2Ioooooooo05;oool009Coool00`0003?o03?o000<<ol000<0003oooooool09Oooo`03o`2I
oooooooo05;oool009Coool00`0003?o03?o000<<ol000<0003oooooool09Oooo`03o`2Ioooooooo
05;oool009Goool00`0003?o03?o000;<ol00P0002Koool00ol0VOooooooo`1Boooo002Eoooo00<0
000co`0co`002c?o00030000oooooooo02Goool00ol0VOooooooo`1Boooo002Foooo00<0000co`0c
o`002S?o00030000oooooooo02Goool00ol0VOooooooo`1Boooo002Foooo00<0000co`0co`002S?o
00030000oooooooo02Goool00ol0VOooooooo`1Boooo002Goooo00<0000co`0co`002C?o00030000
oooooooo02Goool00ol0VOooooooo`1Boooo002Goooo00<0000co`0co`002C?o00030000oooooooo
02Goool00ol0VOooooooo`1Boooo002Hoooo00<0000co`0co`0023?o0080000Voooo00?o09Wooooo
ool0D_ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0Uoooo00?o09Woooooool0D_oo
o`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00VOoo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00VOooo`030000
<ol0<ol000Lco`000`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00VOooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00VOooo`030000<ol0<ol000Lco`02
00009_ooo`03o`2Ioooooooo05;oool009[oool00`0003?o03?o0006<ol000<0003oooooool09Ooo
o`03o`2Ioooooooo05;oool009[oool00`0003?o03?o0006<ol000<0003oooooool09Oooo`03o`2I
oooooooo05;oool009[oool00`0003?o03?o0006<ol000<0003oooooool09Oooo`03o`2Ioooooooo
05;oool009[oool00`0003?o03?o0006<ol000<0003oooooool09Oooo`03o`2Ioooooooo05;oool0
09_oool500000c?o00030000oooooooo02Goool00ol0VOooooooo`1Boooo002Koooo00<0000co`00
00001C?o00030000oooooooo02Goool00ol0VOooooooo`1Boooo002Koooo00<0000co`0000001C?o
00<0000Uoooo00?o09Woooooool0D_ooo`00W?ooo`800005<ol000<0003oooooool09Oooo`03o`2I
oooooooo05;oool009coool200001C?o00030000oooooooo02Goool00ol0VOooooooo`1Boooo002L
oooo0P0000Dco`000`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00W?ooo`030000<ol0<ol0
00@co`000`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00W?ooo`030000<ol0<ol000@co`00
0`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00W?ooo`030000<ol0<ol000@co`0200009_oo
o`03o`2Ioooooooo05;oool009goool00`0003?o03?o0003<ol000<0003oooooool09Oooo`03o`2I
oooooooo05;oool009goool00`0003?o03?o0003<ol000<0003oooooool09Oooo`03o`2Ioooooooo
05;oool009goool00`0003?o03?o0003<ol000<0003oooooool09Oooo`03o`2Ioooooooo05;oool0
09goool00`0003?o03?o0003<ol000<0003oooooool09Oooo`03o`2Ioooooooo05;oool009goool0
0`0003?o03?o0003<ol000<0003oooooool09Oooo`03o`2Ioooooooo05;oool009goool00`0003?o
03?o0003<ol00P0002Koool00ol0VOooooooo`1Boooo002Moooo00<0000co`0co`000c?o00030000
oooooooo02Goool00ol0VOooooooo`1Boooo002Moooo00<0000co`0co`000c?o00030000oooooooo
02Goool00ol0VOooooooo`1Boooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Goool0
0ol0VOooooooo`1Boooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Goool00ol0VOoo
ooooo`1Boooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Goool00ol0VOooooooo`1B
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Goool00ol0VOooooooo`1Boooo002N
oooo00<0000co`0co`000S?o0080000Voooo00?o09Woooooool0D_ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0Uoooo00?o09Woooooool0D_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0U
oooo00?o09Woooooool0D_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Uoooo00?o
09Woooooool0D_ooo`00W_ooo`030000<ol0<ol0008co`0200009_ooo`03o`2Ioooooooo05;oool0
09ooool01@0003?o03?o03?o0000000Woooo00?o09Woooooool0D_ooo`00Woooo`050000<ol0<ol0
<ol0000002Ooool00ol0VOooooooo`1Boooo002Ooooo00D0000co`0co`0co`0000009oooo`03o`2I
oooooooo05;oool009_oool500000c?o00030000oooooooo02Goool00ol0VOooooooo`1Boooo002K
oooo00D0003oooooooooool000000c?o00030000oooooooo02Goool00ol0VOooooooo`1Boooo002L
oooo00@0003oooooool00003<ol00`0002Goool00ol0VOooooooo`1Boooo002Moooo00<0003oool0
00000c?o00030000oooooooo02Goool00ol0VOooooooo`1Boooo002Koooo00<0003oooooool00P00
00<co`000`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00W?ooo`8000000oooo`0003?o0002
<ol000<0003oooooool09Oooo`03o`2Ioooooooo05;oool009ooool01@0003?o03?o03?o0000000W
oooo00?o09Woooooool0D_ooo`00X?ooo`040000<ol0<ol000009oooo`03o`2Ioooooooo05;oool0
0:3oool00`0003?o03?o000200009_ooo`03o`2Ioooooooo05;oool00:3oool0100003?o03?o0000
02Ooool00ol0VOooooooo`1Boooo002Poooo00@0000co`0co`00000Woooo00?o09Woooooool0D_oo
o`00X?ooo`040000<ol0<ol000009oooo`03o`2Ioooooooo05;oool00:3oool0100003?o03?o0000
02Ooool00ol0VOooooooo`1Boooo002Poooo00@0000co`0co`00000Woooo00?o09Woooooool0D_oo
o`00X?ooo`040000<ol0<ol000009oooo`03o`2Ioooooooo05;oool00:7oool0100003?o00000000
02Koool00ol0VOooooooo`1Boooo002Qoooo00<0000co`0000009oooo`03o`2Ioooooooo05;oool0
0:7oool00`0003?o0000000Woooo00?o09Woooooool0D_ooo`00XOooo`030000<ol0000002Ooool0
0ol0VOooooooo`1Boooo002Qoooo00<0000co`0000009oooo`03o`2Ioooooooo05;oool00:7oool0
0`0003?o0000000Woooo00?o09Woooooool0D_ooo`00XOooo`040000<ol0000000009_ooo`03o`2I
oooooooo05;oool00:7oool00`0003?o0000000Woooo00?o09Woooooool0D_ooo`00XOooo`030000
<ol0000002Ooool00ol0VOooooooo`1Boooo002Qoooo00<0000co`0000009oooo`03o`2Ioooooooo
05;oool00:7oool00`0003?o0000000Woooo00?o09Woooooool0D_ooo`00XOooo`030000<ol00000
02Ooool00ol0VOooooooo`1Boooo002Qoooo00@0000co`000000000Voooo00?o09Woooooool0D_oo
o`00XOooo`030000<ol0000002Ooool00ol0VOooooooo`1Boooo002Qoooo00<0000co`0000009ooo
o`03o`2Ioooooooo05;oool00:7oool00`0003?o0000000Woooo00?o09Woooooool0D_ooo`00W?oo
o`800003oooo00<0000co`0000009oooo`03o`2Ioooooooo05;oool009_oool010000?ooooooo`00
00;oool00`0003?o0000000Woooo00?o09Woooooool0D_ooo`00WOooo`060000oooooooooooo0000
<ol00`0002Goool00ol0VOooooooo`1Boooo002Noooo00H0003oooooool0000co`00000Woooo00?o
09Woooooool0D_ooo`00Voooo`040000oooooooo00000_ooo`030000<ol0000002Ooool00ol0VOoo
ooooo`1Boooo002Loooo0P0000Coool200009oooo`03o`2Ioooooooo05;oool00:;oool200009ooo
o`03o`2Ioooooooo05;oool00:;oool200009oooo`03o`2Ioooooooo05;oool00:;oool200009ooo
o`03o`2Ioooooooo05;oool00:;oool300009_ooo`03o`2Ioooooooo05;oool00:;oool200009ooo
o`03o`2Ioooooooo05;oool00:;oool200009oooo`03o`2Ioooooooo05;oool00:;oool200009ooo
o`03o`2Ioooooooo05;oool00:;oool200009oooo`03o`2Ioooooooo05;oool00:;oool200009ooo
o`03o`2Ioooooooo05;oool00:;oool300009_ooo`03o`2Ioooooooo05;oool00:;oool200009ooo
o`03o`2Ioooooooo05;oool00:;oool200009oooo`03o`2Ioooooooo05;oool00:;oool200009ooo
o`03o`2Ioooooooo05;oool00:;oool200009oooo`03o`2Ioooooooo05;oool00:;oool200009ooo
o`03o`2Ioooooooo05;oool00:;oool300009_ooo`03o`2Ioooooooo05;oool00:?oool00`000?oo
ooooo`0Uoooo00?o09Woooooool0D_ooo`00Xoooo`030000oooooooo02Goool00ol0VOooooooo`1B
oooo002Soooo00<0003oooooool09Oooo`03o`2Ioooooooo05;oool00:?oool00`000?ooooooo`0U
oooo00?o09Woooooool0D_ooo`00Xoooo`030000oooooooo02Goool00ol0VOooooooo`1Boooo002S
oooo0P0002Koool00ol0VOooooooo`1Boooo002Soooo00<0003oooooool09Oooo`03o`2Ioooooooo
05;oool00:?oool00`000?ooooooo`0Uoooo00?o09Woooooool0D_ooo`00Xoooo`030000oooooooo
02Goool00ol0VOooooooo`1Boooo002Soooo00<0003oooooool09Oooo`03o`2Ioooooooo05;oool0
09goool300000oooo`030000oooooooo02Goool00ol0VOooooooo`1Boooo002Noooo00<0003ooooo
ool00_ooo`030000oooooooo02Goool00ol0VOooooooo`1Boooo002Koooo1@0000?oool300009Ooo
o`03o`2Ioooooooo05;oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021
oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00Ooooo`030000oooooooo01coool0
0`000?ooooooo`1ooooo001noooo00<0003oooooool02?ooo`030000oooooooo01?oool00`000?oo
ooooo`1noooo001noooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
oooo0P0000Coool00`000?ooooooo`1noooo001noooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo07koool0
07goool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Woool00`000?oo
ooooo`1moooo001noooo00<0003oooooool01@0000koool00`000?ooooooo`08oooo00<0003ooooo
ool0O_ooo`00O_ooo`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003ooooo
ool0O_ooo`00Ooooo`030000oooooooo017oool200002Oooo`030000oooooooo07ooool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.72912 .12361 L
.73838 .12361 L
.74309 .12361 L
.74423 .12361 L
.74546 .12361 L
s
.74546 .12361 m
.74574 .61803 L
s
0 .4 1 r
.02381 .12353 m
.04262 .12349 L
.06244 .12345 L
.07286 .12341 L
.08255 .12338 L
.09388 .12332 L
.10458 .12327 L
.125 .12312 L
.14357 .12292 L
.16355 .12263 L
.18199 .12225 L
.20071 .12172 L
.21136 .12132 L
.22134 .12088 L
.24158 .11969 L
.26011 .11816 L
.27909 .11596 L
.28984 .11435 L
.29982 .11255 L
.32034 .10766 L
.33895 .10139 L
.35819 .09231 L
.36904 .08563 L
.37901 .07824 L
.39944 .05832 L
.40456 .05208 L
.40941 .04562 L
.41152 .04263 L
.41259 .04107 L
.41376 .041 L
.41503 .0411 L
.41623 .04121 L
.4185 .04141 L
.43683 .04337 L
.45647 .04628 L
.47666 .05043 L
.49516 .05565 L
.51408 .06283 L
.53479 .07348 L
.5544 .08717 L
.57535 .10753 L
.58032 .11365 L
.58304 .11732 L
.58559 .121 L
.58627 .12202 L
.58691 .12301 L
.58766 .12361 L
.58834 .12361 L
.59137 .12361 L
.59669 .12361 L
Mistroke
.61684 .12361 L
.65509 .12361 L
.69579 .12361 L
.73497 .12361 L
.7766 .12361 L
.81672 .12361 L
.85532 .12361 L
.89638 .12361 L
.93592 .12361 L
.97394 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00NOooo`0306Kooooooooo02Ooool00`000?ooooooo`1joooo001ioooo2@1V
ob7oool00`000?ooooooo`1joooo001hoooo00<0I_ooooooool01oooo`D0I_lLoooo00<0003ooooo
ool0N_ooo`00Moooo`0306Kooooooooo00goool506Ko5oooo`80001koooo001foooo00<0I_oooooo
ool04oooo`@0I_lCoooo00<0003oooooool0N_ooo`00MOooo`0306Kooooooooo01Soool206Ko4Ooo
o`030000oooooooo07[oool007Coool00`1Vooooooooo`0Koooo0P1Vo`ooool00`000?ooooooo`1j
oooo001coooo00<0I_ooooooool07_ooo`80I_l=oooo00<0003oooooool0N_ooo`00L_ooo`0306Ko
oooooooo027oool206Ko2oooo`030000oooooooo07[oool0077oool00`1Vooooooooo`0Toooo00<0
I_ooooooool02?ooo`80001koooo000[oooo0`0002Soool300005oooo`0306Kooooooooo00Woool4
00006Oooo`80I_l8oooo00<0003oooooool08oooo`@0000Woooo0`0002Woool002_oool010000?oo
ooooo`0002Soool00`000?ooooooo`0Eoooo00<0I_ooooooool02_ooo`030000oooooooo01coool2
06Ko1_ooo`030000oooooooo02?oool00`000?ooooooo`0Yoooo00<0003oooooool0:?ooo`00:ooo
o`040000oooooooo00009Oooo`D0000Doooo0P1Vo`koool00`000?ooooooo`0Moooo00<0I_oooooo
ool00oooo`030000oooooooo02Coool00`000?ooooooo`0Uoooo1@0002Woool002Goool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001?oool206Ko2Oooo`@00004oooo00<0003ooooo
ool07Oooo`0306Kooooooooo00;oool00`000?ooooooo`0Uoooo00<0003oooooool09?ooo`040000
oooooooo0000:_ooo`00;?ooo`030000oooooooo02Koool00`000?ooo`00000Aoooo0P1Voa7oool0
10000?ooooooo`0001ooool01@1Vooooooooooooo`00000Uoooo00@0003oooooool0000Voooo00<0
003oool00000:_ooo`00;?ooo`<0000Woooo0P0000ooool206Ko5?ooo`80000Qoooo00<0I_oooooo
ool00P0002Goool20000:?ooo`80000Zoooo001Toooo0`1Voc[oool00`1Vooooo`00001loooo001P
oooo101Vockoool00`1Vo`000?ooo`1koooo001Noooo0P1Vod;oool00`1Vo`000?ooo`1koooo001E
oooo2@1VodGoool00`000?ooooooo`1joooo001;oooo2P1Vodkoool00`00001Vooooo`1joooo000@
ooooo`00017oool001Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`00000@000000<c
o`00000co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000ooooo`2I
00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0V
oooo00<0003oooooool09Oooo`030000oooooooo00Koool400006c?o00030000oooooooo02Goool0
0`000?ooool0V@0Voooo00<0003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool09ooo
o`03o`2Ioooooooo053oool008coool00`0003?o03?o000D<ol000<0003oooooool09oooo`03o`2I
oooooooo053oool008goool2000053?o00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002?
oooo00<0000co`0co`004C?o00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002@oooo00<0
000co`0co`0043?o0080000Xoooo00?o09Woooooool0D?ooo`00TOooo`80000@<ol000<0003ooooo
ool09oooo`03o`2Ioooooooo053oool009?oool00`0003?o03?o000=<ol000<0003oooooool09ooo
o`03o`2Ioooooooo053oool009?oool00`0003?o03?o000=<ol000<0003oooooool09oooo`03o`2I
oooooooo053oool009Coool00`0003?o03?o000<<ol000<0003oooooool09oooo`03o`2Ioooooooo
053oool009Coool00`0003?o03?o000<<ol000<0003oooooool09oooo`03o`2Ioooooooo053oool0
09Goool00`0003?o03?o000;<ol00P0002Soool00ol0VOooooooo`1@oooo002Eoooo00<0000co`0c
o`002c?o00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Foooo00<0000co`0co`002S?o
00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Foooo00<0000co`0co`002S?o00030000
oooooooo02Ooool00ol0VOooooooo`1@oooo002Goooo00<0000co`0co`002C?o00030000oooooooo
02Ooool00ol0VOooooooo`1@oooo002Goooo00<0000co`0co`002C?o00030000oooooooo02Ooool0
0ol0VOooooooo`1@oooo002Hoooo00<0000co`0co`0023?o0080000Xoooo00?o09Woooooool0D?oo
o`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0Woooo00?o09Woooooool0D?ooo`00V?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`0Woooo00?o09Woooooool0D?ooo`00VOooo`030000
<ol0<ol000Lco`000`000?ooooooo`0Woooo00?o09Woooooool0D?ooo`00VOooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Woooo00?o09Woooooool0D?ooo`00VOooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Woooo00?o09Woooooool0D?ooo`00VOooo`030000<ol0<ol000Lco`020000:?oo
o`03o`2Ioooooooo053oool009[oool00`0003?o03?o0006<ol000<0003oooooool09oooo`03o`2I
oooooooo053oool009[oool00`0003?o03?o0006<ol000<0003oooooool09oooo`03o`2Ioooooooo
053oool009[oool00`0003?o03?o0006<ol000<0003oooooool09oooo`03o`2Ioooooooo053oool0
09[oool00`0003?o03?o0006<ol000<0003oooooool09oooo`03o`2Ioooooooo053oool009_oool5
00000c?o00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Koooo00<0000co`0000001C?o
00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Koooo00<0000co`0000001C?o00<0000W
oooo00?o09Woooooool0D?ooo`00W?ooo`800005<ol000<0003oooooool09oooo`03o`2Ioooooooo
053oool009coool200001C?o00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Loooo0P00
00Dco`000`000?ooooooo`0Woooo00?o09Woooooool0D?ooo`00W?ooo`030000<ol0<ol000@co`00
0`000?ooooooo`0Woooo00?o09Woooooool0D?ooo`00W?ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0Woooo00?o09Woooooool0D?ooo`00W?ooo`030000<ol0<ol000@co`020000:?ooo`03o`2I
oooooooo053oool009goool00`0003?o03?o0003<ol000<0003oooooool09oooo`03o`2Ioooooooo
053oool009goool00`0003?o03?o0003<ol000<0003oooooool09oooo`03o`2Ioooooooo053oool0
09goool00`0003?o03?o0003<ol000<0003oooooool09oooo`03o`2Ioooooooo053oool009goool0
0`0003?o03?o0003<ol000<0003oooooool09oooo`03o`2Ioooooooo053oool009goool00`0003?o
03?o0003<ol000<0003oooooool09oooo`03o`2Ioooooooo053oool009goool00`0003?o03?o0003
<ol00P0002Soool00ol0VOooooooo`1@oooo002Moooo00<0000co`0co`000c?o00030000oooooooo
02Ooool00ol0VOooooooo`1@oooo002Moooo00<0000co`0co`000c?o00030000oooooooo02Ooool0
0ol0VOooooooo`1@oooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Ooool00ol0VOoo
ooooo`1@oooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Ooool00ol0VOooooooo`1@
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002N
oooo00<0000co`0co`000S?o00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Noooo00<0
000co`0co`000S?o0080000Xoooo00?o09Woooooool0D?ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`0Woooo00?o09Woooooool0D?ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0Woooo00?o09Woooooool0D?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0W
oooo00?o09Woooooool0D?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Woooo00?o
09Woooooool0D?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Woooo00?o09Wooooo
ool0D?ooo`00W_ooo`030000<ol0<ol0008co`020000:?ooo`03o`2Ioooooooo053oool009ooool0
1@0003?o03?o03?o0000000Yoooo00?o09Woooooool0D?ooo`00Woooo`050000<ol0<ol0<ol00000
02Woool00ol0VOooooooo`1@oooo002Ooooo00D0000co`0co`0co`000000:Oooo`03o`2Ioooooooo
053oool009_oool500000c?o00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Koooo00D0
003oooooooooool000000c?o00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Loooo00@0
003oooooool00003<ol00`0002Ooool00ol0VOooooooo`1@oooo002Moooo00<0003oool000000c?o
00030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Koooo00<0003oooooool00P0000<co`00
0`000?ooooooo`0Woooo00?o09Woooooool0D?ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0
003oooooool09oooo`03o`2Ioooooooo053oool009ooool01@0003?o03?o03?o0000000Yoooo00?o
09Woooooool0D?ooo`00X?ooo`040000<ol0<ol00000:Oooo`03o`2Ioooooooo053oool00:3oool0
0`0003?o03?o00020000:?ooo`03o`2Ioooooooo053oool00:3oool0100003?o03?o000002Woool0
0ol0VOooooooo`1@oooo002Poooo00@0000co`0co`00000Yoooo00?o09Woooooool0D?ooo`00X?oo
o`040000<ol0<ol00000:Oooo`03o`2Ioooooooo053oool00:3oool0100003?o03?o000002Woool0
0ol0VOooooooo`1@oooo002Poooo00@0000co`0co`00000Yoooo00?o09Woooooool0D?ooo`00X?oo
o`040000<ol0<ol00000:Oooo`03o`2Ioooooooo053oool00:7oool0100003?o0000000002Soool0
0ol0VOooooooo`1@oooo002Qoooo00<0000co`000000:Oooo`03o`2Ioooooooo053oool00:7oool0
0`0003?o0000000Yoooo00?o09Woooooool0D?ooo`00XOooo`030000<ol0000002Woool00ol0VOoo
ooooo`1@oooo002Qoooo00<0000co`000000:Oooo`03o`2Ioooooooo053oool00:7oool00`0003?o
0000000Yoooo00?o09Woooooool0D?ooo`00XOooo`040000<ol000000000:?ooo`03o`2Ioooooooo
053oool00:7oool00`0003?o0000000Yoooo00?o09Woooooool0D?ooo`00XOooo`030000<ol00000
02Woool00ol0VOooooooo`1@oooo002Qoooo00<0000co`000000:Oooo`03o`2Ioooooooo053oool0
0:7oool00`0003?o0000000Yoooo00?o09Woooooool0D?ooo`00XOooo`030000<ol0000002Woool0
0ol0VOooooooo`1@oooo002Qoooo00@0000co`000000000Xoooo00?o09Woooooool0D?ooo`00XOoo
o`030000<ol0000002Woool00ol0VOooooooo`1@oooo002Qoooo00<0000co`000000:Oooo`03o`2I
oooooooo053oool00:7oool00`0003?o0000000Yoooo00?o09Woooooool0D?ooo`00W?ooo`800003
oooo00<0000co`000000:Oooo`03o`2Ioooooooo053oool009_oool010000?ooooooo`0000;oool0
0`0003?o0000000Yoooo00?o09Woooooool0D?ooo`00WOooo`060000oooooooooooo0000<ol00`00
02Ooool00ol0VOooooooo`1@oooo002Noooo00H0003oooooool0000co`00000Yoooo00?o09Wooooo
ool0D?ooo`00Voooo`040000oooooooo00000_ooo`030000<ol0000002Woool00ol0VOooooooo`1@
oooo002Loooo0P0000Coool20000:Oooo`03o`2Ioooooooo053oool00:;oool20000:Oooo`03o`2I
oooooooo053oool00:;oool20000:Oooo`03o`2Ioooooooo053oool00:;oool20000:Oooo`03o`2I
oooooooo053oool00:;oool30000:?ooo`03o`2Ioooooooo053oool00:;oool20000:Oooo`03o`2I
oooooooo053oool00:;oool20000:Oooo`03o`2Ioooooooo053oool00:;oool20000:Oooo`03o`2I
oooooooo053oool00:;oool20000:Oooo`03o`2Ioooooooo053oool00:;oool20000:Oooo`03o`2I
oooooooo053oool00:;oool30000:?ooo`03o`2Ioooooooo053oool00:;oool20000:Oooo`03o`2I
oooooooo053oool00:;oool20000:Oooo`03o`2Ioooooooo053oool00:;oool20000:Oooo`03o`2I
oooooooo053oool00:;oool20000:Oooo`03o`2Ioooooooo053oool00:;oool20000:Oooo`03o`2I
oooooooo053oool00:;oool30000:?ooo`03o`2Ioooooooo053oool00:?oool00`000?ooooooo`0W
oooo00?o09Woooooool0D?ooo`00Xoooo`030000oooooooo02Ooool00ol0VOooooooo`1@oooo002S
oooo00<0003oooooool09oooo`03o`2Ioooooooo053oool00:?oool00`000?ooooooo`0Woooo00?o
09Woooooool0D?ooo`00Xoooo`030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Soooo0P00
02Soool00ol0VOooooooo`1@oooo002Soooo00<0003oooooool09oooo`03o`2Ioooooooo053oool0
0:?oool00`000?ooooooo`0Woooo00?o09Woooooool0D?ooo`00Xoooo`030000oooooooo02Ooool0
0ol0VOooooooo`1@oooo002Soooo00<0003oooooool09oooo`03o`2Ioooooooo053oool009goool3
00000oooo`030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Noooo00<0003oooooool00_oo
o`030000oooooooo02Ooool00ol0VOooooooo`1@oooo002Koooo1@0000?oool300009oooo`03o`2I
oooooooo053oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002M
oooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?oo
ooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1k
oooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P00
00?oool500000_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`09oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000
oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000>oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000004Oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003ooooo
ool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75071 .12361 L
.75216 .12361 L
.75287 .12361 L
.75351 .12361 L
s
.75351 .12361 m
.75398 .61803 L
s
0 .4 1 r
.02381 .12351 m
.04262 .12348 L
.06244 .12342 L
.07286 .12338 L
.08255 .12334 L
.09388 .12328 L
.10458 .12321 L
.125 .12303 L
.14357 .12281 L
.16355 .12247 L
.18199 .12203 L
.20071 .1214 L
.21136 .12094 L
.22134 .12042 L
.24158 .11904 L
.26011 .11726 L
.27909 .1147 L
.28984 .11282 L
.29982 .11072 L
.32034 .10503 L
.33895 .09773 L
.35819 .08714 L
.36904 .07936 L
.37901 .07075 L
.38887 .0606 L
.3943 .0542 L
.39944 .04754 L
.40175 .04434 L
.40302 .04252 L
.40421 .04078 L
.4055 .04001 L
.40618 .04006 L
.40691 .04011 L
.40941 .04029 L
.4185 .04099 L
.43831 .04296 L
.45647 .04545 L
.4754 .04897 L
.4961 .05427 L
.51571 .06113 L
.53666 .07103 L
.558 .0847 L
.57816 .10215 L
.58788 .11316 L
.59044 .11657 L
.5932 .12051 L
.59383 .12146 L
.59453 .12251 L
.59579 .12361 L
.59703 .12361 L
Mistroke
.59817 .12361 L
.60696 .12361 L
.61662 .12361 L
.6558 .12361 L
.69744 .12361 L
.73756 .12361 L
.77616 .12361 L
.81722 .12361 L
.85676 .12361 L
.89478 .12361 L
.93526 .12361 L
.97422 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00Moooo`H0I_lVoooo00<0003oooooool0N_ooo`00M_ooo`0306Kooooooooo
00Coool506Ko8Oooo`030000oooooooo07[oool007Goool00`1Vooooooooo`0:oooo2@1VoaSoool0
0`000?ooooooo`1joooo001doooo00<0I_ooooooool05?ooo`80I_lFoooo0P0007_oool007Coool0
0`1Vooooooooo`0Foooo0`1Voa?oool00`000?ooooooo`1joooo001coooo00<0I_ooooooool06_oo
o`80I_lAoooo00<0003oooooool0N_ooo`00L_ooo`0306Kooooooooo01goool306Ko3_ooo`030000
oooooooo07[oool0077oool00`1Vooooooooo`0Qoooo0P1Vo`coool00`000?ooooooo`1joooo001`
oooo00<0I_ooooooool09?ooo`80I_l:oooo00<0003oooooool0N_ooo`00Koooo`0306Kooooooooo
02Ooool206Ko2?ooo`80001koooo000[oooo0`0002Soool300005Oooo`0306Kooooooooo00_oool4
00006oooo`0306Kooooooooo00Goool00`000?ooooooo`0Soooo100002Ooool30000:Oooo`00:ooo
o`040000oooooooo0000:?ooo`030000oooooooo01;oool206Ko3_ooo`030000oooooooo01goool2
06Ko1Oooo`030000oooooooo02?oool00`000?ooooooo`0Yoooo00<0003oooooool0:?ooo`00:ooo
o`040000oooooooo00009Oooo`D0000Boooo00<0I_ooooooool03oooo`030000oooooooo01koool0
0`1Vooooooooo`02oooo00<0003oooooool09?ooo`030000oooooooo02Goool50000:Oooo`009Ooo
o`@00002oooo0`00023oool400000_ooo`040000oooooooo00004Oooo`80I_l;oooo100000Coool0
0`000?ooooooo`0Noooo00D0I_ooooooooooool000009oooo`030000oooooooo02Coool010000?oo
ooooo`0002[oool002coool00`000?ooooooo`0Voooo00<0003oool000003oooo`80I_lCoooo00@0
003oooooool0000Poooo0P1Vo`03oooo0000oooo02Coool010000?ooooooo`0002Koool00`000?oo
o`00000Zoooo000/oooo0`0002Ooool200003Oooo`80I_lFoooo0P0002?oool00`1Vo`000000000U
oooo0P0002Soool20000:_ooo`00Hoooo`80I_lnoooo00<0003oooooool0N_ooo`00Goooo`@0I_m0
oooo00<00000I_ooool0N_ooo`00G?ooo`<0I_m4oooo00<00000I_ooool0N_ooo`00EOooo`L0I_m7
oooo00<0003oool0I_l0N_ooo`00Boooo`X0I_m>oooo00@0003oooooool0I_mioooo000@ooooo`00
017oool001Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`00000@000000<co`00000c
o`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`050000ooooooooooooo`2I
00Goool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0V
oooo00<0003oooooool09Oooo`030000oooooooo00Koool400006c?o00030000oooooooo02Goool0
1@000?ooooooooooool0V@0Toooo00<0003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo04koool008coool00`0003?o03?o000D<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo04koool008goool2000053?o00030000oooooooo02Woool00ol0VOooooooo`1>
oooo002?oooo00<0000co`0co`004C?o00030000oooooooo02Woool00ol0VOooooooo`1>oooo002@
oooo00<0000co`0co`0043?o0080000Zoooo00?o09Woooooool0C_ooo`00TOooo`80000@<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo04koool009?oool00`0003?o03?o000=<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo04koool009?oool00`0003?o03?o000=<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo04koool009Coool00`0003?o03?o000<<ol000<0003oooooool0:Oooo`03o`2I
oooooooo04koool009Coool00`0003?o03?o000<<ol000<0003oooooool0:Oooo`03o`2Ioooooooo
04koool009Goool00`0003?o03?o000;<ol00P0002[oool00ol0VOooooooo`1>oooo002Eoooo00<0
000co`0co`002c?o00030000oooooooo02Woool00ol0VOooooooo`1>oooo002Foooo00<0000co`0c
o`002S?o00030000oooooooo02Woool00ol0VOooooooo`1>oooo002Foooo00<0000co`0co`002S?o
00030000oooooooo02Woool00ol0VOooooooo`1>oooo002Goooo00<0000co`0co`002C?o00030000
oooooooo02Woool00ol0VOooooooo`1>oooo002Goooo00<0000co`0co`002C?o00030000oooooooo
02Woool00ol0VOooooooo`1>oooo002Hoooo00<0000co`0co`0023?o0080000Zoooo00?o09Wooooo
ool0C_ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0Yoooo00?o09Woooooool0C_oo
o`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00VOoo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00VOooo`030000
<ol0<ol000Lco`000`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00VOooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00VOooo`030000<ol0<ol000Lco`02
0000:_ooo`03o`2Ioooooooo04koool009[oool00`0003?o03?o0006<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo04koool009[oool00`0003?o03?o0006<ol000<0003oooooool0:Oooo`03o`2I
oooooooo04koool009[oool00`0003?o03?o0006<ol000<0003oooooool0:Oooo`03o`2Ioooooooo
04koool009[oool00`0003?o03?o0006<ol000<0003oooooool0:Oooo`03o`2Ioooooooo04koool0
09_oool500000c?o00030000oooooooo02Woool00ol0VOooooooo`1>oooo002Koooo00<0000co`00
00001C?o00030000oooooooo02Woool00ol0VOooooooo`1>oooo002Koooo00<0000co`0000001C?o
00<0000Yoooo00?o09Woooooool0C_ooo`00W?ooo`800005<ol000<0003oooooool0:Oooo`03o`2I
oooooooo04koool009coool200001C?o00030000oooooooo02Woool00ol0VOooooooo`1>oooo002L
oooo0P0000Dco`000`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00W?ooo`030000<ol0<ol0
00@co`000`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00W?ooo`030000<ol0<ol000@co`00
0`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00W?ooo`030000<ol0<ol000@co`020000:_oo
o`03o`2Ioooooooo04koool009goool00`0003?o03?o0003<ol000<0003oooooool0:Oooo`03o`2I
oooooooo04koool009goool00`0003?o03?o0003<ol000<0003oooooool0:Oooo`03o`2Ioooooooo
04koool009goool00`0003?o03?o0003<ol000<0003oooooool0:Oooo`03o`2Ioooooooo04koool0
09goool00`0003?o03?o0003<ol000<0003oooooool0:Oooo`03o`2Ioooooooo04koool009goool0
0`0003?o03?o0003<ol000<0003oooooool0:Oooo`03o`2Ioooooooo04koool009goool00`0003?o
03?o0003<ol00P0002[oool00ol0VOooooooo`1>oooo002Moooo00<0000co`0co`000c?o00030000
oooooooo02Woool00ol0VOooooooo`1>oooo002Moooo00<0000co`0co`000c?o00030000oooooooo
02Woool00ol0VOooooooo`1>oooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Woool0
0ol0VOooooooo`1>oooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Woool00ol0VOoo
ooooo`1>oooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Woool00ol0VOooooooo`1>
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo02Woool00ol0VOooooooo`1>oooo002N
oooo00<0000co`0co`000S?o0080000Zoooo00?o09Woooooool0C_ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0Yoooo00?o09Woooooool0C_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Y
oooo00?o09Woooooool0C_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0Yoooo00?o
09Woooooool0C_ooo`00W_ooo`030000<ol0<ol0008co`020000:_ooo`03o`2Ioooooooo04koool0
09ooool01@0003?o03?o03?o0000000[oooo00?o09Woooooool0C_ooo`00Woooo`050000<ol0<ol0
<ol0000002_oool00ol0VOooooooo`1>oooo002Ooooo00D0000co`0co`0co`000000:oooo`03o`2I
oooooooo04koool009_oool500000c?o00030000oooooooo02Woool00ol0VOooooooo`1>oooo002K
oooo00D0003oooooooooool000000c?o00030000oooooooo02Woool00ol0VOooooooo`1>oooo002L
oooo00@0003oooooool00003<ol00`0002Woool00ol0VOooooooo`1>oooo002Moooo00<0003oool0
00000c?o00030000oooooooo02Woool00ol0VOooooooo`1>oooo002Koooo00<0003oooooool00P00
00<co`000`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00W?ooo`8000000oooo`0003?o0002
<ol000<0003oooooool0:Oooo`03o`2Ioooooooo04koool009ooool01@0003?o03?o03?o0000000[
oooo00?o09Woooooool0C_ooo`00X?ooo`040000<ol0<ol00000:oooo`03o`2Ioooooooo04koool0
0:3oool00`0003?o03?o00020000:_ooo`03o`2Ioooooooo04koool00:3oool0100003?o03?o0000
02_oool00ol0VOooooooo`1>oooo002Poooo00@0000co`0co`00000[oooo00?o09Woooooool0C_oo
o`00X?ooo`040000<ol0<ol00000:oooo`03o`2Ioooooooo04koool00:3oool0100003?o03?o0000
02_oool00ol0VOooooooo`1>oooo002Poooo00@0000co`0co`00000[oooo00?o09Woooooool0C_oo
o`00X?ooo`040000<ol0<ol00000:oooo`03o`2Ioooooooo04koool00:7oool0100003?o00000000
02[oool00ol0VOooooooo`1>oooo002Qoooo00<0000co`000000:oooo`03o`2Ioooooooo04koool0
0:7oool00`0003?o0000000[oooo00?o09Woooooool0C_ooo`00XOooo`030000<ol0000002_oool0
0ol0VOooooooo`1>oooo002Qoooo00<0000co`000000:oooo`03o`2Ioooooooo04koool00:7oool0
0`0003?o0000000[oooo00?o09Woooooool0C_ooo`00XOooo`040000<ol000000000:_ooo`03o`2I
oooooooo04koool00:7oool00`0003?o0000000[oooo00?o09Woooooool0C_ooo`00XOooo`030000
<ol0000002_oool00ol0VOooooooo`1>oooo002Qoooo00<0000co`000000:oooo`03o`2Ioooooooo
04koool00:7oool00`0003?o0000000[oooo00?o09Woooooool0C_ooo`00XOooo`030000<ol00000
02_oool00ol0VOooooooo`1>oooo002Qoooo00@0000co`000000000Zoooo00?o09Woooooool0C_oo
o`00XOooo`030000<ol0000002_oool00ol0VOooooooo`1>oooo002Qoooo00<0000co`000000:ooo
o`03o`2Ioooooooo04koool00:7oool00`0003?o0000000[oooo00?o09Woooooool0C_ooo`00W?oo
o`800003oooo00<0000co`000000:oooo`03o`2Ioooooooo04koool009_oool010000?ooooooo`00
00;oool00`0003?o0000000[oooo00?o09Woooooool0C_ooo`00WOooo`060000oooooooooooo0000
<ol00`0002Woool00ol0VOooooooo`1>oooo002Noooo00H0003oooooool0000co`00000[oooo00?o
09Woooooool0C_ooo`00Voooo`040000oooooooo00000_ooo`030000<ol0000002_oool00ol0VOoo
ooooo`1>oooo002Loooo0P0000Coool20000:oooo`03o`2Ioooooooo04koool00:;oool20000:ooo
o`03o`2Ioooooooo04koool00:;oool20000:oooo`03o`2Ioooooooo04koool00:;oool20000:ooo
o`03o`2Ioooooooo04koool00:;oool30000:_ooo`03o`2Ioooooooo04koool00:;oool20000:ooo
o`03o`2Ioooooooo04koool00:;oool20000:oooo`03o`2Ioooooooo04koool00:;oool20000:ooo
o`03o`2Ioooooooo04koool00:;oool20000:oooo`03o`2Ioooooooo04koool00:;oool20000:ooo
o`03o`2Ioooooooo04koool00:;oool30000:_ooo`03o`2Ioooooooo04koool00:;oool20000:ooo
o`03o`2Ioooooooo04koool00:;oool20000:oooo`03o`2Ioooooooo04koool00:;oool20000:ooo
o`03o`2Ioooooooo04koool00:;oool20000:oooo`03o`2Ioooooooo04koool00:;oool20000:ooo
o`03o`2Ioooooooo04koool00:;oool30000:_ooo`03o`2Ioooooooo04koool00:?oool00`000?oo
ooooo`0Yoooo00?o09Woooooool0C_ooo`00Xoooo`030000oooooooo02Woool00ol0VOooooooo`1>
oooo002Soooo00<0003oooooool0:Oooo`03o`2Ioooooooo04koool00:?oool00`000?ooooooo`0Y
oooo00?o09Woooooool0C_ooo`00Xoooo`030000oooooooo02Woool00ol0VOooooooo`1>oooo002S
oooo0P0002[oool00ol0VOooooooo`1>oooo002Soooo00<0003oooooool0:Oooo`03o`2Ioooooooo
04koool00:?oool00`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00Xoooo`030000oooooooo
02Woool00ol0VOooooooo`1>oooo002Soooo00<0003oooooool0:Oooo`03o`2Ioooooooo04koool0
09goool300000oooo`030000oooooooo02Woool00ol0VOooooooo`1>oooo002Noooo00<0003ooooo
ool00_ooo`030000oooooooo02Woool00ol0VOooooooo`1>oooo002Koooo1@0000?oool30000:Ooo
o`03o`2Ioooooooo04koool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021
oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
oooo0P0000?oool400000oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01?ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03ooo
o`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0N_ooo`00Noooo`030000
oooooooo00D0000>oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool0
0`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75315 .12361 L
.75593 .12361 L
.75853 .12361 L
.7597 .12361 L
.76081 .12361 L
s
.76081 .12361 m
.76132 .61803 L
s
0 .4 1 r
.02381 .1235 m
.04262 .12345 L
.06244 .12339 L
.07286 .12334 L
.08255 .12329 L
.09388 .12323 L
.10458 .12315 L
.125 .12294 L
.14357 .12268 L
.16355 .12229 L
.18199 .12177 L
.20071 .12105 L
.21136 .12051 L
.22134 .11991 L
.24158 .1183 L
.26011 .11623 L
.27909 .11326 L
.28984 .11107 L
.29982 .10864 L
.32034 .10203 L
.33895 .09354 L
.35819 .08124 L
.36904 .07221 L
.37901 .0622 L
.3881 .05141 L
.3931 .04468 L
.39429 .04298 L
.39556 .04114 L
.39664 .03953 L
.39784 .03931 L
.3985 .03935 L
.39922 .03939 L
.40052 .03946 L
.40343 .03963 L
.40853 .03995 L
.4185 .04067 L
.43854 .04253 L
.45964 .04529 L
.47938 .0489 L
.49775 .05344 L
.51821 .06022 L
.5368 .06835 L
.55598 .07918 L
.57678 .09407 L
.59626 .11374 L
.599 .11744 L
.6016 .1212 L
.6023 .12225 L
.60303 .12339 L
.60385 .12361 L
Mistroke
.6046 .12361 L
.60734 .12361 L
.6177 .12361 L
.6571 .12361 L
.69873 .12361 L
.73885 .12361 L
.77746 .12361 L
.81851 .12361 L
.85805 .12361 L
.89607 .12361 L
.93655 .12361 L
.97551 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00M?ooo`T0I_lVoooo00<0003oooooool0N_ooo`00M?ooo`0306Kooooooooo
00Koool506Ko8Oooo`030000oooooooo07[oool007?oool00`1Vooooooooo`0<oooo2@1VoaSoool0
0`000?ooooooo`1joooo001coooo00<0I_ooooooool05Oooo`80I_lFoooo0P0007_oool007;oool0
0`1Vooooooooo`0Hoooo101Voa;oool00`000?ooooooo`1joooo001aoooo00<0I_ooooooool07Ooo
o`@0I_l>oooo00<0003oooooool0N_ooo`00L?ooo`0306Kooooooooo02;oool206Ko3?ooo`030000
oooooooo07[oool006ooool00`1Vooooooooo`0Uoooo0P1Vo`[oool00`000?ooooooo`1joooo001^
oooo00<0I_ooooooool0:?ooo`80I_l8oooo00<0003oooooool0N_ooo`00KOooo`0306Kooooooooo
02_oool206Ko1_ooo`80001koooo000[oooo0`0002Soool300004oooo`0306Kooooooooo00goool4
00007Oooo`0306Kooooooooo00?oool00`000?ooooooo`0Soooo100002Ooool30000:Oooo`00:ooo
o`040000oooooooo0000:?ooo`030000oooooooo017oool00`1Vooooooooo`0>oooo00<0003ooooo
ool07oooo`0306Kooooooooo00;oool00`000?ooooooo`0Soooo00<0003oooooool0:Oooo`030000
oooooooo02Soool002_oool010000?ooooooo`0002Goool500004?ooo`80I_lBoooo00<0003ooooo
ool07oooo`80I_l2oooo00<0003oooooool09?ooo`030000oooooooo02Goool50000:Oooo`009Ooo
o`@00002oooo0`00023oool400000_ooo`040000oooooooo00003oooo`80I_l=oooo100000Coool0
0`000?ooooooo`0Poooo00<0I_ooool000009oooo`030000oooooooo02Coool010000?ooooooo`00
02[oool002coool00`000?ooooooo`0Voooo00<0003oool000003Oooo`80I_lEoooo00@0003ooooo
ool0000Roooo00<0I_l0003oool09?ooo`040000oooooooo00009_ooo`030000oooo000002[oool0
02coool300009oooo`80000;oooo0P1VoaSoool200009?ooo`80000Uoooo0P0002Soool20000:_oo
o`00H?ooo`<0I_m0oooo00<00000I_ooool0N_ooo`00G_ooo`80I_m3oooo00<0003oool0I_l0N_oo
o`00FOooo`D0I_m5oooo00@0003oooooool0I_mioooo001Eoooo101Vod[oool01@000?oooooooooo
o`1Vo`1hoooo0018oooo3@1Vodkoool00`000?ooooooo`02oooo00<0I_ooooooool0MOooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oool0000040000003<ol0
0000<ol000Pco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`03
oooo00Go09Woooooooooool000002Oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Zoooo00<0003ooooo
ool09_ooo`030000oooooooo02Goool00`000?ooooooo`06oooo100001/co`000`000?ooooooo`0U
oooo00<0003oooooool00oooo`03o`2Ioooooooo023oool00`000?ooooooo`0Yoooo0028oooo1000
01Lco`000`000?ooooooo`0[oooo00?o09Woooooool0C?ooo`00S?ooo`030000<ol0<ol001@co`00
0`000?ooooooo`0[oooo00?o09Woooooool0C?ooo`00SOooo`80000D<ol000<0003oooooool0:ooo
o`03o`2Ioooooooo04coool008ooool00`0003?o03?o000A<ol000<0003oooooool0:oooo`03o`2I
oooooooo04coool0093oool00`0003?o03?o000@<ol00P0002coool00ol0VOooooooo`1<oooo002A
oooo0P00010co`000`000?ooooooo`0[oooo00?o09Woooooool0C?ooo`00Toooo`030000<ol0<ol0
00dco`000`000?ooooooo`0[oooo00?o09Woooooool0C?ooo`00Toooo`030000<ol0<ol000dco`00
0`000?ooooooo`0[oooo00?o09Woooooool0C?ooo`00U?ooo`030000<ol0<ol000`co`000`000?oo
ooooo`0[oooo00?o09Woooooool0C?ooo`00U?ooo`030000<ol0<ol000`co`000`000?ooooooo`0[
oooo00?o09Woooooool0C?ooo`00UOooo`030000<ol0<ol000/co`020000;?ooo`03o`2Ioooooooo
04coool009Goool00`0003?o03?o000;<ol000<0003oooooool0:oooo`03o`2Ioooooooo04coool0
09Koool00`0003?o03?o000:<ol000<0003oooooool0:oooo`03o`2Ioooooooo04coool009Koool0
0`0003?o03?o000:<ol000<0003oooooool0:oooo`03o`2Ioooooooo04coool009Ooool00`0003?o
03?o0009<ol000<0003oooooool0:oooo`03o`2Ioooooooo04coool009Ooool00`0003?o03?o0009
<ol000<0003oooooool0:oooo`03o`2Ioooooooo04coool009Soool00`0003?o03?o0008<ol00P00
02coool00ol0VOooooooo`1<oooo002Hoooo00<0000co`0co`0023?o00030000oooooooo02_oool0
0ol0VOooooooo`1<oooo002Hoooo00<0000co`0co`0023?o00030000oooooooo02_oool00ol0VOoo
ooooo`1<oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo02_oool00ol0VOooooooo`1<
oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002I
oooo00<0000co`0co`001c?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002Ioooo00<0
000co`0co`001c?o0080000/oooo00?o09Woooooool0C?ooo`00V_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0[oooo00?o09Woooooool0C?ooo`00V_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0[oooo00?o09Woooooool0C?ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`0[
oooo00?o09Woooooool0C?ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`0[oooo00?o
09Woooooool0C?ooo`00Voooo`D00003<ol000<0003oooooool0:oooo`03o`2Ioooooooo04coool0
09_oool00`0003?o00000005<ol000<0003oooooool0:oooo`03o`2Ioooooooo04coool009_oool0
0`0003?o00000005<ol00`0002_oool00ol0VOooooooo`1<oooo002Loooo0P0000Dco`000`000?oo
ooooo`0[oooo00?o09Woooooool0C?ooo`00W?ooo`800005<ol000<0003oooooool0:oooo`03o`2I
oooooooo04coool009coool200001C?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002L
oooo00<0000co`0co`0013?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002Loooo00<0
000co`0co`0013?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002Loooo00<0000co`0c
o`0013?o0080000/oooo00?o09Woooooool0C?ooo`00WOooo`030000<ol0<ol000<co`000`000?oo
ooooo`0[oooo00?o09Woooooool0C?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0[
oooo00?o09Woooooool0C?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0[oooo00?o
09Woooooool0C?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0[oooo00?o09Wooooo
ool0C?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0[oooo00?o09Woooooool0C?oo
o`00WOooo`030000<ol0<ol000<co`020000;?ooo`03o`2Ioooooooo04coool009goool00`0003?o
03?o0003<ol000<0003oooooool0:oooo`03o`2Ioooooooo04coool009goool00`0003?o03?o0003
<ol000<0003oooooool0:oooo`03o`2Ioooooooo04coool009koool00`0003?o03?o0002<ol000<0
003oooooool0:oooo`03o`2Ioooooooo04coool009koool00`0003?o03?o0002<ol000<0003ooooo
ool0:oooo`03o`2Ioooooooo04coool009koool00`0003?o03?o0002<ol000<0003oooooool0:ooo
o`03o`2Ioooooooo04coool009koool00`0003?o03?o0002<ol000<0003oooooool0:oooo`03o`2I
oooooooo04coool009koool00`0003?o03?o0002<ol00P0002coool00ol0VOooooooo`1<oooo002N
oooo00<0000co`0co`000S?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002Noooo00<0
000co`0co`000S?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002Noooo00<0000co`0co`000S?o
00030000oooooooo02_oool00ol0VOooooooo`1<oooo002Noooo00<0000co`0co`000S?o00030000
oooooooo02_oool00ol0VOooooooo`1<oooo002Noooo00<0000co`0co`000S?o0080000/oooo00?o
09Woooooool0C?ooo`00Woooo`050000<ol0<ol0<ol0000002goool00ol0VOooooooo`1<oooo002O
oooo00D0000co`0co`0co`000000;Oooo`03o`2Ioooooooo04coool009ooool01@0003?o03?o03?o
0000000]oooo00?o09Woooooool0C?ooo`00Voooo`D00003<ol000<0003oooooool0:oooo`03o`2I
oooooooo04coool009_oool01@000?ooooooooooo`000003<ol000<0003oooooool0:oooo`03o`2I
oooooooo04coool009coool010000?ooooooo`0000<co`030000:oooo`03o`2Ioooooooo04coool0
09goool00`000?ooo`000003<ol000<0003oooooool0:oooo`03o`2Ioooooooo04coool009_oool0
0`000?ooooooo`0200000c?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002Loooo0P00
0003oooo0000<ol0008co`000`000?ooooooo`0[oooo00?o09Woooooool0C?ooo`00Woooo`050000
<ol0<ol0<ol0000002goool00ol0VOooooooo`1<oooo002Poooo00@0000co`0co`00000]oooo00?o
09Woooooool0C?ooo`00X?ooo`030000<ol0<ol00080000/oooo00?o09Woooooool0C?ooo`00X?oo
o`040000<ol0<ol00000;Oooo`03o`2Ioooooooo04coool00:3oool0100003?o03?o000002goool0
0ol0VOooooooo`1<oooo002Poooo00@0000co`0co`00000]oooo00?o09Woooooool0C?ooo`00X?oo
o`040000<ol0<ol00000;Oooo`03o`2Ioooooooo04coool00:3oool0100003?o03?o000002goool0
0ol0VOooooooo`1<oooo002Poooo00@0000co`0co`00000]oooo00?o09Woooooool0C?ooo`00XOoo
o`040000<ol000000000;?ooo`03o`2Ioooooooo04coool00:7oool00`0003?o0000000]oooo00?o
09Woooooool0C?ooo`00XOooo`030000<ol0000002goool00ol0VOooooooo`1<oooo002Qoooo00<0
000co`000000;Oooo`03o`2Ioooooooo04coool00:7oool00`0003?o0000000]oooo00?o09Wooooo
ool0C?ooo`00XOooo`030000<ol0000002goool00ol0VOooooooo`1<oooo002Qoooo00@0000co`00
0000000/oooo00?o09Woooooool0C?ooo`00XOooo`030000<ol0000002goool00ol0VOooooooo`1<
oooo002Qoooo00<0000co`000000;Oooo`03o`2Ioooooooo04coool00:7oool00`0003?o0000000]
oooo00?o09Woooooool0C?ooo`00XOooo`030000<ol0000002goool00ol0VOooooooo`1<oooo002Q
oooo00<0000co`000000;Oooo`03o`2Ioooooooo04coool00:7oool0100003?o0000000002coool0
0ol0VOooooooo`1<oooo002Qoooo00<0000co`000000;Oooo`03o`2Ioooooooo04coool00:7oool0
0`0003?o0000000]oooo00?o09Woooooool0C?ooo`00XOooo`030000<ol0000002goool00ol0VOoo
ooooo`1<oooo002Loooo0P0000?oool00`0003?o0000000]oooo00?o09Woooooool0C?ooo`00Vooo
o`040000oooooooo00000_ooo`030000<ol0000002goool00ol0VOooooooo`1<oooo002Moooo00H0
003oooooooooool0000co`030000:oooo`03o`2Ioooooooo04coool009koool01P000?ooooooo`00
03?o000002goool00ol0VOooooooo`1<oooo002Koooo00@0003oooooool00002oooo00<0000co`00
0000;Oooo`03o`2Ioooooooo04coool009coool200001?ooo`80000]oooo00?o09Woooooool0C?oo
o`00X_ooo`80000]oooo00?o09Woooooool0C?ooo`00X_ooo`80000]oooo00?o09Woooooool0C?oo
o`00X_ooo`80000]oooo00?o09Woooooool0C?ooo`00X_ooo`<0000/oooo00?o09Woooooool0C?oo
o`00X_ooo`80000]oooo00?o09Woooooool0C?ooo`00X_ooo`80000]oooo00?o09Woooooool0C?oo
o`00X_ooo`80000]oooo00?o09Woooooool0C?ooo`00X_ooo`80000]oooo00?o09Woooooool0C?oo
o`00X_ooo`80000]oooo00?o09Woooooool0C?ooo`00X_ooo`<0000/oooo00?o09Woooooool0C?oo
o`00X_ooo`80000]oooo00?o09Woooooool0C?ooo`00X_ooo`80000]oooo00?o09Woooooool0C?oo
o`00X_ooo`80000]oooo00?o09Woooooool0C?ooo`00X_ooo`80000]oooo00?o09Woooooool0C?oo
o`00X_ooo`80000]oooo00?o09Woooooool0C?ooo`00X_ooo`<0000/oooo00?o09Woooooool0C?oo
o`00Xoooo`030000oooooooo02_oool00ol0VOooooooo`1<oooo002Soooo00<0003oooooool0:ooo
o`03o`2Ioooooooo04coool00:?oool00`000?ooooooo`0[oooo00?o09Woooooool0C?ooo`00Xooo
o`030000oooooooo02_oool00ol0VOooooooo`1<oooo002Soooo00<0003oooooool0:oooo`03o`2I
oooooooo04coool00:?oool20000;?ooo`03o`2Ioooooooo04coool00:?oool00`000?ooooooo`0[
oooo00?o09Woooooool0C?ooo`00Xoooo`030000oooooooo02_oool00ol0VOooooooo`1<oooo002S
oooo00<0003oooooool0:oooo`03o`2Ioooooooo04coool00:?oool00`000?ooooooo`0[oooo00?o
09Woooooool0C?ooo`00WOooo`<00003oooo00<0003oooooool0:oooo`03o`2Ioooooooo04coool0
09koool00`000?ooooooo`02oooo00<0003oooooool0:oooo`03o`2Ioooooooo04coool009_oool5
00000oooo`<0000[oooo00?o09Woooooool0C?ooo`00Voooo`040000oooooooo0000POooo`00W?oo
o`030000oooo0000087oool009goool20000POooo`00ooooob7oool00?oooolQoooo001loooo00<0
003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003ooooo
ool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo1@0000;oool200001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo
00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_oo
o`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool01@000?oooooooooo
o`00001moooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P00
00?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75853 .12361 L
.76334 .12361 L
.76596 .12361 L
.76725 .12361 L
.76842 .12361 L
.76949 .12361 L
s
.76949 .12361 m
.7699 .61803 L
s
0 .4 1 r
.02381 .12348 m
.04262 .12343 L
.06244 .12335 L
.07286 .1233 L
.08255 .12325 L
.09388 .12316 L
.10458 .12307 L
.125 .12284 L
.14357 .12253 L
.16355 .12208 L
.18199 .12148 L
.20071 .12064 L
.21136 .12002 L
.22134 .11932 L
.24158 .11746 L
.26011 .11505 L
.27909 .11161 L
.28984 .10908 L
.29982 .10625 L
.32034 .09859 L
.33895 .08875 L
.35819 .07449 L
.36904 .06402 L
.37901 .05242 L
.38371 .0462 L
.3863 .04255 L
.38757 .04069 L
.38875 .03893 L
.38985 .03877 L
.39103 .03882 L
.3935 .03894 L
.39784 .03915 L
.4185 .04044 L
.43797 .04214 L
.45625 .04433 L
.47643 .04764 L
.49494 .05175 L
.51386 .05732 L
.53456 .06537 L
.55417 .07524 L
.57512 .08781 L
.59647 .10465 L
.60626 .1165 L
.60864 .11987 L
.60995 .12182 L
.61119 .12361 L
.6119 .12361 L
.61266 .12361 L
.614 .12361 L
.61662 .12361 L
Mistroke
.63664 .12361 L
.65509 .12361 L
.69579 .12361 L
.73497 .12361 L
.7766 .12361 L
.81672 .12361 L
.85532 .12361 L
.89638 .12361 L
.93592 .12361 L
.97394 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00L_ooo`/0I_lVoooo00<0003oooooool0N_ooo`00L_ooo`0306Kooooooooo
00Soool:06Ko7?ooo`030000oooooooo07[oool0077oool00`1Vooooooooo`0Coooo1@1VoaOoool0
0`000?ooooooo`1joooo001`oooo00<0I_ooooooool06Oooo`<0I_lDoooo0P0007_oool006ooool0
0`1Vooooooooo`0Moooo0P1Voa;oool00`000?ooooooo`1joooo001_oooo00<0I_ooooooool07ooo
o`<0I_l?oooo00<0003oooooool0N_ooo`00K_ooo`0306Kooooooooo02?oool306Ko3?ooo`030000
oooooooo07[oool006goool00`1Vooooooooo`0Woooo0`1Vo`Woool00`000?ooooooo`1joooo001/
oooo00<0I_ooooooool0:oooo`80I_l7oooo00<0003oooooool0N_ooo`00Joooo`0306Kooooooooo
02koool206Ko1Oooo`80001koooo000[oooo0`0002Soool300004Oooo`0306Kooooooooo00ooool4
00007_ooo`80I_l3oooo00<0003oooooool08oooo`@0000Woooo0`0002Woool002_oool010000?oo
ooooo`0002Soool00`000?ooooooo`0>oooo0P1Voa;oool00`000?ooooooo`0Qoooo0P1Vo`03oooo
0000oooo02Coool00`000?ooooooo`0Yoooo00<0003oooooool0:?ooo`00:oooo`040000oooooooo
00009Oooo`D0000>oooo00<0I_ooooooool04oooo`030000oooooooo02;oool00`1Vo`000?ooo`0U
oooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo100000;oool300008?ooo`@00002oooo00@0
003oooooool0000=oooo0P1Vo`ooool400001?ooo`030000oooooooo02;oool00`000?ooooooo`0U
oooo00<0003oooooool09?ooo`040000oooooooo0000:_ooo`00;?ooo`030000oooooooo02Koool0
0`000?ooo`00000;oooo0P1VoaOoool010000?ooooooo`0002?oool00`00001Vooooo`0Soooo00@0
003oooooool0000Voooo00<0003oool00000:_ooo`00;?ooo`<0000Woooo0P0000Soool306Ko6_oo
o`80000Toooo0P00000306Kooooooooo02;oool20000:?ooo`80000Zoooo001Noooo0P1Vod?oool0
10000?ooooooo`1VogWoool005coool206KoAOooo`050000oooooooooooo06Ko07Soool005Goool7
06KoAoooo`030000oooooooo00;oool00`1Vooooooooo`1eoooo001@oooo1@1Vodkoool00`000?oo
ooooo`03oooo00<0I_ooooooool0M?ooo`00AOooo`/0I_mCoooo00<0003oooooool01?ooo`80I_md
oooo000@ooooo`00017oool001Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`00000@
000000<co`00000co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Goool00ol0VOooo`000009oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool002[oool00`000?oo
ooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo00Koool400006c?o00030000oooooooo
02Goool00`000?ooooooo`05oooo00?o09Woooooool07_ooo`030000oooooooo02Woool008Soool4
00005c?o00030000oooooooo02goool00ol0VOooooooo`1:oooo002<oooo00<0000co`0co`0053?o
00030000oooooooo02goool00ol0VOooooooo`1:oooo002=oooo0P0001@co`000`000?ooooooo`0]
oooo00?o09Woooooool0B_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0]oooo00?o
09Woooooool0B_ooo`00T?ooo`030000<ol0<ol0010co`020000;_ooo`03o`2Ioooooooo04[oool0
097oool2000043?o00030000oooooooo02goool00ol0VOooooooo`1:oooo002Coooo00<0000co`0c
o`003C?o00030000oooooooo02goool00ol0VOooooooo`1:oooo002Coooo00<0000co`0co`003C?o
00030000oooooooo02goool00ol0VOooooooo`1:oooo002Doooo00<0000co`0co`0033?o00030000
oooooooo02goool00ol0VOooooooo`1:oooo002Doooo00<0000co`0co`0033?o00030000oooooooo
02goool00ol0VOooooooo`1:oooo002Eoooo00<0000co`0co`002c?o0080000^oooo00?o09Wooooo
ool0B_ooo`00UOooo`030000<ol0<ol000/co`000`000?ooooooo`0]oooo00?o09Woooooool0B_oo
o`00U_ooo`030000<ol0<ol000Xco`000`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00U_oo
o`030000<ol0<ol000Xco`000`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00Uoooo`030000
<ol0<ol000Tco`000`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00Uoooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00V?ooo`030000<ol0<ol000Pco`02
0000;_ooo`03o`2Ioooooooo04[oool009Soool00`0003?o03?o0008<ol000<0003oooooool0;Ooo
o`03o`2Ioooooooo04[oool009Soool00`0003?o03?o0008<ol000<0003oooooool0;Oooo`03o`2I
oooooooo04[oool009Woool00`0003?o03?o0007<ol000<0003oooooool0;Oooo`03o`2Ioooooooo
04[oool009Woool00`0003?o03?o0007<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04[oool0
09Woool00`0003?o03?o0007<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04[oool009Woool0
0`0003?o03?o0007<ol00P0002koool00ol0VOooooooo`1:oooo002Joooo00<0000co`0co`001S?o
00030000oooooooo02goool00ol0VOooooooo`1:oooo002Joooo00<0000co`0co`001S?o00030000
oooooooo02goool00ol0VOooooooo`1:oooo002Joooo00<0000co`0co`001S?o00030000oooooooo
02goool00ol0VOooooooo`1:oooo002Joooo00<0000co`0co`001S?o00030000oooooooo02goool0
0ol0VOooooooo`1:oooo002Koooo1@0000<co`000`000?ooooooo`0]oooo00?o09Woooooool0B_oo
o`00Voooo`030000<ol0000000Dco`000`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00Vooo
o`030000<ol0000000Dco`030000;Oooo`03o`2Ioooooooo04[oool009coool200001C?o00030000
oooooooo02goool00ol0VOooooooo`1:oooo002Loooo0P0000Dco`000`000?ooooooo`0]oooo00?o
09Woooooool0B_ooo`00W?ooo`800005<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04[oool0
09coool00`0003?o03?o0004<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04[oool009coool0
0`0003?o03?o0004<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04[oool009coool00`0003?o
03?o0004<ol00P0002koool00ol0VOooooooo`1:oooo002Moooo00<0000co`0co`000c?o00030000
oooooooo02goool00ol0VOooooooo`1:oooo002Moooo00<0000co`0co`000c?o00030000oooooooo
02goool00ol0VOooooooo`1:oooo002Moooo00<0000co`0co`000c?o00030000oooooooo02goool0
0ol0VOooooooo`1:oooo002Moooo00<0000co`0co`000c?o00030000oooooooo02goool00ol0VOoo
ooooo`1:oooo002Moooo00<0000co`0co`000c?o00030000oooooooo02goool00ol0VOooooooo`1:
oooo002Moooo00<0000co`0co`000c?o0080000^oooo00?o09Woooooool0B_ooo`00WOooo`030000
<ol0<ol000<co`000`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00WOooo`030000<ol0<ol0
00<co`000`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0]oooo00?o09Woooooool0B_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0]
oooo00?o09Woooooool0B_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0]oooo00?o
09Woooooool0B_ooo`00W_ooo`030000<ol0<ol0008co`020000;_ooo`03o`2Ioooooooo04[oool0
09koool00`0003?o03?o0002<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04[oool009koool0
0`0003?o03?o0002<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04[oool009koool00`0003?o
03?o0002<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04[oool009koool00`0003?o03?o0002
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04[oool009koool00`0003?o03?o0002<ol000<0
003oooooool0;Oooo`03o`2Ioooooooo04[oool009koool00`0003?o03?o0002<ol00P0002koool0
0ol0VOooooooo`1:oooo002Ooooo00D0000co`0co`0co`000000;oooo`03o`2Ioooooooo04[oool0
09ooool01@0003?o03?o03?o0000000_oooo00?o09Woooooool0B_ooo`00Woooo`050000<ol0<ol0
<ol0000002ooool00ol0VOooooooo`1:oooo002Koooo1@0000<co`000`000?ooooooo`0]oooo00?o
09Woooooool0B_ooo`00Voooo`050000oooooooooooo000000<co`000`000?ooooooo`0]oooo00?o
09Woooooool0B_ooo`00W?ooo`040000oooooooo00000c?o00<0000]oooo00?o09Woooooool0B_oo
o`00WOooo`030000oooo000000<co`000`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00Vooo
o`030000oooooooo00800003<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04[oool009coool2
000000?oool0000co`000S?o00030000oooooooo02goool00ol0VOooooooo`1:oooo002Ooooo00D0
000co`0co`0co`000000;oooo`03o`2Ioooooooo04[oool00:3oool0100003?o03?o000002ooool0
0ol0VOooooooo`1:oooo002Poooo00<0000co`0co`000P0002koool00ol0VOooooooo`1:oooo002P
oooo00@0000co`0co`00000_oooo00?o09Woooooool0B_ooo`00X?ooo`040000<ol0<ol00000;ooo
o`03o`2Ioooooooo04[oool00:3oool0100003?o03?o000002ooool00ol0VOooooooo`1:oooo002P
oooo00@0000co`0co`00000_oooo00?o09Woooooool0B_ooo`00X?ooo`040000<ol0<ol00000;ooo
o`03o`2Ioooooooo04[oool00:3oool0100003?o03?o000002ooool00ol0VOooooooo`1:oooo002Q
oooo00@0000co`000000000^oooo00?o09Woooooool0B_ooo`00XOooo`030000<ol0000002ooool0
0ol0VOooooooo`1:oooo002Qoooo00<0000co`000000;oooo`03o`2Ioooooooo04[oool00:7oool0
0`0003?o0000000_oooo00?o09Woooooool0B_ooo`00XOooo`030000<ol0000002ooool00ol0VOoo
ooooo`1:oooo002Qoooo00<0000co`000000;oooo`03o`2Ioooooooo04[oool00:7oool0100003?o
0000000002koool00ol0VOooooooo`1:oooo002Qoooo00<0000co`000000;oooo`03o`2Ioooooooo
04[oool00:7oool00`0003?o0000000_oooo00?o09Woooooool0B_ooo`00XOooo`030000<ol00000
02ooool00ol0VOooooooo`1:oooo002Qoooo00<0000co`000000;oooo`03o`2Ioooooooo04[oool0
0:7oool00`0003?o0000000_oooo00?o09Woooooool0B_ooo`00XOooo`040000<ol000000000;_oo
o`03o`2Ioooooooo04[oool00:7oool00`0003?o0000000_oooo00?o09Woooooool0B_ooo`00XOoo
o`030000<ol0000002ooool00ol0VOooooooo`1:oooo002Qoooo00<0000co`000000;oooo`03o`2I
oooooooo04[oool009coool200000oooo`030000<ol0000002ooool00ol0VOooooooo`1:oooo002K
oooo00@0003oooooool00002oooo00<0000co`000000;oooo`03o`2Ioooooooo04[oool009goool0
1P000?ooooooooooo`0003?o00<0000]oooo00?o09Woooooool0B_ooo`00W_ooo`060000oooooooo
0000<ol00000;oooo`03o`2Ioooooooo04[oool009_oool010000?ooooooo`0000;oool00`0003?o
0000000_oooo00?o09Woooooool0B_ooo`00W?ooo`800004oooo0P0002ooool00ol0VOooooooo`1:
oooo002Roooo0P0002ooool00ol0VOooooooo`1:oooo002Roooo0P0002ooool00ol0VOooooooo`1:
oooo002Roooo0P0002ooool00ol0VOooooooo`1:oooo002Roooo0`0002koool00ol0VOooooooo`1:
oooo002Roooo0P0002ooool00ol0VOooooooo`1:oooo002Roooo0P0002ooool00ol0VOooooooo`1:
oooo002Roooo0P0002ooool00ol0VOooooooo`1:oooo002Roooo0P0002ooool00ol0VOooooooo`1:
oooo002Roooo0P0002ooool00ol0VOooooooo`1:oooo002Roooo0`0002koool00ol0VOooooooo`1:
oooo002Roooo0P0002ooool00ol0VOooooooo`1:oooo002Roooo0P0002ooool00ol0VOooooooo`1:
oooo002Roooo0P0002ooool00ol0VOooooooo`1:oooo002Roooo0P0002ooool00ol0VOooooooo`1:
oooo002Roooo0P0002ooool00ol0VOooooooo`1:oooo002Roooo0`0002koool00ol0VOooooooo`1:
oooo002Soooo00<0003oooooool0;Oooo`03o`2Ioooooooo04[oool00:?oool00`000?ooooooo`0]
oooo00?o09Woooooool0B_ooo`00Xoooo`030000oooooooo02goool00ol0VOooooooo`1:oooo002S
oooo00<0003oooooool0;Oooo`03o`2Ioooooooo04[oool00:?oool00`000?ooooooo`0]oooo00?o
09Woooooool0B_ooo`00Xoooo`80000^oooo00?o09Woooooool0B_ooo`00Xoooo`030000oooooooo
02goool00ol0VOooooooo`1:oooo002Soooo00<0003oooooool0;Oooo`03o`2Ioooooooo04[oool0
0:?oool00`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00Xoooo`030000oooooooo02goool0
0ol0VOooooooo`1:oooo002Moooo0`0000?oool00`000?ooooooo`0]oooo00?o09Woooooool0B_oo
o`00W_ooo`030000oooooooo00;oool00`000?ooooooo`0]oooo00?o09Woooooool0B_ooo`00Vooo
o`D00003oooo0`0002goool00ol0VOooooooo`1:oooo002Koooo00@0003oooooool00021oooo002L
oooo00<0003oool00000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007coool0
0`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?oo
ooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Koool500000_ooo`800005oooo0`0000;oool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003ooooo
ool02_ooo`050000oooooooooooo000007goool007[oool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Ooool500000oooo`030000oooooooo07[oool007_oool00`000?oo
ooooo`0500003_ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Soool00`000?ooo`000003
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002oooo`800002oooo00<0
003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.76707 .12361 L
.77247 .12361 L
.77511 .12361 L
.77626 .12361 L
.77751 .12361 L
s
.77751 .12361 m
.77804 .61803 L
s
0 .4 1 r
.02381 .12346 m
.04262 .1234 L
.06244 .12331 L
.07286 .12325 L
.08255 .12319 L
.09388 .12309 L
.10458 .12299 L
.125 .12272 L
.14357 .12237 L
.16355 .12184 L
.18199 .12115 L
.20071 .12017 L
.21136 .11945 L
.22134 .11865 L
.24158 .11649 L
.26011 .11371 L
.27909 .10972 L
.28984 .10679 L
.29982 .10352 L
.32034 .09465 L
.33895 .08326 L
.35819 .06676 L
.36904 .05464 L
.37385 .04846 L
.3765 .04482 L
.37901 .04122 L
.3802 .03946 L
.38145 .03834 L
.38211 .03836 L
.38283 .03839 L
.38411 .03844 L
.38875 .03863 L
.39784 .03905 L
.4185 .04029 L
.43785 .04192 L
.4587 .04438 L
.47875 .04766 L
.49984 .05243 L
.51959 .05843 L
.53795 .06565 L
.577 .08499 L
.58724 .09043 L
.59834 .09877 L
.60883 .10961 L
.61388 .11607 L
.61609 .11917 L
.61734 .121 L
.6185 .12275 L
.61966 .12361 L
.62089 .12361 L
Mistroke
.62317 .12361 L
.62819 .12361 L
.63726 .12361 L
.6579 .12361 L
.69953 .12361 L
.73965 .12361 L
.77826 .12361 L
.81931 .12361 L
.85885 .12361 L
.89687 .12361 L
.93735 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00LOooo``0I_lVoooo00<0003oooooool0N_ooo`00L?ooo`0306Kooooooooo
00[oool:06Ko7?ooo`030000oooooooo07[oool006ooool00`1Vooooooooo`0Eoooo1P1VoaKoool0
0`000?ooooooo`1joooo001^oooo00<0I_ooooooool07?ooo`@0I_lBoooo0P0007_oool006koool0
0`1Vooooooooo`0Poooo0P1Voa3oool00`000?ooooooo`1joooo001]oooo00<0I_ooooooool08ooo
o`<0I_l=oooo00<0003oooooool0N_ooo`00K?ooo`0306Kooooooooo02Ooool206Ko2oooo`030000
oooooooo07[oool006_oool00`1Vooooooooo`0Zoooo0P1Vo`Woool00`000?ooooooo`1joooo001Z
oooo00<0I_ooooooool0;Oooo`80I_l7oooo00<0003oooooool0N_ooo`00J?ooo`80I_lboooo0P1V
o`Goool20000Noooo`00:oooo`<0000Xoooo0`0000koool00`1Vooooooooo`0Boooo100001koool2
06Ko0oooo`030000oooooooo02?oool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool03?ooo`0306Kooooooooo01?oool00`000?ooooooo`0Qoooo0P1Vo`03oooo
0000oooo02Coool00`000?ooooooo`0Yoooo00<0003oooooool0:?ooo`00:oooo`040000oooooooo
00009Oooo`D0000;oooo0P1VoaOoool00`000?ooooooo`0Roooo00<0I_l0003oool09Oooo`030000
oooooooo02Goool50000:Oooo`009Oooo`@00002oooo0`00023oool400000_ooo`040000oooooooo
00002_ooo`80I_lBoooo100000Coool00`000?ooooooo`0Roooo00<00000I_l0I_l09Oooo`030000
oooooooo02Coool010000?ooooooo`0002[oool002coool00`000?ooooooo`0Voooo00<0003oool0
00002?ooo`80I_lJoooo00@0003oooooool0000Soooo00<0003oooooool00P1Vob7oool010000?oo
ooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200001_ooo`80I_lMoooo0P00
02Coool200000oooo`0306Kooooooooo01ooool20000:?ooo`80000Zoooo001Loooo0P1VodGoool0
0`000?ooooooo`03oooo00<0I_ooooooool0M?ooo`00FOooo`<0I_m7oooo00<0003oooooool01?oo
o`0306Kooooooooo07?oool005Goool406KoB_ooo`030000oooooooo00Goool00`1Vooooooooo`1b
oooo001@oooo1@1Vodkoool00`000?ooooooo`06oooo00<0I_ooooooool0LOooo`00AOooo`/0I_mC
oooo00<0003oooooool01_ooo`0306Kooooooooo077oool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0
003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000oooooooo00Ooool00ol0VOoo
ooooo`0Loooo00<0003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool0;oooo`03o`2I
oooooooo04Soool008coool00`0003?o03?o000D<ol000<0003oooooool0;oooo`03o`2Ioooooooo
04Soool008goool2000053?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002?oooo00<0
000co`0co`004C?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002@oooo00<0000co`0c
o`0043?o0080000`oooo00?o09Woooooool0B?ooo`00TOooo`80000@<ol000<0003oooooool0;ooo
o`03o`2Ioooooooo04Soool009?oool00`0003?o03?o000=<ol000<0003oooooool0;oooo`03o`2I
oooooooo04Soool009?oool00`0003?o03?o000=<ol000<0003oooooool0;oooo`03o`2Ioooooooo
04Soool009Coool00`0003?o03?o000<<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool0
09Coool00`0003?o03?o000<<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool009Goool0
0`0003?o03?o000;<ol00P00033oool00ol0VOooooooo`18oooo002Eoooo00<0000co`0co`002c?o
00030000oooooooo02ooool00ol0VOooooooo`18oooo002Foooo00<0000co`0co`002S?o00030000
oooooooo02ooool00ol0VOooooooo`18oooo002Foooo00<0000co`0co`002S?o00030000oooooooo
02ooool00ol0VOooooooo`18oooo002Goooo00<0000co`0co`002C?o00030000oooooooo02ooool0
0ol0VOooooooo`18oooo002Goooo00<0000co`0co`002C?o00030000oooooooo02ooool00ol0VOoo
ooooo`18oooo002Hoooo00<0000co`0co`0023?o0080000`oooo00?o09Woooooool0B?ooo`00V?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`0_oooo00?o09Woooooool0B?ooo`00V?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`0_oooo00?o09Woooooool0B?ooo`00VOooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0_oooo00?o09Woooooool0B?ooo`00VOooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0_oooo00?o09Woooooool0B?ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0_oooo00?o09Woooooool0B?ooo`00VOooo`030000<ol0<ol000Lco`020000<?ooo`03o`2I
oooooooo04Soool009[oool00`0003?o03?o0006<ol000<0003oooooool0;oooo`03o`2Ioooooooo
04Soool009[oool00`0003?o03?o0006<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool0
09[oool00`0003?o03?o0006<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool009[oool0
0`0003?o03?o0006<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool009_oool500000c?o
00030000oooooooo02ooool00ol0VOooooooo`18oooo002Koooo00<0000co`0000001C?o00030000
oooooooo02ooool00ol0VOooooooo`18oooo002Koooo00<0000co`0000001C?o00<0000_oooo00?o
09Woooooool0B?ooo`00W?ooo`800005<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool0
09coool200001C?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002Loooo0P0000Dco`00
0`000?ooooooo`0_oooo00?o09Woooooool0B?ooo`00W?ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0_oooo00?o09Woooooool0B?ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0_
oooo00?o09Woooooool0B?ooo`00W?ooo`030000<ol0<ol000@co`020000<?ooo`03o`2Ioooooooo
04Soool009goool00`0003?o03?o0003<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool0
09goool00`0003?o03?o0003<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool009goool0
0`0003?o03?o0003<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool009goool00`0003?o
03?o0003<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool009goool00`0003?o03?o0003
<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Soool009goool00`0003?o03?o0003<ol00P00
033oool00ol0VOooooooo`18oooo002Moooo00<0000co`0co`000c?o00030000oooooooo02ooool0
0ol0VOooooooo`18oooo002Moooo00<0000co`0co`000c?o00030000oooooooo02ooool00ol0VOoo
ooooo`18oooo002Noooo00<0000co`0co`000S?o00030000oooooooo02ooool00ol0VOooooooo`18
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002N
oooo00<0000co`0co`000S?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002Noooo00<0
000co`0co`000S?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002Noooo00<0000co`0c
o`000S?o0080000`oooo00?o09Woooooool0B?ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0_oooo00?o09Woooooool0B?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0_
oooo00?o09Woooooool0B?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0_oooo00?o
09Woooooool0B?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0_oooo00?o09Wooooo
ool0B?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0_oooo00?o09Woooooool0B?oo
o`00W_ooo`030000<ol0<ol0008co`020000<?ooo`03o`2Ioooooooo04Soool009ooool01@0003?o
03?o03?o0000000aoooo00?o09Woooooool0B?ooo`00Woooo`050000<ol0<ol0<ol00000037oool0
0ol0VOooooooo`18oooo002Ooooo00D0000co`0co`0co`000000<Oooo`03o`2Ioooooooo04Soool0
09_oool500000c?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002Koooo00D0003ooooo
ooooool000000c?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002Loooo00@0003ooooo
ool00003<ol00`0002ooool00ol0VOooooooo`18oooo002Moooo00<0003oool000000c?o00030000
oooooooo02ooool00ol0VOooooooo`18oooo002Koooo00<0003oooooool00P0000<co`000`000?oo
ooooo`0_oooo00?o09Woooooool0B?ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003ooooo
ool0;oooo`03o`2Ioooooooo04Soool009ooool01@0003?o03?o03?o0000000aoooo00?o09Wooooo
ool0B?ooo`00X?ooo`040000<ol0<ol00000<Oooo`03o`2Ioooooooo04Soool00:3oool00`0003?o
03?o00020000<?ooo`03o`2Ioooooooo04Soool00:3oool0100003?o03?o0000037oool00ol0VOoo
ooooo`18oooo002Poooo00@0000co`0co`00000aoooo00?o09Woooooool0B?ooo`00X?ooo`040000
<ol0<ol00000<Oooo`03o`2Ioooooooo04Soool00:3oool0100003?o03?o0000037oool00ol0VOoo
ooooo`18oooo002Poooo00@0000co`0co`00000aoooo00?o09Woooooool0B?ooo`00X?ooo`040000
<ol0<ol00000<Oooo`03o`2Ioooooooo04Soool00:7oool0100003?o00000000033oool00ol0VOoo
ooooo`18oooo002Qoooo00<0000co`000000<Oooo`03o`2Ioooooooo04Soool00:7oool00`0003?o
0000000aoooo00?o09Woooooool0B?ooo`00XOooo`030000<ol00000037oool00ol0VOooooooo`18
oooo002Qoooo00<0000co`000000<Oooo`03o`2Ioooooooo04Soool00:7oool00`0003?o0000000a
oooo00?o09Woooooool0B?ooo`00XOooo`040000<ol000000000<?ooo`03o`2Ioooooooo04Soool0
0:7oool00`0003?o0000000aoooo00?o09Woooooool0B?ooo`00XOooo`030000<ol00000037oool0
0ol0VOooooooo`18oooo002Qoooo00<0000co`000000<Oooo`03o`2Ioooooooo04Soool00:7oool0
0`0003?o0000000aoooo00?o09Woooooool0B?ooo`00XOooo`030000<ol00000037oool00ol0VOoo
ooooo`18oooo002Qoooo00@0000co`000000000`oooo00?o09Woooooool0B?ooo`00XOooo`030000
<ol00000037oool00ol0VOooooooo`18oooo002Qoooo00<0000co`000000<Oooo`03o`2Ioooooooo
04Soool00:7oool00`0003?o0000000aoooo00?o09Woooooool0B?ooo`00W?ooo`800003oooo00<0
000co`000000<Oooo`03o`2Ioooooooo04Soool009_oool010000?ooooooo`0000;oool00`0003?o
0000000aoooo00?o09Woooooool0B?ooo`00WOooo`060000oooooooooooo0000<ol00`0002ooool0
0ol0VOooooooo`18oooo002Noooo00H0003oooooool0000co`00000aoooo00?o09Woooooool0B?oo
o`00Voooo`040000oooooooo00000_ooo`030000<ol00000037oool00ol0VOooooooo`18oooo002L
oooo0P0000Coool20000<Oooo`03o`2Ioooooooo04Soool00:;oool20000<Oooo`03o`2Ioooooooo
04Soool00:;oool20000<Oooo`03o`2Ioooooooo04Soool00:;oool20000<Oooo`03o`2Ioooooooo
04Soool00:;oool30000<?ooo`03o`2Ioooooooo04Soool00:;oool20000<Oooo`03o`2Ioooooooo
04Soool00:;oool20000<Oooo`03o`2Ioooooooo04Soool00:;oool20000<Oooo`03o`2Ioooooooo
04Soool00:;oool20000<Oooo`03o`2Ioooooooo04Soool00:;oool20000<Oooo`03o`2Ioooooooo
04Soool00:;oool30000<?ooo`03o`2Ioooooooo04Soool00:;oool20000<Oooo`03o`2Ioooooooo
04Soool00:;oool20000<Oooo`03o`2Ioooooooo04Soool00:;oool20000<Oooo`03o`2Ioooooooo
04Soool00:;oool20000<Oooo`03o`2Ioooooooo04Soool00:;oool20000<Oooo`03o`2Ioooooooo
04Soool00:;oool30000<?ooo`03o`2Ioooooooo04Soool00:?oool00`000?ooooooo`0_oooo00?o
09Woooooool0B?ooo`00Xoooo`030000oooooooo02ooool00ol0VOooooooo`18oooo002Soooo00<0
003oooooool0;oooo`03o`2Ioooooooo04Soool00:?oool00`000?ooooooo`0_oooo00?o09Wooooo
ool0B?ooo`00Xoooo`030000oooooooo02ooool00ol0VOooooooo`18oooo002Soooo0P00033oool0
0ol0VOooooooo`18oooo002Soooo00<0003oooooool0;oooo`03o`2Ioooooooo04Soool00:?oool0
0`000?ooooooo`0_oooo00?o09Woooooool0B?ooo`00Xoooo`030000oooooooo02ooool00ol0VOoo
ooooo`18oooo002Soooo00<0003oooooool0;oooo`03o`2Ioooooooo04Soool009goool300000ooo
o`030000oooooooo02ooool00ol0VOooooooo`18oooo002Noooo00<0003oooooool00_ooo`030000
oooooooo02ooool00ol0VOooooooo`18oooo002Koooo1@0000?oool30000;oooo`03o`2Ioooooooo
04Soool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00
087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00koool00`000?ooooooo`08oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000004Oooo`030000oooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool0Nooo
o`00O?ooo`030000oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.76707 .12361 L
.77751 .12361 L
.78008 .12361 L
.78283 .12361 L
.78364 .12361 L
.78441 .12361 L
.7851 .12361 L
s
.7851 .12361 m
.7854 .61803 L
s
0 .4 1 r
.02381 .12344 m
.04262 .12337 L
.06244 .12327 L
.07286 .1232 L
.08255 .12312 L
.09388 .12301 L
.10458 .12289 L
.125 .12258 L
.14357 .12217 L
.16355 .12156 L
.18199 .12076 L
.20071 .11964 L
.21136 .11881 L
.22134 .11787 L
.24158 .11538 L
.26011 .11216 L
.27909 .10755 L
.28984 .10417 L
.29982 .10038 L
.32034 .09013 L
.33895 .07697 L
.35982 .05596 L
.36897 .04397 L
.37148 .04034 L
.3722 .03926 L
.37288 .03822 L
.37416 .03805 L
.37537 .03809 L
.37649 .03813 L
.37901 .03822 L
.39776 .03901 L
.41757 .04017 L
.43623 .04168 L
.45683 .044 L
.47618 .04701 L
.49703 .05145 L
.51708 .05721 L
.53817 .0652 L
.57628 .0818 L
.58637 .08569 L
.59589 .09088 L
.60687 .09929 L
.61684 .10971 L
.62187 .11613 L
.62432 .1196 L
.6254 .12118 L
.62657 .12296 L
.62778 .12361 L
.62893 .12361 L
.63147 .12361 L
Mistroke
.63686 .12361 L
.65531 .12361 L
.69601 .12361 L
.73519 .12361 L
.77682 .12361 L
.81694 .12361 L
.85555 .12361 L
.8966 .12361 L
.93614 .12361 L
.97416 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00K_ooo`l0I_lVoooo00<0003oooooool0N_ooo`00K_ooo`0306Kooooooooo
00coool:06Ko7?ooo`030000oooooooo07[oool006goool00`1Vooooooooo`0Goooo1@1VoaOoool0
0`000?ooooooo`1joooo001/oooo00<0I_ooooooool07Oooo`@0I_lCoooo0P0007_oool006_oool0
0`1Vooooooooo`0Roooo0P1Voa7oool00`000?ooooooo`1joooo001Zoooo00<0I_ooooooool09Ooo
o`<0I_l>oooo00<0003oooooool0N_ooo`00JOooo`0306Kooooooooo02Woool306Ko2oooo`030000
oooooooo07[oool006Soool00`1Vooooooooo`0]oooo0`1Vo`Soool00`000?ooooooo`1joooo001X
oooo00<0I_ooooooool0<?ooo`80I_l6oooo00<0003oooooool0N_ooo`00Ioooo`0306Kooooooooo
03?oool206Ko1?ooo`80001koooo000[oooo0`0002Soool300003Oooo`0306Kooooooooo01?oool4
00007oooo`80I_l2oooo00<0003oooooool08oooo`@0000Woooo0`0002Woool002_oool010000?oo
ooooo`0002Soool00`000?ooooooo`0:oooo0P1VoaKoool00`000?ooooooo`0Roooo0P1Vo`030000
oooooooo02?oool00`000?ooooooo`0Yoooo00<0003oooooool0:?ooo`00:oooo`040000oooooooo
00009Oooo`D00009oooo0P1VoaWoool00`000?ooooooo`0Soooo00<00000I_l0I_l09?ooo`030000
oooooooo02Goool50000:Oooo`009Oooo`@00002oooo0`00023oool400000_ooo`040000oooooooo
00002Oooo`0306Kooooooooo01;oool400001?ooo`030000oooooooo02;oool00`000?ooooooo`02
06Ko8oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool00`000?ooooooo`0V
oooo00<0003oool000001oooo`80I_lKoooo00@0003oooooool0000Soooo00<0003oooooool00_oo
o`80I_lOoooo00@0003oooooool0000Voooo00<0003oool00000:_ooo`00;?ooo`<0000Woooo0P00
00Goool206Ko7_ooo`80000Toooo0P0000Goool00`1Vooooooooo`0Moooo0P0002Soool20000:_oo
o`00FOooo`@0I_m6oooo00<0003oooooool01Oooo`0306Kooooooooo07;oool005Goool406KoB_oo
o`030000oooooooo00Koool00`1Vooooooooo`1aoooo001@oooo1@1Vodkoool00`000?ooooooo`07
oooo00<0I_ooooooool0L?ooo`00Boooo`D0I_mCoooo00<0003oooooool01oooo`0306Kooooooooo
073oool0047oool:06KoF?ooo`030000oooooooo00Soool00`1Vooooooooo`1_oooo000@ooooo`00
017oool001Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`00000@000000<co`00000c
o`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooool0V@07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`030000oooooooo00Koool400006c?o00030000oooooooo02Goool00`000?oo
ooooo`09oooo00?o09Woooooool06_ooo`030000oooooooo02Woool008Soool400005c?o00030000
oooooooo037oool00ol0VOooooooo`16oooo002<oooo00<0000co`0co`0053?o00030000oooooooo
037oool00ol0VOooooooo`16oooo002=oooo0P0001@co`000`000?ooooooo`0aoooo00?o09Wooooo
ool0A_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0aoooo00?o09Woooooool0A_oo
o`00T?ooo`030000<ol0<ol0010co`020000<_ooo`03o`2Ioooooooo04Koool0097oool2000043?o
00030000oooooooo037oool00ol0VOooooooo`16oooo002Coooo00<0000co`0co`003C?o00030000
oooooooo037oool00ol0VOooooooo`16oooo002Coooo00<0000co`0co`003C?o00030000oooooooo
037oool00ol0VOooooooo`16oooo002Doooo00<0000co`0co`0033?o00030000oooooooo037oool0
0ol0VOooooooo`16oooo002Doooo00<0000co`0co`0033?o00030000oooooooo037oool00ol0VOoo
ooooo`16oooo002Eoooo00<0000co`0co`002c?o0080000boooo00?o09Woooooool0A_ooo`00UOoo
o`030000<ol0<ol000/co`000`000?ooooooo`0aoooo00?o09Woooooool0A_ooo`00U_ooo`030000
<ol0<ol000Xco`000`000?ooooooo`0aoooo00?o09Woooooool0A_ooo`00U_ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0aoooo00?o09Woooooool0A_ooo`00Uoooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0aoooo00?o09Woooooool0A_ooo`00Uoooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0aoooo00?o09Woooooool0A_ooo`00V?ooo`030000<ol0<ol000Pco`020000<_ooo`03o`2I
oooooooo04Koool009Soool00`0003?o03?o0008<ol000<0003oooooool0<Oooo`03o`2Ioooooooo
04Koool009Soool00`0003?o03?o0008<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool0
09Woool00`0003?o03?o0007<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool009Woool0
0`0003?o03?o0007<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool009Woool00`0003?o
03?o0007<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool009Woool00`0003?o03?o0007
<ol00P0003;oool00ol0VOooooooo`16oooo002Joooo00<0000co`0co`001S?o00030000oooooooo
037oool00ol0VOooooooo`16oooo002Joooo00<0000co`0co`001S?o00030000oooooooo037oool0
0ol0VOooooooo`16oooo002Joooo00<0000co`0co`001S?o00030000oooooooo037oool00ol0VOoo
ooooo`16oooo002Joooo00<0000co`0co`001S?o00030000oooooooo037oool00ol0VOooooooo`16
oooo002Koooo1@0000<co`000`000?ooooooo`0aoooo00?o09Woooooool0A_ooo`00Voooo`030000
<ol0000000Dco`000`000?ooooooo`0aoooo00?o09Woooooool0A_ooo`00Voooo`030000<ol00000
00Dco`030000<Oooo`03o`2Ioooooooo04Koool009coool200001C?o00030000oooooooo037oool0
0ol0VOooooooo`16oooo002Loooo0P0000Dco`000`000?ooooooo`0aoooo00?o09Woooooool0A_oo
o`00W?ooo`800005<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool009coool00`0003?o
03?o0004<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool009coool00`0003?o03?o0004
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool009coool00`0003?o03?o0004<ol00P00
03;oool00ol0VOooooooo`16oooo002Moooo00<0000co`0co`000c?o00030000oooooooo037oool0
0ol0VOooooooo`16oooo002Moooo00<0000co`0co`000c?o00030000oooooooo037oool00ol0VOoo
ooooo`16oooo002Moooo00<0000co`0co`000c?o00030000oooooooo037oool00ol0VOooooooo`16
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo037oool00ol0VOooooooo`16oooo002M
oooo00<0000co`0co`000c?o00030000oooooooo037oool00ol0VOooooooo`16oooo002Moooo00<0
000co`0co`000c?o0080000boooo00?o09Woooooool0A_ooo`00WOooo`030000<ol0<ol000<co`00
0`000?ooooooo`0aoooo00?o09Woooooool0A_ooo`00WOooo`030000<ol0<ol000<co`000`000?oo
ooooo`0aoooo00?o09Woooooool0A_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0a
oooo00?o09Woooooool0A_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0aoooo00?o
09Woooooool0A_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0aoooo00?o09Wooooo
ool0A_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0aoooo00?o09Woooooool0A_oo
o`00W_ooo`030000<ol0<ol0008co`020000<_ooo`03o`2Ioooooooo04Koool009koool00`0003?o
03?o0002<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool009koool00`0003?o03?o0002
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool009koool00`0003?o03?o0002<ol000<0
003oooooool0<Oooo`03o`2Ioooooooo04Koool009koool00`0003?o03?o0002<ol000<0003ooooo
ool0<Oooo`03o`2Ioooooooo04Koool009koool00`0003?o03?o0002<ol000<0003oooooool0<Ooo
o`03o`2Ioooooooo04Koool009koool00`0003?o03?o0002<ol00P0003;oool00ol0VOooooooo`16
oooo002Ooooo00D0000co`0co`0co`000000<oooo`03o`2Ioooooooo04Koool009ooool01@0003?o
03?o03?o0000000coooo00?o09Woooooool0A_ooo`00Woooo`050000<ol0<ol0<ol0000003?oool0
0ol0VOooooooo`16oooo002Koooo1@0000<co`000`000?ooooooo`0aoooo00?o09Woooooool0A_oo
o`00Voooo`050000oooooooooooo000000<co`000`000?ooooooo`0aoooo00?o09Woooooool0A_oo
o`00W?ooo`040000oooooooo00000c?o00<0000aoooo00?o09Woooooool0A_ooo`00WOooo`030000
oooo000000<co`000`000?ooooooo`0aoooo00?o09Woooooool0A_ooo`00Voooo`030000oooooooo
00800003<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool009coool2000000?oool0000c
o`000S?o00030000oooooooo037oool00ol0VOooooooo`16oooo002Ooooo00D0000co`0co`0co`00
0000<oooo`03o`2Ioooooooo04Koool00:3oool0100003?o03?o000003?oool00ol0VOooooooo`16
oooo002Poooo00<0000co`0co`000P0003;oool00ol0VOooooooo`16oooo002Poooo00@0000co`0c
o`00000coooo00?o09Woooooool0A_ooo`00X?ooo`040000<ol0<ol00000<oooo`03o`2Ioooooooo
04Koool00:3oool0100003?o03?o000003?oool00ol0VOooooooo`16oooo002Poooo00@0000co`0c
o`00000coooo00?o09Woooooool0A_ooo`00X?ooo`040000<ol0<ol00000<oooo`03o`2Ioooooooo
04Koool00:3oool0100003?o03?o000003?oool00ol0VOooooooo`16oooo002Qoooo00@0000co`00
0000000boooo00?o09Woooooool0A_ooo`00XOooo`030000<ol0000003?oool00ol0VOooooooo`16
oooo002Qoooo00<0000co`000000<oooo`03o`2Ioooooooo04Koool00:7oool00`0003?o0000000c
oooo00?o09Woooooool0A_ooo`00XOooo`030000<ol0000003?oool00ol0VOooooooo`16oooo002Q
oooo00<0000co`000000<oooo`03o`2Ioooooooo04Koool00:7oool0100003?o0000000003;oool0
0ol0VOooooooo`16oooo002Qoooo00<0000co`000000<oooo`03o`2Ioooooooo04Koool00:7oool0
0`0003?o0000000coooo00?o09Woooooool0A_ooo`00XOooo`030000<ol0000003?oool00ol0VOoo
ooooo`16oooo002Qoooo00<0000co`000000<oooo`03o`2Ioooooooo04Koool00:7oool00`0003?o
0000000coooo00?o09Woooooool0A_ooo`00XOooo`040000<ol000000000<_ooo`03o`2Ioooooooo
04Koool00:7oool00`0003?o0000000coooo00?o09Woooooool0A_ooo`00XOooo`030000<ol00000
03?oool00ol0VOooooooo`16oooo002Qoooo00<0000co`000000<oooo`03o`2Ioooooooo04Koool0
09coool200000oooo`030000<ol0000003?oool00ol0VOooooooo`16oooo002Koooo00@0003ooooo
ool00002oooo00<0000co`000000<oooo`03o`2Ioooooooo04Koool009goool01P000?oooooooooo
o`0003?o00<0000aoooo00?o09Woooooool0A_ooo`00W_ooo`060000oooooooo0000<ol00000<ooo
o`03o`2Ioooooooo04Koool009_oool010000?ooooooo`0000;oool00`0003?o0000000coooo00?o
09Woooooool0A_ooo`00W?ooo`800004oooo0P0003?oool00ol0VOooooooo`16oooo002Roooo0P00
03?oool00ol0VOooooooo`16oooo002Roooo0P0003?oool00ol0VOooooooo`16oooo002Roooo0P00
03?oool00ol0VOooooooo`16oooo002Roooo0`0003;oool00ol0VOooooooo`16oooo002Roooo0P00
03?oool00ol0VOooooooo`16oooo002Roooo0P0003?oool00ol0VOooooooo`16oooo002Roooo0P00
03?oool00ol0VOooooooo`16oooo002Roooo0P0003?oool00ol0VOooooooo`16oooo002Roooo0P00
03?oool00ol0VOooooooo`16oooo002Roooo0`0003;oool00ol0VOooooooo`16oooo002Roooo0P00
03?oool00ol0VOooooooo`16oooo002Roooo0P0003?oool00ol0VOooooooo`16oooo002Roooo0P00
03?oool00ol0VOooooooo`16oooo002Roooo0P0003?oool00ol0VOooooooo`16oooo002Roooo0P00
03?oool00ol0VOooooooo`16oooo002Roooo0`0003;oool00ol0VOooooooo`16oooo002Soooo00<0
003oooooool0<Oooo`03o`2Ioooooooo04Koool00:?oool00`000?ooooooo`0aoooo00?o09Wooooo
ool0A_ooo`00Xoooo`030000oooooooo037oool00ol0VOooooooo`16oooo002Soooo00<0003ooooo
ool0<Oooo`03o`2Ioooooooo04Koool00:?oool00`000?ooooooo`0aoooo00?o09Woooooool0A_oo
o`00Xoooo`80000boooo00?o09Woooooool0A_ooo`00Xoooo`030000oooooooo037oool00ol0VOoo
ooooo`16oooo002Soooo00<0003oooooool0<Oooo`03o`2Ioooooooo04Koool00:?oool00`000?oo
ooooo`0aoooo00?o09Woooooool0A_ooo`00Xoooo`030000oooooooo037oool00ol0VOooooooo`16
oooo002Moooo0`0000?oool00`000?ooooooo`0aoooo00?o09Woooooool0A_ooo`00W_ooo`030000
oooooooo00;oool00`000?ooooooo`0aoooo00?o09Woooooool0A_ooo`00Voooo`D00003oooo0`00
037oool00ol0VOooooooo`16oooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool0
0000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0R
oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0
003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool5
00000_ooo`800003oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000
oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo0`0000Coool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Soool00`000?ooooooo`03
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`<00002oooo00<0
003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.77751 .12361 L
.78293 .12361 L
.78866 .12361 L
.79102 .12361 L
.79232 .12361 L
.79355 .12361 L
s
.79355 .12361 m
.79383 .61803 L
s
0 .4 1 r
.02381 .12341 m
.04262 .12333 L
.06244 .12322 L
.07286 .12314 L
.08255 .12305 L
.09388 .12292 L
.10458 .12278 L
.125 .12242 L
.14357 .12195 L
.16355 .12124 L
.18199 .12032 L
.20071 .11902 L
.21136 .11806 L
.22134 .11698 L
.24158 .1141 L
.26011 .11039 L
.27909 .10507 L
.28984 .10115 L
.29982 .09678 L
.32034 .08494 L
.33895 .06974 L
.3491 .05906 L
.35464 .05236 L
.35982 .04547 L
.36208 .04225 L
.36423 .03907 L
.36542 .0378 L
.36671 .03784 L
.36897 .0379 L
.37901 .03823 L
.39904 .03909 L
.41757 .04019 L
.43623 .04171 L
.45683 .04405 L
.47618 .04707 L
.49703 .05154 L
.51708 .05734 L
.53817 .06529 L
.57628 .07986 L
.61684 .10119 L
.62594 .11112 L
.63092 .11769 L
.63336 .12122 L
.63442 .12283 L
.63558 .12361 L
.63682 .12361 L
.63801 .12361 L
.64061 .12361 L
.64615 .12361 L
.65589 .12361 L
Mistroke
.67723 .12361 L
.69739 .12361 L
.73808 .12361 L
.77727 .12361 L
.8189 .12361 L
.85902 .12361 L
.89762 .12361 L
.93868 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00KOoooa00I_lVoooo00<0003oooooool0N_ooo`00K?ooo`0306Kooooooooo
00koool:06Ko7?ooo`030000oooooooo07[oool006_oool00`1Vooooooooo`0Ioooo1@1VoaOoool0
0`000?ooooooo`1joooo001Zoooo00<0I_ooooooool07oooo`@0I_lCoooo0P0007_oool006Woool0
0`1Vooooooooo`0Toooo0P1Voa7oool00`000?ooooooo`1joooo001Yoooo00<0I_ooooooool09_oo
o`<0I_l>oooo00<0003oooooool0N_ooo`00J?ooo`0306Kooooooooo02[oool306Ko2oooo`030000
oooooooo07[oool006Ooool00`1Vooooooooo`0^oooo0`1Vo`Soool00`000?ooooooo`1joooo001V
oooo00<0I_ooooooool0<_ooo`<0I_l5oooo00<0003oooooool0N_ooo`00IOooo`0306Kooooooooo
03Koool306Ko0_ooo`80001koooo000[oooo0`0002Soool300002_ooo`80I_lGoooo1000027oool2
06Ko00<0003oooooool08oooo`@0000Woooo0`0002Woool002_oool010000?ooooooo`0002Soool0
0`000?ooooooo`08oooo00<0I_ooooooool05oooo`030000oooooooo02Coool00`00001Vooooo`0S
oooo00<0003oooooool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool5
00002?ooo`0306Kooooooooo01Woool00`000?ooooooo`0Soooo00@0003oool0I_l0I_lSoooo00<0
003oooooool09Oooo`D0000Yoooo000Uoooo100000;oool300008?ooo`@00002oooo00@0003ooooo
ool00007oooo0P1VoaGoool400001?ooo`030000oooooooo02;oool010000?ooooooooooo`80I_lR
oooo00<0003oooooool09?ooo`040000oooooooo0000:_ooo`00;?ooo`030000oooooooo02Koool0
0`000?ooo`000005oooo0P1Voagoool010000?ooooooo`0002?oool00`000?ooooooo`03oooo0P1V
oakoool010000?ooooooo`0002Koool00`000?ooo`00000Zoooo000/oooo0`0002Ooool200001?oo
o`0306Kooooooooo01koool200009?ooo`800006oooo0P1Voagoool20000:?ooo`80000Zoooo001I
oooo0`1VodOoool00`000?ooooooo`07oooo00<0I_ooooooool0L?ooo`00EOooo`@0I_m:oooo00<0
003oooooool02?ooo`0306Kooooooooo06ooool0053oool506KoC_ooo`030000oooooooo00Woool0
0`1Vooooooooo`1^oooo001;oooo1@1Voe?oool00`000?ooooooo`09oooo00<0I_ooooooool0K_oo
o`00@Oooo`X0I_mHoooo00<0003oooooool02_ooo`0306Kooooooooo06goool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooo0000010000000c?o000003?o0008
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`050000
ooooooooooooo`2I00Goool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo02Koool0
0`000?ooooooo`0Uoooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000
oooooooo00_oool00ol0VOooooooo`0Hoooo00<0003oooooool0:Oooo`00R?ooo`@0000G<ol000<0
003oooooool0<oooo`03o`2Ioooooooo04Coool008coool00`0003?o03?o000D<ol000<0003ooooo
ool0<oooo`03o`2Ioooooooo04Coool008goool2000053?o00030000oooooooo03?oool00ol0VOoo
ooooo`14oooo002?oooo00<0000co`0co`004C?o00030000oooooooo03?oool00ol0VOooooooo`14
oooo002@oooo00<0000co`0co`0043?o0080000doooo00?o09Woooooool0A?ooo`00TOooo`80000@
<ol000<0003oooooool0<oooo`03o`2Ioooooooo04Coool009?oool00`0003?o03?o000=<ol000<0
003oooooool0<oooo`03o`2Ioooooooo04Coool009?oool00`0003?o03?o000=<ol000<0003ooooo
ool0<oooo`03o`2Ioooooooo04Coool009Coool00`0003?o03?o000<<ol000<0003oooooool0<ooo
o`03o`2Ioooooooo04Coool009Coool00`0003?o03?o000<<ol000<0003oooooool0<oooo`03o`2I
oooooooo04Coool009Goool00`0003?o03?o000;<ol00P0003Coool00ol0VOooooooo`14oooo002E
oooo00<0000co`0co`002c?o00030000oooooooo03?oool00ol0VOooooooo`14oooo002Foooo00<0
000co`0co`002S?o00030000oooooooo03?oool00ol0VOooooooo`14oooo002Foooo00<0000co`0c
o`002S?o00030000oooooooo03?oool00ol0VOooooooo`14oooo002Goooo00<0000co`0co`002C?o
00030000oooooooo03?oool00ol0VOooooooo`14oooo002Goooo00<0000co`0co`002C?o00030000
oooooooo03?oool00ol0VOooooooo`14oooo002Hoooo00<0000co`0co`0023?o0080000doooo00?o
09Woooooool0A?ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0coooo00?o09Wooooo
ool0A?ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0coooo00?o09Woooooool0A?oo
o`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00VOoo
o`030000<ol0<ol000Lco`000`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00VOooo`030000
<ol0<ol000Lco`000`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00VOooo`030000<ol0<ol0
00Lco`020000=?ooo`03o`2Ioooooooo04Coool009[oool00`0003?o03?o0006<ol000<0003ooooo
ool0<oooo`03o`2Ioooooooo04Coool009[oool00`0003?o03?o0006<ol000<0003oooooool0<ooo
o`03o`2Ioooooooo04Coool009[oool00`0003?o03?o0006<ol000<0003oooooool0<oooo`03o`2I
oooooooo04Coool009[oool00`0003?o03?o0006<ol000<0003oooooool0<oooo`03o`2Ioooooooo
04Coool009_oool500000c?o00030000oooooooo03?oool00ol0VOooooooo`14oooo002Koooo00<0
000co`0000001C?o00030000oooooooo03?oool00ol0VOooooooo`14oooo002Koooo00<0000co`00
00001C?o00<0000coooo00?o09Woooooool0A?ooo`00W?ooo`800005<ol000<0003oooooool0<ooo
o`03o`2Ioooooooo04Coool009coool200001C?o00030000oooooooo03?oool00ol0VOooooooo`14
oooo002Loooo0P0000Dco`000`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00W?ooo`030000
<ol0<ol000@co`000`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00W?ooo`030000<ol0<ol0
00@co`000`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00W?ooo`030000<ol0<ol000@co`02
0000=?ooo`03o`2Ioooooooo04Coool009goool00`0003?o03?o0003<ol000<0003oooooool0<ooo
o`03o`2Ioooooooo04Coool009goool00`0003?o03?o0003<ol000<0003oooooool0<oooo`03o`2I
oooooooo04Coool009goool00`0003?o03?o0003<ol000<0003oooooool0<oooo`03o`2Ioooooooo
04Coool009goool00`0003?o03?o0003<ol000<0003oooooool0<oooo`03o`2Ioooooooo04Coool0
09goool00`0003?o03?o0003<ol000<0003oooooool0<oooo`03o`2Ioooooooo04Coool009goool0
0`0003?o03?o0003<ol00P0003Coool00ol0VOooooooo`14oooo002Moooo00<0000co`0co`000c?o
00030000oooooooo03?oool00ol0VOooooooo`14oooo002Moooo00<0000co`0co`000c?o00030000
oooooooo03?oool00ol0VOooooooo`14oooo002Noooo00<0000co`0co`000S?o00030000oooooooo
03?oool00ol0VOooooooo`14oooo002Noooo00<0000co`0co`000S?o00030000oooooooo03?oool0
0ol0VOooooooo`14oooo002Noooo00<0000co`0co`000S?o00030000oooooooo03?oool00ol0VOoo
ooooo`14oooo002Noooo00<0000co`0co`000S?o00030000oooooooo03?oool00ol0VOooooooo`14
oooo002Noooo00<0000co`0co`000S?o0080000doooo00?o09Woooooool0A?ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0coooo00?o09Woooooool0A?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0c
oooo00?o09Woooooool0A?ooo`00W_ooo`030000<ol0<ol0008co`020000=?ooo`03o`2Ioooooooo
04Coool009ooool01@0003?o03?o03?o0000000eoooo00?o09Woooooool0A?ooo`00Woooo`050000
<ol0<ol0<ol0000003Goool00ol0VOooooooo`14oooo002Ooooo00D0000co`0co`0co`000000=Ooo
o`03o`2Ioooooooo04Coool009_oool500000c?o00030000oooooooo03?oool00ol0VOooooooo`14
oooo002Koooo00D0003oooooooooool000000c?o00030000oooooooo03?oool00ol0VOooooooo`14
oooo002Loooo00@0003oooooool00003<ol00`0003?oool00ol0VOooooooo`14oooo002Moooo00<0
003oool000000c?o00030000oooooooo03?oool00ol0VOooooooo`14oooo002Koooo00<0003ooooo
ool00P0000<co`000`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00W?ooo`8000000oooo`00
03?o0002<ol000<0003oooooool0<oooo`03o`2Ioooooooo04Coool009ooool01@0003?o03?o03?o
0000000eoooo00?o09Woooooool0A?ooo`00X?ooo`040000<ol0<ol00000=Oooo`03o`2Ioooooooo
04Coool00:3oool00`0003?o03?o00020000=?ooo`03o`2Ioooooooo04Coool00:3oool0100003?o
03?o000003Goool00ol0VOooooooo`14oooo002Poooo00@0000co`0co`00000eoooo00?o09Wooooo
ool0A?ooo`00X?ooo`040000<ol0<ol00000=Oooo`03o`2Ioooooooo04Coool00:3oool0100003?o
03?o000003Goool00ol0VOooooooo`14oooo002Poooo00@0000co`0co`00000eoooo00?o09Wooooo
ool0A?ooo`00X?ooo`040000<ol0<ol00000=Oooo`03o`2Ioooooooo04Coool00:7oool0100003?o
0000000003Coool00ol0VOooooooo`14oooo002Qoooo00<0000co`000000=Oooo`03o`2Ioooooooo
04Coool00:7oool00`0003?o0000000eoooo00?o09Woooooool0A?ooo`00XOooo`030000<ol00000
03Goool00ol0VOooooooo`14oooo002Qoooo00<0000co`000000=Oooo`03o`2Ioooooooo04Coool0
0:7oool00`0003?o0000000eoooo00?o09Woooooool0A?ooo`00XOooo`040000<ol000000000=?oo
o`03o`2Ioooooooo04Coool00:7oool00`0003?o0000000eoooo00?o09Woooooool0A?ooo`00XOoo
o`030000<ol0000003Goool00ol0VOooooooo`14oooo002Qoooo00<0000co`000000=Oooo`03o`2I
oooooooo04Coool00:7oool00`0003?o0000000eoooo00?o09Woooooool0A?ooo`00XOooo`030000
<ol0000003Goool00ol0VOooooooo`14oooo002Qoooo00@0000co`000000000doooo00?o09Wooooo
ool0A?ooo`00XOooo`030000<ol0000003Goool00ol0VOooooooo`14oooo002Qoooo00<0000co`00
0000=Oooo`03o`2Ioooooooo04Coool00:7oool00`0003?o0000000eoooo00?o09Woooooool0A?oo
o`00W?ooo`800003oooo00<0000co`000000=Oooo`03o`2Ioooooooo04Coool009_oool010000?oo
ooooo`0000;oool00`0003?o0000000eoooo00?o09Woooooool0A?ooo`00WOooo`060000oooooooo
oooo0000<ol00`0003?oool00ol0VOooooooo`14oooo002Noooo00H0003oooooool0000co`00000e
oooo00?o09Woooooool0A?ooo`00Voooo`040000oooooooo00000_ooo`030000<ol0000003Goool0
0ol0VOooooooo`14oooo002Loooo0P0000Coool20000=Oooo`03o`2Ioooooooo04Coool00:;oool2
0000=Oooo`03o`2Ioooooooo04Coool00:;oool20000=Oooo`03o`2Ioooooooo04Coool00:;oool2
0000=Oooo`03o`2Ioooooooo04Coool00:;oool30000=?ooo`03o`2Ioooooooo04Coool00:;oool2
0000=Oooo`03o`2Ioooooooo04Coool00:;oool20000=Oooo`03o`2Ioooooooo04Coool00:;oool2
0000=Oooo`03o`2Ioooooooo04Coool00:;oool20000=Oooo`03o`2Ioooooooo04Coool00:;oool2
0000=Oooo`03o`2Ioooooooo04Coool00:;oool30000=?ooo`03o`2Ioooooooo04Coool00:;oool2
0000=Oooo`03o`2Ioooooooo04Coool00:;oool20000=Oooo`03o`2Ioooooooo04Coool00:;oool2
0000=Oooo`03o`2Ioooooooo04Coool00:;oool20000=Oooo`03o`2Ioooooooo04Coool00:;oool2
0000=Oooo`03o`2Ioooooooo04Coool00:;oool30000=?ooo`03o`2Ioooooooo04Coool00:?oool0
0`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00Xoooo`030000oooooooo03?oool00ol0VOoo
ooooo`14oooo002Soooo00<0003oooooool0<oooo`03o`2Ioooooooo04Coool00:?oool00`000?oo
ooooo`0coooo00?o09Woooooool0A?ooo`00Xoooo`030000oooooooo03?oool00ol0VOooooooo`14
oooo002Soooo0P0003Coool00ol0VOooooooo`14oooo002Soooo00<0003oooooool0<oooo`03o`2I
oooooooo04Coool00:?oool00`000?ooooooo`0coooo00?o09Woooooool0A?ooo`00Xoooo`030000
oooooooo03?oool00ol0VOooooooo`14oooo002Soooo00<0003oooooool0<oooo`03o`2Ioooooooo
04Coool009goool300000oooo`030000oooooooo03?oool00ol0VOooooooo`14oooo002Noooo00<0
003oooooool00_ooo`030000oooooooo03?oool00ol0VOooooooo`14oooo002Koooo1@0000?oool3
0000<oooo`03o`2Ioooooooo04Coool009_oool010000?ooooooo`00087oool009coool00`000?oo
o`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`D00002oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo
00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`1j
oooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`0:oooo00D0003oooooooooool0
0000OOooo`00Noooo`050000oooooooooooo0000017oool00`000?ooooooo`07oooo00@0003ooooo
ool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002Oooo`@00002
oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79321 .12361 L
.79616 .12361 L
.79892 .12361 L
.80016 .12361 L
.80134 .12361 L
s
.80134 .12361 m
.8016 .61803 L
s
0 .4 1 r
.02381 .12338 m
.04262 .12329 L
.06244 .12316 L
.07286 .12306 L
.08255 .12296 L
.09388 .12282 L
.10458 .12265 L
.125 .12223 L
.14357 .12169 L
.16355 .12088 L
.18199 .11981 L
.20071 .11831 L
.21136 .11721 L
.22134 .11596 L
.24158 .11264 L
.26011 .10835 L
.27909 .10221 L
.28984 .09769 L
.29982 .09265 L
.32034 .07898 L
.33895 .06143 L
.34831 .05014 L
.35342 .04314 L
.3547 .04128 L
.35592 .03947 L
.35701 .03782 L
.35819 .03764 L
.35949 .03768 L
.36069 .03771 L
.36336 .03778 L
.36904 .03795 L
.37901 .03828 L
.39768 .03909 L
.41828 .04034 L
.43763 .04199 L
.45848 .04448 L
.47852 .04782 L
.49962 .05265 L
.51937 .05876 L
.53773 .06571 L
.57678 .07876 L
.58177 .07954 L
.58645 .08045 L
.59133 .08168 L
.59669 .08342 L
.6021 .08563 L
.60792 .08857 L
.61828 .09552 L
.62754 .10394 L
.6374 .11568 L
Mistroke
.64033 .11979 L
.64176 .12193 L
.64308 .12361 L
.64429 .12361 L
.64555 .12361 L
.64822 .12361 L
.65826 .12361 L
.67943 .12361 L
.69953 .12361 L
.73756 .12361 L
.77803 .12361 L
.81699 .12361 L
.85841 .12361 L
.89831 .12361 L
.93669 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00J_oooa<0I_lVoooo00<0003oooooool0N_ooo`00J_ooo`0306Kooooooooo
013oool:06Ko7?ooo`030000oooooooo07[oool006Woool00`1Vooooooooo`0Koooo1P1VoaKoool0
0`000?ooooooo`1joooo001Yoooo00<0I_ooooooool08Oooo`@0I_lBoooo0P0007_oool006Soool0
0`1Vooooooooo`0Voooo0P1Voa3oool00`000?ooooooo`1joooo001Woooo00<0I_ooooooool0:Ooo
o`<0I_l=oooo00<0003oooooool0N_ooo`00I_ooo`0306Kooooooooo02goool206Ko2oooo`030000
oooooooo07[oool006Goool00`1Vooooooooo`0`oooo0`1Vo`Soool00`000?ooooooo`1joooo001S
oooo0P1VocKoool306Ko1Oooo`030000oooooooo07[oool006;oool00`1Vooooooooo`0ioooo0`1V
o`;oool20000Noooo`00:oooo`<0000Xoooo0`0000Soool00`1Vooooooooo`0Hoooo1000027oool2
06Ko00<00000I_l0I_l08oooo`@0000Woooo0`0002Woool002_oool010000?ooooooo`0002Soool0
0`000?ooooooo`06oooo00<0I_ooooooool06Oooo`030000oooooooo02Coool00`000?ooooooo`02
06Ko8Oooo`030000oooooooo02Woool00`000?ooooooo`0Xoooo000[oooo00@0003oooooool0000U
oooo1@0000Goool206Ko7Oooo`030000oooooooo02?oool00`000?ooooooo`02oooo0P1Vob3oool0
0`000?ooooooo`0Uoooo1@0002Woool002Goool400000_ooo`<0000Poooo100000;oool010000?oo
ooooo`0000Goool00`1Vooooooooo`0Foooo100000Coool00`000?ooooooo`0Roooo00<0003ooooo
ool01?ooo`80I_lOoooo00<0003oooooool09?ooo`040000oooooooo0000:_ooo`00;?ooo`030000
oooooooo02Koool00`000?ooo`000004oooo00<0I_ooooooool07Oooo`040000oooooooo00008ooo
o`030000oooooooo00Koool206Ko6oooo`040000oooooooo00009_ooo`030000oooo000002[oool0
02coool300009oooo`8000001?ooo`1Vo`1Vo`1Vob7oool200009?ooo`800009oooo00<0I_oooooo
ool06Oooo`80000Xoooo0P0002[oool005Koool306KoB_ooo`030000oooooooo00Woool00`1Voooo
ooooo`1^oooo001Doooo0P1Vodgoool00`000?ooooooo`0:oooo00<0I_ooooooool0KOooo`00D?oo
o`@0I_m?oooo00<0003oooooool02oooo`0306Kooooooooo06coool004Soool806KoDoooo`030000
oooooooo00coool00`1Vooooooooo`1[oooo000moooo2`1Voe_oool00`000?ooooooo`0=oooo00<0
I_ooooooool0J_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oool0000040000003<ol00000<ol000Pco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool00oooo`05o`2Ioooooooooooo000000[oool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0E
oooo000Zoooo00<0003oooooool09_ooo`030000oooooooo02Goool00`000?ooooooo`06oooo1000
01/co`000`000?ooooooo`0Uoooo00<0003oooooool03Oooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`0Yoooo0028oooo100001Lco`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00S?oo
o`030000<ol0<ol001@co`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00SOooo`80000D
<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000A<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo04;oool0093oool00`0003?o03?o000@<ol00P0003Koool0
0ol0VOooooooo`12oooo002Aoooo0P00010co`000`000?ooooooo`0eoooo00?o09Woooooool0@_oo
o`00Toooo`030000<ol0<ol000dco`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00Tooo
o`030000<ol0<ol000dco`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00U?ooo`030000
<ol0<ol000`co`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00U?ooo`030000<ol0<ol0
00`co`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00UOooo`030000<ol0<ol000/co`02
0000=_ooo`03o`2Ioooooooo04;oool009Goool00`0003?o03?o000;<ol000<0003oooooool0=Ooo
o`03o`2Ioooooooo04;oool009Koool00`0003?o03?o000:<ol000<0003oooooool0=Oooo`03o`2I
oooooooo04;oool009Koool00`0003?o03?o000:<ol000<0003oooooool0=Oooo`03o`2Ioooooooo
04;oool009Ooool00`0003?o03?o0009<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04;oool0
09Ooool00`0003?o03?o0009<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04;oool009Soool0
0`0003?o03?o0008<ol00P0003Koool00ol0VOooooooo`12oooo002Hoooo00<0000co`0co`0023?o
00030000oooooooo03Goool00ol0VOooooooo`12oooo002Hoooo00<0000co`0co`0023?o00030000
oooooooo03Goool00ol0VOooooooo`12oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo
03Goool00ol0VOooooooo`12oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo03Goool0
0ol0VOooooooo`12oooo002Ioooo00<0000co`0co`001c?o00030000oooooooo03Goool00ol0VOoo
ooooo`12oooo002Ioooo00<0000co`0co`001c?o0080000foooo00?o09Woooooool0@_ooo`00V_oo
o`030000<ol0<ol000Hco`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00V_ooo`030000
<ol0<ol000Hco`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00V_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00V_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00Voooo`D00003<ol000<0003oooooool0=Ooo
o`03o`2Ioooooooo04;oool009_oool00`0003?o00000005<ol000<0003oooooool0=Oooo`03o`2I
oooooooo04;oool009_oool00`0003?o00000005<ol00`0003Goool00ol0VOooooooo`12oooo002L
oooo0P0000Dco`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00W?ooo`800005<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo04;oool009coool200001C?o00030000oooooooo03Goool0
0ol0VOooooooo`12oooo002Loooo00<0000co`0co`0013?o00030000oooooooo03Goool00ol0VOoo
ooooo`12oooo002Loooo00<0000co`0co`0013?o00030000oooooooo03Goool00ol0VOooooooo`12
oooo002Loooo00<0000co`0co`0013?o0080000foooo00?o09Woooooool0@_ooo`00WOooo`030000
<ol0<ol000<co`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00WOooo`030000<ol0<ol0
00<co`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00WOooo`030000<ol0<ol000<co`00
0`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00WOooo`030000<ol0<ol000<co`000`000?oo
ooooo`0eoooo00?o09Woooooool0@_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0e
oooo00?o09Woooooool0@_ooo`00WOooo`030000<ol0<ol000<co`020000=_ooo`03o`2Ioooooooo
04;oool009goool00`0003?o03?o0003<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04;oool0
09goool00`0003?o03?o0003<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04;oool009koool0
0`0003?o03?o0002<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04;oool009koool00`0003?o
03?o0002<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04;oool009koool00`0003?o03?o0002
<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04;oool009koool00`0003?o03?o0002<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo04;oool009koool00`0003?o03?o0002<ol00P0003Koool0
0ol0VOooooooo`12oooo002Noooo00<0000co`0co`000S?o00030000oooooooo03Goool00ol0VOoo
ooooo`12oooo002Noooo00<0000co`0co`000S?o00030000oooooooo03Goool00ol0VOooooooo`12
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo03Goool00ol0VOooooooo`12oooo002N
oooo00<0000co`0co`000S?o00030000oooooooo03Goool00ol0VOooooooo`12oooo002Noooo00<0
000co`0co`000S?o00030000oooooooo03Goool00ol0VOooooooo`12oooo002Noooo00<0000co`0c
o`000S?o0080000foooo00?o09Woooooool0@_ooo`00Woooo`050000<ol0<ol0<ol0000003Ooool0
0ol0VOooooooo`12oooo002Ooooo00D0000co`0co`0co`000000=oooo`03o`2Ioooooooo04;oool0
09ooool01@0003?o03?o03?o0000000goooo00?o09Woooooool0@_ooo`00Voooo`D00003<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo04;oool009_oool01@000?ooooooooooo`000003<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo04;oool009coool010000?ooooooo`0000<co`030000=Ooo
o`03o`2Ioooooooo04;oool009goool00`000?ooo`000003<ol000<0003oooooool0=Oooo`03o`2I
oooooooo04;oool009_oool00`000?ooooooo`0200000c?o00030000oooooooo03Goool00ol0VOoo
ooooo`12oooo002Loooo0P000003oooo0000<ol0008co`000`000?ooooooo`0eoooo00?o09Wooooo
ool0@_ooo`00Woooo`050000<ol0<ol0<ol0000003Ooool00ol0VOooooooo`12oooo002Poooo00@0
000co`0co`00000goooo00?o09Woooooool0@_ooo`00X?ooo`030000<ol0<ol00080000foooo00?o
09Woooooool0@_ooo`00X?ooo`040000<ol0<ol00000=oooo`03o`2Ioooooooo04;oool00:3oool0
100003?o03?o000003Ooool00ol0VOooooooo`12oooo002Poooo00@0000co`0co`00000goooo00?o
09Woooooool0@_ooo`00X?ooo`040000<ol0<ol00000=oooo`03o`2Ioooooooo04;oool00:3oool0
100003?o03?o000003Ooool00ol0VOooooooo`12oooo002Poooo00@0000co`0co`00000goooo00?o
09Woooooool0@_ooo`00XOooo`040000<ol000000000=_ooo`03o`2Ioooooooo04;oool00:7oool0
0`0003?o0000000goooo00?o09Woooooool0@_ooo`00XOooo`030000<ol0000003Ooool00ol0VOoo
ooooo`12oooo002Qoooo00<0000co`000000=oooo`03o`2Ioooooooo04;oool00:7oool00`0003?o
0000000goooo00?o09Woooooool0@_ooo`00XOooo`030000<ol0000003Ooool00ol0VOooooooo`12
oooo002Qoooo00@0000co`000000000foooo00?o09Woooooool0@_ooo`00XOooo`030000<ol00000
03Ooool00ol0VOooooooo`12oooo002Qoooo00<0000co`000000=oooo`03o`2Ioooooooo04;oool0
0:7oool00`0003?o0000000goooo00?o09Woooooool0@_ooo`00XOooo`030000<ol0000003Ooool0
0ol0VOooooooo`12oooo002Qoooo00<0000co`000000=oooo`03o`2Ioooooooo04;oool00:7oool0
100003?o0000000003Koool00ol0VOooooooo`12oooo002Qoooo00<0000co`000000=oooo`03o`2I
oooooooo04;oool00:7oool00`0003?o0000000goooo00?o09Woooooool0@_ooo`00XOooo`030000
<ol0000003Ooool00ol0VOooooooo`12oooo002Loooo0P0000?oool00`0003?o0000000goooo00?o
09Woooooool0@_ooo`00Voooo`040000oooooooo00000_ooo`030000<ol0000003Ooool00ol0VOoo
ooooo`12oooo002Moooo00H0003oooooooooool0000co`030000=Oooo`03o`2Ioooooooo04;oool0
09koool01P000?ooooooo`0003?o000003Ooool00ol0VOooooooo`12oooo002Koooo00@0003ooooo
ool00002oooo00<0000co`000000=oooo`03o`2Ioooooooo04;oool009coool200001?ooo`80000g
oooo00?o09Woooooool0@_ooo`00X_ooo`80000goooo00?o09Woooooool0@_ooo`00X_ooo`80000g
oooo00?o09Woooooool0@_ooo`00X_ooo`80000goooo00?o09Woooooool0@_ooo`00X_ooo`<0000f
oooo00?o09Woooooool0@_ooo`00X_ooo`80000goooo00?o09Woooooool0@_ooo`00X_ooo`80000g
oooo00?o09Woooooool0@_ooo`00X_ooo`80000goooo00?o09Woooooool0@_ooo`00X_ooo`80000g
oooo00?o09Woooooool0@_ooo`00X_ooo`80000goooo00?o09Woooooool0@_ooo`00X_ooo`<0000f
oooo00?o09Woooooool0@_ooo`00X_ooo`80000goooo00?o09Woooooool0@_ooo`00X_ooo`80000g
oooo00?o09Woooooool0@_ooo`00X_ooo`80000goooo00?o09Woooooool0@_ooo`00X_ooo`80000g
oooo00?o09Woooooool0@_ooo`00X_ooo`80000goooo00?o09Woooooool0@_ooo`00X_ooo`<0000f
oooo00?o09Woooooool0@_ooo`00Xoooo`030000oooooooo03Goool00ol0VOooooooo`12oooo002S
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo04;oool00:?oool00`000?ooooooo`0eoooo00?o
09Woooooool0@_ooo`00Xoooo`030000oooooooo03Goool00ol0VOooooooo`12oooo002Soooo00<0
003oooooool0=Oooo`03o`2Ioooooooo04;oool00:?oool20000=_ooo`03o`2Ioooooooo04;oool0
0:?oool00`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00Xoooo`030000oooooooo03Goool0
0ol0VOooooooo`12oooo002Soooo00<0003oooooool0=Oooo`03o`2Ioooooooo04;oool00:?oool0
0`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00WOooo`<00003oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo04;oool009koool00`000?ooooooo`02oooo00<0003oooooool0=Oooo`03o`2I
oooooooo04;oool009_oool500000oooo`<0000eoooo00?o09Woooooool0@_ooo`00Voooo`040000
oooooooo0000POooo`00W?ooo`030000oooo0000087oool009goool20000POooo`00ooooob7oool0
0?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?oo
ooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001?ooo`800004oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001j
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo00@0003ooooo
ool00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003ooooo
ool02?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000017oool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79892 .12361 L
.80403 .12361 L
.80682 .12361 L
.80819 .12361 L
.80943 .12361 L
s
.80943 .12361 m
.80989 .61803 L
s
0 .4 1 r
.02381 .12335 m
.04262 .12324 L
.06244 .12309 L
.07286 .12298 L
.08255 .12286 L
.09388 .1227 L
.10458 .12251 L
.125 .12202 L
.14357 .1214 L
.16355 .12046 L
.18199 .11923 L
.20071 .1175 L
.21136 .11622 L
.22134 .11479 L
.24158 .11095 L
.26011 .106 L
.27909 .09892 L
.28984 .09371 L
.29982 .08789 L
.32034 .07212 L
.33895 .05188 L
.34382 .04537 L
.34649 .04156 L
.34779 .03964 L
.34897 .03785 L
.35006 .03751 L
.35109 .03753 L
.35337 .03759 L
.35819 .03771 L
.36829 .038 L
.37901 .03838 L
.39892 .03929 L
.41734 .04046 L
.43681 .04218 L
.45509 .04438 L
.47528 .04773 L
.49378 .05189 L
.51271 .05754 L
.53341 .0651 L
.57397 .07777 L
.58307 .07867 L
.58766 .07922 L
.59026 .07964 L
.5927 .08009 L
.5978 .08128 L
.60327 .08294 L
.61301 .08705 L
.61873 .09027 L
.62417 .09396 L
.63436 .1028 L
Mistroke
.64412 .11405 L
.64655 .11734 L
.64911 .12105 L
.64976 .12202 L
.65046 .12308 L
.65122 .12361 L
.65193 .12361 L
.65451 .12361 L
.65988 .12361 L
.66492 .12361 L
.67436 .12361 L
.69276 .12361 L
.73417 .12361 L
.77407 .12361 L
.81245 .12361 L
.85328 .12361 L
.8926 .12361 L
.9304 .12361 L
.97066 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00J?oooaD0I_lVoooo00<0003oooooool0N_ooo`00J?ooo`0306Kooooooooo
01;oool:06Ko7?ooo`030000oooooooo07[oool006Ooool00`1Vooooooooo`0Moooo101VoaSoool0
0`000?ooooooo`1joooo001Voooo00<0I_ooooooool08_ooo`@0I_lDoooo0P0007_oool006Goool0
0`1Vooooooooo`0Woooo0P1Voa;oool00`000?ooooooo`1joooo001Toooo00<0I_ooooooool0:_oo
o`<0I_l?oooo00<0003oooooool0N_ooo`00Hoooo`0306Kooooooooo02koool206Ko3Oooo`030000
oooooooo07[oool006;oool00`1Vooooooooo`0aoooo0`1Vo`[oool00`000?ooooooo`1joooo001Q
oooo00<0I_ooooooool0=Oooo`@0I_l6oooo00<0003oooooool0N_ooo`00H?ooo`0306Kooooooooo
03[oool406Ko0_ooo`80001koooo000[oooo0`0002Soool300001Oooo`80I_lLoooo1000027oool2
06Ko00@00000I_l0I_l0I_lRoooo100002Ooool30000:Oooo`00:oooo`040000oooooooo0000:?oo
o`030000oooooooo00?oool00`1Vooooooooo`0Loooo00<0003oooooool09?ooo`040000oooooooo
oooo101Voakoool00`000?ooooooo`0Yoooo00<0003oooooool0:?ooo`00:oooo`040000oooooooo
00009Oooo`D00003oooo00<0I_ooooooool07_ooo`030000oooooooo02?oool00`000?ooooooo`05
oooo0P1Voagoool00`000?ooooooo`0Uoooo1@0002Woool002Goool400000_ooo`<0000Poooo1000
00;oool010000?ooooooo`0000?oool00`1Vooooooooo`0Hoooo100000Coool00`000?ooooooo`0R
oooo00<0003oooooool01oooo`0306Kooooooooo01_oool00`000?ooooooo`0Toooo00@0003ooooo
ool0000Zoooo000/oooo00<0003oooooool09_ooo`040000oooo0000oooo0P1Vob7oool010000?oo
ooooo`0002?oool00`000?ooooooo`08oooo00<0I_ooooooool06?ooo`040000oooooooo00009_oo
o`030000oooo000002[oool002coool300009oooo`8000000`1Vooooooooo`0Roooo0P0002Coool2
00002_ooo`80I_lIoooo0P0002Soool20000:_ooo`00E?ooo`80I_m=oooo00<0003oooooool02ooo
o`0306Kooooooooo06coool0053oool406KoCoooo`030000oooooooo00coool00`1Vooooooooo`1[
oooo001;oooo1@1Voe?oool00`000?ooooooo`0=oooo00<0I_ooooooool0J_ooo`00B?ooo`<0I_mH
oooo00<0003oooooool03_ooo`0306Kooooooooo06Woool003goool;06KoFoooo`030000oooooooo
00koool00`1Vooooooooo`1Yoooo000@ooooo`00017oool001Koool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`05oooo00?o09Woool000002_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
01Goool002[oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo00Koool4
00006c?o00030000oooooooo02Goool00`000?ooooooo`0?oooo00?o09Woooooool05?ooo`030000
oooooooo02Woool008Soool400005c?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002<
oooo00<0000co`0co`0053?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002=oooo0P00
01@co`000`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00T?ooo`030000<ol0<ol0010co`020000>?oo
o`03o`2Ioooooooo043oool0097oool2000043?o00030000oooooooo03Ooool00ol0VOooooooo`10
oooo002Coooo00<0000co`0co`003C?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002C
oooo00<0000co`0co`003C?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Doooo00<0
000co`0co`0033?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Doooo00<0000co`0c
o`0033?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Eoooo00<0000co`0co`002c?o
0080000hoooo00?o09Woooooool0@?ooo`00UOooo`030000<ol0<ol000/co`000`000?ooooooo`0g
oooo00?o09Woooooool0@?ooo`00U_ooo`030000<ol0<ol000Xco`000`000?ooooooo`0goooo00?o
09Woooooool0@?ooo`00U_ooo`030000<ol0<ol000Xco`000`000?ooooooo`0goooo00?o09Wooooo
ool0@?ooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`0goooo00?o09Woooooool0@?oo
o`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00V?oo
o`030000<ol0<ol000Pco`020000>?ooo`03o`2Ioooooooo043oool009Soool00`0003?o03?o0008
<ol000<0003oooooool0=oooo`03o`2Ioooooooo043oool009Soool00`0003?o03?o0008<ol000<0
003oooooool0=oooo`03o`2Ioooooooo043oool009Woool00`0003?o03?o0007<ol000<0003ooooo
ool0=oooo`03o`2Ioooooooo043oool009Woool00`0003?o03?o0007<ol000<0003oooooool0=ooo
o`03o`2Ioooooooo043oool009Woool00`0003?o03?o0007<ol000<0003oooooool0=oooo`03o`2I
oooooooo043oool009Woool00`0003?o03?o0007<ol00P0003Soool00ol0VOooooooo`10oooo002J
oooo00<0000co`0co`001S?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Joooo00<0
000co`0co`001S?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Joooo00<0000co`0c
o`001S?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Joooo00<0000co`0co`001S?o
00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Koooo1@0000<co`000`000?ooooooo`0g
oooo00?o09Woooooool0@?ooo`00Voooo`030000<ol0000000Dco`000`000?ooooooo`0goooo00?o
09Woooooool0@?ooo`00Voooo`030000<ol0000000Dco`030000=oooo`03o`2Ioooooooo043oool0
09coool200001C?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Loooo0P0000Dco`00
0`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00W?ooo`800005<ol000<0003oooooool0=ooo
o`03o`2Ioooooooo043oool009coool00`0003?o03?o0004<ol000<0003oooooool0=oooo`03o`2I
oooooooo043oool009coool00`0003?o03?o0004<ol000<0003oooooool0=oooo`03o`2Ioooooooo
043oool009coool00`0003?o03?o0004<ol00P0003Soool00ol0VOooooooo`10oooo002Moooo00<0
000co`0co`000c?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Moooo00<0000co`0co`000c?o
00030000oooooooo03Ooool00ol0VOooooooo`10oooo002Moooo00<0000co`0co`000c?o00030000
oooooooo03Ooool00ol0VOooooooo`10oooo002Moooo00<0000co`0co`000c?o00030000oooooooo
03Ooool00ol0VOooooooo`10oooo002Moooo00<0000co`0co`000c?o0080000hoooo00?o09Wooooo
ool0@?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0goooo00?o09Woooooool0@?oo
o`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00W_ooo`030000<ol0<ol0008co`020000>?oo
o`03o`2Ioooooooo043oool009koool00`0003?o03?o0002<ol000<0003oooooool0=oooo`03o`2I
oooooooo043oool009koool00`0003?o03?o0002<ol000<0003oooooool0=oooo`03o`2Ioooooooo
043oool009koool00`0003?o03?o0002<ol000<0003oooooool0=oooo`03o`2Ioooooooo043oool0
09koool00`0003?o03?o0002<ol000<0003oooooool0=oooo`03o`2Ioooooooo043oool009koool0
0`0003?o03?o0002<ol000<0003oooooool0=oooo`03o`2Ioooooooo043oool009koool00`0003?o
03?o0002<ol00P0003Soool00ol0VOooooooo`10oooo002Ooooo00D0000co`0co`0co`000000>Ooo
o`03o`2Ioooooooo043oool009ooool01@0003?o03?o03?o0000000ioooo00?o09Woooooool0@?oo
o`00Woooo`050000<ol0<ol0<ol0000003Woool00ol0VOooooooo`10oooo002Koooo1@0000<co`00
0`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00Voooo`050000oooooooooooo000000<co`00
0`000?ooooooo`0goooo00?o09Woooooool0@?ooo`00W?ooo`040000oooooooo00000c?o00<0000g
oooo00?o09Woooooool0@?ooo`00WOooo`030000oooo000000<co`000`000?ooooooo`0hoooo00?o
09Woooooool0?oooo`00Voooo`030000oooooooo00800003<ol000<0003oooooool0>?ooo`03o`2I
oooooooo03ooool009coool2000000?oool0000co`000S?o00030000oooooooo03Soool00ol0VOoo
ooooo`0ooooo002Ooooo00D0000co`0co`0co`000000>_ooo`03o`2Ioooooooo03ooool00:3oool0
100003?o03?o000003[oool00ol0VOooooooo`0ooooo002Poooo00<0000co`0co`000P0003Woool0
0ol0VOooooooo`0ooooo002Poooo00@0000co`0co`00000joooo00?o09Woooooool0?oooo`00X?oo
o`040000<ol0<ol00000>_ooo`03o`2Ioooooooo03ooool00:3oool0100003?o03?o000003[oool0
0ol0VOooooooo`0ooooo002Poooo00@0000co`0co`00000joooo00?o09Woooooool0?oooo`00X?oo
o`040000<ol0<ol00000>_ooo`03o`2Ioooooooo03ooool00:3oool0100003?o03?o000003[oool0
0ol0VOooooooo`0ooooo002Qoooo00@0000co`000000000ioooo00?o09Woooooool0?oooo`00XOoo
o`030000<ol0000003[oool00ol0VOooooooo`0ooooo002Qoooo00<0000co`000000>_ooo`03o`2I
oooooooo03ooool00:7oool00`0003?o0000000joooo00?o09Woooooool0?oooo`00XOooo`030000
<ol0000003[oool00ol0VOooooooo`0ooooo002Qoooo00<0000co`000000>_ooo`03o`2Ioooooooo
03ooool00:7oool0100003?o0000000003Woool00ol0VOooooooo`0ooooo002Qoooo00<0000co`00
0000>_ooo`03o`2Ioooooooo03ooool00:7oool00`0003?o0000000joooo00?o09Woooooool0?ooo
o`00XOooo`030000<ol0000003[oool00ol0VOooooooo`0ooooo002Qoooo00<0000co`000000>_oo
o`03o`2Ioooooooo03ooool00:7oool00`0003?o0000000joooo00?o09Woooooool0?oooo`00XOoo
o`040000<ol000000000>Oooo`03o`2Ioooooooo03ooool00:7oool00`0003?o0000000joooo00?o
09Woooooool0?oooo`00XOooo`030000<ol0000003[oool00ol0VOooooooo`0ooooo002Qoooo00<0
000co`000000>_ooo`03o`2Ioooooooo03ooool009coool200000oooo`030000<ol0000003[oool0
0ol0VOooooooo`0ooooo002Koooo00@0003oooooool00002oooo00<0000co`000000>_ooo`03o`2I
oooooooo03ooool009goool01P000?ooooooooooo`0003?o00<0000hoooo00?o09Woooooool0?ooo
o`00W_ooo`060000oooooooo0000<ol00000>_ooo`03o`2Ioooooooo03ooool009_oool010000?oo
ooooo`0000;oool00`0003?o0000000joooo00?o09Woooooool0?oooo`00W?ooo`800004oooo0P00
03[oool00ol0VOooooooo`0ooooo002Roooo0P0003[oool00ol0VOooooooo`0ooooo002Roooo0P00
03[oool00ol0VOooooooo`0ooooo002Roooo0P0003[oool00ol0VOooooooo`0ooooo002Roooo0`00
03Woool00ol0VOooooooo`0ooooo002Roooo0P0003[oool00ol0VOooooooo`0ooooo002Roooo0P00
03[oool00ol0VOooooooo`0ooooo002Roooo0P0003[oool00ol0VOooooooo`0ooooo002Roooo0P00
03[oool00ol0VOooooooo`0ooooo002Roooo0P0003[oool00ol0VOooooooo`0ooooo002Roooo0`00
03Woool00ol0VOooooooo`0ooooo002Roooo0P0003[oool00ol0VOooooooo`0ooooo002Roooo0P00
03[oool00ol0VOooooooo`0ooooo002Roooo0P0003[oool00ol0VOooooooo`0ooooo002Roooo0P00
03[oool00ol0VOooooooo`0ooooo002Roooo0P0003[oool00ol0VOooooooo`0ooooo002Roooo0`00
03Woool00ol0VOooooooo`0ooooo002Soooo00<0003oooooool0>?ooo`03o`2Ioooooooo03ooool0
0:?oool00`000?ooooooo`0hoooo00?o09Woooooool0?oooo`00Xoooo`030000oooooooo03Soool0
0ol0VOooooooo`0ooooo002Soooo00<0003oooooool0>?ooo`03o`2Ioooooooo03ooool00:?oool0
0`000?ooooooo`0hoooo00?o09Woooooool0?oooo`00Xoooo`80000ioooo00?o09Woooooool0?ooo
o`00Xoooo`030000oooooooo03Soool00ol0VOooooooo`0ooooo002Soooo00<0003oooooool0>?oo
o`03o`2Ioooooooo03ooool00:?oool00`000?ooooooo`0hoooo00?o09Woooooool0?oooo`00Xooo
o`030000oooooooo03Soool00ol0VOooooooo`0ooooo002Moooo0`0000?oool00`000?ooooooo`0h
oooo00?o09Woooooool0?oooo`00W_ooo`030000oooooooo00;oool00`000?ooooooo`0hoooo00?o
09Woooooool0?oooo`00Voooo`D00003oooo0`0003Soool00ol0VOooooooo`0ooooo002Koooo00@0
003oooooool00021oooo002Loooo00<0003oool00000POooo`00WOooo`800021oooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800003oooo0`0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`07oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001j
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`08oooo0`0000Coool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000017oool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79892 .12361 L
.80403 .12361 L
.80943 .12361 L
.81404 .12361 L
.8153 .12361 L
.81599 .12361 L
.81665 .12361 L
s
.81665 .12361 m
.81716 .61803 L
s
0 .4 1 r
.02381 .12331 m
.04262 .12319 L
.06244 .12301 L
.07286 .12289 L
.08255 .12275 L
.09388 .12256 L
.10458 .12234 L
.125 .12178 L
.14357 .12106 L
.16355 .11997 L
.18199 .11856 L
.20071 .11656 L
.21136 .11509 L
.22134 .11343 L
.24158 .10901 L
.26011 .10331 L
.27909 .09513 L
.28984 .08912 L
.29982 .08242 L
.32034 .06423 L
.32939 .05384 L
.33433 .04742 L
.33895 .04088 L
.34013 .03912 L
.34125 .03741 L
.34255 .03742 L
.34373 .03744 L
.34897 .03756 L
.35819 .0378 L
.36829 .03812 L
.37901 .03851 L
.39892 .03949 L
.41734 .04074 L
.43681 .04256 L
.45509 .04492 L
.47528 .0485 L
.49378 .05297 L
.53341 .06651 L
.54368 .07018 L
.55337 .07333 L
.55796 .07466 L
.56281 .0759 L
.56731 .07686 L
.57151 .07756 L
.57367 .07782 L
.57479 .07793 L
.576 .07802 L
.57732 .07809 L
.57857 .07813 L
.57979 .07814 L
Mistroke
.58092 .07814 L
.58157 .07815 L
.58226 .07817 L
.58352 .0782 L
.58474 .07824 L
.58587 .0783 L
.58842 .07845 L
.59113 .07869 L
.59362 .07896 L
.5963 .07933 L
.60112 .08019 L
.60685 .08158 L
.61208 .08324 L
.62201 .0876 L
.6312 .0933 L
.64128 .10179 L
.65197 .11394 L
.65655 .12031 L
.65767 .12197 L
.65885 .12361 L
.66016 .12361 L
.66137 .12361 L
.66665 .12361 L
.67148 .12361 L
.68978 .12361 L
.73133 .12361 L
.77136 .12361 L
.80988 .12361 L
.85085 .12361 L
.8903 .12361 L
.92824 .12361 L
.96864 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00I_oooaL0I_lVoooo00<0003oooooool0N_ooo`00IOooo`0306Kooooooooo
01Goool:06Ko7?ooo`030000oooooooo07[oool006Goool00`1Vooooooooo`0Ooooo101VoaSoool0
0`000?ooooooo`1joooo001Toooo00<0I_ooooooool09?ooo`@0I_lDoooo0P0007_oool006Coool0
0`1Vooooooooo`0Xoooo0P1Voa;oool00`000?ooooooo`1joooo001Roooo0P1Vobgoool306Ko3ooo
o`030000oooooooo07[oool0067oool00`1Vooooooooo`0`oooo0P1Vo`goool00`000?ooooooo`1j
oooo001Poooo00<0I_ooooooool0<oooo`<0I_l:oooo00<0003oooooool0N_ooo`00Goooo`0306Ko
oooooooo03Ooool306Ko1oooo`030000oooooooo07[oool005koool00`1Vooooooooo`0koooo101V
o`?oool20000Noooo`00:oooo`<0000Xoooo0`0000Coool00`1Vooooooooo`0Loooo1000023oool3
06Ko00<00000I_l0I_l0101Voaooool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00<0003oooooool00_ooo`0306Kooooooooo01goool00`000?ooooooo`0Toooo00<0003ooooo
ool01?ooo`<0I_lLoooo00<0003oooooool0:Oooo`030000oooooooo02Soool002_oool010000?oo
ooooo`0002Goool500000_ooo`0306Kooooooooo01ooool00`000?ooooooo`0Soooo00<0003ooooo
ool01oooo`80I_lKoooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo100000;oool300008?oo
o`@00002oooo00D0003oooooool0003oool00P1Voa_oool400001?ooo`030000oooooooo02;oool0
0`000?ooooooo`09oooo00<0I_ooooooool06Oooo`030000oooooooo02Coool010000?ooooooo`00
02[oool002coool00`000?ooooooo`0Voooo00@00000I_l00000I_lSoooo00@0003oooooool0000S
oooo00<0003oooooool02_ooo`0306Kooooooooo01Koool010000?ooooooo`0002Koool00`000?oo
o`00000Zoooo000/oooo0`0002Goool206Ko0P0002Goool200009?ooo`80000<oooo0P1VoaOoool2
0000:?ooo`80000Zoooo001Aoooo0`1Vodooool00`000?ooooooo`0=oooo00<0I_ooooooool0J_oo
o`00Coooo`80I_mBoooo00<0003oooooool03_ooo`0306Kooooooooo06Woool004_oool406KoE?oo
o`030000oooooooo00ooool00`1Vooooooooo`1Xoooo0015oooo1P1VoeSoool00`000?ooooooo`0@
oooo00<0I_ooooooool0Ioooo`00>?ooo`d0I_mNoooo00<0003oooooool04?ooo`0306Kooooooooo
06Ooool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooo0000
010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000
oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_ooo`@0000K<ol000<0003ooooo
ool09Oooo`030000oooooooo017oool00ol0VOooooooo`0Boooo00<0003oooooool0:Oooo`00R?oo
o`@0000G<ol000<0003oooooool0>Oooo`03o`2Ioooooooo03koool008coool00`0003?o03?o000D
<ol000<0003oooooool0>Oooo`03o`2Ioooooooo03koool008goool2000053?o00030000oooooooo
03Woool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`004C?o00030000oooooooo03Woool0
0ol0VOooooooo`0noooo002@oooo00<0000co`0co`0043?o0080000joooo00?o09Woooooool0?_oo
o`00TOooo`80000@<ol000<0003oooooool0>Oooo`03o`2Ioooooooo03koool009?oool00`0003?o
03?o000=<ol000<0003oooooool0>Oooo`03o`2Ioooooooo03koool009?oool00`0003?o03?o000=
<ol000<0003oooooool0>Oooo`03o`2Ioooooooo03koool009Coool00`0003?o03?o000<<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo03koool009Coool00`0003?o03?o000<<ol000<0003ooooo
ool0>Oooo`03o`2Ioooooooo03koool009Goool00`0003?o03?o000;<ol00P0003[oool00ol0VOoo
ooooo`0noooo002Eoooo00<0000co`0co`002c?o00030000oooooooo03Woool00ol0VOooooooo`0n
oooo002Foooo00<0000co`0co`002S?o00030000oooooooo03Woool00ol0VOooooooo`0noooo002F
oooo00<0000co`0co`002S?o00030000oooooooo03Woool00ol0VOooooooo`0noooo002Goooo00<0
000co`0co`002C?o00030000oooooooo03Woool00ol0VOooooooo`0noooo002Goooo00<0000co`0c
o`002C?o00030000oooooooo03Woool00ol0VOooooooo`0noooo002Hoooo00<0000co`0co`0023?o
0080000joooo00?o09Woooooool0?_ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0i
oooo00?o09Woooooool0?_ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0ioooo00?o
09Woooooool0?_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0ioooo00?o09Wooooo
ool0?_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0ioooo00?o09Woooooool0?_oo
o`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00VOoo
o`030000<ol0<ol000Lco`020000>_ooo`03o`2Ioooooooo03koool009[oool00`0003?o03?o0006
<ol000<0003oooooool0>Oooo`03o`2Ioooooooo03koool009[oool00`0003?o03?o0006<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo03koool009[oool00`0003?o03?o0006<ol000<0003ooooo
ool0>Oooo`03o`2Ioooooooo03koool009[oool00`0003?o03?o0006<ol000<0003oooooool0>Ooo
o`03o`2Ioooooooo03koool009_oool500000c?o00030000oooooooo03Woool00ol0VOooooooo`0n
oooo002Koooo00<0000co`0000001C?o00030000oooooooo03Woool00ol0VOooooooo`0noooo002K
oooo00<0000co`0000001C?o00<0000ioooo00?o09Woooooool0?_ooo`00W?ooo`800005<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo03koool009coool200001C?o00030000oooooooo03Woool0
0ol0VOooooooo`0noooo002Loooo0P0000Dco`000`000?ooooooo`0ioooo00?o09Woooooool0?_oo
o`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00W?oo
o`030000<ol0<ol000@co`000`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00W?ooo`030000
<ol0<ol000@co`020000>_ooo`03o`2Ioooooooo03koool009goool00`0003?o03?o0003<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo03koool009goool00`0003?o03?o0003<ol000<0003ooooo
ool0>Oooo`03o`2Ioooooooo03koool009goool00`0003?o03?o0003<ol000<0003oooooool0>Ooo
o`03o`2Ioooooooo03koool009goool00`0003?o03?o0003<ol000<0003oooooool0>Oooo`03o`2I
oooooooo03koool009goool00`0003?o03?o0003<ol000<0003oooooool0>Oooo`03o`2Ioooooooo
03koool009goool00`0003?o03?o0003<ol00P0003[oool00ol0VOooooooo`0noooo002Moooo00<0
000co`0co`000c?o00030000oooooooo03Woool00ol0VOooooooo`0noooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo03Woool00ol0VOooooooo`0noooo002Noooo00<0000co`0co`000S?o
00030000oooooooo03Woool00ol0VOooooooo`0noooo002Noooo00<0000co`0co`000S?o00030000
oooooooo03Woool00ol0VOooooooo`0noooo002Noooo00<0000co`0co`000S?o00030000oooooooo
03Woool00ol0VOooooooo`0noooo002Noooo00<0000co`0co`000S?o00030000oooooooo03Woool0
0ol0VOooooooo`0noooo002Noooo00<0000co`0co`000S?o0080000joooo00?o09Woooooool0?_oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00W_ooo`030000<ol0<ol0008co`020000>_oo
o`03o`2Ioooooooo03koool009ooool01@0003?o03?o03?o0000000koooo00?o09Woooooool0?_oo
o`00Woooo`050000<ol0<ol0<ol0000003_oool00ol0VOooooooo`0noooo002Ooooo00D0000co`0c
o`0co`000000>oooo`03o`2Ioooooooo03koool009_oool500000c?o00030000oooooooo03Woool0
0ol0VOooooooo`0noooo002Koooo00D0003oooooooooool000000c?o00030000oooooooo03Woool0
0ol0VOooooooo`0noooo002Loooo00@0003oooooool00003<ol00`0003Woool00ol0VOooooooo`0n
oooo002Moooo00<0003oool000000c?o00030000oooooooo03Woool00ol0VOooooooo`0noooo002K
oooo00<0003oooooool00P0000<co`000`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00W?oo
o`8000000oooo`0003?o0002<ol000<0003oooooool0>Oooo`03o`2Ioooooooo03koool009ooool0
1@0003?o03?o03?o0000000koooo00?o09Woooooool0?_ooo`00X?ooo`040000<ol0<ol00000>ooo
o`03o`2Ioooooooo03koool00:3oool00`0003?o03?o00020000>_ooo`03o`2Ioooooooo03koool0
0:3oool0100003?o03?o000003_oool00ol0VOooooooo`0noooo002Poooo00@0000co`0co`00000k
oooo00?o09Woooooool0?_ooo`00X?ooo`040000<ol0<ol00000>oooo`03o`2Ioooooooo03koool0
0:3oool0100003?o03?o000003_oool00ol0VOooooooo`0noooo002Poooo00@0000co`0co`00000k
oooo00?o09Woooooool0?_ooo`00X?ooo`040000<ol0<ol00000>oooo`03o`2Ioooooooo03koool0
0:7oool0100003?o0000000003[oool00ol0VOooooooo`0noooo002Qoooo00<0000co`000000>ooo
o`03o`2Ioooooooo03koool00:7oool00`0003?o0000000koooo00?o09Woooooool0?_ooo`00XOoo
o`030000<ol0000003_oool00ol0VOooooooo`0noooo002Qoooo00<0000co`000000>oooo`03o`2I
oooooooo03koool00:7oool00`0003?o0000000koooo00?o09Woooooool0?_ooo`00XOooo`040000
<ol000000000>_ooo`03o`2Ioooooooo03koool00:7oool00`0003?o0000000koooo00?o09Wooooo
ool0?_ooo`00XOooo`030000<ol0000003_oool00ol0VOooooooo`0noooo002Qoooo00<0000co`00
0000>oooo`03o`2Ioooooooo03koool00:7oool00`0003?o0000000koooo00?o09Woooooool0?_oo
o`00XOooo`030000<ol0000003_oool00ol0VOooooooo`0noooo002Qoooo00@0000co`000000000j
oooo00?o09Woooooool0?_ooo`00XOooo`030000<ol0000003_oool00ol0VOooooooo`0noooo002Q
oooo00<0000co`000000>oooo`03o`2Ioooooooo03koool00:7oool00`0003?o0000000koooo00?o
09Woooooool0?_ooo`00W?ooo`800003oooo00<0000co`000000>oooo`03o`2Ioooooooo03koool0
09_oool010000?ooooooo`0000;oool00`0003?o0000000koooo00?o09Woooooool0?_ooo`00WOoo
o`060000oooooooooooo0000<ol00`0003Woool00ol0VOooooooo`0noooo002Noooo00H0003ooooo
ool0000co`00000koooo00?o09Woooooool0?_ooo`00Voooo`040000oooooooo00000_ooo`030000
<ol0000003_oool00ol0VOooooooo`0noooo002Loooo0P0000Coool20000>oooo`03o`2Ioooooooo
03koool00:;oool20000>oooo`03o`2Ioooooooo03koool00:;oool20000>oooo`03o`2Ioooooooo
03koool00:;oool20000>oooo`03o`2Ioooooooo03koool00:;oool30000>_ooo`03o`2Ioooooooo
03koool00:;oool20000>oooo`03o`2Ioooooooo03koool00:;oool20000>oooo`03o`2Ioooooooo
03koool00:;oool20000>oooo`03o`2Ioooooooo03koool00:;oool20000>oooo`03o`2Ioooooooo
03koool00:;oool20000>oooo`03o`2Ioooooooo03koool00:;oool30000>_ooo`03o`2Ioooooooo
03koool00:;oool20000>oooo`03o`2Ioooooooo03koool00:;oool20000>oooo`03o`2Ioooooooo
03koool00:;oool20000>oooo`03o`2Ioooooooo03koool00:;oool20000>oooo`03o`2Ioooooooo
03koool00:;oool20000>oooo`03o`2Ioooooooo03koool00:;oool30000>_ooo`03o`2Ioooooooo
03koool00:?oool00`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00Xoooo`030000oooooooo
03Woool00ol0VOooooooo`0noooo002Soooo00<0003oooooool0>Oooo`03o`2Ioooooooo03koool0
0:?oool00`000?ooooooo`0ioooo00?o09Woooooool0?_ooo`00Xoooo`030000oooooooo03Woool0
0ol0VOooooooo`0noooo002Soooo0P0003[oool00ol0VOooooooo`0noooo002Soooo00<0003ooooo
ool0>Oooo`03o`2Ioooooooo03koool00:?oool00`000?ooooooo`0ioooo00?o09Woooooool0?_oo
o`00Xoooo`030000oooooooo03Woool00ol0VOooooooo`0noooo002Soooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo03koool009goool300000oooo`030000oooooooo03Woool00ol0VOooooooo`0n
oooo002Noooo00<0003oooooool00_ooo`030000oooooooo03Woool00ol0VOooooooo`0noooo002K
oooo1@0000?oool30000>Oooo`03o`2Ioooooooo03koool009_oool010000?ooooooo`00087oool0
09coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00Oooo
o`030000oooooooo01coool00`000?ooooooo`1ooooo001noooo00<0003oooooool02?ooo`030000
oooooooo01?oool00`000?ooooooo`1noooo001noooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`@00003oooo0P0000Coool00`000?ooooooo`1noooo001noooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02_oo
o`030000oooooooo07koool007goool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000
oooooooo00[oool00`000?ooooooo`1moooo001noooo00<0003oooooool01@0000koool00`000?oo
ooooo`08oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Woool00`000?ooooooo`1noooo001ooooo00<0003oooooool04Oooo`800009oooo00<0
003oooooool0Ooooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.80799 .12361 L
.81373 .12361 L
.81909 .12361 L
.82156 .12361 L
.8239 .12361 L
.82518 .12361 L
s
.82518 .12361 m
.82548 .61803 L
s
0 .4 1 r
.02381 .12326 m
.04262 .12312 L
.06244 .12292 L
.07286 .12277 L
.08255 .12262 L
.09388 .1224 L
.10458 .12214 L
.125 .1215 L
.14357 .12067 L
.16355 .11942 L
.18199 .11779 L
.20071 .11549 L
.21136 .11379 L
.22134 .11188 L
.24158 .10678 L
.26011 .1002 L
.27909 .09078 L
.28984 .08385 L
.29982 .07612 L
.31861 .05722 L
.3285 .04443 L
.33091 .04097 L
.33223 .039 L
.33348 .03732 L
.33419 .03733 L
.33496 .03735 L
.33631 .03738 L
.33895 .03743 L
.3501 .0377 L
.36036 .038 L
.38053 .03877 L
.4003 .03984 L
.41029 .04053 L
.42131 .04145 L
.44066 .04356 L
.46152 .04674 L
.48156 .05103 L
.50266 .05726 L
.54076 .07071 L
.55085 .07387 L
.56037 .07632 L
.56564 .07736 L
.56861 .07781 L
.57003 .07799 L
.57135 .07813 L
.57256 .07823 L
.57366 .07831 L
.57488 .07837 L
.5762 .0784 L
.57745 .07841 L
Mistroke
.57817 .07839 L
.57883 .07837 L
.58132 .07826 L
.58262 .07821 L
.58332 .07819 L
.58398 .07817 L
.58514 .07815 L
.58642 .07814 L
.58713 .07813 L
.58781 .07814 L
.58907 .07815 L
.58978 .07816 L
.59044 .07817 L
.59192 .07821 L
.59311 .07826 L
.59422 .07832 L
.59676 .07848 L
.59923 .0787 L
.60189 .079 L
.60663 .07972 L
.61161 .08076 L
.61586 .08189 L
.62051 .08342 L
.63081 .08806 L
.64016 .09404 L
.65095 .10352 L
.65579 .10884 L
.66112 .11555 L
.66355 .11894 L
.66489 .1209 L
.66616 .12282 L
.66734 .12361 L
.66862 .12361 L
.67087 .12361 L
.68117 .12361 L
.69964 .12361 L
.74039 .12361 L
.77962 .12361 L
.81734 .12361 L
.85751 .12361 L
.89617 .12361 L
.93727 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00I?oooaH0I_lYoooo00<0003oooooool0N_ooo`00Hoooo`0306Kooooooooo
01Coool906Ko8?ooo`030000oooooooo07[oool006;oool00`1Vooooooooo`0Noooo1@1Voa_oool0
0`000?ooooooo`1joooo001Roooo00<0I_ooooooool08oooo`@0I_lGoooo0P0007_oool0067oool0
0`1Vooooooooo`0Xoooo0`1VoaCoool00`000?ooooooo`1joooo001Qoooo00<0I_ooooooool0:ooo
o`<0I_lAoooo00<0003oooooool0N_ooo`00H?ooo`0306Kooooooooo02ooool306Ko3_ooo`030000
oooooooo07[oool005koool206Ko=Oooo`<0I_l;oooo00<0003oooooool0N_ooo`00GOooo`0306Ko
oooooooo03Soool306Ko2?ooo`030000oooooooo07[oool005coool00`1Vooooooooo`0loooo101V
o`Coool20000Noooo`00:oooo`<0000Xoooo0`0000;oool00`1Vooooooooo`0Noooo100001ooool4
06Ko00<00000I_l0I_l01@1Voakoool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000X
oooo00@0003oooooool0I_lQoooo00<0003oooooool09?ooo`030000oooooooo00Goool406Ko6_oo
o`030000oooooooo02Woool00`000?ooooooo`0Xoooo000[oooo00@0003oooooool0000Uoooo1@00
000306Kooooooooo027oool00`000?ooooooo`0Soooo00<0003oooooool02Oooo`80I_lIoooo00<0
003oooooool09Oooo`D0000Yoooo000Uoooo100000;oool300008?ooo`@00002oooo00@0003oool0
I_l0000Noooo100000Coool00`000?ooooooo`0Roooo00<0003oooooool02oooo`80I_lHoooo00<0
003oooooool09?ooo`040000oooooooo0000:_ooo`00;?ooo`030000oooooooo02Goool0101Vo`00
0?ooo`0002Coool010000?ooooooo`0002?oool00`000?ooooooo`0=oooo00<0I_ooooooool04ooo
o`040000oooooooo00009_ooo`030000oooo000002[oool002coool300008_ooo`<0I_l2oooo0P00
02Goool200009?ooo`80000?oooo00<0I_ooooooool04oooo`80000Xoooo0P0002[oool004ooool2
06KoD_ooo`030000oooooooo00ooool00`1Vooooooooo`1Xoooo001;oooo101VoeCoool00`000?oo
ooooo`0?oooo00<0I_ooooooool0J?ooo`00B?ooo`<0I_mHoooo00<0003oooooool04?ooo`0306Ko
oooooooo06Ooool0047oool706KoFoooo`030000oooooooo017oool206KoIoooo`00>?ooo`T0I_mR
oooo00<0003oooooool04_ooo`0306Kooooooooo06Goool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooool0V@08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0
003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000oooooooo01?oool00ol0VOoo
ooooo`0@oooo00<0003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool0>oooo`03o`2I
oooooooo03coool008coool00`0003?o03?o000D<ol000<0003oooooool0>oooo`03o`2Ioooooooo
03coool008goool2000053?o00030000oooooooo03_oool00ol0VOooooooo`0loooo002?oooo00<0
000co`0co`004C?o00030000oooooooo03_oool00ol0VOooooooo`0loooo002@oooo00<0000co`0c
o`0043?o0080000loooo00?o09Woooooool0??ooo`00TOooo`80000@<ol000<0003oooooool0>ooo
o`03o`2Ioooooooo03coool009?oool00`0003?o03?o000=<ol000<0003oooooool0>oooo`03o`2I
oooooooo03coool009?oool00`0003?o03?o000=<ol000<0003oooooool0>oooo`03o`2Ioooooooo
03coool009Coool00`0003?o03?o000<<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool0
09Coool00`0003?o03?o000<<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool009Goool0
0`0003?o03?o000;<ol00P0003coool00ol0VOooooooo`0loooo002Eoooo00<0000co`0co`002c?o
00030000oooooooo03_oool00ol0VOooooooo`0loooo002Foooo00<0000co`0co`002S?o00030000
oooooooo03_oool00ol0VOooooooo`0loooo002Foooo00<0000co`0co`002S?o00030000oooooooo
03_oool00ol0VOooooooo`0loooo002Goooo00<0000co`0co`002C?o00030000oooooooo03_oool0
0ol0VOooooooo`0loooo002Goooo00<0000co`0co`002C?o00030000oooooooo03_oool00ol0VOoo
ooooo`0loooo002Hoooo00<0000co`0co`0023?o0080000loooo00?o09Woooooool0??ooo`00V?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`0koooo00?o09Woooooool0??ooo`00V?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`0koooo00?o09Woooooool0??ooo`00VOooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0koooo00?o09Woooooool0??ooo`00VOooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0koooo00?o09Woooooool0??ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0koooo00?o09Woooooool0??ooo`00VOooo`030000<ol0<ol000Lco`020000??ooo`03o`2I
oooooooo03coool009[oool00`0003?o03?o0006<ol000<0003oooooool0>oooo`03o`2Ioooooooo
03coool009[oool00`0003?o03?o0006<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool0
09[oool00`0003?o03?o0006<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool009[oool0
0`0003?o03?o0006<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool009_oool500000c?o
00030000oooooooo03_oool00ol0VOooooooo`0loooo002Koooo00<0000co`0000001C?o00030000
oooooooo03_oool00ol0VOooooooo`0loooo002Koooo00<0000co`0000001C?o00<0000koooo00?o
09Woooooool0??ooo`00W?ooo`800005<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool0
09coool200001C?o00030000oooooooo03_oool00ol0VOooooooo`0loooo002Loooo0P0000Dco`00
0`000?ooooooo`0koooo00?o09Woooooool0??ooo`00W?ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0koooo00?o09Woooooool0??ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`0k
oooo00?o09Woooooool0??ooo`00W?ooo`030000<ol0<ol000@co`020000??ooo`03o`2Ioooooooo
03coool009goool00`0003?o03?o0003<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool0
09goool00`0003?o03?o0003<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool009goool0
0`0003?o03?o0003<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool009goool00`0003?o
03?o0003<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool009goool00`0003?o03?o0003
<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool009goool00`0003?o03?o0003<ol00P00
03coool00ol0VOooooooo`0loooo002Moooo00<0000co`0co`000c?o00030000oooooooo03_oool0
0ol0VOooooooo`0loooo002Moooo00<0000co`0co`000c?o00030000oooooooo03_oool00ol0VOoo
ooooo`0loooo002Noooo00<0000co`0co`000S?o00030000oooooooo03_oool00ol0VOooooooo`0l
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo03_oool00ol0VOooooooo`0loooo002N
oooo00<0000co`0co`000S?o00030000oooooooo03_oool00ol0VOooooooo`0loooo002Noooo00<0
000co`0co`000S?o00030000oooooooo03_oool00ol0VOooooooo`0loooo002Noooo00<0000co`0c
o`000S?o0080000loooo00?o09Woooooool0??ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0koooo00?o09Woooooool0??ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0k
oooo00?o09Woooooool0??ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0koooo00?o
09Woooooool0??ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0koooo00?o09Wooooo
ool0??ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0koooo00?o09Woooooool0??oo
o`00W_ooo`030000<ol0<ol0008co`020000??ooo`03o`2Ioooooooo03coool009ooool01@0003?o
03?o03?o0000000moooo00?o09Woooooool0??ooo`00Woooo`050000<ol0<ol0<ol0000003goool0
0ol0VOooooooo`0loooo002Ooooo00D0000co`0co`0co`000000?Oooo`03o`2Ioooooooo03coool0
09_oool500000c?o00030000oooooooo03_oool00ol0VOooooooo`0loooo002Koooo00D0003ooooo
ooooool000000c?o00030000oooooooo03_oool00ol0VOooooooo`0loooo002Loooo00@0003ooooo
ool00003<ol00`0003_oool00ol0VOooooooo`0loooo002Moooo00<0003oool000000c?o00030000
oooooooo03_oool00ol0VOooooooo`0loooo002Koooo00<0003oooooool00P0000<co`000`000?oo
ooooo`0koooo00?o09Woooooool0??ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003ooooo
ool0>oooo`03o`2Ioooooooo03coool009ooool01@0003?o03?o03?o0000000moooo00?o09Wooooo
ool0??ooo`00X?ooo`040000<ol0<ol00000?Oooo`03o`2Ioooooooo03coool00:3oool00`0003?o
03?o00020000??ooo`03o`2Ioooooooo03coool00:3oool0100003?o03?o000003goool00ol0VOoo
ooooo`0loooo002Poooo00@0000co`0co`00000moooo00?o09Woooooool0??ooo`00X?ooo`040000
<ol0<ol00000?Oooo`03o`2Ioooooooo03coool00:3oool0100003?o03?o000003goool00ol0VOoo
ooooo`0loooo002Poooo00@0000co`0co`00000moooo00?o09Woooooool0??ooo`00X?ooo`040000
<ol0<ol00000?Oooo`03o`2Ioooooooo03coool00:7oool0100003?o0000000003coool00ol0VOoo
ooooo`0loooo002Qoooo00<0000co`000000?Oooo`03o`2Ioooooooo03coool00:7oool00`0003?o
0000000moooo00?o09Woooooool0??ooo`00XOooo`030000<ol0000003goool00ol0VOooooooo`0l
oooo002Qoooo00<0000co`000000?Oooo`03o`2Ioooooooo03coool00:7oool00`0003?o0000000m
oooo00?o09Woooooool0??ooo`00XOooo`040000<ol000000000??ooo`03o`2Ioooooooo03coool0
0:7oool00`0003?o0000000moooo00?o09Woooooool0??ooo`00XOooo`030000<ol0000003goool0
0ol0VOooooooo`0loooo002Qoooo00<0000co`000000?Oooo`03o`2Ioooooooo03coool00:7oool0
0`0003?o0000000moooo00?o09Woooooool0??ooo`00XOooo`030000<ol0000003goool00ol0VOoo
ooooo`0loooo002Qoooo00@0000co`000000000loooo00?o09Woooooool0??ooo`00XOooo`030000
<ol0000003goool00ol0VOooooooo`0loooo002Qoooo00<0000co`000000?Oooo`03o`2Ioooooooo
03coool00:7oool00`0003?o0000000moooo00?o09Woooooool0??ooo`00W?ooo`800003oooo00<0
000co`000000?Oooo`03o`2Ioooooooo03coool009_oool010000?ooooooo`0000;oool00`0003?o
0000000moooo00?o09Woooooool0??ooo`00WOooo`060000oooooooooooo0000<ol00`0003_oool0
0ol0VOooooooo`0loooo002Noooo00H0003oooooool0000co`00000moooo00?o09Woooooool0??oo
o`00Voooo`040000oooooooo00000_ooo`030000<ol0000003goool00ol0VOooooooo`0loooo002L
oooo0P0000Coool20000?Oooo`03o`2Ioooooooo03coool00:;oool20000?Oooo`03o`2Ioooooooo
03coool00:;oool20000?Oooo`03o`2Ioooooooo03coool00:;oool20000?Oooo`03o`2Ioooooooo
03coool00:;oool30000??ooo`03o`2Ioooooooo03coool00:;oool20000?Oooo`03o`2Ioooooooo
03coool00:;oool20000?Oooo`03o`2Ioooooooo03coool00:;oool20000?Oooo`03o`2Ioooooooo
03coool00:;oool20000?Oooo`03o`2Ioooooooo03coool00:;oool20000?Oooo`03o`2Ioooooooo
03coool00:;oool30000??ooo`03o`2Ioooooooo03coool00:;oool20000?Oooo`03o`2Ioooooooo
03coool00:;oool20000?Oooo`03o`2Ioooooooo03coool00:;oool20000?Oooo`03o`2Ioooooooo
03coool00:;oool20000?Oooo`03o`2Ioooooooo03coool00:;oool20000?Oooo`03o`2Ioooooooo
03coool00:;oool30000??ooo`03o`2Ioooooooo03coool00:?oool00`000?ooooooo`0koooo00?o
09Woooooool0??ooo`00Xoooo`030000oooooooo03_oool00ol0VOooooooo`0loooo002Soooo00<0
003oooooool0>oooo`03o`2Ioooooooo03coool00:?oool00`000?ooooooo`0koooo00?o09Wooooo
ool0??ooo`00Xoooo`030000oooooooo03_oool00ol0VOooooooo`0loooo002Soooo0P0003coool0
0ol0VOooooooo`0loooo002Soooo00<0003oooooool0>oooo`03o`2Ioooooooo03coool00:?oool0
0`000?ooooooo`0koooo00?o09Woooooool0??ooo`00Xoooo`030000oooooooo03_oool00ol0VOoo
ooooo`0loooo002Soooo00<0003oooooool0>oooo`03o`2Ioooooooo03coool009goool300000ooo
o`030000oooooooo03_oool00ol0VOooooooo`0loooo002Noooo00<0003oooooool00_ooo`030000
oooooooo03_oool00ol0VOooooooo`0loooo002Koooo1@0000?oool30000>oooo`03o`2Ioooooooo
03coool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00
087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003oooo0P0000?oool5
00000_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`030000
oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo
00[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>
oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000003oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1l
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.80799 .12361 L
.81909 .12361 L
.8239 .12361 L
.82904 .12361 L
.83056 .12361 L
.832 .12361 L
.83329 .12361 L
s
.83329 .12361 m
.83358 .61803 L
s
0 .4 1 r
.02381 .12321 m
.04262 .12305 L
.06244 .12281 L
.07286 .12265 L
.08255 .12247 L
.09388 .12221 L
.10458 .12192 L
.125 .12118 L
.14357 .12022 L
.16355 .11878 L
.18199 .1169 L
.20071 .11425 L
.21136 .11229 L
.22134 .11009 L
.24158 .10421 L
.26011 .09663 L
.27909 .08577 L
.28984 .07778 L
.29982 .06887 L
.31861 .04709 L
.32128 .04337 L
.32376 .03974 L
.32502 .03784 L
.32572 .03727 L
.32636 .03728 L
.3292 .03733 L
.33895 .03755 L
.34994 .03784 L
.36036 .03817 L
.38053 .03901 L
.40044 .04019 L
.41886 .04171 L
.43752 .04384 L
.45813 .04711 L
.47747 .0514 L
.49833 .05772 L
.51798 .06465 L
.53947 .07205 L
.54939 .075 L
.55485 .07639 L
.56 .07751 L
.5648 .07833 L
.5675 .07869 L
.56879 .07882 L
.57 .07893 L
.5711 .07901 L
.5721 .07907 L
.57322 .07911 L
.57442 .07913 L
.57557 .07913 L
Mistroke
.57682 .0791 L
.578 .07904 L
.57909 .07896 L
.58419 .07854 L
.58705 .07836 L
.58842 .07829 L
.58969 .07824 L
.5909 .0782 L
.592 .07817 L
.59323 .07815 L
.59454 .07814 L
.5958 .07814 L
.59651 .07814 L
.59717 .07815 L
.59838 .07817 L
.59966 .07821 L
.6008 .07825 L
.60186 .0783 L
.60423 .07845 L
.60632 .07862 L
.60851 .07885 L
.61318 .07949 L
.61828 .08046 L
.62358 .08183 L
.62858 .08347 L
.63792 .08762 L
.64799 .09397 L
.65889 .10353 L
.66385 .10899 L
.66918 .11572 L
.67177 .11934 L
.67304 .12121 L
.67421 .123 L
.67528 .12361 L
.67641 .12361 L
.6788 .12361 L
.68884 .12361 L
.69986 .12361 L
.73758 .12361 L
.77775 .12361 L
.8164 .12361 L
.85751 .12361 L
.8971 .12361 L
.93518 .12361 L
.97571 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo002Soooo00<0
003oooooool0N_ooo`00H_oooaH0I_l[oooo00<0003oooooool0N_ooo`00H_ooo`0306Kooooooooo
01?oool:06Ko8Oooo`030000oooooooo07[oool0067oool00`1Vooooooooo`0Noooo1@1Voacoool0
0`000?ooooooo`1joooo001Poooo00<0I_ooooooool09?ooo`@0I_lHoooo0P0007_oool005ooool0
0`1Vooooooooo`0Yoooo0`1VoaGoool00`000?ooooooo`1joooo001Noooo00<0I_ooooooool0;Ooo
o`@0I_lAoooo00<0003oooooool0N_ooo`00G_ooo`0306Kooooooooo037oool406Ko3Oooo`030000
oooooooo07[oool005goool00`1Vooooooooo`0foooo0P1Vo`_oool00`000?ooooooo`1joooo001L
oooo00<0I_ooooooool0>Oooo`80I_l9oooo00<0003oooooool0N_ooo`00Foooo`0306Kooooooooo
03coool406Ko1Oooo`80001koooo000[oooo0`0002Soool3000000?oool0I_ooool08?ooo`@0000N
oooo1@1Vo`03000006Ko06Ko00P0I_lKoooo100002Ooool30000:Oooo`00:oooo`040000oooooooo
0000:?ooo`03000006Ko06Ko02;oool00`000?ooooooo`0Toooo00<0003oooooool02?ooo`<0I_lH
oooo00<0003oooooool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0002Goool5
00009?ooo`030000oooooooo02?oool00`000?ooooooo`0;oooo0P1VoaOoool00`000?ooooooo`0U
oooo1@0002Woool002Goool400000_ooo`<0000Poooo100000;oool01000001Vo`1Vo`0001koool4
00001?ooo`030000oooooooo02;oool00`000?ooooooo`0=oooo00<0I_ooooooool05Oooo`030000
oooooooo02Coool010000?ooooooo`0002[oool002coool00`000?ooooooo`0Toooo0P1Vo`030000
oooo000002Coool010000?ooooooo`0002?oool00`000?ooooooo`0>oooo00<0I_ooooooool04_oo
o`040000oooooooo00009_ooo`030000oooo000002[oool002coool300008Oooo`<0I_l3oooo0P00
02Goool200009?ooo`80000@oooo0P1Voa?oool20000:?ooo`80000Zoooo001<oooo101Voe?oool0
0`000?ooooooo`0Aoooo00<0I_ooooooool0I_ooo`00B_ooo`80I_mGoooo00<0003oooooool04_oo
o`0306Kooooooooo06Goool004Soool206KoFOooo`030000oooooooo01?oool00`1Vooooooooo`1T
oooo0011oooo1`1Voe_oool00`000?ooooooo`0Doooo00<0I_ooooooool0Hoooo`00>?ooo`T0I_mR
oooo00<0003oooooool05Oooo`0306Kooooooooo06;oool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
1@000?ooooooooooool0V@06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`0U
oooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000oooooooo01Goool0
0ol0VOooooooo`0>oooo00<0003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool0?Ooo
o`03o`2Ioooooooo03[oool008coool00`0003?o03?o000D<ol000<0003oooooool0?Oooo`03o`2I
oooooooo03[oool008goool2000053?o00030000oooooooo03goool00ol0VOooooooo`0joooo002?
oooo00<0000co`0co`004C?o00030000oooooooo03goool00ol0VOooooooo`0joooo002@oooo00<0
000co`0co`0043?o0080000noooo00?o09Woooooool0>_ooo`00TOooo`80000@<ol000<0003ooooo
ool0?Oooo`03o`2Ioooooooo03[oool009?oool00`0003?o03?o000=<ol000<0003oooooool0?Ooo
o`03o`2Ioooooooo03[oool009?oool00`0003?o03?o000=<ol000<0003oooooool0?Oooo`03o`2I
oooooooo03[oool009Coool00`0003?o03?o000<<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
03[oool009Coool00`0003?o03?o000<<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03[oool0
09Goool00`0003?o03?o000;<ol00P0003koool00ol0VOooooooo`0joooo002Eoooo00<0000co`0c
o`002c?o00030000oooooooo03goool00ol0VOooooooo`0joooo002Foooo00<0000co`0co`002S?o
00030000oooooooo03goool00ol0VOooooooo`0joooo002Foooo00<0000co`0co`002S?o00030000
oooooooo03goool00ol0VOooooooo`0joooo002Goooo00<0000co`0co`002C?o00030000oooooooo
03goool00ol0VOooooooo`0joooo002Goooo00<0000co`0co`002C?o00030000oooooooo03goool0
0ol0VOooooooo`0joooo002Hoooo00<0000co`0co`0023?o0080000noooo00?o09Woooooool0>_oo
o`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0moooo00?o09Woooooool0>_ooo`00V?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`0moooo00?o09Woooooool0>_ooo`00VOooo`030000
<ol0<ol000Lco`000`000?ooooooo`0moooo00?o09Woooooool0>_ooo`00VOooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0moooo00?o09Woooooool0>_ooo`00VOooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0moooo00?o09Woooooool0>_ooo`00VOooo`030000<ol0<ol000Lco`020000?_oo
o`03o`2Ioooooooo03[oool009[oool00`0003?o03?o0006<ol000<0003oooooool0?Oooo`03o`2I
oooooooo03[oool009[oool00`0003?o03?o0006<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
03[oool009[oool00`0003?o03?o0006<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03[oool0
09[oool00`0003?o03?o0006<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03[oool009_oool5
00000c?o00030000oooooooo03goool00ol0VOooooooo`0joooo002Koooo00<0000co`0000001C?o
00030000oooooooo03goool00ol0VOooooooo`0joooo002Koooo00<0000co`0000001C?o00<0000m
oooo00?o09Woooooool0>_ooo`00W?ooo`800005<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
03[oool009coool200001C?o00030000oooooooo03goool00ol0VOooooooo`0joooo002Loooo0P00
00Dco`000`000?ooooooo`0moooo00?o09Woooooool0>_ooo`00W?ooo`030000<ol0<ol000@co`00
0`000?ooooooo`0moooo00?o09Woooooool0>_ooo`00W?ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0moooo00?o09Woooooool0>_ooo`00W?ooo`030000<ol0<ol000@co`020000?_ooo`03o`2I
oooooooo03[oool009goool00`0003?o03?o0003<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
03[oool009goool00`0003?o03?o0003<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03[oool0
09goool00`0003?o03?o0003<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03[oool009goool0
0`0003?o03?o0003<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03[oool009goool00`0003?o
03?o0003<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03[oool009goool00`0003?o03?o0003
<ol00P0003koool00ol0VOooooooo`0joooo002Moooo00<0000co`0co`000c?o00030000oooooooo
03goool00ol0VOooooooo`0joooo002Moooo00<0000co`0co`000c?o00030000oooooooo03goool0
0ol0VOooooooo`0joooo002Noooo00<0000co`0co`000S?o00030000oooooooo03goool00ol0VOoo
ooooo`0joooo002Noooo00<0000co`0co`000S?o00030000oooooooo03goool00ol0VOooooooo`0j
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo03goool00ol0VOooooooo`0joooo002N
oooo00<0000co`0co`000S?o00030000oooooooo03goool00ol0VOooooooo`0joooo002Noooo00<0
000co`0co`000S?o0080000noooo00?o09Woooooool0>_ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`0moooo00?o09Woooooool0>_ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0moooo00?o09Woooooool0>_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0m
oooo00?o09Woooooool0>_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0moooo00?o
09Woooooool0>_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0moooo00?o09Wooooo
ool0>_ooo`00W_ooo`030000<ol0<ol0008co`020000?_ooo`03o`2Ioooooooo03[oool009ooool0
1@0003?o03?o03?o0000000ooooo00?o09Woooooool0>_ooo`00Woooo`050000<ol0<ol0<ol00000
03ooool00ol0VOooooooo`0joooo002Ooooo00D0000co`0co`0co`000000?oooo`03o`2Ioooooooo
03[oool009_oool500000c?o00030000oooooooo03goool00ol0VOooooooo`0joooo002Koooo00D0
003oooooooooool000000c?o00030000oooooooo03goool00ol0VOooooooo`0joooo002Loooo00@0
003oooooool00003<ol00`0003goool00ol0VOooooooo`0joooo002Moooo00<0003oool000000c?o
00030000oooooooo03koool00ol0VOooooooo`0ioooo002Koooo00<0003oooooool00P0000<co`00
0`000?ooooooo`0noooo00?o09Woooooool0>Oooo`00W?ooo`8000000oooo`0003?o0002<ol000<0
003oooooool0?_ooo`03o`2Ioooooooo03Woool009ooool01@0003?o03?o03?o00000010oooo00?o
09Woooooool0>Oooo`00X?ooo`040000<ol0<ol00000@?ooo`03o`2Ioooooooo03Woool00:3oool0
0`0003?o03?o00020000?oooo`03o`2Ioooooooo03Woool00:3oool0100003?o03?o0000043oool0
0ol0VOooooooo`0ioooo002Poooo00@0000co`0co`000010oooo00?o09Woooooool0>Oooo`00X?oo
o`040000<ol0<ol00000@?ooo`03o`2Ioooooooo03Woool00:3oool0100003?o03?o0000043oool0
0ol0VOooooooo`0ioooo002Poooo00@0000co`0co`000010oooo00?o09Woooooool0>Oooo`00X?oo
o`040000<ol0<ol00000@?ooo`03o`2Ioooooooo03Woool00:7oool0100003?o0000000003ooool0
0ol0VOooooooo`0ioooo002Qoooo00<0000co`000000@?ooo`03o`2Ioooooooo03Woool00:7oool0
0`0003?o00000010oooo00?o09Woooooool0>Oooo`00XOooo`030000<ol00000043oool00ol0VOoo
ooooo`0ioooo002Qoooo00<0000co`000000@?ooo`03o`2Ioooooooo03Woool00:7oool00`0003?o
00000010oooo00?o09Woooooool0>Oooo`00XOooo`040000<ol000000000?oooo`03o`2Ioooooooo
03Woool00:7oool00`0003?o00000010oooo00?o09Woooooool0>Oooo`00XOooo`030000<ol00000
043oool00ol0VOooooooo`0ioooo002Qoooo00<0000co`000000@?ooo`03o`2Ioooooooo03Woool0
0:7oool00`0003?o00000010oooo00?o09Woooooool0>Oooo`00XOooo`030000<ol00000043oool0
0ol0VOooooooo`0ioooo002Qoooo00@0000co`000000000ooooo00?o09Woooooool0>Oooo`00XOoo
o`030000<ol00000043oool00ol0VOooooooo`0ioooo002Qoooo00<0000co`000000@?ooo`03o`2I
oooooooo03Woool00:7oool00`0003?o00000010oooo00?o09Woooooool0>Oooo`00W?ooo`800003
oooo00<0000co`000000@?ooo`03o`2Ioooooooo03Woool009_oool010000?ooooooo`0000;oool0
0`0003?o00000010oooo00?o09Woooooool0>Oooo`00WOooo`060000oooooooooooo0000<ol00`00
03koool00ol0VOooooooo`0ioooo002Noooo00H0003oooooool0000co`000010oooo00?o09Wooooo
ool0>Oooo`00Voooo`040000oooooooo00000_ooo`030000<ol00000043oool00ol0VOooooooo`0i
oooo002Loooo0P0000Coool20000@?ooo`03o`2Ioooooooo03Woool00:;oool20000@?ooo`03o`2I
oooooooo03Woool00:;oool20000@?ooo`03o`2Ioooooooo03Woool00:;oool20000@?ooo`03o`2I
oooooooo03Woool00:;oool30000?oooo`03o`2Ioooooooo03Woool00:;oool20000@?ooo`03o`2I
oooooooo03Woool00:;oool20000@?ooo`03o`2Ioooooooo03Woool00:;oool20000@?ooo`03o`2I
oooooooo03Woool00:;oool20000@?ooo`03o`2Ioooooooo03Woool00:;oool20000@?ooo`03o`2I
oooooooo03Woool00:;oool30000?oooo`03o`2Ioooooooo03Woool00:;oool20000@?ooo`03o`2I
oooooooo03Woool00:;oool20000@?ooo`03o`2Ioooooooo03Woool00:;oool20000@?ooo`03o`2I
oooooooo03Woool00:;oool20000@?ooo`03o`2Ioooooooo03Woool00:;oool20000@?ooo`03o`2I
oooooooo03Woool00:;oool30000?oooo`03o`2Ioooooooo03Woool00:?oool00`000?ooooooo`0n
oooo00?o09Woooooool0>Oooo`00Xoooo`030000oooooooo03koool00ol0VOooooooo`0ioooo002S
oooo00<0003oooooool0?_ooo`03o`2Ioooooooo03Woool00:?oool00`000?ooooooo`0noooo00?o
09Woooooool0>Oooo`00Xoooo`030000oooooooo03koool00ol0VOooooooo`0ioooo002Soooo0P00
03ooool00ol0VOooooooo`0ioooo002Soooo00<0003oooooool0?_ooo`03o`2Ioooooooo03Woool0
0:?oool00`000?ooooooo`0noooo00?o09Woooooool0>Oooo`00Xoooo`030000oooooooo03koool0
0ol0VOooooooo`0ioooo002Soooo00<0003oooooool0?_ooo`03o`2Ioooooooo03Woool009goool3
00000oooo`030000oooooooo03koool00ol0VOooooooo`0ioooo002Noooo00<0003oooooool00_oo
o`030000oooooooo03koool00ol0VOooooooo`0ioooo002Koooo1@0000?oool30000?_ooo`03o`2I
oooooooo03Woool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002M
oooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?oo
ooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1k
oooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003oooo0P00
00?oool400000oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`09oooo00<0003oooooool01?oo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000
oooooooo00Woool00`000?ooooooo`04oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000>oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.81909 .12361 L
.82924 .12361 L
.83479 .12361 L
.83749 .12361 L
.83868 .12361 L
.83996 .12361 L
.84114 .12361 L
s
.84114 .12361 m
.84158 .61803 L
s
0 .4 1 r
.02381 .12315 m
.04262 .12296 L
.06244 .12269 L
.07286 .1225 L
.08255 .12229 L
.09388 .122 L
.10458 .12166 L
.125 .12081 L
.14357 .11971 L
.16355 .11804 L
.18199 .11588 L
.20071 .11282 L
.21136 .11056 L
.22134 .10803 L
.24158 .10126 L
.26011 .09252 L
.27909 .08 L
.28984 .0708 L
.29982 .06052 L
.31039 .04745 L
.31291 .04395 L
.31557 .04008 L
.31667 .03843 L
.31784 .03722 L
.31914 .03725 L
.32034 .03727 L
.32928 .03746 L
.33895 .03769 L
.34912 .03798 L
.36019 .03837 L
.38031 .0393 L
.40008 .04059 L
.41007 .04143 L
.42109 .04255 L
.44044 .0451 L
.46129 .04899 L
.48133 .05424 L
.50243 .0613 L
.54054 .07429 L
.55063 .07702 L
.55558 .07814 L
.56015 .079 L
.56266 .07939 L
.56542 .07974 L
.56676 .07987 L
.56819 .08 L
.56899 .08005 L
.56971 .08009 L
.5704 .08013 L
.57113 .08016 L
Mistroke
.5724 .08018 L
.57358 .08019 L
.5743 .08018 L
.57498 .08016 L
.57625 .0801 L
.57746 .08001 L
.57858 .07991 L
.5811 .0796 L
.58582 .07908 L
.59086 .07863 L
.59331 .07846 L
.59563 .07833 L
.59771 .07824 L
.59888 .0782 L
.59997 .07817 L
.60115 .07815 L
.60243 .07814 L
.60363 .07814 L
.60474 .07814 L
.60596 .07816 L
.60666 .07818 L
.6073 .0782 L
.60861 .07825 L
.61 .07831 L
.61287 .0785 L
.61558 .07875 L
.62064 .07941 L
.62529 .08026 L
.63039 .08151 L
.63572 .08318 L
.6407 .08514 L
.6496 .08973 L
.65916 .09649 L
.66875 .10556 L
.67895 .11826 L
.68151 .12202 L
.68221 .12309 L
.68294 .12361 L
.68426 .12361 L
.68729 .12361 L
.69013 .12361 L
.70049 .12361 L
.7403 .12361 L
.77838 .12361 L
.81891 .12361 L
.85792 .12361 L
.89939 .12361 L
.93934 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001Qoooo00<0
I_ooooooool0?oooo`030000oooooooo07[oool0063ooolG06Ko;?ooo`030000oooooooo07[oool0
063oool00`1Vooooooooo`0Doooo301Vob3oool00`000?ooooooo`1joooo001Ooooo00<0I_oooooo
ool08Oooo`@0I_lLoooo00<0003oooooool0N_ooo`00G_ooo`0306Kooooooooo02Koool206Ko6_oo
o`80001koooo001Moooo00<0I_ooooooool0:Oooo`<0I_lGoooo00<0003oooooool0N_ooo`00G?oo
o`0306Kooooooooo02goool306Ko5?ooo`030000oooooooo07[oool005_oool00`1Vooooooooo`0a
oooo0`1Voa7oool00`000?ooooooo`1joooo001Koooo00<0I_ooooooool0=?ooo`<0I_l>oooo00<0
003oooooool0N_ooo`00F_ooo`0306Kooooooooo03Soool306Ko2oooo`030000oooooooo07[oool0
05Soool206Ko?_ooo`<0I_l8oooo0P0007_oool002_oool30000:?ooo`<0000Soooo100001_oool8
06Ko00<00000I_l0I_l02P1VoaWoool400009oooo`<0000Yoooo000[oooo00@0003oooooool0000W
oooo00<0I_l0003oool08oooo`030000oooooooo02Coool00`000?ooooooo`0:oooo0P1VoaOoool0
0`000?ooooooo`0Yoooo00<0003oooooool0:?ooo`00:oooo`040000oooooooo00009Oooo`D0000T
oooo00<0003oooooool08oooo`030000oooooooo00coool206Ko5_ooo`030000oooooooo02Goool5
0000:Oooo`009Oooo`@00002oooo0`00023oool4000000?oool0I_l000000_ooo`030000oooooooo
01coool400001?ooo`030000oooooooo02;oool00`000?ooooooo`0>oooo0P1VoaGoool00`000?oo
ooooo`0Toooo00@0003oooooool0000Zoooo000/oooo00<0003oooooool08_ooo`80I_l2oooo00<0
003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo013oool00`1Vooooooooo`0@
oooo00@0003oooooool0000Voooo00<0003oool00000:_ooo`00;?ooo`<0000Poooo0P1Vo`Goool2
00009Oooo`80000Toooo0P0001;oool00`1Vooooooooo`0@oooo0P0002Soool20000:_ooo`00Booo
o`@0I_mDoooo00<0003oooooool04_ooo`80I_mVoooo0018oooo0`1VoeSoool00`000?ooooooo`0D
oooo00<0I_ooooooool0Hoooo`00AOooo`<0I_mKoooo00<0003oooooool05Oooo`0306Kooooooooo
06;oool003goool806KoG_ooo`030000oooooooo01Goool00`1Vooooooooo`1Roooo000coooo2P1V
ofKoool00`000?ooooooo`0Foooo00<0I_ooooooool0HOooo`004?ooool0000Aoooo000Foooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oool0000040000003<ol00000<ol000Pco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00?oool00ol0VOooooooo`02oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo02Koool0
0`000?ooooooo`0Uoooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000
oooooooo01Ooool00ol0VOooooooo`0<oooo00<0003oooooool0:Oooo`00R?ooo`@0000G<ol000<0
003oooooool0?oooo`03o`2Ioooooooo03Soool008coool00`0003?o03?o000D<ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo03Soool008goool2000053?o00030000oooooooo03ooool00ol0VOoo
ooooo`0hoooo002?oooo00<0000co`0co`004C?o00030000oooooooo03ooool00ol0VOooooooo`0h
oooo002@oooo00<0000co`0co`0043?o00800010oooo00?o09Woooooool0>?ooo`00TOooo`80000@
<ol000<0003oooooool0?oooo`03o`2Ioooooooo03Soool009?oool00`0003?o03?o000=<ol000<0
003oooooool0?oooo`03o`2Ioooooooo03Soool009?oool00`0003?o03?o000=<ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo03Soool009Coool00`0003?o03?o000<<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo03Soool009Coool00`0003?o03?o000<<ol000<0003oooooool0?oooo`03o`2I
oooooooo03Soool009Goool00`0003?o03?o000;<ol00P00043oool00ol0VOooooooo`0hoooo002E
oooo00<0000co`0co`002c?o00030000oooooooo03ooool00ol0VOooooooo`0hoooo002Foooo00<0
000co`0co`002S?o00030000oooooooo03ooool00ol0VOooooooo`0hoooo002Foooo00<0000co`0c
o`002S?o00030000oooooooo03ooool00ol0VOooooooo`0hoooo002Goooo00<0000co`0co`002C?o
00030000oooooooo03ooool00ol0VOooooooo`0hoooo002Goooo00<0000co`0co`002C?o00030000
oooooooo03ooool00ol0VOooooooo`0hoooo002Hoooo00<0000co`0co`0023?o00800010oooo00?o
09Woooooool0>?ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0ooooo00?o09Wooooo
ool0>?ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0ooooo00?o09Woooooool0>?oo
o`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`0ooooo00?o09Woooooool0>?ooo`00VOoo
o`030000<ol0<ol000Lco`000`000?ooooooo`0ooooo00?o09Woooooool0>?ooo`00VOooo`030000
<ol0<ol000Lco`000`000?ooooooo`0ooooo00?o09Woooooool0>?ooo`00VOooo`030000<ol0<ol0
00Lco`020000@?ooo`03o`2Ioooooooo03Soool009[oool00`0003?o03?o0006<ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo03Soool009[oool00`0003?o03?o0006<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo03Soool009[oool00`0003?o03?o0006<ol000<0003oooooool0?oooo`03o`2I
oooooooo03Soool009[oool00`0003?o03?o0006<ol000<0003oooooool0?oooo`03o`2Ioooooooo
03Soool009_oool500000c?o00030000oooooooo03ooool00ol0VOooooooo`0hoooo002Koooo00<0
000co`0000001C?o00030000oooooooo03ooool00ol0VOooooooo`0hoooo002Koooo00<0000co`00
00001C?o00<0000ooooo00?o09Woooooool0>?ooo`00W?ooo`800005<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo03Soool009coool200001C?o00030000oooooooo03ooool00ol0VOooooooo`0h
oooo002Loooo0P0000Dco`000`000?ooooooo`0ooooo00?o09Woooooool0>?ooo`00W?ooo`030000
<ol0<ol000@co`000`000?ooooooo`0ooooo00?o09Woooooool0>?ooo`00W?ooo`030000<ol0<ol0
00@co`000`000?ooooooo`0ooooo00?o09Woooooool0>?ooo`00W?ooo`030000<ol0<ol000@co`02
0000@?ooo`03o`2Ioooooooo03Soool009goool00`0003?o03?o0003<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo03Soool009goool00`0003?o03?o0003<ol000<0003oooooool0?oooo`03o`2I
oooooooo03Soool009goool00`0003?o03?o0003<ol000<0003oooooool0?oooo`03o`2Ioooooooo
03Soool009goool00`0003?o03?o0003<ol000<0003oooooool0?oooo`03o`2Ioooooooo03Soool0
09goool00`0003?o03?o0003<ol000<0003oooooool0?oooo`03o`2Ioooooooo03Soool009goool0
0`0003?o03?o0003<ol00P00043oool00ol0VOooooooo`0hoooo002Moooo00<0000co`0co`000c?o
00030000oooooooo03ooool00ol0VOooooooo`0hoooo002Moooo00<0000co`0co`000c?o00030000
oooooooo03ooool00ol0VOooooooo`0hoooo002Noooo00<0000co`0co`000S?o00030000oooooooo
03ooool00ol0VOooooooo`0hoooo002Noooo00<0000co`0co`000S?o00030000oooooooo03ooool0
0ol0VOooooooo`0hoooo002Noooo00<0000co`0co`000S?o00030000oooooooo03ooool00ol0VOoo
ooooo`0hoooo002Noooo00<0000co`0co`000S?o00030000oooooooo03ooool00ol0VOooooooo`0h
oooo002Noooo00<0000co`0co`000S?o00800010oooo00?o09Woooooool0>?ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`0ooooo00?o09Woooooool0>?ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`0ooooo00?o09Woooooool0>?ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`0ooooo00?o09Woooooool0>?ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`0ooooo00?o09Woooooool0>?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`0o
oooo00?o09Woooooool0>?ooo`00W_ooo`030000<ol0<ol0008co`020000@?ooo`03o`2Ioooooooo
03Soool009ooool01@0003?o03?o03?o00000011oooo00?o09Woooooool0>?ooo`00Woooo`050000
<ol0<ol0<ol00000047oool00ol0VOooooooo`0hoooo002Ooooo00D0000co`0co`0co`000000@Ooo
o`03o`2Ioooooooo03Soool009_oool500000c?o00030000oooooooo03ooool00ol0VOooooooo`0h
oooo002Koooo00D0003oooooooooool000000c?o00030000oooooooo03ooool00ol0VOooooooo`0h
oooo002Loooo00@0003oooooool00003<ol00`0003ooool00ol0VOooooooo`0hoooo002Moooo00<0
003oool000000c?o00030000oooooooo043oool00ol0VOooooooo`0goooo002Koooo00<0003ooooo
ool00P0000<co`000`000?ooooooo`10oooo00?o09Woooooool0=oooo`00W?ooo`8000000oooo`00
03?o0002<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03Ooool009ooool01@0003?o03?o03?o
00000012oooo00?o09Woooooool0=oooo`00X?ooo`040000<ol0<ol00000@_ooo`03o`2Ioooooooo
03Ooool00:3oool00`0003?o03?o00020000@Oooo`03o`2Ioooooooo03Ooool00:3oool0100003?o
03?o000004;oool00ol0VOooooooo`0goooo002Poooo00@0000co`0co`000012oooo00?o09Wooooo
ool0=oooo`00X?ooo`040000<ol0<ol00000@_ooo`03o`2Ioooooooo03Ooool00:3oool0100003?o
03?o000004;oool00ol0VOooooooo`0goooo002Poooo00@0000co`0co`000012oooo00?o09Wooooo
ool0=oooo`00X?ooo`040000<ol0<ol00000@_ooo`03o`2Ioooooooo03Ooool00:7oool0100003?o
00000000047oool00ol0VOooooooo`0goooo002Qoooo00<0000co`000000@_ooo`03o`2Ioooooooo
03Ooool00:7oool00`0003?o00000012oooo00?o09Woooooool0=oooo`00XOooo`030000<ol00000
04;oool00ol0VOooooooo`0goooo002Qoooo00<0000co`000000@_ooo`03o`2Ioooooooo03Ooool0
0:7oool00`0003?o00000012oooo00?o09Woooooool0=oooo`00XOooo`040000<ol000000000@Ooo
o`03o`2Ioooooooo03Ooool00:7oool00`0003?o00000012oooo00?o09Woooooool0=oooo`00XOoo
o`030000<ol0000004;oool00ol0VOooooooo`0goooo002Qoooo00<0000co`000000@_ooo`03o`2I
oooooooo03Ooool00:7oool00`0003?o00000012oooo00?o09Woooooool0=oooo`00XOooo`030000
<ol0000004;oool00ol0VOooooooo`0goooo002Qoooo00@0000co`0000000011oooo00?o09Wooooo
ool0=oooo`00XOooo`030000<ol0000004;oool00ol0VOooooooo`0goooo002Qoooo00<0000co`00
0000@_ooo`03o`2Ioooooooo03Ooool00:7oool00`0003?o00000012oooo00?o09Woooooool0=ooo
o`00W?ooo`800003oooo00<0000co`000000@_ooo`03o`2Ioooooooo03Ooool009_oool010000?oo
ooooo`0000;oool00`0003?o00000012oooo00?o09Woooooool0=oooo`00WOooo`060000oooooooo
oooo0000<ol00`00043oool00ol0VOooooooo`0goooo002Noooo00H0003oooooool0000co`000012
oooo00?o09Woooooool0=oooo`00Voooo`040000oooooooo00000_ooo`030000<ol0000004;oool0
0ol0VOooooooo`0goooo002Loooo0P0000Coool20000@_ooo`03o`2Ioooooooo03Ooool00:;oool2
0000@_ooo`03o`2Ioooooooo03Ooool00:;oool20000@_ooo`03o`2Ioooooooo03Ooool00:;oool2
0000@_ooo`03o`2Ioooooooo03Ooool00:;oool30000@Oooo`03o`2Ioooooooo03Ooool00:;oool2
0000@_ooo`03o`2Ioooooooo03Ooool00:;oool20000@_ooo`03o`2Ioooooooo03Ooool00:;oool2
0000@_ooo`03o`2Ioooooooo03Ooool00:;oool20000@_ooo`03o`2Ioooooooo03Ooool00:;oool2
0000@_ooo`03o`2Ioooooooo03Ooool00:;oool30000@Oooo`03o`2Ioooooooo03Ooool00:;oool2
0000@_ooo`03o`2Ioooooooo03Ooool00:;oool20000@_ooo`03o`2Ioooooooo03Ooool00:;oool2
0000@_ooo`03o`2Ioooooooo03Ooool00:;oool20000@_ooo`03o`2Ioooooooo03Ooool00:;oool2
0000@_ooo`03o`2Ioooooooo03Ooool00:;oool30000@Oooo`03o`2Ioooooooo03Ooool00:?oool0
0`000?ooooooo`10oooo00?o09Woooooool0=oooo`00Xoooo`030000oooooooo043oool00ol0VOoo
ooooo`0goooo002Soooo00<0003oooooool0@?ooo`03o`2Ioooooooo03Ooool00:?oool00`000?oo
ooooo`10oooo00?o09Woooooool0=oooo`00Xoooo`030000oooooooo043oool00ol0VOooooooo`0g
oooo002Soooo0P00047oool00ol0VOooooooo`0goooo002Soooo00<0003oooooool0@?ooo`03o`2I
oooooooo03Ooool00:?oool00`000?ooooooo`10oooo00?o09Woooooool0=oooo`00Xoooo`030000
oooooooo043oool00ol0VOooooooo`0goooo002Soooo00<0003oooooool0@?ooo`03o`2Ioooooooo
03Ooool009goool300000oooo`030000oooooooo043oool00ol0VOooooooo`0goooo002Noooo00<0
003oooooool00_ooo`030000oooooooo043oool00ol0VOooooooo`0goooo002Koooo1@0000?oool3
0000@?ooo`03o`2Ioooooooo03Ooool009_oool010000?ooooooo`00087oool009coool00`000?oo
o`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`@00003oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`09oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?oo
ooooo`0>oooo00<0003oooooool02_ooo`030000oooooooo00?oool00`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0000koool00`000?ooooooo`0:oooo00D0003oooooooooool00000OOoo
o`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool0
0`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.81909 .12361 L
.82924 .12361 L
.83996 .12361 L
.84438 .12361 L
.84681 .12361 L
.84801 .12361 L
.84911 .12361 L
s
.84911 .12361 m
.84964 .61803 L
s
0 .4 1 r
.02381 .12308 m
.04262 .12286 L
.06244 .12255 L
.07286 .12233 L
.08255 .12209 L
.09388 .12175 L
.10458 .12136 L
.125 .12038 L
.14357 .11912 L
.16355 .1172 L
.18199 .1147 L
.20071 .11117 L
.21136 .10858 L
.22134 .10565 L
.24158 .09785 L
.26011 .08778 L
.27909 .07336 L
.28984 .06275 L
.29982 .05091 L
.30489 .04403 L
.30756 .04015 L
.30827 .0391 L
.30902 .03795 L
.30974 .03719 L
.31039 .0372 L
.31286 .03725 L
.31557 .0373 L
.32034 .03739 L
.33895 .03786 L
.35803 .03853 L
.36882 .03902 L
.37879 .03956 L
.39746 .04088 L
.41806 .04292 L
.43741 .04564 L
.45826 .04978 L
.4783 .05536 L
.4994 .06257 L
.53751 .07543 L
.5476 .07813 L
.55712 .08011 L
.56239 .08089 L
.56383 .08106 L
.56536 .0812 L
.56668 .08131 L
.56741 .08136 L
.5681 .0814 L
.56938 .08145 L
.57055 .08148 L
.57165 .08149 L
Mistroke
.57285 .08148 L
.57416 .08143 L
.57489 .0814 L
.57556 .08135 L
.57685 .08125 L
.57807 .08111 L
.58786 .07974 L
.59321 .07913 L
.59819 .07868 L
.60245 .07839 L
.60484 .07827 L
.60589 .07823 L
.60701 .07819 L
.60825 .07816 L
.60939 .07814 L
.61062 .07814 L
.61132 .07813 L
.61198 .07814 L
.61316 .07815 L
.61424 .07817 L
.61543 .0782 L
.61667 .07825 L
.61791 .07831 L
.61926 .07839 L
.62169 .07858 L
.62406 .07881 L
.62625 .07907 L
.63121 .07986 L
.63646 .08101 L
.64098 .08229 L
.64521 .08375 L
.65484 .08818 L
.65983 .09117 L
.66527 .09503 L
.67516 .10394 L
.68473 .11528 L
.68701 .11844 L
.68825 .12024 L
.68941 .12197 L
.6904 .12349 L
.69146 .12361 L
.69264 .12361 L
.69371 .12361 L
.69823 .12361 L
.7031 .12361 L
.71346 .12361 L
.73446 .12361 L
.77441 .12361 L
.81285 .12361 L
.85373 .12361 L
Mistroke
.8931 .12361 L
.93096 .12361 L
.97127 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001Ooooo00<0
I_ooooooool0@Oooo`030000oooooooo07[oool005kooolJ06Ko:oooo`030000oooooooo07[oool0
05goool00`1Vooooooooo`0Hoooo1@1VobKoool00`000?ooooooo`1joooo001Loooo00<0I_oooooo
ool07_ooo`D0I_lQoooo00<0003oooooool0N_ooo`00G?ooo`0306Kooooooooo02?oool506Ko7?oo
o`80001koooo001Koooo00<0I_ooooooool0:Oooo`@0I_lHoooo00<0003oooooool0N_ooo`00Fooo
o`0306Kooooooooo02goool306Ko5Oooo`030000oooooooo07[oool005[oool00`1Vooooooooo`0a
oooo0`1Voa;oool00`000?ooooooo`1joooo001Ioooo00<0I_ooooooool0=Oooo`<0I_l?oooo00<0
003oooooool0N_ooo`00F?ooo`0306Kooooooooo03Woool306Ko3?ooo`030000oooooooo07[oool0
05Ooool00`1Vooooooooo`0moooo0`1Vo`Woool20000Noooo`00:oooo`<0000Woooo00@0I_l00000
0000000Soooo100001[oool406Ko1Oooo`030000oooo06Ko00/0I_lHoooo100002Ooool30000:Ooo
o`00:oooo`040000oooooooo00009?ooo`80I_l2oooo00<0003oooooool08_ooo`030000oooooooo
01ooool506Ko00<00000I_ooool02oooo`@0I_lDoooo00<0003oooooool0:Oooo`030000oooooooo
02Soool002_oool010000?ooooooo`0002?oool00`1Vooooo`00000400009?ooo`030000oooooooo
02?oool00`000?ooooooo`0?oooo0P1Voa?oool00`000?ooooooo`0Uoooo1@0002Woool002Goool4
00000_ooo`<0000Poooo100000;oool010000?ooooooo`0001koool400001?ooo`030000oooooooo
02;oool00`000?ooooooo`0Aoooo00<0I_ooooooool04Oooo`030000oooooooo02Coool010000?oo
ooooo`0002[oool002coool00`000?ooooooo`0Ooooo0P1Vo`Goool00`000?ooo`00000Toooo00@0
003oooooool0000Soooo00<0003oooooool04_ooo`80I_l?oooo00@0003oooooool0000Voooo00<0
003oool00000:_ooo`00;?ooo`<0000Moooo0P1Vo`Soool200009Oooo`80000Toooo0P0001Goool0
0`1Vooooooooo`0=oooo0P0002Soool20000:_ooo`00B_ooo`80I_mGoooo00<0003oooooool05Ooo
o`0306Kooooooooo06;oool004Soool206KoFOooo`030000oooooooo01Koool00`1Vooooooooo`1Q
oooo0011oooo1`1Voe_oool00`000?ooooooo`0Goooo00<0I_ooooooool0H?ooo`00?Oooo`@0I_mR
oooo00<0003oooooool06?ooo`0306Kooooooooo05ooool003?oool:06KoI_ooo`030000oooooooo
01Soool00`1Vooooooooo`1Ooooo000@ooooo`00017oool001Koool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01Ooo
o`04o`2Ioooooooo00002Oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_oo
o`@0000K<ol000<0003oooooool09Oooo`030000oooooooo01Woool00ol0VOooooooo`0:oooo00<0
003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool0
08coool00`0003?o03?o000D<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool008goool2
000053?o00030000oooooooo047oool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`004C?o
00030000oooooooo047oool00ol0VOooooooo`0foooo002@oooo00<0000co`0co`0043?o00800012
oooo00?o09Woooooool0=_ooo`00TOooo`80000@<ol000<0003oooooool0@Oooo`03o`2Ioooooooo
03Koool009?oool00`0003?o03?o000=<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool0
09?oool00`0003?o03?o000=<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009Coool0
0`0003?o03?o000<<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009Coool00`0003?o
03?o000<<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009Goool00`0003?o03?o000;
<ol00P0004;oool00ol0VOooooooo`0foooo002Eoooo00<0000co`0co`002c?o00030000oooooooo
047oool00ol0VOooooooo`0foooo002Foooo00<0000co`0co`002S?o00030000oooooooo047oool0
0ol0VOooooooo`0foooo002Foooo00<0000co`0co`002S?o00030000oooooooo047oool00ol0VOoo
ooooo`0foooo002Goooo00<0000co`0co`002C?o00030000oooooooo047oool00ol0VOooooooo`0f
oooo002Goooo00<0000co`0co`002C?o00030000oooooooo047oool00ol0VOooooooo`0foooo002H
oooo00<0000co`0co`0023?o00800012oooo00?o09Woooooool0=_ooo`00V?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`11oooo00?o09Woooooool0=_ooo`00V?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`11oooo00?o09Woooooool0=_ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`11oooo00?o09Woooooool0=_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`11
oooo00?o09Woooooool0=_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`11oooo00?o
09Woooooool0=_ooo`00VOooo`030000<ol0<ol000Lco`020000@_ooo`03o`2Ioooooooo03Koool0
09[oool00`0003?o03?o0006<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009[oool0
0`0003?o03?o0006<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009[oool00`0003?o
03?o0006<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009[oool00`0003?o03?o0006
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009_oool500000c?o00030000oooooooo
047oool00ol0VOooooooo`0foooo002Koooo00<0000co`0000001C?o00030000oooooooo047oool0
0ol0VOooooooo`0foooo002Koooo00<0000co`0000001C?o00<00011oooo00?o09Woooooool0=_oo
o`00W?ooo`800005<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009coool200001C?o
00030000oooooooo047oool00ol0VOooooooo`0foooo002Loooo0P0000Dco`000`000?ooooooo`11
oooo00?o09Woooooool0=_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`11oooo00?o
09Woooooool0=_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`11oooo00?o09Wooooo
ool0=_ooo`00W?ooo`030000<ol0<ol000@co`020000@_ooo`03o`2Ioooooooo03Koool009goool0
0`0003?o03?o0003<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009goool00`0003?o
03?o0003<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009goool00`0003?o03?o0003
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool009goool00`0003?o03?o0003<ol000<0
003oooooool0@Oooo`03o`2Ioooooooo03Koool009goool00`0003?o03?o0003<ol000<0003ooooo
ool0@Oooo`03o`2Ioooooooo03Koool009goool00`0003?o03?o0003<ol00P0004;oool00ol0VOoo
ooooo`0foooo002Moooo00<0000co`0co`000c?o00030000oooooooo047oool00ol0VOooooooo`0f
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo047oool00ol0VOooooooo`0foooo002N
oooo00<0000co`0co`000S?o00030000oooooooo047oool00ol0VOooooooo`0foooo002Noooo00<0
000co`0co`000S?o00030000oooooooo047oool00ol0VOooooooo`0foooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo047oool00ol0VOooooooo`0foooo002Noooo00<0000co`0co`000S?o
00030000oooooooo047oool00ol0VOooooooo`0foooo002Noooo00<0000co`0co`000S?o00800012
oooo00?o09Woooooool0=_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`11oooo00?o
09Woooooool0=_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`11oooo00?o09Wooooo
ool0=_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`11oooo00?o09Woooooool0=_oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`11oooo00?o09Woooooool0=_ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`11oooo00?o09Woooooool0=_ooo`00W_ooo`030000
<ol0<ol0008co`020000@_ooo`03o`2Ioooooooo03Koool009ooool01@0003?o03?o03?o00000013
oooo00?o09Woooooool0=_ooo`00Woooo`050000<ol0<ol0<ol0000004?oool00ol0VOooooooo`0f
oooo002Ooooo00D0000co`0co`0co`000000@oooo`03o`2Ioooooooo03Koool009_oool500000c?o
00030000oooooooo047oool00ol0VOooooooo`0foooo002Koooo00D0003oooooooooool000000c?o
00030000oooooooo047oool00ol0VOooooooo`0foooo002Loooo00@0003oooooool00003<ol00`00
047oool00ol0VOooooooo`0foooo002Moooo00<0003oool000000c?o00030000oooooooo04;oool0
0ol0VOooooooo`0eoooo002Koooo00<0003oooooool00P0000<co`000`000?ooooooo`12oooo00?o
09Woooooool0=Oooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003oooooool0@_ooo`03o`2I
oooooooo03Goool009ooool01@0003?o03?o03?o00000014oooo00?o09Woooooool0=Oooo`00X?oo
o`040000<ol0<ol00000A?ooo`03o`2Ioooooooo03Goool00:3oool00`0003?o03?o00020000@ooo
o`03o`2Ioooooooo03Goool00:3oool0100003?o03?o000004Coool00ol0VOooooooo`0eoooo002P
oooo00@0000co`0co`000014oooo00?o09Woooooool0=Oooo`00X?ooo`040000<ol0<ol00000A?oo
o`03o`2Ioooooooo03Goool00:3oool0100003?o03?o000004Coool00ol0VOooooooo`0eoooo002P
oooo00@0000co`0co`000014oooo00?o09Woooooool0=Oooo`00X?ooo`040000<ol0<ol00000A?oo
o`03o`2Ioooooooo03Goool00:7oool0100003?o0000000004?oool00ol0VOooooooo`0eoooo002Q
oooo00<0000co`000000A?ooo`03o`2Ioooooooo03Goool00:7oool00`0003?o00000014oooo00?o
09Woooooool0=Oooo`00XOooo`030000<ol0000004Coool00ol0VOooooooo`0eoooo002Qoooo00<0
000co`000000A?ooo`03o`2Ioooooooo03Goool00:7oool00`0003?o00000014oooo00?o09Wooooo
ool0=Oooo`00XOooo`040000<ol000000000@oooo`03o`2Ioooooooo03Goool00:7oool00`0003?o
00000014oooo00?o09Woooooool0=Oooo`00XOooo`030000<ol0000004Coool00ol0VOooooooo`0e
oooo002Qoooo00<0000co`000000A?ooo`03o`2Ioooooooo03Goool00:7oool00`0003?o00000014
oooo00?o09Woooooool0=Oooo`00XOooo`030000<ol0000004Coool00ol0VOooooooo`0eoooo002Q
oooo00@0000co`0000000013oooo00?o09Woooooool0=Oooo`00XOooo`030000<ol0000004Coool0
0ol0VOooooooo`0eoooo002Qoooo00<0000co`000000A?ooo`03o`2Ioooooooo03Goool00:7oool0
0`0003?o00000014oooo00?o09Woooooool0=Oooo`00W?ooo`800003oooo00<0000co`000000A?oo
o`03o`2Ioooooooo03Goool009_oool010000?ooooooo`0000;oool00`0003?o00000014oooo00?o
09Woooooool0=Oooo`00WOooo`060000oooooooooooo0000<ol00`0004;oool00ol0VOooooooo`0e
oooo002Noooo00H0003oooooool0000co`000014oooo00?o09Woooooool0=Oooo`00Voooo`040000
oooooooo00000_ooo`030000<ol0000004Coool00ol0VOooooooo`0eoooo002Loooo0P0000Coool2
0000A?ooo`03o`2Ioooooooo03Goool00:;oool20000A?ooo`03o`2Ioooooooo03Goool00:;oool2
0000A?ooo`03o`2Ioooooooo03Goool00:;oool20000A?ooo`03o`2Ioooooooo03Goool00:;oool3
0000@oooo`03o`2Ioooooooo03Goool00:;oool20000A?ooo`03o`2Ioooooooo03Goool00:;oool2
0000A?ooo`03o`2Ioooooooo03Goool00:;oool20000A?ooo`03o`2Ioooooooo03Goool00:;oool2
0000A?ooo`03o`2Ioooooooo03Goool00:;oool20000A?ooo`03o`2Ioooooooo03Goool00:;oool3
0000@oooo`03o`2Ioooooooo03Goool00:;oool20000A?ooo`03o`2Ioooooooo03Goool00:;oool2
0000A?ooo`03o`2Ioooooooo03Goool00:;oool20000A?ooo`03o`2Ioooooooo03Goool00:;oool2
0000A?ooo`03o`2Ioooooooo03Goool00:;oool20000A?ooo`03o`2Ioooooooo03Goool00:;oool3
0000@oooo`03o`2Ioooooooo03Goool00:?oool00`000?ooooooo`12oooo00?o09Woooooool0=Ooo
o`00Xoooo`030000oooooooo04;oool00ol0VOooooooo`0eoooo002Soooo00<0003oooooool0@_oo
o`03o`2Ioooooooo03Goool00:?oool00`000?ooooooo`12oooo00?o09Woooooool0=Oooo`00Xooo
o`030000oooooooo04;oool00ol0VOooooooo`0eoooo002Soooo0P0004?oool00ol0VOooooooo`0e
oooo002Soooo00<0003oooooool0@_ooo`03o`2Ioooooooo03Goool00:?oool00`000?ooooooo`12
oooo00?o09Woooooool0=Oooo`00Xoooo`030000oooooooo04;oool00ol0VOooooooo`0eoooo002S
oooo00<0003oooooool0@_ooo`03o`2Ioooooooo03Goool009goool300000oooo`030000oooooooo
04;oool00ol0VOooooooo`0eoooo002Noooo00<0003oooooool00_ooo`030000oooooooo04;oool0
0ol0VOooooooo`0eoooo002Koooo1@0000?oool30000@_ooo`03o`2Ioooooooo03Goool009_oool0
10000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQ
oooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0
003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01_ooo`@00003oooo0P0000Goool300000_ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool00`000?ooooooo`0<oooo00D0003oooooooooool00000OOooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02?ooo`D00003oooo00<0003ooooo
ool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00009oooo00<0003oool000000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0A
oooo0P0000_oool200000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.81909 .12361 L
.82924 .12361 L
.83996 .12361 L
.84911 .12361 L
.85162 .12361 L
.85431 .12361 L
.85561 .12361 L
.85685 .12361 L
s
.85685 .12361 m
.85729 .61803 L
s
0 .4 1 r
.02381 .12299 m
.04262 .12275 L
.06244 .12239 L
.07286 .12214 L
.08255 .12186 L
.09388 .12147 L
.10458 .12102 L
.125 .11989 L
.14357 .11843 L
.16355 .11622 L
.18199 .11335 L
.20071 .10928 L
.21136 .10629 L
.22134 .10292 L
.24158 .09393 L
.26011 .08233 L
.27909 .06571 L
.28984 .05349 L
.29504 .04669 L
.29982 .03985 L
.30109 .03792 L
.30229 .03717 L
.30353 .0372 L
.30489 .03722 L
.31039 .03733 L
.32034 .03754 L
.33895 .03807 L
.3593 .03888 L
.37786 .03992 L
.39694 .04141 L
.40681 .04241 L
.4177 .04372 L
.43748 .04684 L
.44831 .04907 L
.45848 .05156 L
.49717 .06424 L
.51682 .07112 L
.52721 .07451 L
.53831 .07777 L
.54907 .08039 L
.55415 .08138 L
.55884 .08212 L
.56108 .0824 L
.56355 .08265 L
.56475 .08275 L
.56603 .08284 L
.56674 .08287 L
.56739 .0829 L
.56866 .08294 L
.56984 .08296 L
Mistroke
.57094 .08296 L
.57214 .08294 L
.57342 .08289 L
.57464 .08281 L
.57579 .08271 L
.57794 .08246 L
.58683 .08101 L
.59635 .07967 L
.60182 .07906 L
.6068 .07862 L
.6092 .07846 L
.6118 .07831 L
.613 .07826 L
.61426 .07821 L
.61535 .07818 L
.61654 .07816 L
.6178 .07814 L
.61844 .07814 L
.61913 .07813 L
.62036 .07814 L
.6215 .07816 L
.6222 .07817 L
.62286 .07819 L
.62409 .07823 L
.62541 .07829 L
.62685 .07837 L
.6293 .07855 L
.63188 .0788 L
.63652 .07941 L
.64171 .08038 L
.64656 .08159 L
.65188 .08329 L
.65759 .0856 L
.66775 .09116 L
.67349 .09525 L
.67881 .09976 L
.68918 .11081 L
.69426 .11747 L
.69649 .12068 L
.69766 .12245 L
.69892 .12361 L
.70011 .12361 L
.70118 .12361 L
.70329 .12361 L
.70789 .12361 L
.71756 .12361 L
.73816 .12361 L
.77811 .12361 L
.81654 .12361 L
.85743 .12361 L
Mistroke
.8968 .12361 L
.93465 .12361 L
.97496 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001Moooo00<0
I_ooooooool0@oooo`030000oooooooo07[oool005cooolG06Ko<?ooo`030000oooooooo07[oool0
05_oool00`1Vooooooooo`0Eoooo2P1VobKoool00`000?ooooooo`1joooo001Koooo00<0I_oooooo
ool07oooo`@0I_lRoooo00<0003oooooool0N_ooo`00F_ooo`0306Kooooooooo02Coool506Ko7Ooo
o`80001koooo001Joooo00<0I_ooooooool0:Oooo`<0I_lJoooo00<0003oooooool0N_ooo`00FOoo
o`0306Kooooooooo02goool406Ko5_ooo`030000oooooooo07[oool005Soool00`1Vooooooooo`0b
oooo0`1Voa?oool00`000?ooooooo`1joooo001Goooo00<0I_ooooooool0=_ooo`80I_lAoooo00<0
003oooooool0N_ooo`00E_ooo`0306Kooooooooo03Woool306Ko3_ooo`030000oooooooo07[oool0
05Coool206Ko?oooo`<0I_l;oooo0P0007_oool002_oool300009Oooo`0306Kooooooooo00<0000S
oooo100001Soool406Ko1oooo`040000oooooooooooo3@1VoaGoool400009oooo`<0000Yoooo000[
oooo00@0003oooooool0000Soooo00<0I_ooooooool00_ooo`030000oooooooo02;oool00`000?oo
ooooo`0Moooo1`1Vo`04000006Ko06Ko06Ko3Oooo`80I_lCoooo00<0003oooooool0:Oooo`030000
oooooooo02Soool002_oool010000?ooooooo`00027oool206Ko0_ooo`D0000Toooo00<0003ooooo
ool08oooo`030000oooooooo013oool306Ko4Oooo`030000oooooooo02Goool50000:Oooo`009Ooo
o`@00002oooo0`00023oool400000_ooo`040000oooooooo00007_ooo`@00004oooo00<0003ooooo
ool08_ooo`030000oooooooo01?oool206Ko4?ooo`030000oooooooo02Coool010000?ooooooo`00
02[oool002coool00`000?ooooooo`0Moooo0P1Vo`Ooool00`000?ooo`00000Toooo00@0003ooooo
ool0000Soooo00<0003oooooool05Oooo`0306Kooooooooo00_oool010000?ooooooo`0002Koool0
0`000?ooo`00000Zoooo000/oooo0`0001_oool206Ko2_ooo`80000Uoooo0P0002Coool200005ooo
o`0306Kooooooooo00_oool20000:?ooo`80000Zoooo0018oooo0P1VoeWoool00`000?ooooooo`0G
oooo00<0I_ooooooool0H?ooo`00AOooo`<0I_mKoooo00<0003oooooool06?ooo`0306Kooooooooo
05ooool0047oool406KoG_ooo`030000oooooooo01Woool00`1Vooooooooo`1Noooo000moooo101V
of;oool00`000?ooooooo`0Ioooo00<0I_ooooooool0G_ooo`00;_ooo`l0I_mVoooo00<0003ooooo
ool06_ooo`0306Kooooooooo05goool0013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00?o09T0003oool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_oo
o`@0000K<ol000<0003oooooool09Oooo`030000oooooooo01_oool00ol0VOooooooo`08oooo00<0
003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool0
08coool00`0003?o03?o000D<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool008goool2
000053?o00030000oooooooo04?oool00ol0VOooooooo`0doooo002?oooo00<0000co`0co`004C?o
00030000oooooooo04?oool00ol0VOooooooo`0doooo002@oooo00<0000co`0co`0043?o00800014
oooo00?o09Woooooool0=?ooo`00TOooo`80000@<ol000<0003oooooool0@oooo`03o`2Ioooooooo
03Coool009?oool00`0003?o03?o000=<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool0
09?oool00`0003?o03?o000=<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009Coool0
0`0003?o03?o000<<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009Coool00`0003?o
03?o000<<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009Goool00`0003?o03?o000;
<ol00P0004Coool00ol0VOooooooo`0doooo002Eoooo00<0000co`0co`002c?o00030000oooooooo
04?oool00ol0VOooooooo`0doooo002Foooo00<0000co`0co`002S?o00030000oooooooo04?oool0
0ol0VOooooooo`0doooo002Foooo00<0000co`0co`002S?o00030000oooooooo04?oool00ol0VOoo
ooooo`0doooo002Goooo00<0000co`0co`002C?o00030000oooooooo04?oool00ol0VOooooooo`0d
oooo002Goooo00<0000co`0co`002C?o00030000oooooooo04?oool00ol0VOooooooo`0doooo002H
oooo00<0000co`0co`0023?o00800014oooo00?o09Woooooool0=?ooo`00V?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`13oooo00?o09Woooooool0=?ooo`00V?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`13oooo00?o09Woooooool0=?ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`13oooo00?o09Woooooool0=?ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`13
oooo00?o09Woooooool0=?ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`13oooo00?o
09Woooooool0=?ooo`00VOooo`030000<ol0<ol000Lco`020000A?ooo`03o`2Ioooooooo03Coool0
09[oool00`0003?o03?o0006<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009[oool0
0`0003?o03?o0006<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009[oool00`0003?o
03?o0006<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009[oool00`0003?o03?o0006
<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009_oool500000c?o00030000oooooooo
04?oool00ol0VOooooooo`0doooo002Koooo00<0000co`0000001C?o00030000oooooooo04?oool0
0ol0VOooooooo`0doooo002Koooo00<0000co`0000001C?o00<00013oooo00?o09Woooooool0=?oo
o`00W?ooo`800005<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009coool200001C?o
00030000oooooooo04?oool00ol0VOooooooo`0doooo002Loooo0P0000Dco`000`000?ooooooo`13
oooo00?o09Woooooool0=?ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`13oooo00?o
09Woooooool0=?ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`13oooo00?o09Wooooo
ool0=?ooo`00W?ooo`030000<ol0<ol000@co`020000A?ooo`03o`2Ioooooooo03Coool009goool0
0`0003?o03?o0003<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009goool00`0003?o
03?o0003<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009goool00`0003?o03?o0003
<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Coool009goool00`0003?o03?o0003<ol000<0
003oooooool0@oooo`03o`2Ioooooooo03Coool009goool00`0003?o03?o0003<ol000<0003ooooo
ool0@oooo`03o`2Ioooooooo03Coool009goool00`0003?o03?o0003<ol00P0004Coool00ol0VOoo
ooooo`0doooo002Moooo00<0000co`0co`000c?o00030000oooooooo04?oool00ol0VOooooooo`0d
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo04?oool00ol0VOooooooo`0doooo002N
oooo00<0000co`0co`000S?o00030000oooooooo04?oool00ol0VOooooooo`0doooo002Noooo00<0
000co`0co`000S?o00030000oooooooo04?oool00ol0VOooooooo`0doooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo04?oool00ol0VOooooooo`0doooo002Noooo00<0000co`0co`000S?o
00030000oooooooo04?oool00ol0VOooooooo`0doooo002Noooo00<0000co`0co`000S?o00800014
oooo00?o09Woooooool0=?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`13oooo00?o
09Woooooool0=?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`13oooo00?o09Wooooo
ool0=?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`13oooo00?o09Woooooool0=?oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`13oooo00?o09Woooooool0=?ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`13oooo00?o09Woooooool0=?ooo`00W_ooo`030000
<ol0<ol0008co`020000A?ooo`03o`2Ioooooooo03Coool009ooool01@0003?o03?o03?o00000015
oooo00?o09Woooooool0=?ooo`00Woooo`050000<ol0<ol0<ol0000004Goool00ol0VOooooooo`0d
oooo002Ooooo00D0000co`0co`0co`000000AOooo`03o`2Ioooooooo03Coool009_oool500000c?o
00030000oooooooo04?oool00ol0VOooooooo`0doooo002Koooo00D0003oooooooooool000000c?o
00030000oooooooo04?oool00ol0VOooooooo`0doooo002Loooo00@0003oooooool00003<ol00`00
04?oool00ol0VOooooooo`0doooo002Moooo00<0003oool000000c?o00030000oooooooo04Coool0
0ol0VOooooooo`0coooo002Koooo00<0003oooooool00P0000<co`000`000?ooooooo`14oooo00?o
09Woooooool0<oooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003oooooool0A?ooo`03o`2I
oooooooo03?oool009ooool01@0003?o03?o03?o00000016oooo00?o09Woooooool0<oooo`00X?oo
o`040000<ol0<ol00000A_ooo`03o`2Ioooooooo03?oool00:3oool00`0003?o03?o00020000AOoo
o`03o`2Ioooooooo03?oool00:3oool0100003?o03?o000004Koool00ol0VOooooooo`0coooo002P
oooo00@0000co`0co`000016oooo00?o09Woooooool0<oooo`00X?ooo`040000<ol0<ol00000A_oo
o`03o`2Ioooooooo03?oool00:3oool0100003?o03?o000004Koool00ol0VOooooooo`0coooo002P
oooo00@0000co`0co`000016oooo00?o09Woooooool0<oooo`00X?ooo`040000<ol0<ol00000A_oo
o`03o`2Ioooooooo03?oool00:7oool0100003?o0000000004Goool00ol0VOooooooo`0coooo002Q
oooo00<0000co`000000A_ooo`03o`2Ioooooooo03?oool00:7oool00`0003?o00000016oooo00?o
09Woooooool0<oooo`00XOooo`030000<ol0000004Koool00ol0VOooooooo`0coooo002Qoooo00<0
000co`000000A_ooo`03o`2Ioooooooo03?oool00:7oool00`0003?o00000016oooo00?o09Wooooo
ool0<oooo`00XOooo`040000<ol000000000AOooo`03o`2Ioooooooo03?oool00:7oool00`0003?o
00000016oooo00?o09Woooooool0<oooo`00XOooo`030000<ol0000004Koool00ol0VOooooooo`0c
oooo002Qoooo00<0000co`000000A_ooo`03o`2Ioooooooo03?oool00:7oool00`0003?o00000016
oooo00?o09Woooooool0<oooo`00XOooo`030000<ol0000004Koool00ol0VOooooooo`0coooo002Q
oooo00@0000co`0000000015oooo00?o09Woooooool0<oooo`00XOooo`030000<ol0000004Koool0
0ol0VOooooooo`0coooo002Qoooo00<0000co`000000A_ooo`03o`2Ioooooooo03?oool00:7oool0
0`0003?o00000016oooo00?o09Woooooool0<oooo`00W?ooo`800003oooo00<0000co`000000A_oo
o`03o`2Ioooooooo03?oool009_oool010000?ooooooo`0000;oool00`0003?o00000016oooo00?o
09Woooooool0<oooo`00WOooo`060000oooooooooooo0000<ol00`0004Coool00ol0VOooooooo`0c
oooo002Noooo00H0003oooooool0000co`000016oooo00?o09Woooooool0<oooo`00Voooo`040000
oooooooo00000_ooo`030000<ol0000004Koool00ol0VOooooooo`0coooo002Loooo0P0000Coool2
0000A_ooo`03o`2Ioooooooo03?oool00:;oool20000A_ooo`03o`2Ioooooooo03?oool00:;oool2
0000A_ooo`03o`2Ioooooooo03?oool00:;oool20000A_ooo`03o`2Ioooooooo03?oool00:;oool3
0000AOooo`03o`2Ioooooooo03?oool00:;oool20000A_ooo`03o`2Ioooooooo03?oool00:;oool2
0000A_ooo`03o`2Ioooooooo03?oool00:;oool20000A_ooo`03o`2Ioooooooo03?oool00:;oool2
0000A_ooo`03o`2Ioooooooo03?oool00:;oool20000A_ooo`03o`2Ioooooooo03?oool00:;oool3
0000AOooo`03o`2Ioooooooo03?oool00:;oool20000A_ooo`03o`2Ioooooooo03?oool00:;oool2
0000A_ooo`03o`2Ioooooooo03?oool00:;oool20000A_ooo`03o`2Ioooooooo03?oool00:;oool2
0000A_ooo`03o`2Ioooooooo03?oool00:;oool20000A_ooo`03o`2Ioooooooo03?oool00:;oool3
0000AOooo`03o`2Ioooooooo03?oool00:?oool00`000?ooooooo`14oooo00?o09Woooooool0<ooo
o`00Xoooo`030000oooooooo04Coool00ol0VOooooooo`0coooo002Soooo00<0003oooooool0A?oo
o`03o`2Ioooooooo03?oool00:?oool00`000?ooooooo`14oooo00?o09Woooooool0<oooo`00Xooo
o`030000oooooooo04Coool00ol0VOooooooo`0coooo002Soooo0P0004Goool00ol0VOooooooo`0c
oooo002Soooo00<0003oooooool0A?ooo`03o`2Ioooooooo03?oool00:?oool00`000?ooooooo`14
oooo00?o09Woooooool0<oooo`00Xoooo`030000oooooooo04Coool00ol0VOooooooo`0coooo002S
oooo00<0003oooooool0A?ooo`03o`2Ioooooooo03?oool009goool300000oooo`030000oooooooo
04Coool00ol0VOooooooo`0coooo002Noooo00<0003oooooool00_ooo`030000oooooooo04Coool0
0ol0VOooooooo`0coooo002Koooo1@0000?oool30000A?ooo`03o`2Ioooooooo03?oool009_oool0
10000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQ
oooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0
003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01_ooo`@00003oooo0P0000Coool200001?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00003oooo00<0003oooooool0Nooo
o`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02oooo`030000
oooooooo00;oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?oo
ooooo`08oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003ooo
o`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0
003oooooool04Oooo`80000:oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.84911 .12361 L
.85396 .12361 L
.85916 .12361 L
.86176 .12361 L
.86305 .12361 L
.86423 .12361 L
s
.86423 .12361 m
.86466 .61803 L
s
0 .4 1 r
.02381 .1229 m
.04262 .12262 L
.06244 .1222 L
.07286 .12192 L
.08255 .1216 L
.09388 .12115 L
.10458 .12063 L
.125 .11932 L
.14357 .11764 L
.16355 .1151 L
.18199 .11178 L
.20071 .1071 L
.21136 .10365 L
.22134 .09977 L
.24158 .08942 L
.26011 .07605 L
.2807 .05496 L
.28586 .04835 L
.29073 .04153 L
.29285 .03837 L
.29392 .03715 L
.29509 .03717 L
.29755 .03721 L
.29982 .03725 L
.3183 .03766 L
.33801 .03828 L
.35752 .03913 L
.36846 .03976 L
.37844 .04045 L
.39752 .04216 L
.40739 .04329 L
.41828 .04479 L
.43806 .04837 L
.44889 .05092 L
.45906 .05378 L
.49775 .067 L
.5174 .07374 L
.52779 .07699 L
.53889 .08005 L
.54442 .08137 L
.54964 .08246 L
.55473 .08334 L
.55696 .08367 L
.55942 .08397 L
.56156 .08419 L
.56387 .08438 L
.56514 .08445 L
.5663 .08451 L
.56747 .08454 L
.56858 .08456 L
Mistroke
.56977 .08456 L
.57105 .08453 L
.57225 .08449 L
.57333 .08443 L
.57462 .08433 L
.576 .08419 L
.57851 .08383 L
.5981 .08051 L
.60347 .07978 L
.60921 .07912 L
.612 .07885 L
.61463 .07863 L
.61698 .07847 L
.61957 .07832 L
.62076 .07827 L
.62204 .07822 L
.62324 .07818 L
.62435 .07816 L
.62553 .07814 L
.62682 .07813 L
.62747 .07814 L
.62817 .07814 L
.62942 .07816 L
.6306 .07818 L
.63188 .07822 L
.63308 .07828 L
.63419 .07833 L
.6363 .07847 L
.63852 .07866 L
.64097 .07893 L
.64359 .07928 L
.64833 .08011 L
.65397 .08144 L
.65911 .08304 L
.66901 .08728 L
.67817 .09284 L
.68823 .10115 L
.69892 .11307 L
.70348 .11929 L
.70458 .12092 L
.70577 .12271 L
.70707 .12361 L
.70828 .12361 L
.71354 .12361 L
.71837 .12361 L
.73664 .12361 L
.77811 .12361 L
.81806 .12361 L
.85649 .12361 L
.89738 .12361 L
Mistroke
.93675 .12361 L
.9746 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001Koooo0P1V
odKoool00`000?ooooooo`1joooo001Joooo00<0I_ooool0I_l05P1Voc3oool00`000?ooooooo`1j
oooo001Joooo00<0I_ooooooool05_ooo`X0I_lVoooo00<0003oooooool0N_ooo`00FOooo`0306Ko
oooooooo027oool406Ko8_ooo`030000oooooooo07[oool005Soool00`1Vooooooooo`0Voooo0`1V
oaooool20000Noooo`00Eoooo`0306Kooooooooo02[oool306Ko7?ooo`030000oooooooo07[oool0
05Koool00`1Vooooooooo`0^oooo0`1VoaWoool00`000?ooooooo`1joooo001Eoooo00<0I_oooooo
ool0<_ooo`<0I_lFoooo00<0003oooooool0N_ooo`00E?ooo`0306Kooooooooo03Koool306Ko4ooo
o`030000oooooooo07[oool005?oool00`1Vooooooooo`0joooo0P1Voa7oool00`000?ooooooo`1j
oooo001Boooo00<0I_ooooooool0?Oooo`<0I_l>oooo0P0007_oool002_oool300008oooo`0306Ko
oooooooo00;oool300008oooo`@0000Eoooo1@1Vo`Woool00`000?ooooooo`0@06Ko4oooo`@0000W
oooo0`0002Woool002_oool010000?ooooooo`00023oool206Ko1_ooo`030000oooooooo02;oool0
0`000?ooooooo`0Koooo2@1Vo`03000006Ko06Ko013oool306Ko4?ooo`030000oooooooo02Woool0
0`000?ooooooo`0Xoooo000[oooo00@0003oooooool0000Ooooo00<0I_ooooooool00oooo`D0000T
oooo00<0003oooooool08?ooo`80I_l00oooo`000?ooo`0Doooo0P1Vo`ooool00`000?ooooooo`0U
oooo1@0002Woool002Goool400000_ooo`<0000Noooo0P1Vo`@00002oooo00@0003oooooool0000N
oooo100000Coool00`000?ooooooo`0Roooo00<0003oooooool05Oooo`0306Kooooooooo00goool0
0`000?ooooooo`0Toooo00@0003oooooool0000Zoooo000/oooo00<0003oooooool06oooo`80I_l9
oooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo01Koool00`1Voooo
ooooo`0:oooo00@0003oooooool0000Voooo00<0003oool00000:_ooo`00;?ooo`<0000Ioooo0P1V
o`coool200009Oooo`80000Toooo0P0001Soool206Ko2oooo`80000Xoooo0P0002[oool004Goool3
06KoFoooo`030000oooooooo01Woool00`1Vooooooooo`1Noooo0011oooo101Voekoool00`000?oo
ooooo`0Joooo00<0I_ooooooool0GOooo`00?Oooo`@0I_mRoooo00<0003oooooool06_ooo`0306Ko
oooooooo05goool003Soool506KoI_ooo`030000oooooooo01_oool00`1Vooooooooo`1Loooo000^
oooo2P1Vof_oool00`000?ooooooo`0Loooo0P1Voecoool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooo0000010000000c?o000003?o0008<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003o09Woool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo02Koool00`000?ooooooo`0Uoooo00<0
003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000oooooooo01goool00ol0VOoo
ooooo`06oooo00<0003oooooool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool0AOooo`03o`2I
oooooooo03;oool008coool00`0003?o03?o000D<ol000<0003oooooool0AOooo`03o`2Ioooooooo
03;oool008goool2000053?o00030000oooooooo04Goool00ol0VOooooooo`0boooo002?oooo00<0
000co`0co`004C?o00030000oooooooo04Goool00ol0VOooooooo`0boooo002@oooo00<0000co`0c
o`0043?o00800016oooo00?o09Woooooool0<_ooo`00TOooo`80000@<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo03;oool009?oool00`0003?o03?o000=<ol000<0003oooooool0AOooo`03o`2I
oooooooo03;oool009?oool00`0003?o03?o000=<ol000<0003oooooool0AOooo`03o`2Ioooooooo
03;oool009Coool00`0003?o03?o000<<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool0
09Coool00`0003?o03?o000<<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool009Goool0
0`0003?o03?o000;<ol00P0004Koool00ol0VOooooooo`0boooo002Eoooo00<0000co`0co`002c?o
00030000oooooooo04Goool00ol0VOooooooo`0boooo002Foooo00<0000co`0co`002S?o00030000
oooooooo04Goool00ol0VOooooooo`0boooo002Foooo00<0000co`0co`002S?o00030000oooooooo
04Goool00ol0VOooooooo`0boooo002Goooo00<0000co`0co`002C?o00030000oooooooo04Goool0
0ol0VOooooooo`0boooo002Goooo00<0000co`0co`002C?o00030000oooooooo04Goool00ol0VOoo
ooooo`0boooo002Hoooo00<0000co`0co`0023?o00800016oooo00?o09Woooooool0<_ooo`00V?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`15oooo00?o09Woooooool0<_ooo`00V?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`15oooo00?o09Woooooool0<_ooo`00VOooo`030000<ol0<ol0
00Lco`000`000?ooooooo`15oooo00?o09Woooooool0<_ooo`00VOooo`030000<ol0<ol000Lco`00
0`000?ooooooo`15oooo00?o09Woooooool0<_ooo`00VOooo`030000<ol0<ol000Lco`000`000?oo
ooooo`15oooo00?o09Woooooool0<_ooo`00VOooo`030000<ol0<ol000Lco`020000A_ooo`03o`2I
oooooooo03;oool009[oool00`0003?o03?o0006<ol000<0003oooooool0AOooo`03o`2Ioooooooo
03;oool009[oool00`0003?o03?o0006<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool0
09[oool00`0003?o03?o0006<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool009[oool0
0`0003?o03?o0006<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool009_oool500000c?o
00030000oooooooo04Goool00ol0VOooooooo`0boooo002Koooo00<0000co`0000001C?o00030000
oooooooo04Goool00ol0VOooooooo`0boooo002Koooo00<0000co`0000001C?o00<00015oooo00?o
09Woooooool0<_ooo`00W?ooo`800005<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool0
09coool200001C?o00030000oooooooo04Goool00ol0VOooooooo`0boooo002Loooo0P0000Dco`00
0`000?ooooooo`15oooo00?o09Woooooool0<_ooo`00W?ooo`030000<ol0<ol000@co`000`000?oo
ooooo`15oooo00?o09Woooooool0<_ooo`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`15
oooo00?o09Woooooool0<_ooo`00W?ooo`030000<ol0<ol000@co`020000A_ooo`03o`2Ioooooooo
03;oool009goool00`0003?o03?o0003<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool0
09goool00`0003?o03?o0003<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool009goool0
0`0003?o03?o0003<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool009goool00`0003?o
03?o0003<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool009goool00`0003?o03?o0003
<ol000<0003oooooool0AOooo`03o`2Ioooooooo03;oool009goool00`0003?o03?o0003<ol00P00
04Koool00ol0VOooooooo`0boooo002Moooo00<0000co`0co`000c?o00030000oooooooo04Goool0
0ol0VOooooooo`0boooo002Moooo00<0000co`0co`000c?o00030000oooooooo04Goool00ol0VOoo
ooooo`0boooo002Noooo00<0000co`0co`000S?o00030000oooooooo04Goool00ol0VOooooooo`0b
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo04Goool00ol0VOooooooo`0boooo002N
oooo00<0000co`0co`000S?o00030000oooooooo04Goool00ol0VOooooooo`0boooo002Noooo00<0
000co`0co`000S?o00030000oooooooo04Goool00ol0VOooooooo`0boooo002Noooo00<0000co`0c
o`000S?o00800016oooo00?o09Woooooool0<_ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`15oooo00?o09Woooooool0<_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`15
oooo00?o09Woooooool0<_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`15oooo00?o
09Woooooool0<_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`15oooo00?o09Wooooo
ool0<_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`15oooo00?o09Woooooool0<_oo
o`00W_ooo`030000<ol0<ol0008co`020000A_ooo`03o`2Ioooooooo03;oool009ooool01@0003?o
03?o03?o00000017oooo00?o09Woooooool0<_ooo`00Woooo`050000<ol0<ol0<ol0000004Ooool0
0ol0VOooooooo`0boooo002Ooooo00D0000co`0co`0co`000000Aoooo`03o`2Ioooooooo03;oool0
09_oool500000c?o00030000oooooooo04Goool00ol0VOooooooo`0boooo002Koooo00D0003ooooo
ooooool000000c?o00030000oooooooo04Goool00ol0VOooooooo`0boooo002Loooo00@0003ooooo
ool00003<ol00`0004Goool00ol0VOooooooo`0boooo002Moooo00<0003oool000000c?o00030000
oooooooo04Goool00ol0VOooooooo`0boooo002Koooo00<0003oooooool00P0000<co`000`000?oo
ooooo`15oooo00?o09Woooooool0<_ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo03;oool009ooool01@0003?o03?o03?o00000017oooo00?o09Wooooo
ool0<_ooo`00X?ooo`040000<ol0<ol00000Aoooo`03o`2Ioooooooo03;oool00:3oool00`0003?o
03?o00020000A_ooo`03o`2Ioooooooo03;oool00:3oool0100003?o03?o000004Ooool00ol0VOoo
ooooo`0boooo002Poooo00@0000co`0co`000017oooo00?o09Woooooool0<_ooo`00X?ooo`040000
<ol0<ol00000Aoooo`03o`2Ioooooooo03;oool00:3oool0100003?o03?o000004Ooool00ol0VOoo
ooooo`0boooo002Poooo00@0000co`0co`000017oooo00?o09Woooooool0<_ooo`00X?ooo`040000
<ol0<ol00000Aoooo`03o`2Ioooooooo03;oool00:7oool0100003?o0000000004Koool00ol0VOoo
ooooo`0boooo002Qoooo00<0000co`000000Aoooo`03o`2Ioooooooo03;oool00:7oool00`0003?o
00000017oooo00?o09Woooooool0<_ooo`00XOooo`030000<ol0000004Ooool00ol0VOooooooo`0b
oooo002Qoooo00<0000co`000000Aoooo`03o`2Ioooooooo03;oool00:7oool00`0003?o00000017
oooo00?o09Woooooool0<_ooo`00XOooo`040000<ol000000000A_ooo`03o`2Ioooooooo03;oool0
0:7oool00`0003?o00000017oooo00?o09Woooooool0<_ooo`00XOooo`030000<ol0000004Ooool0
0ol0VOooooooo`0boooo002Qoooo00<0000co`000000Aoooo`03o`2Ioooooooo03;oool00:7oool0
0`0003?o00000017oooo00?o09Woooooool0<_ooo`00XOooo`030000<ol0000004Ooool00ol0VOoo
ooooo`0boooo002Qoooo00@0000co`0000000016oooo00?o09Woooooool0<_ooo`00XOooo`030000
<ol0000004Ooool00ol0VOooooooo`0boooo002Qoooo00<0000co`000000Aoooo`03o`2Ioooooooo
03;oool00:7oool00`0003?o00000017oooo00?o09Woooooool0<_ooo`00W?ooo`800003oooo00<0
000co`000000Aoooo`03o`2Ioooooooo03;oool009_oool010000?ooooooo`0000;oool00`0003?o
00000017oooo00?o09Woooooool0<_ooo`00WOooo`060000oooooooooooo0000<ol00`0004Goool0
0ol0VOooooooo`0boooo002Noooo00H0003oooooool0000co`000017oooo00?o09Woooooool0<_oo
o`00Voooo`040000oooooooo00000_ooo`030000<ol0000004Ooool00ol0VOooooooo`0boooo002L
oooo0P0000Coool20000Aoooo`03o`2Ioooooooo03;oool00:;oool20000Aoooo`03o`2Ioooooooo
03;oool00:;oool20000Aoooo`03o`2Ioooooooo03;oool00:;oool20000Aoooo`03o`2Ioooooooo
03;oool00:;oool30000A_ooo`03o`2Ioooooooo03;oool00:;oool20000Aoooo`03o`2Ioooooooo
03;oool00:;oool20000Aoooo`03o`2Ioooooooo03;oool00:;oool20000Aoooo`03o`2Ioooooooo
03;oool00:;oool20000Aoooo`03o`2Ioooooooo03;oool00:;oool20000Aoooo`03o`2Ioooooooo
03;oool00:;oool30000A_ooo`03o`2Ioooooooo03;oool00:;oool20000Aoooo`03o`2Ioooooooo
03;oool00:;oool20000Aoooo`03o`2Ioooooooo03;oool00:;oool20000Aoooo`03o`2Ioooooooo
03;oool00:;oool20000Aoooo`03o`2Ioooooooo03;oool00:;oool20000Aoooo`03o`2Ioooooooo
03;oool00:;oool30000A_ooo`03o`2Ioooooooo03;oool00:?oool00`000?ooooooo`15oooo00?o
09Woooooool0<_ooo`00Xoooo`030000oooooooo04Goool00ol0VOooooooo`0boooo002Soooo00<0
003oooooool0AOooo`03o`2Ioooooooo03;oool00:?oool00`000?ooooooo`15oooo00?o09Wooooo
ool0<_ooo`00Xoooo`030000oooooooo04Goool00ol0VOooooooo`0boooo002Soooo0P0004Koool0
0ol0VOooooooo`0boooo002Soooo00<0003oooooool0AOooo`03o`2Ioooooooo03;oool00:?oool0
0`000?ooooooo`15oooo00?o09Woooooool0<_ooo`00Xoooo`030000oooooooo04Goool00ol0VOoo
ooooo`0boooo002Soooo00<0003oooooool0AOooo`03o`2Ioooooooo03;oool009goool300000ooo
o`030000oooooooo04Goool00ol0VOooooooo`0boooo002Noooo00<0003oooooool00_ooo`030000
oooooooo04Goool00ol0VOooooooo`0boooo002Koooo1@0000?oool30000AOooo`03o`2Ioooooooo
03;oool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002Moooo0P00
087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003oooo0P0000?oool3
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooooo
ool02?ooo`040000oooooooo00001?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`05
00003_ooo`030000oooooooo00Ooool300001?ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo
07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo07coool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.84911 .12361 L
.85916 .12361 L
.86384 .12361 L
.86642 .12361 L
.86886 .12361 L
.87112 .12361 L
.8724 .12361 L
s
.8724 .12361 m
.87288 .61803 L
s
0 .4 1 r
.02381 .12279 m
.04262 .12247 L
.06244 .12199 L
.07286 .12166 L
.08255 .12129 L
.09388 .12077 L
.10458 .12018 L
.125 .11867 L
.14357 .11674 L
.16355 .1138 L
.18199 .10999 L
.20071 .10459 L
.21136 .10062 L
.22134 .09615 L
.24158 .08422 L
.26011 .06881 L
.27008 .05816 L
.27555 .05146 L
.2807 .04452 L
.28304 .04115 L
.28432 .03925 L
.28552 .03743 L
.28681 .03715 L
.2875 .03716 L
.28823 .03717 L
.29073 .03722 L
.29982 .0374 L
.3198 .03791 L
.33801 .03856 L
.3571 .03951 L
.36788 .0402 L
.37786 .04098 L
.39652 .04285 L
.41712 .04577 L
.43647 .04966 L
.45733 .05554 L
.49847 .06985 L
.51899 .07667 L
.529 .07963 L
.53809 .082 L
.54693 .08393 L
.55159 .08476 L
.55651 .08546 L
.55902 .08575 L
.56035 .08587 L
.56178 .08599 L
.56309 .08608 L
.56429 .08614 L
.5655 .08619 L
.56664 .08622 L
Mistroke
.56779 .08624 L
.56901 .08623 L
.57017 .08621 L
.57121 .08617 L
.57245 .0861 L
.57378 .086 L
.57504 .08588 L
.5762 .08574 L
.59666 .08199 L
.60665 .08042 L
.61574 .07927 L
.62026 .07882 L
.62265 .07863 L
.62517 .07845 L
.62738 .07833 L
.62855 .07827 L
.62981 .07822 L
.63097 .07819 L
.63203 .07816 L
.63304 .07815 L
.6341 .07814 L
.63534 .07814 L
.63646 .07814 L
.63775 .07816 L
.63897 .0782 L
.6401 .07824 L
.64115 .07828 L
.6435 .07842 L
.64588 .07861 L
.64849 .07888 L
.65376 .07964 L
.65899 .0807 L
.66395 .08203 L
.67325 .0855 L
.67845 .08807 L
.68326 .09092 L
.69415 .09928 L
.70388 .1094 L
.709 .1159 L
.71179 .11983 L
.71315 .12186 L
.71438 .12361 L
.71556 .12361 L
.71667 .12361 L
.71911 .12361 L
.72429 .12361 L
.73339 .12361 L
.77111 .12361 L
.80954 .12361 L
.85043 .12361 L
Mistroke
.8898 .12361 L
.92765 .12361 L
.96796 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001Ioooo0P1V
odSoool00`000?ooooooo`1joooo001Hoooo0P1Vo`03oooo06Ko06Ko01H0I_l`oooo00<0003ooooo
ool0N_ooo`00Eoooo`0306Kooooooooo01Woool506Ko:oooo`030000oooooooo07[oool005Koool0
0`1Vooooooooo`0Ooooo1@1VobKoool00`000?ooooooo`1joooo001Foooo00<0I_ooooooool09?oo
o`D0I_lQoooo0P0007_oool005Goool00`1Vooooooooo`0Zoooo101Voagoool00`000?ooooooo`1j
oooo001Eoooo00<0I_ooooooool0;_ooo`<0I_lJoooo00<0003oooooool0N_ooo`00E?ooo`0306Ko
oooooooo03;oool206Ko6?ooo`030000oooooooo07[oool005?oool00`1Vooooooooo`0eoooo0`1V
oaGoool00`000?ooooooo`1joooo001Boooo00<0I_ooooooool0>Oooo`<0I_lBoooo00<0003ooooo
ool0N_ooo`00D?ooo`80I_looooo0P1Voa3oool20000Noooo`00:oooo`<0000Poooo0P1Vo`Koool3
00008oooo`@0000Coooo1@1Vo`_oool00`000?ooooooo`03oooo3P1Voa;oool400009oooo`<0000Y
oooo000[oooo00@0003oooooool0000Noooo00<0I_ooooooool01oooo`030000oooooooo02;oool0
0`000?ooooooo`0Ioooo101Vo`Ooool00`000?ooo`1Vo`0306Ko3_ooo`<0I_l?oooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0001coool206Ko1oooo`D0000T
oooo00<0003oooooool07?ooo`L0I_l00`00001Vooooo`0Doooo0`1Vo`goool00`000?ooooooo`0U
oooo1@0002Woool002Goool400000_ooo`<0000Koooo0P1Vo`?oool400000_ooo`040000oooooooo
00007_ooo`@00004oooo00<0003oooooool08_ooo`030000oooooooo01Ooool00`1Vooooooooo`0;
oooo00<0003oooooool09?ooo`040000oooooooo0000:_ooo`00;?ooo`030000oooooooo01Woool0
0`1Vooooooooo`0:oooo00<0003oool000009?ooo`040000oooooooo00008oooo`030000oooooooo
01Soool206Ko2Oooo`040000oooooooo00009_ooo`030000oooo000002[oool002coool300006?oo
o`0306Kooooooooo00coool200009Oooo`80000Toooo0P0001_oool00`1Vooooooooo`07oooo0P00
02Soool20000:_ooo`00AOooo`80I_mLoooo00<0003oooooool06oooo`0306Kooooooooo05coool0
047oool406KoG_ooo`030000oooooooo01coool00`1Vooooooooo`1Koooo000moooo101Vof;oool0
0`000?ooooooo`0Moooo00<0I_ooooooool0F_ooo`00>?ooo`D0I_mVoooo00<0003oooooool07_oo
o`0306Kooooooooo05Woool002koool:06KoJoooo`030000oooooooo01ooool00`1Vooooooooo`1H
oooo000@ooooo`00017oool001Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`00000@
000000<co`00000co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`040000ooooooooo`2I1_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000
oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_ooo`@0000K<ol000<0003ooooo
ool09Oooo`030000oooooooo01ooool00ol0VOooooooo`04oooo00<0003oooooool0:Oooo`00R?oo
o`@0000G<ol000<0003oooooool0Aoooo`03o`2Ioooooooo033oool008coool00`0003?o03?o000D
<ol000<0003oooooool0Aoooo`03o`2Ioooooooo033oool008goool2000053?o00030000oooooooo
04Ooool00ol0VOooooooo`0`oooo002?oooo00<0000co`0co`004C?o00030000oooooooo04Ooool0
0ol0VOooooooo`0`oooo002@oooo00<0000co`0co`0043?o00800018oooo00?o09Woooooool0<?oo
o`00TOooo`80000@<ol000<0003oooooool0Aoooo`03o`2Ioooooooo033oool009?oool00`0003?o
03?o000=<ol000<0003oooooool0Aoooo`03o`2Ioooooooo033oool009?oool00`0003?o03?o000=
<ol000<0003oooooool0Aoooo`03o`2Ioooooooo033oool009Coool00`0003?o03?o000<<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo033oool009Coool00`0003?o03?o000<<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo033oool009Goool00`0003?o03?o000;<ol00P0004Soool00ol0VOoo
ooooo`0`oooo002Eoooo00<0000co`0co`002c?o00030000oooooooo04Ooool00ol0VOooooooo`0`
oooo002Foooo00<0000co`0co`002S?o00030000oooooooo04Ooool00ol0VOooooooo`0`oooo002F
oooo00<0000co`0co`002S?o00030000oooooooo04Ooool00ol0VOooooooo`0`oooo002Goooo00<0
000co`0co`002C?o00030000oooooooo04Ooool00ol0VOooooooo`0`oooo002Goooo00<0000co`0c
o`002C?o00030000oooooooo04Ooool00ol0VOooooooo`0`oooo002Hoooo00<0000co`0co`0023?o
00800018oooo00?o09Woooooool0<?ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`17
oooo00?o09Woooooool0<?ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`17oooo00?o
09Woooooool0<?ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`17oooo00?o09Wooooo
ool0<?ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`17oooo00?o09Woooooool0<?oo
o`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`17oooo00?o09Woooooool0<?ooo`00VOoo
o`030000<ol0<ol000Lco`020000B?ooo`03o`2Ioooooooo033oool009[oool00`0003?o03?o0006
<ol000<0003oooooool0Aoooo`03o`2Ioooooooo033oool009[oool00`0003?o03?o0006<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo033oool009[oool00`0003?o03?o0006<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo033oool009[oool00`0003?o03?o0006<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo033oool009_oool500000c?o00030000oooooooo04Ooool00ol0VOooooooo`0`
oooo002Koooo00<0000co`0000001C?o00030000oooooooo04Ooool00ol0VOooooooo`0`oooo002K
oooo00<0000co`0000001C?o00<00017oooo00?o09Woooooool0<?ooo`00W?ooo`800005<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo033oool009coool200001C?o00030000oooooooo04Ooool0
0ol0VOooooooo`0`oooo002Loooo0P0000Dco`000`000?ooooooo`17oooo00?o09Woooooool0<?oo
o`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`17oooo00?o09Woooooool0<?ooo`00W?oo
o`030000<ol0<ol000@co`000`000?ooooooo`17oooo00?o09Woooooool0<?ooo`00W?ooo`030000
<ol0<ol000@co`020000B?ooo`03o`2Ioooooooo033oool009goool00`0003?o03?o0003<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo033oool009goool00`0003?o03?o0003<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo033oool009goool00`0003?o03?o0003<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo033oool009goool00`0003?o03?o0003<ol000<0003oooooool0Aoooo`03o`2I
oooooooo033oool009goool00`0003?o03?o0003<ol000<0003oooooool0Aoooo`03o`2Ioooooooo
033oool009goool00`0003?o03?o0003<ol00P0004Soool00ol0VOooooooo`0`oooo002Moooo00<0
000co`0co`000c?o00030000oooooooo04Ooool00ol0VOooooooo`0`oooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo04Ooool00ol0VOooooooo`0`oooo002Noooo00<0000co`0co`000S?o
00030000oooooooo04Ooool00ol0VOooooooo`0`oooo002Noooo00<0000co`0co`000S?o00030000
oooooooo04Ooool00ol0VOooooooo`0`oooo002Noooo00<0000co`0co`000S?o00030000oooooooo
04Ooool00ol0VOooooooo`0`oooo002Noooo00<0000co`0co`000S?o00030000oooooooo04Ooool0
0ol0VOooooooo`0`oooo002Noooo00<0000co`0co`000S?o00800018oooo00?o09Woooooool0<?oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`17oooo00?o09Woooooool0<?ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`17oooo00?o09Woooooool0<?ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`17oooo00?o09Woooooool0<?ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`17oooo00?o09Woooooool0<?ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`17oooo00?o09Woooooool0<?ooo`00W_ooo`030000<ol0<ol0008co`020000B?oo
o`03o`2Ioooooooo033oool009ooool01@0003?o03?o03?o00000019oooo00?o09Woooooool0<?oo
o`00Woooo`050000<ol0<ol0<ol0000004Woool00ol0VOooooooo`0`oooo002Ooooo00D0000co`0c
o`0co`000000BOooo`03o`2Ioooooooo033oool009_oool500000c?o00030000oooooooo04Ooool0
0ol0VOooooooo`0`oooo002Koooo00D0003oooooooooool000000c?o00030000oooooooo04Ooool0
0ol0VOooooooo`0`oooo002Loooo00@0003oooooool00003<ol00`0004Ooool00ol0VOooooooo`0`
oooo002Moooo00<0003oool000000c?o00030000oooooooo04Soool00ol0VOooooooo`0_oooo002K
oooo00<0003oooooool00P0000<co`000`000?ooooooo`18oooo00?o09Woooooool0;oooo`00W?oo
o`8000000oooo`0003?o0002<ol000<0003oooooool0B?ooo`03o`2Ioooooooo02ooool009ooool0
1@0003?o03?o03?o0000001:oooo00?o09Woooooool0;oooo`00X?ooo`040000<ol0<ol00000B_oo
o`03o`2Ioooooooo02ooool00:3oool00`0003?o03?o00020000BOooo`03o`2Ioooooooo02ooool0
0:3oool0100003?o03?o000004[oool00ol0VOooooooo`0_oooo002Poooo00@0000co`0co`00001:
oooo00?o09Woooooool0;oooo`00X?ooo`040000<ol0<ol00000B_ooo`03o`2Ioooooooo02ooool0
0:3oool0100003?o03?o000004[oool00ol0VOooooooo`0_oooo002Poooo00@0000co`0co`00001:
oooo00?o09Woooooool0;oooo`00X?ooo`040000<ol0<ol00000B_ooo`03o`2Ioooooooo02ooool0
0:7oool0100003?o0000000004Woool00ol0VOooooooo`0_oooo002Qoooo00<0000co`000000B_oo
o`03o`2Ioooooooo02ooool00:7oool00`0003?o0000001:oooo00?o09Woooooool0;oooo`00XOoo
o`030000<ol0000004[oool00ol0VOooooooo`0_oooo002Qoooo00<0000co`000000B_ooo`03o`2I
oooooooo02ooool00:7oool00`0003?o0000001:oooo00?o09Woooooool0;oooo`00XOooo`040000
<ol000000000BOooo`03o`2Ioooooooo02ooool00:7oool00`0003?o0000001:oooo00?o09Wooooo
ool0;oooo`00XOooo`030000<ol0000004[oool00ol0VOooooooo`0_oooo002Qoooo00<0000co`00
0000B_ooo`03o`2Ioooooooo02ooool00:7oool00`0003?o0000001:oooo00?o09Woooooool0;ooo
o`00XOooo`030000<ol0000004[oool00ol0VOooooooo`0_oooo002Qoooo00@0000co`0000000019
oooo00?o09Woooooool0;oooo`00XOooo`030000<ol0000004[oool00ol0VOooooooo`0_oooo002Q
oooo00<0000co`000000B_ooo`03o`2Ioooooooo02ooool00:7oool00`0003?o0000001:oooo00?o
09Woooooool0;oooo`00W?ooo`800003oooo00<0000co`000000B_ooo`03o`2Ioooooooo02ooool0
09_oool010000?ooooooo`0000;oool00`0003?o0000001:oooo00?o09Woooooool0;oooo`00WOoo
o`060000oooooooooooo0000<ol00`0004Soool00ol0VOooooooo`0_oooo002Noooo00H0003ooooo
ool0000co`00001:oooo00?o09Woooooool0;oooo`00Voooo`040000oooooooo00000_ooo`030000
<ol0000004[oool00ol0VOooooooo`0_oooo002Loooo0P0000Coool20000B_ooo`03o`2Ioooooooo
02ooool00:;oool20000B_ooo`03o`2Ioooooooo02ooool00:;oool20000B_ooo`03o`2Ioooooooo
02ooool00:;oool20000B_ooo`03o`2Ioooooooo02ooool00:;oool30000BOooo`03o`2Ioooooooo
02ooool00:;oool20000B_ooo`03o`2Ioooooooo02ooool00:;oool20000B_ooo`03o`2Ioooooooo
02ooool00:;oool20000B_ooo`03o`2Ioooooooo02ooool00:;oool20000B_ooo`03o`2Ioooooooo
02ooool00:;oool20000B_ooo`03o`2Ioooooooo02ooool00:;oool30000BOooo`03o`2Ioooooooo
02ooool00:;oool20000B_ooo`03o`2Ioooooooo02ooool00:;oool20000B_ooo`03o`2Ioooooooo
02ooool00:;oool20000B_ooo`03o`2Ioooooooo02ooool00:;oool20000B_ooo`03o`2Ioooooooo
02ooool00:;oool20000B_ooo`03o`2Ioooooooo02ooool00:;oool30000BOooo`03o`2Ioooooooo
02ooool00:?oool00`000?ooooooo`18oooo00?o09Woooooool0;oooo`00Xoooo`030000oooooooo
04Soool00ol0VOooooooo`0_oooo002Soooo00<0003oooooool0B?ooo`03o`2Ioooooooo02ooool0
0:?oool00`000?ooooooo`18oooo00?o09Woooooool0;oooo`00Xoooo`030000oooooooo04Soool0
0ol0VOooooooo`0_oooo002Soooo0P0004Woool00ol0VOooooooo`0_oooo002Soooo00<0003ooooo
ool0B?ooo`03o`2Ioooooooo02ooool00:?oool00`000?ooooooo`18oooo00?o09Woooooool0;ooo
o`00Xoooo`030000oooooooo04Soool00ol0VOooooooo`0_oooo002Soooo00<0003oooooool0B?oo
o`03o`2Ioooooooo02ooool009goool300000oooo`030000oooooooo04Soool00ol0VOooooooo`0_
oooo002Noooo00<0003oooooool00_ooo`030000oooooooo04Soool00ol0VOooooooo`0_oooo002K
oooo1@0000?oool30000B?ooo`03o`2Ioooooooo02ooool009_oool010000?ooooooo`00087oool0
09coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?oo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`@00003oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`030000oooooooo00_oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02_ooo`030000oooooooo00?oool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`0:oooo00D0
003oooooooooool00000OOooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Ooo
o`800009oooo100000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.85916 .12361 L
.86886 .12361 L
.87359 .12361 L
.87791 .12361 L
.87903 .12361 L
.88025 .12361 L
s
.88025 .12361 m
.88071 .61803 L
s
0 .4 1 r
.02381 .12267 m
.04262 .1223 L
.06244 .12174 L
.07286 .12136 L
.08255 .12094 L
.09388 .12034 L
.10458 .11966 L
.125 .11792 L
.14357 .11569 L
.16355 .11231 L
.18199 .10792 L
.20071 .1017 L
.21136 .09712 L
.22134 .09197 L
.24158 .07823 L
.26011 .06048 L
.2693 .04925 L
.27434 .04226 L
.27555 .04049 L
.27682 .03859 L
.2779 .03712 L
.27909 .03714 L
.2818 .03719 L
.28473 .03724 L
.28984 .03734 L
.29982 .03756 L
.31933 .03813 L
.33027 .03854 L
.34024 .03899 L
.35933 .04012 L
.37011 .04094 L
.38009 .04186 L
.39875 .04408 L
.41935 .04755 L
.4387 .05217 L
.45956 .05877 L
.5007 .07323 L
.52122 .07973 L
.53123 .08248 L
.54032 .08463 L
.54487 .08555 L
.5498 .08642 L
.55406 .08704 L
.55875 .08756 L
.55999 .08766 L
.56132 .08776 L
.56247 .08783 L
.56372 .08789 L
.56445 .08791 L
.56513 .08793 L
Mistroke
.56578 .08795 L
.56647 .08796 L
.56779 .08796 L
.56899 .08794 L
.57021 .0879 L
.57133 .08785 L
.57256 .08776 L
.57385 .08765 L
.57604 .0874 L
.57843 .08701 L
.59962 .08287 L
.60964 .08116 L
.61891 .07983 L
.62347 .07929 L
.6285 .07879 L
.63356 .07842 L
.63489 .07835 L
.63633 .07828 L
.63768 .07823 L
.63893 .07819 L
.64004 .07816 L
.64123 .07814 L
.64255 .07813 L
.64375 .07814 L
.645 .07815 L
.6457 .07816 L
.64635 .07818 L
.64755 .07822 L
.64881 .07827 L
.65104 .07839 L
.65313 .07855 L
.65541 .07877 L
.65787 .07906 L
.66314 .0799 L
.66802 .08097 L
.67338 .0825 L
.67908 .08459 L
.68864 .08935 L
.6992 .09678 L
.7094 .10661 L
.71496 .11329 L
.71768 .11692 L
.72014 .12045 L
.72124 .12209 L
.72242 .12361 L
.72354 .12361 L
.72458 .12361 L
.72932 .12361 L
.73937 .12361 L
.77802 .12361 L
Mistroke
.81739 .12361 L
.85525 .12361 L
.89556 .12361 L
.93435 .12361 L
.97559 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001Goooo0P1V
od[oool00`000?ooooooo`1joooo001Foooo00<0I_ooool0I_l05`1Voc?oool00`000?ooooooo`1j
oooo001Foooo00<0I_ooooooool05oooo`P0I_l[oooo00<0003oooooool0N_ooo`00EOooo`0306Ko
oooooooo023oool506Ko9_ooo`030000oooooooo07[oool005Coool00`1Vooooooooo`0Voooo101V
ob;oool20000Noooo`00Doooo`0306Kooooooooo02_oool306Ko7oooo`030000oooooooo07[oool0
05;oool00`1Vooooooooo`0_oooo0`1Voacoool00`000?ooooooo`1joooo001Aoooo00<0I_oooooo
ool0<oooo`80I_lJoooo00<0003oooooool0N_ooo`00D?ooo`0306Kooooooooo03Koool306Ko5ooo
o`030000oooooooo07[oool004ooool00`1Vooooooooo`0joooo0P1VoaGoool00`000?ooooooo`1j
oooo001>oooo00<0I_ooooooool0?Oooo`@0I_lAoooo0P0007_oool002_oool300007oooo`0306Ko
oooooooo00Koool300008oooo`@0000Boooo101Vo`goool00`000?ooooooo`07oooo301Voa3oool4
00009oooo`<0000Yoooo000[oooo00@0003oooooool0000Loooo0P1Vo`[oool00`000?ooooooo`0R
oooo00<0003oooooool05oooo`80I_l;oooo00<0003oooooool01`1Vo`coool306Ko3Oooo`030000
oooooooo02Woool00`000?ooooooo`0Xoooo000[oooo00@0003oooooool0000Joooo0P1Vo`Woool5
00009?ooo`030000oooooooo01Soool;06Ko00<00000I_l0I_l05_ooo`80I_l<oooo00<0003ooooo
ool09Oooo`D0000Yoooo000Uoooo100000;oool300006_ooo`0306Kooooooooo00?oool400000_oo
o`040000oooooooo00007_ooo`@00004oooo00<0003oooooool08_ooo`030000oooooooo01Soool2
06Ko2oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool00`000?ooooooo`0H
oooo00<0I_ooooooool02oooo`030000oooo000002Coool010000?ooooooo`0002?oool00`000?oo
ooooo`0Joooo00<0I_ooooooool01_ooo`040000oooooooo00009_ooo`030000oooo000002[oool0
02coool300005_ooo`80I_l?oooo0P0002Goool200009?ooo`80000Loooo00<0I_ooooooool01_oo
o`80000Xoooo0P0002[oool0047oool406KoG_ooo`030000oooooooo01coool206KoG?ooo`00?_oo
o`<0I_mRoooo00<0003oooooool07_ooo`0306Kooooooooo05Woool003coool206KoIOooo`030000
oooooooo01koool00`1Vooooooooo`1Ioooo000coooo2@1VofOoool00`000?ooooooo`0Ooooo00<0
I_ooooooool0F?ooo`00:_ooo`T0I_m`oooo00<0003oooooool08?ooo`0306Kooooooooo05Ooool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooo000001000000
0c?o000003?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool00_ooo`03o`2I
oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool0
02[oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo00Koool400006c?o
00030000oooooooo02Goool00`000?ooooooo`0Qoooo00?o09Woooooool00_ooo`030000oooooooo
02Woool008Soool400005c?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002<oooo00<0
000co`0co`0053?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002=oooo0P0001@co`00
0`000?ooooooo`19oooo00?o09Woooooool0;_ooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`19oooo00?o09Woooooool0;_ooo`00T?ooo`030000<ol0<ol0010co`020000B_ooo`03o`2I
oooooooo02koool0097oool2000043?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002C
oooo00<0000co`0co`003C?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002Coooo00<0
000co`0co`003C?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002Doooo00<0000co`0c
o`0033?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002Doooo00<0000co`0co`0033?o
00030000oooooooo04Woool00ol0VOooooooo`0^oooo002Eoooo00<0000co`0co`002c?o0080001:
oooo00?o09Woooooool0;_ooo`00UOooo`030000<ol0<ol000/co`000`000?ooooooo`19oooo00?o
09Woooooool0;_ooo`00U_ooo`030000<ol0<ol000Xco`000`000?ooooooo`19oooo00?o09Wooooo
ool0;_ooo`00U_ooo`030000<ol0<ol000Xco`000`000?ooooooo`19oooo00?o09Woooooool0;_oo
o`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`19oooo00?o09Woooooool0;_ooo`00Uooo
o`030000<ol0<ol000Tco`000`000?ooooooo`19oooo00?o09Woooooool0;_ooo`00V?ooo`030000
<ol0<ol000Pco`020000B_ooo`03o`2Ioooooooo02koool009Soool00`0003?o03?o0008<ol000<0
003oooooool0BOooo`03o`2Ioooooooo02koool009Soool00`0003?o03?o0008<ol000<0003ooooo
ool0BOooo`03o`2Ioooooooo02koool009Woool00`0003?o03?o0007<ol000<0003oooooool0BOoo
o`03o`2Ioooooooo02koool009Woool00`0003?o03?o0007<ol000<0003oooooool0BOooo`03o`2I
oooooooo02koool009Woool00`0003?o03?o0007<ol000<0003oooooool0BOooo`03o`2Ioooooooo
02koool009Woool00`0003?o03?o0007<ol00P0004[oool00ol0VOooooooo`0^oooo002Joooo00<0
000co`0co`001S?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002Joooo00<0000co`0c
o`001S?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002Joooo00<0000co`0co`001S?o
00030000oooooooo04Woool00ol0VOooooooo`0^oooo002Joooo00<0000co`0co`001S?o00030000
oooooooo04Woool00ol0VOooooooo`0^oooo002Koooo1@0000<co`000`000?ooooooo`19oooo00?o
09Woooooool0;_ooo`00Voooo`030000<ol0000000Dco`000`000?ooooooo`19oooo00?o09Wooooo
ool0;_ooo`00Voooo`030000<ol0000000Dco`030000BOooo`03o`2Ioooooooo02koool009coool2
00001C?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002Loooo0P0000Dco`000`000?oo
ooooo`19oooo00?o09Woooooool0;_ooo`00W?ooo`800005<ol000<0003oooooool0BOooo`03o`2I
oooooooo02koool009coool00`0003?o03?o0004<ol000<0003oooooool0BOooo`03o`2Ioooooooo
02koool009coool00`0003?o03?o0004<ol000<0003oooooool0BOooo`03o`2Ioooooooo02koool0
09coool00`0003?o03?o0004<ol00P0004[oool00ol0VOooooooo`0^oooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002Moooo00<0000co`0co`000c?o
00030000oooooooo04Woool00ol0VOooooooo`0^oooo002Moooo00<0000co`0co`000c?o00030000
oooooooo04Woool00ol0VOooooooo`0^oooo002Moooo00<0000co`0co`000c?o00030000oooooooo
04Woool00ol0VOooooooo`0^oooo002Moooo00<0000co`0co`000c?o00030000oooooooo04Woool0
0ol0VOooooooo`0^oooo002Moooo00<0000co`0co`000c?o0080001:oooo00?o09Woooooool0;_oo
o`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`19oooo00?o09Woooooool0;_ooo`00WOoo
o`030000<ol0<ol000<co`000`000?ooooooo`19oooo00?o09Woooooool0;_ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`19oooo00?o09Woooooool0;_ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`19oooo00?o09Woooooool0;_ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`19oooo00?o09Woooooool0;_ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`19oooo00?o09Woooooool0;_ooo`00W_ooo`030000<ol0<ol0008co`020000B_ooo`03o`2I
oooooooo02koool009koool00`0003?o03?o0002<ol000<0003oooooool0BOooo`03o`2Ioooooooo
02koool009koool00`0003?o03?o0002<ol000<0003oooooool0BOooo`03o`2Ioooooooo02koool0
09koool00`0003?o03?o0002<ol000<0003oooooool0BOooo`03o`2Ioooooooo02koool009koool0
0`0003?o03?o0002<ol000<0003oooooool0BOooo`03o`2Ioooooooo02koool009koool00`0003?o
03?o0002<ol000<0003oooooool0BOooo`03o`2Ioooooooo02koool009koool00`0003?o03?o0002
<ol00P0004[oool00ol0VOooooooo`0^oooo002Ooooo00D0000co`0co`0co`000000Boooo`03o`2I
oooooooo02koool009ooool01@0003?o03?o03?o0000001;oooo00?o09Woooooool0;_ooo`00Wooo
o`050000<ol0<ol0<ol0000004_oool00ol0VOooooooo`0^oooo002Koooo1@0000<co`000`000?oo
ooooo`19oooo00?o09Woooooool0;_ooo`00Voooo`050000oooooooooooo000000<co`000`000?oo
ooooo`19oooo00?o09Woooooool0;_ooo`00W?ooo`040000oooooooo00000c?o00<00019oooo00?o
09Woooooool0;_ooo`00WOooo`030000oooo000000<co`000`000?ooooooo`1:oooo00?o09Wooooo
ool0;Oooo`00Voooo`030000oooooooo00800003<ol000<0003oooooool0B_ooo`03o`2Ioooooooo
02goool009coool2000000?oool0000co`000S?o00030000oooooooo04[oool00ol0VOooooooo`0]
oooo002Ooooo00D0000co`0co`0co`000000C?ooo`03o`2Ioooooooo02goool00:3oool0100003?o
03?o000004coool00ol0VOooooooo`0]oooo002Poooo00<0000co`0co`000P0004_oool00ol0VOoo
ooooo`0]oooo002Poooo00@0000co`0co`00001<oooo00?o09Woooooool0;Oooo`00X?ooo`040000
<ol0<ol00000C?ooo`03o`2Ioooooooo02goool00:3oool0100003?o03?o000004coool00ol0VOoo
ooooo`0]oooo002Poooo00@0000co`0co`00001<oooo00?o09Woooooool0;Oooo`00X?ooo`040000
<ol0<ol00000C?ooo`03o`2Ioooooooo02goool00:3oool0100003?o03?o000004coool00ol0VOoo
ooooo`0]oooo002Qoooo00@0000co`000000001;oooo00?o09Woooooool0;Oooo`00XOooo`030000
<ol0000004coool00ol0VOooooooo`0]oooo002Qoooo00<0000co`000000C?ooo`03o`2Ioooooooo
02goool00:7oool00`0003?o0000001<oooo00?o09Woooooool0;Oooo`00XOooo`030000<ol00000
04coool00ol0VOooooooo`0]oooo002Qoooo00<0000co`000000C?ooo`03o`2Ioooooooo02goool0
0:7oool0100003?o0000000004_oool00ol0VOooooooo`0]oooo002Qoooo00<0000co`000000C?oo
o`03o`2Ioooooooo02goool00:7oool00`0003?o0000001<oooo00?o09Woooooool0;Oooo`00XOoo
o`030000<ol0000004coool00ol0VOooooooo`0]oooo002Qoooo00<0000co`000000C?ooo`03o`2I
oooooooo02goool00:7oool00`0003?o0000001<oooo00?o09Woooooool0;Oooo`00XOooo`040000
<ol000000000Boooo`03o`2Ioooooooo02goool00:7oool00`0003?o0000001<oooo00?o09Wooooo
ool0;Oooo`00XOooo`030000<ol0000004coool00ol0VOooooooo`0]oooo002Qoooo00<0000co`00
0000C?ooo`03o`2Ioooooooo02goool009coool200000oooo`030000<ol0000004coool00ol0VOoo
ooooo`0]oooo002Koooo00@0003oooooool00002oooo00<0000co`000000C?ooo`03o`2Ioooooooo
02goool009goool01P000?ooooooooooo`0003?o00<0001:oooo00?o09Woooooool0;Oooo`00W_oo
o`060000oooooooo0000<ol00000C?ooo`03o`2Ioooooooo02goool009_oool010000?ooooooo`00
00;oool00`0003?o0000001<oooo00?o09Woooooool0;Oooo`00W?ooo`800004oooo0P0004coool0
0ol0VOooooooo`0]oooo002Roooo0P0004coool00ol0VOooooooo`0]oooo002Roooo0P0004coool0
0ol0VOooooooo`0]oooo002Roooo0P0004coool00ol0VOooooooo`0]oooo002Roooo0`0004_oool0
0ol0VOooooooo`0]oooo002Roooo0P0004coool00ol0VOooooooo`0]oooo002Roooo0P0004coool0
0ol0VOooooooo`0]oooo002Roooo0P0004coool00ol0VOooooooo`0]oooo002Roooo0P0004coool0
0ol0VOooooooo`0]oooo002Roooo0P0004coool00ol0VOooooooo`0]oooo002Roooo0`0004_oool0
0ol0VOooooooo`0]oooo002Roooo0P0004coool00ol0VOooooooo`0]oooo002Roooo0P0004coool0
0ol0VOooooooo`0]oooo002Roooo0P0004coool00ol0VOooooooo`0]oooo002Roooo0P0004coool0
0ol0VOooooooo`0]oooo002Roooo0P0004coool00ol0VOooooooo`0]oooo002Roooo0`0004_oool0
0ol0VOooooooo`0]oooo002Soooo00<0003oooooool0B_ooo`03o`2Ioooooooo02goool00:?oool0
0`000?ooooooo`1:oooo00?o09Woooooool0;Oooo`00Xoooo`030000oooooooo04[oool00ol0VOoo
ooooo`0]oooo002Soooo00<0003oooooool0B_ooo`03o`2Ioooooooo02goool00:?oool00`000?oo
ooooo`1:oooo00?o09Woooooool0;Oooo`00Xoooo`80001;oooo00?o09Woooooool0;Oooo`00Xooo
o`030000oooooooo04[oool00ol0VOooooooo`0]oooo002Soooo00<0003oooooool0B_ooo`03o`2I
oooooooo02goool00:?oool00`000?ooooooo`1:oooo00?o09Woooooool0;Oooo`00Xoooo`030000
oooooooo04[oool00ol0VOooooooo`0]oooo002Moooo0`0000?oool00`000?ooooooo`1:oooo00?o
09Woooooool0;Oooo`00W_ooo`030000oooooooo00;oool00`000?ooooooo`1:oooo00?o09Wooooo
ool0;Oooo`00Voooo`D00003oooo0`0004[oool00ol0VOooooooo`0]oooo002Koooo00@0003ooooo
ool00021oooo002Loooo00<0003oool00000POooo`00WOooo`800021oooo003ooooo8Oooo`00oooo
ob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo
00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool400000oooo`800004oooo0P0000Coool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00<0003oooooool02Oooo`040000oooooooo00000oooo`030000oooooooo07_oool007[oool0
0`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00Soool010000?ooooooo`00
00Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`08
oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool00`000?oo
ooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.85916 .12361 L
.87791 .12361 L
.88246 .12361 L
.88497 .12361 L
.88735 .12361 L
.888 .12361 L
.88869 .12361 L
s
.88869 .12361 m
.88899 .61803 L
s
0 .4 1 r
.02381 .12253 m
.04262 .1221 L
.06244 .12146 L
.07286 .12102 L
.08255 .12053 L
.09388 .11985 L
.10458 .11906 L
.125 .11706 L
.14357 .11449 L
.16355 .11059 L
.18199 .10553 L
.20071 .09837 L
.21136 .0931 L
.22134 .08716 L
.24158 .07133 L
.26011 .05088 L
.26487 .04444 L
.26749 .04066 L
.26877 .03874 L
.26995 .03712 L
.27107 .03713 L
.27226 .03715 L
.27475 .0372 L
.27909 .03728 L
.2891 .03749 L
.29982 .03776 L
.31946 .0384 L
.33779 .03925 L
.34796 .03986 L
.35903 .04065 L
.36859 .04148 L
.37915 .04256 L
.39893 .04524 L
.40976 .04715 L
.41993 .04931 L
.44012 .05487 L
.45862 .06109 L
.49824 .075 L
.51821 .08122 L
.53635 .08587 L
.54119 .08688 L
.54644 .08784 L
.55098 .08853 L
.55596 .08913 L
.5587 .08938 L
.56126 .08955 L
.56267 .08962 L
.56396 .08967 L
.56467 .08968 L
.56545 .08969 L
Mistroke
.56618 .0897 L
.56686 .0897 L
.56818 .08968 L
.56942 .08964 L
.57053 .08959 L
.57173 .08952 L
.57305 .08941 L
.57443 .08927 L
.57691 .08893 L
.59682 .08491 L
.61494 .08159 L
.62431 .08017 L
.62925 .07954 L
.63449 .07897 L
.63714 .07873 L
.64008 .07851 L
.64274 .07835 L
.64524 .07824 L
.64649 .0782 L
.6478 .07817 L
.64892 .07815 L
.65014 .07814 L
.65083 .07813 L
.65146 .07814 L
.65219 .07814 L
.65287 .07815 L
.65409 .07817 L
.65541 .07821 L
.65665 .07826 L
.65778 .07832 L
.66032 .07849 L
.66267 .0787 L
.6649 .07894 L
.6699 .07968 L
.67533 .08081 L
.68063 .08228 L
.68626 .08428 L
.69639 .08924 L
.70574 .09565 L
.71583 .10498 L
.7204 .11017 L
.72529 .11648 L
.72767 .11984 L
.72883 .12157 L
.72991 .12322 L
.73089 .12361 L
.73192 .12361 L
.7341 .12361 L
.74366 .12361 L
.75412 .12361 L
Mistroke
.77521 .12361 L
.81307 .12361 L
.85337 .12361 L
.89217 .12361 L
.93341 .12361 L
.97314 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001Eoooo0P1V
odcoool00`000?ooooooo`1joooo001Doooo00<0I_ooooooool05P1VocKoool00`000?ooooooo`1j
oooo001Coooo00<0I_ooooooool05oooo`H0I_l`oooo00<0003oooooool0N_ooo`00D_ooo`0306Ko
oooooooo01koool706Ko:Oooo`030000oooooooo07[oool005;oool00`1Vooooooooo`0Uoooo101V
obGoool20000Noooo`00DOooo`0306Kooooooooo02[oool306Ko8_ooo`030000oooooooo07[oool0
053oool00`1Vooooooooo`0^oooo0P1Vob3oool00`000?ooooooo`1joooo001?oooo00<0I_oooooo
ool0<Oooo`<0I_lMoooo00<0003oooooool0N_ooo`00C_ooo`0306Kooooooooo03Goool406Ko6Ooo
o`030000oooooooo07[oool004goool00`1Vooooooooo`0joooo101VoaGoool00`000?ooooooo`1j
oooo001<oooo00<0I_ooooooool0?oooo`<0I_lBoooo0P0007_oool002_oool300007?ooo`80I_l:
oooo0`0002?oool400004Oooo`80I_l@oooo00<0003oooooool02?ooo`d0I_l>oooo100002Ooool3
0000:Oooo`00:oooo`040000oooooooo00006_ooo`0306Kooooooooo00_oool00`000?ooooooo`0R
oooo00<0003oooooool05?ooo`<0I_l=oooo00<0003oooooool01Oooo`<0I_l=oooo101Vo`[oool0
0`000?ooooooo`0Yoooo00<0003oooooool0:?ooo`00:oooo`040000oooooooo00006Oooo`0306Ko
oooooooo00Woool500009?ooo`030000oooooooo01Koool606Ko1oooo`030000oooooooo00D0I_lD
oooo0P1Vo`Woool00`000?ooooooo`0Uoooo1@0002Woool002Goool400000_ooo`<0000Ioooo00<0
I_ooooooool01?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0K
oooo1`1Vo`03000006Ko06Ko01_oool00`1Vooooooooo`07oooo00<0003oooooool09?ooo`040000
oooooooo0000:_ooo`00;?ooo`030000oooooooo01Koool206Ko3_ooo`030000oooo000002Coool0
10000?ooooooo`0002?oool00`000?ooooooo`0Loooo0P1Vo`Goool010000?ooooooo`0002Koool0
0`000?ooo`00000Zoooo000/oooo0`0001?oool306Ko4Oooo`80000Uoooo0P0002Coool200007ooo
o`0306Kooooooooo00?oool20000:?ooo`80000Zoooo0010oooo0P1Vof7oool00`000?ooooooo`0O
oooo00<0I_ooooooool0F?ooo`00?Oooo`<0I_mSoooo00<0003oooooool08?ooo`0306Kooooooooo
05Ooool003Soool506KoI_ooo`030000oooooooo027oool00`1Vooooooooo`1Foooo000coooo1@1V
of_oool00`000?ooooooo`0Qoooo00<0I_ooooooool0E_ooo`009oooo``0I_m`oooo00<0003ooooo
ool08_ooo`80I_mFoooo000@ooooo`00017oool001Koool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Goool00ol0VOooo`000009oooo00<0003oooooool01oooo`030000oooooooo01Goool0
02[oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo00Koool400006c?o
00030000oooooooo02Goool00`000?ooooooo`0Toooo00?o09Woool00000:oooo`00R?ooo`@0000G
<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02_oool008coool00`0003?o03?o000D<ol000<0
003oooooool0C?ooo`03o`2Ioooooooo02_oool008goool2000053?o00030000oooooooo04coool0
0ol0VOooooooo`0[oooo002?oooo00<0000co`0co`004C?o00030000oooooooo04coool00ol0VOoo
ooooo`0[oooo002@oooo00<0000co`0co`0043?o0080001=oooo00?o09Woooooool0:oooo`00TOoo
o`80000@<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02_oool009?oool00`0003?o03?o000=
<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02_oool009?oool00`0003?o03?o000=<ol000<0
003oooooool0C?ooo`03o`2Ioooooooo02_oool009Coool00`0003?o03?o000<<ol000<0003ooooo
ool0C?ooo`03o`2Ioooooooo02_oool009Coool00`0003?o03?o000<<ol000<0003oooooool0C?oo
o`03o`2Ioooooooo02_oool009Goool00`0003?o03?o000;<ol00P0004goool00ol0VOooooooo`0[
oooo002Eoooo00<0000co`0co`002c?o00030000oooooooo04coool00ol0VOooooooo`0[oooo002F
oooo00<0000co`0co`002S?o00030000oooooooo04coool00ol0VOooooooo`0[oooo002Foooo00<0
000co`0co`002S?o00030000oooooooo04coool00ol0VOooooooo`0[oooo002Goooo00<0000co`0c
o`002C?o00030000oooooooo04coool00ol0VOooooooo`0[oooo002Goooo00<0000co`0co`002C?o
00030000oooooooo04coool00ol0VOooooooo`0[oooo002Hoooo00<0000co`0co`0023?o0080001=
oooo00?o09Woooooool0:oooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1<oooo00?o
09Woooooool0:oooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1<oooo00?o09Wooooo
ool0:oooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`1<oooo00?o09Woooooool0:ooo
o`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00VOoo
o`030000<ol0<ol000Lco`000`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00VOooo`030000
<ol0<ol000Lco`020000COooo`03o`2Ioooooooo02_oool009[oool00`0003?o03?o0006<ol000<0
003oooooool0C?ooo`03o`2Ioooooooo02_oool009[oool00`0003?o03?o0006<ol000<0003ooooo
ool0C?ooo`03o`2Ioooooooo02_oool009[oool00`0003?o03?o0006<ol000<0003oooooool0C?oo
o`03o`2Ioooooooo02_oool009[oool00`0003?o03?o0006<ol000<0003oooooool0C?ooo`03o`2I
oooooooo02_oool009_oool500000c?o00030000oooooooo04coool00ol0VOooooooo`0[oooo002K
oooo00<0000co`0000001C?o00030000oooooooo04coool00ol0VOooooooo`0[oooo002Koooo00<0
000co`0000001C?o00<0001<oooo00?o09Woooooool0:oooo`00W?ooo`800005<ol000<0003ooooo
ool0C?ooo`03o`2Ioooooooo02_oool009coool200001C?o00030000oooooooo04coool00ol0VOoo
ooooo`0[oooo002Loooo0P0000Dco`000`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00W?oo
o`030000<ol0<ol000@co`000`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00W?ooo`030000
<ol0<ol000@co`000`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00W?ooo`030000<ol0<ol0
00@co`020000COooo`03o`2Ioooooooo02_oool009goool00`0003?o03?o0003<ol000<0003ooooo
ool0C?ooo`03o`2Ioooooooo02_oool009goool00`0003?o03?o0003<ol000<0003oooooool0C?oo
o`03o`2Ioooooooo02_oool009goool00`0003?o03?o0003<ol000<0003oooooool0C?ooo`03o`2I
oooooooo02_oool009goool00`0003?o03?o0003<ol000<0003oooooool0C?ooo`03o`2Ioooooooo
02_oool009goool00`0003?o03?o0003<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02_oool0
09goool00`0003?o03?o0003<ol00P0004goool00ol0VOooooooo`0[oooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo04coool00ol0VOooooooo`0[oooo002Moooo00<0000co`0co`000c?o
00030000oooooooo04coool00ol0VOooooooo`0[oooo002Noooo00<0000co`0co`000S?o00030000
oooooooo04coool00ol0VOooooooo`0[oooo002Noooo00<0000co`0co`000S?o00030000oooooooo
04coool00ol0VOooooooo`0[oooo002Noooo00<0000co`0co`000S?o00030000oooooooo04coool0
0ol0VOooooooo`0[oooo002Noooo00<0000co`0co`000S?o00030000oooooooo04coool00ol0VOoo
ooooo`0[oooo002Noooo00<0000co`0co`000S?o0080001=oooo00?o09Woooooool0:oooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1<oooo00?o09Woooooool0:oooo`00W_ooo`030000<ol0<ol0008co`020000COooo`03o`2I
oooooooo02_oool009ooool01@0003?o03?o03?o0000001>oooo00?o09Woooooool0:oooo`00Wooo
o`050000<ol0<ol0<ol0000004koool00ol0VOooooooo`0[oooo002Ooooo00D0000co`0co`0co`00
0000C_ooo`03o`2Ioooooooo02_oool009_oool500000c?o00030000oooooooo04coool00ol0VOoo
ooooo`0[oooo002Koooo00D0003oooooooooool000000c?o00030000oooooooo04coool00ol0VOoo
ooooo`0[oooo002Loooo00@0003oooooool00003<ol00`0004coool00ol0VOooooooo`0[oooo002M
oooo00<0003oool000000c?o00030000oooooooo04coool00ol0VOooooooo`0[oooo002Koooo00<0
003oooooool00P0000<co`000`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00W?ooo`800000
0oooo`0003?o0002<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02_oool009ooool01@0003?o
03?o03?o0000001>oooo00?o09Woooooool0:oooo`00X?ooo`040000<ol0<ol00000C_ooo`03o`2I
oooooooo02_oool00:3oool00`0003?o03?o00020000COooo`03o`2Ioooooooo02_oool00:3oool0
100003?o03?o000004koool00ol0VOooooooo`0[oooo002Poooo00@0000co`0co`00001>oooo00?o
09Woooooool0:oooo`00X?ooo`040000<ol0<ol00000C_ooo`03o`2Ioooooooo02_oool00:3oool0
100003?o03?o000004koool00ol0VOooooooo`0[oooo002Poooo00@0000co`0co`00001>oooo00?o
09Woooooool0:oooo`00X?ooo`040000<ol0<ol00000C_ooo`03o`2Ioooooooo02_oool00:7oool0
100003?o0000000004goool00ol0VOooooooo`0[oooo002Qoooo00<0000co`000000C_ooo`03o`2I
oooooooo02_oool00:7oool00`0003?o0000001>oooo00?o09Woooooool0:oooo`00XOooo`030000
<ol0000004koool00ol0VOooooooo`0[oooo002Qoooo00<0000co`000000C_ooo`03o`2Ioooooooo
02_oool00:7oool00`0003?o0000001>oooo00?o09Woooooool0:oooo`00XOooo`040000<ol00000
0000COooo`03o`2Ioooooooo02_oool00:7oool00`0003?o0000001>oooo00?o09Woooooool0:ooo
o`00XOooo`030000<ol0000004koool00ol0VOooooooo`0[oooo002Qoooo00<0000co`000000C_oo
o`03o`2Ioooooooo02_oool00:7oool00`0003?o0000001>oooo00?o09Woooooool0:oooo`00XOoo
o`030000<ol0000004koool00ol0VOooooooo`0[oooo002Qoooo00@0000co`000000001=oooo00?o
09Woooooool0:oooo`00XOooo`030000<ol0000004koool00ol0VOooooooo`0[oooo002Qoooo00<0
000co`000000C_ooo`03o`2Ioooooooo02_oool00:7oool00`0003?o0000001>oooo00?o09Wooooo
ool0:oooo`00W?ooo`800003oooo00<0000co`000000C_ooo`03o`2Ioooooooo02_oool009_oool0
10000?ooooooo`0000;oool00`0003?o0000001>oooo00?o09Woooooool0:oooo`00WOooo`060000
oooooooooooo0000<ol00`0004coool00ol0VOooooooo`0[oooo002Noooo00H0003oooooool0000c
o`00001>oooo00?o09Woooooool0:oooo`00Voooo`040000oooooooo00000_ooo`030000<ol00000
04koool00ol0VOooooooo`0[oooo002Loooo0P0000Coool20000C_ooo`03o`2Ioooooooo02_oool0
0:;oool20000C_ooo`03o`2Ioooooooo02_oool00:;oool20000C_ooo`03o`2Ioooooooo02_oool0
0:;oool20000C_ooo`03o`2Ioooooooo02_oool00:;oool30000COooo`03o`2Ioooooooo02_oool0
0:;oool20000C_ooo`03o`2Ioooooooo02_oool00:;oool20000C_ooo`03o`2Ioooooooo02_oool0
0:;oool20000C_ooo`03o`2Ioooooooo02_oool00:;oool20000C_ooo`03o`2Ioooooooo02_oool0
0:;oool20000C_ooo`03o`2Ioooooooo02_oool00:;oool30000COooo`03o`2Ioooooooo02_oool0
0:;oool20000C_ooo`03o`2Ioooooooo02_oool00:;oool20000C_ooo`03o`2Ioooooooo02_oool0
0:;oool20000C_ooo`03o`2Ioooooooo02_oool00:;oool20000C_ooo`03o`2Ioooooooo02_oool0
0:;oool20000C_ooo`03o`2Ioooooooo02_oool00:;oool30000COooo`03o`2Ioooooooo02_oool0
0:?oool00`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00Xoooo`030000oooooooo04coool0
0ol0VOooooooo`0[oooo002Soooo00<0003oooooool0C?ooo`03o`2Ioooooooo02_oool00:?oool0
0`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00Xoooo`030000oooooooo04coool00ol0VOoo
ooooo`0[oooo002Soooo0P0004goool00ol0VOooooooo`0[oooo002Soooo00<0003oooooool0C?oo
o`03o`2Ioooooooo02_oool00:?oool00`000?ooooooo`1<oooo00?o09Woooooool0:oooo`00Xooo
o`030000oooooooo04coool00ol0VOooooooo`0[oooo002Soooo00<0003oooooool0C?ooo`03o`2I
oooooooo02_oool009goool300000oooo`030000oooooooo04coool00ol0VOooooooo`0[oooo002N
oooo00<0003oooooool00_ooo`030000oooooooo04coool00ol0VOooooooo`0[oooo002Koooo1@00
00?oool30000C?ooo`03o`2Ioooooooo02_oool009_oool010000?ooooooo`00087oool009coool0
0`000?ooo`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000
oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo
01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01_ooo`@00003oooo0P0000?oool300001?ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0;
oooo00<0003oooooool00_ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0
003oooooool03_ooo`030000oooooooo00Woool300001?ooo`030000oooooooo07[oool007_oool0
0`000?ooooooo`0500003_ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool3
00000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.85916 .12361 L
.87791 .12361 L
.88735 .12361 L
.88993 .12361 L
.89271 .12361 L
.89405 .12361 L
.89533 .12361 L
.89647 .12361 L
s
.89647 .12361 m
.89697 .61803 L
s
0 .4 1 r
.02381 .12236 m
.04262 .12187 L
.06244 .12113 L
.07286 .12063 L
.08255 .12007 L
.09388 .11927 L
.10458 .11836 L
.125 .11606 L
.14357 .1131 L
.16355 .10862 L
.18199 .10278 L
.20071 .09454 L
.21136 .08846 L
.22134 .08162 L
.24158 .06338 L
.25055 .05295 L
.25547 .04647 L
.26011 .03983 L
.26132 .03801 L
.26259 .03712 L
.26326 .03713 L
.26399 .03714 L
.26527 .03716 L
.26995 .03725 L
.27909 .03743 L
.28993 .03769 L
.29982 .03798 L
.31933 .03872 L
.33007 .03925 L
.34024 .03985 L
.36015 .0414 L
.37857 .04341 L
.39724 .04625 L
.41784 .05067 L
.43719 .0564 L
.45804 .06361 L
.49918 .07787 L
.51971 .08396 L
.52971 .08649 L
.53881 .08845 L
.54335 .08928 L
.54828 .09006 L
.55254 .09062 L
.55723 .09108 L
.55847 .09117 L
.5598 .09126 L
.56095 .09132 L
.5622 .09137 L
.56294 .0914 L
.56362 .09142 L
Mistroke
.56427 .09143 L
.56496 .09144 L
.56628 .09144 L
.56747 .09142 L
.56869 .09139 L
.56981 .09134 L
.57104 .09127 L
.57234 .09117 L
.57452 .09094 L
.57691 .09061 L
.5981 .08624 L
.61739 .08253 L
.62699 .08093 L
.63204 .0802 L
.63741 .07951 L
.64209 .079 L
.64458 .07878 L
.64726 .07857 L
.64971 .07841 L
.65195 .07829 L
.6541 .07821 L
.65517 .07818 L
.65635 .07815 L
.657 .07815 L
.65768 .07814 L
.6589 .07813 L
.66021 .07814 L
.66096 .07815 L
.66165 .07817 L
.66291 .0782 L
.66407 .07824 L
.66539 .0783 L
.66665 .07838 L
.66898 .07855 L
.67113 .07875 L
.676 .07938 L
.68083 .08026 L
.68616 .08157 L
.69173 .08335 L
.69696 .08546 L
.70678 .09074 L
.71712 .09853 L
.72595 .10738 L
.73059 .11297 L
.73562 .11987 L
.73695 .12185 L
.73768 .12296 L
.73836 .12361 L
.73957 .12361 L
.74089 .12361 L
Mistroke
.74588 .12361 L
.75521 .12361 L
.77615 .12361 L
.81494 .12361 L
.85618 .12361 L
.89591 .12361 L
.93413 .12361 L
.97479 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001Coooo00<0
I_ooooooool0COooo`030000oooooooo07[oool005;oool00`1Vooooo`1Vo`0D06Ko>_ooo`030000
oooooooo07[oool0057oool00`1Vooooooooo`0Eoooo2P1Voc3oool00`000?ooooooo`1joooo001A
oooo00<0I_ooooooool07oooo`D0I_l[oooo00<0003oooooool0N_ooo`00D?ooo`0306Kooooooooo
02Goool506Ko9_ooo`80001koooo001?oooo00<0I_ooooooool0:oooo`@0I_lRoooo00<0003ooooo
ool0N_ooo`00C_ooo`0306Kooooooooo033oool206Ko8?ooo`030000oooooooo07[oool004goool0
0`1Vooooooooo`0coooo0`1Voagoool00`000?ooooooo`1joooo001<oooo00<0I_ooooooool0=ooo
o`<0I_lJoooo00<0003oooooool0N_ooo`00Boooo`0306Kooooooooo03_oool206Ko6?ooo`030000
oooooooo07[oool004[oool00`1Vooooooooo`0noooo0`1VoaGoool20000Noooo`00:oooo`<0000K
oooo00<0I_ooooooool02_ooo`<0000Soooo100000koool406Ko4Oooo`030000oooooooo00[oool>
06Ko2oooo`@0000Woooo0`0002Woool002_oool010000?ooooooo`0001Woool00`1Vooooooooo`0<
oooo00<0003oooooool08_ooo`030000oooooooo01?oool406Ko3Oooo`030000oooooooo00Goool5
06Ko3_ooo`<0I_l8oooo00<0003oooooool0:Oooo`030000oooooooo02Soool002_oool010000?oo
ooooo`0001Ooool206Ko3?ooo`D0000Toooo00<0003oooooool05_ooo`@0I_l9oooo00<0003ooooo
ool01@1VoaKoool00`1Vooooooooo`06oooo00<0003oooooool09Oooo`D0000Yoooo000Uoooo1000
00;oool300005_ooo`80I_l8oooo100000;oool010000?ooooooo`0001koool400001?ooo`030000
oooooooo01Woool906Ko00<00000I_l0I_l07?ooo`80I_l7oooo00<0003oooooool09?ooo`040000
oooooooo0000:_ooo`00;?ooo`030000oooooooo01?oool206Ko4Oooo`030000oooo000002Coool0
10000?ooooooo`0002?oool00`000?ooooooo`0Noooo0P1Vo`?oool010000?ooooooo`0002Koool0
0`000?ooo`00000Zoooo000/oooo0`00017oool206Ko5?ooo`80000Uoooo0P0002Coool200008Ooo
o`0406Kooooooooooooo0P0002Soool20000:_ooo`00?_ooo`80I_mSoooo00<0003oooooool08Ooo
o`0306Kooooooooo05Koool003coool206KoIOooo`030000oooooooo02;oool00`1Vooooooooo`1E
oooo000hoooo101VofOoool00`000?ooooooo`0Roooo00<0I_ooooooool0EOooo`00;_ooo`X0I_m[
oooo00<0003oooooool08oooo`0306Kooooooooo05Coool002Ooool706KoMOooo`030000oooooooo
02Coool206KoE?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oool0000040000003<ol00000<ol000Pco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`06oooo00?o09T0003oool02?ooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Z
oooo00<0003oooooool09_ooo`030000oooooooo02Goool00`000?ooooooo`06oooo100001/co`00
0`000?ooooooo`0Uoooo00<0003oooooool09Oooo`03o`2I0000oooo02[oool008Soool400005c?o
00030000oooooooo04goool00ol0VOooooooo`0Zoooo002<oooo00<0000co`0co`0053?o00030000
oooooooo04goool00ol0VOooooooo`0Zoooo002=oooo0P0001@co`000`000?ooooooo`1=oooo00?o
09Woooooool0:_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1=oooo00?o09Wooooo
ool0:_ooo`00T?ooo`030000<ol0<ol0010co`020000C_ooo`03o`2Ioooooooo02[oool0097oool2
000043?o00030000oooooooo04goool00ol0VOooooooo`0Zoooo002Coooo00<0000co`0co`003C?o
00030000oooooooo04goool00ol0VOooooooo`0Zoooo002Coooo00<0000co`0co`003C?o00030000
oooooooo04goool00ol0VOooooooo`0Zoooo002Doooo00<0000co`0co`0033?o00030000oooooooo
04goool00ol0VOooooooo`0Zoooo002Doooo00<0000co`0co`0033?o00030000oooooooo04goool0
0ol0VOooooooo`0Zoooo002Eoooo00<0000co`0co`002c?o0080001>oooo00?o09Woooooool0:_oo
o`00UOooo`030000<ol0<ol000/co`000`000?ooooooo`1=oooo00?o09Woooooool0:_ooo`00U_oo
o`030000<ol0<ol000Xco`000`000?ooooooo`1=oooo00?o09Woooooool0:_ooo`00U_ooo`030000
<ol0<ol000Xco`000`000?ooooooo`1=oooo00?o09Woooooool0:_ooo`00Uoooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1=oooo00?o09Woooooool0:_ooo`00Uoooo`030000<ol0<ol000Tco`00
0`000?ooooooo`1=oooo00?o09Woooooool0:_ooo`00V?ooo`030000<ol0<ol000Pco`020000C_oo
o`03o`2Ioooooooo02[oool009Soool00`0003?o03?o0008<ol000<0003oooooool0COooo`03o`2I
oooooooo02[oool009Soool00`0003?o03?o0008<ol000<0003oooooool0COooo`03o`2Ioooooooo
02[oool009Woool00`0003?o03?o0007<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool0
09Woool00`0003?o03?o0007<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool009Woool0
0`0003?o03?o0007<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool009Woool00`0003?o
03?o0007<ol00P0004koool00ol0VOooooooo`0Zoooo002Joooo00<0000co`0co`001S?o00030000
oooooooo04goool00ol0VOooooooo`0Zoooo002Joooo00<0000co`0co`001S?o00030000oooooooo
04goool00ol0VOooooooo`0Zoooo002Joooo00<0000co`0co`001S?o00030000oooooooo04goool0
0ol0VOooooooo`0Zoooo002Joooo00<0000co`0co`001S?o00030000oooooooo04goool00ol0VOoo
ooooo`0Zoooo002Koooo1@0000<co`000`000?ooooooo`1=oooo00?o09Woooooool0:_ooo`00Vooo
o`030000<ol0000000Dco`000`000?ooooooo`1=oooo00?o09Woooooool0:_ooo`00Voooo`030000
<ol0000000Dco`030000COooo`03o`2Ioooooooo02[oool009coool200001C?o00030000oooooooo
04goool00ol0VOooooooo`0Zoooo002Loooo0P0000Dco`000`000?ooooooo`1=oooo00?o09Wooooo
ool0:_ooo`00W?ooo`800005<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool009coool0
0`0003?o03?o0004<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool009coool00`0003?o
03?o0004<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool009coool00`0003?o03?o0004
<ol00P0004koool00ol0VOooooooo`0Zoooo002Moooo00<0000co`0co`000c?o00030000oooooooo
04goool00ol0VOooooooo`0Zoooo002Moooo00<0000co`0co`000c?o00030000oooooooo04goool0
0ol0VOooooooo`0Zoooo002Moooo00<0000co`0co`000c?o00030000oooooooo04goool00ol0VOoo
ooooo`0Zoooo002Moooo00<0000co`0co`000c?o00030000oooooooo04goool00ol0VOooooooo`0Z
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo04goool00ol0VOooooooo`0Zoooo002M
oooo00<0000co`0co`000c?o0080001>oooo00?o09Woooooool0:_ooo`00WOooo`030000<ol0<ol0
00<co`000`000?ooooooo`1=oooo00?o09Woooooool0:_ooo`00WOooo`030000<ol0<ol000<co`00
0`000?ooooooo`1=oooo00?o09Woooooool0:_ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1=oooo00?o09Woooooool0:_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1=
oooo00?o09Woooooool0:_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1=oooo00?o
09Woooooool0:_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1=oooo00?o09Wooooo
ool0:_ooo`00W_ooo`030000<ol0<ol0008co`020000C_ooo`03o`2Ioooooooo02[oool009koool0
0`0003?o03?o0002<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool009koool00`0003?o
03?o0002<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool009koool00`0003?o03?o0002
<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool009koool00`0003?o03?o0002<ol000<0
003oooooool0COooo`03o`2Ioooooooo02[oool009koool00`0003?o03?o0002<ol000<0003ooooo
ool0COooo`03o`2Ioooooooo02[oool009koool00`0003?o03?o0002<ol00P0004koool00ol0VOoo
ooooo`0Zoooo002Ooooo00D0000co`0co`0co`000000Coooo`03o`2Ioooooooo02[oool009ooool0
1@0003?o03?o03?o0000001?oooo00?o09Woooooool0:_ooo`00Woooo`050000<ol0<ol0<ol00000
04ooool00ol0VOooooooo`0Zoooo002Koooo1@0000<co`000`000?ooooooo`1=oooo00?o09Wooooo
ool0:_ooo`00Voooo`050000oooooooooooo000000<co`000`000?ooooooo`1=oooo00?o09Wooooo
ool0:_ooo`00W?ooo`040000oooooooo00000c?o00<0001=oooo00?o09Woooooool0:_ooo`00WOoo
o`030000oooo000000<co`000`000?ooooooo`1>oooo00?o09Woooooool0:Oooo`00Voooo`030000
oooooooo00800003<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02Woool009coool2000000?o
ool0000co`000S?o00030000oooooooo04koool00ol0VOooooooo`0Yoooo002Ooooo00D0000co`0c
o`0co`000000D?ooo`03o`2Ioooooooo02Woool00:3oool0100003?o03?o0000053oool00ol0VOoo
ooooo`0Yoooo002Poooo00<0000co`0co`000P0004ooool00ol0VOooooooo`0Yoooo002Poooo00@0
000co`0co`00001@oooo00?o09Woooooool0:Oooo`00X?ooo`040000<ol0<ol00000D?ooo`03o`2I
oooooooo02Woool00:3oool0100003?o03?o0000053oool00ol0VOooooooo`0Yoooo002Poooo00@0
000co`0co`00001@oooo00?o09Woooooool0:Oooo`00X?ooo`040000<ol0<ol00000D?ooo`03o`2I
oooooooo02Woool00:3oool0100003?o03?o0000053oool00ol0VOooooooo`0Yoooo002Qoooo00@0
000co`000000001?oooo00?o09Woooooool0:Oooo`00XOooo`030000<ol00000053oool00ol0VOoo
ooooo`0Yoooo002Qoooo00<0000co`000000D?ooo`03o`2Ioooooooo02Woool00:7oool00`0003?o
0000001@oooo00?o09Woooooool0:Oooo`00XOooo`030000<ol00000053oool00ol0VOooooooo`0Y
oooo002Qoooo00<0000co`000000D?ooo`03o`2Ioooooooo02Woool00:7oool0100003?o00000000
04ooool00ol0VOooooooo`0Yoooo002Qoooo00<0000co`000000D?ooo`03o`2Ioooooooo02Woool0
0:7oool00`0003?o0000001@oooo00?o09Woooooool0:Oooo`00XOooo`030000<ol00000053oool0
0ol0VOooooooo`0Yoooo002Qoooo00<0000co`000000D?ooo`03o`2Ioooooooo02Woool00:7oool0
0`0003?o0000001@oooo00?o09Woooooool0:Oooo`00XOooo`040000<ol000000000Coooo`03o`2I
oooooooo02Woool00:7oool00`0003?o0000001@oooo00?o09Woooooool0:Oooo`00XOooo`030000
<ol00000053oool00ol0VOooooooo`0Yoooo002Qoooo00<0000co`000000D?ooo`03o`2Ioooooooo
02Woool009coool200000oooo`030000<ol00000053oool00ol0VOooooooo`0Yoooo002Koooo00@0
003oooooool00002oooo00<0000co`000000D?ooo`03o`2Ioooooooo02Woool009goool01P000?oo
ooooooooo`0003?o00<0001>oooo00?o09Woooooool0:Oooo`00W_ooo`060000oooooooo0000<ol0
0000D?ooo`03o`2Ioooooooo02Woool009_oool010000?ooooooo`0000;oool00`0003?o0000001@
oooo00?o09Woooooool0:Oooo`00W?ooo`800004oooo0P00053oool00ol0VOooooooo`0Yoooo002R
oooo0P00053oool00ol0VOooooooo`0Yoooo002Roooo0P00053oool00ol0VOooooooo`0Yoooo002R
oooo0P00053oool00ol0VOooooooo`0Yoooo002Roooo0`0004ooool00ol0VOooooooo`0Yoooo002R
oooo0P00053oool00ol0VOooooooo`0Yoooo002Roooo0P00053oool00ol0VOooooooo`0Yoooo002R
oooo0P00053oool00ol0VOooooooo`0Yoooo002Roooo0P00053oool00ol0VOooooooo`0Yoooo002R
oooo0P00053oool00ol0VOooooooo`0Yoooo002Roooo0`0004ooool00ol0VOooooooo`0Yoooo002R
oooo0P00053oool00ol0VOooooooo`0Yoooo002Roooo0P00053oool00ol0VOooooooo`0Yoooo002R
oooo0P00053oool00ol0VOooooooo`0Yoooo002Roooo0P00053oool00ol0VOooooooo`0Yoooo002R
oooo0P00053oool00ol0VOooooooo`0Yoooo002Roooo0`0004ooool00ol0VOooooooo`0Yoooo002S
oooo00<0003oooooool0C_ooo`03o`2Ioooooooo02Woool00:?oool00`000?ooooooo`1>oooo00?o
09Woooooool0:Oooo`00Xoooo`030000oooooooo04koool00ol0VOooooooo`0Yoooo002Soooo00<0
003oooooool0C_ooo`03o`2Ioooooooo02Woool00:?oool00`000?ooooooo`1>oooo00?o09Wooooo
ool0:Oooo`00Xoooo`80001?oooo00?o09Woooooool0:Oooo`00Xoooo`030000oooooooo04koool0
0ol0VOooooooo`0Yoooo002Soooo00<0003oooooool0C_ooo`03o`2Ioooooooo02Woool00:?oool0
0`000?ooooooo`1>oooo00?o09Woooooool0:Oooo`00Xoooo`030000oooooooo04koool00ol0VOoo
ooooo`0Yoooo002Moooo0`0000?oool00`000?ooooooo`1>oooo00?o09Woooooool0:Oooo`00W_oo
o`030000oooooooo00;oool00`000?ooooooo`1>oooo00?o09Woooooool0:Oooo`00Voooo`D00003
oooo0`0004koool00ol0VOooooooo`0Yoooo002Koooo00@0003oooooool00021oooo002Loooo00<0
003oool00000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007ooool00`000?oo
ooooo`0Loooo00<0003oooooool0Ooooo`00O_ooo`030000oooooooo00Soool00`000?ooooooo`0C
oooo00<0003oooooool0O_ooo`00O_ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool200001?ooo`800004oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002Oooo`030000
oooooooo07koool007goool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo
00Woool00`000?ooooooo`1moooo001noooo00<0003oooooool01@0000ooool00`000?ooooooo`07
oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Woool00`000?ooooooo`1noooo001ooooo00<0003oooooool04Oooo`800009oooo00<0003ooooo
ool0Ooooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.87754 .12361 L
.88797 .12361 L
.89307 .12361 L
.89771 .12361 L
.90008 .12361 L
.90133 .12361 L
.90265 .12361 L
.90381 .12361 L
s
.90381 .12361 m
.90432 .61803 L
s
0 .4 1 r
.02381 .12217 m
.04262 .1216 L
.06244 .12076 L
.07286 .12018 L
.08255 .11953 L
.09388 .11862 L
.10458 .11757 L
.125 .11492 L
.14357 .11151 L
.16355 .10634 L
.18199 .09962 L
.20071 .09012 L
.21136 .08312 L
.22134 .07524 L
.23988 .05631 L
.24967 .04348 L
.25102 .04153 L
.25249 .03935 L
.25316 .03834 L
.25387 .03725 L
.25514 .03712 L
.25637 .03714 L
.25751 .03716 L
.26011 .03721 L
.27107 .03742 L
.28124 .03767 L
.30133 .0383 L
.31179 .03872 L
.32169 .03921 L
.34024 .04038 L
.36015 .04216 L
.37857 .04447 L
.39724 .04772 L
.41784 .0528 L
.45804 .06639 L
.49673 .07962 L
.51638 .08535 L
.52677 .08794 L
.53787 .09027 L
.5434 .09123 L
.54862 .09199 L
.55331 .09253 L
.55596 .09277 L
.5584 .09295 L
.5595 .09301 L
.56068 .09306 L
.56179 .09311 L
.56281 .09313 L
.56401 .09315 L
.56531 .09316 L
Mistroke
.56653 .09315 L
.56767 .09312 L
.56896 .09307 L
.57017 .09301 L
.57125 .09294 L
.57243 .09284 L
.57507 .09255 L
.57749 .09218 L
.59795 .08791 L
.61703 .08406 L
.6264 .08234 L
.63657 .08068 L
.64618 .07941 L
.65076 .07893 L
.65506 .07858 L
.65751 .07841 L
.65976 .0783 L
.66096 .07825 L
.66226 .0782 L
.66357 .07817 L
.66429 .07815 L
.66495 .07814 L
.66561 .07814 L
.66632 .07813 L
.66761 .07814 L
.66887 .07815 L
.67003 .07818 L
.67129 .07821 L
.67266 .07827 L
.6741 .07835 L
.67545 .07843 L
.67785 .07863 L
.68013 .07887 L
.68441 .07945 L
.68901 .08031 L
.69402 .08154 L
.7034 .0848 L
.70875 .08731 L
.71377 .09014 L
.72387 .0975 L
.73477 .10838 L
.73978 .1146 L
.74253 .11839 L
.74388 .12035 L
.74513 .12222 L
.74631 .12361 L
.74756 .12361 L
.75019 .12361 L
.75478 .12361 L
.76485 .12361 L
Mistroke
.77587 .12361 L
.81373 .12361 L
.85404 .12361 L
.89283 .12361 L
.93407 .12361 L
.9738 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001Aoooo0`1V
odooool00`000?ooooooo`1joooo001@oooo0P1Vo`;ooolE06Ko>_ooo`030000oooooooo07[oool0
04ooool206Ko6?ooo`X0I_l`oooo00<0003oooooool0N_ooo`00C_ooo`0306Kooooooooo02;oool5
06Ko:oooo`030000oooooooo07[oool004koool00`1Vooooooooo`0Woooo101VobOoool20000Nooo
o`00COooo`0306Kooooooooo02coool206Ko9Oooo`030000oooooooo07[oool004coool00`1Voooo
ooooo`0_oooo0`1Vob;oool00`000?ooooooo`1joooo001;oooo00<0I_ooooooool0<oooo`80I_lP
oooo00<0003oooooool0N_ooo`00B_ooo`0306Kooooooooo03Koool306Ko7Oooo`030000oooooooo
07[oool004Woool00`1Vooooooooo`0joooo0`1Voa[oool00`000?ooooooo`1joooo0018oooo00<0
I_ooooooool0?_ooo`@0I_lFoooo0P0007_oool002_oool300006Oooo`0306Kooooooooo00coool3
00008oooo`@0000=oooo0`1Voa?oool00`000?ooooooo`0>oooo301Vo`Woool400009oooo`<0000Y
oooo000[oooo00@0003oooooool0000Goooo00<0I_ooooooool03_ooo`030000oooooooo02;oool0
0`000?ooooooo`0Aoooo0P1Voa7oool00`000?ooooooo`05oooo2@1Vo`coool206Ko1oooo`030000
oooooooo02Woool00`000?ooooooo`0Xoooo000[oooo00@0003oooooool0000Eoooo0P1Vo`koool5
00009?ooo`030000oooooooo01;oool606Ko2oooo`030000oooooooo00D0I_lGoooo0`1Vo`Goool0
0`000?ooooooo`0Uoooo1@0002Woool002Goool400000_ooo`<0000Doooo0P1Vo`[oool400000_oo
o`040000oooooooo00007_ooo`@00004oooo00<0003oooooool05oooo`@0I_l7oooo00<00000I_l0
I_l07oooo`0306Kooooooooo00?oool00`000?ooooooo`0Toooo00@0003oooooool0000Zoooo000/
oooo00<0003oooooool04Oooo`80I_lCoooo00<0003oool000009?ooo`040000oooooooo00007?oo
o`L0I_l00`000?ooooooo`0Poooo0P1Vo`05oooo0000oooooooo000002Koool00`000?ooo`00000Z
oooo000/oooo0`0000ooool206Ko5_ooo`80000Uoooo0P0002Coool200008oooo`0406Kooooo0000
0000:?ooo`80000Zoooo000loooo0P1VofGoool00`000?ooooooo`0Soooo00<0I_ooooooool0E?oo
o`00>?ooo`@0I_mWoooo00<0003oooooool08oooo`0306Kooooooooo05Coool003?oool506KoJooo
o`030000oooooooo02Coool00`1Vooooooooo`1Coooo000^oooo1@1Vog3oool00`000?ooooooo`0U
oooo0P1Voe?oool002Goool906KoMOooo`030000oooooooo02Koool00`1Vooooooooo`1Aoooo000@
ooooo`00017oool001Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`00000@000000<c
o`00000co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?l0
VOooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0V
oooo00<0003oooooool09Oooo`030000oooooooo00Koool400006c?o00030000oooooooo02Goool0
0`000?ooooooo`0Voooo00<0003o09Woool0:Oooo`00R?ooo`@0000G<ol000<0003oooooool0Cooo
o`03o`2Ioooooooo02Soool008coool00`0003?o03?o000D<ol000<0003oooooool0Coooo`03o`2I
oooooooo02Soool008goool2000053?o00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002?
oooo00<0000co`0co`004C?o00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002@oooo00<0
000co`0co`0043?o0080001@oooo00?o09Woooooool0:?ooo`00TOooo`80000@<ol000<0003ooooo
ool0Coooo`03o`2Ioooooooo02Soool009?oool00`0003?o03?o000=<ol000<0003oooooool0Cooo
o`03o`2Ioooooooo02Soool009?oool00`0003?o03?o000=<ol000<0003oooooool0Coooo`03o`2I
oooooooo02Soool009Coool00`0003?o03?o000<<ol000<0003oooooool0Coooo`03o`2Ioooooooo
02Soool009Coool00`0003?o03?o000<<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Soool0
09Goool00`0003?o03?o000;<ol00P00053oool00ol0VOooooooo`0Xoooo002Eoooo00<0000co`0c
o`002c?o00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Foooo00<0000co`0co`002S?o
00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Foooo00<0000co`0co`002S?o00030000
oooooooo04ooool00ol0VOooooooo`0Xoooo002Goooo00<0000co`0co`002C?o00030000oooooooo
04ooool00ol0VOooooooo`0Xoooo002Goooo00<0000co`0co`002C?o00030000oooooooo04ooool0
0ol0VOooooooo`0Xoooo002Hoooo00<0000co`0co`0023?o0080001@oooo00?o09Woooooool0:?oo
o`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00V?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00VOooo`030000
<ol0<ol000Lco`000`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00VOooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00VOooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00VOooo`030000<ol0<ol000Lco`020000D?oo
o`03o`2Ioooooooo02Soool009[oool00`0003?o03?o0006<ol000<0003oooooool0Coooo`03o`2I
oooooooo02Soool009[oool00`0003?o03?o0006<ol000<0003oooooool0Coooo`03o`2Ioooooooo
02Soool009[oool00`0003?o03?o0006<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Soool0
09[oool00`0003?o03?o0006<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Soool009_oool5
00000c?o00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Koooo00<0000co`0000001C?o
00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Koooo00<0000co`0000001C?o00<0001?
oooo00?o09Woooooool0:?ooo`00W?ooo`800005<ol000<0003oooooool0Coooo`03o`2Ioooooooo
02Soool009coool200001C?o00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Loooo0P00
00Dco`000`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00W?ooo`030000<ol0<ol000@co`00
0`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00W?ooo`030000<ol0<ol000@co`000`000?oo
ooooo`1?oooo00?o09Woooooool0:?ooo`00W?ooo`030000<ol0<ol000@co`020000D?ooo`03o`2I
oooooooo02Soool009goool00`0003?o03?o0003<ol000<0003oooooool0Coooo`03o`2Ioooooooo
02Soool009goool00`0003?o03?o0003<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Soool0
09goool00`0003?o03?o0003<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Soool009goool0
0`0003?o03?o0003<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Soool009goool00`0003?o
03?o0003<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Soool009goool00`0003?o03?o0003
<ol00P00053oool00ol0VOooooooo`0Xoooo002Moooo00<0000co`0co`000c?o00030000oooooooo
04ooool00ol0VOooooooo`0Xoooo002Moooo00<0000co`0co`000c?o00030000oooooooo04ooool0
0ol0VOooooooo`0Xoooo002Noooo00<0000co`0co`000S?o00030000oooooooo04ooool00ol0VOoo
ooooo`0Xoooo002Noooo00<0000co`0co`000S?o00030000oooooooo04ooool00ol0VOooooooo`0X
oooo002Noooo00<0000co`0co`000S?o00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002N
oooo00<0000co`0co`000S?o00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Noooo00<0
000co`0co`000S?o0080001@oooo00?o09Woooooool0:?ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1?oooo00?o09Woooooool0:?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1?
oooo00?o09Woooooool0:?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1?oooo00?o
09Woooooool0:?ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1?oooo00?o09Wooooo
ool0:?ooo`00W_ooo`030000<ol0<ol0008co`020000D?ooo`03o`2Ioooooooo02Soool009ooool0
1@0003?o03?o03?o0000001Aoooo00?o09Woooooool0:?ooo`00Woooo`050000<ol0<ol0<ol00000
057oool00ol0VOooooooo`0Xoooo002Ooooo00D0000co`0co`0co`000000DOooo`03o`2Ioooooooo
02Soool009_oool500000c?o00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Koooo00D0
003oooooooooool000000c?o00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Loooo00@0
003oooooool00003<ol00`0004ooool00ol0VOooooooo`0Xoooo002Moooo00<0003oool000000c?o
00030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Koooo00<0003oooooool00P0000<co`00
0`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00W?ooo`8000000oooo`0003?o0002<ol000<0
003oooooool0Coooo`03o`2Ioooooooo02Soool009ooool01@0003?o03?o03?o0000001Aoooo00?o
09Woooooool0:?ooo`00X?ooo`040000<ol0<ol00000DOooo`03o`2Ioooooooo02Soool00:3oool0
0`0003?o03?o00020000D?ooo`03o`2Ioooooooo02Soool00:3oool0100003?o03?o0000057oool0
0ol0VOooooooo`0Xoooo002Poooo00@0000co`0co`00001Aoooo00?o09Woooooool0:?ooo`00X?oo
o`040000<ol0<ol00000DOooo`03o`2Ioooooooo02Soool00:3oool0100003?o03?o0000057oool0
0ol0VOooooooo`0Xoooo002Poooo00@0000co`0co`00001Aoooo00?o09Woooooool0:?ooo`00X?oo
o`040000<ol0<ol00000DOooo`03o`2Ioooooooo02Soool00:7oool0100003?o00000000053oool0
0ol0VOooooooo`0Xoooo002Qoooo00<0000co`000000DOooo`03o`2Ioooooooo02Soool00:7oool0
0`0003?o0000001Aoooo00?o09Woooooool0:?ooo`00XOooo`030000<ol00000057oool00ol0VOoo
ooooo`0Xoooo002Qoooo00<0000co`000000DOooo`03o`2Ioooooooo02Soool00:7oool00`0003?o
0000001Aoooo00?o09Woooooool0:?ooo`00XOooo`040000<ol000000000D?ooo`03o`2Ioooooooo
02Soool00:7oool00`0003?o0000001Aoooo00?o09Woooooool0:?ooo`00XOooo`030000<ol00000
057oool00ol0VOooooooo`0Xoooo002Qoooo00<0000co`000000DOooo`03o`2Ioooooooo02Soool0
0:7oool00`0003?o0000001Aoooo00?o09Woooooool0:?ooo`00XOooo`030000<ol00000057oool0
0ol0VOooooooo`0Xoooo002Qoooo00@0000co`000000001@oooo00?o09Woooooool0:?ooo`00XOoo
o`030000<ol00000057oool00ol0VOooooooo`0Xoooo002Qoooo00<0000co`000000DOooo`03o`2I
oooooooo02Soool00:7oool00`0003?o0000001Aoooo00?o09Woooooool0:?ooo`00W?ooo`800003
oooo00<0000co`000000DOooo`03o`2Ioooooooo02Soool009_oool010000?ooooooo`0000;oool0
0`0003?o0000001Aoooo00?o09Woooooool0:?ooo`00WOooo`060000oooooooooooo0000<ol00`00
04ooool00ol0VOooooooo`0Xoooo002Noooo00H0003oooooool0000co`00001Aoooo00?o09Wooooo
ool0:?ooo`00Voooo`040000oooooooo00000_ooo`030000<ol00000057oool00ol0VOooooooo`0X
oooo002Loooo0P0000Coool20000DOooo`03o`2Ioooooooo02Soool00:;oool20000DOooo`03o`2I
oooooooo02Soool00:;oool20000DOooo`03o`2Ioooooooo02Soool00:;oool20000DOooo`03o`2I
oooooooo02Soool00:;oool30000D?ooo`03o`2Ioooooooo02Soool00:;oool20000DOooo`03o`2I
oooooooo02Soool00:;oool20000DOooo`03o`2Ioooooooo02Soool00:;oool20000DOooo`03o`2I
oooooooo02Soool00:;oool20000DOooo`03o`2Ioooooooo02Soool00:;oool20000DOooo`03o`2I
oooooooo02Soool00:;oool30000D?ooo`03o`2Ioooooooo02Soool00:;oool20000DOooo`03o`2I
oooooooo02Soool00:;oool20000DOooo`03o`2Ioooooooo02Soool00:;oool20000DOooo`03o`2I
oooooooo02Soool00:;oool20000DOooo`03o`2Ioooooooo02Soool00:;oool20000DOooo`03o`2I
oooooooo02Soool00:;oool30000D?ooo`03o`2Ioooooooo02Soool00:?oool00`000?ooooooo`1?
oooo00?o09Woooooool0:?ooo`00Xoooo`030000oooooooo04ooool00ol0VOooooooo`0Xoooo002S
oooo00<0003oooooool0Coooo`03o`2Ioooooooo02Soool00:?oool00`000?ooooooo`1?oooo00?o
09Woooooool0:?ooo`00Xoooo`030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Soooo0P00
053oool00ol0VOooooooo`0Xoooo002Soooo00<0003oooooool0Coooo`03o`2Ioooooooo02Soool0
0:?oool00`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00Xoooo`030000oooooooo04ooool0
0ol0VOooooooo`0Xoooo002Soooo00<0003oooooool0Coooo`03o`2Ioooooooo02Soool009goool3
00000oooo`030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Noooo00<0003oooooool00_oo
o`030000oooooooo04ooool00ol0VOooooooo`0Xoooo002Koooo1@0000?oool30000Coooo`03o`2I
oooooooo02Soool009_oool010000?ooooooo`00087oool009coool00`000?ooo`000021oooo002M
oooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?oo
ooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1k
oooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P00
00?oool500000_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0
003oooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003ooooo
ool01@0000ooool00`000?ooooooo`08oooo00<0003oooooool00_ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.87754 .12361 L
.88797 .12361 L
.89771 .12361 L
.90265 .12361 L
.90733 .12361 L
.90992 .12361 L
.91063 .12361 L
.91138 .12361 L
.91202 .12361 L
s
.91202 .12361 m
.9123 .61803 L
s
0 .4 1 r
.02381 .12196 m
.04262 .1213 L
.06244 .12032 L
.07286 .11965 L
.08255 .11891 L
.09388 .11786 L
.10458 .11665 L
.125 .1136 L
.14357 .10967 L
.16355 .10371 L
.18199 .09597 L
.20071 .08503 L
.21136 .07697 L
.22134 .06789 L
.23988 .04609 L
.24249 .04239 L
.24495 .03875 L
.24562 .03774 L
.24632 .0371 L
.24709 .03712 L
.24779 .03713 L
.25037 .03717 L
.26011 .03736 L
.27018 .03758 L
.28124 .03788 L
.29175 .03823 L
.30133 .0386 L
.32084 .0396 L
.33158 .04032 L
.34176 .04113 L
.36167 .04323 L
.38009 .04595 L
.39875 .04979 L
.41935 .05566 L
.45956 .06971 L
.49824 .08256 L
.51789 .08796 L
.52828 .09036 L
.53938 .09248 L
.54492 .09334 L
.55014 .09399 L
.55483 .09444 L
.55747 .09463 L
.55865 .09469 L
.55991 .09475 L
.5611 .09479 L
.56219 .09482 L
.56329 .09484 L
.56433 .09484 L
.56553 .09484 L
Mistroke
.56665 .09482 L
.56788 .09478 L
.56919 .09473 L
.57046 .09465 L
.57184 .09455 L
.57434 .09429 L
.57677 .09395 L
.57901 .09355 L
.61855 .08532 L
.63845 .08164 L
.64714 .0803 L
.65657 .07914 L
.66179 .07867 L
.66409 .0785 L
.66662 .07835 L
.66776 .07829 L
.669 .07824 L
.67006 .07821 L
.67123 .07817 L
.67247 .07815 L
.67378 .07814 L
.67499 .07813 L
.67612 .07814 L
.67743 .07816 L
.67817 .07818 L
.67885 .0782 L
.68011 .07825 L
.68143 .07831 L
.68372 .07846 L
.68625 .07867 L
.68894 .07897 L
.69183 .07937 L
.69705 .08034 L
.70232 .08165 L
.70721 .0832 L
.71246 .08529 L
.71826 .08815 L
.72801 .09446 L
.73838 .10366 L
.74779 .1147 L
.75027 .11811 L
.75163 .12007 L
.75292 .122 L
.75412 .12361 L
.75542 .12361 L
.7577 .12361 L
.76289 .12361 L
.76857 .12361 L
.77855 .12361 L
.81944 .12361 L
Mistroke
.85881 .12361 L
.89666 .12361 L
.93697 .12361 L
.97576 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001?oooo0P1V
oe;oool00`000?ooooooo`1joooo001>oooo00<0I_ooooooool06@1VocWoool00`000?ooooooo`1j
oooo001>oooo00<0I_ooooooool06Oooo`D0I_ldoooo00<0003oooooool0N_ooo`00COooo`0306Ko
oooooooo01ooool406Ko<?ooo`030000oooooooo07[oool004coool00`1Vooooooooo`0Toooo1@1V
ob_oool20000Noooo`00Boooo`0306Kooooooooo02[oool506Ko9_ooo`030000oooooooo07[oool0
04[oool00`1Vooooooooo`0`oooo0P1VobCoool00`000?ooooooo`1joooo0019oooo00<0I_oooooo
ool0<oooo`<0I_lQoooo00<0003oooooool0N_ooo`00B?ooo`0306Kooooooooo03Ooool206Ko7ooo
o`030000oooooooo07[oool004Ooool00`1Vooooooooo`0joooo0`1Voacoool00`000?ooooooo`1j
oooo0017oooo00<0I_ooooooool0?Oooo`<0I_lIoooo0P0007_oool002_oool300006?ooo`0306Ko
oooooooo00goool300008oooo`@0000:oooo101VoaGoool00`000?ooooooo`0>oooo3P1Vo`Ooool4
00009oooo`<0000Yoooo000[oooo00@0003oooooool0000Eoooo0P1Voa7oool00`000?ooooooo`0R
oooo00<0003oooooool03oooo`@0I_lAoooo00<0003oooooool02_ooo`@0I_l>oooo0`1Vo`Coool0
0`000?ooooooo`0Yoooo00<0003oooooool0:?ooo`00:oooo`040000oooooooo00004oooo`80I_l@
oooo1@0002Coool00`000?ooooooo`0Boooo0`1Vo`koool00`000?ooooooo`05oooo1@1VoaGoool2
06Ko0oooo`030000oooooooo02Goool50000:Oooo`009Oooo`@00002oooo0`0001;oool206Ko3?oo
o`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0Doooo0`1Vo`_oool0
0`000?ooooooo`0506Ko7?ooo`80I_l2oooo00<0003oooooool09?ooo`040000oooooooo0000:_oo
o`00;?ooo`030000oooooooo00ooool206Ko5Oooo`030000oooo000002Coool010000?ooooooo`00
01Soool;06Ko00<00000I_l0I_l08oooo`040000oooooooo00009_ooo`030000oooo000002[oool0
02coool300003Oooo`80I_lHoooo0P0002Goool200009?ooo`80000Uoooo0P0002Soool20000:_oo
o`00>Oooo`<0I_mWoooo00<0003oooooool09Oooo`0306Kooooooooo05;oool003Ooool206KoJ_oo
o`030000oooooooo02Koool00`1Vooooooooo`1Aoooo000coooo101Vofcoool00`000?ooooooo`0W
oooo00<0I_ooooooool0D?ooo`00;_ooo`D0I_m`oooo00<0003oooooool0:?ooo`0306Kooooooooo
04ooool002;oool<06KoMOooo`030000oooooooo02Soool00`1Vooooooooo`1?oooo000@ooooo`00
017oool001Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`00000@000000<co`00000c
o`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool010000?ooooooool0
V@Koool00`000?ooooooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo02Koool0
0`000?ooooooo`0Uoooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Oooo`030000
oooooooo02Koool010000?ooooooool0VBSoool008Soool400005c?o00030000oooooooo057oool0
0ol0VOooooooo`0Voooo002<oooo00<0000co`0co`0053?o00030000oooooooo057oool00ol0VOoo
ooooo`0Voooo002=oooo0P0001@co`000`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00T?ooo`030000
<ol0<ol0010co`020000D_ooo`03o`2Ioooooooo02Koool0097oool2000043?o00030000oooooooo
057oool00ol0VOooooooo`0Voooo002Coooo00<0000co`0co`003C?o00030000oooooooo057oool0
0ol0VOooooooo`0Voooo002Coooo00<0000co`0co`003C?o00030000oooooooo057oool00ol0VOoo
ooooo`0Voooo002Doooo00<0000co`0co`0033?o00030000oooooooo057oool00ol0VOooooooo`0V
oooo002Doooo00<0000co`0co`0033?o00030000oooooooo057oool00ol0VOooooooo`0Voooo002E
oooo00<0000co`0co`002c?o0080001Boooo00?o09Woooooool09_ooo`00UOooo`030000<ol0<ol0
00/co`000`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00U_ooo`030000<ol0<ol000Xco`00
0`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00U_ooo`030000<ol0<ol000Xco`000`000?oo
ooooo`1Aoooo00?o09Woooooool09_ooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`1A
oooo00?o09Woooooool09_ooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`1Aoooo00?o
09Woooooool09_ooo`00V?ooo`030000<ol0<ol000Pco`020000D_ooo`03o`2Ioooooooo02Koool0
09Soool00`0003?o03?o0008<ol000<0003oooooool0DOooo`03o`2Ioooooooo02Koool009Soool0
0`0003?o03?o0008<ol000<0003oooooool0DOooo`03o`2Ioooooooo02Koool009Woool00`0003?o
03?o0007<ol000<0003oooooool0DOooo`03o`2Ioooooooo02Koool009Woool00`0003?o03?o0007
<ol000<0003oooooool0DOooo`03o`2Ioooooooo02Koool009Woool00`0003?o03?o0007<ol000<0
003oooooool0DOooo`03o`2Ioooooooo02Koool009Woool00`0003?o03?o0007<ol00P0005;oool0
0ol0VOooooooo`0Voooo002Joooo00<0000co`0co`001S?o00030000oooooooo057oool00ol0VOoo
ooooo`0Voooo002Joooo00<0000co`0co`001S?o00030000oooooooo057oool00ol0VOooooooo`0V
oooo002Joooo00<0000co`0co`001S?o00030000oooooooo057oool00ol0VOooooooo`0Voooo002J
oooo00<0000co`0co`001S?o00030000oooooooo057oool00ol0VOooooooo`0Voooo002Koooo1@00
00<co`000`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00Voooo`030000<ol0000000Dco`00
0`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00Voooo`030000<ol0000000Dco`030000DOoo
o`03o`2Ioooooooo02Koool009coool200001C?o00030000oooooooo057oool00ol0VOooooooo`0V
oooo002Loooo0P0000Dco`000`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00W?ooo`800005
<ol000<0003oooooool0DOooo`03o`2Ioooooooo02Koool009coool00`0003?o03?o0004<ol000<0
003oooooool0DOooo`03o`2Ioooooooo02Koool009coool00`0003?o03?o0004<ol000<0003ooooo
ool0DOooo`03o`2Ioooooooo02Koool009coool00`0003?o03?o0004<ol00P0005;oool00ol0VOoo
ooooo`0Voooo002Moooo00<0000co`0co`000c?o00030000oooooooo057oool00ol0VOooooooo`0V
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo057oool00ol0VOooooooo`0Voooo002M
oooo00<0000co`0co`000c?o00030000oooooooo057oool00ol0VOooooooo`0Voooo002Moooo00<0
000co`0co`000c?o00030000oooooooo057oool00ol0VOooooooo`0Voooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo057oool00ol0VOooooooo`0Voooo002Moooo00<0000co`0co`000c?o
0080001Boooo00?o09Woooooool09_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1A
oooo00?o09Woooooool09_ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1Aoooo00?o
09Woooooool09_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1Aoooo00?o09Wooooo
ool09_ooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1Aoooo00?o09Woooooool09_oo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00W_ooo`030000
<ol0<ol0008co`020000D_ooo`03o`2Ioooooooo02Koool009koool00`0003?o03?o0002<ol000<0
003oooooool0DOooo`03o`2Ioooooooo02Koool009koool00`0003?o03?o0002<ol000<0003ooooo
ool0DOooo`03o`2Ioooooooo02Koool009koool00`0003?o03?o0002<ol000<0003oooooool0DOoo
o`03o`2Ioooooooo02Koool009koool00`0003?o03?o0002<ol000<0003oooooool0DOooo`03o`2I
oooooooo02Koool009koool00`0003?o03?o0002<ol000<0003oooooool0DOooo`03o`2Ioooooooo
02Koool009koool00`0003?o03?o0002<ol00P0005;oool00ol0VOooooooo`0Voooo002Ooooo00D0
000co`0co`0co`000000Doooo`03o`2Ioooooooo02Koool009ooool01@0003?o03?o03?o0000001C
oooo00?o09Woooooool09_ooo`00Woooo`050000<ol0<ol0<ol0000005?oool00ol0VOooooooo`0V
oooo002Koooo1@0000<co`000`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00Voooo`050000
oooooooooooo000000<co`000`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00W?ooo`040000
oooooooo00000c?o00<0001Aoooo00?o09Woooooool09_ooo`00WOooo`030000oooo000000<co`00
0`000?ooooooo`1Boooo00?o09Woooooool09Oooo`00Voooo`030000oooooooo00800003<ol000<0
003oooooool0D_ooo`03o`2Ioooooooo02Goool009coool2000000?oool0000co`000S?o00030000
oooooooo05;oool00ol0VOooooooo`0Uoooo002Ooooo00D0000co`0co`0co`000000E?ooo`03o`2I
oooooooo02Goool00:3oool0100003?o03?o000005Coool00ol0VOooooooo`0Uoooo002Poooo00<0
000co`0co`000P0005?oool00ol0VOooooooo`0Uoooo002Poooo00@0000co`0co`00001Doooo00?o
09Woooooool09Oooo`00X?ooo`040000<ol0<ol00000E?ooo`03o`2Ioooooooo02Goool00:3oool0
100003?o03?o000005Coool00ol0VOooooooo`0Uoooo002Poooo00@0000co`0co`00001Doooo00?o
09Woooooool09Oooo`00X?ooo`040000<ol0<ol00000E?ooo`03o`2Ioooooooo02Goool00:3oool0
100003?o03?o000005Coool00ol0VOooooooo`0Uoooo002Qoooo00@0000co`000000001Coooo00?o
09Woooooool09Oooo`00XOooo`030000<ol0000005Coool00ol0VOooooooo`0Uoooo002Qoooo00<0
000co`000000E?ooo`03o`2Ioooooooo02Goool00:7oool00`0003?o0000001Doooo00?o09Wooooo
ool09Oooo`00XOooo`030000<ol0000005Coool00ol0VOooooooo`0Uoooo002Qoooo00<0000co`00
0000E?ooo`03o`2Ioooooooo02Goool00:7oool0100003?o0000000005?oool00ol0VOooooooo`0U
oooo002Qoooo00<0000co`000000E?ooo`03o`2Ioooooooo02Goool00:7oool00`0003?o0000001D
oooo00?o09Woooooool09Oooo`00XOooo`030000<ol0000005Coool00ol0VOooooooo`0Uoooo002Q
oooo00<0000co`000000E?ooo`03o`2Ioooooooo02Goool00:7oool00`0003?o0000001Doooo00?o
09Woooooool09Oooo`00XOooo`040000<ol000000000Doooo`03o`2Ioooooooo02Goool00:7oool0
0`0003?o0000001Doooo00?o09Woooooool09Oooo`00XOooo`030000<ol0000005Coool00ol0VOoo
ooooo`0Uoooo002Qoooo00<0000co`000000E?ooo`03o`2Ioooooooo02Goool009coool200000ooo
o`030000<ol0000005Coool00ol0VOooooooo`0Uoooo002Koooo00@0003oooooool00002oooo00<0
000co`000000E?ooo`03o`2Ioooooooo02Goool009goool01P000?ooooooooooo`0003?o00<0001B
oooo00?o09Woooooool09Oooo`00W_ooo`060000oooooooo0000<ol00000E?ooo`03o`2Ioooooooo
02Goool009_oool010000?ooooooo`0000;oool00`0003?o0000001Doooo00?o09Woooooool09Ooo
o`00W?ooo`800004oooo0P0005Coool00ol0VOooooooo`0Uoooo002Roooo0P0005Coool00ol0VOoo
ooooo`0Uoooo002Roooo0P0005Coool00ol0VOooooooo`0Uoooo002Roooo0P0005Coool00ol0VOoo
ooooo`0Uoooo002Roooo0`0005?oool00ol0VOooooooo`0Uoooo002Roooo0P0005Coool00ol0VOoo
ooooo`0Uoooo002Roooo0P0005Coool00ol0VOooooooo`0Uoooo002Roooo0P0005Coool00ol0VOoo
ooooo`0Uoooo002Roooo0P0005Coool00ol0VOooooooo`0Uoooo002Roooo0P0005Coool00ol0VOoo
ooooo`0Uoooo002Roooo0`0005?oool00ol0VOooooooo`0Uoooo002Roooo0P0005Coool00ol0VOoo
ooooo`0Uoooo002Roooo0P0005Coool00ol0VOooooooo`0Uoooo002Roooo0P0005Coool00ol0VOoo
ooooo`0Uoooo002Roooo0P0005Coool00ol0VOooooooo`0Uoooo002Roooo0P0005Coool00ol0VOoo
ooooo`0Uoooo002Roooo0`0005?oool00ol0VOooooooo`0Uoooo002Soooo00<0003oooooool0D_oo
o`03o`2Ioooooooo02Goool00:?oool00`000?ooooooo`1Boooo00?o09Woooooool09Oooo`00Xooo
o`030000oooooooo05;oool00ol0VOooooooo`0Uoooo002Soooo00<0003oooooool0D_ooo`03o`2I
oooooooo02Goool00:?oool00`000?ooooooo`1Boooo00?o09Woooooool09Oooo`00Xoooo`80001C
oooo00?o09Woooooool09Oooo`00Xoooo`030000oooooooo05;oool00ol0VOooooooo`0Uoooo002S
oooo00<0003oooooool0D_ooo`03o`2Ioooooooo02Goool00:?oool00`000?ooooooo`1Boooo00?o
09Woooooool09Oooo`00Xoooo`030000oooooooo05;oool00ol0VOooooooo`0Uoooo002Moooo0`00
00?oool00`000?ooooooo`1Boooo00?o09Woooooool09Oooo`00W_ooo`030000oooooooo00;oool0
0`000?ooooooo`1Boooo00?o09Woooooool09Oooo`00Voooo`D00003oooo0`0005;oool00ol0VOoo
ooooo`0Uoooo002Koooo00@0003oooooool00021oooo002Loooo00<0003oool00000POooo`00WOoo
o`800021oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Nooo
o`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003
oooo100000?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00<0003oooooool01?oo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000
oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000?oooo00<0003oooooool02?ooo`030000oooooooo00;oool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.90802 .12361 L
.91306 .12361 L
.91765 .12361 L
.91884 .12361 L
.92014 .12361 L
s
.92014 .12361 m
.92063 .61803 L
s
0 .4 1 r
.02381 .12171 m
.04262 .12095 L
.06244 .11982 L
.07286 .11905 L
.08255 .11819 L
.09388 .11698 L
.10458 .11559 L
.125 .11208 L
.14357 .10755 L
.16355 .10069 L
.18199 .09178 L
.20071 .07917 L
.21136 .06988 L
.22134 .05943 L
.23172 .04639 L
.23419 .04291 L
.23555 .04093 L
.23683 .03902 L
.23803 .0372 L
.23933 .03712 L
.2405 .03714 L
.24158 .03715 L
.25044 .03732 L
.26011 .03753 L
.27893 .03805 L
.28962 .03844 L
.2996 .03888 L
.31995 .04005 L
.33851 .04155 L
.35759 .04371 L
.36837 .0453 L
.37835 .04707 L
.39702 .05134 L
.41762 .05767 L
.45782 .07187 L
.49651 .08444 L
.51616 .08967 L
.52655 .092 L
.53765 .09407 L
.54318 .09491 L
.5484 .09556 L
.55309 .09601 L
.55574 .09621 L
.55691 .09628 L
.55817 .09635 L
.55937 .0964 L
.56046 .09644 L
.56155 .09647 L
.56259 .09648 L
.5638 .09649 L
Mistroke
.56492 .09648 L
.56614 .09647 L
.56745 .09643 L
.56873 .09637 L
.57011 .0963 L
.5726 .0961 L
.57504 .09582 L
.57727 .09549 L
.61681 .08729 L
.63671 .08334 L
.65484 .08034 L
.65965 .0797 L
.66488 .07911 L
.66982 .07866 L
.67202 .0785 L
.67438 .07836 L
.67569 .07829 L
.67688 .07824 L
.67809 .0782 L
.67921 .07817 L
.68045 .07815 L
.68111 .07814 L
.68181 .07814 L
.68255 .07813 L
.68324 .07814 L
.68454 .07815 L
.68585 .07818 L
.68651 .07819 L
.68723 .07822 L
.68971 .07833 L
.69111 .07842 L
.69261 .07853 L
.69531 .07879 L
.70059 .0795 L
.70547 .08044 L
.71083 .08181 L
.71653 .08371 L
.72608 .08808 L
.73153 .09134 L
.73664 .09499 L
.75509 .11387 L
.75769 .11739 L
.76015 .12093 L
.76081 .12192 L
.76151 .12299 L
.76227 .12361 L
.76298 .12361 L
.76556 .12361 L
.7753 .12361 L
.79531 .12361 L
Mistroke
.8164 .12361 L
.85426 .12361 L
.89457 .12361 L
.93336 .12361 L
.9746 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001=oooo0P1V
oeCoool00`000?ooooooo`1joooo001<oooo00<0I_ooooooool05@1Vocooool00`000?ooooooo`1j
oooo001<oooo00<0I_ooooooool05Oooo`T0I_lfoooo00<0003oooooool0N_ooo`00Boooo`0306Ko
oooooooo01ooool606Ko<?ooo`030000oooooooo07[oool004[oool00`1Vooooooooo`0Voooo101V
obcoool20000Noooo`00BOooo`0306Kooooooooo02_oool206Ko:_ooo`030000oooooooo07[oool0
04Soool00`1Vooooooooo`0^oooo0`1VobOoool00`000?ooooooo`1joooo0017oooo00<0I_oooooo
ool0<_ooo`<0I_lToooo00<0003oooooool0N_ooo`00Aoooo`0306Kooooooooo03Goool406Ko8?oo
o`030000oooooooo07[oool004Koool00`1Vooooooooo`0joooo0`1Voagoool00`000?ooooooo`1j
oooo0014oooo0P1Vod3oool306Ko6_ooo`80001koooo000[oooo0`0001Goool00`1Vooooooooo`0@
oooo0`0002?oool400002Oooo`@0I_lFoooo00<0003oooooool03oooo`l0I_l5oooo100002Ooool3
0000:Oooo`00:oooo`040000oooooooo00004_ooo`80I_lDoooo00<0003oooooool08_ooo`030000
oooooooo00koool306Ko4oooo`030000oooooooo00[oool506Ko3oooo`<0I_l2oooo00<0003ooooo
ool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`00013oool206Ko4oooo`D0000T
oooo00<0003oooooool04?ooo`80I_lAoooo00<0003oooooool01Oooo`D0I_lGoooo0P1Vo`03oooo
0000oooo02Koool50000:Oooo`009Oooo`@00002oooo0`00013oool00`1Vooooooooo`0=oooo1000
00;oool010000?ooooooo`0001koool400001?ooo`030000oooooooo017oool606Ko2oooo`030000
oooooooo00D0I_lNoooo0P1Vo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0>oooo00<0I_ooooooool05Oooo`030000oooo000002Coool010000?ooooooo`00
01Soool706Ko00Goool0I_l0I_l0I_l000000P1Vob?oool010000?ooo`1Vo`0002Koool00`000?oo
o`00000Zoooo000/oooo0`0000coool206Ko6Oooo`80000Uoooo0P0001ooool306Ko0_ooo`80000U
oooo0P00000306Kooooooooo02Goool20000:_ooo`00>?ooo`<0I_mXoooo00<0003oooooool09ooo
o`0306Kooooooooo053oool003?oool506KoJoooo`030000oooooooo02Soool00`1Vooooooooo`1?
oooo000^oooo1@1Vog3oool00`000?ooooooo`0Yoooo00<0I_ooooooool0C_ooo`00:_ooo`@0I_me
oooo00<0003oooooool0:_ooo`0306Kooooooooo04goool001koool<06KoNOooo`030000oooooooo
02[oool00`1Vooooooooo`1=oooo000@ooooo`00017oool001Koool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?oo
o`030000oooooooo00Ooool00`000?ooooooo`02oooo00?o09Woooooool00_ooo`030000oooooooo
00Ooool00`000?ooooooo`0Eoooo000Zoooo00<0003oooooool09_ooo`030000oooooooo02Goool0
0`000?ooooooo`06oooo100001/co`000`000?ooooooo`0Uoooo00<0003oooooool09_ooo`030000
oooooooo00;oool00ol0VOooooooo`0Toooo0028oooo100001Lco`000`000?ooooooo`1Coooo00?o
09Woooooool09?ooo`00S?ooo`030000<ol0<ol001@co`000`000?ooooooo`1Coooo00?o09Wooooo
ool09?ooo`00SOooo`80000D<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool008ooool0
0`0003?o03?o000A<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool0093oool00`0003?o
03?o000@<ol00P0005Coool00ol0VOooooooo`0Toooo002Aoooo0P00010co`000`000?ooooooo`1C
oooo00?o09Woooooool09?ooo`00Toooo`030000<ol0<ol000dco`000`000?ooooooo`1Coooo00?o
09Woooooool09?ooo`00Toooo`030000<ol0<ol000dco`000`000?ooooooo`1Coooo00?o09Wooooo
ool09?ooo`00U?ooo`030000<ol0<ol000`co`000`000?ooooooo`1Coooo00?o09Woooooool09?oo
o`00U?ooo`030000<ol0<ol000`co`000`000?ooooooo`1Coooo00?o09Woooooool09?ooo`00UOoo
o`030000<ol0<ol000/co`020000E?ooo`03o`2Ioooooooo02Coool009Goool00`0003?o03?o000;
<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool009Koool00`0003?o03?o000:<ol000<0
003oooooool0Doooo`03o`2Ioooooooo02Coool009Koool00`0003?o03?o000:<ol000<0003ooooo
ool0Doooo`03o`2Ioooooooo02Coool009Ooool00`0003?o03?o0009<ol000<0003oooooool0Dooo
o`03o`2Ioooooooo02Coool009Ooool00`0003?o03?o0009<ol000<0003oooooool0Doooo`03o`2I
oooooooo02Coool009Soool00`0003?o03?o0008<ol00P0005Coool00ol0VOooooooo`0Toooo002H
oooo00<0000co`0co`0023?o00030000oooooooo05?oool00ol0VOooooooo`0Toooo002Hoooo00<0
000co`0co`0023?o00030000oooooooo05?oool00ol0VOooooooo`0Toooo002Ioooo00<0000co`0c
o`001c?o00030000oooooooo05?oool00ol0VOooooooo`0Toooo002Ioooo00<0000co`0co`001c?o
00030000oooooooo05?oool00ol0VOooooooo`0Toooo002Ioooo00<0000co`0co`001c?o00030000
oooooooo05?oool00ol0VOooooooo`0Toooo002Ioooo00<0000co`0co`001c?o0080001Doooo00?o
09Woooooool09?ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1Coooo00?o09Wooooo
ool09?ooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1Coooo00?o09Woooooool09?oo
o`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1Coooo00?o09Woooooool09?ooo`00V_oo
o`030000<ol0<ol000Hco`000`000?ooooooo`1Coooo00?o09Woooooool09?ooo`00Voooo`D00003
<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool009_oool00`0003?o00000005<ol000<0
003oooooool0Doooo`03o`2Ioooooooo02Coool009_oool00`0003?o00000005<ol00`0005?oool0
0ol0VOooooooo`0Toooo002Loooo0P0000Dco`000`000?ooooooo`1Coooo00?o09Woooooool09?oo
o`00W?ooo`800005<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool009coool200001C?o
00030000oooooooo05?oool00ol0VOooooooo`0Toooo002Loooo00<0000co`0co`0013?o00030000
oooooooo05?oool00ol0VOooooooo`0Toooo002Loooo00<0000co`0co`0013?o00030000oooooooo
05?oool00ol0VOooooooo`0Toooo002Loooo00<0000co`0co`0013?o0080001Doooo00?o09Wooooo
ool09?ooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1Coooo00?o09Woooooool09?oo
o`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1Coooo00?o09Woooooool09?ooo`00WOoo
o`030000<ol0<ol000<co`000`000?ooooooo`1Coooo00?o09Woooooool09?ooo`00WOooo`030000
<ol0<ol000<co`000`000?ooooooo`1Coooo00?o09Woooooool09?ooo`00WOooo`030000<ol0<ol0
00<co`000`000?ooooooo`1Coooo00?o09Woooooool09?ooo`00WOooo`030000<ol0<ol000<co`02
0000E?ooo`03o`2Ioooooooo02Coool009goool00`0003?o03?o0003<ol000<0003oooooool0Dooo
o`03o`2Ioooooooo02Coool009goool00`0003?o03?o0003<ol000<0003oooooool0Doooo`03o`2I
oooooooo02Coool009koool00`0003?o03?o0002<ol000<0003oooooool0Doooo`03o`2Ioooooooo
02Coool009koool00`0003?o03?o0002<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool0
09koool00`0003?o03?o0002<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool009koool0
0`0003?o03?o0002<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool009koool00`0003?o
03?o0002<ol00P0005Coool00ol0VOooooooo`0Toooo002Noooo00<0000co`0co`000S?o00030000
oooooooo05?oool00ol0VOooooooo`0Toooo002Noooo00<0000co`0co`000S?o00030000oooooooo
05?oool00ol0VOooooooo`0Toooo002Noooo00<0000co`0co`000S?o00030000oooooooo05?oool0
0ol0VOooooooo`0Toooo002Noooo00<0000co`0co`000S?o00030000oooooooo05?oool00ol0VOoo
ooooo`0Toooo002Noooo00<0000co`0co`000S?o00030000oooooooo05?oool00ol0VOooooooo`0T
oooo002Noooo00<0000co`0co`000S?o0080001Doooo00?o09Woooooool09?ooo`00Woooo`050000
<ol0<ol0<ol0000005Goool00ol0VOooooooo`0Toooo002Ooooo00D0000co`0co`0co`000000EOoo
o`03o`2Ioooooooo02Coool009ooool01@0003?o03?o03?o0000001Eoooo00?o09Woooooool09?oo
o`00Voooo`D00003<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool009_oool01@000?oo
ooooooooo`000003<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool009coool010000?oo
ooooo`0000<co`030000Doooo`03o`2Ioooooooo02Coool009goool00`000?ooo`000003<ol000<0
003oooooool0E?ooo`03o`2Ioooooooo02?oool009_oool00`000?ooooooo`0200000c?o00030000
oooooooo05Coool00ol0VOooooooo`0Soooo002Loooo0P000003oooo0000<ol0008co`000`000?oo
ooooo`1Doooo00?o09Woooooool08oooo`00Woooo`050000<ol0<ol0<ol0000005Koool00ol0VOoo
ooooo`0Soooo002Poooo00@0000co`0co`00001Foooo00?o09Woooooool08oooo`00X?ooo`030000
<ol0<ol00080001Eoooo00?o09Woooooool08oooo`00X?ooo`040000<ol0<ol00000E_ooo`03o`2I
oooooooo02?oool00:3oool0100003?o03?o000005Koool00ol0VOooooooo`0Soooo002Poooo00@0
000co`0co`00001Foooo00?o09Woooooool08oooo`00X?ooo`040000<ol0<ol00000E_ooo`03o`2I
oooooooo02?oool00:3oool0100003?o03?o000005Koool00ol0VOooooooo`0Soooo002Poooo00@0
000co`0co`00001Foooo00?o09Woooooool08oooo`00XOooo`040000<ol000000000EOooo`03o`2I
oooooooo02?oool00:7oool00`0003?o0000001Foooo00?o09Woooooool08oooo`00XOooo`030000
<ol0000005Koool00ol0VOooooooo`0Soooo002Qoooo00<0000co`000000E_ooo`03o`2Ioooooooo
02?oool00:7oool00`0003?o0000001Foooo00?o09Woooooool08oooo`00XOooo`030000<ol00000
05Koool00ol0VOooooooo`0Soooo002Qoooo00@0000co`000000001Eoooo00?o09Woooooool08ooo
o`00XOooo`030000<ol0000005Koool00ol0VOooooooo`0Soooo002Qoooo00<0000co`000000E_oo
o`03o`2Ioooooooo02?oool00:7oool00`0003?o0000001Foooo00?o09Woooooool08oooo`00XOoo
o`030000<ol0000005Koool00ol0VOooooooo`0Soooo002Qoooo00<0000co`000000E_ooo`03o`2I
oooooooo02?oool00:7oool0100003?o0000000005Goool00ol0VOooooooo`0Soooo002Qoooo00<0
000co`000000E_ooo`03o`2Ioooooooo02?oool00:7oool00`0003?o0000001Foooo00?o09Wooooo
ool08oooo`00XOooo`030000<ol0000005Koool00ol0VOooooooo`0Soooo002Loooo0P0000?oool0
0`0003?o0000001Foooo00?o09Woooooool08oooo`00Voooo`040000oooooooo00000_ooo`030000
<ol0000005Koool00ol0VOooooooo`0Soooo002Moooo00H0003oooooooooool0000co`030000E?oo
o`03o`2Ioooooooo02?oool009koool01P000?ooooooo`0003?o000005Koool00ol0VOooooooo`0S
oooo002Koooo00@0003oooooool00002oooo00<0000co`000000E_ooo`03o`2Ioooooooo02?oool0
09coool200001?ooo`80001Foooo00?o09Woooooool08oooo`00X_ooo`80001Foooo00?o09Wooooo
ool08oooo`00X_ooo`80001Foooo00?o09Woooooool08oooo`00X_ooo`80001Foooo00?o09Wooooo
ool08oooo`00X_ooo`<0001Eoooo00?o09Woooooool08oooo`00X_ooo`80001Foooo00?o09Wooooo
ool08oooo`00X_ooo`80001Foooo00?o09Woooooool08oooo`00X_ooo`80001Foooo00?o09Wooooo
ool08oooo`00X_ooo`80001Foooo00?o09Woooooool08oooo`00X_ooo`80001Foooo00?o09Wooooo
ool08oooo`00X_ooo`<0001Eoooo00?o09Woooooool08oooo`00X_ooo`80001Foooo00?o09Wooooo
ool08oooo`00X_ooo`80001Foooo00?o09Woooooool08oooo`00X_ooo`80001Foooo00?o09Wooooo
ool08oooo`00X_ooo`80001Foooo00?o09Woooooool08oooo`00X_ooo`80001Foooo00?o09Wooooo
ool08oooo`00X_ooo`<0001Eoooo00?o09Woooooool08oooo`00Xoooo`030000oooooooo05Coool0
0ol0VOooooooo`0Soooo002Soooo00<0003oooooool0E?ooo`03o`2Ioooooooo02?oool00:?oool0
0`000?ooooooo`1Doooo00?o09Woooooool08oooo`00Xoooo`030000oooooooo05Coool00ol0VOoo
ooooo`0Soooo002Soooo00<0003oooooool0E?ooo`03o`2Ioooooooo02?oool00:?oool20000EOoo
o`03o`2Ioooooooo02?oool00:?oool00`000?ooooooo`1Doooo00?o09Woooooool08oooo`00Xooo
o`030000oooooooo05Coool00ol0VOooooooo`0Soooo002Soooo00<0003oooooool0E?ooo`03o`2I
oooooooo02?oool00:?oool00`000?ooooooo`1Doooo00?o09Woooooool08oooo`00WOooo`<00003
oooo00<0003oooooool0E?ooo`03o`2Ioooooooo02?oool009koool00`000?ooooooo`02oooo00<0
003oooooool0E?ooo`03o`2Ioooooooo02?oool009_oool500000oooo`<0001Doooo00?o09Wooooo
ool08oooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000oooo0000087oool009goool2
0000POooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?oo
o`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000
oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000?oooo00<0003oooooool02Oooo`050000oooooooooooo000007goool007_oool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91765 .12361 L
.9225 .12361 L
.92516 .12361 L
.92648 .12361 L
.92769 .12361 L
.92838 .12361 L
s
.92838 .12361 m
.92868 .61803 L
s
0 .4 1 r
.02381 .12142 m
.04262 .12055 L
.06244 .11925 L
.07286 .11836 L
.08255 .11737 L
.09388 .11598 L
.10458 .11438 L
.125 .11033 L
.14357 .10511 L
.16355 .09721 L
.18199 .08694 L
.20071 .07242 L
.21136 .06172 L
.22134 .04968 L
.2263 .04284 L
.22892 .03898 L
.22968 .03783 L
.23039 .0371 L
.23103 .03711 L
.23172 .03712 L
.23683 .03721 L
.24158 .0373 L
.26011 .03772 L
.28005 .03837 L
.29009 .0388 L
.30111 .03936 L
.32062 .04067 L
.33156 .04163 L
.34154 .04269 L
.36062 .04531 L
.37141 .04724 L
.38138 .04938 L
.40005 .05452 L
.42065 .06143 L
.46085 .07565 L
.49954 .0876 L
.51958 .0925 L
.52978 .09455 L
.54068 .09632 L
.546 .097 L
.55102 .09751 L
.55321 .09768 L
.55553 .09784 L
.55674 .09791 L
.55808 .09797 L
.5592 .09801 L
.56042 .09805 L
.56165 .09807 L
.56281 .09808 L
.56394 .09808 L
Mistroke
.565 .09807 L
.56624 .09805 L
.56738 .09801 L
.56868 .09795 L
.56991 .09788 L
.57213 .09771 L
.57418 .0975 L
.57642 .0972 L
.57879 .09681 L
.61681 .08895 L
.638 .08461 L
.65729 .08116 L
.66688 .07979 L
.67194 .0792 L
.67731 .0787 L
.67956 .07853 L
.68199 .07838 L
.68338 .07831 L
.68465 .07825 L
.68595 .07821 L
.68715 .07817 L
.68818 .07815 L
.68927 .07814 L
.69049 .07813 L
.69159 .07814 L
.69274 .07815 L
.69399 .07818 L
.69516 .07822 L
.69625 .07826 L
.6987 .0784 L
.70094 .07857 L
.70352 .07882 L
.70597 .07912 L
.71032 .07982 L
.71505 .08082 L
.72025 .08226 L
.72577 .08422 L
.7357 .08903 L
.74506 .09536 L
.75515 .10459 L
.76461 .11598 L
.76698 .11932 L
.76815 .12103 L
.76923 .12266 L
.7702 .12361 L
.77124 .12361 L
.77342 .12361 L
.77804 .12361 L
.78298 .12361 L
.79344 .12361 L
Mistroke
.81453 .12361 L
.85239 .12361 L
.89269 .12361 L
.93148 .12361 L
.97273 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo001;oooo0P1V
oeKoool00`000?ooooooo`1joooo001:oooo00<0I_ooooooool05P1Vod3oool00`000?ooooooo`1j
oooo001:oooo00<0I_ooooooool05_ooo`L0I_lioooo00<0003oooooool0N_ooo`00BOooo`0306Ko
oooooooo01koool606Ko<oooo`030000oooooooo07[oool004Soool00`1Vooooooooo`0Uoooo101V
obooool20000Noooo`00Aoooo`0306Kooooooooo02[oool406Ko:oooo`030000oooooooo07[oool0
04Ooool00`1Vooooooooo`0^oooo0P1VobWoool00`000?ooooooo`1joooo0016oooo00<0I_oooooo
ool0<Oooo`<0I_lVoooo00<0003oooooool0N_ooo`00A?ooo`80I_lgoooo0`1Vob?oool00`000?oo
ooooo`1joooo0013oooo00<0I_ooooooool0>_ooo`@0I_lOoooo00<0003oooooool0N_ooo`00@_oo
o`0306Kooooooooo03ooool306Ko7?ooo`80001koooo000[oooo0`0001;oool206Ko5?ooo`<0000S
oooo100000Ooool306Ko6Oooo`030000oooooooo01?oool<06Ko1?ooo`@0000Woooo0`0002Woool0
02_oool010000?ooooooo`00013oool00`1Vooooooooo`0Eoooo00<0003oooooool08_ooo`030000
oooooooo00_oool406Ko5Oooo`030000oooooooo00ooool406Ko3?ooo`@0I_l00`000?ooooooo`0Y
oooo00<0003oooooool0:?ooo`00:oooo`040000oooooooo00003oooo`0306Kooooooooo01?oool5
00009?ooo`030000oooooooo00koool306Ko4_ooo`030000oooooooo00[oool506Ko5?ooo`0306Ko
0000oooo02Koool50000:Oooo`009Oooo`@00002oooo0`0000ooool00`1Vooooooooo`0>oooo1000
00;oool010000?ooooooo`0001koool400001?ooo`030000oooooooo013oool206Ko4?ooo`030000
oooooooo00Goool506Ko6oooo`030000oooooooo02Coool010000?ooooooo`0002[oool002coool0
0`000?ooooooo`0<oooo0P1VoaSoool00`000?ooo`00000Toooo00@0003oooooool0000Coooo1`1V
o`Woool00`000?ooooooo`0506Ko7_ooo`050000oooooooo000006Ko02Goool00`000?ooo`00000Z
oooo000/oooo0`0000[oool206Ko6oooo`80000Uoooo0P0001_oool906Ko0P00000306Kooooooooo
02;oool200000_ooo`0306Kooooooooo02?oool20000:_ooo`00=oooo`80I_mZoooo00<0003ooooo
ool0:Oooo`0306Kooooooooo04koool003?oool406KoK?ooo`030000oooooooo02[oool00`1Voooo
ooooo`1=oooo000^oooo1@1Vog3oool00`000?ooooooo`0[oooo00<0I_ooooooool0C?ooo`009ooo
o`L0I_meoooo00<0003oooooool0;?ooo`0306Kooooooooo04_oool001koool906KoO?ooo`030000
oooooooo02goool00`1Vooooooooo`1:oooo000@ooooo`00017oool001Koool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooo`00000@000000<co`00000co`0023?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`05oooo00?o09Woool000002Oooo`030000
oooooooo01Goool002[oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
00Koool400006c?o00030000oooooooo02Goool00`000?ooooooo`0Voooo00<0003oooooool01Ooo
o`03o`2Ioooooooo027oool008Soool400005c?o00030000oooooooo05Koool00ol0VOooooooo`0Q
oooo002<oooo00<0000co`0co`0053?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002=
oooo0P0001@co`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol0
014co`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00T?ooo`030000<ol0<ol0010co`02
0000Eoooo`03o`2Ioooooooo027oool0097oool2000043?o00030000oooooooo05Koool00ol0VOoo
ooooo`0Qoooo002Coooo00<0000co`0co`003C?o00030000oooooooo05Koool00ol0VOooooooo`0Q
oooo002Coooo00<0000co`0co`003C?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002D
oooo00<0000co`0co`0033?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Doooo00<0
000co`0co`0033?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Eoooo00<0000co`0c
o`002c?o0080001Goooo00?o09Woooooool08Oooo`00UOooo`030000<ol0<ol000/co`000`000?oo
ooooo`1Foooo00?o09Woooooool08Oooo`00U_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1F
oooo00?o09Woooooool08Oooo`00U_ooo`030000<ol0<ol000Xco`000`000?ooooooo`1Foooo00?o
09Woooooool08Oooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`1Foooo00?o09Wooooo
ool08Oooo`00Uoooo`030000<ol0<ol000Tco`000`000?ooooooo`1Foooo00?o09Woooooool08Ooo
o`00V?ooo`030000<ol0<ol000Pco`020000Eoooo`03o`2Ioooooooo027oool009Soool00`0003?o
03?o0008<ol000<0003oooooool0E_ooo`03o`2Ioooooooo027oool009Soool00`0003?o03?o0008
<ol000<0003oooooool0E_ooo`03o`2Ioooooooo027oool009Woool00`0003?o03?o0007<ol000<0
003oooooool0E_ooo`03o`2Ioooooooo027oool009Woool00`0003?o03?o0007<ol000<0003ooooo
ool0E_ooo`03o`2Ioooooooo027oool009Woool00`0003?o03?o0007<ol000<0003oooooool0E_oo
o`03o`2Ioooooooo027oool009Woool00`0003?o03?o0007<ol00P0005Ooool00ol0VOooooooo`0Q
oooo002Joooo00<0000co`0co`001S?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002J
oooo00<0000co`0co`001S?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Joooo00<0
000co`0co`001S?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Joooo00<0000co`0c
o`001S?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Koooo1@0000<co`000`000?oo
ooooo`1Foooo00?o09Woooooool08Oooo`00Voooo`030000<ol0000000Dco`000`000?ooooooo`1F
oooo00?o09Woooooool08Oooo`00Voooo`030000<ol0000000Dco`030000E_ooo`03o`2Ioooooooo
027oool009coool200001C?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Loooo0P00
00Dco`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00W?ooo`800005<ol000<0003ooooo
ool0E_ooo`03o`2Ioooooooo027oool009coool00`0003?o03?o0004<ol000<0003oooooool0E_oo
o`03o`2Ioooooooo027oool009coool00`0003?o03?o0004<ol000<0003oooooool0E_ooo`03o`2I
oooooooo027oool009coool00`0003?o03?o0004<ol00P0005Ooool00ol0VOooooooo`0Qoooo002M
oooo00<0000co`0co`000c?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Moooo00<0
000co`0co`000c?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Moooo00<0000co`0co`000c?o
00030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Moooo00<0000co`0co`000c?o00030000
oooooooo05Koool00ol0VOooooooo`0Qoooo002Moooo00<0000co`0co`000c?o0080001Goooo00?o
09Woooooool08Oooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1Foooo00?o09Wooooo
ool08Oooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1Foooo00?o09Woooooool08Ooo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00W_ooo`030000<ol0<ol0008co`02
0000Eoooo`03o`2Ioooooooo027oool009koool00`0003?o03?o0002<ol000<0003oooooool0E_oo
o`03o`2Ioooooooo027oool009koool00`0003?o03?o0002<ol000<0003oooooool0E_ooo`03o`2I
oooooooo027oool009koool00`0003?o03?o0002<ol000<0003oooooool0E_ooo`03o`2Ioooooooo
027oool009koool00`0003?o03?o0002<ol000<0003oooooool0E_ooo`03o`2Ioooooooo027oool0
09koool00`0003?o03?o0002<ol000<0003oooooool0E_ooo`03o`2Ioooooooo027oool009koool0
0`0003?o03?o0002<ol00P0005Ooool00ol0VOooooooo`0Qoooo002Ooooo00D0000co`0co`0co`00
0000F?ooo`03o`2Ioooooooo027oool009ooool01@0003?o03?o03?o0000001Hoooo00?o09Wooooo
ool08Oooo`00Woooo`050000<ol0<ol0<ol0000005Soool00ol0VOooooooo`0Qoooo002Koooo1@00
00<co`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00Voooo`050000oooooooooooo0000
00<co`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00W?ooo`040000oooooooo00000c?o
00<0001Foooo00?o09Woooooool08Oooo`00WOooo`030000oooo000000<co`000`000?ooooooo`1F
oooo00?o09Woooooool08Oooo`00Voooo`030000oooooooo00800003<ol000<0003oooooool0E_oo
o`03o`2Ioooooooo027oool009coool2000000?oool0000co`000S?o00030000oooooooo05Koool0
0ol0VOooooooo`0Qoooo002Ooooo00D0000co`0co`0co`000000F?ooo`03o`2Ioooooooo027oool0
0:3oool0100003?o03?o000005Soool00ol0VOooooooo`0Qoooo002Poooo00<0000co`0co`000P00
05Ooool00ol0VOooooooo`0Qoooo002Poooo00@0000co`0co`00001Hoooo00?o09Woooooool08Ooo
o`00X?ooo`040000<ol0<ol00000F?ooo`03o`2Ioooooooo027oool00:3oool0100003?o03?o0000
05Soool00ol0VOooooooo`0Qoooo002Poooo00@0000co`0co`00001Hoooo00?o09Woooooool08Ooo
o`00X?ooo`040000<ol0<ol00000F?ooo`03o`2Ioooooooo027oool00:3oool0100003?o03?o0000
05Soool00ol0VOooooooo`0Qoooo002Qoooo00@0000co`000000001Goooo00?o09Woooooool08Ooo
o`00XOooo`030000<ol0000005Soool00ol0VOooooooo`0Qoooo002Qoooo00<0000co`000000F?oo
o`03o`2Ioooooooo027oool00:7oool00`0003?o0000001Hoooo00?o09Woooooool08Oooo`00XOoo
o`030000<ol0000005Soool00ol0VOooooooo`0Qoooo002Qoooo00<0000co`000000F?ooo`03o`2I
oooooooo027oool00:7oool0100003?o0000000005Ooool00ol0VOooooooo`0Qoooo002Qoooo00<0
000co`000000F?ooo`03o`2Ioooooooo027oool00:7oool00`0003?o0000001Hoooo00?o09Wooooo
ool08Oooo`00XOooo`030000<ol0000005Soool00ol0VOooooooo`0Qoooo002Qoooo00<0000co`00
0000F?ooo`03o`2Ioooooooo027oool00:7oool00`0003?o0000001Hoooo00?o09Woooooool08Ooo
o`00XOooo`040000<ol000000000Eoooo`03o`2Ioooooooo027oool00:7oool00`0003?o0000001H
oooo00?o09Woooooool08Oooo`00XOooo`030000<ol0000005Soool00ol0VOooooooo`0Qoooo002Q
oooo00<0000co`000000F?ooo`03o`2Ioooooooo027oool009coool200000oooo`030000<ol00000
05Soool00ol0VOooooooo`0Qoooo002Koooo00@0003oooooool00002oooo00<0000co`000000F?oo
o`03o`2Ioooooooo027oool009goool01P000?ooooooooooo`0003?o00<0001Foooo00?o09Wooooo
ool08Oooo`00W_ooo`060000oooooooo0000<ol00000F?ooo`03o`2Ioooooooo027oool009_oool0
10000?ooooooo`0000;oool00`0003?o0000001Hoooo00?o09Woooooool08Oooo`00W?ooo`800004
oooo0P0005Soool00ol0VOooooooo`0Qoooo002Roooo0P0005Soool00ol0VOooooooo`0Qoooo002R
oooo0P0005Soool00ol0VOooooooo`0Qoooo002Roooo0P0005Soool00ol0VOooooooo`0Qoooo002R
oooo0`0005Ooool00ol0VOooooooo`0Qoooo002Roooo0P0005Soool00ol0VOooooooo`0Qoooo002R
oooo0P0005Soool00ol0VOooooooo`0Qoooo002Roooo0P0005Soool00ol0VOooooooo`0Qoooo002R
oooo0P0005Soool00ol0VOooooooo`0Qoooo002Roooo0P0005Soool00ol0VOooooooo`0Qoooo002R
oooo0`0005Ooool00ol0VOooooooo`0Qoooo002Roooo0P0005Soool00ol0VOooooooo`0Qoooo002R
oooo0P0005Soool00ol0VOooooooo`0Qoooo002Roooo0P0005Soool00ol0VOooooooo`0Qoooo002R
oooo0P0005Soool00ol0VOooooooo`0Qoooo002Roooo0P0005Soool00ol0VOooooooo`0Qoooo002R
oooo0`0005Ooool00ol0VOooooooo`0Qoooo002Soooo00<0003oooooool0E_ooo`03o`2Ioooooooo
027oool00:?oool00`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00Xoooo`030000oooooooo
05Koool00ol0VOooooooo`0Qoooo002Soooo00<0003oooooool0E_ooo`03o`2Ioooooooo027oool0
0:?oool00`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00Xoooo`80001Goooo00?o09Wooooo
ool08Oooo`00Xoooo`030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Soooo00<0003ooooo
ool0E_ooo`03o`2Ioooooooo027oool00:?oool00`000?ooooooo`1Foooo00?o09Woooooool08Ooo
o`00Xoooo`030000oooooooo05Koool00ol0VOooooooo`0Qoooo002Moooo0`0000?oool00`000?oo
ooooo`1Foooo00?o09Woooooool08Oooo`00W_ooo`030000oooooooo00;oool00`000?ooooooo`1F
oooo00?o09Woooooool08Oooo`00Voooo`D00003oooo0`0005Koool00ol0VOooooooo`0Qoooo002K
oooo00@0003oooooool00021oooo002Loooo00<0003oool00000POooo`00WOooo`800021oooo003o
oooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Nooo
o`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800005oooo0`0000;oool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool0000;oooo00D0003oooooooooool00000OOooo`00N_oo
o`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`D00003oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000?oooo00<0003oooooool01_ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0
003oooooool00009oooo00<0003oool000000oooo`030000oooooooo07_oool007coool00`000?oo
ooooo`0Aoooo0P0000_oool200000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91765 .12361 L
.92769 .12361 L
.93044 .12361 L
.93339 .12361 L
.93482 .12361 L
.93553 .12361 L
.93618 .12361 L
s
.93618 .12361 m
.93666 .61803 L
s
0 .4 1 r
.02381 .12109 m
.04262 .12008 L
.06244 .11859 L
.07286 .11756 L
.08255 .11643 L
.09388 .11482 L
.10458 .11297 L
.125 .10831 L
.14357 .1023 L
.16355 .0932 L
.18199 .08137 L
.20071 .06464 L
.21136 .05232 L
.21653 .04543 L
.21905 .04184 L
.22134 .03845 L
.22257 .0371 L
.22374 .03712 L
.2263 .03716 L
.23172 .03726 L
.24158 .03746 L
.26011 .03795 L
.28019 .03871 L
.29866 .03968 L
.31748 .04106 L
.32817 .04208 L
.33815 .04323 L
.3585 .04629 L
.37706 .05024 L
.39614 .05578 L
.4169 .06289 L
.45768 .07726 L
.49695 .08912 L
.51664 .09383 L
.5347 .09717 L
.54413 .09844 L
.54886 .09893 L
.55153 .09916 L
.55405 .09933 L
.55536 .09941 L
.55678 .09948 L
.55797 .09953 L
.55927 .09957 L
.56 .09959 L
.56068 .0996 L
.5614 .09961 L
.56217 .09962 L
.56289 .09962 L
.56357 .09962 L
.56485 .09961 L
Mistroke
.56606 .09958 L
.56735 .09954 L
.56856 .09949 L
.56966 .09942 L
.57236 .09922 L
.5749 .09894 L
.57732 .0986 L
.57957 .0982 L
.58469 .09721 L
.59502 .09515 L
.61351 .09132 L
.65247 .08336 L
.66267 .08157 L
.67375 .07992 L
.67883 .07931 L
.68421 .07878 L
.68881 .07844 L
.69143 .0783 L
.69261 .07825 L
.69388 .07821 L
.69516 .07817 L
.69632 .07815 L
.69749 .07814 L
.69859 .07813 L
.69988 .07814 L
.70106 .07816 L
.70236 .07819 L
.70302 .07821 L
.70374 .07824 L
.70632 .07838 L
.70777 .07848 L
.7091 .07859 L
.7117 .07885 L
.7141 .07915 L
.71865 .07989 L
.72361 .08097 L
.72798 .08219 L
.73262 .08379 L
.74197 .08809 L
.75207 .09464 L
.7616 .10305 L
.77034 .11306 L
.77507 .11953 L
.77643 .12154 L
.77772 .12351 L
.77887 .12361 L
.78013 .12361 L
.78924 .12361 L
.80993 .12361 L
.85082 .12361 L
Mistroke
.89019 .12361 L
.92804 .12361 L
.96835 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo0019oooo0P1V
oeSoool00`000?ooooooo`1joooo0018oooo00<0I_ooooooool05`1Vod7oool00`000?ooooooo`1j
oooo0018oooo00<0I_ooooooool05oooo`L0I_ljoooo00<0003oooooool0N_ooo`00Aoooo`0306Ko
oooooooo01ooool506Ko=Oooo`030000oooooooo07[oool004Koool00`1Vooooooooo`0Uoooo1@1V
oc3oool20000Noooo`00AOooo`0306Kooooooooo02_oool406Ko;?ooo`030000oooooooo07[oool0
04Coool00`1Vooooooooo`0`oooo0P1Vob[oool00`000?ooooooo`1joooo0013oooo00<0I_oooooo
ool0<oooo`<0I_lWoooo00<0003oooooool0N_ooo`00@_ooo`0306Kooooooooo03Ooool206Ko9Ooo
o`030000oooooooo07[oool0047oool00`1Vooooooooo`0joooo0`1Vob;oool00`000?ooooooo`1j
oooo0010oooo00<0I_ooooooool0?_ooo`80I_lPoooo0P0007_oool002_oool300004Oooo`0306Ko
oooooooo01Coool300008oooo`@00003oooo0`1Voagoool00`000?ooooooo`0Doooo3@1Vo`;oool4
00009oooo`<0000Yoooo000[oooo00@0003oooooool0000?oooo00<0I_ooooooool05_ooo`030000
oooooooo02;oool00`000?ooooooo`07oooo0`1Voa[oool00`000?ooooooo`0>oooo1P1Vo`goool2
06Ko00<00000I_ooool0:Oooo`030000oooooooo02Soool002_oool010000?ooooooo`0000koool0
0`1Vooooooooo`0Doooo1@0002Coool00`000?ooooooo`09oooo101VoaKoool00`000?ooooooo`09
oooo1@1VoaKoool00`00001Vo`1Vo`0Uoooo1@0002Woool002Goool400000_ooo`<0000=oooo0P1V
oa7oool400000_ooo`040000oooooooo00007_ooo`@00004oooo00<0003oooooool03?ooo`@0I_lB
oooo00<0003oooooool01?ooo`D0I_lLoooo00@0003oool0I_l0I_lSoooo00@0003oooooool0000Z
oooo000/oooo00<0003oooooool02_ooo`80I_lJoooo00<0003oool000009?ooo`040000oooooooo
00004Oooo`D0I_l=oooo00<0003oooooool0101Voaooool010000?ooooooo`0000;oool00`1Voooo
ooooo`0Qoooo00<0003oool00000:_ooo`00;?ooo`<00008oooo0P1Voagoool200009Oooo`80000G
oooo3@1Vo`8000000`1Vooooooooo`0Roooo0P0000Coool00`1Vooooooooo`0Qoooo0P0002[oool0
03Coool306KoK?ooo`030000oooooooo02_oool00`1Vooooooooo`1<oooo000boooo0P1Vofooool0
0`000?ooooooo`0/oooo00<0I_ooooooool0Boooo`00;_ooo`@0I_maoooo00<0003oooooool0;Ooo
o`0306Kooooooooo04[oool002Ooool706KoMOooo`030000oooooooo02koool00`1Vooooooooo`19
oooo000Noooo2@1Vogcoool00`000?ooooooo`0_oooo00<0I_ooooooool0B?ooo`004?ooool0000A
oooo000Foooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oool0000040000003<ol00000<ol0
00Pco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Zoooo00<0003oooooool09_ooo`030000
oooooooo02Goool00`000?ooooooo`06oooo100001/co`000`000?ooooooo`0Uoooo00<0003ooooo
ool09_ooo`030000oooooooo00Ooool00ol0VOooooooo`0Ooooo0028oooo100001Lco`000`000?oo
ooooo`1Hoooo00?o09Woooooool07oooo`00S?ooo`030000<ol0<ol001@co`000`000?ooooooo`1H
oooo00?o09Woooooool07oooo`00SOooo`80000D<ol000<0003oooooool0F?ooo`03o`2Ioooooooo
01ooool008ooool00`0003?o03?o000A<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool0
093oool00`0003?o03?o000@<ol00P0005Woool00ol0VOooooooo`0Ooooo002Aoooo0P00010co`00
0`000?ooooooo`1Hoooo00?o09Woooooool07oooo`00Toooo`030000<ol0<ol000dco`000`000?oo
ooooo`1Hoooo00?o09Woooooool07oooo`00Toooo`030000<ol0<ol000dco`000`000?ooooooo`1H
oooo00?o09Woooooool07oooo`00U?ooo`030000<ol0<ol000`co`000`000?ooooooo`1Hoooo00?o
09Woooooool07oooo`00U?ooo`030000<ol0<ol000`co`000`000?ooooooo`1Hoooo00?o09Wooooo
ool07oooo`00UOooo`030000<ol0<ol000/co`020000FOooo`03o`2Ioooooooo01ooool009Goool0
0`0003?o03?o000;<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool009Koool00`0003?o
03?o000:<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool009Koool00`0003?o03?o000:
<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool009Ooool00`0003?o03?o0009<ol000<0
003oooooool0F?ooo`03o`2Ioooooooo01ooool009Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo01ooool009Soool00`0003?o03?o0008<ol00P0005Woool00ol0VOoo
ooooo`0Ooooo002Hoooo00<0000co`0co`0023?o00030000oooooooo05Soool00ol0VOooooooo`0O
oooo002Hoooo00<0000co`0co`0023?o00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002I
oooo00<0000co`0co`001c?o00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002Ioooo00<0
000co`0co`001c?o00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002Ioooo00<0000co`0c
o`001c?o00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002Ioooo00<0000co`0co`001c?o
0080001Ioooo00?o09Woooooool07oooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1H
oooo00?o09Woooooool07oooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1Hoooo00?o
09Woooooool07oooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1Hoooo00?o09Wooooo
ool07oooo`00V_ooo`030000<ol0<ol000Hco`000`000?ooooooo`1Hoooo00?o09Woooooool07ooo
o`00Voooo`D00003<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool009_oool00`0003?o
00000005<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool009_oool00`0003?o00000005
<ol00`0005Soool00ol0VOooooooo`0Ooooo002Loooo0P0000Dco`000`000?ooooooo`1Hoooo00?o
09Woooooool07oooo`00W?ooo`800005<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool0
09coool200001C?o00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002Loooo00<0000co`0c
o`0013?o00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002Loooo00<0000co`0co`0013?o
00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002Loooo00<0000co`0co`0013?o0080001I
oooo00?o09Woooooool07oooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1Hoooo00?o
09Woooooool07oooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1Hoooo00?o09Wooooo
ool07oooo`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1Hoooo00?o09Woooooool07ooo
o`00WOooo`030000<ol0<ol000<co`000`000?ooooooo`1Hoooo00?o09Woooooool07oooo`00WOoo
o`030000<ol0<ol000<co`000`000?ooooooo`1Hoooo00?o09Woooooool07oooo`00WOooo`030000
<ol0<ol000<co`020000FOooo`03o`2Ioooooooo01ooool009goool00`0003?o03?o0003<ol000<0
003oooooool0F?ooo`03o`2Ioooooooo01ooool009goool00`0003?o03?o0003<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo01ooool009koool00`0003?o03?o0002<ol000<0003oooooool0F?oo
o`03o`2Ioooooooo01ooool009koool00`0003?o03?o0002<ol000<0003oooooool0F?ooo`03o`2I
oooooooo01ooool009koool00`0003?o03?o0002<ol000<0003oooooool0F?ooo`03o`2Ioooooooo
01ooool009koool00`0003?o03?o0002<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool0
09koool00`0003?o03?o0002<ol00P0005Woool00ol0VOooooooo`0Ooooo002Noooo00<0000co`0c
o`000S?o00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002Noooo00<0000co`0co`000S?o
00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002Noooo00<0000co`0co`000S?o00030000
oooooooo05Soool00ol0VOooooooo`0Ooooo002Noooo00<0000co`0co`000S?o00030000oooooooo
05Soool00ol0VOooooooo`0Ooooo002Noooo00<0000co`0co`000S?o00030000oooooooo05Soool0
0ol0VOooooooo`0Ooooo002Noooo00<0000co`0co`000S?o0080001Ioooo00?o09Woooooool07ooo
o`00Woooo`050000<ol0<ol0<ol0000005[oool00ol0VOooooooo`0Ooooo002Ooooo00D0000co`0c
o`0co`000000F_ooo`03o`2Ioooooooo01ooool009ooool01@0003?o03?o03?o0000001Joooo00?o
09Woooooool07oooo`00Voooo`D00003<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool0
09_oool01@000?ooooooooooo`000003<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool0
09coool010000?ooooooo`0000<co`030000F?ooo`03o`2Ioooooooo01ooool009goool00`000?oo
o`000003<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool009_oool00`000?ooooooo`02
00000c?o00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002Loooo0P000003oooo0000<ol0
008co`000`000?ooooooo`1Hoooo00?o09Woooooool07oooo`00Woooo`050000<ol0<ol0<ol00000
05[oool00ol0VOooooooo`0Ooooo002Poooo00@0000co`0co`00001Joooo00?o09Woooooool07ooo
o`00X?ooo`030000<ol0<ol00080001Ioooo00?o09Woooooool07oooo`00X?ooo`040000<ol0<ol0
0000F_ooo`03o`2Ioooooooo01ooool00:3oool0100003?o03?o000005[oool00ol0VOooooooo`0O
oooo002Poooo00@0000co`0co`00001Joooo00?o09Woooooool07oooo`00X?ooo`040000<ol0<ol0
0000F_ooo`03o`2Ioooooooo01ooool00:3oool0100003?o03?o000005[oool00ol0VOooooooo`0O
oooo002Poooo00@0000co`0co`00001Joooo00?o09Woooooool07oooo`00XOooo`040000<ol00000
0000FOooo`03o`2Ioooooooo01ooool00:7oool00`0003?o0000001Joooo00?o09Woooooool07ooo
o`00XOooo`030000<ol0000005[oool00ol0VOooooooo`0Ooooo002Qoooo00<0000co`000000F_oo
o`03o`2Ioooooooo01ooool00:7oool00`0003?o0000001Joooo00?o09Woooooool07oooo`00XOoo
o`030000<ol0000005[oool00ol0VOooooooo`0Ooooo002Qoooo00@0000co`000000001Ioooo00?o
09Woooooool07oooo`00XOooo`030000<ol0000005[oool00ol0VOooooooo`0Ooooo002Qoooo00<0
000co`000000F_ooo`03o`2Ioooooooo01ooool00:7oool00`0003?o0000001Joooo00?o09Wooooo
ool07oooo`00XOooo`030000<ol0000005[oool00ol0VOooooooo`0Ooooo002Qoooo00<0000co`00
0000F_ooo`03o`2Ioooooooo01ooool00:7oool0100003?o0000000005Woool00ol0VOooooooo`0O
oooo002Qoooo00<0000co`000000F_ooo`03o`2Ioooooooo01ooool00:7oool00`0003?o0000001J
oooo00?o09Woooooool07oooo`00XOooo`030000<ol0000005[oool00ol0VOooooooo`0Ooooo002L
oooo0P0000?oool00`0003?o0000001Joooo00?o09Woooooool07oooo`00Voooo`040000oooooooo
00000_ooo`030000<ol0000005[oool00ol0VOooooooo`0Ooooo002Moooo00H0003oooooooooool0
000co`030000F?ooo`03o`2Ioooooooo01ooool009koool01P000?ooooooo`0003?o000005[oool0
0ol0VOooooooo`0Ooooo002Koooo00@0003oooooool00002oooo00<0000co`000000F_ooo`03o`2I
oooooooo01ooool009coool200001?ooo`80001Joooo00?o09Woooooool07oooo`00X_ooo`80001J
oooo00?o09Woooooool07oooo`00X_ooo`80001Joooo00?o09Woooooool07oooo`00X_ooo`80001J
oooo00?o09Woooooool07oooo`00X_ooo`<0001Ioooo00?o09Woooooool07oooo`00X_ooo`80001J
oooo00?o09Woooooool07oooo`00X_ooo`80001Joooo00?o09Woooooool07oooo`00X_ooo`80001J
oooo00?o09Woooooool07oooo`00X_ooo`80001Joooo00?o09Woooooool07oooo`00X_ooo`80001J
oooo00?o09Woooooool07oooo`00X_ooo`<0001Ioooo00?o09Woooooool07oooo`00X_ooo`80001J
oooo00?o09Woooooool07oooo`00X_ooo`80001Joooo00?o09Woooooool07oooo`00X_ooo`80001J
oooo00?o09Woooooool07oooo`00X_ooo`80001Joooo00?o09Woooooool07oooo`00X_ooo`80001J
oooo00?o09Woooooool07oooo`00X_ooo`<0001Ioooo00?o09Woooooool07oooo`00Xoooo`030000
oooooooo05Soool00ol0VOooooooo`0Ooooo002Soooo00<0003oooooool0F?ooo`03o`2Ioooooooo
01ooool00:?oool00`000?ooooooo`1Hoooo00?o09Woooooool07oooo`00Xoooo`030000oooooooo
05Soool00ol0VOooooooo`0Ooooo002Soooo00<0003oooooool0F?ooo`03o`2Ioooooooo01ooool0
0:?oool20000FOooo`03o`2Ioooooooo01ooool00:?oool00`000?ooooooo`1Hoooo00?o09Wooooo
ool07oooo`00Xoooo`030000oooooooo05Soool00ol0VOooooooo`0Ooooo002Soooo00<0003ooooo
ool0F?ooo`03o`2Ioooooooo01ooool00:?oool00`000?ooooooo`1Hoooo00?o09Woooooool07ooo
o`00WOooo`<00003oooo00<0003oooooool0F?ooo`03o`2Ioooooooo01ooool009koool00`000?oo
ooooo`02oooo00<0003oooooool0F?ooo`03o`2Ioooooooo01ooool009_oool500000oooo`<0001H
oooo00?o09Woooooool07oooo`00Voooo`040000oooooooo0000POooo`00W?ooo`030000oooo0000
087oool009goool20000POooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P00
00Coool200001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00[oool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00Nooo
o`030000oooooooo00D0000?oooo00<0003oooooool01oooo`800004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`03
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`<00002oooo00<0
003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91726 .12361 L
.92761 .12361 L
.93331 .12361 L
.93871 .12361 L
.94107 .12361 L
.94236 .12361 L
.94357 .12361 L
s
.94357 .12361 m
.94409 .61803 L
s
0 .4 1 r
.02381 .1207 m
.04262 .11955 L
.06244 .11783 L
.07286 .11665 L
.08255 .11533 L
.09388 .11348 L
.10458 .11136 L
.125 .10598 L
.14357 .09907 L
.16355 .08858 L
.18199 .07495 L
.2023 .05373 L
.2074 .04708 L
.20991 .04358 L
.21224 .04018 L
.21333 .03856 L
.21435 .03709 L
.21552 .03711 L
.21659 .03713 L
.22134 .03721 L
.23957 .0376 L
.25917 .03818 L
.26894 .03856 L
.27925 .03903 L
.29772 .04014 L
.31736 .04178 L
.3357 .04394 L
.35605 .04732 L
.3746 .05167 L
.41445 .06484 L
.45278 .07827 L
.47216 .08441 L
.49356 .0904 L
.51405 .09519 L
.53283 .09858 L
.54225 .09983 L
.54699 .10032 L
.55217 .10074 L
.55491 .1009 L
.5574 .10101 L
.55878 .10105 L
.55955 .10107 L
.56027 .10108 L
.56158 .1011 L
.56225 .1011 L
.56298 .1011 L
.56429 .10109 L
.56548 .10107 L
.56614 .10105 L
.56686 .10103 L
Mistroke
.56817 .10097 L
.56939 .10091 L
.57069 .10082 L
.57303 .10062 L
.57565 .10032 L
.5784 .09991 L
.58334 .09899 L
.59448 .09684 L
.61466 .09274 L
.65269 .08484 L
.66357 .08278 L
.67387 .08105 L
.6839 .07964 L
.68831 .07915 L
.69317 .0787 L
.69542 .07853 L
.69784 .07838 L
.70013 .07827 L
.70114 .07823 L
.70223 .07819 L
.70339 .07817 L
.70447 .07815 L
.70575 .07814 L
.70691 .07814 L
.70813 .07815 L
.70945 .07817 L
.71069 .07821 L
.71184 .07825 L
.71427 .07838 L
.71654 .07854 L
.71903 .07878 L
.7217 .0791 L
.72715 .08 L
.73213 .08112 L
.73692 .08251 L
.74202 .08437 L
.75119 .0888 L
.76105 .09545 L
.77194 .10557 L
.78135 .11717 L
.78364 .12045 L
.78489 .12234 L
.78608 .12361 L
.78675 .12361 L
.78749 .12361 L
.78876 .12361 L
.79126 .12361 L
.80213 .12361 L
.81211 .12361 L
.853 .12361 L
Mistroke
.89237 .12361 L
.93022 .12361 L
.97053 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo0017oooo101V
oeSoool00`000?ooooooo`1joooo0016oooo00<0I_ooooooool00_oooa@0I_m4oooo00<0003ooooo
ool0N_ooo`00AOooo`0306Kooooooooo01Ooool906Ko>oooo`030000oooooooo07[oool004Goool0
0`1Vooooooooo`0Poooo1@1VocKoool00`000?ooooooo`1joooo0014oooo00<0I_ooooooool09_oo
o`@0I_lboooo0P0007_oool004?oool00`1Vooooooooo`0[oooo0P1Voc3oool00`000?ooooooo`1j
oooo0012oooo00<0I_ooooooool0;_ooo`<0I_l]oooo00<0003oooooool0N_ooo`00@Oooo`0306Ko
oooooooo03;oool206Ko:oooo`030000oooooooo07[oool0043oool00`1Vooooooooo`0eoooo0`1V
obSoool00`000?ooooooo`1joooo000ooooo00<0I_ooooooool0>Oooo`<0I_lUoooo00<0003ooooo
ool0N_ooo`00?_ooo`0306Kooooooooo03goool406Ko8Oooo`80001koooo000[oooo0`0000ooool0
0`1Vooooooooo`0Foooo0`0002?oool400000_ooo`@0I_lMoooo00<0003oooooool05oooo``0I_l4
00009oooo`<0000Yoooo000[oooo00@0003oooooool0000=oooo00<0I_ooooooool06?ooo`030000
oooooooo02;oool00`000?ooooooo`07oooo101VoaWoool00`000?ooooooo`0Boooo1@1Vo`coool0
1000001Vo`1Vo`1VobSoool00`000?ooooooo`0Xoooo000[oooo00@0003oooooool0000<oooo00<0
I_ooooooool05_ooo`D0000Toooo00<0003oooooool02_ooo`80I_lGoooo00<0003oooooool03_oo
o`@0I_lBoooo00<0003oooooool00P1Vob?oool50000:Oooo`009Oooo`@00002oooo0`0000_oool2
06Ko4oooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`0;oooo101V
oa?oool00`000?ooooooo`09oooo1@1VoaOoool01@000?ooooooooooo`1Vo`0Roooo00@0003ooooo
ool0000Zoooo000/oooo00<0003oooooool02?ooo`80I_lLoooo00<0003oool000009?ooo`040000
oooooooo00004?ooo`D0I_l>oooo00<0003oooooool01?ooo`D0I_lJoooo00@0003oooooool00003
oooo0P1Vob7oool00`000?ooo`00000Zoooo000/oooo0`0000Goool306Ko7oooo`80000Uoooo0P00
01Koool706Ko1_ooo`0306Ko0000000000D0I_lPoooo0P0000Koool00`1Vooooooooo`0Ooooo0P00
02[oool003;oool206KoJ?ooo`H0I_l00oooo`000?ooo`0^oooo00<0I_ooooooool0B_ooo`00;_oo
o`@0I_maoooo00<0003oooooool0;_ooo`0306Kooooooooo04Woool002[oool406KoMOooo`030000
oooooooo02ooool00`1Vooooooooo`18oooo000Uoooo1@1VogWoool00`000?ooooooo`0_oooo00<0
I_ooooooool0B?ooo`006Oooo``0I_mnoooo00<0003oooooool0<?ooo`0306Kooooooooo04Ooool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooo000001000000
0c?o000003?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?l0VOooo`07oooo00<0003oooooool05Oooo`00:_ooo`030000oooooooo
02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_ooo`@0000K<ol000<0003oooooool09Ooo
o`030000oooooooo02Koool00`000?ooooooo`08oooo00?o09Woooooool07_ooo`00R?ooo`@0000G
<ol000<0003oooooool0FOooo`03o`2Ioooooooo01koool008coool00`0003?o03?o000D<ol000<0
003oooooool0FOooo`03o`2Ioooooooo01koool008goool2000053?o00030000oooooooo05Woool0
0ol0VOooooooo`0Noooo002?oooo00<0000co`0co`004C?o00030000oooooooo05Woool00ol0VOoo
ooooo`0Noooo002@oooo00<0000co`0co`0043?o0080001Joooo00?o09Woooooool07_ooo`00TOoo
o`80000@<ol000<0003oooooool0FOooo`03o`2Ioooooooo01koool009?oool00`0003?o03?o000=
<ol000<0003oooooool0FOooo`03o`2Ioooooooo01koool009?oool00`0003?o03?o000=<ol000<0
003oooooool0FOooo`03o`2Ioooooooo01koool009Coool00`0003?o03?o000<<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo01koool009Coool00`0003?o03?o000<<ol000<0003oooooool0FOoo
o`03o`2Ioooooooo01koool009Goool00`0003?o03?o000;<ol00P0005[oool00ol0VOooooooo`0N
oooo002Eoooo00<0000co`0co`002c?o00030000oooooooo05Woool00ol0VOooooooo`0Noooo002F
oooo00<0000co`0co`002S?o00030000oooooooo05Woool00ol0VOooooooo`0Noooo002Foooo00<0
000co`0co`002S?o00030000oooooooo05Woool00ol0VOooooooo`0Noooo002Goooo00<0000co`0c
o`002C?o00030000oooooooo05Woool00ol0VOooooooo`0Noooo002Goooo00<0000co`0co`002C?o
00030000oooooooo05Woool00ol0VOooooooo`0Noooo002Hoooo00<0000co`0co`0023?o0080001J
oooo00?o09Woooooool07_ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1Ioooo00?o
09Woooooool07_ooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1Ioooo00?o09Wooooo
ool07_ooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`1Ioooo00?o09Woooooool07_oo
o`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`1Ioooo00?o09Woooooool07_ooo`00VOoo
o`030000<ol0<ol000Lco`000`000?ooooooo`1Ioooo00?o09Woooooool07_ooo`00VOooo`030000
<ol0<ol000Lco`020000F_ooo`03o`2Ioooooooo01koool009[oool00`0003?o03?o0006<ol000<0
003oooooool0FOooo`03o`2Ioooooooo01koool009[oool00`0003?o03?o0006<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo01koool009[oool00`0003?o03?o0006<ol000<0003oooooool0FOoo
o`03o`2Ioooooooo01koool009[oool00`0003?o03?o0006<ol000<0003oooooool0FOooo`03o`2I
oooooooo01koool009_oool500000c?o00030000oooooooo05Woool00ol0VOooooooo`0Noooo002K
oooo00<0000co`0000001C?o00030000oooooooo05Woool00ol0VOooooooo`0Noooo002Koooo00<0
000co`0000001C?o00<0001Ioooo00?o09Woooooool07_ooo`00W?ooo`800005<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo01koool009coool200001C?o00030000oooooooo05Woool00ol0VOoo
ooooo`0Noooo002Loooo0P0000Dco`000`000?ooooooo`1Ioooo00?o09Woooooool07_ooo`00W?oo
o`030000<ol0<ol000@co`000`000?ooooooo`1Ioooo00?o09Woooooool07_ooo`00W?ooo`030000
<ol0<ol000@co`000`000?ooooooo`1Ioooo00?o09Woooooool07_ooo`00W?ooo`030000<ol0<ol0
00@co`020000F_ooo`03o`2Ioooooooo01koool009goool00`0003?o03?o0003<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo01koool009goool00`0003?o03?o0003<ol000<0003oooooool0FOoo
o`03o`2Ioooooooo01koool009goool00`0003?o03?o0003<ol000<0003oooooool0FOooo`03o`2I
oooooooo01koool009goool00`0003?o03?o0003<ol000<0003oooooool0FOooo`03o`2Ioooooooo
01koool009goool00`0003?o03?o0003<ol000<0003oooooool0FOooo`03o`2Ioooooooo01koool0
09goool00`0003?o03?o0003<ol00P0005[oool00ol0VOooooooo`0Noooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo05Woool00ol0VOooooooo`0Noooo002Moooo00<0000co`0co`000c?o
00030000oooooooo05Woool00ol0VOooooooo`0Noooo002Noooo00<0000co`0co`000S?o00030000
oooooooo05Woool00ol0VOooooooo`0Noooo002Noooo00<0000co`0co`000S?o00030000oooooooo
05Woool00ol0VOooooooo`0Noooo002Noooo00<0000co`0co`000S?o00030000oooooooo05Woool0
0ol0VOooooooo`0Noooo002Noooo00<0000co`0co`000S?o00030000oooooooo05Woool00ol0VOoo
ooooo`0Noooo002Noooo00<0000co`0co`000S?o0080001Joooo00?o09Woooooool07_ooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`1Ioooo00?o09Woooooool07_ooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`1Ioooo00?o09Woooooool07_ooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`1Ioooo00?o09Woooooool07_ooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1Ioooo00?o09Woooooool07_ooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1Ioooo00?o09Woooooool07_ooo`00W_ooo`030000<ol0<ol0008co`020000F_ooo`03o`2I
oooooooo01koool009ooool01@0003?o03?o03?o0000001Koooo00?o09Woooooool07_ooo`00Wooo
o`050000<ol0<ol0<ol0000005_oool00ol0VOooooooo`0Noooo002Ooooo00D0000co`0co`0co`00
0000Foooo`03o`2Ioooooooo01koool009_oool500000c?o00030000oooooooo05Woool00ol0VOoo
ooooo`0Noooo002Koooo00D0003oooooooooool000000c?o00030000oooooooo05Woool00ol0VOoo
ooooo`0Noooo002Loooo00@0003oooooool00003<ol00`0005Woool00ol0VOooooooo`0Noooo002M
oooo00<0003oool000000c?o00030000oooooooo05[oool00ol0VOooooooo`0Moooo002Koooo00<0
003oooooool00P0000<co`000`000?ooooooo`1Joooo00?o09Woooooool07Oooo`00W?ooo`800000
0oooo`0003?o0002<ol000<0003oooooool0F_ooo`03o`2Ioooooooo01goool009ooool01@0003?o
03?o03?o0000001Loooo00?o09Woooooool07Oooo`00X?ooo`040000<ol0<ol00000G?ooo`03o`2I
oooooooo01goool00:3oool00`0003?o03?o00020000Foooo`03o`2Ioooooooo01goool00:3oool0
100003?o03?o000005coool00ol0VOooooooo`0Moooo002Poooo00@0000co`0co`00001Loooo00?o
09Woooooool07Oooo`00X?ooo`040000<ol0<ol00000G?ooo`03o`2Ioooooooo01goool00:3oool0
100003?o03?o000005coool00ol0VOooooooo`0Moooo002Poooo00@0000co`0co`00001Loooo00?o
09Woooooool07Oooo`00X?ooo`040000<ol0<ol00000G?ooo`03o`2Ioooooooo01goool00:7oool0
100003?o0000000005_oool00ol0VOooooooo`0Moooo002Qoooo00<0000co`000000G?ooo`03o`2I
oooooooo01goool00:7oool00`0003?o0000001Loooo00?o09Woooooool07Oooo`00XOooo`030000
<ol0000005coool00ol0VOooooooo`0Moooo002Qoooo00<0000co`000000G?ooo`03o`2Ioooooooo
01goool00:7oool00`0003?o0000001Loooo00?o09Woooooool07Oooo`00XOooo`040000<ol00000
0000Foooo`03o`2Ioooooooo01goool00:7oool00`0003?o0000001Loooo00?o09Woooooool07Ooo
o`00XOooo`030000<ol0000005coool00ol0VOooooooo`0Moooo002Qoooo00<0000co`000000G?oo
o`03o`2Ioooooooo01goool00:7oool00`0003?o0000001Loooo00?o09Woooooool07Oooo`00XOoo
o`030000<ol0000005coool00ol0VOooooooo`0Moooo002Qoooo00@0000co`000000001Koooo00?o
09Woooooool07Oooo`00XOooo`030000<ol0000005coool00ol0VOooooooo`0Moooo002Qoooo00<0
000co`000000G?ooo`03o`2Ioooooooo01goool00:7oool00`0003?o0000001Loooo00?o09Wooooo
ool07Oooo`00W?ooo`800003oooo00<0000co`000000G?ooo`03o`2Ioooooooo01goool009_oool0
10000?ooooooo`0000;oool00`0003?o0000001Loooo00?o09Woooooool07Oooo`00WOooo`060000
oooooooooooo0000<ol00`0005[oool00ol0VOooooooo`0Moooo002Noooo00H0003oooooool0000c
o`00001Loooo00?o09Woooooool07Oooo`00Voooo`040000oooooooo00000_ooo`030000<ol00000
05coool00ol0VOooooooo`0Moooo002Loooo0P0000Coool20000G?ooo`03o`2Ioooooooo01goool0
0:;oool20000G?ooo`03o`2Ioooooooo01goool00:;oool20000G?ooo`03o`2Ioooooooo01goool0
0:;oool20000G?ooo`03o`2Ioooooooo01goool00:;oool30000Foooo`03o`2Ioooooooo01goool0
0:;oool20000G?ooo`03o`2Ioooooooo01goool00:;oool20000G?ooo`03o`2Ioooooooo01goool0
0:;oool20000G?ooo`03o`2Ioooooooo01goool00:;oool20000G?ooo`03o`2Ioooooooo01goool0
0:;oool20000G?ooo`03o`2Ioooooooo01goool00:;oool30000Foooo`03o`2Ioooooooo01goool0
0:;oool20000G?ooo`03o`2Ioooooooo01goool00:;oool20000G?ooo`03o`2Ioooooooo01goool0
0:;oool20000G?ooo`03o`2Ioooooooo01goool00:;oool20000G?ooo`03o`2Ioooooooo01goool0
0:;oool20000G?ooo`03o`2Ioooooooo01goool00:;oool30000Foooo`03o`2Ioooooooo01goool0
0:?oool00`000?ooooooo`1Joooo00?o09Woooooool07Oooo`00Xoooo`030000oooooooo05[oool0
0ol0VOooooooo`0Moooo002Soooo00<0003oooooool0F_ooo`03o`2Ioooooooo01goool00:?oool0
0`000?ooooooo`1Joooo00?o09Woooooool07Oooo`00Xoooo`030000oooooooo05[oool00ol0VOoo
ooooo`0Moooo002Soooo0P0005_oool00ol0VOooooooo`0Moooo002Soooo00<0003oooooool0F_oo
o`03o`2Ioooooooo01goool00:?oool00`000?ooooooo`1Joooo00?o09Woooooool07Oooo`00Xooo
o`030000oooooooo05[oool00ol0VOooooooo`0Moooo002Soooo00<0003oooooool0F_ooo`03o`2I
oooooooo01goool009goool300000oooo`030000oooooooo05[oool00ol0VOooooooo`0Moooo002N
oooo00<0003oooooool00_ooo`030000oooooooo05[oool00ol0VOooooooo`0Moooo002Koooo1@00
00?oool30000F_ooo`03o`2Ioooooooo01goool009_oool010000?ooooooo`00087oool009coool0
0`000?ooo`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000
oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo
01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004oooo0P0000?oool300001?ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_oo
o`030000oooooooo00ooool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003ooooo
ool0N_ooo`00Noooo`030000oooooooo00D0000?oooo00<0003oooooool01_ooo`<00004oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Woool0
0`000?ooooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_oo
o`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91726 .12361 L
.92761 .12361 L
.93871 .12361 L
.94392 .12361 L
.94648 .12361 L
.94885 .12361 L
.951 .12361 L
.95208 .12361 L
s
.95208 .12361 m
.95256 .61803 L
s
0 .4 1 r
.02381 .12026 m
.04262 .11893 L
.06244 .11695 L
.07286 .11559 L
.08255 .11408 L
.09388 .11195 L
.10458 .1095 L
.125 .10331 L
.14357 .09534 L
.16355 .08326 L
.18199 .06756 L
.19177 .05688 L
.19717 .05014 L
.2023 .04311 L
.2046 .03974 L
.20587 .03783 L
.20706 .0371 L
.20773 .03711 L
.20847 .03713 L
.20975 .03715 L
.21224 .03719 L
.22134 .03736 L
.24104 .03785 L
.25917 .03848 L
.278 .03939 L
.28868 .04006 L
.29866 .04081 L
.31901 .04282 L
.33757 .04541 L
.35665 .04914 L
.37741 .05484 L
.4182 .06901 L
.45746 .08235 L
.49521 .09289 L
.51456 .09712 L
.52452 .09892 L
.53542 .10055 L
.54044 .10117 L
.5458 .10171 L
.5484 .10193 L
.55086 .10211 L
.55305 .10225 L
.55546 .10237 L
.55669 .10242 L
.55802 .10246 L
.55875 .10248 L
.55942 .10249 L
.56072 .10251 L
.56192 .10251 L
.56322 .10251 L
Mistroke
.56444 .1025 L
.56558 .10247 L
.56627 .10245 L
.56702 .10243 L
.56837 .10237 L
.5709 .10221 L
.57233 .1021 L
.57385 .10195 L
.57656 .10162 L
.58153 .10079 L
.58606 .09997 L
.59623 .09805 L
.61458 .0944 L
.65448 .08608 L
.67273 .08256 L
.68312 .08084 L
.69286 .07952 L
.69751 .07902 L
.7024 .0786 L
.70496 .07842 L
.70632 .07835 L
.70776 .07828 L
.7091 .07823 L
.71031 .07819 L
.71153 .07816 L
.71267 .07814 L
.71389 .07813 L
.71458 .07813 L
.71523 .07814 L
.71653 .07815 L
.71726 .07817 L
.71793 .07818 L
.71912 .07822 L
.72041 .07828 L
.72277 .07841 L
.72552 .07863 L
.72844 .07895 L
.73369 .07974 L
.73857 .08075 L
.74305 .08195 L
.74787 .08356 L
.75314 .08574 L
.76204 .09055 L
.77141 .09744 L
.78233 .10831 L
.78769 .11499 L
.79005 .11824 L
.79129 .12004 L
.79264 .12205 L
.79385 .12361 L
Mistroke
.79496 .12361 L
.79713 .12361 L
.8019 .12361 L
.81194 .12361 L
.85095 .12361 L
.89068 .12361 L
.9289 .12361 L
.96956 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo0015oooo0P1V
oecoool00`000?ooooooo`1joooo0014oooo00<0I_ooooooool0601VodCoool00`000?ooooooo`1j
oooo0013oooo00<0I_ooooooool06Oooo`D0I_looooo00<0003oooooool0N_ooo`00@_ooo`0306Ko
oooooooo01ooool506Ko>_ooo`030000oooooooo07[oool004;oool00`1Vooooooooo`0Toooo1@1V
ocGoool20000Noooo`00@Oooo`0306Kooooooooo02[oool406Ko<Oooo`030000oooooooo07[oool0
043oool00`1Vooooooooo`0_oooo0P1Vobooool00`000?ooooooo`1joooo000ooooo00<0I_oooooo
ool0<_ooo`<0I_l/oooo00<0003oooooool0N_ooo`00?_ooo`0306Kooooooooo03Koool206Ko:_oo
o`030000oooooooo07[oool003goool00`1Vooooooooo`0ioooo0`1VobOoool00`000?ooooooo`1j
oooo000loooo00<0I_ooooooool0?Oooo`<0I_lToooo0P0007_oool002_oool300003Oooo`0306Ko
oooooooo01Soool300008oooo`@0000306Ko8?ooo`030000oooooooo01Woool:06Ko100002Ooool3
0000:Oooo`00:oooo`040000oooooooo00002oooo`0306Kooooooooo01[oool00`000?ooooooo`0R
oooo00<0003oooooool01?ooo`<0I_lMoooo00<0003oooooool04oooo`H0I_l:oooo00<0003oool0
I_l00`1VobKoool00`000?ooooooo`0Xoooo000[oooo00@0003oooooool00009oooo0P1Voa[oool5
00009?ooo`030000oooooooo00Koool306Ko6_ooo`030000oooooooo00koool506Ko4Oooo`030000
oooooooo00;oool00`1Vooooooooo`0Poooo1@0002Woool002Goool400000_ooo`<00008oooo0P1V
oaKoool400000_ooo`040000oooooooo00007_ooo`@00004oooo00<0003oooooool02?ooo`@0I_lF
oooo00<0003oooooool02Oooo`D0I_lGoooo00<0003oooooool00_ooo`80I_lPoooo00@0003ooooo
ool0000Zoooo000/oooo00<0003oooooool01Oooo`80I_lOoooo00<0003oool000009?ooo`040000
oooooooo00003Oooo`@0I_lBoooo00<0003oooooool01?ooo`D0I_lJoooo00@0003oooooool00005
oooo0P1Voaooool00`000?ooo`00000Zoooo000/oooo0`0000?oool206Ko8_ooo`80000Uoooo0P00
01;oool606Ko3?ooo`80000506Ko8?ooo`800008oooo00<0I_ooooooool07Oooo`80000Zoooo000_
oooo0`1VofGoool<06Ko00<00000I_ooool0;oooo`0306Kooooooooo04Soool002goool206KoM?oo
o`030000oooooooo033oool00`1Vooooooooo`17oooo000Woooo1P1VogKoool00`000?ooooooo`0a
oooo00<0I_ooooooool0A_ooo`008_ooo`D0I_mloooo00<0003oooooool0<_ooo`0306Kooooooooo
04Goool001Woool906KoPOooo`030000oooooooo03?oool00`1Vooooooooo`14oooo000@ooooo`00
017oool001Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooo`00000@000000<co`00000c
o`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00D0003ooooooooooooo09T01Oooo`030000oooooooo01Goool002[oool00`000?ooooooo`0V
oooo00<0003oooooool09Oooo`030000oooooooo00Koool400006c?o00030000oooooooo02Goool0
0`000?ooooooo`0Voooo00<0003oooooool02oooo`03o`2Ioooooooo01_oool008Soool400005c?o
00030000oooooooo05coool00ol0VOooooooo`0Koooo002<oooo00<0000co`0co`0053?o00030000
oooooooo05coool00ol0VOooooooo`0Koooo002=oooo0P0001@co`000`000?ooooooo`1Loooo00?o
09Woooooool06oooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1Loooo00?o09Wooooo
ool06oooo`00T?ooo`030000<ol0<ol0010co`020000GOooo`03o`2Ioooooooo01_oool0097oool2
000043?o00030000oooooooo05coool00ol0VOooooooo`0Koooo002Coooo00<0000co`0co`003C?o
00030000oooooooo05coool00ol0VOooooooo`0Koooo002Coooo00<0000co`0co`003C?o00030000
oooooooo05coool00ol0VOooooooo`0Koooo002Doooo00<0000co`0co`0033?o00030000oooooooo
05coool00ol0VOooooooo`0Koooo002Doooo00<0000co`0co`0033?o00030000oooooooo05coool0
0ol0VOooooooo`0Koooo002Eoooo00<0000co`0co`002c?o0080001Moooo00?o09Woooooool06ooo
o`00UOooo`030000<ol0<ol000/co`000`000?ooooooo`1Loooo00?o09Woooooool06oooo`00U_oo
o`030000<ol0<ol000Xco`000`000?ooooooo`1Loooo00?o09Woooooool06oooo`00U_ooo`030000
<ol0<ol000Xco`000`000?ooooooo`1Loooo00?o09Woooooool06oooo`00Uoooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1Loooo00?o09Woooooool06oooo`00Uoooo`030000<ol0<ol000Tco`00
0`000?ooooooo`1Loooo00?o09Woooooool06oooo`00V?ooo`030000<ol0<ol000Pco`020000GOoo
o`03o`2Ioooooooo01_oool009Soool00`0003?o03?o0008<ol000<0003oooooool0G?ooo`03o`2I
oooooooo01_oool009Soool00`0003?o03?o0008<ol000<0003oooooool0G?ooo`03o`2Ioooooooo
01_oool009Woool00`0003?o03?o0007<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01_oool0
09Woool00`0003?o03?o0007<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01_oool009Woool0
0`0003?o03?o0007<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01_oool009Woool00`0003?o
03?o0007<ol00P0005goool00ol0VOooooooo`0Koooo002Joooo00<0000co`0co`001S?o00030000
oooooooo05coool00ol0VOooooooo`0Koooo002Joooo00<0000co`0co`001S?o00030000oooooooo
05coool00ol0VOooooooo`0Koooo002Joooo00<0000co`0co`001S?o00030000oooooooo05coool0
0ol0VOooooooo`0Koooo002Joooo00<0000co`0co`001S?o00030000oooooooo05coool00ol0VOoo
ooooo`0Koooo002Koooo1@0000<co`000`000?ooooooo`1Loooo00?o09Woooooool06oooo`00Vooo
o`030000<ol0000000Dco`000`000?ooooooo`1Loooo00?o09Woooooool06oooo`00Voooo`030000
<ol0000000Dco`030000G?ooo`03o`2Ioooooooo01_oool009coool200001C?o00030000oooooooo
05coool00ol0VOooooooo`0Koooo002Loooo0P0000Dco`000`000?ooooooo`1Loooo00?o09Wooooo
ool06oooo`00W?ooo`800005<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01_oool009coool0
0`0003?o03?o0004<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01_oool009coool00`0003?o
03?o0004<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01_oool009coool00`0003?o03?o0004
<ol00P0005goool00ol0VOooooooo`0Koooo002Moooo00<0000co`0co`000c?o00030000oooooooo
05coool00ol0VOooooooo`0Koooo002Moooo00<0000co`0co`000c?o00030000oooooooo05coool0
0ol0VOooooooo`0Koooo002Moooo00<0000co`0co`000c?o00030000oooooooo05coool00ol0VOoo
ooooo`0Koooo002Moooo00<0000co`0co`000c?o00030000oooooooo05coool00ol0VOooooooo`0K
oooo002Moooo00<0000co`0co`000c?o00030000oooooooo05coool00ol0VOooooooo`0Koooo002M
oooo00<0000co`0co`000c?o0080001Moooo00?o09Woooooool06oooo`00WOooo`030000<ol0<ol0
00<co`000`000?ooooooo`1Loooo00?o09Woooooool06oooo`00WOooo`030000<ol0<ol000<co`00
0`000?ooooooo`1Loooo00?o09Woooooool06oooo`00W_ooo`030000<ol0<ol0008co`000`000?oo
ooooo`1Loooo00?o09Woooooool06oooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1L
oooo00?o09Woooooool06oooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1Loooo00?o
09Woooooool06oooo`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1Loooo00?o09Wooooo
ool06oooo`00W_ooo`030000<ol0<ol0008co`020000GOooo`03o`2Ioooooooo01_oool009koool0
0`0003?o03?o0002<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01_oool009koool00`0003?o
03?o0002<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01_oool009koool00`0003?o03?o0002
<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01_oool009koool00`0003?o03?o0002<ol000<0
003oooooool0G?ooo`03o`2Ioooooooo01_oool009koool00`0003?o03?o0002<ol000<0003ooooo
ool0G?ooo`03o`2Ioooooooo01_oool009koool00`0003?o03?o0002<ol00P0005goool00ol0VOoo
ooooo`0Koooo002Ooooo00D0000co`0co`0co`000000G_ooo`03o`2Ioooooooo01_oool009ooool0
1@0003?o03?o03?o0000001Noooo00?o09Woooooool06oooo`00Woooo`050000<ol0<ol0<ol00000
05koool00ol0VOooooooo`0Koooo002Koooo1@0000<co`000`000?ooooooo`1Loooo00?o09Wooooo
ool06oooo`00Voooo`050000oooooooooooo000000<co`000`000?ooooooo`1Loooo00?o09Wooooo
ool06oooo`00W?ooo`040000oooooooo00000c?o00<0001Loooo00?o09Woooooool06oooo`00WOoo
o`030000oooo000000<co`000`000?ooooooo`1Loooo00?o09Woooooool06oooo`00Voooo`030000
oooooooo00800003<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01_oool009coool2000000?o
ool0000co`000S?o00030000oooooooo05coool00ol0VOooooooo`0Koooo002Ooooo00D0000co`0c
o`0co`000000G_ooo`03o`2Ioooooooo01_oool00:3oool0100003?o03?o000005koool00ol0VOoo
ooooo`0Koooo002Poooo00<0000co`0co`000P0005goool00ol0VOooooooo`0Koooo002Poooo00@0
000co`0co`00001Noooo00?o09Woooooool06oooo`00X?ooo`040000<ol0<ol00000G_ooo`03o`2I
oooooooo01_oool00:3oool0100003?o03?o000005koool00ol0VOooooooo`0Koooo002Poooo00@0
000co`0co`00001Noooo00?o09Woooooool06oooo`00X?ooo`040000<ol0<ol00000G_ooo`03o`2I
oooooooo01_oool00:3oool0100003?o03?o000005koool00ol0VOooooooo`0Koooo002Qoooo00@0
000co`000000001Moooo00?o09Woooooool06oooo`00XOooo`030000<ol0000005koool00ol0VOoo
ooooo`0Koooo002Qoooo00<0000co`000000G_ooo`03o`2Ioooooooo01_oool00:7oool00`0003?o
0000001Noooo00?o09Woooooool06oooo`00XOooo`030000<ol0000005koool00ol0VOooooooo`0K
oooo002Qoooo00<0000co`000000G_ooo`03o`2Ioooooooo01_oool00:7oool0100003?o00000000
05goool00ol0VOooooooo`0Koooo002Qoooo00<0000co`000000G_ooo`03o`2Ioooooooo01_oool0
0:7oool00`0003?o0000001Noooo00?o09Woooooool06oooo`00XOooo`030000<ol0000005koool0
0ol0VOooooooo`0Koooo002Qoooo00<0000co`000000G_ooo`03o`2Ioooooooo01_oool00:7oool0
0`0003?o0000001Noooo00?o09Woooooool06oooo`00XOooo`040000<ol000000000GOooo`03o`2I
oooooooo01_oool00:7oool00`0003?o0000001Noooo00?o09Woooooool06oooo`00XOooo`030000
<ol0000005koool00ol0VOooooooo`0Koooo002Qoooo00<0000co`000000G_ooo`03o`2Ioooooooo
01_oool009coool200000oooo`030000<ol0000005koool00ol0VOooooooo`0Koooo002Koooo00@0
003oooooool00002oooo00<0000co`000000G_ooo`03o`2Ioooooooo01_oool009goool01P000?oo
ooooooooo`0003?o00<0001Loooo00?o09Woooooool06oooo`00W_ooo`060000oooooooo0000<ol0
0000G_ooo`03o`2Ioooooooo01_oool009_oool010000?ooooooo`0000;oool00`0003?o0000001N
oooo00?o09Woooooool06oooo`00W?ooo`800004oooo0P0005koool00ol0VOooooooo`0Koooo002R
oooo0P0005koool00ol0VOooooooo`0Koooo002Roooo0P0005koool00ol0VOooooooo`0Koooo002R
oooo0P0005koool00ol0VOooooooo`0Koooo002Roooo0`0005goool00ol0VOooooooo`0Koooo002R
oooo0P0005koool00ol0VOooooooo`0Koooo002Roooo0P0005koool00ol0VOooooooo`0Koooo002R
oooo0P0005koool00ol0VOooooooo`0Koooo002Roooo0P0005koool00ol0VOooooooo`0Koooo002R
oooo0P0005koool00ol0VOooooooo`0Koooo002Roooo0`0005goool00ol0VOooooooo`0Koooo002R
oooo0P0005koool00ol0VOooooooo`0Koooo002Roooo0P0005koool00ol0VOooooooo`0Koooo002R
oooo0P0005koool00ol0VOooooooo`0Koooo002Roooo0P0005koool00ol0VOooooooo`0Koooo002R
oooo0P0005koool00ol0VOooooooo`0Koooo002Roooo0`0005goool00ol0VOooooooo`0Koooo002S
oooo00<0003oooooool0G?ooo`03o`2Ioooooooo01_oool00:?oool00`000?ooooooo`1Loooo00?o
09Woooooool06oooo`00Xoooo`030000oooooooo05coool00ol0VOooooooo`0Koooo002Soooo00<0
003oooooool0G?ooo`03o`2Ioooooooo01_oool00:?oool00`000?ooooooo`1Loooo00?o09Wooooo
ool06oooo`00Xoooo`80001Moooo00?o09Woooooool06oooo`00Xoooo`030000oooooooo05coool0
0ol0VOooooooo`0Koooo002Soooo00<0003oooooool0G?ooo`03o`2Ioooooooo01_oool00:?oool0
0`000?ooooooo`1Loooo00?o09Woooooool06oooo`00Xoooo`030000oooooooo05coool00ol0VOoo
ooooo`0Koooo002Moooo0`0000?oool00`000?ooooooo`1Loooo00?o09Woooooool06oooo`00W_oo
o`030000oooooooo00;oool00`000?ooooooo`1Loooo00?o09Woooooool06oooo`00Voooo`D00003
oooo0`0005coool00ol0VOooooooo`0Koooo002Koooo00@0003oooooool00021oooo002Loooo00<0
003oool00000POooo`00WOooo`800021oooo003ooooo8Oooo`00ooooob7oool007coool00`000?oo
ooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0I
oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool200001?ooo`800005oooo00<0003oooooool00_ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?oo
ooooo`1joooo001koooo00<0003oooooool01@0000ooool00`000?ooooooo`09oooo00D0003ooooo
ooooool00000OOooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`800009
oooo100000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
.2 1 0 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.06244 .12361 L
.06788 .12361 L
.07379 .12361 L
.07899 .12361 L
.08451 .12361 L
.08947 .12361 L
.09494 .12361 L
.10458 .12361 L
.10978 .12361 L
.11472 .12361 L
.12399 .12361 L
.13397 .12361 L
.13962 .12361 L
.14487 .12361 L
.14994 .12361 L
.15543 .12361 L
.16539 .12361 L
.17508 .12361 L
.184 .12361 L
.19373 .12361 L
.20282 .12361 L
.21279 .12361 L
.21839 .12361 L
.22348 .12361 L
.2334 .12361 L
.24257 .12361 L
.25264 .12361 L
.25772 .12361 L
.26333 .12361 L
.27342 .12361 L
.28268 .12362 L
.29284 .12362 L
.29795 .12362 L
.30353 .12363 L
.31381 .12363 L
.32314 .12364 L
.32831 .12365 L
.33392 .12366 L
.34409 .12368 L
.35356 .12372 L
.35894 .12374 L
.36397 .12376 L
.37411 .12383 L
.37981 .12388 L
.38501 .12394 L
Mistroke
.39488 .12408 L
.40404 .12426 L
.41408 .12455 L
.41969 .12475 L
.42477 .12498 L
.43482 .12558 L
.44406 .12635 L
.4542 .12754 L
.4593 .12833 L
.46489 .12938 L
.47015 .13058 L
.47512 .13194 L
.48444 .13526 L
.48965 .13767 L
.49447 .14035 L
.49972 .14387 L
.50537 .1485 L
.51041 .15354 L
.51502 .15908 L
.52407 .17325 L
.52887 .18305 L
.53412 .19615 L
.53956 .21301 L
.54469 .23283 L
.54963 .25656 L
.55499 .28888 L
.55944 .32259 L
.56434 .36904 L
.56964 .43439 L
.57235 .47563 L
.57525 .52746 L
.57665 .55567 L
.57797 .58468 L
.57915 .61281 L
.58045 .12361 L
.58167 .12361 L
.58297 .12361 L
.5853 .12361 L
.62302 .12361 L
.66319 .12361 L
.70184 .12361 L
.74295 .12361 L
.78254 .12361 L
.82062 .12361 L
.86115 .12361 L
.90016 .12361 L
.94163 .12361 L
.97619 .12361 L
Mfstroke
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91726 .12361 L
.93871 .12361 L
.94807 .12361 L
.95322 .12361 L
.95575 .12361 L
.9581 .12361 L
.95923 .12361 L
.96029 .12361 L
s
.96029 .12361 m
.96074 .61803 L
s
0 .4 1 r
.02381 .11975 m
.04262 .11822 L
.06244 .11594 L
.07286 .11437 L
.08255 .11263 L
.09388 .11018 L
.10458 .10735 L
.125 .10022 L
.14357 .09105 L
.16355 .07713 L
.18199 .05904 L
.19101 .04779 L
.19339 .0445 L
.19598 .04076 L
.19717 .03899 L
.19844 .03709 L
.19963 .03711 L
.20071 .03713 L
.20627 .03723 L
.21136 .03732 L
.22134 .03754 L
.24058 .03809 L
.25143 .03849 L
.2614 .03893 L
.28023 .04002 L
.29092 .04082 L
.30089 .04172 L
.32124 .04413 L
.3398 .04723 L
.35889 .05169 L
.37965 .05817 L
.42043 .07261 L
.45969 .08548 L
.49744 .09537 L
.51679 .09925 L
.52675 .10088 L
.53765 .10233 L
.54267 .10286 L
.54803 .10332 L
.55063 .1035 L
.55309 .10364 L
.5553 .10373 L
.55645 .10378 L
.55769 .10381 L
.559 .10384 L
.56023 .10386 L
.56098 .10386 L
.56169 .10387 L
.56233 .10386 L
.56302 .10386 L
Mistroke
.56377 .10385 L
.56444 .10384 L
.56522 .10383 L
.56595 .10381 L
.56726 .10376 L
.56867 .1037 L
.57123 .10353 L
.57394 .10329 L
.57625 .10303 L
.57879 .10266 L
.61926 .09506 L
.65822 .08693 L
.67807 .08303 L
.68854 .08124 L
.69964 .07966 L
.70439 .07912 L
.7095 .07866 L
.71243 .07845 L
.71511 .07831 L
.71644 .07825 L
.71768 .07821 L
.71897 .07817 L
.71965 .07816 L
.72038 .07815 L
.72167 .07814 L
.72286 .07814 L
.72416 .07815 L
.72482 .07816 L
.72555 .07818 L
.72676 .07821 L
.72807 .07826 L
.73042 .07839 L
.73287 .07858 L
.73519 .07881 L
.73954 .07939 L
.74411 .08022 L
.74917 .08143 L
.75446 .08307 L
.75942 .085 L
.76828 .08951 L
.77783 .09618 L
.78732 .10504 L
.79746 .1175 L
.79889 .11955 L
.80045 .12186 L
.80117 .12296 L
.80192 .12361 L
.80257 .12361 L
.80328 .12361 L
.80858 .12361 L
Mistroke
.81894 .12361 L
.85853 .12361 L
.89884 .12361 L
.93763 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.123607 0.123607 [
[.10317 .11111 -6 -9 ]
[.10317 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.42063 .11111 -6 -9 ]
[.42063 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.89683 .11111 -3 -9 ]
[.89683 .11111 3 0 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .24721 -6 -4.5 ]
[.56687 .24721 0 4.5 ]
[.56687 .37082 -6 -4.5 ]
[.56687 .37082 0 4.5 ]
[.56687 .49443 -6 -4.5 ]
[.56687 .49443 0 4.5 ]
[.56687 .61803 -6 -4.5 ]
[.56687 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .12361 m
.10317 .12986 L
s
[(-6)] .10317 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-4)] .2619 .11111 0 1 Mshowa
.42063 .12361 m
.42063 .12986 L
s
[(-2)] .42063 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(2)] .7381 .11111 0 1 Mshowa
.89683 .12361 m
.89683 .12986 L
s
[(4)] .89683 .11111 0 1 Mshowa
.125 Mabswid
.14286 .12361 m
.14286 .12736 L
s
.18254 .12361 m
.18254 .12736 L
s
.22222 .12361 m
.22222 .12736 L
s
.30159 .12361 m
.30159 .12736 L
s
.34127 .12361 m
.34127 .12736 L
s
.38095 .12361 m
.38095 .12736 L
s
.46032 .12361 m
.46032 .12736 L
s
.5 .12361 m
.5 .12736 L
s
.53968 .12361 m
.53968 .12736 L
s
.61905 .12361 m
.61905 .12736 L
s
.65873 .12361 m
.65873 .12736 L
s
.69841 .12361 m
.69841 .12736 L
s
.77778 .12361 m
.77778 .12736 L
s
.81746 .12361 m
.81746 .12736 L
s
.85714 .12361 m
.85714 .12736 L
s
.06349 .12361 m
.06349 .12736 L
s
.02381 .12361 m
.02381 .12736 L
s
.93651 .12361 m
.93651 .12736 L
s
.97619 .12361 m
.97619 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.57937 0 m
.58562 0 L
s
[(-1)] .56687 0 1 0 Mshowa
.57937 .24721 m
.58562 .24721 L
s
[(1)] .56687 .24721 1 0 Mshowa
.57937 .37082 m
.58562 .37082 L
s
[(2)] .56687 .37082 1 0 Mshowa
.57937 .49443 m
.58562 .49443 L
s
[(3)] .56687 .49443 1 0 Mshowa
.57937 .61803 m
.58562 .61803 L
s
[(4)] .56687 .61803 1 0 Mshowa
.125 Mabswid
.57937 .02472 m
.58312 .02472 L
s
.57937 .04944 m
.58312 .04944 L
s
.57937 .07416 m
.58312 .07416 L
s
.57937 .09889 m
.58312 .09889 L
s
.57937 .14833 m
.58312 .14833 L
s
.57937 .17305 m
.58312 .17305 L
s
.57937 .19777 m
.58312 .19777 L
s
.57937 .22249 m
.58312 .22249 L
s
.57937 .27193 m
.58312 .27193 L
s
.57937 .29666 m
.58312 .29666 L
s
.57937 .32138 m
.58312 .32138 L
s
.57937 .3461 m
.58312 .3461 L
s
.57937 .39554 m
.58312 .39554 L
s
.57937 .42026 m
.58312 .42026 L
s
.57937 .44498 m
.58312 .44498 L
s
.57937 .46971 m
.58312 .46971 L
s
.57937 .51915 m
.58312 .51915 L
s
.57937 .54387 m
.58312 .54387 L
s
.57937 .56859 m
.58312 .56859 L
s
.57937 .59331 m
.58312 .59331 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002Koooo1@00083oool009goool00`000?ooooooo`20oooo002Moooo00<0003ooooo
ool00oooo`<0001joooo002Eoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0N_oo
o`00WOooo`030000oooooooo00?oool00`000?ooooooo`1joooo002Loooo0P0000Goool00`000?oo
ooooo`1joooo002Soooo00<0003oooooool0N_ooo`00Xoooo`030000oooooooo07[oool00:?oool2
0000Noooo`00Xoooo`030000oooooooo07[oool00:?oool00`000?ooooooo`1joooo0013oooo00<0
I_ooooooool0GOooo`030000oooooooo07[oool004;oool00`1Vooooo`1Vo`0F06KoB?ooo`030000
oooooooo07[oool0047oool00`1Vooooooooo`0Goooo2@1Vocooool00`000?ooooooo`1joooo0011
oooo00<0I_ooooooool08?ooo`D0I_ljoooo00<0003oooooool0N_ooo`00@?ooo`0306Kooooooooo
02Koool406Ko=_ooo`80001koooo000ooooo00<0I_ooooooool0:oooo`80I_ldoooo00<0003ooooo
ool0N_ooo`00?_ooo`0306Kooooooooo02koool306Ko<Oooo`030000oooooooo07[oool003goool0
0`1Vooooooooo`0boooo101Vobgoool00`000?ooooooo`1joooo000loooo00<0I_ooooooool0=ooo
o`@0I_lYoooo00<0003oooooool0N_ooo`00??ooo`0306Kooooooooo03_oool306Ko9_ooo`030000
oooooooo07[oool003_oool00`1Vooooooooo`0ooooo0P1VobCoool20000Noooo`00:oooo`<0000<
oooo00<0I_ooooooool06Oooo`<0000Soooo10000080I_lQoooo00<0003oooooool06oooo`P0I_l4
000000<0I_ooooooool09?ooo`<0000Yoooo000[oooo00@0003oooooool00009oooo0P1Voagoool0
0`000?ooooooo`0Roooo00<0003oooooool00oooo`80I_lOoooo00<0003oooooool05?ooo`L0I_l8
oooo00<0003oooooool00_ooo`80I_lUoooo00<0003oooooool0:?ooo`00:oooo`040000oooooooo
00001oooo`80I_lLoooo1@0002Coool00`000?ooooooo`04oooo101Voa_oool00`000?ooooooo`0?
oooo1@1Voa3oool00`000?ooooooo`03oooo0P1Vob3oool50000:Oooo`009Oooo`@00002oooo0`00
00Koool206Ko6?ooo`@00002oooo00@0003oooooool0000Noooo100000Coool00`000?ooooooo`07
oooo101VoaOoool00`000?ooooooo`0:oooo1@1VoaKoool00`000?ooooooo`04oooo0P1Voakoool0
10000?ooooooo`0002[oool002coool00`000?ooooooo`03oooo0P1Vob7oool00`000?ooo`00000T
oooo00@0003oooooool0000<oooo1@1Voa;oool00`000?ooooooo`05oooo1@1VoaWoool010000?oo
ooooo`0000Ooool206Ko7Oooo`030000oooo000002[oool002coool300000`1VobCoool200009Ooo
o`80000Boooo101Vo`koool2000000?oool0I_l0I_l00`1Voaooool200002_ooo`0306Kooooooooo
01_oool20000:_ooo`00;Oooo`80I_mVoooo3P1Vo`03000006Ko06Ko037oool00`1Vooooooooo`16
oooo000Zoooo0`1VogKoool00`000?ooooooo`0boooo00<0I_ooooooool0AOooo`009oooo`<0I_mi
oooo00<0003oooooool0<oooo`0306Kooooooooo04Coool001koool906KoO?ooo`030000oooooooo
03?oool00`1Vooooooooo`14oooo000Foooo201VohGoool00`000?ooooooo`0doooo0P1VodCoool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooo000001000000
0c?o000003?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`03oooo00Go09Woooooooooool000005oooo`00:_ooo`030000
oooooooo02Koool00`000?ooooooo`0Uoooo00<0003oooooool01_ooo`@0000K<ol000<0003ooooo
ool09Oooo`030000oooooooo02Koool00`000?ooooooo`0=oooo00?o09Woooooool06Oooo`00R?oo
o`@0000G<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01Woool008coool00`0003?o03?o000D
<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01Woool008goool2000053?o00030000oooooooo
05koool00ol0VOooooooo`0Ioooo002?oooo00<0000co`0co`004C?o00030000oooooooo05koool0
0ol0VOooooooo`0Ioooo002@oooo00<0000co`0co`0043?o0080001Ooooo00?o09Woooooool06Ooo
o`00TOooo`80000@<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01Woool009?oool00`0003?o
03?o000=<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01Woool009?oool00`0003?o03?o000=
<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01Woool009Coool00`0003?o03?o000<<ol000<0
003oooooool0G_ooo`03o`2Ioooooooo01Woool009Coool00`0003?o03?o000<<ol000<0003ooooo
ool0G_ooo`03o`2Ioooooooo01Woool009Goool00`0003?o03?o000;<ol00P0005ooool00ol0VOoo
ooooo`0Ioooo002Eoooo00<0000co`0co`002c?o00030000oooooooo05koool00ol0VOooooooo`0I
oooo002Foooo00<0000co`0co`002S?o00030000oooooooo05koool00ol0VOooooooo`0Ioooo002F
oooo00<0000co`0co`002S?o00030000oooooooo05koool00ol0VOooooooo`0Ioooo002Goooo00<0
000co`0co`002C?o00030000oooooooo05koool00ol0VOooooooo`0Ioooo002Goooo00<0000co`0c
o`002C?o00030000oooooooo05koool00ol0VOooooooo`0Ioooo002Hoooo00<0000co`0co`0023?o
0080001Ooooo00?o09Woooooool06Oooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1N
oooo00?o09Woooooool06Oooo`00V?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1Noooo00?o
09Woooooool06Oooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`1Noooo00?o09Wooooo
ool06Oooo`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`1Noooo00?o09Woooooool06Ooo
o`00VOooo`030000<ol0<ol000Lco`000`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00VOoo
o`030000<ol0<ol000Lco`020000Goooo`03o`2Ioooooooo01Woool009[oool00`0003?o03?o0006
<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01Woool009[oool00`0003?o03?o0006<ol000<0
003oooooool0G_ooo`03o`2Ioooooooo01Woool009[oool00`0003?o03?o0006<ol000<0003ooooo
ool0G_ooo`03o`2Ioooooooo01Woool009[oool00`0003?o03?o0006<ol000<0003oooooool0G_oo
o`03o`2Ioooooooo01Woool009_oool500000c?o00030000oooooooo05koool00ol0VOooooooo`0I
oooo002Koooo00<0000co`0000001C?o00030000oooooooo05koool00ol0VOooooooo`0Ioooo002K
oooo00<0000co`0000001C?o00<0001Noooo00?o09Woooooool06Oooo`00W?ooo`800005<ol000<0
003oooooool0G_ooo`03o`2Ioooooooo01Woool009coool200001C?o00030000oooooooo05koool0
0ol0VOooooooo`0Ioooo002Loooo0P0000Dco`000`000?ooooooo`1Noooo00?o09Woooooool06Ooo
o`00W?ooo`030000<ol0<ol000@co`000`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00W?oo
o`030000<ol0<ol000@co`000`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00W?ooo`030000
<ol0<ol000@co`020000Goooo`03o`2Ioooooooo01Woool009goool00`0003?o03?o0003<ol000<0
003oooooool0G_ooo`03o`2Ioooooooo01Woool009goool00`0003?o03?o0003<ol000<0003ooooo
ool0G_ooo`03o`2Ioooooooo01Woool009goool00`0003?o03?o0003<ol000<0003oooooool0G_oo
o`03o`2Ioooooooo01Woool009goool00`0003?o03?o0003<ol000<0003oooooool0G_ooo`03o`2I
oooooooo01Woool009goool00`0003?o03?o0003<ol000<0003oooooool0G_ooo`03o`2Ioooooooo
01Woool009goool00`0003?o03?o0003<ol00P0005ooool00ol0VOooooooo`0Ioooo002Moooo00<0
000co`0co`000c?o00030000oooooooo05koool00ol0VOooooooo`0Ioooo002Moooo00<0000co`0c
o`000c?o00030000oooooooo05koool00ol0VOooooooo`0Ioooo002Noooo00<0000co`0co`000S?o
00030000oooooooo05koool00ol0VOooooooo`0Ioooo002Noooo00<0000co`0co`000S?o00030000
oooooooo05koool00ol0VOooooooo`0Ioooo002Noooo00<0000co`0co`000S?o00030000oooooooo
05koool00ol0VOooooooo`0Ioooo002Noooo00<0000co`0co`000S?o00030000oooooooo05koool0
0ol0VOooooooo`0Ioooo002Noooo00<0000co`0co`000S?o0080001Ooooo00?o09Woooooool06Ooo
o`00W_ooo`030000<ol0<ol0008co`000`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00W_oo
o`030000<ol0<ol0008co`000`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00W_ooo`030000
<ol0<ol0008co`000`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00W_ooo`030000<ol0<ol0
008co`000`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00W_ooo`030000<ol0<ol0008co`00
0`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00W_ooo`030000<ol0<ol0008co`020000Gooo
o`03o`2Ioooooooo01Woool009ooool01@0003?o03?o03?o0000001Poooo00?o09Woooooool06Ooo
o`00Woooo`050000<ol0<ol0<ol00000063oool00ol0VOooooooo`0Ioooo002Ooooo00D0000co`0c
o`0co`000000H?ooo`03o`2Ioooooooo01Woool009_oool500000c?o00030000oooooooo05koool0
0ol0VOooooooo`0Ioooo002Koooo00D0003oooooooooool000000c?o00030000oooooooo05koool0
0ol0VOooooooo`0Ioooo002Loooo00@0003oooooool00003<ol00`0005koool00ol0VOooooooo`0I
oooo002Moooo00<0003oool000000c?o00030000oooooooo05koool00ol0VOooooooo`0Ioooo002K
oooo00<0003oooooool00P0000<co`000`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00W?oo
o`8000000oooo`0003?o0002<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01Woool009ooool0
1@0003?o03?o03?o0000001Poooo00?o09Woooooool06Oooo`00X?ooo`040000<ol0<ol00000H?oo
o`03o`2Ioooooooo01Woool00:3oool00`0003?o03?o00020000Goooo`03o`2Ioooooooo01Woool0
0:3oool0100003?o03?o0000063oool00ol0VOooooooo`0Ioooo002Poooo00@0000co`0co`00001P
oooo00?o09Woooooool06Oooo`00X?ooo`040000<ol0<ol00000H?ooo`03o`2Ioooooooo01Woool0
0:3oool0100003?o03?o0000063oool00ol0VOooooooo`0Ioooo002Poooo00@0000co`0co`00001P
oooo00?o09Woooooool06Oooo`00X?ooo`040000<ol0<ol00000H?ooo`03o`2Ioooooooo01Woool0
0:7oool0100003?o0000000005ooool00ol0VOooooooo`0Ioooo002Qoooo00<0000co`000000H?oo
o`03o`2Ioooooooo01Woool00:7oool00`0003?o0000001Poooo00?o09Woooooool06Oooo`00XOoo
o`030000<ol00000063oool00ol0VOooooooo`0Ioooo002Qoooo00<0000co`000000H?ooo`03o`2I
oooooooo01Woool00:7oool00`0003?o0000001Poooo00?o09Woooooool06Oooo`00XOooo`040000
<ol000000000Goooo`03o`2Ioooooooo01Woool00:7oool00`0003?o0000001Poooo00?o09Wooooo
ool06Oooo`00XOooo`030000<ol00000063oool00ol0VOooooooo`0Ioooo002Qoooo00<0000co`00
0000H?ooo`03o`2Ioooooooo01Woool00:7oool00`0003?o0000001Poooo00?o09Woooooool06Ooo
o`00XOooo`030000<ol00000063oool00ol0VOooooooo`0Ioooo002Qoooo00@0000co`000000001O
oooo00?o09Woooooool06Oooo`00XOooo`030000<ol00000063oool00ol0VOooooooo`0Ioooo002Q
oooo00<0000co`000000H?ooo`03o`2Ioooooooo01Woool00:7oool00`0003?o0000001Poooo00?o
09Woooooool06Oooo`00W?ooo`800003oooo00<0000co`000000H?ooo`03o`2Ioooooooo01Woool0
09_oool010000?ooooooo`0000;oool00`0003?o0000001Poooo00?o09Woooooool06Oooo`00WOoo
o`060000oooooooooooo0000<ol00`0005koool00ol0VOooooooo`0Ioooo002Noooo00H0003ooooo
ool0000co`00001Poooo00?o09Woooooool06Oooo`00Voooo`040000oooooooo00000_ooo`030000
<ol00000063oool00ol0VOooooooo`0Ioooo002Loooo0P0000Coool20000H?ooo`03o`2Ioooooooo
01Woool00:;oool20000H?ooo`03o`2Ioooooooo01Woool00:;oool20000H?ooo`03o`2Ioooooooo
01Woool00:;oool20000H?ooo`03o`2Ioooooooo01Woool00:;oool30000Goooo`03o`2Ioooooooo
01Woool00:;oool20000H?ooo`03o`2Ioooooooo01Woool00:;oool20000H?ooo`03o`2Ioooooooo
01Woool00:;oool20000H?ooo`03o`2Ioooooooo01Woool00:;oool20000H?ooo`03o`2Ioooooooo
01Woool00:;oool20000H?ooo`03o`2Ioooooooo01Woool00:;oool30000Goooo`03o`2Ioooooooo
01Woool00:;oool20000H?ooo`03o`2Ioooooooo01Woool00:;oool20000H?ooo`03o`2Ioooooooo
01Woool00:;oool20000H?ooo`03o`2Ioooooooo01Woool00:;oool20000H?ooo`03o`2Ioooooooo
01Woool00:;oool20000H?ooo`03o`2Ioooooooo01Woool00:;oool30000Goooo`03o`2Ioooooooo
01Woool00:?oool00`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00Xoooo`030000oooooooo
05koool00ol0VOooooooo`0Ioooo002Soooo00<0003oooooool0G_ooo`03o`2Ioooooooo01Woool0
0:?oool00`000?ooooooo`1Noooo00?o09Woooooool06Oooo`00Xoooo`030000oooooooo05koool0
0ol0VOooooooo`0Ioooo002Soooo0P0005ooool00ol0VOooooooo`0Ioooo002Soooo00<0003ooooo
ool0G_ooo`03o`2Ioooooooo01Woool00:?oool00`000?ooooooo`1Noooo00?o09Woooooool06Ooo
o`00Xoooo`030000oooooooo05koool00ol0VOooooooo`0Ioooo002Soooo00<0003oooooool0G_oo
o`03o`2Ioooooooo01Woool009goool300000oooo`030000oooooooo05koool00ol0VOooooooo`0I
oooo002Noooo00<0003oooooool00_ooo`030000oooooooo05koool00ol0VOooooooo`0Ioooo002K
oooo1@0000?oool30000G_ooo`03o`2Ioooooooo01Woool009_oool010000?ooooooo`00087oool0
09coool00`000?ooo`000021oooo002Moooo0P00087oool00?oooolQoooo003ooooo8Oooo`00O?oo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000?oooo00<0003oooooool01oooo`800004
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Ooo
o`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-8.12947, \
-1.14361, 0.0496935, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-8.12947, -1.14361, 0.0496935, 0.031907}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-2\), \ 
              3}, \ PlotRange -> {\(-1\), 1}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-2\), \ 3}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(-1\), 
                1}], \[IndentingNewLine]\ \ \ \ \ \ \ Plot[{g[x, 
                t]}, {x, \ \(-2\), \ 3}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(-1\), 
                1}]}, \[IndentingNewLine]\ {t, \ \(-2.9\), \ 1.9,  .1}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.03279 .30902 L
.03793 .30902 L
.04018 .30902 L
.04136 .30902 L
.04262 .30902 L
s
.04262 .30902 m
.04268 .61803 L
s
0 .4 1 r
.02381 .49434 m
.03279 .49207 L
.03793 .4907 L
.04018 .49009 L
.04136 .48976 L
.04262 .48941 L
.04325 .30902 L
.04394 .30902 L
.04517 .30902 L
.04641 .30902 L
.04758 .30902 L
.04826 .30902 L
.04891 .30902 L
.05013 .30902 L
.05145 .30902 L
.05219 .30902 L
.05288 .30902 L
.05413 .30902 L
.05531 .30902 L
.05637 .30902 L
.05751 .30902 L
.05876 .30902 L
.06008 .30902 L
.06121 .30902 L
.06244 .30902 L
.0631 .30902 L
.0638 .30902 L
.06456 .30902 L
.06527 .30902 L
.06654 .30902 L
.06727 .30902 L
.06795 .30902 L
.06921 .30902 L
.07036 .30902 L
.07163 .30902 L
.07226 .30902 L
.07296 .30902 L
.07372 .30902 L
.07444 .30902 L
.07509 .30902 L
.07579 .30902 L
.07655 .30902 L
.07735 .30902 L
.07804 .30902 L
.0788 .30902 L
.07951 .30902 L
.08016 .30902 L
.0809 .30902 L
.08161 .30902 L
.08287 .30902 L
Mistroke
.08358 .30902 L
.08424 .30902 L
.08552 .30902 L
.08624 .30902 L
.0869 .30902 L
.08812 .30902 L
.08941 .30902 L
.09056 .30902 L
.09164 .30902 L
.09282 .30902 L
.09409 .30902 L
.09479 .30902 L
.09544 .30902 L
.09615 .30902 L
.09691 .30902 L
.09818 .30902 L
.0989 .30902 L
.09958 .30902 L
.10084 .30902 L
.10199 .30902 L
.10325 .30902 L
.10389 .30902 L
.10458 .30902 L
.10522 .30902 L
.10591 .30902 L
.10713 .30902 L
.10844 .30902 L
.10919 .30902 L
.10988 .30902 L
.11114 .30902 L
.11229 .30902 L
.11293 .30902 L
.11362 .30902 L
.11488 .30902 L
.116 .30902 L
.11723 .30902 L
.11852 .30902 L
.11973 .30902 L
.12086 .30902 L
.1219 .30902 L
.12303 .30902 L
.12423 .30902 L
.12554 .30902 L
.12673 .30902 L
.12739 .30902 L
.12811 .30902 L
.12941 .30902 L
.13063 .30902 L
.13192 .30902 L
.13302 .30902 L
Mistroke
.13424 .30902 L
.13497 .30902 L
.13566 .30902 L
.13696 .30902 L
.13769 .30902 L
.13837 .30902 L
.13911 .30902 L
.13989 .30902 L
.14058 .30902 L
.14133 .30902 L
.14203 .30902 L
.14267 .30902 L
.1439 .30902 L
.14519 .30902 L
.14641 .30902 L
.1471 .30902 L
.14774 .30902 L
.14891 .30902 L
.15016 .30902 L
.15127 .30902 L
.15231 .30902 L
.15345 .30902 L
.15468 .30902 L
.15592 .30902 L
.15662 .30902 L
.15727 .30902 L
.15795 .30902 L
.15867 .30902 L
.15998 .30902 L
.16121 .30902 L
.16251 .30902 L
.16363 .30902 L
.16485 .30902 L
.16597 .30902 L
.16719 .30902 L
.16833 .30902 L
.16937 .30902 L
.17058 .30902 L
.17189 .30902 L
.17313 .30902 L
.17428 .30902 L
.17545 .30902 L
.17655 .30902 L
.17753 .30902 L
.17859 .30902 L
.17976 .30902 L
.18099 .30902 L
.18204 .30902 L
.18318 .30902 L
.1845 .30902 L
Mistroke
.18571 .30902 L
.18634 .30902 L
.18704 .30902 L
.18777 .30902 L
.18845 .30902 L
.1897 .30902 L
.19085 .30902 L
.19217 .30902 L
.19343 .30902 L
.19454 .30902 L
.19574 .30902 L
.19686 .30902 L
.19788 .30902 L
.19909 .30902 L
.20039 .30902 L
.20162 .30902 L
.20275 .30902 L
.20396 .30902 L
.20526 .30902 L
.20648 .30902 L
.2076 .30902 L
.20891 .30902 L
.20965 .30902 L
.21033 .30902 L
.21159 .30902 L
.21229 .30902 L
.21293 .30902 L
.21419 .30902 L
.21486 .30902 L
.21556 .30902 L
.21674 .30902 L
.21804 .30902 L
.21876 .30902 L
.21945 .30902 L
.22024 .30902 L
.22096 .30902 L
.22227 .30902 L
.223 .30902 L
.22368 .30902 L
.22493 .30902 L
.22612 .30902 L
.22719 .30902 L
.22835 .30902 L
.22961 .30902 L
.23032 .30902 L
.23095 .30902 L
.2322 .30902 L
.23337 .30902 L
.23447 .30902 L
.23564 .30902 L
Mistroke
.23665 .30902 L
.23773 .30902 L
.23889 .30902 L
.23997 .30902 L
.24126 .30902 L
.24244 .30902 L
.24372 .30902 L
.24436 .30902 L
.24508 .30902 L
.24634 .30902 L
.24752 .30902 L
.24819 .30902 L
.2489 .30902 L
.25017 .30902 L
.25088 .30902 L
.25154 .30902 L
.25227 .30902 L
.25304 .30902 L
.25434 .30902 L
.25507 .30902 L
.25574 .30902 L
.25699 .30902 L
.2583 .30902 L
.25947 .30902 L
.26057 .30902 L
.26178 .30902 L
.26307 .30902 L
.26428 .30902 L
.26498 .30902 L
.26563 .30902 L
.26693 .30902 L
.2676 .30902 L
.26834 .30902 L
.26958 .30902 L
.27089 .30902 L
.2721 .30902 L
.27322 .30902 L
.27391 .30902 L
.27466 .30902 L
.27537 .30902 L
.27602 .30902 L
.27726 .30902 L
.27856 .30902 L
.27924 .30902 L
.27997 .30902 L
.28128 .30902 L
.28208 .30902 L
.28285 .30902 L
.28358 .30902 L
.28428 .30902 L
Mistroke
.28554 .30902 L
.28669 .30902 L
.28793 .30902 L
.28862 .30902 L
.28926 .30902 L
.29034 .30902 L
.29152 .30902 L
.29275 .30902 L
.29389 .30902 L
.29455 .30902 L
.29525 .30902 L
.29654 .30902 L
.2978 .30902 L
.29896 .30902 L
.30179 .30902 L
.30303 .30902 L
.30373 .30902 L
.30439 .30902 L
.30548 .30902 L
.30665 .30902 L
.30779 .30902 L
.30902 .30902 L
.30972 .30902 L
.31037 .30902 L
.31164 .30902 L
.3128 .30902 L
.31402 .30902 L
.31509 .30902 L
.31624 .30902 L
.31733 .30902 L
.31832 .30902 L
.31949 .30902 L
.32075 .30902 L
.32195 .30902 L
.32306 .30902 L
.32436 .30902 L
.32509 .30902 L
.32576 .30902 L
.32699 .30902 L
.3283 .30902 L
.32947 .30902 L
.33056 .30902 L
.33176 .30902 L
.33304 .30902 L
.3337 .30902 L
.33441 .30902 L
.33518 .30902 L
.3359 .30902 L
.33657 .30902 L
.33729 .30902 L
Mistroke
.3386 .30902 L
.33986 .30902 L
.34101 .30902 L
.34166 .30902 L
.34237 .30902 L
.34366 .30902 L
.34431 .30902 L
.34499 .30902 L
.34621 .30902 L
.34752 .30902 L
.34827 .30902 L
.34897 .30902 L
.35023 .30902 L
.35138 .30902 L
.35202 .30902 L
.35271 .30902 L
.35397 .30902 L
.35509 .30902 L
.35632 .30902 L
.35761 .30902 L
.35882 .30902 L
.35995 .30902 L
.36098 .30902 L
.36212 .30902 L
.36332 .30902 L
.36463 .30902 L
.36582 .30902 L
.36648 .30902 L
.3672 .30902 L
.3685 .30902 L
.36972 .30902 L
.37101 .30902 L
.37211 .30902 L
.37333 .30902 L
.37406 .30902 L
.37475 .30902 L
.37605 .30902 L
.37678 .30902 L
.37746 .30902 L
.3782 .30902 L
.37899 .30902 L
.37967 .30902 L
.38042 .30902 L
.38112 .30902 L
.38176 .30902 L
.38299 .30902 L
.38428 .30902 L
.38551 .30902 L
.3862 .30902 L
.38683 .30902 L
Mistroke
.38801 .30902 L
.38925 .30902 L
.39036 .30902 L
.3914 .30902 L
.39254 .30902 L
.39377 .30902 L
.39501 .30902 L
.39571 .30902 L
.39636 .30902 L
.39768 .30902 L
.39841 .30902 L
.39908 .30902 L
.40028 .30902 L
.40158 .30902 L
.40281 .30902 L
.40394 .30902 L
.405 .30902 L
.40614 .30902 L
.40819 .30902 L
.41285 .30902 L
.42228 .30902 L
.46359 .30902 L
.50337 .30902 L
.54165 .30902 L
.58237 .30902 L
.62158 .30902 L
.66324 .30902 L
.70339 .30902 L
.74202 .30902 L
.7831 .30902 L
.82267 .30902 L
.86072 .30902 L
.90123 .30902 L
.94021 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo1@00
000306Ko00000000008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool00_ooo`0306Kooooooooo00X0000O<ol000<0000co`0co`00;C?o00030000
oooooooo02goool00`000?ooooooo`0]oooo00<0003oooooool0;_ooo`030000oooooooo01Goool0
01_oool00`1Vooooooooo`0:oooo1P0004Tco`000`000?ooooooo`2Voooo000Koooo00<0I_oooooo
ool04?ooo`D00014<ol00P000:Ooool001_oool00`1Vooooooooo`0Eoooo1000040co`000`000?oo
ooooo`2Voooo000Koooo00<0I_ooooooool06Oooo`80000n<ol000<0003oooooool0Y_ooo`006ooo
o`0306Kooooooooo01_oool30000>c?o00030000oooooooo0:Koool001_oool00`1Vooooooooo`0N
oooo0P0003Tco`020000Yoooo`006oooo`0306Kooooooooo023oool20000=c?o00030000oooooooo
0:Koool001_oool00`1Vooooooooo`0Roooo0P0003Dco`000`000?ooooooo`2Voooo000Koooo00<0
I_ooooooool09?ooo`80000c<ol000<0003oooooool0Y_ooo`006oooo`0306Kooooooooo02Koool2
0000<C?o0080002Woooo000Koooo00<0I_ooooooool0:?ooo`030000<ol0<ol002hco`000`000?oo
ooooo`2Voooo000Koooo00<0I_ooooooool0:Oooo`030000<ol0<ol002dco`000`000?ooooooo`2V
oooo000Koooo00<0I_ooooooool0:_ooo`030000<ol0<ol002`co`000`000?ooooooo`2Voooo000K
oooo00<0I_ooooooool0:oooo`030000<ol0<ol002/co`020000Yoooo`006oooo`0306Kooooooooo
02coool00`0003?o03?o000Z<ol000<0003oooooool0Y_ooo`006oooo`0306Kooooooooo02goool0
0`0003?o03?o000@<ol00P0000@co`0200000c?o00@00003<ol00P0000Dco`000`000?ooooooo`2V
oooo000Koooo00<0I_ooooooool0;_ooo`030000<ol0<ol000hco`00100003?o03?o000000Pco`00
0`0003?o03?o0003<ol000@0000co`0co`000004<ol000<0003oooooool0Y_ooo`006oooo`0306Ko
oooooooo02ooool00`0003?o03?o000=<ol000@0000co`0co`000009<ol000<0000co`0co`001C?o
00030000<ol0<ol0008co`020000Yoooo`006oooo`0306Kooooooooo033oool00`0003?o03?o000<
<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Y_oo
o`006oooo`0306Kooooooooo037oool00`0003?o03?o000;<ol000@0000co`0co`000008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo0:Koool001_oool00`1Voooo
ooooo`0aoooo00<0000co`0co`0033?o0080000:<ol00P0000@co`03000013?o00030000oooooooo
0:Koool001_oool00`1Vooooooooo`0boooo00<0000co`0co`0093?o0080002Woooo000Koooo00<0
I_ooooooool0<oooo`030000<ol0<ol002<co`000`000?ooooooo`2Voooo000Koooo00<0I_oooooo
ool0=?ooo`030000<ol0<ol0028co`000`000?ooooooo`2Voooo000Koooo00<0I_ooooooool0=?oo
o`030000<ol0<ol0028co`000`000?ooooooo`2Voooo000Koooo00<0I_ooooooool0=Oooo`030000
<ol0<ol0024co`020000Yoooo`006oooo`0306Kooooooooo03Goool00`0003?o03?o000Q<ol000<0
003oooooool0Y_ooo`006oooo`0306Kooooooooo03Koool00`0003?o03?o000P<ol000<0003ooooo
ool0Y_ooo`006oooo`0306Kooooooooo03Koool00`0003?o03?o000P<ol000<0003oooooool0Y_oo
o`006oooo`0306Kooooooooo03Ooool00`0003?o03?o000O<ol00P000:Ooool001_oool00`1Voooo
ooooo`0goooo00<0000co`0co`007c?o00030000oooooooo0:Koool001_oool00`1Vooooooooo`0h
oooo00<0000co`0co`007S?o00030000oooooooo0:Koool001_oool00`1Vooooooooo`0hoooo00<0
000co`0co`007S?o00030000oooooooo0:Koool001_oool00`1Vooooooooo`0ioooo00<0000co`0c
o`007C?o0080002Woooo000Koooo00<0I_ooooooool0>Oooo`030000<ol0<ol001dco`000`000?oo
ooooo`2Voooo000Koooo00<0I_ooooooool0>_ooo`030000<ol0<ol000Tco`02000013?o00800004
<ol00P0000Dco`000`000?ooooooo`2Voooo000Koooo00<0I_ooooooool0>_ooo`030000<ol0<ol0
00Pco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`2Voooo000K
oooo00<0I_ooooooool0>oooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`000`0003?o
03?o0002<ol00P000:Ooool001_oool00`1Vooooooooo`0koooo00<0000co`0co`001c?o00040000
<ol0<ol000002C?o00800005<ol000<0003oooooool0Y_ooo`006oooo`0306Kooooooooo03_oool0
0`0003?o03?o0007<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000oooooooo
0:Koool001_oool00`1Vooooooooo`0loooo00<0000co`0co`001c?o0080000:<ol00`0000@co`00
0`000?ooooooo`2Voooo000Koooo00<0I_ooooooool0??ooo`030000<ol0<ol001Xco`020000Yooo
o`006oooo`0306Kooooooooo03coool00`0003?o03?o000J<ol000<0003oooooool0Y_ooo`006_oo
o`80I_looooo00<0000co`0co`006C?o00030000oooooooo0:Koool001Koool406Ko00?ooooo09Wo
ool0?_ooo`030000<ol0<ol001Tco`020000Yoooo`006oooo`03o`2Ioooooooo03goool00`0003?o
03?o000I<ol000<0003oooooool0Y_ooo`006oooo`03o`2Ioooooooo03koool00`0003?o03?o000H
<ol000<0003oooooool0Y_ooo`006oooo`03o`2Ioooooooo03koool00`0003?o03?o000H<ol000<0
003oooooool0Y_ooo`006oooo`03o`2Ioooooooo03koool00`0003?o03?o000H<ol00P000:Ooool0
01_oool00ol0VOooooooo`0ooooo00<0000co`0co`005c?o00030000oooooooo0:Koool001_oool0
0ol0VOooooooo`0ooooo00<0000co`0co`005c?o00030000oooooooo0:Koool001_oool00ol0VOoo
ooooo`0ooooo00<0000co`0co`005c?o00030000oooooooo0:Koool001_oool00ol0VOooooooo`10
oooo00<0000co`0co`005S?o0080002Woooo000Koooo00?o09Woooooool0@?ooo`030000<ol0<ol0
01Hco`000`000?ooooooo`2Voooo000Koooo00?o09Woooooool0@?ooo`800004<ol00P0000Dco`00
0`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`2Voooo000Koooo00?o09Woooooool0?ooo
o`040000oooo000000002S?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0
003oooooool0Y_ooo`006oooo`03o`2Ioooooooo03ooool010000?ooo`00000000Xco`000`0003?o
03?o0004<ol000<0000co`0co`000S?o0080002Woooo000Koooo00?o09Woooooool0?oooo`040000
oooo000000002c?o00040000<ol0<ol0<ol00P0000Dco`000`000?ooooooo`2Voooo000Koooo00?o
09Woooooool0?oooo`040000oooooooo000023?o00040000<ol0<ol000000c?o00030000<ol0<ol0
00@co`000`000?ooooooo`2Voooo000Koooo00?o09Woooooool0@?ooo`<00008<ol0100000<co`03
000013?o00030000oooooooo0:Koool001_oool00ol0VOooooooo`12oooo00<0000co`0co`0053?o
0080002Woooo000Koooo00?o09Woooooool0@_ooo`030000<ol0<ol001@co`000`000?ooooooo`2V
oooo000Koooo00?o09Woooooool0@oooo`030000<ol0<ol001<co`000`000?ooooooo`2Voooo000K
oooo00?o09Woooooool0@oooo`030000<ol0<ol001<co`000`000?ooooooo`2Voooo000Koooo00?o
09Woooooool0@oooo`030000<ol0<ol001<co`020000Yoooo`006oooo`03o`2Ioooooooo04?oool0
0`0003?o03?o000C<ol000<0003oooooool0Y_ooo`006oooo`03o`2Ioooooooo04Coool00`0003?o
03?o000B<ol000<0003oooooool0Y_ooo`006oooo`03o`2Ioooooooo04Coool00`0003?o03?o000B
<ol000<0003oooooool0Y_ooo`006oooo`03o`2Ioooooooo04Coool00`0003?o03?o000B<ol00P00
0:Ooool001_oool00ol0VOooooooo`14oooo00<0000co`0co`004S?o00030000oooooooo0:Koool0
01_oool00ol0VOooooooo`15oooo00<0000co`0co`004C?o00030000oooooooo0:Koool001_oool0
0ol0VOooooooo`15oooo00<0000co`0co`004C?o00030000oooooooo0:Koool001_oool00ol0VOoo
ooooo`15oooo00<0000co`0co`004C?o0080002Woooo000Koooo00?o09Woooooool0AOooo`030000
<ol0<ol0014co`000`000?ooooooo`2Voooo000Koooo00?o09Woooooool0AOooo`030000<ol0<ol0
00Tco`0500000c?o00030000oooooooo0:Koool001_oool00ol0VOooooooo`16oooo00<0000co`0c
o`002S?o00030000<ol0<ol000<co`000`000?ooooooo`2Voooo000Koooo00?o09Woooooool0A_oo
o`030000<ol0<ol000Xco`000`0003?o03?o0003<ol00P000:Ooool006Coool=<ol000<0000co`0c
o`000c?o0:Woool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool<<ol00P0000Dco`2Y
oooo001Uoooo4S?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`02oooo00<0003oooooool0:?oo
o`030000oooooooo07Woool006GooolB<ol000?oool0003oool02Oooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001Uoooo4S?o0003oooo0000oooo00?oool200001?ooo`030000oooooooo
00coool400000oooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001Uoooo4S?o0003oooo
0000oooo00;oool010000?ooooooo`0000Coool00`000?ooooooo`04oooo100000?oool00`000?oo
ooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo07Soool006GooolB<ol000<0003ooooo
ool00_ooo`030000oooooooo01Coool00`000?ooooooo`09oooo0`0000Coool00`000?ooooooo`1g
oooo001Voooo4C?o0004oooo0000oooooooo1@0001Coool00`000?ooooooo`07oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00I_oooa4co`000oooo`000?ooo`02oooo00<0003ooooo
ool04oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
06KooolA<ol00_ooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003oooooool0NOoo
o`00I_oooa4co`2Yoooo001Voooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{80.375, 309.75}, {524.438, 383.125}} -> {-0.353114, \
2.71119, 0.00349883, 0.00566123}, {{80.6875, 309.375}, {524.438, 383.125}} -> \
{-4.55721, 5.06602, 0.0207442, 0.0127866}, {{80.6875, 309.375}, {524.438, \
383.125}} -> {-4.55721, 5.06602, 0.0207442, 0.0127866}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.03279 .30902 L
.04262 .30902 L
.04758 .30902 L
.05288 .30902 L
.05546 .30902 L
.05789 .30902 L
.06007 .30902 L
.06131 .30902 L
s
.06131 .30902 m
.06142 .61803 L
s
0 .4 1 r
.02381 .4985 m
.03279 .49652 L
.04262 .49419 L
.04758 .49295 L
.05288 .49158 L
.05546 .49089 L
.05789 .49023 L
.06007 .48963 L
.06131 .48928 L
.06244 .30902 L
.06371 .30902 L
.06487 .30902 L
.0655 .30902 L
.0662 .30902 L
.06747 .30902 L
.06865 .30902 L
.06991 .30902 L
.0711 .30902 L
.07218 .30902 L
.07285 .30902 L
.07356 .30902 L
.07483 .30902 L
.07554 .30902 L
.0762 .30902 L
.07692 .30902 L
.0777 .30902 L
.07837 .30902 L
.07909 .30902 L
.07978 .30902 L
.08042 .30902 L
.08162 .30902 L
.0829 .30902 L
.08415 .30902 L
.08531 .30902 L
.08653 .30902 L
.08717 .30902 L
.08786 .30902 L
.08861 .30902 L
.08932 .30902 L
.08996 .30902 L
.09065 .30902 L
.09129 .30902 L
.09198 .30902 L
.0932 .30902 L
.0939 .30902 L
.09465 .30902 L
.09535 .30902 L
.096 .30902 L
.09675 .30902 L
.09757 .30902 L
Mistroke
.09835 .30902 L
.09907 .30902 L
.09979 .30902 L
.10047 .30902 L
.10174 .30902 L
.10245 .30902 L
.1031 .30902 L
.10382 .30902 L
.10458 .30902 L
.10572 .30902 L
.10692 .30902 L
.10824 .30902 L
.10946 .30902 L
.1106 .30902 L
.11166 .30902 L
.11283 .30902 L
.11408 .30902 L
.11479 .30902 L
.11544 .30902 L
.11612 .30902 L
.11686 .30902 L
.11809 .30902 L
.11941 .30902 L
.12064 .30902 L
.12193 .30902 L
.12304 .30902 L
.12426 .30902 L
.12549 .30902 L
.12663 .30902 L
.12788 .30902 L
.12857 .30902 L
.12921 .30902 L
.13036 .30902 L
.1316 .30902 L
.13278 .30902 L
.13388 .30902 L
.13491 .30902 L
.13589 .30902 L
.13695 .30902 L
.13811 .30902 L
.13925 .30902 L
.14045 .30902 L
.14148 .30902 L
.1426 .30902 L
.14392 .30902 L
.14513 .30902 L
.14577 .30902 L
.14647 .30902 L
.1472 .30902 L
.14788 .30902 L
Mistroke
.14913 .30902 L
.15028 .30902 L
.15091 .30902 L
.1516 .30902 L
.15286 .30902 L
.15409 .30902 L
.1552 .30902 L
.15649 .30902 L
.1577 .30902 L
.15882 .30902 L
.15986 .30902 L
.16099 .30902 L
.16219 .30902 L
.1635 .30902 L
.16468 .30902 L
.16534 .30902 L
.16606 .30902 L
.16736 .30902 L
.16857 .30902 L
.16986 .30902 L
.17096 .30902 L
.17218 .30902 L
.17287 .30902 L
.1736 .30902 L
.1749 .30902 L
.17562 .30902 L
.1763 .30902 L
.17704 .30902 L
.17783 .30902 L
.17852 .30902 L
.17926 .30902 L
.17996 .30902 L
.18061 .30902 L
.18183 .30902 L
.18313 .30902 L
.18434 .30902 L
.18567 .30902 L
.18691 .30902 L
.18807 .30902 L
.19258 .30902 L
.1938 .30902 L
.19511 .30902 L
.19635 .30902 L
.19749 .30902 L
.19813 .30902 L
.19883 .30902 L
.19956 .30902 L
.20024 .30902 L
.20144 .30902 L
.20272 .30902 L
Mistroke
.20395 .30902 L
.20508 .30902 L
.20631 .30902 L
.207 .30902 L
.20765 .30902 L
.20874 .30902 L
.20991 .30902 L
.21117 .30902 L
.21231 .30902 L
.21342 .30902 L
.21445 .30902 L
.21558 .30902 L
.21679 .30902 L
.21793 .30902 L
.21902 .30902 L
.21999 .30902 L
.22104 .30902 L
.22228 .30902 L
.22341 .30902 L
.22472 .30902 L
.22595 .30902 L
.22709 .30902 L
.22815 .30902 L
.22931 .30902 L
.23054 .30902 L
.2318 .30902 L
.23243 .30902 L
.23313 .30902 L
.23388 .30902 L
.23458 .30902 L
.23523 .30902 L
.23592 .30902 L
.23657 .30902 L
.23728 .30902 L
.23856 .30902 L
.23982 .30902 L
.24097 .30902 L
.24216 .30902 L
.24328 .30902 L
.24451 .30902 L
.24583 .30902 L
.24649 .30902 L
.24721 .30902 L
.24852 .30902 L
.2498 .30902 L
.25098 .30902 L
.25167 .30902 L
.25243 .30902 L
.25313 .30902 L
.25379 .30902 L
Mistroke
.25502 .30902 L
.25633 .30902 L
.25764 .30902 L
.25838 .30902 L
.25905 .30902 L
.25984 .30902 L
.26059 .30902 L
.26128 .30902 L
.26203 .30902 L
.26325 .30902 L
.26437 .30902 L
.2656 .30902 L
.26689 .30902 L
.26802 .30902 L
.26907 .30902 L
.27022 .30902 L
.27145 .30902 L
.27215 .30902 L
.27279 .30902 L
.2735 .30902 L
.27425 .30902 L
.27551 .30902 L
.27622 .30902 L
.27689 .30902 L
.27814 .30902 L
.27928 .30902 L
.28059 .30902 L
.28183 .30902 L
.28304 .30902 L
.28372 .30902 L
.28437 .30902 L
.28566 .30902 L
.28639 .30902 L
.28706 .30902 L
.28818 .30902 L
.28941 .30902 L
.2907 .30902 L
.2919 .30902 L
.29258 .30902 L
.29332 .30902 L
.29402 .30902 L
.29467 .30902 L
.29589 .30902 L
.29719 .30902 L
.29786 .30902 L
.29858 .30902 L
.29988 .30902 L
.30068 .30902 L
.30143 .30902 L
.30211 .30902 L
Mistroke
.30285 .30902 L
.3035 .30902 L
.30418 .30902 L
.30541 .30902 L
.30672 .30902 L
.30747 .30902 L
.30817 .30902 L
.30943 .30902 L
.31058 .30902 L
.31122 .30902 L
.31191 .30902 L
.31317 .30902 L
.31429 .30902 L
.31553 .30902 L
.31682 .30902 L
.31804 .30902 L
.31909 .30902 L
.3202 .30902 L
.32142 .30902 L
.32253 .30902 L
.32385 .30902 L
.32504 .30902 L
.3257 .30902 L
.32642 .30902 L
.32772 .30902 L
.32894 .30902 L
.33023 .30902 L
.33134 .30902 L
.33255 .30902 L
.33328 .30902 L
.33398 .30902 L
.33528 .30902 L
.33601 .30902 L
.33668 .30902 L
.33742 .30902 L
.33821 .30902 L
.3389 .30902 L
.33964 .30902 L
.34034 .30902 L
.34099 .30902 L
.34221 .30902 L
.34351 .30902 L
.34473 .30902 L
.34542 .30902 L
.34606 .30902 L
.34724 .30902 L
.34848 .30902 L
.34959 .30902 L
.35064 .30902 L
.35178 .30902 L
Mistroke
.35301 .30902 L
.35431 .30902 L
.35505 .30902 L
.35574 .30902 L
.35699 .30902 L
.35769 .30902 L
.35833 .30902 L
.35953 .30902 L
.36083 .30902 L
.36206 .30902 L
.36319 .30902 L
.36425 .30902 L
.36539 .30902 L
.36646 .30902 L
.36744 .30902 L
.36859 .30902 L
.36984 .30902 L
.37102 .30902 L
.37211 .30902 L
.37323 .30902 L
.37428 .30902 L
.37543 .30902 L
.37668 .30902 L
.37799 .30902 L
.37922 .30902 L
.38043 .30902 L
.38154 .30902 L
.38268 .30902 L
.38393 .30902 L
.38517 .30902 L
.38649 .30902 L
.38762 .30902 L
.38868 .30902 L
.38984 .30902 L
.3911 .30902 L
.3918 .30902 L
.39245 .30902 L
.39373 .30902 L
.3949 .30902 L
.39614 .30902 L
.39684 .30902 L
.3976 .30902 L
.39832 .30902 L
.39898 .30902 L
.40024 .30902 L
.40087 .30902 L
.40156 .30902 L
.40224 .30902 L
.40298 .30902 L
.40367 .30902 L
Mistroke
.40432 .30902 L
.40553 .30902 L
.40683 .30902 L
.41247 .30902 L
.42265 .30902 L
.46043 .30902 L
.50066 .30902 L
.53938 .30902 L
.58054 .30902 L
.6202 .30902 L
.65833 .30902 L
.69892 .30902 L
.73799 .30902 L
.77952 .30902 L
.81953 .30902 L
.85802 .30902 L
.89897 .30902 L
.9384 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`8000000`1Vo`000000000500007c?o00030000<ol0<ol002dco`000`000?ooooooo`0]
oooo00<0003oooooool0;Oooo`030000oooooooo02koool00`000?ooooooo`0Eoooo000Poooo00<0
I_ooooooool01Oooo`H00019<ol000<0003oooooool0Y_ooo`008?ooo`0306Kooooooooo00_oool5
0000A3?o0080002Woooo000Poooo00<0I_ooooooool04?ooo`@00010<ol000<0003oooooool0Y_oo
o`008?ooo`0306Kooooooooo01Coool20000?S?o00030000oooooooo0:Koool0023oool00`1Voooo
ooooo`0Foooo0`0003/co`000`000?ooooooo`2Voooo000Poooo00<0I_ooooooool06Oooo`80000i
<ol00P000:Ooool0023oool00`1Vooooooooo`0Koooo0P0003Lco`000`000?ooooooo`2Voooo000P
oooo00<0I_ooooooool07Oooo`80000e<ol000<0003oooooool0Y_ooo`008?ooo`0306Kooooooooo
01ooool20000<c?o00030000oooooooo0:Koool0023oool00`1Vooooooooo`0Qoooo0P00034co`02
0000Yoooo`008?ooo`0306Kooooooooo02?oool00`0003?o03?o000^<ol000<0003oooooool0Y_oo
o`008?ooo`0306Kooooooooo02Coool00`0003?o03?o000]<ol000<0003oooooool0Y_ooo`008?oo
o`0306Kooooooooo02Goool00`0003?o03?o000/<ol000<0003oooooool0Y_ooo`008?ooo`0306Ko
oooooooo02Koool00`0003?o03?o000[<ol00P000:Ooool0023oool00`1Vooooooooo`0Woooo00<0
000co`0co`00:S?o00030000oooooooo0:Koool0023oool00`1Vooooooooo`0Xoooo00<0000co`0c
o`0043?o00800004<ol00P0000<co`0400000c?o00800005<ol000<0003oooooool0Y_ooo`008?oo
o`0306Kooooooooo02Woool00`0003?o03?o000><ol000@0000co`0co`000008<ol000<0000co`0c
o`000c?o00040000<ol0<ol0000013?o00030000oooooooo0:Koool0023oool00`1Vooooooooo`0Z
oooo00<0000co`0co`003C?o00040000<ol0<ol000002C?o00030000<ol0<ol000Dco`000`0003?o
03?o0002<ol00P000:Ooool0023oool00`1Vooooooooo`0[oooo00<0000co`0co`0033?o00040000
<ol0<ol000002S?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo0:Koool0023oool0
0`1Vooooooooo`0/oooo00<0000co`0co`002c?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000c?o00030000<ol0<ol000@co`000`000?ooooooo`2Voooo000Poooo00<0I_ooooooool0;?oo
o`030000<ol0<ol000`co`0200002S?o00800004<ol00`0000@co`000`000?ooooooo`2Voooo000P
oooo00<0I_ooooooool0;Oooo`030000<ol0<ol002@co`020000Yoooo`008?ooo`0306Kooooooooo
02koool00`0003?o03?o000S<ol000<0003oooooool0Y_ooo`008?ooo`0306Kooooooooo02ooool0
0`0003?o03?o000R<ol000<0003oooooool0Y_ooo`008?ooo`0306Kooooooooo02ooool00`0003?o
03?o000R<ol000<0003oooooool0Y_ooo`008?ooo`0306Kooooooooo033oool00`0003?o03?o000Q
<ol00P000:Ooool0023oool00`1Vooooooooo`0`oooo00<0000co`0co`008C?o00030000oooooooo
0:Koool0023oool00`1Vooooooooo`0aoooo00<0000co`0co`0083?o00030000oooooooo0:Koool0
023oool00`1Vooooooooo`0aoooo00<0000co`0co`0083?o00030000oooooooo0:Koool0023oool0
0`1Vooooooooo`0boooo00<0000co`0co`007c?o0080002Woooo000Poooo00<0I_ooooooool0<_oo
o`030000<ol0<ol001lco`000`000?ooooooo`2Voooo000Poooo00<0I_ooooooool0<oooo`030000
<ol0<ol001hco`000`000?ooooooo`2Voooo000Poooo00<0I_ooooooool0<oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Voooo000Poooo00<0I_ooooooool0=?ooo`030000<ol0<ol001dco`02
0000Yoooo`008?ooo`0306Kooooooooo03Coool00`0003?o03?o000M<ol000<0003oooooool0Y_oo
o`008?ooo`0306Kooooooooo03Goool00`0003?o03?o0009<ol00P0000@co`02000013?o00800005
<ol000<0003oooooool0Y_ooo`008?ooo`0306Kooooooooo03Goool00`0003?o03?o0008<ol000@0
000co`0co`000008<ol000@0000co`0co`000004<ol000<0003oooooool0Y_ooo`008?ooo`0306Ko
oooooooo03Koool00`0003?o03?o0007<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o
0080002Woooo000Poooo00<0I_ooooooool0=_ooo`030000<ol0<ol000Lco`00100003?o03?o0000
00Tco`0200001C?o00030000oooooooo0:Koool0023oool00`1Vooooooooo`0foooo00<0000co`0c
o`001c?o00040000<ol0<ol000002C?o00030000<ol0<ol000@co`000`000?ooooooo`2Voooo000P
oooo00<0I_ooooooool0=oooo`030000<ol0<ol000Lco`0200002S?o00<00004<ol000<0003ooooo
ool0Y_ooo`008?ooo`0306Kooooooooo03Ooool00`0003?o03?o000J<ol00P000:Ooool0023oool0
0`1Vooooooooo`0goooo00<0000co`0co`006S?o00030000oooooooo0:Koool001ooool206Ko>_oo
o`030000<ol0<ol001Tco`000`000?ooooooo`2Voooo000Koooo101Vo`03ooooo`2Ioooo03Woool0
0`0003?o03?o000I<ol00P000:Ooool001Koool506Ko1Oooo`03o`2Ioooooooo03Soool00`0003?o
03?o000I<ol000<0003oooooool0Y_ooo`008?ooo`03o`2Ioooooooo03Woool00`0003?o03?o000H
<ol000<0003oooooool0Y_ooo`008?ooo`03o`2Ioooooooo03Woool00`0003?o03?o000H<ol000<0
003oooooool0Y_ooo`008?ooo`03o`2Ioooooooo03Woool00`0003?o03?o000H<ol00P000:Ooool0
023oool00ol0VOooooooo`0joooo00<0000co`0co`005c?o00030000oooooooo0:Koool0023oool0
0ol0VOooooooo`0joooo00<0000co`0co`005c?o00030000oooooooo0:Koool0023oool00ol0VOoo
ooooo`0joooo00<0000co`0co`005c?o00030000oooooooo0:Koool0023oool00ol0VOooooooo`0k
oooo00<0000co`0co`005S?o0080002Woooo000Poooo00?o09Woooooool0>oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`2Voooo000Poooo00?o09Woooooool0>oooo`800004<ol00P0000Dco`00
0`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`2Voooo000Poooo00?o09Woooooool0>_oo
o`040000oooo000000002S?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0
003oooooool0Y_ooo`008?ooo`03o`2Ioooooooo03[oool010000?ooo`00000000Xco`000`0003?o
03?o0004<ol000<0000co`0co`000S?o0080002Woooo000Poooo00?o09Woooooool0>_ooo`040000
oooo000000002c?o00040000<ol0<ol0<ol00P0000Dco`000`000?ooooooo`2Voooo000Poooo00?o
09Woooooool0>_ooo`040000oooooooo000023?o00040000<ol0<ol000000c?o00030000<ol0<ol0
00@co`000`000?ooooooo`2Voooo000Poooo00?o09Woooooool0>oooo`<00008<ol0100000<co`03
000013?o00030000oooooooo0:Koool0023oool00ol0VOooooooo`0moooo00<0000co`0co`0053?o
0080002Woooo000Poooo00?o09Woooooool0?Oooo`030000<ol0<ol001@co`000`000?ooooooo`2V
oooo000Poooo00?o09Woooooool0?_ooo`030000<ol0<ol001<co`000`000?ooooooo`2Voooo000P
oooo00?o09Woooooool0?_ooo`030000<ol0<ol001<co`000`000?ooooooo`2Voooo000Poooo00?o
09Woooooool0?_ooo`030000<ol0<ol001<co`020000Yoooo`008?ooo`03o`2Ioooooooo03koool0
0`0003?o03?o000C<ol000<0003oooooool0Y_ooo`008?ooo`03o`2Ioooooooo03ooool00`0003?o
03?o000B<ol000<0003oooooool0Y_ooo`008?ooo`03o`2Ioooooooo03ooool00`0003?o03?o000B
<ol000<0003oooooool0Y_ooo`008?ooo`03o`2Ioooooooo03ooool00`0003?o03?o000B<ol00P00
0:Ooool0023oool00ol0VOooooooo`0ooooo00<0000co`0co`004S?o00030000oooooooo0:Koool0
023oool00ol0VOooooooo`10oooo00<0000co`0co`004C?o00030000oooooooo0:Koool0023oool0
0ol0VOooooooo`10oooo00<0000co`0co`004C?o00030000oooooooo0:Koool0023oool00ol0VOoo
ooooo`10oooo00<0000co`0co`004C?o0080002Woooo000Poooo00?o09Woooooool0@?ooo`030000
<ol0<ol0014co`000`000?ooooooo`2Voooo000Poooo00?o09Woooooool0@?ooo`030000<ol0<ol0
00Tco`0500000c?o00030000oooooooo0:Koool0023oool00ol0VOooooooo`11oooo00<0000co`0c
o`002S?o00030000<ol0<ol000<co`000`000?ooooooo`2Voooo000Poooo00?o09Woooooool0@Ooo
o`030000<ol0<ol000Xco`000`0003?o03?o0003<ol00P000:Ooool006Coool=<ol000<0000co`0c
o`000c?o0:Woool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool<<ol00P0000Dco`2Y
oooo001Uoooo4S?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`02oooo00<0003oooooool0:?oo
o`030000oooooooo07Woool006GooolB<ol000?oool0003oool02Oooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001Uoooo4S?o0003oooo0000oooo00?oool200001?ooo`030000oooooooo
00coool400000oooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001Uoooo4S?o0003oooo
0000oooo00;oool010000?ooooooo`0000Coool00`000?ooooooo`04oooo100000?oool00`000?oo
ooooo`09oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00IOoooa8co`000`000?oo
ooooo`02oooo00<0003oooooool05?ooo`030000oooooooo00Soool010000?ooooooo`0000Coool0
0`000?ooooooo`1goooo001Voooo4C?o0004oooo0000oooooooo1@0001Coool00`000?ooooooo`08
oooo0P0000Coool00`000?ooooooo`1hoooo001Voooo4C?o0003oooo0000oooo00;oool00`000?oo
ooooo`0Coooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00I_oooa4co`02oooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1i
oooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.06747 .30902 L
.07286 .30902 L
.07547 .30902 L
.07793 .30902 L
.07901 .30902 L
.08015 .30902 L
s
.08015 .30902 m
.08027 .61803 L
s
0 .4 1 r
.02381 .50208 m
.04262 .4983 L
.06244 .49372 L
.06747 .49245 L
.07286 .49104 L
.07547 .49034 L
.07793 .48966 L
.07901 .48936 L
.08015 .48904 L
.0814 .30902 L
.08255 .30902 L
.08381 .30902 L
.08452 .30902 L
.08515 .30902 L
.08591 .30902 L
.08663 .30902 L
.08728 .30902 L
.08799 .30902 L
.0893 .30902 L
.08996 .30902 L
.09069 .30902 L
.09197 .30902 L
.09317 .30902 L
.09394 .30902 L
.09467 .30902 L
.09533 .30902 L
.09604 .30902 L
.09682 .30902 L
.09764 .30902 L
.09835 .30902 L
.09913 .30902 L
.09983 .30902 L
.10048 .30902 L
.10119 .30902 L
.10194 .30902 L
.1032 .30902 L
.10391 .30902 L
.10458 .30902 L
.1058 .30902 L
.10649 .30902 L
.10713 .30902 L
.10829 .30902 L
.10953 .30902 L
.11063 .30902 L
.11167 .30902 L
.1128 .30902 L
.11402 .30902 L
.11532 .30902 L
.11605 .30902 L
.11673 .30902 L
Mistroke
.11797 .30902 L
.11867 .30902 L
.1193 .30902 L
.12049 .30902 L
.12178 .30902 L
.12299 .30902 L
.12411 .30902 L
.12518 .30902 L
.12633 .30902 L
.1276 .30902 L
.12876 .30902 L
.12996 .30902 L
.13127 .30902 L
.13251 .30902 L
.13365 .30902 L
.1347 .30902 L
.13567 .30902 L
.13675 .30902 L
.1379 .30902 L
.13905 .30902 L
.14026 .30902 L
.14129 .30902 L
.14241 .30902 L
.14306 .30902 L
.14374 .30902 L
.14496 .30902 L
.14627 .30902 L
.14702 .30902 L
.14772 .30902 L
.14898 .30902 L
.15013 .30902 L
.15076 .30902 L
.15146 .30902 L
.15272 .30902 L
.15383 .30902 L
.15507 .30902 L
.15636 .30902 L
.15757 .30902 L
.1587 .30902 L
.15973 .30902 L
.16087 .30902 L
.16206 .30902 L
.16335 .30902 L
.16457 .30902 L
.16524 .30902 L
.16597 .30902 L
.16725 .30902 L
.16846 .30902 L
.16976 .30902 L
.17086 .30902 L
Mistroke
.17207 .30902 L
.1728 .30902 L
.1735 .30902 L
.1748 .30902 L
.17553 .30902 L
.1762 .30902 L
.17694 .30902 L
.17773 .30902 L
.17842 .30902 L
.17916 .30902 L
.17986 .30902 L
.18051 .30902 L
.18173 .30902 L
.18303 .30902 L
.18425 .30902 L
.18494 .30902 L
.18558 .30902 L
.18675 .30902 L
.18799 .30902 L
.1891 .30902 L
.19014 .30902 L
.19128 .30902 L
.19252 .30902 L
.19375 .30902 L
.19445 .30902 L
.1951 .30902 L
.19642 .30902 L
.19715 .30902 L
.19782 .30902 L
.19902 .30902 L
.20032 .30902 L
.20155 .30902 L
.20268 .30902 L
.20373 .30902 L
.20473 .30902 L
.20588 .30902 L
.20693 .30902 L
.20808 .30902 L
.20934 .30902 L
.21051 .30902 L
.21159 .30902 L
.21283 .30902 L
.21399 .30902 L
.21503 .30902 L
.21616 .30902 L
.21739 .30902 L
.21869 .30902 L
.2198 .30902 L
.22102 .30902 L
.22233 .30902 L
Mistroke
.22354 .30902 L
.22418 .30902 L
.22487 .30902 L
.2256 .30902 L
.22628 .30902 L
.22754 .30902 L
.22868 .30902 L
.23 .30902 L
.23126 .30902 L
.23238 .30902 L
.23357 .30902 L
.2347 .30902 L
.23572 .30902 L
.23692 .30902 L
.23822 .30902 L
.23945 .30902 L
.24058 .30902 L
.24179 .30902 L
.24309 .30902 L
.24432 .30902 L
.24543 .30902 L
.24674 .30902 L
.24748 .30902 L
.24817 .30902 L
.24943 .30902 L
.25006 .30902 L
.25076 .30902 L
.25144 .30902 L
.25215 .30902 L
.25343 .30902 L
.25409 .30902 L
.2548 .30902 L
.25558 .30902 L
.25631 .30902 L
.25698 .30902 L
.25771 .30902 L
.2584 .30902 L
.25904 .30902 L
.26024 .30902 L
.26152 .30902 L
.26273 .30902 L
.26404 .30902 L
.26521 .30902 L
.26644 .30902 L
.26767 .30902 L
.26878 .30902 L
.2699 .30902 L
.27095 .30902 L
.27218 .30902 L
.27348 .30902 L
Mistroke
.2746 .30902 L
.27582 .30902 L
.27713 .30902 L
.27787 .30902 L
.27854 .30902 L
.27985 .30902 L
.28108 .30902 L
.28213 .30902 L
.28329 .30902 L
.2845 .30902 L
.28564 .30902 L
.2867 .30902 L
.28767 .30902 L
.28874 .30902 L
.28986 .30902 L
.291 .30902 L
.29222 .30902 L
.29337 .30902 L
.29441 .30902 L
.29564 .30902 L
.29634 .30902 L
.29697 .30902 L
.29815 .30902 L
.29939 .30902 L
.30061 .30902 L
.30193 .30902 L
.30318 .30902 L
.30433 .30902 L
.30537 .30902 L
.30652 .30902 L
.30772 .30902 L
.30885 .30902 L
.31008 .30902 L
.31122 .30902 L
.31242 .30902 L
.31373 .30902 L
.31442 .30902 L
.31506 .30902 L
.31578 .30902 L
.31647 .30902 L
.31768 .30902 L
.319 .30902 L
.32013 .30902 L
.3212 .30902 L
.32236 .30902 L
.32362 .30902 L
.32493 .30902 L
.32618 .30902 L
.32732 .30902 L
.32852 .30902 L
Mistroke
.32967 .30902 L
.3307 .30902 L
.33175 .30902 L
.33273 .30902 L
.33388 .30902 L
.33493 .30902 L
.33609 .30902 L
.33732 .30902 L
.33854 .30902 L
.33923 .30902 L
.33987 .30902 L
.34104 .30902 L
.34228 .30902 L
.34339 .30902 L
.34443 .30902 L
.34557 .30902 L
.3468 .30902 L
.34803 .30902 L
.34873 .30902 L
.34938 .30902 L
.3507 .30902 L
.35143 .30902 L
.3521 .30902 L
.3533 .30902 L
.3546 .30902 L
.35583 .30902 L
.35696 .30902 L
.35802 .30902 L
.35915 .30902 L
.36023 .30902 L
.3612 .30902 L
.36235 .30902 L
.3636 .30902 L
.36478 .30902 L
.36587 .30902 L
.3671 .30902 L
.36827 .30902 L
.36931 .30902 L
.37044 .30902 L
.37167 .30902 L
.37297 .30902 L
.37408 .30902 L
.3753 .30902 L
.37661 .30902 L
.37782 .30902 L
.37845 .30902 L
.37915 .30902 L
.37988 .30902 L
.38056 .30902 L
.38181 .30902 L
Mistroke
.38295 .30902 L
.38428 .30902 L
.38553 .30902 L
.38665 .30902 L
.38784 .30902 L
.38897 .30902 L
.38999 .30902 L
.39119 .30902 L
.39249 .30902 L
.39372 .30902 L
.39485 .30902 L
.39606 .30902 L
.39736 .30902 L
.39858 .30902 L
.3997 .30902 L
.40101 .30902 L
.40175 .30902 L
.40243 .30902 L
.40369 .30902 L
.40433 .30902 L
.40503 .30902 L
.4057 .30902 L
.40642 .30902 L
.40769 .30902 L
.41057 .30902 L
.41578 .30902 L
.45387 .30902 L
.4944 .30902 L
.53342 .30902 L
.5749 .30902 L
.61485 .30902 L
.65329 .30902 L
.69419 .30902 L
.73357 .30902 L
.77143 .30902 L
.81174 .30902 L
.85054 .30902 L
.8918 .30902 L
.93153 .30902 L
.96975 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0002<ol000<0I_lco`0co`000S?o00030000<ol0<ol000Hco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0003oooooool01_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo00Goool7000000<0I_l0000000007c?o00030000<ol0<ol002dco`00
0`000?ooooooo`0]oooo00<0003oooooool0;Oooo`030000oooooooo02koool00`000?ooooooo`0E
oooo000Uoooo00<0I_ooooooool01P0004Tco`000`000?ooooooo`2Voooo000Uoooo00<0I_oooooo
ool01_ooo`D00014<ol00P000:Ooool002Goool00`1Vooooooooo`0;oooo1000040co`000`000?oo
ooooo`2Voooo000Uoooo00<0I_ooooooool03oooo`80000n<ol000<0003oooooool0Y_ooo`009Ooo
o`0306Kooooooooo017oool30000>c?o00030000oooooooo0:Koool002Goool00`1Vooooooooo`0D
oooo0P0003Tco`020000Yoooo`009Oooo`0306Kooooooooo01Koool20000=c?o00030000oooooooo
0:Koool002Goool00`1Vooooooooo`0Hoooo0P0003Dco`000`000?ooooooo`2Voooo000Uoooo00<0
I_ooooooool06_ooo`80000c<ol000<0003oooooool0Y_ooo`009Oooo`0306Kooooooooo01coool2
0000<C?o0080002Woooo000Uoooo00<0I_ooooooool07_ooo`030000<ol0<ol002hco`000`000?oo
ooooo`2Voooo000Uoooo00<0I_ooooooool07oooo`030000<ol0<ol002dco`000`000?ooooooo`2V
oooo000Uoooo00<0I_ooooooool08?ooo`030000<ol0<ol002`co`000`000?ooooooo`2Voooo000U
oooo00<0I_ooooooool08Oooo`030000<ol0<ol002/co`020000Yoooo`009Oooo`0306Kooooooooo
02;oool00`0003?o03?o000Z<ol000<0003oooooool0Y_ooo`009Oooo`0306Kooooooooo02?oool0
0`0003?o03?o000@<ol00P0000@co`0200000c?o00@00003<ol00P0000Dco`000`000?ooooooo`2V
oooo000Uoooo00<0I_ooooooool09?ooo`030000<ol0<ol000hco`00100003?o03?o000000Pco`00
0`0003?o03?o0003<ol000@0000co`0co`000004<ol000<0003oooooool0Y_ooo`009Oooo`0306Ko
oooooooo02Goool00`0003?o03?o000=<ol000@0000co`0co`000009<ol000<0000co`0co`001C?o
00030000<ol0<ol0008co`020000Yoooo`009Oooo`0306Kooooooooo02Koool00`0003?o03?o000<
<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Y_oo
o`009Oooo`0306Kooooooooo02Ooool00`0003?o03?o000;<ol000@0000co`0co`000008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo0:Koool002Goool00`1Voooo
ooooo`0Woooo00<0000co`0co`0033?o0080000:<ol00P0000@co`03000013?o00030000oooooooo
0:Koool002Goool00`1Vooooooooo`0Xoooo00<0000co`0co`0093?o0080002Woooo000Uoooo00<0
I_ooooooool0:Oooo`030000<ol0<ol002<co`000`000?ooooooo`2Voooo000Uoooo00<0I_oooooo
ool0:_ooo`030000<ol0<ol0028co`000`000?ooooooo`2Voooo000Uoooo00<0I_ooooooool0:_oo
o`030000<ol0<ol0028co`000`000?ooooooo`2Voooo000Uoooo00<0I_ooooooool0:oooo`030000
<ol0<ol0024co`020000Yoooo`009Oooo`0306Kooooooooo02_oool00`0003?o03?o000Q<ol000<0
003oooooool0Y_ooo`009Oooo`0306Kooooooooo02coool00`0003?o03?o000P<ol000<0003ooooo
ool0Y_ooo`009Oooo`0306Kooooooooo02coool00`0003?o03?o000P<ol000<0003oooooool0Y_oo
o`009Oooo`0306Kooooooooo02goool00`0003?o03?o000O<ol00P000:Ooool002Goool00`1Voooo
ooooo`0]oooo00<0000co`0co`007c?o00030000oooooooo0:Koool002Goool00`1Vooooooooo`0^
oooo00<0000co`0co`007S?o00030000oooooooo0:Koool002Goool00`1Vooooooooo`0^oooo00<0
000co`0co`007S?o00030000oooooooo0:Koool002Goool00`1Vooooooooo`0_oooo00<0000co`0c
o`007C?o0080002Woooo000Uoooo00<0I_ooooooool0;oooo`030000<ol0<ol001dco`000`000?oo
ooooo`2Voooo000Uoooo00<0I_ooooooool0<?ooo`030000<ol0<ol000Tco`02000013?o00800004
<ol00P0000Dco`000`000?ooooooo`2Voooo000Uoooo00<0I_ooooooool0<?ooo`030000<ol0<ol0
00Pco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`2Voooo000U
oooo00<0I_ooooooool0<Oooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`000`0003?o
03?o0002<ol00P000:Ooool002Goool00`1Vooooooooo`0aoooo00<0000co`0co`001c?o00040000
<ol0<ol000002C?o00800005<ol000<0003oooooool0Y_ooo`009Oooo`0306Kooooooooo037oool0
0`0003?o03?o0007<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000oooooooo
0:Koool002Goool00`1Vooooooooo`0boooo00<0000co`0co`001c?o0080000:<ol00`0000@co`00
0`000?ooooooo`2Voooo000Uoooo00<0I_ooooooool0<_ooo`030000<ol0<ol001Xco`020000Yooo
o`009Oooo`0306Kooooooooo03;oool00`0003?o03?o000J<ol000<0003oooooool0Y_ooo`008ooo
o`<0I_leoooo00<0000co`0co`006C?o00030000oooooooo0:Koool001koool606Ko00?ooooo09Wo
ool0=?ooo`030000<ol0<ol001Tco`020000Yoooo`006Oooo`D0I_l7oooo00?o09Woooooool0<ooo
o`030000<ol0<ol001Tco`000`000?ooooooo`2Voooo000Foooo0`1Vo`coool00ol0VOooooooo`0d
oooo00<0000co`0co`0063?o00030000oooooooo0:Koool002Goool00ol0VOooooooo`0doooo00<0
000co`0co`0063?o00030000oooooooo0:Koool002Goool00ol0VOooooooo`0doooo00<0000co`0c
o`0063?o0080002Woooo000Uoooo00?o09Woooooool0=Oooo`030000<ol0<ol001Lco`000`000?oo
ooooo`2Voooo000Uoooo00?o09Woooooool0=Oooo`030000<ol0<ol001Lco`000`000?ooooooo`2V
oooo000Uoooo00?o09Woooooool0=Oooo`030000<ol0<ol001Lco`000`000?ooooooo`2Voooo000U
oooo00?o09Woooooool0=_ooo`030000<ol0<ol001Hco`020000Yoooo`009Oooo`03o`2Ioooooooo
03Koool00`0003?o03?o000F<ol000<0003oooooool0Y_ooo`009Oooo`03o`2Ioooooooo03Koool2
000013?o00800005<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Y_ooo`009Ooo
o`03o`2Ioooooooo03Goool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0
000co`0co`000S?o00030000oooooooo0:Koool002Goool00ol0VOooooooo`0eoooo00@0003oool0
0000000:<ol000<0000co`0co`0013?o00030000<ol0<ol0008co`020000Yoooo`009Oooo`03o`2I
oooooooo03Goool010000?ooo`00000000/co`00100003?o03?o03?o00800005<ol000<0003ooooo
ool0Y_ooo`009Oooo`03o`2Ioooooooo03Goool010000?ooooooo`0000Pco`00100003?o03?o0000
00<co`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`009Oooo`03o`2Ioooooooo03Koool3
000023?o00@00003<ol00`0000@co`000`000?ooooooo`2Voooo000Uoooo00?o09Woooooool0>?oo
o`030000<ol0<ol001@co`020000Yoooo`009Oooo`03o`2Ioooooooo03Soool00`0003?o03?o000D
<ol000<0003oooooool0Y_ooo`009Oooo`03o`2Ioooooooo03Woool00`0003?o03?o000C<ol000<0
003oooooool0Y_ooo`009Oooo`03o`2Ioooooooo03Woool00`0003?o03?o000C<ol000<0003ooooo
ool0Y_ooo`009Oooo`03o`2Ioooooooo03Woool00`0003?o03?o000C<ol00P000:Ooool002Goool0
0ol0VOooooooo`0ioooo00<0000co`0co`004c?o00030000oooooooo0:Koool002Goool00ol0VOoo
ooooo`0joooo00<0000co`0co`004S?o00030000oooooooo0:Koool002Goool00ol0VOooooooo`0j
oooo00<0000co`0co`004S?o00030000oooooooo0:Koool002Goool00ol0VOooooooo`0joooo00<0
000co`0co`004S?o0080002Woooo000Uoooo00?o09Woooooool0>_ooo`030000<ol0<ol0018co`00
0`000?ooooooo`2Voooo000Uoooo00?o09Woooooool0>oooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Voooo000Uoooo00?o09Woooooool0>oooo`030000<ol0<ol0014co`000`000?ooooooo`2V
oooo000Uoooo00?o09Woooooool0>oooo`030000<ol0<ol0014co`020000Yoooo`009Oooo`03o`2I
oooooooo03_oool00`0003?o03?o000A<ol000<0003oooooool0Y_ooo`009Oooo`03o`2Ioooooooo
03_oool00`0003?o03?o0009<ol01@0000<co`000`000?ooooooo`2Voooo000Uoooo00?o09Wooooo
ool0??ooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003oooooool0Y_ooo`009Ooo
o`03o`2Ioooooooo03coool00`0003?o03?o000:<ol000<0000co`0co`000c?o0080002Woooo001T
oooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001T
oooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol00_oo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Uoooo4S?o0003oooo0000oooo00Woool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`03oooo0P00
00Coool00`000?ooooooo`0<oooo100000?oool200001Oooo`030000oooooooo00;oool00`000?oo
ooooo`1hoooo001Uoooo4S?o0003oooo0000oooo00;oool010000?ooooooo`0000Coool00`000?oo
ooooo`04oooo100000?oool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo
07Soool006GooolB<ol000<0003oooooool00_ooo`030000oooooooo01Coool00`000?ooooooo`0:
oooo00<0003oooooool00oooo`030000oooooooo07Ooool006KooolA<ol000Coool0003oooooool5
00005?ooo`030000oooooooo00[oool01@000?ooooooooooo`00001joooo001Voooo4C?o0003oooo
0000oooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00I_oooa4co`02oooo00<0003oooooool05oooo`800009oooo1000
00;oool00`000?ooooooo`1ioooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.04262 .30902 L
.06244 .30902 L
.08255 .30902 L
.08806 .30902 L
.09396 .30902 L
.09682 .30902 L
.09822 .30902 L
.09952 .30902 L
s
.09952 .30902 m
.09964 .61803 L
s
0 .4 1 r
.02381 .50514 m
.04262 .50182 L
.06244 .4978 L
.08255 .49309 L
.08806 .49167 L
.09396 .4901 L
.09682 .48931 L
.09822 .48891 L
.09952 .48854 L
.1007 .30902 L
.10195 .30902 L
.1032 .30902 L
.10391 .30902 L
.10458 .30902 L
.10583 .30902 L
.10652 .30902 L
.10715 .30902 L
.10838 .30902 L
.10954 .30902 L
.1102 .30902 L
.1109 .30902 L
.11214 .30902 L
.11284 .30902 L
.11349 .30902 L
.1142 .30902 L
.11496 .30902 L
.11623 .30902 L
.11695 .30902 L
.11761 .30902 L
.11883 .30902 L
.12012 .30902 L
.12122 .30902 L
.12239 .30902 L
.12366 .30902 L
.12483 .30902 L
.12595 .30902 L
.127 .30902 L
.12814 .30902 L
.12937 .30902 L
.13052 .30902 L
.1316 .30902 L
.13258 .30902 L
.13363 .30902 L
.1348 .30902 L
.13609 .30902 L
.13674 .30902 L
.13743 .30902 L
.13869 .30902 L
.13994 .30902 L
.14113 .30902 L
Mistroke
.14219 .30902 L
.14335 .30902 L
.144 .30902 L
.14469 .30902 L
.14591 .30902 L
.14723 .30902 L
.14798 .30902 L
.14868 .30902 L
.14995 .30902 L
.1511 .30902 L
.15174 .30902 L
.15244 .30902 L
.1537 .30902 L
.15482 .30902 L
.15606 .30902 L
.15735 .30902 L
.15856 .30902 L
.1597 .30902 L
.16073 .30902 L
.16187 .30902 L
.16306 .30902 L
.16438 .30902 L
.16558 .30902 L
.16624 .30902 L
.16696 .30902 L
.16826 .30902 L
.16948 .30902 L
.17078 .30902 L
.17188 .30902 L
.17309 .30902 L
.17383 .30902 L
.17452 .30902 L
.17583 .30902 L
.17655 .30902 L
.17723 .30902 L
.17797 .30902 L
.17876 .30902 L
.18005 .30902 L
.18127 .30902 L
.18197 .30902 L
.18261 .30902 L
.18331 .30902 L
.18405 .30902 L
.18528 .30902 L
.18597 .30902 L
.18662 .30902 L
.18779 .30902 L
.18904 .30902 L
.19016 .30902 L
.1912 .30902 L
Mistroke
.19235 .30902 L
.19358 .30902 L
.19479 .30902 L
.19608 .30902 L
.19682 .30902 L
.19749 .30902 L
.1988 .30902 L
.20003 .30902 L
.20072 .30902 L
.20136 .30902 L
.20253 .30902 L
.20377 .30902 L
.20491 .30902 L
.20613 .30902 L
.20729 .30902 L
.20834 .30902 L
.20957 .30902 L
.21027 .30902 L
.21092 .30902 L
.2121 .30902 L
.21336 .30902 L
.21439 .30902 L
.21551 .30902 L
.21656 .30902 L
.21753 .30902 L
.2186 .30902 L
.21977 .30902 L
.22099 .30902 L
.22213 .30902 L
.2234 .30902 L
.22405 .30902 L
.22476 .30902 L
.22601 .30902 L
.22718 .30902 L
.22789 .30902 L
.22856 .30902 L
.22982 .30902 L
.23053 .30902 L
.23118 .30902 L
.2319 .30902 L
.23266 .30902 L
.23395 .30902 L
.23468 .30902 L
.23535 .30902 L
.23658 .30902 L
.23788 .30902 L
.23904 .30902 L
.24013 .30902 L
.24132 .30902 L
.2426 .30902 L
Mistroke
.24384 .30902 L
.245 .30902 L
.24626 .30902 L
.2469 .30902 L
.2476 .30902 L
.24878 .30902 L
.25004 .30902 L
.25124 .30902 L
.25233 .30902 L
.25346 .30902 L
.2545 .30902 L
.25565 .30902 L
.25687 .30902 L
.25804 .30902 L
.25914 .30902 L
.26012 .30902 L
.26119 .30902 L
.26243 .30902 L
.26356 .30902 L
.26478 .30902 L
.26547 .30902 L
.2661 .30902 L
.26724 .30902 L
.26846 .30902 L
.26952 .30902 L
.27069 .30902 L
.27135 .30902 L
.27204 .30902 L
.27328 .30902 L
.27397 .30902 L
.27461 .30902 L
.27532 .30902 L
.27607 .30902 L
.27672 .30902 L
.27743 .30902 L
.27871 .30902 L
.27987 .30902 L
.28112 .30902 L
.28243 .30902 L
.28365 .30902 L
.2844 .30902 L
.28511 .30902 L
.28575 .30902 L
.28644 .30902 L
.28718 .30902 L
.28786 .30902 L
.28863 .30902 L
.28936 .30902 L
.29067 .30902 L
.2914 .30902 L
Mistroke
.29208 .30902 L
.29329 .30902 L
.29442 .30902 L
.29566 .30902 L
.29636 .30902 L
.29699 .30902 L
.29827 .30902 L
.29899 .30902 L
.29966 .30902 L
.30088 .30902 L
.30218 .30902 L
.30332 .30902 L
.30457 .30902 L
.30587 .30902 L
.30708 .30902 L
.30819 .30902 L
.30939 .30902 L
.31053 .30902 L
.31157 .30902 L
.31282 .30902 L
.31413 .30902 L
.31524 .30902 L
.31646 .30902 L
.31776 .30902 L
.31849 .30902 L
.31916 .30902 L
.32046 .30902 L
.32168 .30902 L
.32273 .30902 L
.32389 .30902 L
.32509 .30902 L
.32623 .30902 L
.32728 .30902 L
.32825 .30902 L
.32932 .30902 L
.33044 .30902 L
.33158 .30902 L
.33279 .30902 L
.33394 .30902 L
.33499 .30902 L
.33622 .30902 L
.33691 .30902 L
.33755 .30902 L
.33873 .30902 L
.33997 .30902 L
.34118 .30902 L
.34249 .30902 L
.34374 .30902 L
.34489 .30902 L
.34603 .30902 L
Mistroke
.34707 .30902 L
.34826 .30902 L
.34939 .30902 L
.35062 .30902 L
.35192 .30902 L
.35303 .30902 L
.35425 .30902 L
.35556 .30902 L
.3563 .30902 L
.35697 .30902 L
.35828 .30902 L
.35951 .30902 L
.36056 .30902 L
.36172 .30902 L
.36293 .30902 L
.36407 .30902 L
.36512 .30902 L
.36609 .30902 L
.36716 .30902 L
.36828 .30902 L
.36942 .30902 L
.37064 .30902 L
.37179 .30902 L
.37283 .30902 L
.37406 .30902 L
.37476 .30902 L
.3754 .30902 L
.37657 .30902 L
.37781 .30902 L
.37903 .30902 L
.38035 .30902 L
.38159 .30902 L
.38275 .30902 L
.38389 .30902 L
.38493 .30902 L
.38613 .30902 L
.38725 .30902 L
.38849 .30902 L
.3898 .30902 L
.39091 .30902 L
.39213 .30902 L
.39345 .30902 L
.39418 .30902 L
.39485 .30902 L
.39616 .30902 L
.39739 .30902 L
.39845 .30902 L
.39961 .30902 L
.40082 .30902 L
.40196 .30902 L
Mistroke
.40302 .30902 L
.40399 .30902 L
.40511 .30902 L
.40617 .30902 L
.41571 .30902 L
.45388 .30902 L
.4945 .30902 L
.5336 .30902 L
.57516 .30902 L
.6152 .30902 L
.65373 .30902 L
.69471 .30902 L
.73417 .30902 L
.77212 .30902 L
.81252 .30902 L
.8514 .30902 L
.89274 .30902 L
.93256 .30902 L
.97086 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0006<ol000?o09T0000co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X000000c?o0?l0V@1Vo`0L<ol000<0000co`0co`00;C?o00030000oooooooo02goool0
0`000?ooooooo`0]oooo00<0003oooooool0;_ooo`030000oooooooo01Goool002Soool00`000?l0
V@1Vo`030000BC?o00030000oooooooo0:Koool002Woool00ol0V@1Vooooo`02oooo1@0004@co`02
0000Yoooo`00:Oooo`03o`2I06Kooooo00Ooool40000@3?o00030000oooooooo0:Koool002Woool0
0ol0V@1Vooooo`0;oooo0P0003hco`000`000?ooooooo`2Voooo000Yoooo00?o09T0I_ooool03Ooo
o`<0000k<ol000<0003oooooool0Y_ooo`00:Oooo`03o`2I06Kooooo013oool20000>C?o0080002W
oooo000Yoooo00?o09T0I_ooool04_ooo`80000g<ol000<0003oooooool0Y_ooo`00:Oooo`03o`2I
06Kooooo01Coool20000=C?o00030000oooooooo0:Koool002Woool00ol0V@1Vooooo`0Foooo0P00
03<co`000`000?ooooooo`2Voooo000Yoooo00?o09T0I_ooool06?ooo`80000a<ol00P000:Ooool0
02Woool00ol0V@1Vooooo`0Joooo00<0000co`0co`00;S?o00030000oooooooo0:Koool002Woool0
0ol0V@1Vooooo`0Koooo00<0000co`0co`00;C?o00030000oooooooo0:Koool002Woool00ol0V@1V
ooooo`0Loooo00<0000co`0co`00;3?o00030000oooooooo0:Koool002Woool00ol0V@1Vooooo`0M
oooo00<0000co`0co`00:c?o0080002Woooo000Yoooo00?o09T0I_ooool07_ooo`030000<ol0<ol0
02Xco`000`000?ooooooo`2Voooo000Yoooo00?o09T0I_ooool07oooo`030000<ol0<ol0010co`02
000013?o00800003<ol0100000<co`0200001C?o00030000oooooooo0:Koool002Woool00ol0V@1V
ooooo`0Poooo00<0000co`0co`003S?o00040000<ol0<ol0000023?o00030000<ol0<ol000<co`00
100003?o03?o000000@co`000`000?ooooooo`2Voooo000Yoooo00?o09T0I_ooool08Oooo`030000
<ol0<ol000dco`00100003?o03?o000000Tco`000`0003?o03?o0005<ol000<0000co`0co`000S?o
0080002Woooo000Yoooo00?o09T0I_ooool08_ooo`030000<ol0<ol000`co`00100003?o03?o0000
00Xco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`2Voooo000Yoooo00?o09T0I_oo
ool08oooo`030000<ol0<ol000/co`00100003?o03?o000000Pco`00100003?o03?o000000<co`00
0`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00:Oooo`0306Kooooooooo02?oool00`0003?o
03?o000<<ol00P0000Xco`02000013?o00<00004<ol000<0003oooooool0Y_ooo`00:Oooo`0306Ko
oooooooo02Coool00`0003?o03?o000T<ol00P000:Ooool002Woool00`1Vooooooooo`0Uoooo00<0
000co`0co`008c?o00030000oooooooo0:Koool002Woool00`1Vooooooooo`0Voooo00<0000co`0c
o`008S?o00030000oooooooo0:Koool002Woool00`1Vooooooooo`0Voooo00<0000co`0co`008S?o
00030000oooooooo0:Koool002Woool00`1Vooooooooo`0Woooo00<0000co`0co`008C?o0080002W
oooo000Yoooo00<0I_ooooooool09oooo`030000<ol0<ol0024co`000`000?ooooooo`2Voooo000Y
oooo00<0I_ooooooool0:?ooo`030000<ol0<ol0020co`000`000?ooooooo`2Voooo000Yoooo00<0
I_ooooooool0:?ooo`030000<ol0<ol0020co`000`000?ooooooo`2Voooo000Yoooo00<0I_oooooo
ool0:Oooo`030000<ol0<ol001lco`020000Yoooo`00:Oooo`0306Kooooooooo02Woool00`0003?o
03?o000O<ol000<0003oooooool0Y_ooo`00:Oooo`0306Kooooooooo02[oool00`0003?o03?o000N
<ol000<0003oooooool0Y_ooo`00:Oooo`0306Kooooooooo02[oool00`0003?o03?o000N<ol000<0
003oooooool0Y_ooo`00:Oooo`0306Kooooooooo02_oool00`0003?o03?o000M<ol00P000:Ooool0
02Woool00`1Vooooooooo`0[oooo00<0000co`0co`007C?o00030000oooooooo0:Koool002Woool0
0`1Vooooooooo`0/oooo00<0000co`0co`002C?o00800004<ol00P0000@co`0200001C?o00030000
oooooooo0:Koool002Woool00`1Vooooooooo`0/oooo00<0000co`0co`0023?o00040000<ol0<ol0
000023?o00040000<ol0<ol0000013?o00030000oooooooo0:Koool002Woool00`1Vooooooooo`0]
oooo00<0000co`0co`001c?o00040000<ol0<ol000002c?o00030000<ol0<ol0008co`020000Yooo
o`00:Oooo`0306Kooooooooo02goool00`0003?o03?o0007<ol000@0000co`0co`000009<ol00P00
00Dco`000`000?ooooooo`2Voooo000Yoooo00<0I_ooooooool0;Oooo`030000<ol0<ol000Lco`00
100003?o03?o000000Tco`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00:Oooo`0306Ko
oooooooo02koool00`0003?o03?o0007<ol00P0000Xco`03000013?o00030000oooooooo0:Koool0
02Woool00`1Vooooooooo`0^oooo00<0000co`0co`006S?o0080002Woooo000Yoooo00<0I_oooooo
ool0;_ooo`030000<ol0<ol001Xco`000`000?ooooooo`2Voooo000Xoooo0P1Voc7oool00`0003?o
03?o000I<ol000<0003oooooool0Y_ooo`008oooo`D0I_l00oooool0VOooo`0`oooo00<0000co`0c
o`006C?o0080002Woooo000Noooo1@1Vo`Koool00ol0VOooooooo`0_oooo00<0000co`0co`006C?o
00030000oooooooo0:Koool001Woool506Ko2oooo`03o`2Ioooooooo033oool00`0003?o03?o000H
<ol000<0003oooooool0Y_ooo`005_ooo`<0I_l@oooo00?o09Woooooool0<?ooo`030000<ol0<ol0
01Pco`000`000?ooooooo`2Voooo000Yoooo00?o09Woooooool0<?ooo`030000<ol0<ol001Pco`02
0000Yoooo`00:Oooo`03o`2Ioooooooo037oool00`0003?o03?o000G<ol000<0003oooooool0Y_oo
o`00:Oooo`03o`2Ioooooooo037oool00`0003?o03?o000G<ol000<0003oooooool0Y_ooo`00:Ooo
o`03o`2Ioooooooo037oool00`0003?o03?o000G<ol000<0003oooooool0Y_ooo`00:Oooo`03o`2I
oooooooo03;oool00`0003?o03?o000F<ol00P000:Ooool002Woool00ol0VOooooooo`0boooo00<0
000co`0co`005S?o00030000oooooooo0:Koool002Woool00ol0VOooooooo`0boooo0P0000@co`02
00001C?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo0:Koool002Woool00ol0VOoo
ooooo`0aoooo00@0003oool00000000:<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0
008co`000`000?ooooooo`2Voooo000Yoooo00?o09Woooooool0<Oooo`040000oooo000000002S?o
00030000<ol0<ol000@co`000`0003?o03?o0002<ol00P000:Ooool002Woool00ol0VOooooooo`0a
oooo00@0003oool00000000;<ol000@0000co`0co`0co`0200001C?o00030000oooooooo0:Koool0
02Woool00ol0VOooooooo`0aoooo00@0003oooooool00008<ol000@0000co`0co`000003<ol000<0
000co`0co`0013?o00030000oooooooo0:Koool002Woool00ol0VOooooooo`0boooo0`0000Pco`04
00000c?o00<00004<ol000<0003oooooool0Y_ooo`00:Oooo`03o`2Ioooooooo03Coool00`0003?o
03?o000D<ol00P000:Ooool002Woool00ol0VOooooooo`0doooo00<0000co`0co`0053?o00030000
oooooooo0:Koool002Woool00ol0VOooooooo`0eoooo00<0000co`0co`004c?o00030000oooooooo
0:Koool002Woool00ol0VOooooooo`0eoooo00<0000co`0co`004c?o00030000oooooooo0:Koool0
02Woool00ol0VOooooooo`0eoooo00<0000co`0co`004c?o0080002Woooo000Yoooo00?o09Wooooo
ool0=Oooo`030000<ol0<ol001<co`000`000?ooooooo`2Voooo000Yoooo00?o09Woooooool0=_oo
o`030000<ol0<ol0018co`000`000?ooooooo`2Voooo000Yoooo00?o09Woooooool0=_ooo`030000
<ol0<ol0018co`000`000?ooooooo`2Voooo000Yoooo00?o09Woooooool0=_ooo`030000<ol0<ol0
018co`020000Yoooo`00:Oooo`03o`2Ioooooooo03Koool00`0003?o03?o000B<ol000<0003ooooo
ool0Y_ooo`00:Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000A<ol000<0003oooooool0Y_oo
o`00:Oooo`03o`2Ioooooooo03Ooool00`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00:Ooo
o`03o`2Ioooooooo03Ooool00`0003?o03?o000A<ol00P000:Ooool002Woool00ol0VOooooooo`0g
oooo00<0000co`0co`004C?o00030000oooooooo0:Koool002Woool00ol0VOooooooo`0goooo00<0
000co`0co`002C?o00D00003<ol000<0003oooooool0Y_ooo`00:Oooo`03o`2Ioooooooo03Soool0
0`0003?o03?o000:<ol000<0000co`0co`000c?o00030000oooooooo0:Koool002Woool00ol0VOoo
ooooo`0hoooo00<0000co`0co`002S?o00030000<ol0<ol000<co`020000Yoooo`00I?ooo`dco`00
0`0003?o03?o0003<ol0ZOooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo``co`02
00001C?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o00;oool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00IOoooa8co`000oooo`000?ooo`09oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool006GooolB<ol000?oool0003oool00oooo`800004oooo00<0
003oooooool03?ooo`@00003oooo0P0000?oool300001?ooo`030000oooooooo07Soool006GooolB
<ol000?oool0003oool00_ooo`040000oooooooo00001?ooo`030000oooooooo00Coool400000ooo
o`030000oooooooo00Woool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001Uoooo4S?o
00030000oooooooo00;oool00`000?ooooooo`0Doooo00<0003oooooool02?ooo`040000oooooooo
00001?ooo`030000oooooooo07Ooool006KooolA<ol000Coool0003oooooool500005?ooo`030000
oooooooo00Ooool300001?ooo`030000oooooooo07Soool006KooolA<ol000?oool0003oool00_oo
o`030000oooooooo01?oool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0003ooooo
ool0N?ooo`00I_oooa4co`02oooo00<0003oooooool05oooo`80000:oooo0`0000;oool00`000?oo
ooooo`1ioooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.0932 .30902 L
.10458 .30902 L
.11009 .30902 L
.1128 .30902 L
.11531 .30902 L
.11758 .30902 L
.11872 .30902 L
s
.11872 .30902 m
.11885 .61803 L
s
0 .4 1 r
.02381 .50774 m
.06244 .50127 L
.08255 .49712 L
.0932 .49467 L
.10458 .49183 L
.11009 .49037 L
.1128 .48963 L
.11531 .48894 L
.11758 .4883 L
.11872 .48797 L
.11999 .30902 L
.12125 .30902 L
.12196 .30902 L
.12261 .30902 L
.12387 .30902 L
.12507 .30902 L
.12627 .30902 L
.12736 .30902 L
.12853 .30902 L
.1298 .30902 L
.13098 .30902 L
.13206 .30902 L
.1331 .30902 L
.13419 .30902 L
.13538 .30902 L
.13665 .30902 L
.13785 .30902 L
.13894 .30902 L
.14022 .30902 L
.14095 .30902 L
.14162 .30902 L
.14285 .30902 L
.14415 .30902 L
.14529 .30902 L
.14653 .30902 L
.14783 .30902 L
.14904 .30902 L
.15018 .30902 L
.15121 .30902 L
.1524 .30902 L
.15352 .30902 L
.15475 .30902 L
.15604 .30902 L
.15715 .30902 L
.15837 .30902 L
.15968 .30902 L
.16041 .30902 L
.16108 .30902 L
.16239 .30902 L
.16362 .30902 L
Mistroke
.16478 .30902 L
.16582 .30902 L
.16703 .30902 L
.16816 .30902 L
.16921 .30902 L
.17018 .30902 L
.17124 .30902 L
.17237 .30902 L
.17351 .30902 L
.17458 .30902 L
.17585 .30902 L
.17701 .30902 L
.17821 .30902 L
.17952 .30902 L
.18076 .30902 L
.1819 .30902 L
.18309 .30902 L
.18433 .30902 L
.18539 .30902 L
.18655 .30902 L
.18781 .30902 L
.18851 .30902 L
.18914 .30902 L
.19039 .30902 L
.19155 .30902 L
.19265 .30902 L
.19382 .30902 L
.19481 .30902 L
.1959 .30902 L
.19707 .30902 L
.19833 .30902 L
.19952 .30902 L
.2006 .30902 L
.20188 .30902 L
.20252 .30902 L
.20324 .30902 L
.20449 .30902 L
.20567 .30902 L
.20635 .30902 L
.20706 .30902 L
.20832 .30902 L
.20899 .30902 L
.20969 .30902 L
.21047 .30902 L
.21119 .30902 L
.21248 .30902 L
.21321 .30902 L
.21389 .30902 L
.21513 .30902 L
.21644 .30902 L
Mistroke
.21754 .30902 L
.21872 .30902 L
.22001 .30902 L
.22122 .30902 L
.22253 .30902 L
.22376 .30902 L
.22444 .30902 L
.22518 .30902 L
.22647 .30902 L
.2277 .30902 L
.229 .30902 L
.23012 .30902 L
.23134 .30902 L
.23208 .30902 L
.23278 .30902 L
.23409 .30902 L
.23483 .30902 L
.23551 .30902 L
.23625 .30902 L
.23704 .30902 L
.23826 .30902 L
.23958 .30902 L
.24033 .30902 L
.24102 .30902 L
.24168 .30902 L
.24237 .30902 L
.24363 .30902 L
.24478 .30902 L
.2461 .30902 L
.24734 .30902 L
.2485 .30902 L
.24956 .30902 L
.25073 .30902 L
.25197 .30902 L
.25322 .30902 L
.25391 .30902 L
.25455 .30902 L
.25579 .30902 L
.25697 .30902 L
.25763 .30902 L
.25833 .30902 L
.2596 .30902 L
.26037 .30902 L
.2611 .30902 L
.26176 .30902 L
.26247 .30902 L
.26371 .30902 L
.26485 .30902 L
.26607 .30902 L
.26677 .30902 L
Mistroke
.2674 .30902 L
.26855 .30902 L
.26977 .30902 L
.27094 .30902 L
.27201 .30902 L
.27324 .30902 L
.27392 .30902 L
.27457 .30902 L
.27572 .30902 L
.27698 .30902 L
.2777 .30902 L
.27835 .30902 L
.27906 .30902 L
.27982 .30902 L
.28053 .30902 L
.28118 .30902 L
.28246 .30902 L
.28368 .30902 L
.28498 .30902 L
.28622 .30902 L
.28734 .30902 L
.28866 .30902 L
.28941 .30902 L
.2901 .30902 L
.29136 .30902 L
.292 .30902 L
.29271 .30902 L
.29339 .30902 L
.29411 .30902 L
.2954 .30902 L
.29611 .30902 L
.29678 .30902 L
.29751 .30902 L
.29829 .30902 L
.29897 .30902 L
.29971 .30902 L
.3004 .30902 L
.30104 .30902 L
.30226 .30902 L
.30354 .30902 L
.30475 .30902 L
.30607 .30902 L
.30731 .30902 L
.30847 .30902 L
.30961 .30902 L
.31065 .30902 L
.31185 .30902 L
.31297 .30902 L
.31421 .30902 L
.31551 .30902 L
Mistroke
.31662 .30902 L
.31784 .30902 L
.31916 .30902 L
.31989 .30902 L
.32057 .30902 L
.32187 .30902 L
.32311 .30902 L
.32416 .30902 L
.32532 .30902 L
.32653 .30902 L
.32767 .30902 L
.32872 .30902 L
.32969 .30902 L
.33076 .30902 L
.33188 .30902 L
.33302 .30902 L
.33424 .30902 L
.33539 .30902 L
.33644 .30902 L
.33767 .30902 L
.33836 .30902 L
.339 .30902 L
.34017 .30902 L
.34142 .30902 L
.34263 .30902 L
.34395 .30902 L
.3452 .30902 L
.34636 .30902 L
.34749 .30902 L
.34855 .30902 L
.34965 .30902 L
.35087 .30902 L
.35211 .30902 L
.35342 .30902 L
.35453 .30902 L
.35575 .30902 L
.35707 .30902 L
.35781 .30902 L
.35848 .30902 L
.35979 .30902 L
.36102 .30902 L
.36208 .30902 L
.36324 .30902 L
.36445 .30902 L
.36559 .30902 L
.36665 .30902 L
.36762 .30902 L
.36874 .30902 L
.36981 .30902 L
.37095 .30902 L
Mistroke
.37217 .30902 L
.37332 .30902 L
.37437 .30902 L
.37551 .30902 L
.37674 .30902 L
.37744 .30902 L
.37809 .30902 L
.37934 .30902 L
.38054 .30902 L
.38185 .30902 L
.38308 .30902 L
.38422 .30902 L
.38541 .30902 L
.38672 .30902 L
.38738 .30902 L
.38809 .30902 L
.38937 .30902 L
.39049 .30902 L
.39172 .30902 L
.39299 .30902 L
.39418 .30902 L
.3953 .30902 L
.39632 .30902 L
.39749 .30902 L
.3986 .30902 L
.3998 .30902 L
.40048 .30902 L
.40112 .30902 L
.40241 .30902 L
.40313 .30902 L
.40379 .30902 L
.40497 .30902 L
.40625 .30902 L
.40859 .30902 L
.41942 .30902 L
.46012 .30902 L
.49931 .30902 L
.54095 .30902 L
.58108 .30902 L
.61969 .30902 L
.66075 .30902 L
.7003 .30902 L
.73833 .30902 L
.77882 .30902 L
.81778 .30902 L
.85921 .30902 L
.89911 .30902 L
.9375 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000H0000co`0co`0co`3o09T0I_l3<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000oooooooo00Koool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`05oooo2P0000Hco`000ol0V@1Voc?o000F<ol000<0000co`0co`00;C?o00030000
oooooooo02goool00`000?ooooooo`0]oooo00<0003oooooool0;_ooo`030000oooooooo01Goool0
02Soool6000000?o09T0I_lco`00AS?o00030000oooooooo0:Koool002koool00ol0V@1Vo`000002
0000A3?o0080002Woooo000^oooo00?o09T0I_ooool00_ooo`@00010<ol000<0003oooooool0Y_oo
o`00;_ooo`03o`2I06Kooooo00Koool20000?S?o00030000oooooooo0:Koool002koool00ol0V@1V
ooooo`08oooo0`0003/co`000`000?ooooooo`2Voooo000^oooo00?o09T0I_ooool02oooo`80000i
<ol00P000:Ooool002koool00ol0V@1Vooooo`0=oooo0P0003Lco`000`000?ooooooo`2Voooo000^
oooo00?o09T0I_ooool03oooo`80000e<ol000<0003oooooool0Y_ooo`00;_ooo`03o`2I06Kooooo
017oool20000<c?o00030000oooooooo0:Koool002koool00ol0V@1Vooooo`0Coooo0P00034co`02
0000Yoooo`00;_ooo`03o`2I06Kooooo01Goool00`0003?o03?o000^<ol000<0003oooooool0Y_oo
o`00;_ooo`03o`2I06Kooooo01Koool00`0003?o03?o000]<ol000<0003oooooool0Y_ooo`00;_oo
o`03o`2I06Kooooo01Ooool00`0003?o03?o000/<ol000<0003oooooool0Y_ooo`00;_ooo`03o`2I
06Kooooo01Soool00`0003?o03?o000[<ol00P000:Ooool002koool00ol0V@1Vooooo`0Ioooo00<0
000co`0co`00:S?o00030000oooooooo0:Koool002koool00ol0V@1Vooooo`0Joooo00<0000co`0c
o`0043?o00800004<ol00P0000<co`0400000c?o00800005<ol000<0003oooooool0Y_ooo`00;_oo
o`03o`2I06Kooooo01_oool00`0003?o03?o000><ol000@0000co`0co`000008<ol000<0000co`0c
o`000c?o00040000<ol0<ol0000013?o00030000oooooooo0:Koool002koool00ol0V@1Vooooo`0L
oooo00<0000co`0co`003C?o00040000<ol0<ol000002C?o00030000<ol0<ol000Dco`000`0003?o
03?o0002<ol00P000:Ooool002koool00ol0V@1Vooooo`0Moooo00<0000co`0co`0033?o00040000
<ol0<ol000002S?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo0:Koool002koool0
0ol0V@1Vooooo`0Noooo00<0000co`0co`002c?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000c?o00030000<ol0<ol000@co`000`000?ooooooo`2Voooo000^oooo00<0I_ooooooool07_oo
o`030000<ol0<ol000`co`0200002S?o00800004<ol00`0000@co`000`000?ooooooo`2Voooo000^
oooo00<0I_ooooooool07oooo`030000<ol0<ol002@co`020000Yoooo`00;_ooo`0306Kooooooooo
023oool00`0003?o03?o000S<ol000<0003oooooool0Y_ooo`00;_ooo`0306Kooooooooo027oool0
0`0003?o03?o000R<ol000<0003oooooool0Y_ooo`00;_ooo`0306Kooooooooo027oool00`0003?o
03?o000R<ol000<0003oooooool0Y_ooo`00;_ooo`0306Kooooooooo02;oool00`0003?o03?o000Q
<ol00P000:Ooool002koool00`1Vooooooooo`0Roooo00<0000co`0co`008C?o00030000oooooooo
0:Koool002koool00`1Vooooooooo`0Soooo00<0000co`0co`0083?o00030000oooooooo0:Koool0
02koool00`1Vooooooooo`0Soooo00<0000co`0co`0083?o00030000oooooooo0:Koool002koool0
0`1Vooooooooo`0Toooo00<0000co`0co`007c?o0080002Woooo000^oooo00<0I_ooooooool09?oo
o`030000<ol0<ol001lco`000`000?ooooooo`2Voooo000^oooo00<0I_ooooooool09Oooo`030000
<ol0<ol001hco`000`000?ooooooo`2Voooo000^oooo00<0I_ooooooool09Oooo`030000<ol0<ol0
01hco`000`000?ooooooo`2Voooo000^oooo00<0I_ooooooool09_ooo`030000<ol0<ol001dco`02
0000Yoooo`00;_ooo`0306Kooooooooo02Koool00`0003?o03?o000M<ol000<0003oooooool0Y_oo
o`00;_ooo`0306Kooooooooo02Ooool00`0003?o03?o0009<ol00P0000@co`02000013?o00800005
<ol000<0003oooooool0Y_ooo`00;_ooo`0306Kooooooooo02Ooool00`0003?o03?o0008<ol000@0
000co`0co`000008<ol000@0000co`0co`000004<ol000<0003oooooool0Y_ooo`00;_ooo`0306Ko
oooooooo02Soool00`0003?o03?o0007<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o
0080002Woooo000^oooo00<0I_ooooooool0:?ooo`030000<ol0<ol000Lco`00100003?o03?o0000
00Tco`0200001C?o00030000oooooooo0:Koool002koool00`1Vooooooooo`0Xoooo00<0000co`0c
o`001c?o00040000<ol0<ol000002C?o00030000<ol0<ol000@co`000`000?ooooooo`2Voooo000^
oooo00<0I_ooooooool0:Oooo`030000<ol0<ol000Lco`0200002S?o00<00004<ol000<0003ooooo
ool0Y_ooo`00;_ooo`0306Kooooooooo02Woool00`0003?o03?o000J<ol00P000:Ooool002koool0
0`1Vooooooooo`0Yoooo00<0000co`0co`006S?o00030000oooooooo0:Koool002coool306Ko;?oo
o`030000<ol0<ol001Tco`000`000?ooooooo`2Voooo000Woooo1@1Vo`;oool00ol0VOooooooo`0Z
oooo00<0000co`0co`006C?o0080002Woooo000Soooo101Vo`Ooool00ol0VOooooooo`0Zoooo00<0
000co`0co`006C?o00030000oooooooo0:Koool001koool506Ko2oooo`03o`2Ioooooooo02_oool0
0`0003?o03?o000H<ol000<0003oooooool0Y_ooo`006Oooo`D0I_l@oooo00?o09Woooooool0:ooo
o`030000<ol0<ol001Pco`000`000?ooooooo`2Voooo000Foooo0`1VoaGoool00ol0VOooooooo`0[
oooo00<0000co`0co`0063?o0080002Woooo000^oooo00?o09Woooooool0;?ooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Voooo000^oooo00?o09Woooooool0;?ooo`030000<ol0<ol001Lco`00
0`000?ooooooo`2Voooo000^oooo00?o09Woooooool0;?ooo`030000<ol0<ol001Lco`000`000?oo
ooooo`2Voooo000^oooo00?o09Woooooool0;Oooo`030000<ol0<ol001Hco`020000Yoooo`00;_oo
o`03o`2Ioooooooo02goool00`0003?o03?o000F<ol000<0003oooooool0Y_ooo`00;_ooo`03o`2I
oooooooo02goool2000013?o00800005<ol000<0000co`0co`000S?o00800005<ol000<0003ooooo
ool0Y_ooo`00;_ooo`03o`2Ioooooooo02coool010000?ooo`00000000Xco`001@0003?o03?o03?o
00000002<ol000<0000co`0co`000S?o00030000oooooooo0:Koool002koool00ol0VOooooooo`0/
oooo00@0003oool00000000:<ol000<0000co`0co`0013?o00030000<ol0<ol0008co`020000Yooo
o`00;_ooo`03o`2Ioooooooo02coool010000?ooo`00000000/co`00100003?o03?o03?o00800005
<ol000<0003oooooool0Y_ooo`00;_ooo`03o`2Ioooooooo02coool010000?ooooooo`0000Pco`00
100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00;_ooo`03o`2I
oooooooo02goool3000023?o00@00003<ol00`0000@co`000`000?ooooooo`2Voooo000^oooo00?o
09Woooooool0;oooo`030000<ol0<ol001@co`020000Yoooo`00;_ooo`03o`2Ioooooooo02ooool0
0`0003?o03?o000D<ol000<0003oooooool0Y_ooo`00;_ooo`03o`2Ioooooooo033oool00`0003?o
03?o000C<ol000<0003oooooool0Y_ooo`00;_ooo`03o`2Ioooooooo033oool00`0003?o03?o000C
<ol000<0003oooooool0Y_ooo`00;_ooo`03o`2Ioooooooo033oool00`0003?o03?o000C<ol00P00
0:Ooool002koool00ol0VOooooooo`0`oooo00<0000co`0co`004c?o00030000oooooooo0:Koool0
02koool00ol0VOooooooo`0aoooo00<0000co`0co`004S?o00030000oooooooo0:Koool002koool0
0ol0VOooooooo`0aoooo00<0000co`0co`004S?o00030000oooooooo0:Koool002koool00ol0VOoo
ooooo`0aoooo00<0000co`0co`004S?o0080002Woooo000^oooo00?o09Woooooool0<Oooo`030000
<ol0<ol0018co`000`000?ooooooo`2Voooo000^oooo00?o09Woooooool0<_ooo`030000<ol0<ol0
014co`000`000?ooooooo`2Voooo000^oooo00?o09Woooooool0<_ooo`030000<ol0<ol0014co`00
0`000?ooooooo`2Voooo000^oooo00?o09Woooooool0<_ooo`030000<ol0<ol0014co`020000Yooo
o`00;_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00;_oo
o`03o`2Ioooooooo03;oool00`0003?o03?o0009<ol01@0000<co`000`000?ooooooo`2Voooo000^
oooo00?o09Woooooool0<oooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003ooooo
ool0Y_ooo`00;_ooo`03o`2Ioooooooo03?oool00`0003?o03?o000:<ol000<0000co`0co`000c?o
0080002Woooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol0
00<co`2Yoooo001Toooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool0
06GooolB<ol00_ooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Uoooo4S?o0003oooo
0000oooo00Woool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`00
0?ooo`03oooo0P0000Coool00`000?ooooooo`0<oooo100000?oool200001?ooo`800004oooo00<0
003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`02oooo00@0003oooooool00004oooo00<0
003oooooool01?ooo`@00003oooo00<0003oooooool02Oooo`040000oooooooo00000oooo`030000
oooooooo07Soool006GooolB<ol000<0003oooooool00_ooo`030000oooooooo01Coool00`000?oo
ooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo07Ooool006KooolA<ol000Coool0003o
ooooool500005?ooo`030000oooooooo00Soool200001?ooo`030000oooooooo07Soool006KooolA
<ol000?oool0003oool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Woool00`000?oo
ooooo`03oooo00<0003oooooool0N?ooo`00I_oooa4co`02oooo00<0003oooooool05oooo`80000:
oooo0`0000;oool00`000?ooooooo`1ioooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.08255 .30902 L
.10458 .30902 L
.11448 .30902 L
.12507 .30902 L
.1302 .30902 L
.13273 .30902 L
.13506 .30902 L
.13615 .30902 L
.13718 .30902 L
s
.13718 .30902 m
.13728 .61803 L
s
0 .4 1 r
.02381 .50995 m
.06244 .50421 L
.08255 .50053 L
.10458 .49585 L
.11448 .4935 L
.12507 .49079 L
.1302 .4894 L
.13273 .4887 L
.13506 .48804 L
.13615 .48773 L
.13718 .48743 L
.13824 .30902 L
.13942 .30902 L
.14061 .30902 L
.1417 .30902 L
.14296 .30902 L
.14415 .30902 L
.1454 .30902 L
.1461 .30902 L
.14674 .30902 L
.14793 .30902 L
.14918 .30902 L
.1503 .30902 L
.15135 .30902 L
.1525 .30902 L
.15374 .30902 L
.15443 .30902 L
.15506 .30902 L
.15632 .30902 L
.15746 .30902 L
.15867 .30902 L
.15997 .30902 L
.16118 .30902 L
.16188 .30902 L
.16252 .30902 L
.16322 .30902 L
.16396 .30902 L
.16511 .30902 L
.16616 .30902 L
.16728 .30902 L
.16851 .30902 L
.16964 .30902 L
.17068 .30902 L
.17168 .30902 L
.17274 .30902 L
.17388 .30902 L
.1751 .30902 L
.17626 .30902 L
.17731 .30902 L
.17855 .30902 L
Mistroke
.17925 .30902 L
.17989 .30902 L
.18108 .30902 L
.18234 .30902 L
.18359 .30902 L
.1843 .30902 L
.18496 .30902 L
.18566 .30902 L
.18629 .30902 L
.18703 .30902 L
.18772 .30902 L
.18895 .30902 L
.19009 .30902 L
.19133 .30902 L
.19196 .30902 L
.19266 .30902 L
.19336 .30902 L
.1941 .30902 L
.19473 .30902 L
.19543 .30902 L
.19617 .30902 L
.19697 .30902 L
.19772 .30902 L
.19841 .30902 L
.1991 .30902 L
.19974 .30902 L
.20044 .30902 L
.20118 .30902 L
.20243 .30902 L
.20314 .30902 L
.2038 .30902 L
.20505 .30902 L
.20576 .30902 L
.20641 .30902 L
.20761 .30902 L
.20889 .30902 L
.21003 .30902 L
.21109 .30902 L
.21227 .30902 L
.21353 .30902 L
.2148 .30902 L
.21552 .30902 L
.21619 .30902 L
.21689 .30902 L
.21754 .30902 L
.21828 .30902 L
.21898 .30902 L
.22023 .30902 L
.22138 .30902 L
.22264 .30902 L
Mistroke
.22328 .30902 L
.22398 .30902 L
.22527 .30902 L
.22647 .30902 L
.22778 .30902 L
.22852 .30902 L
.22918 .30902 L
.23041 .30902 L
.23173 .30902 L
.23298 .30902 L
.23412 .30902 L
.23524 .30902 L
.23628 .30902 L
.23742 .30902 L
.23864 .30902 L
.23992 .30902 L
.24113 .30902 L
.24222 .30902 L
.2434 .30902 L
.24461 .30902 L
.2459 .30902 L
.24665 .30902 L
.24733 .30902 L
.24798 .30902 L
.24867 .30902 L
.24933 .30902 L
.25005 .30902 L
.25133 .30902 L
.25212 .30902 L
.25286 .30902 L
.25353 .30902 L
.25425 .30902 L
.25546 .30902 L
.25615 .30902 L
.25679 .30902 L
.25808 .30902 L
.25881 .30902 L
.25947 .30902 L
.26066 .30902 L
.26194 .30902 L
.26316 .30902 L
.26429 .30902 L
.26558 .30902 L
.26623 .30902 L
.26694 .30902 L
.26821 .30902 L
.26939 .30902 L
.2701 .30902 L
.27078 .30902 L
.27205 .30902 L
Mistroke
.27276 .30902 L
.27341 .30902 L
.27413 .30902 L
.27489 .30902 L
.27607 .30902 L
.27734 .30902 L
.27854 .30902 L
.27964 .30902 L
.28092 .30902 L
.28164 .30902 L
.28232 .30902 L
.28355 .30902 L
.28486 .30902 L
.28612 .30902 L
.28728 .30902 L
.28855 .30902 L
.28919 .30902 L
.28989 .30902 L
.29107 .30902 L
.29234 .30902 L
.29354 .30902 L
.29463 .30902 L
.29576 .30902 L
.29681 .30902 L
.29796 .30902 L
.29918 .30902 L
.30023 .30902 L
.30123 .30902 L
.30232 .30902 L
.30349 .30902 L
.30474 .30902 L
.30588 .30902 L
.3072 .30902 L
.30844 .30902 L
.30959 .30902 L
.31065 .30902 L
.31182 .30902 L
.31305 .30902 L
.31429 .30902 L
.31499 .30902 L
.31563 .30902 L
.31686 .30902 L
.31804 .30902 L
.3187 .30902 L
.3194 .30902 L
.32066 .30902 L
.32143 .30902 L
.32216 .30902 L
.32281 .30902 L
.32352 .30902 L
Mistroke
.32484 .30902 L
.32607 .30902 L
.32678 .30902 L
.32742 .30902 L
.32816 .30902 L
.32887 .30902 L
.32955 .30902 L
.33027 .30902 L
.33157 .30902 L
.33229 .30902 L
.33297 .30902 L
.33371 .30902 L
.33451 .30902 L
.33574 .30902 L
.33644 .30902 L
.33708 .30902 L
.33839 .30902 L
.33912 .30902 L
.33979 .30902 L
.34098 .30902 L
.34227 .30902 L
.34349 .30902 L
.34462 .30902 L
.34587 .30902 L
.34707 .30902 L
.34814 .30902 L
.3493 .30902 L
.35057 .30902 L
.35121 .30902 L
.35191 .30902 L
.35316 .30902 L
.35433 .30902 L
.35544 .30902 L
.35661 .30902 L
.3576 .30902 L
.3587 .30902 L
.35987 .30902 L
.36114 .30902 L
.36233 .30902 L
.36341 .30902 L
.36469 .30902 L
.36534 .30902 L
.36606 .30902 L
.36732 .30902 L
.3685 .30902 L
.36921 .30902 L
.36989 .30902 L
.37116 .30902 L
.37187 .30902 L
.37253 .30902 L
Mistroke
.37325 .30902 L
.37402 .30902 L
.37533 .30902 L
.37606 .30902 L
.37674 .30902 L
.37798 .30902 L
.37929 .30902 L
.38046 .30902 L
.38156 .30902 L
.38277 .30902 L
.38406 .30902 L
.38528 .30902 L
.38597 .30902 L
.38662 .30902 L
.38793 .30902 L
.38867 .30902 L
.38935 .30902 L
.39048 .30902 L
.39173 .30902 L
.39303 .30902 L
.39424 .30902 L
.39493 .30902 L
.39568 .30902 L
.39639 .30902 L
.39704 .30902 L
.39828 .30902 L
.39959 .30902 L
.40027 .30902 L
.40099 .30902 L
.40231 .30902 L
.40311 .30902 L
.40388 .30902 L
.40456 .30902 L
.4053 .30902 L
.40596 .30902 L
.40667 .30902 L
.40796 .30902 L
.41036 .30902 L
.41575 .30902 L
.42543 .30902 L
.46649 .30902 L
.50604 .30902 L
.54407 .30902 L
.58455 .30902 L
.62352 .30902 L
.66494 .30902 L
.70485 .30902 L
.74324 .30902 L
.78408 .30902 L
.82341 .30902 L
Mistroke
.86122 .30902 L
.90148 .30902 L
.94023 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000;<ol000<0I_lco`0co`004C?o00030000<ol0<ol002dco`000`000?ooooooo`0]
oooo00<0003oooooool0;Oooo`030000oooooooo02koool00`000?ooooooo`0Eoooo000Xoooo1P00
00Dco`000`1Voc?o03?o0011<ol000<0003oooooool0Y_ooo`00;_ooo`D000000`1Voc?o03?o0011
<ol00P000:Ooool003?oool0101Vo`0000000000040co`000`000?ooooooo`2Voooo000coooo00@0
I_ooooooooooool20000?S?o00030000oooooooo0:Koool003?oool00`1Vooooooooo`03oooo0`00
03/co`000`000?ooooooo`2Voooo000coooo00<0I_ooooooool01_ooo`80000i<ol00P000:Ooool0
03?oool00`1Vooooooooo`08oooo0P0003Lco`000`000?ooooooo`2Voooo000coooo00<0I_oooooo
ool02_ooo`80000e<ol000<0003oooooool0Y_ooo`00<oooo`0306Kooooooooo00coool20000<c?o
00030000oooooooo0:Koool003?oool00`1Vooooooooo`0>oooo0P00034co`020000Yoooo`00<ooo
o`0306Kooooooooo013oool00`0003?o03?o000^<ol000<0003oooooool0Y_ooo`00<oooo`0306Ko
oooooooo017oool00`0003?o03?o000]<ol000<0003oooooool0Y_ooo`00<oooo`0306Kooooooooo
01;oool00`0003?o03?o000/<ol000<0003oooooool0Y_ooo`00<oooo`0306Kooooooooo01?oool0
0`0003?o03?o000[<ol00P000:Ooool003?oool00`1Vooooooooo`0Doooo00<0000co`0co`00:S?o
00030000oooooooo0:Koool003?oool00`1Vooooooooo`0Eoooo00<0000co`0co`0043?o00800004
<ol00P0000<co`0400000c?o00800005<ol000<0003oooooool0Y_ooo`00<oooo`0306Kooooooooo
01Koool00`0003?o03?o000><ol000@0000co`0co`000008<ol000<0000co`0co`000c?o00040000
<ol0<ol0000013?o00030000oooooooo0:Koool003?oool00`1Vooooooooo`0Goooo00<0000co`0c
o`003C?o00040000<ol0<ol000002C?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol00P00
0:Ooool003?oool00`1Vooooooooo`0Hoooo00<0000co`0co`0033?o00040000<ol0<ol000002S?o
00030000<ol0<ol0008co`0200001C?o00030000oooooooo0:Koool003?oool00`1Vooooooooo`0I
oooo00<0000co`0co`002c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0<ol000@co`000`000?ooooooo`2Voooo000coooo00<0I_ooooooool06Oooo`030000<ol0<ol0
00`co`0200002S?o00800004<ol00`0000@co`000`000?ooooooo`2Voooo000coooo00<0I_oooooo
ool06_ooo`030000<ol0<ol002@co`020000Yoooo`00<oooo`0306Kooooooooo01_oool00`0003?o
03?o000S<ol000<0003oooooool0Y_ooo`00<oooo`0306Kooooooooo01coool00`0003?o03?o000R
<ol000<0003oooooool0Y_ooo`00<oooo`0306Kooooooooo01coool00`0003?o03?o000R<ol000<0
003oooooool0Y_ooo`00<oooo`0306Kooooooooo01goool00`0003?o03?o000Q<ol00P000:Ooool0
03?oool00`1Vooooooooo`0Moooo00<0000co`0co`008C?o00030000oooooooo0:Koool003?oool0
0`1Vooooooooo`0Noooo00<0000co`0co`0083?o00030000oooooooo0:Koool003?oool00`1Voooo
ooooo`0Noooo00<0000co`0co`0083?o00030000oooooooo0:Koool003?oool00`1Vooooooooo`0O
oooo00<0000co`0co`007c?o0080002Woooo000coooo00<0I_ooooooool07oooo`030000<ol0<ol0
01lco`000`000?ooooooo`2Voooo000coooo00<0I_ooooooool08?ooo`030000<ol0<ol001hco`00
0`000?ooooooo`2Voooo000coooo00<0I_ooooooool08?ooo`030000<ol0<ol001hco`000`000?oo
ooooo`2Voooo000coooo00<0I_ooooooool08Oooo`030000<ol0<ol001dco`020000Yoooo`00<ooo
o`0306Kooooooooo027oool00`0003?o03?o000M<ol000<0003oooooool0Y_ooo`00<oooo`0306Ko
oooooooo02;oool00`0003?o03?o0009<ol00P0000@co`02000013?o00800005<ol000<0003ooooo
ool0Y_ooo`00<oooo`0306Kooooooooo02;oool00`0003?o03?o0008<ol000@0000co`0co`000008
<ol000@0000co`0co`000004<ol000<0003oooooool0Y_ooo`00<oooo`0306Kooooooooo02?oool0
0`0003?o03?o0007<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o0080002Woooo000c
oooo00<0I_ooooooool08oooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`0200001C?o
00030000oooooooo0:Koool003?oool00`1Vooooooooo`0Soooo00<0000co`0co`001c?o00040000
<ol0<ol000002C?o00030000<ol0<ol000@co`000`000?ooooooo`2Voooo000coooo00<0I_oooooo
ool09?ooo`030000<ol0<ol000Lco`0200002S?o00<00004<ol000<0003oooooool0Y_ooo`00<ooo
o`0306Kooooooooo02Coool00`0003?o03?o000J<ol00P000:Ooool003?oool00`1Vooooooooo`0T
oooo00<0000co`0co`006S?o00030000oooooooo0:Koool0037oool306Ko9oooo`030000<ol0<ol0
01Tco`000`000?ooooooo`2Voooo000]oooo101Vo`;oool00ol0VOooooooo`0Uoooo00<0000co`0c
o`006C?o0080002Woooo000Yoooo101Vo`Koool00ol0VOooooooo`0Uoooo00<0000co`0co`006C?o
00030000oooooooo0:Koool002?oool606Ko2_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000H
<ol000<0003oooooool0Y_ooo`007?ooo`L0I_l@oooo00?o09Woooooool09_ooo`030000<ol0<ol0
01Pco`000`000?ooooooo`2Voooo000Foooo1P1VoaOoool00ol0VOooooooo`0Voooo00<0000co`0c
o`0063?o0080002Woooo000coooo00?o09Woooooool09oooo`030000<ol0<ol001Lco`000`000?oo
ooooo`2Voooo000coooo00?o09Woooooool09oooo`030000<ol0<ol001Lco`000`000?ooooooo`2V
oooo000coooo00?o09Woooooool09oooo`030000<ol0<ol001Lco`000`000?ooooooo`2Voooo000c
oooo00?o09Woooooool0:?ooo`030000<ol0<ol001Hco`020000Yoooo`00<oooo`03o`2Ioooooooo
02Soool00`0003?o03?o000F<ol000<0003oooooool0Y_ooo`00<oooo`03o`2Ioooooooo02Soool2
000013?o00800005<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Y_ooo`00<ooo
o`03o`2Ioooooooo02Ooool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0
000co`0co`000S?o00030000oooooooo0:Koool003?oool00ol0VOooooooo`0Woooo00@0003oool0
0000000:<ol000<0000co`0co`0013?o00030000<ol0<ol0008co`020000Yoooo`00<oooo`03o`2I
oooooooo02Ooool010000?ooo`00000000/co`00100003?o03?o03?o00800005<ol000<0003ooooo
ool0Y_ooo`00<oooo`03o`2Ioooooooo02Ooool010000?ooooooo`0000Pco`00100003?o03?o0000
00<co`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00<oooo`03o`2Ioooooooo02Soool3
000023?o00@00003<ol00`0000@co`000`000?ooooooo`2Voooo000coooo00?o09Woooooool0:_oo
o`030000<ol0<ol001@co`020000Yoooo`00<oooo`03o`2Ioooooooo02[oool00`0003?o03?o000D
<ol000<0003oooooool0Y_ooo`00<oooo`03o`2Ioooooooo02_oool00`0003?o03?o000C<ol000<0
003oooooool0Y_ooo`00<oooo`03o`2Ioooooooo02_oool00`0003?o03?o000C<ol000<0003ooooo
ool0Y_ooo`00<oooo`03o`2Ioooooooo02_oool00`0003?o03?o000C<ol00P000:Ooool003?oool0
0ol0VOooooooo`0[oooo00<0000co`0co`004c?o00030000oooooooo0:Koool003?oool00ol0VOoo
ooooo`0/oooo00<0000co`0co`004S?o00030000oooooooo0:Koool003?oool00ol0VOooooooo`0/
oooo00<0000co`0co`004S?o00030000oooooooo0:Koool003?oool00ol0VOooooooo`0/oooo00<0
000co`0co`004S?o0080002Woooo000coooo00?o09Woooooool0;?ooo`030000<ol0<ol0018co`00
0`000?ooooooo`2Voooo000coooo00?o09Woooooool0;Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Voooo000coooo00?o09Woooooool0;Oooo`030000<ol0<ol0014co`000`000?ooooooo`2V
oooo000coooo00?o09Woooooool0;Oooo`030000<ol0<ol0014co`020000Yoooo`00<oooo`03o`2I
oooooooo02goool00`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00<oooo`03o`2Ioooooooo
02goool00`0003?o03?o0009<ol01@0000<co`000`000?ooooooo`2Voooo000coooo00?o09Wooooo
ool0;_ooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003oooooool0Y_ooo`00<ooo
o`03o`2Ioooooooo02koool00`0003?o03?o000:<ol000<0000co`0co`000c?o0080002Woooo001T
oooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001T
oooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol00_oo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Uoooo4S?o0003oooo0000oooo00Woool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`03oooo0P00
00Coool00`000?ooooooo`0<oooo100000?oool200001Oooo`<00002oooo00<0003oooooool0N?oo
o`00IOoooa8co`000oooo`000?ooo`02oooo00@0003oooooool00004oooo00<0003oooooool01?oo
o`@00003oooo00<0003oooooool03?ooo`050000oooooooooooo000007[oool006GooolB<ol000<0
003oooooool00_ooo`030000oooooooo01Coool00`000?ooooooo`08oooo1@0000?oool00`000?oo
ooooo`1goooo001Voooo4C?o0004oooo0000oooooooo1@0001Coool00`000?ooooooo`07oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00I_oooa4co`000oooo`000?ooo`02oooo00<0
003oooooool04oooo`040000oooooooo00002Oooo`030000oooo000000?oool00`000?ooooooo`1h
oooo001Voooo4C?o00;oool00`000?ooooooo`0Goooo0P0000_oool200000_ooo`030000oooooooo
07Woool006KooolA<ol0ZOooo`00I_oooa4co`2Yoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.13506 .30902 L
.14415 .30902 L
.14868 .30902 L
.15107 .30902 L
.1536 .30902 L
.15581 .30902 L
.15707 .30902 L
s
.15707 .30902 m
.15719 .61803 L
s
0 .4 1 r
.02381 .51179 m
.06244 .50667 L
.10458 .49922 L
.12507 .49471 L
.13506 .49227 L
.14415 .48989 L
.14868 .48865 L
.15107 .48798 L
.1536 .48726 L
.15581 .48661 L
.15707 .48625 L
.15825 .30902 L
.15933 .30902 L
.16032 .30902 L
.16146 .30902 L
.16254 .30902 L
.16378 .30902 L
.1649 .30902 L
.16619 .30902 L
.16742 .30902 L
.16855 .30902 L
.16959 .30902 L
.17073 .30902 L
.17194 .30902 L
.17316 .30902 L
.17447 .30902 L
.17571 .30902 L
.17684 .30902 L
.17816 .30902 L
.1789 .30902 L
.17959 .30902 L
.18086 .30902 L
.1815 .30902 L
.18221 .30902 L
.18342 .30902 L
.18456 .30902 L
.1858 .30902 L
.18649 .30902 L
.18712 .30902 L
.1884 .30902 L
.18912 .30902 L
.18979 .30902 L
.19101 .30902 L
.1923 .30902 L
.1934 .30902 L
.19458 .30902 L
.19671 .30902 L
.20155 .30902 L
.20285 .30902 L
.20357 .30902 L
Mistroke
.20423 .30902 L
.20501 .30902 L
.20574 .30902 L
.20642 .30902 L
.20715 .30902 L
.20779 .30902 L
.20849 .30902 L
.20923 .30902 L
.20991 .30902 L
.21114 .30902 L
.21245 .30902 L
.21374 .30902 L
.21446 .30902 L
.21513 .30902 L
.21636 .30902 L
.21767 .30902 L
.21883 .30902 L
.21992 .30902 L
.22112 .30902 L
.22241 .30902 L
.22367 .30902 L
.22482 .30902 L
.22614 .30902 L
.22739 .30902 L
.22854 .30902 L
.2296 .30902 L
.23077 .30902 L
.23201 .30902 L
.23325 .30902 L
.23395 .30902 L
.23459 .30902 L
.23583 .30902 L
.237 .30902 L
.23766 .30902 L
.23837 .30902 L
.23963 .30902 L
.24033 .30902 L
.24099 .30902 L
.24171 .30902 L
.24249 .30902 L
.24313 .30902 L
.24382 .30902 L
.24505 .30902 L
.2458 .30902 L
.24652 .30902 L
.24716 .30902 L
.24785 .30902 L
.24853 .30902 L
.24928 .30902 L
.25006 .30902 L
Mistroke
.25079 .30902 L
.2521 .30902 L
.25283 .30902 L
.2535 .30902 L
.25479 .30902 L
.25598 .30902 L
.25729 .30902 L
.25802 .30902 L
.25868 .30902 L
.2599 .30902 L
.26122 .30902 L
.26246 .30902 L
.2636 .30902 L
.26487 .30902 L
.26606 .30902 L
.26714 .30902 L
.26831 .30902 L
.26958 .30902 L
.27022 .30902 L
.27093 .30902 L
.27218 .30902 L
.27335 .30902 L
.27446 .30902 L
.27563 .30902 L
.27663 .30902 L
.27773 .30902 L
.27891 .30902 L
.28017 .30902 L
.28136 .30902 L
.28244 .30902 L
.30311 .30902 L
.30544 .30902 L
.30672 .30902 L
.30793 .30902 L
.30906 .30902 L
.31029 .30902 L
.3114 .30902 L
.31244 .30902 L
.31363 .30902 L
.31472 .30902 L
.31597 .30902 L
.31714 .30902 L
.31844 .30902 L
.31963 .30902 L
.32093 .30902 L
.32159 .30902 L
.32231 .30902 L
.32304 .30902 L
.32373 .30902 L
.32502 .30902 L
Mistroke
.32574 .30902 L
.32641 .30902 L
.32714 .30902 L
.32791 .30902 L
.3292 .30902 L
.3304 .30902 L
.33172 .30902 L
.33246 .30902 L
.33314 .30902 L
.3344 .30902 L
.33558 .30902 L
.33687 .30902 L
.33759 .30902 L
.33825 .30902 L
.33945 .30902 L
.34075 .30902 L
.34198 .30902 L
.34311 .30902 L
.34437 .30902 L
.34557 .30902 L
.34664 .30902 L
.34781 .30902 L
.35025 .30902 L
.35089 .30902 L
.35159 .30902 L
.35284 .30902 L
.35401 .30902 L
.35508 .30902 L
.35629 .30902 L
.35756 .30902 L
.35864 .30902 L
.35965 .30902 L
.36075 .30902 L
.36193 .30902 L
.3626 .30902 L
.36332 .30902 L
.3646 .30902 L
.36531 .30902 L
.36598 .30902 L
.36671 .30902 L
.36749 .30902 L
.36817 .30902 L
.3689 .30902 L
.3696 .30902 L
.37024 .30902 L
.37146 .30902 L
.37275 .30902 L
.37403 .30902 L
.37475 .30902 L
.37541 .30902 L
Mistroke
.3766 .30902 L
.37791 .30902 L
.37909 .30902 L
.38019 .30902 L
.38135 .30902 L
.38259 .30902 L
.38381 .30902 L
.38451 .30902 L
.38516 .30902 L
.38647 .30902 L
.38721 .30902 L
.38789 .30902 L
.38903 .30902 L
.39027 .30902 L
.39157 .30902 L
.39278 .30902 L
.39348 .30902 L
.39423 .30902 L
.39494 .30902 L
.39559 .30902 L
.39683 .30902 L
.39814 .30902 L
.39882 .30902 L
.39955 .30902 L
.40086 .30902 L
.40167 .30902 L
.40243 .30902 L
.40311 .30902 L
.40386 .30902 L
.4051 .30902 L
.40626 .30902 L
.40892 .30902 L
.41431 .30902 L
.42399 .30902 L
.46263 .30902 L
.50373 .30902 L
.54331 .30902 L
.58137 .30902 L
.62189 .30902 L
.66089 .30902 L
.70234 .30902 L
.74228 .30902 L
.7807 .30902 L
.82157 .30902 L
.86093 .30902 L
.89877 .30902 L
.93907 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol0008co`000`1Voc?o
03?o0002<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0003oooooool01_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo00Goool:000043?o000306Ko<ol0<ol000`co`000`0003?o03?o000]
<ol000<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0^oooo00<0003ooooo
ool05Oooo`00:?ooo`H0000:<ol000<0I_lco`0co`00?3?o00030000oooooooo0:Koool002koool5
00001C?o000306Ko<ol0<ol003`co`020000Yoooo`00<oooo`@000000c?o001Voc?o000m<ol000<0
003oooooool0Y_ooo`00=oooo`03000006Ko<ol003dco`000`000?ooooooo`2Voooo000hoooo00@0
I_l000000000000k<ol000<0003oooooool0Y_ooo`00>?ooo`0406Kooooooooooooo0P0003Tco`02
0000Yoooo`00>?ooo`0306Kooooooooo00?oool20000=c?o00030000oooooooo0:Koool003Soool0
0`1Vooooooooo`05oooo0P0003Dco`000`000?ooooooo`2Voooo000hoooo00<0I_ooooooool01ooo
o`80000c<ol000<0003oooooool0Y_ooo`00>?ooo`0306Kooooooooo00Woool20000<C?o0080002W
oooo000hoooo00<0I_ooooooool02oooo`030000<ol0<ol002hco`000`000?ooooooo`2Voooo000h
oooo00<0I_ooooooool03?ooo`030000<ol0<ol002dco`000`000?ooooooo`2Voooo000hoooo00<0
I_ooooooool03Oooo`030000<ol0<ol002`co`000`000?ooooooo`2Voooo000hoooo00<0I_oooooo
ool03_ooo`030000<ol0<ol002/co`020000Yoooo`00>?ooo`0306Kooooooooo00ooool00`0003?o
03?o000Z<ol000<0003oooooool0Y_ooo`00>?ooo`0306Kooooooooo013oool00`0003?o03?o000@
<ol00P0000@co`0200000c?o00@00003<ol00P0000Dco`000`000?ooooooo`2Voooo000hoooo00<0
I_ooooooool04Oooo`030000<ol0<ol000hco`00100003?o03?o000000Pco`000`0003?o03?o0003
<ol000@0000co`0co`000004<ol000<0003oooooool0Y_ooo`00>?ooo`0306Kooooooooo01;oool0
0`0003?o03?o000=<ol000@0000co`0co`000009<ol000<0000co`0co`001C?o00030000<ol0<ol0
008co`020000Yoooo`00>?ooo`0306Kooooooooo01?oool00`0003?o03?o000<<ol000@0000co`0c
o`00000:<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Y_ooo`00>?ooo`0306Ko
oooooooo01Coool00`0003?o03?o000;<ol000@0000co`0co`000008<ol000@0000co`0co`000003
<ol000<0000co`0co`0013?o00030000oooooooo0:Koool003Soool00`1Vooooooooo`0Doooo00<0
000co`0co`0033?o0080000:<ol00P0000@co`03000013?o00030000oooooooo0:Koool003Soool0
0`1Vooooooooo`0Eoooo00<0000co`0co`0093?o0080002Woooo000hoooo00<0I_ooooooool05_oo
o`030000<ol0<ol002<co`000`000?ooooooo`2Voooo000hoooo00<0I_ooooooool05oooo`030000
<ol0<ol0028co`000`000?ooooooo`2Voooo000hoooo00<0I_ooooooool05oooo`030000<ol0<ol0
028co`000`000?ooooooo`2Voooo000hoooo00<0I_ooooooool06?ooo`030000<ol0<ol0024co`02
0000Yoooo`00>?ooo`0306Kooooooooo01Soool00`0003?o03?o000Q<ol000<0003oooooool0Y_oo
o`00>?ooo`0306Kooooooooo01Woool00`0003?o03?o000P<ol000<0003oooooool0Y_ooo`00>?oo
o`0306Kooooooooo01Woool00`0003?o03?o000P<ol000<0003oooooool0Y_ooo`00>?ooo`0306Ko
oooooooo01[oool00`0003?o03?o000O<ol00P000:Ooool003Soool00`1Vooooooooo`0Joooo00<0
000co`0co`007c?o00030000oooooooo0:Koool003Soool00`1Vooooooooo`0Koooo00<0000co`0c
o`007S?o00030000oooooooo0:Koool003Soool00`1Vooooooooo`0Koooo00<0000co`0co`007S?o
00030000oooooooo0:Koool003Soool00`1Vooooooooo`0Loooo00<0000co`0co`007C?o0080002W
oooo000hoooo00<0I_ooooooool07?ooo`030000<ol0<ol001dco`000`000?ooooooo`2Voooo000h
oooo00<0I_ooooooool07Oooo`030000<ol0<ol000Tco`02000013?o00800004<ol00P0000Dco`00
0`000?ooooooo`2Voooo000hoooo00<0I_ooooooool07Oooo`030000<ol0<ol000Pco`00100003?o
03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`2Voooo000hoooo00<0I_oooooo
ool07_ooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`000`0003?o03?o0002<ol00P00
0:Ooool003Soool00`1Vooooooooo`0Noooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o
00800005<ol000<0003oooooool0Y_ooo`00>?ooo`0306Kooooooooo01koool00`0003?o03?o0007
<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000oooooooo0:Koool003Soool0
0`1Vooooooooo`0Ooooo00<0000co`0co`001c?o0080000:<ol00`0000@co`000`000?ooooooo`2V
oooo000hoooo00<0I_ooooooool07oooo`030000<ol0<ol001Xco`020000Yoooo`00>?ooo`0306Ko
oooooooo01ooool00`0003?o03?o000J<ol000<0003oooooool0Y_ooo`00=?ooo`@0I_l00ol0VOoo
ooooo`0Poooo00<0000co`0co`006C?o00030000oooooooo0:Koool002ooool506Ko1?ooo`03o`2I
oooooooo023oool00`0003?o03?o000I<ol00P000:Ooool002goool206Ko2Oooo`03o`2Ioooooooo
023oool00`0003?o03?o000I<ol000<0003oooooool0Y_ooo`00:Oooo`@0I_l;oooo00?o09Wooooo
ool08Oooo`030000<ol0<ol001Pco`000`000?ooooooo`2Voooo000Soooo1P1Vo`ooool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`0063?o00030000oooooooo0:Koool001coool706Ko5Oooo`03o`2I
oooooooo027oool00`0003?o03?o000H<ol00P000:Ooool001Koool606Ko7?ooo`03o`2Ioooooooo
02;oool00`0003?o03?o000G<ol000<0003oooooool0Y_ooo`00>?ooo`03o`2Ioooooooo02;oool0
0`0003?o03?o000G<ol000<0003oooooool0Y_ooo`00>?ooo`03o`2Ioooooooo02;oool00`0003?o
03?o000G<ol000<0003oooooool0Y_ooo`00>?ooo`03o`2Ioooooooo02?oool00`0003?o03?o000F
<ol00P000:Ooool003Soool00ol0VOooooooo`0Soooo00<0000co`0co`005S?o00030000oooooooo
0:Koool003Soool00ol0VOooooooo`0Soooo0P0000@co`0200001C?o00030000<ol0<ol0008co`02
00001C?o00030000oooooooo0:Koool003Soool00ol0VOooooooo`0Roooo00@0003oool00000000:
<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`000?ooooooo`2Voooo000h
oooo00?o09Woooooool08_ooo`040000oooo000000002S?o00030000<ol0<ol000@co`000`0003?o
03?o0002<ol00P000:Ooool003Soool00ol0VOooooooo`0Roooo00@0003oool00000000;<ol000@0
000co`0co`0co`0200001C?o00030000oooooooo0:Koool003Soool00ol0VOooooooo`0Roooo00@0
003oooooool00008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo
0:Koool003Soool00ol0VOooooooo`0Soooo0`0000Pco`0400000c?o00<00004<ol000<0003ooooo
ool0Y_ooo`00>?ooo`03o`2Ioooooooo02Goool00`0003?o03?o000D<ol00P000:Ooool003Soool0
0ol0VOooooooo`0Uoooo00<0000co`0co`0053?o00030000oooooooo0:Koool003Soool00ol0VOoo
ooooo`0Voooo00<0000co`0co`004c?o00030000oooooooo0:Koool003Soool00ol0VOooooooo`0V
oooo00<0000co`0co`004c?o00030000oooooooo0:Koool003Soool00ol0VOooooooo`0Voooo00<0
000co`0co`004c?o0080002Woooo000hoooo00?o09Woooooool09_ooo`030000<ol0<ol001<co`00
0`000?ooooooo`2Voooo000hoooo00?o09Woooooool09oooo`030000<ol0<ol0018co`000`000?oo
ooooo`2Voooo000hoooo00?o09Woooooool09oooo`030000<ol0<ol0018co`000`000?ooooooo`2V
oooo000hoooo00?o09Woooooool09oooo`030000<ol0<ol0018co`020000Yoooo`00>?ooo`03o`2I
oooooooo02Ooool00`0003?o03?o000B<ol000<0003oooooool0Y_ooo`00>?ooo`03o`2Ioooooooo
02Soool00`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00>?ooo`03o`2Ioooooooo02Soool0
0`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00>?ooo`03o`2Ioooooooo02Soool00`0003?o
03?o000A<ol00P000:Ooool003Soool00ol0VOooooooo`0Xoooo00<0000co`0co`004C?o00030000
oooooooo0:Koool003Soool00ol0VOooooooo`0Xoooo00<0000co`0co`002C?o00D00003<ol000<0
003oooooool0Y_ooo`00>?ooo`03o`2Ioooooooo02Woool00`0003?o03?o000:<ol000<0000co`0c
o`000c?o00030000oooooooo0:Koool003Soool00ol0VOooooooo`0Yoooo00<0000co`0co`002S?o
00030000<ol0<ol000<co`020000Yoooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?oo
o`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo``co`0200001C?o0:Woool006GooolB<ol0ZOoo
o`00IOoooa8co`2Yoooo001Uoooo4S?o00;oool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00IOoooa8co`000oooo`000?ooo`09oooo00<0003oooooool07oooo`030000oooooooo07Soool0
06GooolB<ol000?oool0003oool00oooo`800004oooo00<0003oooooool03?ooo`@00003oooo0P00
00Coool200001?ooo`030000oooooooo07Soool006GooolB<ol000?oool0003oool00_ooo`040000
oooooooo00001?ooo`030000oooooooo00Coool400000oooo`030000oooooooo00Woool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001Uoooo4S?o00030000oooooooo00;oool00`000?oo
ooooo`0Doooo00<0003oooooool02_ooo`030000oooooooo00?oool00`000?ooooooo`1goooo001V
oooo4C?o0004oooo0000oooooooo1@0001Coool00`000?ooooooo`0:oooo00D0003oooooooooool0
0000N_ooo`00I_oooa4co`000oooo`000?ooo`02oooo00<0003oooooool04oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool006KooolA<ol00_ooo`030000
oooooooo01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00I_oooa4co`2Yoooo001V
oooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.12507 .30902 L
.14415 .30902 L
.16254 .30902 L
.16783 .30902 L
.17044 .30902 L
.17284 .30902 L
.17502 .30902 L
.17612 .30902 L
s
.17612 .30902 m
.17624 .61803 L
s
0 .4 1 r
.02381 .51332 m
.06244 .50871 L
.10458 .502 L
.12507 .49796 L
.14415 .49363 L
.16254 .48889 L
.16783 .48742 L
.17044 .48667 L
.17284 .48597 L
.17502 .48532 L
.17612 .48499 L
.17733 .30902 L
.17854 .30902 L
.17985 .30902 L
.18108 .30902 L
.18221 .30902 L
.18349 .30902 L
.18471 .30902 L
.1858 .30902 L
.18697 .30902 L
.18826 .30902 L
.18891 .30902 L
.18962 .30902 L
.19088 .30902 L
.19205 .30902 L
.19324 .30902 L
.19436 .30902 L
.19537 .30902 L
.19646 .30902 L
.19766 .30902 L
.19892 .30902 L
.2 .30902 L
.20119 .30902 L
.2025 .30902 L
.20316 .30902 L
.20388 .30902 L
.20517 .30902 L
.20634 .30902 L
.20705 .30902 L
.20773 .30902 L
.20844 .30902 L
.20921 .30902 L
.20988 .30902 L
.2106 .30902 L
.21188 .30902 L
.21307 .30902 L
.21435 .30902 L
.21546 .30902 L
.21666 .30902 L
.21739 .30902 L
Mistroke
.21807 .30902 L
.21872 .30902 L
.21941 .30902 L
.22072 .30902 L
.22192 .30902 L
.22312 .30902 L
.22425 .30902 L
.22548 .30902 L
.22681 .30902 L
.22747 .30902 L
.22819 .30902 L
.22951 .30902 L
.23079 .30902 L
.23197 .30902 L
.23307 .30902 L
.2341 .30902 L
.23523 .30902 L
.23645 .30902 L
.23766 .30902 L
.23893 .30902 L
.24002 .30902 L
.2412 .30902 L
.24188 .30902 L
.24261 .30902 L
.2433 .30902 L
.24394 .30902 L
.24515 .30902 L
.24643 .30902 L
.24709 .30902 L
.2478 .30902 L
.24908 .30902 L
.24987 .30902 L
.25061 .30902 L
.25128 .30902 L
.252 .30902 L
.25717 .30902 L
.25841 .30902 L
.25971 .30902 L
.26082 .30902 L
.26204 .30902 L
.26316 .30902 L
.26437 .30902 L
.26551 .30902 L
.26655 .30902 L
.26775 .30902 L
.26905 .30902 L
.27028 .30902 L
.27142 .30902 L
.27266 .30902 L
.27382 .30902 L
Mistroke
.27509 .30902 L
.2758 .30902 L
.27645 .30902 L
.27776 .30902 L
.2785 .30902 L
.27919 .30902 L
.28179 .30902 L
.28311 .30902 L
.28385 .30902 L
.28453 .30902 L
.28579 .30902 L
.28642 .30902 L
.28712 .30902 L
.28833 .30902 L
.28962 .30902 L
.29084 .30902 L
.29195 .30902 L
.29262 .30902 L
.29334 .30902 L
.29462 .30902 L
.29528 .30902 L
.296 .30902 L
.29678 .30902 L
.29752 .30902 L
.29816 .30902 L
.29886 .30902 L
.29959 .30902 L
.30027 .30902 L
.30148 .30902 L
.30279 .30902 L
.30402 .30902 L
.30472 .30902 L
.30538 .30902 L
.30607 .30902 L
.3067 .30902 L
.30744 .30902 L
.30812 .30902 L
.30933 .30902 L
.31064 .30902 L
.3118 .30902 L
.31304 .30902 L
.31379 .30902 L
.31448 .30902 L
.31524 .30902 L
.31604 .30902 L
.31674 .30902 L
.31739 .30902 L
.31811 .30902 L
.31887 .30902 L
.31955 .30902 L
Mistroke
.32029 .30902 L
.32099 .30902 L
.32163 .30902 L
.32285 .30902 L
.32415 .30902 L
.32539 .30902 L
.32653 .30902 L
.32785 .30902 L
.3291 .30902 L
.33025 .30902 L
.33131 .30902 L
.33249 .30902 L
.33374 .30902 L
.33445 .30902 L
.33511 .30902 L
.33583 .30902 L
.33659 .30902 L
.33787 .30902 L
.33861 .30902 L
.33928 .30902 L
.34053 .30902 L
.34122 .30902 L
.34188 .30902 L
.34304 .30902 L
.3443 .30902 L
.34552 .30902 L
.34663 .30902 L
.34786 .30902 L
.34915 .30902 L
.35027 .30902 L
.35132 .30902 L
.35247 .30902 L
.3537 .30902 L
.35439 .30902 L
.35504 .30902 L
.35574 .30902 L
.35649 .30902 L
.35775 .30902 L
.35846 .30902 L
.35913 .30902 L
.36037 .30902 L
.36151 .30902 L
.36282 .30902 L
.36407 .30902 L
.36475 .30902 L
.36539 .30902 L
.36659 .30902 L
.36788 .30902 L
.36861 .30902 L
.36928 .30902 L
Mistroke
.37049 .30902 L
.37178 .30902 L
.373 .30902 L
.37412 .30902 L
.37542 .30902 L
.37666 .30902 L
.37735 .30902 L
.37799 .30902 L
.3787 .30902 L
.37945 .30902 L
.38011 .30902 L
.38083 .30902 L
.38212 .30902 L
.38287 .30902 L
.38366 .30902 L
.38434 .30902 L
.38507 .30902 L
.38572 .30902 L
.3864 .30902 L
.38762 .30902 L
.38893 .30902 L
.38967 .30902 L
.39037 .30902 L
.39163 .30902 L
.39278 .30902 L
.39342 .30902 L
.39411 .30902 L
.39537 .30902 L
.39648 .30902 L
.39772 .30902 L
.39901 .30902 L
.40022 .30902 L
.40135 .30902 L
.40238 .30902 L
.40352 .30902 L
.40471 .30902 L
.40602 .30902 L
.40722 .30902 L
.40989 .30902 L
.41472 .30902 L
.42567 .30902 L
.46561 .30902 L
.50403 .30902 L
.54491 .30902 L
.58427 .30902 L
.62211 .30902 L
.6624 .30902 L
.70118 .30902 L
.74241 .30902 L
.78213 .30902 L
Mistroke
.82033 .30902 L
.86098 .30902 L
.90012 .30902 L
.94171 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000E<ol000<0I_lco`0co`001c?o00030000<ol0<ol002dco`000`000?ooooooo`0]
oooo00<0003oooooool0;Oooo`030000oooooooo02koool00`000?ooooooo`0Eoooo000Xoooo1P00
00lco`000`1Voc?o03?o000g<ol000<0003oooooool0Y_ooo`00;_ooo`D0000:<ol000<0I_lco`0c
o`00=c?o0080002Woooo000coooo100000Hco`000`1Voc?o03?o000g<ol000<0003oooooool0Y_oo
o`00=oooo`800004<ol000<0I_lco`0co`00=c?o00030000oooooooo0:Koool003Woool3000000<c
o`00I_lco`00>3?o00030000oooooooo0:Koool003coool00`00001Voc?o000h<ol00P000:Ooool0
03goool00`1Vo`000000000g<ol000<0003oooooool0Y_ooo`00?Oooo`0306Kooooooooo0080000e
<ol000<0003oooooool0Y_ooo`00?Oooo`0306Kooooooooo00;oool20000<c?o00030000oooooooo
0:Koool003goool00`1Vooooooooo`04oooo0P00034co`020000Yoooo`00?Oooo`0306Kooooooooo
00Koool00`0003?o03?o000^<ol000<0003oooooool0Y_ooo`00?Oooo`0306Kooooooooo00Ooool0
0`0003?o03?o000]<ol000<0003oooooool0Y_ooo`00?Oooo`0306Kooooooooo00Soool00`0003?o
03?o000/<ol000<0003oooooool0Y_ooo`00?Oooo`0306Kooooooooo00Woool00`0003?o03?o000[
<ol00P000:Ooool003goool00`1Vooooooooo`0:oooo00<0000co`0co`00:S?o00030000oooooooo
0:Koool003goool00`1Vooooooooo`0;oooo00<0000co`0co`0043?o00800004<ol00P0000<co`04
00000c?o00800005<ol000<0003oooooool0Y_ooo`00?Oooo`0306Kooooooooo00coool00`0003?o
03?o000><ol000@0000co`0co`000008<ol000<0000co`0co`000c?o00040000<ol0<ol0000013?o
00030000oooooooo0:Koool003goool00`1Vooooooooo`0=oooo00<0000co`0co`003C?o00040000
<ol0<ol000002C?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol00P000:Ooool003goool0
0`1Vooooooooo`0>oooo00<0000co`0co`0033?o00040000<ol0<ol000002S?o00030000<ol0<ol0
008co`0200001C?o00030000oooooooo0:Koool003goool00`1Vooooooooo`0?oooo00<0000co`0c
o`002c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`00
0`000?ooooooo`2Voooo000moooo00<0I_ooooooool03oooo`030000<ol0<ol000`co`0200002S?o
00800004<ol00`0000@co`000`000?ooooooo`2Voooo000moooo00<0I_ooooooool04?ooo`030000
<ol0<ol002@co`020000Yoooo`00?Oooo`0306Kooooooooo017oool00`0003?o03?o000S<ol000<0
003oooooool0Y_ooo`00?Oooo`0306Kooooooooo01;oool00`0003?o03?o000R<ol000<0003ooooo
ool0Y_ooo`00?Oooo`0306Kooooooooo01;oool00`0003?o03?o000R<ol000<0003oooooool0Y_oo
o`00?Oooo`0306Kooooooooo01?oool00`0003?o03?o000Q<ol00P000:Ooool003goool00`1Voooo
ooooo`0Coooo00<0000co`0co`008C?o00030000oooooooo0:Koool003goool00`1Vooooooooo`0D
oooo00<0000co`0co`0083?o00030000oooooooo0:Koool003goool00`1Vooooooooo`0Doooo00<0
000co`0co`0083?o00030000oooooooo0:Koool003goool00`1Vooooooooo`0Eoooo00<0000co`0c
o`007c?o0080002Woooo000moooo00<0I_ooooooool05Oooo`030000<ol0<ol001lco`000`000?oo
ooooo`2Voooo000moooo00<0I_ooooooool05_ooo`030000<ol0<ol001hco`000`000?ooooooo`2V
oooo000moooo00<0I_ooooooool05_ooo`030000<ol0<ol001hco`000`000?ooooooo`2Voooo000m
oooo00<0I_ooooooool05oooo`030000<ol0<ol001dco`020000Yoooo`00?Oooo`0306Kooooooooo
01Ooool00`0003?o03?o000M<ol000<0003oooooool0Y_ooo`00?Oooo`0306Kooooooooo01Soool0
0`0003?o03?o0009<ol00P0000@co`02000013?o00800005<ol000<0003oooooool0Y_ooo`00?Ooo
o`0306Kooooooooo01Soool00`0003?o03?o0008<ol000@0000co`0co`000008<ol000@0000co`0c
o`000004<ol000<0003oooooool0Y_ooo`00?Oooo`0306Kooooooooo01Woool00`0003?o03?o0007
<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o0080002Woooo000moooo00<0I_oooooo
ool06Oooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`0200001C?o00030000oooooooo
0:Koool003goool00`1Vooooooooo`0Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o
00030000<ol0<ol000@co`000`000?ooooooo`2Voooo000moooo00<0I_ooooooool06_ooo`030000
<ol0<ol000Lco`0200002S?o00<00004<ol000<0003oooooool0Y_ooo`00?Oooo`0306Kooooooooo
01[oool00`0003?o03?o000J<ol00P000:Ooool003_oool306Ko7?ooo`030000<ol0<ol001Xco`00
0`000?ooooooo`2Voooo000hoooo101Vo`03ooooo`2Ioooo01coool00`0003?o03?o000I<ol000<0
003oooooool0Y_ooo`00<oooo`D0I_l5oooo00?o09Woooooool06oooo`030000<ol0<ol001Tco`02
0000Yoooo`00;_ooo`D0I_l:oooo00?o09Woooooool06oooo`030000<ol0<ol001Tco`000`000?oo
ooooo`2Voooo000Yoooo1@1Vo`ooool00ol0VOooooooo`0Loooo00<0000co`0co`0063?o00030000
oooooooo0:Koool002?oool606Ko5?ooo`03o`2Ioooooooo01coool00`0003?o03?o000H<ol000<0
003oooooool0Y_ooo`007?ooo`L0I_lJoooo00?o09Woooooool07?ooo`030000<ol0<ol001Pco`02
0000Yoooo`005_ooo`H0I_lQoooo00?o09Woooooool07Oooo`030000<ol0<ol001Lco`000`000?oo
ooooo`2Voooo000moooo00?o09Woooooool07Oooo`030000<ol0<ol001Lco`000`000?ooooooo`2V
oooo000moooo00?o09Woooooool07Oooo`030000<ol0<ol001Lco`000`000?ooooooo`2Voooo000m
oooo00?o09Woooooool07_ooo`030000<ol0<ol001Hco`020000Yoooo`00?Oooo`03o`2Ioooooooo
01koool00`0003?o03?o000F<ol000<0003oooooool0Y_ooo`00?Oooo`03o`2Ioooooooo01koool2
000013?o00800005<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Y_ooo`00?Ooo
o`03o`2Ioooooooo01goool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0
000co`0co`000S?o00030000oooooooo0:Koool003goool00ol0VOooooooo`0Moooo00@0003oool0
0000000:<ol000<0000co`0co`0013?o00030000<ol0<ol0008co`020000Yoooo`00?Oooo`03o`2I
oooooooo01goool010000?ooo`00000000/co`00100003?o03?o03?o00800005<ol000<0003ooooo
ool0Y_ooo`00?Oooo`03o`2Ioooooooo01goool010000?ooooooo`0000Pco`00100003?o03?o0000
00<co`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00?Oooo`03o`2Ioooooooo01koool3
000023?o00@00003<ol00`0000@co`000`000?ooooooo`2Voooo000moooo00?o09Woooooool08?oo
o`030000<ol0<ol001@co`020000Yoooo`00?Oooo`03o`2Ioooooooo023oool00`0003?o03?o000D
<ol000<0003oooooool0Y_ooo`00?Oooo`03o`2Ioooooooo027oool00`0003?o03?o000C<ol000<0
003oooooool0Y_ooo`00?Oooo`03o`2Ioooooooo027oool00`0003?o03?o000C<ol000<0003ooooo
ool0Y_ooo`00?Oooo`03o`2Ioooooooo027oool00`0003?o03?o000C<ol00P000:Ooool003goool0
0ol0VOooooooo`0Qoooo00<0000co`0co`004c?o00030000oooooooo0:Koool003goool00ol0VOoo
ooooo`0Roooo00<0000co`0co`004S?o00030000oooooooo0:Koool003goool00ol0VOooooooo`0R
oooo00<0000co`0co`004S?o00030000oooooooo0:Koool003goool00ol0VOooooooo`0Roooo00<0
000co`0co`004S?o0080002Woooo000moooo00?o09Woooooool08_ooo`030000<ol0<ol0018co`00
0`000?ooooooo`2Voooo000moooo00?o09Woooooool08oooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Voooo000moooo00?o09Woooooool08oooo`030000<ol0<ol0014co`000`000?ooooooo`2V
oooo000moooo00?o09Woooooool08oooo`030000<ol0<ol0014co`020000Yoooo`00?Oooo`03o`2I
oooooooo02?oool00`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00?Oooo`03o`2Ioooooooo
02?oool00`0003?o03?o0009<ol01@0000<co`000`000?ooooooo`2Voooo000moooo00?o09Wooooo
ool09?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003oooooool0Y_ooo`00?Ooo
o`03o`2Ioooooooo02Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o0080002Woooo001T
oooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001T
oooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol00_oo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Uoooo4S?o0003oooo0000oooo00Woool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`03oooo0P00
00Coool00`000?ooooooo`0<oooo100000?oool200000oooo`@00003oooo00<0003oooooool0N?oo
o`00IOoooa8co`000oooo`000?ooo`02oooo00@0003oooooool00004oooo00<0003oooooool01?oo
o`@00003oooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?ooooooo`1hoooo001U
oooo4S?o00030000oooooooo00;oool00`000?ooooooo`0Doooo00<0003oooooool02Oooo`030000
oooooooo00Coool00`000?ooooooo`1goooo001Voooo4C?o0004oooo0000oooooooo1@0001Coool0
0`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07Soool006KooolA<ol000?o
ool0003oool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001Voooo4C?o00;oool00`000?ooooooo`0Goooo0P0000[oool2
00000oooo`030000oooooooo07Woool006KooolA<ol0ZOooo`00I_oooa4co`2Yoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.527129 0.25166 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.14964 .29652 -12 -9 ]
[.14964 .29652 12 0 ]
[.27547 .29652 -6 -9 ]
[.27547 .29652 6 0 ]
[.4013 .29652 -12 -9 ]
[.4013 .29652 12 0 ]
[.65296 .29652 -9 -9 ]
[.65296 .29652 9 0 ]
[.77879 .29652 -3 -9 ]
[.77879 .29652 3 0 ]
[.90462 .29652 -9 -9 ]
[.90462 .29652 9 0 ]
[.51463 0 -12 -4.5 ]
[.51463 0 0 4.5 ]
[.51463 .07725 -30 -4.5 ]
[.51463 .07725 0 4.5 ]
[.51463 .15451 -24 -4.5 ]
[.51463 .15451 0 4.5 ]
[.51463 .23176 -30 -4.5 ]
[.51463 .23176 0 4.5 ]
[.51463 .38627 -24 -4.5 ]
[.51463 .38627 0 4.5 ]
[.51463 .46353 -18 -4.5 ]
[.51463 .46353 0 4.5 ]
[.51463 .54078 -24 -4.5 ]
[.51463 .54078 0 4.5 ]
[.51463 .61803 -6 -4.5 ]
[.51463 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.14964 .30902 m
.14964 .31527 L
s
[(-1.5)] .14964 .29652 0 1 Mshowa
.27547 .30902 m
.27547 .31527 L
s
[(-1)] .27547 .29652 0 1 Mshowa
.4013 .30902 m
.4013 .31527 L
s
[(-0.5)] .4013 .29652 0 1 Mshowa
.65296 .30902 m
.65296 .31527 L
s
[(0.5)] .65296 .29652 0 1 Mshowa
.77879 .30902 m
.77879 .31527 L
s
[(1)] .77879 .29652 0 1 Mshowa
.90462 .30902 m
.90462 .31527 L
s
[(1.5)] .90462 .29652 0 1 Mshowa
.125 Mabswid
.04898 .30902 m
.04898 .31277 L
s
.07414 .30902 m
.07414 .31277 L
s
.09931 .30902 m
.09931 .31277 L
s
.12447 .30902 m
.12447 .31277 L
s
.17481 .30902 m
.17481 .31277 L
s
.19997 .30902 m
.19997 .31277 L
s
.22514 .30902 m
.22514 .31277 L
s
.2503 .30902 m
.2503 .31277 L
s
.30064 .30902 m
.30064 .31277 L
s
.3258 .30902 m
.3258 .31277 L
s
.35097 .30902 m
.35097 .31277 L
s
.37613 .30902 m
.37613 .31277 L
s
.42647 .30902 m
.42647 .31277 L
s
.45163 .30902 m
.45163 .31277 L
s
.4768 .30902 m
.4768 .31277 L
s
.50196 .30902 m
.50196 .31277 L
s
.5523 .30902 m
.5523 .31277 L
s
.57746 .30902 m
.57746 .31277 L
s
.60263 .30902 m
.60263 .31277 L
s
.62779 .30902 m
.62779 .31277 L
s
.67813 .30902 m
.67813 .31277 L
s
.70329 .30902 m
.70329 .31277 L
s
.72846 .30902 m
.72846 .31277 L
s
.75362 .30902 m
.75362 .31277 L
s
.80396 .30902 m
.80396 .31277 L
s
.82912 .30902 m
.82912 .31277 L
s
.85429 .30902 m
.85429 .31277 L
s
.87945 .30902 m
.87945 .31277 L
s
.92979 .30902 m
.92979 .31277 L
s
.95495 .30902 m
.95495 .31277 L
s
.98012 .30902 m
.98012 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.52713 0 m
.53338 0 L
s
[(-1)] .51463 0 1 0 Mshowa
.52713 .07725 m
.53338 .07725 L
s
[(-0.75)] .51463 .07725 1 0 Mshowa
.52713 .15451 m
.53338 .15451 L
s
[(-0.5)] .51463 .15451 1 0 Mshowa
.52713 .23176 m
.53338 .23176 L
s
[(-0.25)] .51463 .23176 1 0 Mshowa
.52713 .38627 m
.53338 .38627 L
s
[(0.25)] .51463 .38627 1 0 Mshowa
.52713 .46353 m
.53338 .46353 L
s
[(0.5)] .51463 .46353 1 0 Mshowa
.52713 .54078 m
.53338 .54078 L
s
[(0.75)] .51463 .54078 1 0 Mshowa
.52713 .61803 m
.53338 .61803 L
s
[(1)] .51463 .61803 1 0 Mshowa
.125 Mabswid
.52713 .01545 m
.53088 .01545 L
s
.52713 .0309 m
.53088 .0309 L
s
.52713 .04635 m
.53088 .04635 L
s
.52713 .0618 m
.53088 .0618 L
s
.52713 .09271 m
.53088 .09271 L
s
.52713 .10816 m
.53088 .10816 L
s
.52713 .12361 m
.53088 .12361 L
s
.52713 .13906 m
.53088 .13906 L
s
.52713 .16996 m
.53088 .16996 L
s
.52713 .18541 m
.53088 .18541 L
s
.52713 .20086 m
.53088 .20086 L
s
.52713 .21631 m
.53088 .21631 L
s
.52713 .24721 m
.53088 .24721 L
s
.52713 .26266 m
.53088 .26266 L
s
.52713 .27812 m
.53088 .27812 L
s
.52713 .29357 m
.53088 .29357 L
s
.52713 .32447 m
.53088 .32447 L
s
.52713 .33992 m
.53088 .33992 L
s
.52713 .35537 m
.53088 .35537 L
s
.52713 .37082 m
.53088 .37082 L
s
.52713 .40172 m
.53088 .40172 L
s
.52713 .41717 m
.53088 .41717 L
s
.52713 .43262 m
.53088 .43262 L
s
.52713 .44807 m
.53088 .44807 L
s
.52713 .47898 m
.53088 .47898 L
s
.52713 .49443 m
.53088 .49443 L
s
.52713 .50988 m
.53088 .50988 L
s
.52713 .52533 m
.53088 .52533 L
s
.52713 .55623 m
.53088 .55623 L
s
.52713 .57168 m
.53088 .57168 L
s
.52713 .58713 m
.53088 .58713 L
s
.52713 .60258 m
.53088 .60258 L
s
.25 Mabswid
.52713 0 m
.52713 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04866 .31294 L
.07485 .31429 L
.10142 .31613 L
.13052 .31889 L
.15638 .32224 L
.18405 .32709 L
.21219 .33389 L
.2388 .34267 L
.26519 .35451 L
.28956 .36918 L
.3143 .38908 L
.34155 .41902 L
.36719 .45793 L
.39478 .51644 L
.40813 .5532 L
.4227 .60155 L
s
.4227 .60155 m
.42679 .61803 L
s
.52759 .61803 m
.52783 .30902 L
.52947 .30902 L
.55388 .30902 L
.60776 .30902 L
.65964 .30902 L
.70952 .30902 L
.76263 .30902 L
.81375 .30902 L
.8681 .30902 L
.92045 .30902 L
.9708 .30902 L
s
.9708 .30902 m
1 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04866 .31294 L
.07485 .31429 L
.10142 .31613 L
.13052 .31889 L
.15638 .32224 L
.18405 .32709 L
.21219 .33389 L
.2388 .34267 L
.26519 .35451 L
.28956 .36918 L
.3143 .38908 L
.34155 .41902 L
.36719 .45793 L
.39478 .51644 L
.40813 .5532 L
.4227 .60155 L
.43662 .65768 L
.44924 .71904 L
.47523 .88801 L
.4895 1.01446 L
.50294 1.16447 L
.51584 1.34603 L
.52234 1.45529 L
.52412 1.48768 L
.5251 1.506 L
.52603 1.52368 L
.52689 1.54041 L
.52783 .30902 L
.52947 .30902 L
.55388 .30902 L
.60776 .30902 L
.65964 .30902 L
.70952 .30902 L
.76263 .30902 L
.81375 .30902 L
.8681 .30902 L
.92045 .30902 L
.9708 .30902 L
1.02439 .30902 L
1.07598 .30902 L
1.13081 .30902 L
1.18363 .30902 L
1.23445 .30902 L
1.28211 .30902 L
1.28211 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04866 .31294 L
.07485 .31429 L
.10142 .31613 L
.13052 .31889 L
.15638 .32224 L
.18405 .32709 L
.21219 .33389 L
.2388 .34267 L
.26519 .35451 L
.28956 .36918 L
.3143 .38908 L
.34155 .41902 L
.36719 .45793 L
.39478 .51644 L
.40813 .5532 L
.4227 .60155 L
s
.4227 .60155 m
.42679 .61803 L
s
.52759 .61803 m
.52783 .30902 L
.52947 .30902 L
.55388 .30902 L
.60776 .30902 L
.65964 .30902 L
.70952 .30902 L
.76263 .30902 L
.81375 .30902 L
.8681 .30902 L
.92045 .30902 L
.9708 .30902 L
s
.9708 .30902 m
1 .30902 L
s
1 0 .6 r
.02381 .30902 m
.07485 .30902 L
.13052 .30902 L
.18281 .30902 L
.20913 .30902 L
.23309 .30902 L
.23946 .30902 L
.24282 .30902 L
.24638 .30902 L
.24788 .30902 L
.24949 .30902 L
s
.24949 .30902 m
.24958 .61803 L
s
0 .4 1 r
.02381 .51455 m
.07485 .51035 L
.13052 .50426 L
.18281 .49666 L
.20913 .49199 L
.23309 .48715 L
.23946 .48577 L
.24282 .48502 L
.24638 .48421 L
.24788 .48387 L
.24949 .48349 L
.25041 .30902 L
.25126 .30902 L
.25291 .30902 L
.25439 .30902 L
.25601 .30902 L
.25753 .30902 L
.25895 .30902 L
.26068 .30902 L
.26166 .30902 L
.26256 .30902 L
.26422 .30902 L
.26505 .30902 L
.26597 .30902 L
.26756 .30902 L
.26926 .30902 L
.27087 .30902 L
.27234 .30902 L
.27322 .30902 L
.27416 .30902 L
.27585 .30902 L
.27678 .30902 L
.27766 .30902 L
.27863 .30902 L
.27967 .30902 L
.28051 .30902 L
.28143 .30902 L
.28239 .30902 L
.28329 .30902 L
.28489 .30902 L
.28661 .30902 L
.28824 .30902 L
.28916 .30902 L
.29003 .30902 L
.29177 .30902 L
.29275 .30902 L
.29365 .30902 L
.29524 .30902 L
.29698 .30902 L
.29862 .30902 L
Mistroke
.30014 .30902 L
.30106 .30902 L
.30206 .30902 L
.303 .30902 L
.30387 .30902 L
.30551 .30902 L
.30725 .30902 L
.30815 .30902 L
.30911 .30902 L
.31086 .30902 L
.31192 .30902 L
.31293 .30902 L
.31383 .30902 L
.31481 .30902 L
.31635 .30902 L
.31778 .30902 L
.31928 .30902 L
.32091 .30902 L
.32257 .30902 L
.3235 .30902 L
.32434 .30902 L
.32595 .30902 L
.32748 .30902 L
.32835 .30902 L
.32928 .30902 L
.33094 .30902 L
.3318 .30902 L
.33272 .30902 L
.33373 .30902 L
.33468 .30902 L
.33555 .30902 L
.33649 .30902 L
.33821 .30902 L
.33989 .30902 L
.34144 .30902 L
.34293 .30902 L
.34454 .30902 L
.34607 .30902 L
.34746 .30902 L
.34901 .30902 L
.35071 .30902 L
.35156 .30902 L
.35248 .30902 L
.35412 .30902 L
.35587 .30902 L
.35685 .30902 L
.35776 .30902 L
.35942 .30902 L
.36026 .30902 L
.36119 .30902 L
Mistroke
.36279 .30902 L
.36451 .30902 L
.36613 .30902 L
.36761 .30902 L
.36932 .30902 L
.37028 .30902 L
.37115 .30902 L
.37283 .30902 L
.37442 .30902 L
.37533 .30902 L
.37628 .30902 L
.37799 .30902 L
.37895 .30902 L
.37984 .30902 L
.38081 .30902 L
.38186 .30902 L
.3836 .30902 L
.38458 .30902 L
.38549 .30902 L
.38716 .30902 L
.388 .30902 L
.38894 .30902 L
.39054 .30902 L
.39226 .30902 L
.39389 .30902 L
.39539 .30902 L
.39708 .30902 L
.39867 .30902 L
.40011 .30902 L
.40166 .30902 L
.40335 .30902 L
.4042 .30902 L
.40514 .30902 L
.4068 .30902 L
.40835 .30902 L
.40991 .30902 L
.41139 .30902 L
.41272 .30902 L
.41417 .30902 L
.41574 .30902 L
.41741 .30902 L
.41898 .30902 L
.42041 .30902 L
.42213 .30902 L
.42299 .30902 L
.42394 .30902 L
.42562 .30902 L
.42719 .30902 L
.42814 .30902 L
.42904 .30902 L
Mistroke
.43072 .30902 L
.43167 .30902 L
.43254 .30902 L
.43349 .30902 L
.43451 .30902 L
.43608 .30902 L
.43776 .30902 L
.43936 .30902 L
.44082 .30902 L
.44252 .30902 L
.44348 .30902 L
.44438 .30902 L
.44602 .30902 L
.44693 .30902 L
.44777 .30902 L
.44935 .30902 L
.45083 .30902 L
.45246 .30902 L
.4542 .30902 L
.45507 .30902 L
.45603 .30902 L
.45776 .30902 L
.45944 .30902 L
.461 .30902 L
.46245 .30902 L
.46381 .30902 L
.4653 .30902 L
.46691 .30902 L
.4685 .30902 L
.47018 .30902 L
.47161 .30902 L
.47318 .30902 L
.47407 .30902 L
.47504 .30902 L
.47595 .30902 L
.47679 .30902 L
.47838 .30902 L
.48007 .30902 L
.48094 .30902 L
.48188 .30902 L
.48357 .30902 L
.48461 .30902 L
.48559 .30902 L
.48647 .30902 L
.48743 .30902 L
.48833 .30902 L
.48918 .30902 L
.49076 .30902 L
.49246 .30902 L
.49334 .30902 L
Mistroke
.49431 .30902 L
.49592 .30902 L
.49763 .30902 L
.49921 .30902 L
.50069 .30902 L
.50236 .30902 L
.5032 .30902 L
.50413 .30902 L
.50577 .30902 L
.50732 .30902 L
.5082 .30902 L
.50913 .30902 L
.51079 .30902 L
.51171 .30902 L
.51257 .30902 L
.51351 .30902 L
.51452 .30902 L
.51622 .30902 L
.51717 .30902 L
.51805 .30902 L
.51967 .30902 L
.52139 .30902 L
.52292 .30902 L
.52435 .30902 L
.52593 .30902 L
.52762 .30902 L
.52925 .30902 L
.53077 .30902 L
.5342 .30902 L
.54044 .30902 L
.55214 .30902 L
.60396 .30902 L
.65378 .30902 L
.70684 .30902 L
.7579 .30902 L
.81219 .30902 L
.86449 .30902 L
.91478 .30902 L
.96831 .30902 L
Mfstroke
.96831 .30902 m
1 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.527129 0.25166 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.14964 .29652 -12 -9 ]
[.14964 .29652 12 0 ]
[.27547 .29652 -6 -9 ]
[.27547 .29652 6 0 ]
[.4013 .29652 -12 -9 ]
[.4013 .29652 12 0 ]
[.65296 .29652 -9 -9 ]
[.65296 .29652 9 0 ]
[.77879 .29652 -3 -9 ]
[.77879 .29652 3 0 ]
[.90462 .29652 -9 -9 ]
[.90462 .29652 9 0 ]
[.51463 0 -12 -4.5 ]
[.51463 0 0 4.5 ]
[.51463 .07725 -30 -4.5 ]
[.51463 .07725 0 4.5 ]
[.51463 .15451 -24 -4.5 ]
[.51463 .15451 0 4.5 ]
[.51463 .23176 -30 -4.5 ]
[.51463 .23176 0 4.5 ]
[.51463 .38627 -24 -4.5 ]
[.51463 .38627 0 4.5 ]
[.51463 .46353 -18 -4.5 ]
[.51463 .46353 0 4.5 ]
[.51463 .54078 -24 -4.5 ]
[.51463 .54078 0 4.5 ]
[.51463 .61803 -6 -4.5 ]
[.51463 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.14964 .30902 m
.14964 .31527 L
s
[(-1.5)] .14964 .29652 0 1 Mshowa
.27547 .30902 m
.27547 .31527 L
s
[(-1)] .27547 .29652 0 1 Mshowa
.4013 .30902 m
.4013 .31527 L
s
[(-0.5)] .4013 .29652 0 1 Mshowa
.65296 .30902 m
.65296 .31527 L
s
[(0.5)] .65296 .29652 0 1 Mshowa
.77879 .30902 m
.77879 .31527 L
s
[(1)] .77879 .29652 0 1 Mshowa
.90462 .30902 m
.90462 .31527 L
s
[(1.5)] .90462 .29652 0 1 Mshowa
.125 Mabswid
.04898 .30902 m
.04898 .31277 L
s
.07414 .30902 m
.07414 .31277 L
s
.09931 .30902 m
.09931 .31277 L
s
.12447 .30902 m
.12447 .31277 L
s
.17481 .30902 m
.17481 .31277 L
s
.19997 .30902 m
.19997 .31277 L
s
.22514 .30902 m
.22514 .31277 L
s
.2503 .30902 m
.2503 .31277 L
s
.30064 .30902 m
.30064 .31277 L
s
.3258 .30902 m
.3258 .31277 L
s
.35097 .30902 m
.35097 .31277 L
s
.37613 .30902 m
.37613 .31277 L
s
.42647 .30902 m
.42647 .31277 L
s
.45163 .30902 m
.45163 .31277 L
s
.4768 .30902 m
.4768 .31277 L
s
.50196 .30902 m
.50196 .31277 L
s
.5523 .30902 m
.5523 .31277 L
s
.57746 .30902 m
.57746 .31277 L
s
.60263 .30902 m
.60263 .31277 L
s
.62779 .30902 m
.62779 .31277 L
s
.67813 .30902 m
.67813 .31277 L
s
.70329 .30902 m
.70329 .31277 L
s
.72846 .30902 m
.72846 .31277 L
s
.75362 .30902 m
.75362 .31277 L
s
.80396 .30902 m
.80396 .31277 L
s
.82912 .30902 m
.82912 .31277 L
s
.85429 .30902 m
.85429 .31277 L
s
.87945 .30902 m
.87945 .31277 L
s
.92979 .30902 m
.92979 .31277 L
s
.95495 .30902 m
.95495 .31277 L
s
.98012 .30902 m
.98012 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.52713 0 m
.53338 0 L
s
[(-1)] .51463 0 1 0 Mshowa
.52713 .07725 m
.53338 .07725 L
s
[(-0.75)] .51463 .07725 1 0 Mshowa
.52713 .15451 m
.53338 .15451 L
s
[(-0.5)] .51463 .15451 1 0 Mshowa
.52713 .23176 m
.53338 .23176 L
s
[(-0.25)] .51463 .23176 1 0 Mshowa
.52713 .38627 m
.53338 .38627 L
s
[(0.25)] .51463 .38627 1 0 Mshowa
.52713 .46353 m
.53338 .46353 L
s
[(0.5)] .51463 .46353 1 0 Mshowa
.52713 .54078 m
.53338 .54078 L
s
[(0.75)] .51463 .54078 1 0 Mshowa
.52713 .61803 m
.53338 .61803 L
s
[(1)] .51463 .61803 1 0 Mshowa
.125 Mabswid
.52713 .01545 m
.53088 .01545 L
s
.52713 .0309 m
.53088 .0309 L
s
.52713 .04635 m
.53088 .04635 L
s
.52713 .0618 m
.53088 .0618 L
s
.52713 .09271 m
.53088 .09271 L
s
.52713 .10816 m
.53088 .10816 L
s
.52713 .12361 m
.53088 .12361 L
s
.52713 .13906 m
.53088 .13906 L
s
.52713 .16996 m
.53088 .16996 L
s
.52713 .18541 m
.53088 .18541 L
s
.52713 .20086 m
.53088 .20086 L
s
.52713 .21631 m
.53088 .21631 L
s
.52713 .24721 m
.53088 .24721 L
s
.52713 .26266 m
.53088 .26266 L
s
.52713 .27812 m
.53088 .27812 L
s
.52713 .29357 m
.53088 .29357 L
s
.52713 .32447 m
.53088 .32447 L
s
.52713 .33992 m
.53088 .33992 L
s
.52713 .35537 m
.53088 .35537 L
s
.52713 .37082 m
.53088 .37082 L
s
.52713 .40172 m
.53088 .40172 L
s
.52713 .41717 m
.53088 .41717 L
s
.52713 .43262 m
.53088 .43262 L
s
.52713 .44807 m
.53088 .44807 L
s
.52713 .47898 m
.53088 .47898 L
s
.52713 .49443 m
.53088 .49443 L
s
.52713 .50988 m
.53088 .50988 L
s
.52713 .52533 m
.53088 .52533 L
s
.52713 .55623 m
.53088 .55623 L
s
.52713 .57168 m
.53088 .57168 L
s
.52713 .58713 m
.53088 .58713 L
s
.52713 .60258 m
.53088 .60258 L
s
.25 Mabswid
.52713 0 m
.52713 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo002>oooo1@0008goool0093oool00`000?ooooooo`2=oooo002@oooo00<0003ooooo
ool00oooo`800028oooo0028oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Qooo
o`00T?ooo`030000oooooooo00?oool00`000?ooooooo`27oooo002?oooo0P0000Goool00`000?oo
ooooo`27oooo002Foooo0P0008Soool009Koool00`000?ooooooo`27oooo002Foooo00<0003ooooo
ool0Qoooo`00U_ooo`030000oooooooo08Ooool009Koool20000R?ooo`00U_ooo`030000oooooooo
08Ooool009Koool00`000?ooooooo`27oooo002Foooo00<0003oooooool0Qoooo`00U_ooo`800028
oooo002Foooo00<0003oooooool0Qoooo`00U_ooo`030000oooooooo08Ooool009Koool00`000?oo
ooooo`27oooo002Foooo0P0008Soool009Koool00`000?ooooooo`27oooo001moooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo08Ooool007coool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
08Ooool007coool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`800028oooo001foooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Qoooo`00O?ooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`27oooo001moooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Qoooo`00U_ooo`800028oooo002Foooo00<0003oooooool0Qoooo`00U_oo
o`030000oooooooo08Ooool009Koool20000R?ooo`00U_ooo`030000oooooooo08Ooool009Koool0
0`000?ooooooo`27oooo002Foooo00<0003oooooool0Qoooo`00U_ooo`800028oooo002Foooo00<0
003oooooool0Qoooo`00U_ooo`030000oooooooo08Ooool009Koool00`000?ooooooo`27oooo002F
oooo0P0008Soool009Koool00`000?ooooooo`27oooo0023oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Qoooo`00P_ooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo08Ooool008;oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
08Soool007coool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Qooo
o`00P_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`27oooo0023
oooo0P0000[oool300001?ooo`030000oooooooo08Ooool009Koool20000R?ooo`00U_ooo`030000
oooooooo08Ooool009Koool00`000?ooooooo`27oooo002Foooo00<0003oooooool0Qoooo`00U_oo
o`800028oooo002Foooo00<0003oooooool0Qoooo`00U_ooo`030000oooooooo08Ooool009Koool0
0`000?ooooooo`27oooo002Foooo0P0008Soool009Koool00`000?ooooooo`27oooo002Foooo00<0
003oooooool0Qoooo`00U_ooo`030000oooooooo08Ooool009Koool20000R?ooo`00U_ooo`030000
oooooooo08Ooool007goool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
08Ooool007coool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Qoooo`00O?ooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P0008Soool007Koool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo08Ooool007coool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Qoooo`00OOooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo08Ooool009Koool20000R?ooo`00U_ooo`030000
oooooooo08Ooool009Koool00`000?ooooooo`27oooo002Foooo00<0003oooooool0Qoooo`005ooo
o`@0000Foooo1@0000;oool200001?ooo`80000Goooo1@0001Koool200001?ooo`800004oooo0P00
01Koool200005oooo`800004oooo0P0000Coool200005oooo`D0000Eoooo1@0000;oool200001?oo
o`80000Soooo000Goooo00<0003oooooool06Oooo`030000oooooooo00Ooool010000?ooooooo`00
01Soool00`000?ooooooo`0Eoooo00@0003oooooool00008oooo00@0003oooooool0000Eoooo00<0
003oooooool05Oooo`040000oooooooo00002?ooo`040000oooooooo00006?ooo`030000oooooooo
01Ooool00`000?ooooooo`07oooo00@0003oooooool0000Roooo000Hoooo00<0003oooooool06?oo
o`030000oooooooo00[oool00`000?ooooooo`0Foooo00<0003oooooool05Oooo`040000oooooooo
00002oooo`030000oooooooo01?oool00`000?ooooooo`0Eoooo00@0003oooooool0000;oooo00<0
003oooooool05_ooo`030000oooooooo01Ooool00`000?ooooooo`0:oooo00<0003oooooool08?oo
o`004Oooo`@00004oooo00<0003oooooool03oooo`@00004oooo00<0003oooooool02?ooo`80000A
oooo100000Coool00`000?ooooooo`0?oooo100000;oool010000?ooooooo`0000Woool200005_oo
o`030000oooooooo01Goool010000?ooooooo`0000Woool200006Oooo`030000oooooooo01Ooool0
0`000?ooooooo`08oooo0P0002?oool001Ooool010000?ooooooo`0001Soool00`000?ooooooo`08
oooo00<0003oooooool06?ooo`030000oooooooo01Goool010000?ooooooo`0000Woool00`000?oo
ooooo`0Eoooo0P0001Koool010000?ooooooo`0000Woool00`000?ooooooo`0Hoooo00<0003ooooo
ool05oooo`030000oooooooo00Soool00`000?ooooooo`0Roooo000Hoooo0P0001Soool200002_oo
o`<0000Goooo0P0001Soool200002_ooo`<0000Eoooo00<0003oooooool05_ooo`80000:oooo0`00
01Ooool200006?ooo`80000:oooo0`0002;oool009Koool00`000?ooooooo`27oooo002Foooo0P00
08Soool009Koool00`000?ooooooo`27oooo002Foooo00<0003oooooool0Qoooo`00U_ooo`030000
oooooooo08Ooool0013ooooo00004Oooo`005_ooo`X00003<ol000<0000co`0co`000c?o00030000
<ol0<ol000@co`000`0003?o03?o0003<ol000<0000co`0co`0013?o00030000<ol0<ol000<co`00
0`0003?o03?o0003<ol000<0000co`0co`000c?o0003o`2I0000<ol000@co`000`0003?o03?o0003
<ol000<0000co`0co`0013?o00030000<ol0<ol000<co`000`0003?o03?o0004<ol000<0000co`0c
o`000c?o00030000<ol0<ol000<co`000`0003?o03?o0004<ol000<0000co`0co`000c?o00030000
<ol0<ol000<co`000`0003?o03?o0004<ol000<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool05?ooo`005_ooo`030000oooooooo00Ooool>000023?o
00030000<ol0<ol001Hco`000ol0V@1Voc?o0004<ol000<0000co`0co`007C?o00030000<ol0<ol0
01dco`000`000?ooooooo`0Moooo00<0003oooooool07Oooo`030000oooooooo01goool00`000?oo
ooooo`0Woooo000^oooo1`0001Xco`000ol0V@1Voc?o0014<ol000<0003oooooool0Qoooo`00=Ooo
o`L0000C<ol000?o09T0I_lco`00A3?o00800028oooo000loooo1@0000hco`000ol0V@1Voc?o0014
<ol000<0003oooooool0Qoooo`00@Oooo`@0000:<ol000?o09T0I_lco`00A3?o00030000oooooooo
08Ooool004Goool300001c?o0003o`2I06Ko<ol004@co`000`000?ooooooo`27oooo0018oooo1000
00<co`000ol0V@1Voc?o0014<ol00P0008Soool004coool2000000<co`3o09T0I_l0AC?o00030000
oooooooo08Ooool004koool00`000?l0V@1Vo`15<ol000<0003oooooool0Qoooo`00Coooo`03o`2I
06Ko000004@co`000`000?ooooooo`27oooo001?oooo00?o09T0I_ooool00P00048co`020000R?oo
o`00Coooo`03o`2I06Kooooo00;oool20000@3?o00030000oooooooo08Ooool004ooool00ol0V@1V
ooooo`04oooo0P0003hco`000`000?ooooooo`27oooo001?oooo00?o09T0I_ooool01_ooo`80000l
<ol000<0003oooooool0Qoooo`00Coooo`03o`2I06Kooooo00Soool00`0003?o03?o000i<ol00P00
08Soool004ooool00ol0V@1Vooooo`09oooo00<0000co`0co`00>3?o00030000oooooooo08Ooool0
04ooool00ol0V@1Vooooo`0:oooo00<0000co`0co`007S?o00800004<ol00P0000<co`0400000c?o
00800005<ol000<0003oooooool0Qoooo`00Coooo`03o`2I06Kooooo00_oool200007C?o00040000
<ol0<ol0000023?o00030000<ol0<ol000<co`00100003?o03?o000000@co`000`000?ooooooo`27
oooo001?oooo00?o09T0I_ooool03Oooo`030000<ol0<ol001Xco`00100003?o03?o000000Tco`00
0`0003?o03?o0005<ol000<0000co`0co`000S?o00800028oooo001?oooo00?o09T0I_ooool03_oo
o`030000<ol0<ol001Tco`00100003?o03?o000000Xco`000`0003?o03?o0002<ol00P0000Dco`00
0`000?ooooooo`27oooo001?oooo00?o09T0I_ooool03oooo`030000<ol0<ol001Pco`00100003?o
03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00Coooo`0306Kooooooooo013oool00`0003?o03?o000H<ol00P0000Xco`02000013?o00<00004
<ol000<0003oooooool0Qoooo`00Coooo`0306Kooooooooo017oool00`0003?o03?o000`<ol00P00
08Soool004ooool00`1Vooooooooo`0Boooo00<0000co`0co`00;c?o00030000oooooooo08Ooool0
04ooool00`1Vooooooooo`0Coooo00<0000co`0co`00;S?o00030000oooooooo08Ooool004ooool0
0`1Vooooooooo`0Doooo00<0000co`0co`00;C?o00030000oooooooo08Ooool004ooool00`1Voooo
ooooo`0Eoooo00<0000co`0co`00;3?o00800028oooo001?oooo00<0I_ooooooool05_ooo`030000
<ol0<ol002/co`000`000?ooooooo`27oooo001?oooo00<0I_ooooooool05_ooo`030000<ol0<ol0
02/co`000`000?ooooooo`27oooo001?oooo00<0I_ooooooool05oooo`030000<ol0<ol002Xco`00
0`000?ooooooo`27oooo001?oooo00<0I_ooooooool05oooo`030000<ol0<ol002Xco`020000R?oo
o`00Coooo`0306Kooooooooo01Soool00`0003?o03?o000Y<ol000<0003oooooool0Qoooo`00Cooo
o`0306Kooooooooo01Woool00`0003?o03?o000X<ol000<0003oooooool0Qoooo`00Coooo`0306Ko
oooooooo01Woool00`0003?o03?o000X<ol000<0003oooooool0Qoooo`00Coooo`0306Kooooooooo
01[oool00`0003?o03?o000W<ol00P0008Soool004ooool00`1Vooooooooo`0Joooo00<0000co`0c
o`009c?o00030000oooooooo08Ooool004ooool00`1Vooooooooo`0Koooo00<0000co`0co`004c?o
00800004<ol00P0000@co`0200001C?o00030000oooooooo08Ooool004ooool00`1Vooooooooo`0K
oooo00<0000co`0co`004S?o00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000
oooooooo08Ooool004ooool00`1Vooooooooo`0Loooo00<0000co`0co`004C?o00040000<ol0<ol0
00002c?o00030000<ol0<ol0008co`020000R?ooo`00Coooo`0306Kooooooooo01coool00`0003?o
03?o000A<ol000@0000co`0co`000009<ol00P0000Dco`000`000?ooooooo`27oooo001?oooo00<0
I_ooooooool07Oooo`030000<ol0<ol0010co`00100003?o03?o000000Tco`000`0003?o03?o0004
<ol000<0003oooooool0Qoooo`00Coooo`0306Kooooooooo01goool00`0003?o03?o000A<ol00P00
00Xco`03000013?o00030000oooooooo08Ooool004ooool00`1Vooooooooo`0Noooo00<0000co`0c
o`008c?o00800028oooo001=oooo0`1Vob3oool00`0003?o03?o000S<ol000<0003oooooool0Qooo
o`00BOooo`@0I_l2oooo00?o09Woooooool07oooo`030000<ol0<ol0028co`000`000?ooooooo`27
oooo0013oooo1P1Vo`Koool00ol0VOooooooo`0Ooooo00<0000co`0co`008S?o00800028oooo000l
oooo1`1Vo`coool00ol0VOooooooo`0Poooo00<0000co`0co`008C?o00030000oooooooo08Ooool0
03Goool706Ko4oooo`03o`2Ioooooooo023oool00`0003?o03?o000Q<ol000<0003oooooool0Qooo
o`00:oooo`X0I_lJoooo00?o09Woooooool08Oooo`030000<ol0<ol0020co`000`000?ooooooo`27
oooo000Poooo2`1VobCoool00ol0VOooooooo`0Qoooo00<0000co`0co`0083?o00800028oooo000J
oooo1P1Vobooool00ol0VOooooooo`0Roooo00<0000co`0co`007c?o00030000oooooooo08Ooool0
01Koool406Ko=Oooo`03o`2Ioooooooo02;oool00`0003?o03?o000O<ol000<0003oooooool0Qooo
o`00Coooo`03o`2Ioooooooo02;oool00`0003?o03?o000O<ol000<0003oooooool0Qoooo`00Cooo
o`03o`2Ioooooooo02?oool00`0003?o03?o000N<ol00P0008Soool004ooool00ol0VOooooooo`0S
oooo00<0000co`0co`007S?o00030000oooooooo08Ooool004ooool00ol0VOooooooo`0Toooo00<0
000co`0co`0013?o00800004<ol00P0000Dco`000`0003?o03?o0002<ol00P0000Dco`000`000?oo
ooooo`27oooo001?oooo00?o09Woooooool09?ooo`030000<ol0<ol000<co`00100003?o03?o0000
00Xco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000oooooooo08Ooool0
04ooool00ol0VOooooooo`0Uoooo00<0000co`0co`000S?o00040000<ol0<ol000002S?o00030000
<ol0<ol000@co`000`0003?o03?o0002<ol00P0008Soool004ooool00ol0VOooooooo`0Uoooo00<0
000co`0co`000S?o00040000<ol0<ol000002c?o00040000<ol0<ol0<ol00P0000Dco`000`000?oo
ooooo`27oooo001?oooo00?o09Woooooool09_ooo`050000<ol0<ol0<ol00000008co`000`0003?o
03?o0006<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo08Ooool0
04ooool00ol0VOooooooo`0Voooo00<0000co`0co`000S?o00800009<ol0100000<co`03000013?o
00030000oooooooo08Ooool004ooool00ol0VOooooooo`0Voooo00<0000co`0co`006c?o00800028
oooo001?oooo00?o09Woooooool09_ooo`030000<ol0<ol001/co`000`000?ooooooo`27oooo001?
oooo00?o09Woooooool09oooo`030000<ol0<ol001Xco`000`000?ooooooo`27oooo001?oooo00?o
09Woooooool09oooo`030000<ol0<ol001Xco`000`000?ooooooo`27oooo001?oooo00?o09Wooooo
ool09oooo`030000<ol0<ol001Xco`020000R?ooo`00Coooo`03o`2Ioooooooo02Ooool00`0003?o
03?o000J<ol000<0003oooooool0Qoooo`00Coooo`03o`2Ioooooooo02Soool00`0003?o03?o000I
<ol000<0003oooooool0Qoooo`00Coooo`03o`2Ioooooooo02Soool00`0003?o03?o000I<ol000<0
003oooooool0Qoooo`00Coooo`03o`2Ioooooooo02Soool00`0003?o03?o000I<ol00P0008Soool0
04ooool00ol0VOooooooo`0Xoooo00<0000co`0co`006C?o00030000oooooooo08Ooool004ooool0
0ol0VOooooooo`0Yoooo00<0000co`0co`0063?o00030000oooooooo08Ooool004ooool00ol0VOoo
ooooo`0Yoooo00<0000co`0co`0063?o00030000oooooooo08Ooool004ooool00ol0VOooooooo`0Y
oooo00<0000co`0co`0063?o00800028oooo001?oooo00?o09Woooooool0:Oooo`030000<ol0<ol0
01Pco`000`000?ooooooo`27oooo001?oooo00?o09Woooooool0:Oooo`030000<ol0<ol0010co`05
00000c?o00030000oooooooo08Ooool004ooool00ol0VOooooooo`0Zoooo00<0000co`0co`004C?o
00030000<ol0<ol000<co`000`000?ooooooo`27oooo001?oooo00?o09Woooooool0:_ooo`030000
<ol0<ol0014co`000`0003?o03?o0003<ol00P0008Soool007gooolC<ol000<0000co`0co`000c?o
08[oool007gooolC<ol000<0000co`0co`000c?o08[oool007gooolB<ol00P0000Dco`2:oooo001n
oooo63?o08[oool007kooolH<ol0R_ooo`00NOooo`030000oooooooo00;ooolH<ol03_ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`04oooo13?o00030000<ol0<ol0010co`0?oooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2000013?o00030000<ol0<ol000`co`04
00000oooo`800003oooo1@0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000<ol0<ol0008co`000`0003?o03?o0004<ol0100000<co`00100003?o03?o03?o
00[oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0D<ol000<0000co`0co`002_ooo`030000oooooooo00?oool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0001@co`000`0003?o0?ooo`09oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000003oooo4S?o00040000<ol0<ol0
00002_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool01?oo
oa<co`02000000<co`3oooooool01oooo`800003oooo00<0003oooooool0NOooo`00P?oooaHco`2:
oooo0020oooo5S?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.3562, \
-1.05744, 0.0156717, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.3562, -1.05744, 0.0156717, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20178 .30902 L
.20742 .30902 L
.21019 .30902 L
.2114 .30902 L
.21274 .30902 L
.21394 .30902 L
s
.21394 .30902 m
.21405 .61803 L
s
0 .4 1 r
.02381 .51553 m
.06244 .51165 L
.10458 .50603 L
.14415 .49904 L
.18221 .49032 L
.20178 .48491 L
.20742 .48322 L
.21019 .48237 L
.2114 .48199 L
.21274 .48157 L
.21394 .48119 L
.21506 .30902 L
.21625 .30902 L
.21753 .30902 L
.21819 .30902 L
.21892 .30902 L
.22024 .30902 L
.22144 .30902 L
.22272 .30902 L
.22335 .30902 L
.22405 .30902 L
.22527 .30902 L
.22596 .30902 L
.2267 .30902 L
.22739 .30902 L
.22803 .30902 L
.22926 .30902 L
.22996 .30902 L
.2306 .30902 L
.23178 .30902 L
.23303 .30902 L
.23414 .30902 L
.23533 .30902 L
.23636 .30902 L
.23748 .30902 L
.23873 .30902 L
.24004 .30902 L
.24126 .30902 L
.24239 .30902 L
.2437 .30902 L
.24444 .30902 L
.24512 .30902 L
.24638 .30902 L
.24701 .30902 L
.2477 .30902 L
.2489 .30902 L
.2502 .30902 L
.25142 .30902 L
.25253 .30902 L
.2532 .30902 L
Mistroke
.25391 .30902 L
.25519 .30902 L
.25591 .30902 L
.25668 .30902 L
.25741 .30902 L
.25809 .30902 L
.25873 .30902 L
.25943 .30902 L
.26017 .30902 L
.26086 .30902 L
.26207 .30902 L
.26336 .30902 L
.26459 .30902 L
.26528 .30902 L
.26593 .30902 L
.26663 .30902 L
.26736 .30902 L
.26866 .30902 L
.26979 .30902 L
.27102 .30902 L
.27234 .30902 L
.27356 .30902 L
.27426 .30902 L
.27501 .30902 L
.27572 .30902 L
.27637 .30902 L
.27761 .30902 L
.27892 .30902 L
.2796 .30902 L
.28033 .30902 L
.28165 .30902 L
.28245 .30902 L
.28321 .30902 L
.2839 .30902 L
.28464 .30902 L
.28588 .30902 L
.28705 .30902 L
.28833 .30902 L
.28905 .30902 L
.28971 .30902 L
.29096 .30902 L
.29167 .30902 L
.29233 .30902 L
.29303 .30902 L
.29367 .30902 L
.29436 .30902 L
.2951 .30902 L
.29634 .30902 L
.29748 .30902 L
.29872 .30902 L
Mistroke
.29942 .30902 L
.30007 .30902 L
.30126 .30902 L
.30234 .30902 L
.30359 .30902 L
.30478 .30902 L
.30602 .30902 L
.30672 .30902 L
.30737 .30902 L
.30856 .30902 L
.30981 .30902 L
.31093 .30902 L
.31198 .30902 L
.31314 .30902 L
.31437 .30902 L
.31569 .30902 L
.31643 .30902 L
.31712 .30902 L
.31838 .30902 L
.31902 .30902 L
.31972 .30902 L
.32093 .30902 L
.32224 .30902 L
.32347 .30902 L
.3246 .30902 L
.32567 .30902 L
.32681 .30902 L
.3279 .30902 L
.32888 .30902 L
.33003 .30902 L
.33129 .30902 L
.33247 .30902 L
.33356 .30902 L
.33469 .30902 L
.33574 .30902 L
.3369 .30902 L
.33814 .30902 L
.33944 .30902 L
.34067 .30902 L
.34188 .30902 L
.34299 .30902 L
.34424 .30902 L
.3449 .30902 L
.34559 .30902 L
.34686 .30902 L
.34804 .30902 L
.34909 .30902 L
.35022 .30902 L
.35147 .30902 L
.35261 .30902 L
Mistroke
.35392 .30902 L
.35513 .30902 L
.35577 .30902 L
.35646 .30902 L
.35719 .30902 L
.35787 .30902 L
.35912 .30902 L
.36027 .30902 L
.36159 .30902 L
.36285 .30902 L
.3639 .30902 L
.36504 .30902 L
.36612 .30902 L
.36711 .30902 L
.36826 .30902 L
.36949 .30902 L
.37052 .30902 L
.37165 .30902 L
.37289 .30902 L
.37359 .30902 L
.37422 .30902 L
.37546 .30902 L
.37663 .30902 L
.37778 .30902 L
.37884 .30902 L
.38001 .30902 L
.38125 .30902 L
.38239 .30902 L
.38363 .30902 L
.38493 .30902 L
.38614 .30902 L
.38727 .30902 L
.3883 .30902 L
.38949 .30902 L
.39062 .30902 L
.39184 .30902 L
.39314 .30902 L
.39424 .30902 L
.39546 .30902 L
.39614 .30902 L
.39687 .30902 L
.39756 .30902 L
.39821 .30902 L
.39942 .30902 L
.40072 .30902 L
.40195 .30902 L
.4031 .30902 L
.40414 .30902 L
.40527 .30902 L
.40651 .30902 L
Mistroke
.40781 .30902 L
.41016 .30902 L
.41899 .30902 L
.457 .30902 L
.49747 .30902 L
.53642 .30902 L
.57782 .30902 L
.6177 .30902 L
.65607 .30902 L
.69689 .30902 L
.7362 .30902 L
.77399 .30902 L
.81423 .30902 L
.85296 .30902 L
.89414 .30902 L
.9338 .30902 L
.97195 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0006<ol000?o09T0000co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000N<ol000?o09T0000co`00;S?o00030000oooooooo02goool00`000?ooooooo`0]
oooo00<0003oooooool0;_ooo`030000oooooooo01Goool002Soool6000063?o0003o`2I06Ko<ol0
02hco`000`000?ooooooo`2Voooo000^oooo1@0001<co`000ol0V@1Voc?o000^<ol00P000:Ooool0
03?oool400003c?o0003o`2I06Ko<ol002hco`000`000?ooooooo`2Voooo000goooo0P0000dco`00
0ol0V@1Voc?o000^<ol000<0003oooooool0Y_ooo`00>Oooo`<0000:<ol000?o09T0I_lco`00;S?o
00030000oooooooo0:Koool003coool2000023?o0003o`2I06Ko<ol002hco`020000Yoooo`00?_oo
o`800006<ol000?o09T0I_lco`00;S?o00030000oooooooo0:Koool0043oool2000013?o0003o`2I
06Ko<ol002hco`000`000?ooooooo`2Voooo0012oooo0P00008co`000ol0V@1Voc?o000^<ol000<0
003oooooool0Y_ooo`00A?ooo`8000000ol0V@1Voc?o000^<ol00P000:Ooool004Koool00ol0V@1V
oc?o000^<ol000<0003oooooool0Y_ooo`00A_ooo`03o`2I06Ko<ol002hco`000`000?ooooooo`2V
oooo0016oooo00?o09T0I_l00000;S?o00030000oooooooo0:Koool004Koool01?l0V@1Vooooo`00
02dco`020000Yoooo`00A_ooo`05o`2I06Kooooooooo000002`co`000`000?ooooooo`2Voooo0016
oooo00?o09T0I_ooool00_ooo`030000<ol0<ol0010co`02000013?o00800003<ol0100000<co`02
00001C?o00030000oooooooo0:Koool004Koool00ol0V@1Vooooo`03oooo00<0000co`0co`003S?o
00040000<ol0<ol0000023?o00030000<ol0<ol000<co`00100003?o03?o000000@co`000`000?oo
ooooo`2Voooo0016oooo00?o09T0I_ooool01?ooo`030000<ol0<ol000dco`00100003?o03?o0000
00Tco`000`0003?o03?o0005<ol000<0000co`0co`000S?o0080002Woooo0016oooo00?o09T0I_oo
ool01Oooo`030000<ol0<ol000`co`00100003?o03?o000000Xco`000`0003?o03?o0002<ol00P00
00Dco`000`000?ooooooo`2Voooo0016oooo00<0I_ooooooool01_ooo`030000<ol0<ol000/co`00
100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003ooooo
ool0Y_ooo`00A_ooo`0306Kooooooooo00Koool00`0003?o03?o000<<ol00P0000Xco`02000013?o
00<00004<ol000<0003oooooool0Y_ooo`00A_ooo`0306Kooooooooo00Ooool00`0003?o03?o000T
<ol00P000:Ooool004Koool00`1Vooooooooo`08oooo00<0000co`0co`008c?o00030000oooooooo
0:Koool004Koool00`1Vooooooooo`09oooo00<0000co`0co`008S?o00030000oooooooo0:Koool0
04Koool00`1Vooooooooo`09oooo00<0000co`0co`008S?o00030000oooooooo0:Koool004Koool0
0`1Vooooooooo`0:oooo00<0000co`0co`008C?o0080002Woooo0016oooo00<0I_ooooooool02_oo
o`030000<ol0<ol0024co`000`000?ooooooo`2Voooo0016oooo00<0I_ooooooool02oooo`030000
<ol0<ol0020co`000`000?ooooooo`2Voooo0016oooo00<0I_ooooooool02oooo`030000<ol0<ol0
020co`000`000?ooooooo`2Voooo0016oooo00<0I_ooooooool03?ooo`030000<ol0<ol001lco`02
0000Yoooo`00A_ooo`0306Kooooooooo00coool00`0003?o03?o000O<ol000<0003oooooool0Y_oo
o`00A_ooo`0306Kooooooooo00goool00`0003?o03?o000N<ol000<0003oooooool0Y_ooo`00A_oo
o`0306Kooooooooo00goool00`0003?o03?o000N<ol000<0003oooooool0Y_ooo`00A_ooo`0306Ko
oooooooo00koool00`0003?o03?o000M<ol00P000:Ooool004Koool00`1Vooooooooo`0>oooo00<0
000co`0co`007C?o00030000oooooooo0:Koool004Koool00`1Vooooooooo`0?oooo00<0000co`0c
o`002C?o00800004<ol00P0000@co`0200001C?o00030000oooooooo0:Koool004Koool00`1Voooo
ooooo`0?oooo00<0000co`0co`0023?o00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o
00030000oooooooo0:Koool004Koool00`1Vooooooooo`0@oooo00<0000co`0co`001c?o00040000
<ol0<ol000002c?o00030000<ol0<ol0008co`020000Yoooo`00A_ooo`0306Kooooooooo013oool0
0`0003?o03?o0007<ol000@0000co`0co`000009<ol00P0000Dco`000`000?ooooooo`2Voooo0016
oooo00<0I_ooooooool04?ooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`000`0003?o
03?o0004<ol000<0003oooooool0Y_ooo`00A_ooo`0306Kooooooooo017oool00`0003?o03?o0007
<ol00P0000Xco`03000013?o00030000oooooooo0:Koool004Goool206Ko4oooo`030000<ol0<ol0
01Xco`020000Yoooo`00@Oooo`D0I_l00ol0VOooooooo`0Aoooo00<0000co`0co`006S?o00030000
oooooooo0:Koool003goool406Ko1Oooo`03o`2Ioooooooo01;oool00`0003?o03?o000I<ol000<0
003oooooool0Y_ooo`00>_ooo`<0I_l9oooo00?o09Woooooool04_ooo`030000<ol0<ol001Tco`02
0000Yoooo`00=oooo`<0I_l<oooo00?o09Woooooool04_ooo`030000<ol0<ol001Tco`000`000?oo
ooooo`2Voooo000aoooo1P1Vo`ooool00ol0VOooooooo`0Coooo00<0000co`0co`0063?o00030000
oooooooo0:Koool002Woool806Ko5Oooo`03o`2Ioooooooo01?oool00`0003?o03?o000H<ol000<0
003oooooool0Y_ooo`008oooo`H0I_lMoooo00?o09Woooooool04oooo`030000<ol0<ol001Pco`02
0000Yoooo`007?ooo`L0I_lSoooo00?o09Woooooool05?ooo`030000<ol0<ol001Lco`000`000?oo
ooooo`2Voooo000Foooo1P1Vob[oool00ol0VOooooooo`0Doooo00<0000co`0co`005c?o00030000
oooooooo0:Koool004Koool00ol0VOooooooo`0Doooo00<0000co`0co`005c?o00030000oooooooo
0:Koool004Koool00ol0VOooooooo`0Eoooo00<0000co`0co`005S?o0080002Woooo0016oooo00?o
09Woooooool05Oooo`030000<ol0<ol001Hco`000`000?ooooooo`2Voooo0016oooo00?o09Wooooo
ool05Oooo`800004<ol00P0000Dco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`2V
oooo0016oooo00?o09Woooooool05?ooo`040000oooo000000002S?o00050000<ol0<ol0<ol00000
008co`000`0003?o03?o0002<ol000<0003oooooool0Y_ooo`00A_ooo`03o`2Ioooooooo01Coool0
10000?ooo`00000000Xco`000`0003?o03?o0004<ol000<0000co`0co`000S?o0080002Woooo0016
oooo00?o09Woooooool05?ooo`040000oooo000000002c?o00040000<ol0<ol0<ol00P0000Dco`00
0`000?ooooooo`2Voooo0016oooo00?o09Woooooool05?ooo`040000oooooooo000023?o00040000
<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?ooooooo`2Voooo0016oooo00?o09Wooooo
ool05Oooo`<00008<ol0100000<co`03000013?o00030000oooooooo0:Koool004Koool00ol0VOoo
ooooo`0Goooo00<0000co`0co`0053?o0080002Woooo0016oooo00?o09Woooooool05oooo`030000
<ol0<ol001@co`000`000?ooooooo`2Voooo0016oooo00?o09Woooooool06?ooo`030000<ol0<ol0
01<co`000`000?ooooooo`2Voooo0016oooo00?o09Woooooool06?ooo`030000<ol0<ol001<co`00
0`000?ooooooo`2Voooo0016oooo00?o09Woooooool06?ooo`030000<ol0<ol001<co`020000Yooo
o`00A_ooo`03o`2Ioooooooo01Soool00`0003?o03?o000C<ol000<0003oooooool0Y_ooo`00A_oo
o`03o`2Ioooooooo01Woool00`0003?o03?o000B<ol000<0003oooooool0Y_ooo`00A_ooo`03o`2I
oooooooo01Woool00`0003?o03?o000B<ol000<0003oooooool0Y_ooo`00A_ooo`03o`2Ioooooooo
01Woool00`0003?o03?o000B<ol00P000:Ooool004Koool00ol0VOooooooo`0Ioooo00<0000co`0c
o`004S?o00030000oooooooo0:Koool004Koool00ol0VOooooooo`0Joooo00<0000co`0co`004C?o
00030000oooooooo0:Koool004Koool00ol0VOooooooo`0Joooo00<0000co`0co`004C?o00030000
oooooooo0:Koool004Koool00ol0VOooooooo`0Joooo00<0000co`0co`004C?o0080002Woooo0016
oooo00?o09Woooooool06_ooo`030000<ol0<ol0014co`000`000?ooooooo`2Voooo0016oooo00?o
09Woooooool06_ooo`030000<ol0<ol000Tco`0500000c?o00030000oooooooo0:Koool004Koool0
0ol0VOooooooo`0Koooo00<0000co`0co`002S?o00030000<ol0<ol000<co`000`000?ooooooo`2V
oooo0016oooo00?o09Woooooool06oooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol00P00
0:Ooool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool=<ol000<0000co`0co`000c?o
0:Woool006Coool<<ol00P0000Dco`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol0ZOooo`00IOoo
oa8co`05oooo00<0003oooooool08_ooo`030000oooooooo07coool006GooolB<ol01?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00IOoooa8co`04oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`@00003oooo0P0000Coool00`000?oo
ooooo`1koooo001Uoooo4S?o00Coool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`030000oooooooo00[oool00`000?ooooooo`1koooo001U
oooo4S?o00?oool00`000?ooooooo`02oooo00<0003oooooool05?ooo`030000oooooooo00[oool0
0`000?ooooooo`1joooo001Voooo4C?o00Coool00`000?ooooooo`0500005?ooo`030000oooooooo
00Soool00`000?ooooooo`1koooo001Voooo4C?o00Coool01@000?ooooooooooo`00000Eoooo00@0
003oooooool00009oooo00<0003oooooool0Noooo`00I_oooa4co`05oooo00<0003oooooool05ooo
o`800009oooo00<0003oooooool0O?ooo`00I_oooa4co`2Yoooo001Voooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.22738 .30902 L
.22994 .30902 L
.23119 .30902 L
.23233 .30902 L
s
.23233 .30902 m
.23245 .61803 L
s
0 .4 1 r
.02381 .51625 m
.06244 .51261 L
.10458 .50735 L
.14415 .50082 L
.18221 .49269 L
.20342 .4872 L
.22272 .48153 L
.22738 .48006 L
.22994 .47923 L
.23119 .47882 L
.23233 .47845 L
.23357 .30902 L
.23426 .30902 L
.23491 .30902 L
.23561 .30902 L
.23627 .30902 L
.23699 .30902 L
.23775 .30902 L
.2384 .30902 L
.23911 .30902 L
.24038 .30902 L
.24162 .30902 L
.24276 .30902 L
.24386 .30902 L
.24503 .30902 L
.24614 .30902 L
.24715 .30902 L
.24834 .30902 L
.24963 .30902 L
.25085 .30902 L
.25198 .30902 L
.25313 .30902 L
.25422 .30902 L
.25541 .30902 L
.2567 .30902 L
.25797 .30902 L
.25861 .30902 L
.25931 .30902 L
.26055 .30902 L
.26171 .30902 L
.26299 .30902 L
.26363 .30902 L
.26434 .30902 L
.26559 .30902 L
.26676 .30902 L
.26747 .30902 L
.26814 .30902 L
.2694 .30902 L
.2701 .30902 L
.27075 .30902 L
Mistroke
.27147 .30902 L
.27223 .30902 L
.27352 .30902 L
.27425 .30902 L
.27492 .30902 L
.27615 .30902 L
.27745 .30902 L
.27861 .30902 L
.2797 .30902 L
.28089 .30902 L
.28217 .30902 L
.28341 .30902 L
.28456 .30902 L
.28583 .30902 L
.28646 .30902 L
.28717 .30902 L
.28834 .30902 L
.28961 .30902 L
.2908 .30902 L
.2919 .30902 L
.29413 .30902 L
.29522 .30902 L
.29621 .30902 L
.29726 .30902 L
.29838 .30902 L
.2996 .30902 L
.30075 .30902 L
.30191 .30902 L
.30316 .30902 L
.30433 .30902 L
.3054 .30902 L
.30665 .30902 L
.30736 .30902 L
.30802 .30902 L
.30922 .30902 L
.3105 .30902 L
.31172 .30902 L
.31303 .30902 L
.31426 .30902 L
.3154 .30902 L
.31666 .30902 L
.31737 .30902 L
.31803 .30902 L
.31874 .30902 L
.31937 .30902 L
.32011 .30902 L
.32081 .30902 L
.32187 .30902 L
.32304 .30902 L
.32427 .30902 L
Mistroke
.32541 .30902 L
.32648 .30902 L
.32746 .30902 L
.32859 .30902 L
.32966 .30902 L
.33082 .30902 L
.33205 .30902 L
.33321 .30902 L
.33426 .30902 L
.3355 .30902 L
.3362 .30902 L
.33684 .30902 L
.33802 .30902 L
.33927 .30902 L
.34049 .30902 L
.34119 .30902 L
.34182 .30902 L
.34299 .30902 L
.34424 .30902 L
.34535 .30902 L
.34639 .30902 L
.34753 .30902 L
.34876 .30902 L
.35135 .30902 L
.35264 .30902 L
.35338 .30902 L
.35407 .30902 L
.3553 .30902 L
.35642 .30902 L
.35771 .30902 L
.35893 .30902 L
.35999 .30902 L
.36115 .30902 L
.36237 .30902 L
.36351 .30902 L
.36457 .30902 L
.36554 .30902 L
.36666 .30902 L
.36773 .30902 L
.36888 .30902 L
.3701 .30902 L
.37125 .30902 L
.37229 .30902 L
.37352 .30902 L
.37422 .30902 L
.37486 .30902 L
.37603 .30902 L
.37727 .30902 L
.37849 .30902 L
.37919 .30902 L
Mistroke
.37982 .30902 L
.381 .30902 L
.38225 .30902 L
.38336 .30902 L
.3844 .30902 L
.38555 .30902 L
.38678 .30902 L
.38808 .30902 L
.38882 .30902 L
.3895 .30902 L
.39076 .30902 L
.39146 .30902 L
.39209 .30902 L
.3933 .30902 L
.3946 .30902 L
.39583 .30902 L
.39696 .30902 L
.39802 .30902 L
.39916 .30902 L
.40023 .30902 L
.40121 .30902 L
.40236 .30902 L
.40361 .30902 L
.40479 .30902 L
.40588 .30902 L
.41531 .30902 L
.45456 .30902 L
.4923 .30902 L
.53249 .30902 L
.57117 .30902 L
.61229 .30902 L
.65191 .30902 L
.69 .30902 L
.73055 .30902 L
.76958 .30902 L
.81107 .30902 L
.85104 .30902 L
.88949 .30902 L
.9304 .30902 L
.96979 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000D0000co`0co`0co`00I_l013?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool01Oooo`X0000O<ol000D0000co`0co`0co`00I_l0:c?o00030000oooooooo02goool0
0`000?ooooooo`0]oooo00<0003oooooool0;_ooo`030000oooooooo01Goool002Soool600007C?o
000306Ko<ol0<ol002Tco`000`000?ooooooo`2Voooo000^oooo1@0001Pco`000`1Voc?o03?o000Y
<ol00P000:Ooool003?oool4000053?o000306Ko<ol0<ol002Tco`000`000?ooooooo`2Voooo000g
oooo0P00018co`000`1Voc?o03?o000Y<ol000<0003oooooool0Y_ooo`00>Oooo`<0000?<ol000<0
I_lco`0co`00:C?o00030000oooooooo0:Koool003coool200003C?o000306Ko<ol0<ol002Tco`02
0000Yoooo`00?_ooo`80000;<ol000<0I_lco`0co`00:C?o00030000oooooooo0:Koool0043oool2
00002C?o000306Ko<ol0<ol002Tco`000`000?ooooooo`2Voooo0012oooo0P0000Lco`000`1Voc?o
03?o000Y<ol000<0003oooooool0Y_ooo`00A?ooo`800005<ol000<0I_lco`0co`00:C?o0080002W
oooo0016oooo00<0000co`0co`000S?o000306Ko<ol0<ol002Tco`000`000?ooooooo`2Voooo0017
oooo00D0000co`0co`0co`00I_l0:c?o00030000oooooooo0:Koool004Soool0100003?o03?o001V
ob/co`000`000?ooooooo`2Voooo0019oooo00<0000co`00I_l0:c?o0080002Woooo001:oooo00<0
0000I_lco`00:S?o00030000oooooooo0:Koool004_oool00`1Voc?o03?o000@<ol00P0000@co`02
00000c?o00@00003<ol00P0000Dco`000`000?ooooooo`2Voooo001;oooo00<0I_l0000co`003c?o
00040000<ol0<ol0000023?o00030000<ol0<ol000<co`00100003?o03?o000000@co`000`000?oo
ooooo`2Voooo001;oooo00<0I_ooool000003c?o00040000<ol0<ol000002C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0002<ol00P000:Ooool004_oool0101Vooooooooo`0000hco`00100003?o
03?o000000Xco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`2Voooo001;oooo00D0
I_ooooooooooool000003C?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0<ol000@co`000`000?ooooooo`2Voooo001;oooo00D0I_ooooooooooool000003S?o0080000:
<ol00P0000@co`03000013?o00030000oooooooo0:Koool004_oool00`1Vooooooooo`02oooo00<0
000co`0co`0093?o0080002Woooo001;oooo00<0I_ooooooool00oooo`030000<ol0<ol002<co`00
0`000?ooooooo`2Voooo001;oooo00<0I_ooooooool01?ooo`030000<ol0<ol0028co`000`000?oo
ooooo`2Voooo001;oooo00<0I_ooooooool01?ooo`030000<ol0<ol0028co`000`000?ooooooo`2V
oooo001;oooo00<0I_ooooooool01Oooo`030000<ol0<ol0024co`020000Yoooo`00Boooo`0306Ko
oooooooo00Goool00`0003?o03?o000Q<ol000<0003oooooool0Y_ooo`00Boooo`0306Kooooooooo
00Koool00`0003?o03?o000P<ol000<0003oooooool0Y_ooo`00Boooo`0306Kooooooooo00Koool0
0`0003?o03?o000P<ol000<0003oooooool0Y_ooo`00Boooo`0306Kooooooooo00Ooool00`0003?o
03?o000O<ol00P000:Ooool004_oool00`1Vooooooooo`07oooo00<0000co`0co`007c?o00030000
oooooooo0:Koool004_oool00`1Vooooooooo`08oooo00<0000co`0co`007S?o00030000oooooooo
0:Koool004_oool00`1Vooooooooo`08oooo00<0000co`0co`007S?o00030000oooooooo0:Koool0
04_oool00`1Vooooooooo`09oooo00<0000co`0co`007C?o0080002Woooo001;oooo00<0I_oooooo
ool02Oooo`030000<ol0<ol001dco`000`000?ooooooo`2Voooo001;oooo00<0I_ooooooool02_oo
o`030000<ol0<ol000Tco`02000013?o00800004<ol00P0000Dco`000`000?ooooooo`2Voooo001;
oooo00<0I_ooooooool02_ooo`030000<ol0<ol000Pco`00100003?o03?o000000Pco`00100003?o
03?o000000@co`000`000?ooooooo`2Voooo001;oooo00<0I_ooooooool02oooo`030000<ol0<ol0
00Lco`00100003?o03?o000000/co`000`0003?o03?o0002<ol00P000:Ooool004_oool00`1Voooo
ooooo`0;oooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o00800005<ol000<0003ooooo
ool0Y_ooo`00Boooo`0306Kooooooooo00_oool00`0003?o03?o0007<ol000@0000co`0co`000009
<ol000<0000co`0co`0013?o00030000oooooooo0:Koool004_oool00`1Vooooooooo`0<oooo00<0
000co`0co`001c?o0080000:<ol00`0000@co`000`000?ooooooo`2Voooo0018oooo0`1Vo`03o`2I
oooooooo00coool00`0003?o03?o000J<ol00P000:Ooool004Koool206Ko0oooo`03o`2Ioooooooo
00coool00`0003?o03?o000J<ol000<0003oooooool0Y_ooo`00@_ooo`@0I_l5oooo00?o09Wooooo
ool03Oooo`030000<ol0<ol001Tco`000`000?ooooooo`2Voooo000loooo1P1Vo`Woool00ol0VOoo
ooooo`0=oooo00<0000co`0co`006C?o0080002Woooo000hoooo101Vo`ooool00ol0VOooooooo`0=
oooo00<0000co`0co`006C?o00030000oooooooo0:Koool003?oool506Ko4oooo`03o`2Ioooooooo
00koool00`0003?o03?o000H<ol000<0003oooooool0Y_ooo`00;_ooo`D0I_lHoooo00?o09Wooooo
ool03_ooo`030000<ol0<ol001Pco`000`000?ooooooo`2Voooo000Voooo201Voagoool00ol0VOoo
ooooo`0>oooo00<0000co`0co`0063?o0080002Woooo000Loooo2P1VobGoool00ol0VOooooooo`0?
oooo00<0000co`0co`005c?o00030000oooooooo0:Koool001Koool606Ko;oooo`03o`2Ioooooooo
00ooool00`0003?o03?o000G<ol000<0003oooooool0Y_ooo`00Boooo`03o`2Ioooooooo00ooool0
0`0003?o03?o000G<ol000<0003oooooool0Y_ooo`00Boooo`03o`2Ioooooooo013oool00`0003?o
03?o000F<ol00P000:Ooool004_oool00ol0VOooooooo`0@oooo00<0000co`0co`005S?o00030000
oooooooo0:Koool004_oool00ol0VOooooooo`0@oooo0P0000@co`0200001C?o00030000<ol0<ol0
008co`0200001C?o00030000oooooooo0:Koool004_oool00ol0VOooooooo`0?oooo00@0003oool0
0000000:<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`000?ooooooo`2V
oooo001;oooo00?o09Woooooool03oooo`040000oooo000000002S?o00030000<ol0<ol000@co`00
0`0003?o03?o0002<ol00P000:Ooool004_oool00ol0VOooooooo`0?oooo00@0003oool00000000;
<ol000@0000co`0co`0co`0200001C?o00030000oooooooo0:Koool004_oool00ol0VOooooooo`0?
oooo00@0003oooooool00008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000
oooooooo0:Koool004_oool00ol0VOooooooo`0@oooo0`0000Pco`0400000c?o00<00004<ol000<0
003oooooool0Y_ooo`00Boooo`03o`2Ioooooooo01;oool00`0003?o03?o000D<ol00P000:Ooool0
04_oool00ol0VOooooooo`0Boooo00<0000co`0co`0053?o00030000oooooooo0:Koool004_oool0
0ol0VOooooooo`0Coooo00<0000co`0co`004c?o00030000oooooooo0:Koool004_oool00ol0VOoo
ooooo`0Coooo00<0000co`0co`004c?o00030000oooooooo0:Koool004_oool00ol0VOooooooo`0C
oooo00<0000co`0co`004c?o0080002Woooo001;oooo00?o09Woooooool04oooo`030000<ol0<ol0
01<co`000`000?ooooooo`2Voooo001;oooo00?o09Woooooool05?ooo`030000<ol0<ol0018co`00
0`000?ooooooo`2Voooo001;oooo00?o09Woooooool05?ooo`030000<ol0<ol0018co`000`000?oo
ooooo`2Voooo001;oooo00?o09Woooooool05?ooo`030000<ol0<ol0018co`020000Yoooo`00Booo
o`03o`2Ioooooooo01Coool00`0003?o03?o000B<ol000<0003oooooool0Y_ooo`00Boooo`03o`2I
oooooooo01Goool00`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00Boooo`03o`2Ioooooooo
01Goool00`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00Boooo`03o`2Ioooooooo01Goool0
0`0003?o03?o000A<ol00P000:Ooool004_oool00ol0VOooooooo`0Eoooo00<0000co`0co`004C?o
00030000oooooooo0:Koool004_oool00ol0VOooooooo`0Eoooo00<0000co`0co`002C?o00D00003
<ol000<0003oooooool0Y_ooo`00Boooo`03o`2Ioooooooo01Koool00`0003?o03?o000:<ol000<0
000co`0co`000c?o00030000oooooooo0:Koool004_oool00ol0VOooooooo`0Foooo00<0000co`0c
o`002S?o00030000<ol0<ol000<co`020000Yoooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOoo
o`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo``co`0200001C?o0:Woool006GooolB
<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o00;oool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00IOoooa8co`000oooo`000?ooo`09oooo00<0003oooooool07oooo`030000oooooooo
07Soool006GooolB<ol000?oool0003oool00oooo`800004oooo00<0003oooooool03?ooo`D00002
oooo0P0000?oool300001?ooo`030000oooooooo07Soool006GooolB<ol000?oool0003oool00_oo
o`040000oooooooo00001?ooo`030000oooooooo00Coool400001Oooo`030000oooooooo00Woool0
0`000?ooooooo`02oooo00<0003oooooool0N?ooo`00IOoooa8co`000`000?ooooooo`02oooo00<0
003oooooool05Oooo`030000oooooooo00Soool300001?ooo`030000oooooooo07Ooool006KooolA
<ol000Coool0003oooooool500005?ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001Voooo4C?o0003oooo0000oooo00;oool00`000?ooooooo`0Eoooo00<0
003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool006KooolA<ol00_oo
o`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003oooooool0NOooo`00I_oooa4co`2Y
oooo001Voooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.20342 .30902 L
.22272 .30902 L
.23233 .30902 L
.23739 .30902 L
.24276 .30902 L
.24745 .30902 L
.24873 .30902 L
.25012 .30902 L
.25142 .30902 L
s
.25142 .30902 m
.25154 .61803 L
s
0 .4 1 r
.02381 .51675 m
.06244 .51327 L
.10458 .50825 L
.14415 .50203 L
.18221 .4943 L
.20342 .48909 L
.22272 .48372 L
.23233 .4808 L
.23739 .47919 L
.24276 .47744 L
.24745 .47586 L
.24873 .47541 L
.25012 .47494 L
.25142 .47448 L
.25261 .30902 L
.25377 .30902 L
.25484 .30902 L
.25602 .30902 L
.25728 .30902 L
.25847 .30902 L
.2596 .30902 L
.26061 .30902 L
.26171 .30902 L
.26295 .30902 L
.26408 .30902 L
.26539 .30902 L
.26663 .30902 L
.26777 .30902 L
.26882 .30902 L
.26998 .30902 L
.27121 .30902 L
.27245 .30902 L
.27314 .30902 L
.27377 .30902 L
.27494 .30902 L
.27617 .30902 L
.27683 .30902 L
.27753 .30902 L
.27879 .30902 L
.27956 .30902 L
.28029 .30902 L
.28094 .30902 L
.28165 .30902 L
.28296 .30902 L
.28418 .30902 L
.28489 .30902 L
.28553 .30902 L
.28628 .30902 L
.28697 .30902 L
.28764 .30902 L
Mistroke
.28836 .30902 L
.28915 .30902 L
.28986 .30902 L
.29054 .30902 L
.29128 .30902 L
.29197 .30902 L
.29261 .30902 L
.29382 .30902 L
.29495 .30902 L
.2962 .30902 L
.29689 .30902 L
.29753 .30902 L
.2988 .30902 L
.29952 .30902 L
.30019 .30902 L
.30141 .30902 L
.30271 .30902 L
.30395 .30902 L
.3051 .30902 L
.30631 .30902 L
.30762 .30902 L
.30876 .30902 L
.30979 .30902 L
.31098 .30902 L
.31211 .30902 L
.31334 .30902 L
.31464 .30902 L
.31575 .30902 L
.31697 .30902 L
.31828 .30902 L
.31901 .30902 L
.31968 .30902 L
.32099 .30902 L
.32222 .30902 L
.32327 .30902 L
.32443 .30902 L
.32564 .30902 L
.32677 .30902 L
.32783 .30902 L
.3288 .30902 L
.32986 .30902 L
.33098 .30902 L
.33212 .30902 L
.33334 .30902 L
.33449 .30902 L
.33553 .30902 L
.33676 .30902 L
.33746 .30902 L
.3381 .30902 L
.33927 .30902 L
Mistroke
.34052 .30902 L
.34163 .30902 L
.34283 .30902 L
.34413 .30902 L
.34535 .30902 L
.34659 .30902 L
.34775 .30902 L
.3488 .30902 L
.34994 .30902 L
.35058 .30902 L
.35128 .30902 L
.35201 .30902 L
.35269 .30902 L
.35392 .30902 L
.35523 .30902 L
.35653 .30902 L
.35776 .30902 L
.35886 .30902 L
.36007 .30902 L
.36121 .30902 L
.36228 .30902 L
.36341 .30902 L
.36462 .30902 L
.36569 .30902 L
.36682 .30902 L
.36778 .30902 L
.36884 .30902 L
.37009 .30902 L
.37123 .30902 L
.37254 .30902 L
.37378 .30902 L
.37492 .30902 L
.37598 .30902 L
.37714 .30902 L
.37837 .30902 L
.37958 .30902 L
.3809 .30902 L
.38215 .30902 L
.38331 .30902 L
.38445 .30902 L
.38549 .30902 L
.38669 .30902 L
.38782 .30902 L
.38905 .30902 L
.39036 .30902 L
.39147 .30902 L
.39269 .30902 L
.39401 .30902 L
.39475 .30902 L
.39542 .30902 L
Mistroke
.39673 .30902 L
.39796 .30902 L
.39901 .30902 L
.40018 .30902 L
.40139 .30902 L
.40253 .30902 L
.40359 .30902 L
.40456 .30902 L
.40568 .30902 L
.40674 .30902 L
.41628 .30902 L
.45446 .30902 L
.49509 .30902 L
.53421 .30902 L
.57578 .30902 L
.61583 .30902 L
.65437 .30902 L
.69536 .30902 L
.73484 .30902 L
.7728 .30902 L
.81321 .30902 L
.85211 .30902 L
.89345 .30902 L
.93329 .30902 L
.9716 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000O<ol000<0000co`0co`001S?o000306Ko<ol0<ol002@co`000`000?ooooooo`0]
oooo00<0003oooooool0;Oooo`030000oooooooo02koool00`000?ooooooo`0Eoooo000Xoooo1P00
028co`000`1Voc?o03?o000T<ol000<0003oooooool0Y_ooo`00;_ooo`D0000M<ol000<0I_lco`0c
o`0093?o0080002Woooo000coooo100001Tco`000`1Voc?o03?o000T<ol000<0003oooooool0Y_oo
o`00=oooo`80000G<ol000<0I_lco`0co`0093?o00030000oooooooo0:Koool003Woool3000053?o
000306Ko<ol0<ol002@co`000`000?ooooooo`2Voooo000loooo0P00018co`000`1Voc?o03?o000T
<ol00P000:Ooool003koool2000043?o000306Ko<ol0<ol002@co`000`000?ooooooo`2Voooo0010
oooo0P0000hco`000`1Voc?o03?o000T<ol000<0003oooooool0Y_ooo`00@_ooo`80000<<ol000<0
I_lco`0co`0093?o00030000oooooooo0:Koool004Coool200002S?o000306Ko<ol0<ol002@co`02
0000Yoooo`00A_ooo`030000<ol0<ol000Lco`000`1Voc?o03?o000T<ol000<0003oooooool0Y_oo
o`00Aoooo`030000<ol0<ol000Hco`000`1Voc?o03?o000T<ol000<0003oooooool0Y_ooo`00B?oo
o`030000<ol0<ol000Dco`000`1Voc?o03?o000T<ol000<0003oooooool0Y_ooo`00BOooo`030000
<ol0<ol000@co`000`1Voc?o03?o000T<ol00P000:Ooool004[oool00`0003?o03?o0003<ol000<0
I_lco`0co`0093?o00030000oooooooo0:Koool004_oool00`0003?o03?o0002<ol000<0I_lco`0c
o`002c?o00800004<ol00P0000<co`0400000c?o00800005<ol000<0003oooooool0Y_ooo`00C?oo
o`050000<ol0<ol0<ol006Ko00`co`00100003?o03?o000000Pco`000`0003?o03?o0003<ol000@0
000co`0co`000004<ol000<0003oooooool0Y_ooo`00COooo`040000<ol0<ol006Ko33?o00040000
<ol0<ol000002C?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol00P000:Ooool004koool0
0`0003?o001Vo`0<<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800005<ol000<0
003oooooool0Y_ooo`00Coooo`03000006Ko<ol000/co`00100003?o03?o000000Pco`00100003?o
03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00Coooo`03000006Ko<ol0
00`co`0200002S?o00800004<ol00`0000@co`000`000?ooooooo`2Voooo001@oooo00<0I_lco`0c
o`0093?o0080002Woooo001@oooo00<0I_l0000co`0093?o00030000oooooooo0:Koool0053oool0
0`1Vooooo`00000T<ol000<0003oooooool0Y_ooo`00D?ooo`0306Kooooo000002@co`000`000?oo
ooooo`2Voooo001@oooo00@0I_ooooooool0000S<ol00P000:Ooool0053oool0101Vooooooooo`00
02<co`000`000?ooooooo`2Voooo001@oooo00D0I_ooooooooooool000008S?o00030000oooooooo
0:Koool0053oool01@1Vooooooooooooo`00000R<ol000<0003oooooool0Y_ooo`00D?ooo`0306Ko
oooooooo00;oool00`0003?o03?o000O<ol00P000:Ooool0053oool00`1Vooooooooo`02oooo00<0
000co`0co`007c?o00030000oooooooo0:Koool0053oool00`1Vooooooooo`03oooo00<0000co`0c
o`007S?o00030000oooooooo0:Koool0053oool00`1Vooooooooo`03oooo00<0000co`0co`007S?o
00030000oooooooo0:Koool0053oool00`1Vooooooooo`04oooo00<0000co`0co`007C?o0080002W
oooo001@oooo00<0I_ooooooool01?ooo`030000<ol0<ol001dco`000`000?ooooooo`2Voooo001@
oooo00<0I_ooooooool01Oooo`030000<ol0<ol000Tco`02000013?o00800004<ol00P0000Dco`00
0`000?ooooooo`2Voooo001@oooo00<0I_ooooooool01Oooo`030000<ol0<ol000Pco`00100003?o
03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`2Voooo001@oooo00<0I_oooooo
ool01_ooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`000`0003?o03?o0002<ol00P00
0:Ooool0053oool00`1Vooooooooo`06oooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o
00800005<ol000<0003oooooool0Y_ooo`00D?ooo`0306Kooooooooo00Koool00`0003?o03?o0007
<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000oooooooo0:Koool004koool2
06Ko00?o09Woooooool01oooo`030000<ol0<ol000Lco`0200002S?o00<00004<ol000<0003ooooo
ool0Y_ooo`00Boooo`<0I_l2oooo00?o09Woooooool01oooo`030000<ol0<ol001Xco`020000Yooo
o`00Aoooo`@0I_l5oooo00?o09Woooooool01oooo`030000<ol0<ol001Xco`000`000?ooooooo`2V
oooo0012oooo1@1Vo`Woool00ol0VOooooooo`08oooo00<0000co`0co`006C?o00030000oooooooo
0:Koool003coool606Ko3_ooo`03o`2Ioooooooo00Soool00`0003?o03?o000I<ol00P000:Ooool0
03Soool406Ko5?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000I<ol000<0003oooooool0Y_oo
o`00<oooo`D0I_lHoooo00?o09Woooooool02Oooo`030000<ol0<ol001Pco`000`000?ooooooo`2V
oooo000^oooo1@1Voagoool00ol0VOooooooo`09oooo00<0000co`0co`0063?o00030000oooooooo
0:Koool002Koool806Ko8_ooo`03o`2Ioooooooo00Woool00`0003?o03?o000H<ol00P000:Ooool0
01coool:06Ko:_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000G<ol000<0003oooooool0Y_oo
o`005_ooo`H0I_ldoooo00?o09Woooooool02_ooo`030000<ol0<ol001Lco`000`000?ooooooo`2V
oooo001@oooo00?o09Woooooool02_ooo`030000<ol0<ol001Lco`000`000?ooooooo`2Voooo001@
oooo00?o09Woooooool02oooo`030000<ol0<ol001Hco`020000Yoooo`00D?ooo`03o`2Ioooooooo
00_oool00`0003?o03?o000F<ol000<0003oooooool0Y_ooo`00D?ooo`03o`2Ioooooooo00_oool2
000013?o00800005<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Y_ooo`00D?oo
o`03o`2Ioooooooo00[oool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0
000co`0co`000S?o00030000oooooooo0:Koool0053oool00ol0VOooooooo`0:oooo00@0003oool0
0000000:<ol000<0000co`0co`0013?o00030000<ol0<ol0008co`020000Yoooo`00D?ooo`03o`2I
oooooooo00[oool010000?ooo`00000000/co`00100003?o03?o03?o00800005<ol000<0003ooooo
ool0Y_ooo`00D?ooo`03o`2Ioooooooo00[oool010000?ooooooo`0000Pco`00100003?o03?o0000
00<co`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00D?ooo`03o`2Ioooooooo00_oool3
000023?o00@00003<ol00`0000@co`000`000?ooooooo`2Voooo001@oooo00?o09Woooooool03Ooo
o`030000<ol0<ol001@co`020000Yoooo`00D?ooo`03o`2Ioooooooo00goool00`0003?o03?o000D
<ol000<0003oooooool0Y_ooo`00D?ooo`03o`2Ioooooooo00koool00`0003?o03?o000C<ol000<0
003oooooool0Y_ooo`00D?ooo`03o`2Ioooooooo00koool00`0003?o03?o000C<ol000<0003ooooo
ool0Y_ooo`00D?ooo`03o`2Ioooooooo00koool00`0003?o03?o000C<ol00P000:Ooool0053oool0
0ol0VOooooooo`0>oooo00<0000co`0co`004c?o00030000oooooooo0:Koool0053oool00ol0VOoo
ooooo`0?oooo00<0000co`0co`004S?o00030000oooooooo0:Koool0053oool00ol0VOooooooo`0?
oooo00<0000co`0co`004S?o00030000oooooooo0:Koool0053oool00ol0VOooooooo`0?oooo00<0
000co`0co`004S?o0080002Woooo001@oooo00?o09Woooooool03oooo`030000<ol0<ol0018co`00
0`000?ooooooo`2Voooo001@oooo00?o09Woooooool04?ooo`030000<ol0<ol0014co`000`000?oo
ooooo`2Voooo001@oooo00?o09Woooooool04?ooo`030000<ol0<ol0014co`000`000?ooooooo`2V
oooo001@oooo00?o09Woooooool04?ooo`030000<ol0<ol0014co`020000Yoooo`00D?ooo`03o`2I
oooooooo013oool00`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00D?ooo`03o`2Ioooooooo
013oool00`0003?o03?o0009<ol01@0000<co`000`000?ooooooo`2Voooo001@oooo00?o09Wooooo
ool04Oooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003oooooool0Y_ooo`00D?oo
o`03o`2Ioooooooo017oool00`0003?o03?o000:<ol000<0000co`0co`000c?o0080002Woooo001T
oooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001T
oooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol00_oo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001Uoooo4S?o0003oooo0000oooo00Woool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`03oooo0P00
00Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00IOoooa8co`000oooo`000?ooo`02oooo00@0003oooooool00004oooo00<0003oooooool01?oo
o`@00005oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool0
06GooolB<ol000<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`07oooo00@0
003oooooool00004oooo00<0003oooooool0Moooo`00I_oooa4co`001?ooo`000?ooooooo`D0000D
oooo00<0003oooooool02?ooo`800004oooo00<0003oooooool0N?ooo`00I_oooa4co`000oooo`00
0?ooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001Voooo4C?o00;oool00`000?ooooooo`0Goooo0P0000[oool200000ooo
o`030000oooooooo07Woool006KooolA<ol0ZOooo`00I_oooa4co`2Yoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.25127 .30902 L
.26171 .30902 L
.26698 .30902 L
.26843 .30902 L
.26922 .30902 L
.26998 .30902 L
.27068 .30902 L
s
.27068 .30902 m
.27076 .61803 L
s
0 .4 1 r
.02381 .51702 m
.06244 .51364 L
.10458 .50875 L
.14415 .5027 L
.18221 .49519 L
.22272 .48493 L
.24141 .47928 L
.25127 .47604 L
.26171 .4724 L
.26698 .47049 L
.26843 .46995 L
.26922 .46966 L
.26998 .46937 L
.27068 .46911 L
.27145 .30902 L
.27214 .30902 L
.27279 .30902 L
.27343 .30902 L
.27412 .30902 L
.27538 .30902 L
.27661 .30902 L
.27774 .30902 L
.27896 .30902 L
.27966 .30902 L
.2803 .30902 L
.28161 .30902 L
.28235 .30902 L
.28302 .30902 L
.28426 .30902 L
.28489 .30902 L
.28559 .30902 L
.28682 .30902 L
.28797 .30902 L
.28863 .30902 L
.28932 .30902 L
.29056 .30902 L
.29125 .30902 L
.2919 .30902 L
.2926 .30902 L
.29336 .30902 L
.29462 .30902 L
.29534 .30902 L
.296 .30902 L
.29721 .30902 L
.29849 .30902 L
.29964 .30902 L
.30071 .30902 L
.30199 .30902 L
.30316 .30902 L
.30441 .30902 L
Mistroke
.30509 .30902 L
.30574 .30902 L
.30689 .30902 L
.30813 .30902 L
.30885 .30902 L
.30951 .30902 L
.3102 .30902 L
.31096 .30902 L
.31222 .30902 L
.31292 .30902 L
.31356 .30902 L
.31483 .30902 L
.316 .30902 L
.31728 .30902 L
.31793 .30902 L
.31864 .30902 L
.31983 .30902 L
.32112 .30902 L
.32233 .30902 L
.32344 .30902 L
.32453 .30902 L
.32568 .30902 L
.32677 .30902 L
.32776 .30902 L
.32893 .30902 L
.33019 .30902 L
.33138 .30902 L
.33248 .30902 L
.33362 .30902 L
.33468 .30902 L
.33585 .30902 L
.3371 .30902 L
.33841 .30902 L
.33965 .30902 L
.34077 .30902 L
.34198 .30902 L
.34319 .30902 L
.34431 .30902 L
.34553 .30902 L
.34682 .30902 L
.34794 .30902 L
.34899 .30902 L
.35014 .30902 L
.35136 .30902 L
.35206 .30902 L
.3527 .30902 L
.35341 .30902 L
.35415 .30902 L
.35541 .30902 L
.35612 .30902 L
Mistroke
.35679 .30902 L
.35804 .30902 L
.35917 .30902 L
.36048 .30902 L
.36173 .30902 L
.36241 .30902 L
.36305 .30902 L
.36425 .30902 L
.36554 .30902 L
.36627 .30902 L
.36694 .30902 L
.36806 .30902 L
.36929 .30902 L
.37057 .30902 L
.37177 .30902 L
.37307 .30902 L
.37381 .30902 L
.37449 .30902 L
.37574 .30902 L
.37637 .30902 L
.37706 .30902 L
.3778 .30902 L
.37859 .30902 L
.37934 .30902 L
.38003 .30902 L
.38134 .30902 L
.38201 .30902 L
.38273 .30902 L
.38405 .30902 L
.38527 .30902 L
.38591 .30902 L
.38661 .30902 L
.38734 .30902 L
.38802 .30902 L
.38928 .30902 L
.39043 .30902 L
.39106 .30902 L
.39176 .30902 L
.39301 .30902 L
.39425 .30902 L
.39536 .30902 L
.39665 .30902 L
.39786 .30902 L
.39899 .30902 L
.40002 .30902 L
.40116 .30902 L
.40235 .30902 L
.40366 .30902 L
.40485 .30902 L
.40551 .30902 L
Mistroke
.40623 .30902 L
.40753 .30902 L
.41235 .30902 L
.42331 .30902 L
.46416 .30902 L
.5035 .30902 L
.54133 .30902 L
.5816 .30902 L
.62036 .30902 L
.66157 .30902 L
.70127 .30902 L
.73945 .30902 L
.78008 .30902 L
.8192 .30902 L
.86077 .30902 L
.90082 .30902 L
.93936 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol0008co`000`1Voc?o03?o0002<ol000<0
000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0003oooooool01_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo00Goool:00007c?o00030000<ol0<ol000/co`000`1Voc?o03?o000O
<ol000<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0^oooo00<0003ooooo
ool05Oooo`00:?ooo`H0000W<ol000<0I_lco`0co`007c?o00030000oooooooo0:Koool002koool5
00008S?o000306Ko<ol0<ol001lco`020000Yoooo`00<oooo`@0000N<ol000<0I_lco`0co`007c?o
00030000oooooooo0:Koool003Ooool2000073?o000306Ko<ol0<ol001lco`000`000?ooooooo`2V
oooo000ioooo0`0001Tco`000`1Voc?o03?o000O<ol000<0003oooooool0Y_ooo`00??ooo`80000G
<ol000<0I_lco`0co`007c?o0080002Woooo000noooo0P0001Dco`000`1Voc?o03?o000O<ol000<0
003oooooool0Y_ooo`00@?ooo`80000C<ol000<0I_lco`0co`007c?o00030000oooooooo0:Koool0
04;oool200004C?o000306Ko<ol0<ol001lco`000`000?ooooooo`2Voooo0014oooo0P0000lco`00
0`1Voc?o03?o000O<ol00P000:Ooool004Koool00`0003?o03?o000<<ol000<0I_lco`0co`007c?o
00030000oooooooo0:Koool004Ooool00`0003?o03?o000;<ol000<0I_lco`0co`007c?o00030000
oooooooo0:Koool004Soool00`0003?o03?o000:<ol000<0I_lco`0co`007c?o00030000oooooooo
0:Koool004Woool00`0003?o03?o0009<ol000<0I_lco`0co`007c?o0080002Woooo001:oooo00<0
000co`0co`0023?o000306Ko<ol0<ol001lco`000`000?ooooooo`2Voooo001;oooo00<0000co`0c
o`001c?o000306Ko<ol0<ol000Hco`02000013?o00800003<ol0100000<co`0200001C?o00030000
oooooooo0:Koool004coool00`0003?o03?o0006<ol000<0I_lco`0co`001C?o00040000<ol0<ol0
000023?o00030000<ol0<ol000<co`00100003?o03?o000000@co`000`000?ooooooo`2Voooo001=
oooo00<0000co`0co`001C?o000306Ko<ol0<ol000Dco`00100003?o03?o000000Tco`000`0003?o
03?o0005<ol000<0000co`0co`000S?o0080002Woooo001>oooo00<0000co`0co`0013?o000306Ko
<ol0<ol000Dco`00100003?o03?o000000Xco`000`0003?o03?o0002<ol00P0000Dco`000`000?oo
ooooo`2Voooo001?oooo00<0000co`0co`000c?o000306Ko<ol0<ol000Dco`00100003?o03?o0000
00Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00Cooo
o`030000<ol0<ol000<co`000`1Voc?o03?o0006<ol00P0000Xco`02000013?o00<00004<ol000<0
003oooooool0Y_ooo`00D?ooo`030000<ol0<ol0008co`000`1Voc?o03?o000O<ol00P000:Ooool0
057oool01@0003?o03?o03?o001Vo`0Q<ol000<0003oooooool0Y_ooo`00D_ooo`040000<ol0<ol0
06Ko8C?o00030000oooooooo0:Koool005;oool0100003?o03?o001Vob4co`000`000?ooooooo`2V
oooo001Coooo00<0000co`00I_l08C?o0080002Woooo001Coooo00<0000co`00I_l08C?o00030000
oooooooo0:Koool005Coool00`00001Voc?o000P<ol000<0003oooooool0Y_ooo`00E?ooo`030000
06Ko<ol0020co`000`000?ooooooo`2Voooo001Eoooo00<0I_lco`0co`007c?o0080002Woooo001E
oooo00<0I_lco`0co`007c?o00030000oooooooo0:Koool005Goool00`1Vo`0003?o000O<ol000<0
003oooooool0Y_ooo`00EOooo`0306Ko0000<ol001lco`000`000?ooooooo`2Voooo001Eoooo00<0
I_ooool000007c?o0080002Woooo001Eoooo00<0I_ooool000007c?o00030000oooooooo0:Koool0
05Goool0101Vooooooooo`0000/co`02000013?o00800004<ol00P0000Dco`000`000?ooooooo`2V
oooo001Eoooo00@0I_ooooooool0000:<ol000@0000co`0co`000008<ol000@0000co`0co`000004
<ol000<0003oooooool0Y_ooo`00EOooo`0506Kooooooooooooo000000Tco`00100003?o03?o0000
00/co`000`0003?o03?o0002<ol00P000:Ooool005Coool206Ko0oooo`030000<ol0<ol000Lco`00
100003?o03?o000000Tco`0200001C?o00030000oooooooo0:Koool005;oool206Ko00?ooooo09Wo
ool00_ooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`000`0003?o03?o0004<ol000<0
003oooooool0Y_ooo`00Coooo`<0I_l3oooo00?o09Woooooool00_ooo`030000<ol0<ol000Lco`02
00002S?o00<00004<ol000<0003oooooool0Y_ooo`00C?ooo`<0I_l6oooo00?o09Woooooool00_oo
o`030000<ol0<ol001Xco`020000Yoooo`00B?ooo`@0I_l9oooo00?o09Woooooool00_ooo`030000
<ol0<ol001Xco`000`000?ooooooo`2Voooo0014oooo101Vo`goool00ol0VOooooooo`03oooo00<0
000co`0co`006C?o00030000oooooooo0:Koool0043oool406Ko4Oooo`03o`2Ioooooooo00?oool0
0`0003?o03?o000I<ol00P000:Ooool003coool406Ko5Oooo`03o`2Ioooooooo00?oool00`0003?o
03?o000I<ol000<0003oooooool0Y_ooo`00>?ooo`@0I_lIoooo00?o09Woooooool01?ooo`030000
<ol0<ol001Pco`000`000?ooooooo`2Voooo000aoooo1`1Voagoool00ol0VOooooooo`04oooo00<0
000co`0co`0063?o00030000oooooooo0:Koool002Koool;06Ko9?ooo`03o`2Ioooooooo00Coool0
0`0003?o03?o000H<ol00P000:Ooool001coool:06Ko;oooo`03o`2Ioooooooo00Goool00`0003?o
03?o000G<ol000<0003oooooool0Y_ooo`005_ooo`H0I_lioooo00?o09Woooooool01Oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Voooo001Eoooo00?o09Woooooool01Oooo`030000<ol0<ol0
01Lco`000`000?ooooooo`2Voooo001Eoooo00?o09Woooooool01_ooo`030000<ol0<ol001Hco`02
0000Yoooo`00EOooo`03o`2Ioooooooo00Koool00`0003?o03?o000F<ol000<0003oooooool0Y_oo
o`00EOooo`03o`2Ioooooooo00Koool2000013?o00800005<ol000<0000co`0co`000S?o00800005
<ol000<0003oooooool0Y_ooo`00EOooo`03o`2Ioooooooo00Goool010000?ooo`00000000Xco`00
1@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000oooooooo0:Koool005Goool0
0ol0VOooooooo`05oooo00@0003oool00000000:<ol000<0000co`0co`0013?o00030000<ol0<ol0
008co`020000Yoooo`00EOooo`03o`2Ioooooooo00Goool010000?ooo`00000000/co`00100003?o
03?o03?o00800005<ol000<0003oooooool0Y_ooo`00EOooo`03o`2Ioooooooo00Goool010000?oo
ooooo`0000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0Y_oo
o`00EOooo`03o`2Ioooooooo00Koool3000023?o00@00003<ol00`0000@co`000`000?ooooooo`2V
oooo001Eoooo00?o09Woooooool02?ooo`030000<ol0<ol001@co`020000Yoooo`00EOooo`03o`2I
oooooooo00Soool00`0003?o03?o000D<ol000<0003oooooool0Y_ooo`00EOooo`03o`2Ioooooooo
00Woool00`0003?o03?o000C<ol000<0003oooooool0Y_ooo`00EOooo`03o`2Ioooooooo00Woool0
0`0003?o03?o000C<ol000<0003oooooool0Y_ooo`00EOooo`03o`2Ioooooooo00Woool00`0003?o
03?o000C<ol00P000:Ooool005Goool00ol0VOooooooo`09oooo00<0000co`0co`004c?o00030000
oooooooo0:Koool005Goool00ol0VOooooooo`0:oooo00<0000co`0co`004S?o00030000oooooooo
0:Koool005Goool00ol0VOooooooo`0:oooo00<0000co`0co`004S?o00030000oooooooo0:Koool0
05Goool00ol0VOooooooo`0:oooo00<0000co`0co`004S?o0080002Woooo001Eoooo00?o09Wooooo
ool02_ooo`030000<ol0<ol0018co`000`000?ooooooo`2Voooo001Eoooo00?o09Woooooool02ooo
o`030000<ol0<ol0014co`000`000?ooooooo`2Voooo001Eoooo00?o09Woooooool02oooo`030000
<ol0<ol0014co`000`000?ooooooo`2Voooo001Eoooo00?o09Woooooool02oooo`030000<ol0<ol0
014co`020000Yoooo`00EOooo`03o`2Ioooooooo00_oool00`0003?o03?o000A<ol000<0003ooooo
ool0Y_ooo`00EOooo`03o`2Ioooooooo00_oool00`0003?o03?o0009<ol01@0000<co`000`000?oo
ooooo`2Voooo001Eoooo00?o09Woooooool03?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003
<ol000<0003oooooool0Y_ooo`00EOooo`03o`2Ioooooooo00coool00`0003?o03?o000:<ol000<0
000co`0co`000c?o0080002Woooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o
00030000<ol0<ol000<co`2Yoooo001Toooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001U
oooo4S?o0:Woool006GooolB<ol00_ooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001U
oooo4S?o0003oooo0000oooo00Woool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00IOoo
oa8co`000oooo`000?ooo`03oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001Ooo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001Uoooo4S?o0003oooo0000oooo00;oool0
10000?ooooooo`0000Coool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`09oooo00<0
003oooooool00_ooo`030000oooooooo07Soool006GooolB<ol000<0003oooooool00_ooo`030000
oooooooo01Goool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo07Ooool0
06KooolA<ol000Coool0003oooooool500005?ooo`030000oooooooo00[oool01@000?oooooooooo
o`00001joooo001Voooo4C?o0003oooo0000oooo00;oool00`000?ooooooo`0Eoooo00<0003ooooo
ool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool006KooolA<ol00_ooo`030000
oooooooo01Ooool200002Oooo`@00002oooo00<0003oooooool0NOooo`00I_oooa4co`2Yoooo001V
oooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.27731 .30902 L
.28302 .30902 L
.28542 .30902 L
.288 .30902 L
.28876 .30902 L
.28948 .30902 L
.29013 .30902 L
s
.29013 .30902 m
.2902 .61803 L
s
0 .4 1 r
.02381 .51708 m
.06244 .51371 L
.10458 .50886 L
.14415 .50284 L
.18221 .49537 L
.22272 .48518 L
.26171 .47275 L
.27193 .46901 L
.27731 .46695 L
.28302 .46471 L
.28542 .46374 L
.288 .46269 L
.28876 .46238 L
.28948 .46208 L
.29013 .46181 L
.29083 .30902 L
.2915 .30902 L
.29221 .30902 L
.29349 .30902 L
.29474 .30902 L
.29545 .30902 L
.2961 .30902 L
.29729 .30902 L
.29856 .30902 L
.29969 .30902 L
.30075 .30902 L
.30191 .30902 L
.30316 .30902 L
.30437 .30902 L
.30507 .30902 L
.30572 .30902 L
.30703 .30902 L
.3077 .30902 L
.30844 .30902 L
.30968 .30902 L
.31099 .30902 L
.31219 .30902 L
.31333 .30902 L
.31403 .30902 L
.31478 .30902 L
.3161 .30902 L
.31685 .30902 L
.31764 .30902 L
.31832 .30902 L
.31906 .30902 L
.31976 .30902 L
.32039 .30902 L
.32112 .30902 L
.32182 .30902 L
.32305 .30902 L
Mistroke
.32375 .30902 L
.3244 .30902 L
.32566 .30902 L
.32633 .30902 L
.32703 .30902 L
.32832 .30902 L
.32951 .30902 L
.33065 .30902 L
.33172 .30902 L
.33289 .30902 L
.33414 .30902 L
.33484 .30902 L
.33548 .30902 L
.33618 .30902 L
.33693 .30902 L
.33819 .30902 L
.3389 .30902 L
.33957 .30902 L
.34081 .30902 L
.34195 .30902 L
.3432 .30902 L
.34452 .30902 L
.34576 .30902 L
.34646 .30902 L
.3471 .30902 L
.34828 .30902 L
.34953 .30902 L
.35066 .30902 L
.3517 .30902 L
.35285 .30902 L
.35409 .30902 L
.3554 .30902 L
.35614 .30902 L
.35683 .30902 L
.35809 .30902 L
.35872 .30902 L
.35943 .30902 L
.36063 .30902 L
.36194 .30902 L
.36317 .30902 L
.3643 .30902 L
.36537 .30902 L
.36651 .30902 L
.36759 .30902 L
.36857 .30902 L
.36972 .30902 L
.37097 .30902 L
.37216 .30902 L
.37325 .30902 L
.37437 .30902 L
Mistroke
.37543 .30902 L
.37658 .30902 L
.37783 .30902 L
.37913 .30902 L
.38036 .30902 L
.38147 .30902 L
.38268 .30902 L
.38332 .30902 L
.38401 .30902 L
.38523 .30902 L
.38655 .30902 L
.3873 .30902 L
.388 .30902 L
.38926 .30902 L
.39041 .30902 L
.39107 .30902 L
.39176 .30902 L
.39301 .30902 L
.3941 .30902 L
.39531 .30902 L
.3966 .30902 L
.39781 .30902 L
.39896 .30902 L
.4 .30902 L
.40115 .30902 L
.40236 .30902 L
.40358 .30902 L
.40487 .30902 L
.40554 .30902 L
.40628 .30902 L
.40758 .30902 L
.41251 .30902 L
.41819 .30902 L
.42334 .30902 L
.4431 .30902 L
.46147 .30902 L
.50183 .30902 L
.54067 .30902 L
.58197 .30902 L
.62175 .30902 L
.66002 .30902 L
.70073 .30902 L
.73994 .30902 L
.78159 .30902 L
.82173 .30902 L
.86035 .30902 L
.90143 .30902 L
.94099 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000O<ol000<0000co`0co`0043?o000306Ko<ol0<ol001Xco`000`000?ooooooo`0]
oooo00<0003oooooool0;Oooo`030000oooooooo02koool00`000?ooooooo`0Eoooo000Xoooo1P00
02`co`000`1Voc?o03?o000J<ol000<0003oooooool0Y_ooo`00;_ooo`D0000W<ol000<0I_lco`0c
o`006S?o0080002Woooo000coooo100002<co`000`1Voc?o03?o000J<ol000<0003oooooool0Y_oo
o`00=oooo`80000Q<ol000<0I_lco`0co`006S?o00030000oooooooo0:Koool003Woool300007S?o
000306Ko<ol0<ol001Xco`000`000?ooooooo`2Voooo000loooo0P0001`co`000`1Voc?o03?o000J
<ol00P000:Ooool003koool200006S?o000306Ko<ol0<ol001Xco`000`000?ooooooo`2Voooo0010
oooo0P0001Pco`000`1Voc?o03?o000J<ol000<0003oooooool0Y_ooo`00@_ooo`80000F<ol000<0
I_lco`0co`006S?o00030000oooooooo0:Koool004Coool2000053?o000306Ko<ol0<ol001Xco`02
0000Yoooo`00A_ooo`030000<ol0<ol0014co`000`1Voc?o03?o000J<ol000<0003oooooool0Y_oo
o`00Aoooo`030000<ol0<ol0010co`000`1Voc?o03?o000J<ol000<0003oooooool0Y_ooo`00B?oo
o`030000<ol0<ol000lco`000`1Voc?o03?o000J<ol000<0003oooooool0Y_ooo`00BOooo`030000
<ol0<ol000hco`000`1Voc?o03?o000J<ol00P000:Ooool004[oool00`0003?o03?o000=<ol000<0
I_lco`0co`006S?o00030000oooooooo0:Koool004_oool00`0003?o03?o000<<ol000@0I_lco`0c
o`0co`02000013?o00800003<ol0100000<co`0200001C?o00030000oooooooo0:Koool004coool0
0`0003?o03?o000;<ol000@0I_lco`0co`000002<ol000<0000co`0co`001S?o00030000<ol0<ol0
00<co`00100003?o03?o000000@co`000`000?ooooooo`2Voooo001=oooo00<0000co`0co`002S?o
000406Ko<ol0<ol000000S?o00030000<ol0<ol000Lco`000`0003?o03?o0005<ol000<0000co`0c
o`000S?o0080002Woooo001>oooo00<0000co`0co`002C?o000406Ko<ol0<ol000000S?o00030000
<ol0<ol000Pco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`2Voooo001?oooo00<0
000co`0co`0023?o000406Ko<ol0<ol000000S?o00030000<ol0<ol000Hco`00100003?o03?o0000
00<co`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00Coooo`030000<ol0<ol000Pco`00
101Voc?o03?o03?o0080000:<ol00P0000@co`03000013?o00030000oooooooo0:Koool0053oool0
0`0003?o03?o0007<ol000<0I_lco`0co`006S?o0080002Woooo001Aoooo00<0000co`0co`001S?o
000306Ko<ol0<ol001Xco`000`000?ooooooo`2Voooo001Boooo00<0000co`0co`001C?o000306Ko
<ol0<ol001Xco`000`000?ooooooo`2Voooo001Boooo00<0000co`0co`001C?o000306Ko<ol0<ol0
01Xco`000`000?ooooooo`2Voooo001Coooo00<0000co`0co`0013?o000306Ko<ol0<ol001Xco`02
0000Yoooo`00Doooo`030000<ol0<ol000@co`000`1Voc?o03?o000J<ol000<0003oooooool0Y_oo
o`00E?ooo`030000<ol0<ol000<co`000`1Voc?o03?o000J<ol000<0003oooooool0Y_ooo`00E?oo
o`030000<ol0<ol000<co`000`1Voc?o03?o000J<ol000<0003oooooool0Y_ooo`00EOooo`030000
<ol0<ol0008co`000`1Voc?o03?o000J<ol00P000:Ooool005Goool00`0003?o03?o0002<ol000<0
I_lco`0co`006S?o00030000oooooooo0:Koool005Koool01@0003?o03?o03?o001Vo`0L<ol000<0
003oooooool0Y_ooo`00E_ooo`050000<ol0<ol0<ol006Ko01`co`000`000?ooooooo`2Voooo001G
oooo00@0000co`0co`00I_lL<ol00P000:Ooool005Ooool0100003?o03?o001Voa`co`000`000?oo
ooooo`2Voooo001Hoooo00<0000co`00I_l02C?o00800004<ol00P0000@co`0200001C?o00030000
oooooooo0:Koool005Soool00`00001Vo`1Vo`08<ol000@0000co`0co`000008<ol000@0000co`0c
o`000004<ol000<0003oooooool0Y_ooo`00Eoooo`<0I_l00ol0VC?o03?o0006<ol000@0000co`0c
o`00000;<ol000<0000co`0co`000S?o0080002Woooo001Eoooo0P1Vo`;oool00`000?l0VC?o0007
<ol000@0000co`0co`000009<ol00P0000Dco`000`000?ooooooo`2Voooo001Boooo0`1Vo`Coool0
0`000?l0VC?o0007<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000oooooooo
0:Koool004ooool306Ko2?ooo`03o`2I<ol0<ol000Lco`0200002S?o00<00004<ol000<0003ooooo
ool0Y_ooo`00Boooo`@0I_l;oooo00?o09Tco`0co`006S?o0080002Woooo0018oooo0`1Vo`ooool0
0ol0VC?o03?o000J<ol000<0003oooooool0Y_ooo`00A?ooo`@0I_lBoooo00?o09T0000co`006S?o
00030000oooooooo0:Koool0043oool406Ko5_ooo`03o`2I0000<ol001Xco`020000Yoooo`00??oo
o`@0I_lJoooo00?o09T0000co`006S?o00030000oooooooo0:Koool003Soool406Ko7_ooo`03o`2I
oooo000001Xco`000`000?ooooooo`2Voooo000aoooo1`1Vob;oool00ol0VOooo`00000J<ol000<0
003oooooool0Y_ooo`009_ooo`/0I_lYoooo00?o09Woool000006S?o0080002Woooo000Loooo2P1V
ocCoool01?l0VOooooooo`0001Tco`000`000?ooooooo`2Voooo000Foooo1P1Vockoool01?l0VOoo
ooooo`0001Tco`000`000?ooooooo`2Voooo001Joooo00Co09Woooooool0000I<ol000<0003ooooo
ool0Y_ooo`00F_ooo`05o`2Ioooooooooooo000001Pco`020000Yoooo`00F_ooo`05o`2Ioooooooo
oooo000001Pco`000`000?ooooooo`2Voooo001Joooo00Co09Woooooooooool2000013?o00800005
<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Y_ooo`00F_ooo`05o`2Ioooooooo
0000oooo0080000:<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Voooo001Joooo00Go09Woooooool0003oool00P0000Xco`000`0003?o03?o0004<ol000<0
000co`0co`000S?o0080002Woooo001Joooo00Go09Woooooool0003oool00P0000/co`00100003?o
03?o03?o00800005<ol000<0003oooooool0Y_ooo`00F_ooo`04o`2Ioooooooo00000_ooo`030000
<ol0<ol000Hco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0Y_oo
o`00F_ooo`04o`2Ioooooooooooo0`0000Pco`0400000c?o00<00004<ol000<0003oooooool0Y_oo
o`00F_ooo`03o`2Ioooooooo00?oool00`0003?o03?o000D<ol00P000:Ooool005[oool00ol0VOoo
ooooo`03oooo00<0000co`0co`0053?o00030000oooooooo0:Koool005[oool00ol0VOooooooo`04
oooo00<0000co`0co`004c?o00030000oooooooo0:Koool005[oool00ol0VOooooooo`04oooo00<0
000co`0co`004c?o00030000oooooooo0:Koool005[oool00ol0VOooooooo`04oooo00<0000co`0c
o`004c?o0080002Woooo001Joooo00?o09Woooooool01?ooo`030000<ol0<ol001<co`000`000?oo
ooooo`2Voooo001Joooo00?o09Woooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`2V
oooo001Joooo00?o09Woooooool01Oooo`030000<ol0<ol0018co`000`000?ooooooo`2Voooo001J
oooo00?o09Woooooool01Oooo`030000<ol0<ol0018co`020000Yoooo`00F_ooo`03o`2Ioooooooo
00Goool00`0003?o03?o000B<ol000<0003oooooool0Y_ooo`00F_ooo`03o`2Ioooooooo00Koool0
0`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00F_ooo`03o`2Ioooooooo00Koool00`0003?o
03?o000A<ol000<0003oooooool0Y_ooo`00F_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000A
<ol00P000:Ooool005[oool00ol0VOooooooo`06oooo00<0000co`0co`004C?o00030000oooooooo
0:Koool005[oool00ol0VOooooooo`06oooo00<0000co`0co`002C?o00D00003<ol000<0003ooooo
ool0Y_ooo`00F_ooo`03o`2Ioooooooo00Ooool00`0003?o03?o000:<ol000<0000co`0co`000c?o
00030000oooooooo0:Koool005[oool00ol0VOooooooo`07oooo00<0000co`0co`002S?o00030000
<ol0<ol000<co`020000Yoooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo`dco`00
0`0003?o03?o0003<ol0ZOooo`00I?ooo``co`0200001C?o0:Woool006GooolB<ol0ZOooo`00IOoo
oa8co`2Yoooo001Uoooo4S?o00;oool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00IOoo
oa8co`000oooo`000?ooo`09oooo00<0003oooooool07oooo`030000oooooooo07Soool006GooolB
<ol000?oool0003oool00oooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000?oool3
00001?ooo`030000oooooooo07Soool006GooolB<ol000?oool0003oool00_ooo`040000oooooooo
00001?ooo`030000oooooooo00Coool400001Oooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001Uoooo4S?o00030000oooooooo00;oool00`000?ooooooo`0E
oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo07Ooool006KooolA
<ol000Coool0003oooooool500005?ooo`030000oooooooo00Ooool300001?ooo`030000oooooooo
07Soool006KooolA<ol000?oool0003oool00_ooo`030000oooooooo01Goool00`000?ooooooo`08
oooo00<0003oooooool00oooo`030000oooooooo07Soool006KooolA<ol00_ooo`030000oooooooo
01Ooool200002_ooo`<00002oooo00<0003oooooool0NOooo`00I_oooa4co`2Yoooo001Voooo4C?o
0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.29779 .30902 L
.30316 .30902 L
.3056 .30902 L
.30791 .30902 L
.30919 .30902 L
s
.30919 .30902 m
.30927 .61803 L
s
0 .4 1 r
.02381 .51692 m
.06244 .5135 L
.10458 .50857 L
.14415 .50246 L
.18221 .49486 L
.22272 .48449 L
.26171 .47181 L
.28158 .46418 L
.29205 .45982 L
.29779 .45733 L
.30316 .45493 L
.3056 .45381 L
.30791 .45274 L
.30919 .45214 L
.30992 .30902 L
.31059 .30902 L
.31177 .30902 L
.31304 .30902 L
.31377 .30902 L
.31445 .30902 L
.31519 .30902 L
.31597 .30902 L
.31729 .30902 L
.31804 .30902 L
.31874 .30902 L
.32005 .30902 L
.32124 .30902 L
.3219 .30902 L
.32261 .30902 L
.32392 .30902 L
.3251 .30902 L
.32621 .30902 L
.32743 .30902 L
.32874 .30902 L
.33005 .30902 L
.3307 .30902 L
.33142 .30902 L
.33269 .30902 L
.33387 .30902 L
.33507 .30902 L
.33621 .30902 L
.33722 .30902 L
.33833 .30902 L
.33953 .30902 L
.3408 .30902 L
.34189 .30902 L
.34309 .30902 L
.34438 .30902 L
.34558 .30902 L
.3469 .30902 L
Mistroke
.34763 .30902 L
.3483 .30902 L
.34952 .30902 L
.35021 .30902 L
.35085 .30902 L
.35202 .30902 L
.35325 .30902 L
.35435 .30902 L
.35555 .30902 L
.35668 .30902 L
.35773 .30902 L
.35895 .30902 L
.36024 .30902 L
.36133 .30902 L
.36253 .30902 L
.36381 .30902 L
.36453 .30902 L
.36519 .30902 L
.36641 .30902 L
.36769 .30902 L
.36888 .30902 L
.36999 .30902 L
.3712 .30902 L
.3725 .30902 L
.37324 .30902 L
.37391 .30902 L
.37466 .30902 L
.37545 .30902 L
.37613 .30902 L
.37677 .30902 L
.37747 .30902 L
.37823 .30902 L
.3789 .30902 L
.37962 .30902 L
.38094 .30902 L
.38342 .30902 L
.38456 .30902 L
.38575 .30902 L
.38706 .30902 L
.38826 .30902 L
.38939 .30902 L
.39043 .30902 L
.39158 .30902 L
.39281 .30902 L
.39351 .30902 L
.39415 .30902 L
.39485 .30902 L
.3956 .30902 L
.39686 .30902 L
.39757 .30902 L
Mistroke
.39824 .30902 L
.39948 .30902 L
.40062 .30902 L
.40193 .30902 L
.40318 .30902 L
.40386 .30902 L
.4045 .30902 L
.4057 .30902 L
.40699 .30902 L
.40838 .30902 L
.41322 .30902 L
.42417 .30902 L
.4652 .30902 L
.50471 .30902 L
.5427 .30902 L
.58314 .30902 L
.62207 .30902 L
.66345 .30902 L
.70332 .30902 L
.74167 .30902 L
.78247 .30902 L
.82175 .30902 L
.85952 .30902 L
.89975 .30902 L
.93845 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0002<ol000<0
I_lco`0co`000S?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0003oooooool01_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo00Goool:00007c?o00030000<ol0<ol001Dco`000`1Voc?o03?o000E
<ol000<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0^oooo00<0003ooooo
ool05Oooo`00:?ooo`H0000a<ol000<0I_lco`0co`005C?o00030000oooooooo0:Koool002koool5
0000;3?o000306Ko<ol0<ol001Dco`020000Yoooo`00<oooo`@0000X<ol000<0I_lco`0co`005C?o
00030000oooooooo0:Koool003Ooool200009S?o000306Ko<ol0<ol001Dco`000`000?ooooooo`2V
oooo000ioooo0`0002<co`000`1Voc?o03?o000E<ol000<0003oooooool0Y_ooo`00??ooo`80000Q
<ol000<0I_lco`0co`005C?o0080002Woooo000noooo0P0001lco`000`1Voc?o03?o000E<ol000<0
003oooooool0Y_ooo`00@?ooo`80000M<ol000<0I_lco`0co`005C?o00030000oooooooo0:Koool0
04;oool200006c?o000306Ko<ol0<ol001Dco`000`000?ooooooo`2Voooo0014oooo0P0001Tco`00
0`1Voc?o03?o000E<ol00P000:Ooool004Koool00`0003?o03?o000F<ol000<0I_lco`0co`005C?o
00030000oooooooo0:Koool004Ooool00`0003?o03?o000E<ol000<0I_lco`0co`005C?o00030000
oooooooo0:Koool004Soool00`0003?o03?o000D<ol000<0I_lco`0co`005C?o00030000oooooooo
0:Koool004Woool00`0003?o03?o000C<ol000<0I_lco`0co`005C?o0080002Woooo001:oooo00<0
000co`0co`004S?o000306Ko<ol0<ol001Dco`000`000?ooooooo`2Voooo001;oooo00<0000co`0c
o`0043?o00800004<ol00P0000<co`0400000c?o00800005<ol000<0003oooooool0Y_ooo`00C?oo
o`030000<ol0<ol000hco`00100003?o001Vo`0000Pco`000`0003?o03?o0003<ol000@0000co`0c
o`000004<ol000<0003oooooool0Y_ooo`00COooo`030000<ol0<ol000dco`00100003?o001Vo`00
00Tco`000`0003?o03?o0005<ol000<0000co`0co`000S?o0080002Woooo001>oooo00<0000co`0c
o`0033?o00040000<ol006Ko00002S?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo
0:Koool004ooool00`0003?o03?o000;<ol000@0000co`00I_l00008<ol000@0000co`0co`000003
<ol000<0000co`0co`0013?o00030000oooooooo0:Koool004ooool00`0003?o03?o000<<ol00P00
00Xco`02000013?o00<00004<ol000<0003oooooool0Y_ooo`00D?ooo`030000<ol0<ol000`co`00
0`1Voc?o03?o000E<ol00P000:Ooool0057oool00`0003?o03?o000;<ol000<0I_lco`0co`005C?o
00030000oooooooo0:Koool005;oool00`0003?o03?o000:<ol000<0I_lco`0co`005C?o00030000
oooooooo0:Koool005;oool00`0003?o03?o000:<ol000<0I_lco`0co`005C?o00030000oooooooo
0:Koool005?oool00`0003?o03?o0009<ol000<0I_lco`0co`005C?o0080002Woooo001Coooo00<0
000co`0co`002C?o000306Ko<ol0<ol001Dco`000`000?ooooooo`2Voooo001Doooo00<0000co`0c
o`0023?o000306Ko<ol0<ol001Dco`000`000?ooooooo`2Voooo001Doooo00<0000co`0co`0023?o
000306Ko<ol0<ol001Dco`000`000?ooooooo`2Voooo001Eoooo00<0000co`0co`001c?o000306Ko
<ol0<ol001Dco`020000Yoooo`00EOooo`030000<ol0<ol000Lco`000`1Voc?o03?o000E<ol000<0
003oooooool0Y_ooo`00E_ooo`030000<ol0<ol000Hco`000`1Voc?o03?o000E<ol000<0003ooooo
ool0Y_ooo`00E_ooo`030000<ol0<ol000Hco`000`1Voc?o03?o000E<ol000<0003oooooool0Y_oo
o`00Eoooo`030000<ol0<ol000Dco`000`1Voc?o03?o000E<ol00P000:Ooool005Ooool00`0003?o
03?o0003<ol00`1VoaLco`000`000?ooooooo`2Voooo001Hoooo00D0000co`0co`0co`00I_l00S?o
0003o`2I<ol0<ol0008co`02000013?o00800004<ol00P0000Dco`000`000?ooooooo`2Voooo001H
oooo00@0000co`00I_l0I_l3<ol000Go09Tco`0co`0co`0000000S?o00030000<ol0<ol000Hco`00
100003?o03?o000000@co`000`000?ooooooo`2Voooo001Goooo0`1Vo`Dco`001Ol0VC?o03?o03?o
00000002<ol000<0000co`0co`002C?o00030000<ol0<ol0008co`020000Yoooo`00EOooo`80I_l2
oooo00<0000co`0co`000c?o0005o`2I<ol0<ol0<ol00000008co`000`0003?o03?o0007<ol00P00
00Dco`000`000?ooooooo`2Voooo001Boooo0`1Vo`Coool00`0003?o03?o0003<ol000Go09Tco`0c
o`0co`0000000S?o00030000<ol0<ol000Lco`000`0003?o03?o0004<ol000<0003oooooool0Y_oo
o`00Coooo`<0I_l8oooo00<0000co`0co`000S?o0003o`2I<ol0<ol0008co`0200002S?o00<00004
<ol000<0003oooooool0Y_ooo`00Boooo`@0I_l;oooo00<0000co`0co`000S?o0003o`2I<ol0<ol0
01Dco`020000Yoooo`00B?ooo`<0I_l?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001Dco`00
0`000?ooooooo`2Voooo0014oooo101Voa?oool01@0003?o03?o03?o0?l0V@0G<ol000<0003ooooo
ool0Y_ooo`00@?ooo`@0I_lGoooo00D0000co`0co`0co`3o09T05c?o0080002Woooo000joooo1P1V
oa_oool01@0003?o03?o03?o0?l0V@0G<ol000<0003oooooool0Y_ooo`00<oooo`L0I_lRoooo00@0
000co`0co`3o09TG<ol000<0003oooooool0Y_ooo`00;_ooo`D0I_lYoooo00@0000co`0co`3o09TG
<ol000<0003oooooool0Y_ooo`009_ooo`P0I_l^oooo00@0000co`0co`3o09TG<ol00P000:Ooool0
01coool:06Ko=oooo`030000<ol0o`2I01Lco`000`000?ooooooo`2Voooo000Foooo1P1Vod7oool0
0`0003?o0?l0V@0G<ol000<0003oooooool0Y_ooo`00GOooo`030000<ol0o`2I01Lco`000`000?oo
ooooo`2Voooo001Noooo00<0003o09Tco`005S?o0080002Woooo001Noooo00<0003o09Tco`005S?o
00030000oooooooo0:Koool005koool2000013?o00800005<ol000<0000co`0co`000S?o00800005
<ol000<0003oooooool0Y_ooo`00GOooo`040000ooooo`2I00002S?o00050000<ol0<ol0<ol00000
008co`000`0003?o03?o0002<ol000<0003oooooool0Y_ooo`00GOooo`040000ooooo`2I00002S?o
00030000<ol0<ol000@co`000`0003?o03?o0002<ol00P000:Ooool005goool010000?ooool0V@00
00/co`00100003?o03?o03?o00800005<ol000<0003oooooool0Y_ooo`00GOooo`040000ooooo`2I
000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?ooooooo`2Voooo001N
oooo0`0000Pco`0400000c?o00<00004<ol000<0003oooooool0Y_ooo`00Goooo`03o`2I0000<ol0
01Dco`020000Yoooo`00Goooo`03o`2I0000<ol001Dco`000`000?ooooooo`2Voooo001Ooooo00?o
09Woool000005C?o00030000oooooooo0:Koool005ooool00ol0VOooo`00000E<ol000<0003ooooo
ool0Y_ooo`00Goooo`03o`2Ioooo000001Dco`020000Yoooo`00Goooo`03o`2Ioooo000001Dco`00
0`000?ooooooo`2Voooo001Ooooo00Co09Woooooool0000D<ol000<0003oooooool0Y_ooo`00Gooo
o`04o`2Ioooooooo000053?o00030000oooooooo0:Koool005ooool01?l0VOooooooo`0001@co`02
0000Yoooo`00Goooo`04o`2Ioooooooo000053?o00030000oooooooo0:Koool005ooool01Ol0VOoo
ooooooooo`00000C<ol000<0003oooooool0Y_ooo`00Goooo`05o`2Ioooooooooooo000001<co`00
0`000?ooooooo`2Voooo001Ooooo00Go09Woooooooooool000004c?o0080002Woooo001Ooooo00Go
09Woooooooooool000004c?o00030000oooooooo0:Koool005ooool01Ol0VOooooooooooo`00000;
<ol01@0000<co`000`000?ooooooo`2Voooo001Ooooo00?o09Woooooool00_ooo`030000<ol0<ol0
00Xco`000`0003?o03?o0003<ol000<0003oooooool0Y_ooo`00Goooo`03o`2Ioooooooo00;oool0
0`0003?o03?o000:<ol000<0000co`0co`000c?o0080002Woooo001Toooo3C?o00030000<ol0<ol0
00<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo33?o00800005<ol0ZOoo
o`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol00_ooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001Uoooo4S?o0003oooo0000oooo00Woool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`03oooo0P0000Coool00`000?ooooooo`0<
oooo1@0000;oool200001?ooo`800004oooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`00
0?ooo`02oooo00@0003oooooool00004oooo00<0003oooooool01?ooo`@00005oooo00<0003ooooo
ool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool006GooolB<ol000<0003ooooo
ool00_ooo`030000oooooooo01Goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`030000
oooooooo07Ooool006KooolA<ol000Coool0003oooooool500005?ooo`030000oooooooo00Soool2
00001?ooo`030000oooooooo07Soool006KooolA<ol000?oool0003oool00_ooo`030000oooooooo
01Goool00`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooooooo07Soool006KooolA
<ol00_ooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003oooooool0NOooo`00I_oo
oa4co`2Yoooo001Voooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.31875 .30902 L
.32392 .30902 L
.32617 .30902 L
.32728 .30902 L
.32831 .30902 L
s
.32831 .30902 m
.32843 .61803 L
s
0 .4 1 r
.02381 .51654 m
.06244 .513 L
.10458 .50789 L
.14415 .50154 L
.18221 .49364 L
.22272 .48283 L
.26171 .46957 L
.28158 .46157 L
.30316 .45183 L
.31323 .44688 L
.31875 .44405 L
.32392 .44133 L
.32617 .44013 L
.32728 .43953 L
.32831 .43897 L
.32949 .30902 L
.33078 .30902 L
.33187 .30902 L
.33304 .30902 L
.33575 .30902 L
.3364 .30902 L
.33708 .30902 L
.33831 .30902 L
.3394 .30902 L
.3406 .30902 L
.34189 .30902 L
.34309 .30902 L
.34434 .30902 L
.34551 .30902 L
.34674 .30902 L
.34739 .30902 L
.34809 .30902 L
.34881 .30902 L
.34957 .30902 L
.35021 .30902 L
.35092 .30902 L
.35157 .30902 L
.35228 .30902 L
.35354 .30902 L
.35482 .30902 L
.35554 .30902 L
.3562 .30902 L
.35743 .30902 L
.35872 .30902 L
.35981 .30902 L
.36097 .30902 L
.36224 .30902 L
.36344 .30902 L
.36467 .30902 L
.36582 .30902 L
Mistroke
.36707 .30902 L
.36778 .30902 L
.36841 .30902 L
.36958 .30902 L
.37084 .30902 L
.37204 .30902 L
.37313 .30902 L
.3742 .30902 L
.37519 .30902 L
.37628 .30902 L
.37744 .30902 L
.37867 .30902 L
.37983 .30902 L
.38086 .30902 L
.38199 .30902 L
.38322 .30902 L
.38434 .30902 L
.38557 .30902 L
.38686 .30902 L
.38799 .30902 L
.38904 .30902 L
.39019 .30902 L
.39142 .30902 L
.39212 .30902 L
.39276 .30902 L
.39347 .30902 L
.39422 .30902 L
.39548 .30902 L
.3962 .30902 L
.39686 .30902 L
.39811 .30902 L
.39925 .30902 L
.40056 .30902 L
.40181 .30902 L
.40301 .30902 L
.4037 .30902 L
.40434 .30902 L
.40563 .30902 L
.40636 .30902 L
.40703 .30902 L
.41187 .30902 L
.42283 .30902 L
.46242 .30902 L
.5005 .30902 L
.54102 .30902 L
.58004 .30902 L
.6215 .30902 L
.66145 .30902 L
.69989 .30902 L
.74077 .30902 L
Mistroke
.78014 .30902 L
.818 .30902 L
.85831 .30902 L
.8971 .30902 L
.93834 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000?o
09T0000co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000O<ol000<0000co`0co`006C?o0003o`2I06Ko<ol0014co`000`000?ooooooo`0]
oooo00<0003oooooool0;Oooo`030000oooooooo02koool00`000?ooooooo`0Eoooo000Xoooo1P00
03Dco`000ol0V@1Voc?o000A<ol000<0003oooooool0Y_ooo`00;_ooo`D0000`<ol000?o09T0I_lc
o`004C?o0080002Woooo000coooo100002`co`000ol0V@1Voc?o000A<ol000<0003oooooool0Y_oo
o`00=oooo`80000Z<ol000?o09T0I_lco`004C?o00030000oooooooo0:Koool003Woool300009c?o
0003o`2I06Ko<ol0014co`000`000?ooooooo`2Voooo000loooo0P0002Dco`000ol0V@1Voc?o000A
<ol00P000:Ooool003koool200008c?o0003o`2I06Ko<ol0014co`000`000?ooooooo`2Voooo0010
oooo0P00024co`000ol0V@1Voc?o000A<ol000<0003oooooool0Y_ooo`00@_ooo`80000O<ol000?o
09T0I_lco`004C?o00030000oooooooo0:Koool004Coool200007C?o0003o`2I06Ko<ol0014co`02
0000Yoooo`00A_ooo`030000<ol0<ol001Xco`000ol0V@1Voc?o000A<ol000<0003oooooool0Y_oo
o`00Aoooo`030000<ol0<ol001Tco`000ol0V@1Voc?o000A<ol000<0003oooooool0Y_ooo`00B?oo
o`030000<ol0<ol001Pco`000ol0V@1Voc?o000A<ol000<0003oooooool0Y_ooo`00BOooo`030000
<ol0<ol001Lco`000ol0V@1Voc?o000A<ol00P000:Ooool004[oool00`0003?o03?o000F<ol000<0
I_lco`0co`004C?o00030000oooooooo0:Koool004_oool00`0003?o03?o000@<ol00P0000<co`00
0`1Vo`0000000003<ol0100000<co`0200001C?o00030000oooooooo0:Koool004coool00`0003?o
03?o000><ol000@0000co`0co`000002<ol000<0I_lco`0co`000c?o00030000<ol0<ol000<co`00
100003?o03?o000000@co`000`000?ooooooo`2Voooo001=oooo00<0000co`0co`003C?o00040000
<ol0<ol000000S?o000306Ko<ol0<ol000@co`000`0003?o03?o0005<ol000<0000co`0co`000S?o
0080002Woooo001>oooo00<0000co`0co`0033?o00040000<ol0<ol000000S?o000306Ko<ol0<ol0
00Dco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`2Voooo001?oooo00<0000co`0c
o`002c?o00040000<ol0<ol000000S?o000306Ko<ol0<ol000<co`00100003?o03?o000000<co`00
0`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00Coooo`030000<ol0<ol000`co`0200000c?o
000306Ko<ol0<ol000@co`02000013?o00<00004<ol000<0003oooooool0Y_ooo`00D?ooo`030000
<ol0<ol0010co`000`1Voc?o03?o000A<ol00P000:Ooool0057oool00`0003?o03?o000?<ol000<0
I_lco`0co`004C?o00030000oooooooo0:Koool005;oool00`0003?o03?o000><ol000<0I_lco`0c
o`004C?o00030000oooooooo0:Koool005;oool00`0003?o03?o000><ol000<0I_lco`0co`004C?o
00030000oooooooo0:Koool005?oool00`0003?o03?o000=<ol000<0I_lco`0co`004C?o0080002W
oooo001Coooo00<0000co`0co`003C?o000306Ko<ol0<ol0014co`000`000?ooooooo`2Voooo001D
oooo00<0000co`0co`0033?o000306Ko<ol0<ol0014co`000`000?ooooooo`2Voooo001Doooo00<0
000co`0co`0033?o000306Ko<ol0<ol0014co`000`000?ooooooo`2Voooo001Eoooo00<0000co`0c
o`002c?o000306Ko<ol0<ol0014co`020000Yoooo`00EOooo`030000<ol0<ol000/co`000`1Voc?o
03?o000A<ol000<0003oooooool0Y_ooo`00E_ooo`030000<ol0<ol000Tco`0206Ko4c?o00030000
oooooooo0:Koool005Koool00`0003?o03?o0007<ol00P1Vo`03<ol0o`2I<ol0018co`000`000?oo
ooooo`2Voooo001Goooo00<0000co`0co`0013?o0080I_l3<ol000?o09Tco`0co`004C?o0080002W
oooo001Goooo00<0000co`0co`000S?o0080I_l5<ol000?o09Tco`0co`004C?o00030000oooooooo
0:Koool005Soool0100003?o001Vo`1Vo`Lco`000ol0V@0000000004<ol00P0000@co`0200001C?o
00030000oooooooo0:Koool005Ooool306Ko2C?o00040000<ol0<ol0000023?o00040000<ol0<ol0
000013?o00030000oooooooo0:Koool005Goool206Ko0_ooo`030000<ol0<ol000Lco`00100003?o
03?o000000/co`000`0003?o03?o0002<ol00P000:Ooool005;oool306Ko1?ooo`030000<ol0<ol0
00Lco`00100003?o03?o000000Tco`0200001C?o00030000oooooooo0:Koool004ooool306Ko1ooo
o`030000<ol0<ol000Lco`00100003?o03?o000000Tco`000`0003?o03?o0004<ol000<0003ooooo
ool0Y_ooo`00Boooo`@0I_l;oooo00<0000co`0co`001S?o0003o`2I0000000000Xco`03000013?o
00030000oooooooo0:Koool004Soool306Ko3oooo`030000<ol0<ol000Hco`000ol0VC?o03?o000A
<ol00P000:Ooool004Coool406Ko4_ooo`030000<ol0<ol000Hco`000ol0VC?o03?o000A<ol000<0
003oooooool0Y_ooo`00@?ooo`@0I_lGoooo00<0000co`0co`001C?o0003o`2I<ol0<ol0014co`00
0`000?ooooooo`2Voooo000loooo101Voa_oool00`0003?o03?o0005<ol000?o09Tco`0co`004C?o
0080002Woooo000hoooo101Voaooool00`0003?o03?o0005<ol000?o09Tco`0co`004C?o00030000
oooooooo0:Koool003?oool506Ko9?ooo`030000<ol0<ol000@co`000ol0VC?o03?o000A<ol000<0
003oooooool0Y_ooo`00;_ooo`D0I_lYoooo00<0000co`0co`0013?o0003o`2I<ol0<ol0014co`00
0`000?ooooooo`2Voooo000Voooo201Vobkoool00`0003?o03?o0004<ol000?o09Tco`0co`004C?o
0080002Woooo000Loooo2P1VocOoool00`0003?o03?o0003<ol000?o09Tco`0co`004C?o00030000
oooooooo0:Koool001Koool606Ko@Oooo`030000<ol0<ol000<co`000ol0VC?o03?o000A<ol000<0
003oooooool0Y_ooo`00GOooo`030000<ol0<ol000<co`000ol0VC?o03?o000A<ol000<0003ooooo
ool0Y_ooo`00G_ooo`030000<ol0<ol0008co`000ol0VC?o03?o000A<ol00P000:Ooool005koool0
0`0003?o03?o0002<ol000?o09Tco`0co`004C?o00030000oooooooo0:Koool005koool200000c?o
0003o`2I0000000000Dco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`2Voooo001M
oooo00@0003oool000000002<ol000?o09Tco`0co`001C?o00050000<ol0<ol0<ol00000008co`00
0`0003?o03?o0002<ol000<0003oooooool0Y_ooo`00GOooo`040000oooo000000000S?o0003o`2I
<ol0<ol000Dco`000`0003?o03?o0004<ol000<0000co`0co`000S?o0080002Woooo001Moooo00@0
003oool000000002<ol000?o09Tco`0co`001S?o00040000<ol0<ol0<ol00P0000Dco`000`000?oo
ooooo`2Voooo001Moooo00@0003oooooool00002<ol000?o09Tco`0co`000c?o00040000<ol0<ol0
00000c?o00030000<ol0<ol000@co`000`000?ooooooo`2Voooo001Noooo0`00008co`000ol0VC?o
03?o0003<ol0100000<co`03000013?o00030000oooooooo0:Koool0063oool0100003?o03?o0?l0
VA<co`020000Yoooo`00H?ooo`040000<ol0<ol0o`2I4c?o00030000oooooooo0:Koool0067oool0
0`0003?o0?l0V@0C<ol000<0003oooooool0Y_ooo`00HOooo`030000<ol0o`2I01<co`000`000?oo
ooooo`2Voooo001Qoooo00<0000co`3o09T04c?o0080002Woooo001Qoooo00<0000co`3o09T04c?o
00030000oooooooo0:Koool006;oool00`000?l0VC?o000B<ol000<0003oooooool0Y_ooo`00H_oo
o`030000o`2I<ol0018co`000`000?ooooooo`2Voooo001Roooo00<0003o09Tco`004S?o0080002W
oooo001Roooo00<0003o09Tco`004S?o00030000oooooooo0:Koool006?oool00ol0VC?o03?o000A
<ol000<0003oooooool0Y_ooo`00Hoooo`03o`2I<ol0<ol0014co`000`000?ooooooo`2Voooo001S
oooo00?o09Tco`0co`004C?o0080002Woooo001Soooo00?o09Tco`0co`004C?o00030000oooooooo
0:Koool006?oool00ol0VC?o03?o0009<ol01@0000<co`000`000?ooooooo`2Voooo001Soooo00?o
09T0000co`002c?o00030000<ol0<ol000<co`000`000?ooooooo`2Voooo001Soooo00?o09T0000c
o`002c?o00030000<ol0<ol000<co`020000Yoooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOoo
o`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo``co`0200001C?o0:Woool006GooolB
<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o00;oool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00IOoooa8co`000oooo`000?ooo`09oooo00<0003oooooool07oooo`030000oooooooo
07Soool006GooolB<ol000?oool0003oool00oooo`800004oooo00<0003oooooool03?ooo`D00002
oooo0P0000Goool300000_ooo`030000oooooooo07Soool006GooolB<ol000?oool0003oool00_oo
o`040000oooooooo00001?ooo`030000oooooooo00Coool400001Oooo`030000oooooooo00[oool0
1@000?ooooooooooo`00001joooo001Uoooo4S?o00030000oooooooo00;oool00`000?ooooooo`0E
oooo00<0003oooooool01oooo`D00003oooo00<0003oooooool0Moooo`00I_oooa4co`001?ooo`00
0?ooooooo`D0000Doooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo
07Soool006KooolA<ol000?oool0003oool00_ooo`030000oooooooo01Goool00`000?ooooooo`08
oooo00<0003oool000000oooo`030000oooooooo07Soool006KooolA<ol00_ooo`030000oooooooo
01Ooool200002oooo`800002oooo00<0003oooooool0NOooo`00I_oooa4co`2Yoooo001Voooo4C?o
0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.33788 .30902 L
.34055 .30902 L
.34309 .30902 L
.34549 .30902 L
.34615 .30902 L
.34685 .30902 L
s
.34685 .30902 m
.34698 .61803 L
s
0 .4 1 r
.02381 .51594 m
.06244 .5122 L
.10458 .50679 L
.14415 .50007 L
.18221 .49168 L
.22272 .48017 L
.26171 .46599 L
.30316 .44687 L
.32392 .43546 L
.33304 .43003 L
.33788 .42703 L
.34055 .42534 L
.34309 .42372 L
.34549 .42216 L
.34615 .42173 L
.34685 .42127 L
.34811 .30902 L
.34935 .30902 L
.35053 .30902 L
.35158 .30902 L
.35271 .30902 L
.3538 .30902 L
.355 .30902 L
.35624 .30902 L
.35741 .30902 L
.3585 .30902 L
.3595 .30902 L
.36064 .30902 L
.36173 .30902 L
.36287 .30902 L
.36412 .30902 L
.36542 .30902 L
.36665 .30902 L
.36779 .30902 L
.36884 .30902 L
.36999 .30902 L
.3712 .30902 L
.37243 .30902 L
.37375 .30902 L
.37499 .30902 L
.37612 .30902 L
.37681 .30902 L
.37745 .30902 L
.37815 .30902 L
.37889 .30902 L
.38013 .30902 L
.38084 .30902 L
.3815 .30902 L
.38275 .30902 L
.38345 .30902 L
Mistroke
.38408 .30902 L
.38532 .30902 L
.38648 .30902 L
.38714 .30902 L
.38784 .30902 L
.38909 .30902 L
.38978 .30902 L
.39043 .30902 L
.39114 .30902 L
.39191 .30902 L
.39318 .30902 L
.3939 .30902 L
.39456 .30902 L
.39576 .30902 L
.39708 .30902 L
.39826 .30902 L
.39936 .30902 L
.40053 .30902 L
.40179 .30902 L
.40295 .30902 L
.40404 .30902 L
.40523 .30902 L
.4065 .30902 L
.41146 .30902 L
.42032 .30902 L
.46187 .30902 L
.50191 .30902 L
.54043 .30902 L
.5814 .30902 L
.62085 .30902 L
.65879 .30902 L
.69918 .30902 L
.73806 .30902 L
.77939 .30902 L
.8192 .30902 L
.8575 .30902 L
.89825 .30902 L
.93748 .30902 L
.9752 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000D0
000co`0co`0co`00I_l013?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool01Oooo`X0000O<ol000<0000co`0co`007S?o000306Ko<ol0<ol000`co`000`000?oo
ooooo`0]oooo00<0003oooooool0;Oooo`030000oooooooo02koool00`000?ooooooo`0Eoooo000X
oooo1P0003Xco`000`1Voc?o03?o000<<ol000<0003oooooool0Y_ooo`00;_ooo`D0000e<ol000<0
I_lco`0co`0033?o0080002Woooo000coooo1000034co`000`1Voc?o03?o000<<ol000<0003ooooo
ool0Y_ooo`00=oooo`80000_<ol000<0I_lco`0co`0033?o00030000oooooooo0:Koool003Woool3
0000;3?o000306Ko<ol0<ol000`co`000`000?ooooooo`2Voooo000loooo0P0002Xco`000`1Voc?o
03?o000<<ol00P000:Ooool003koool20000:3?o000306Ko<ol0<ol000`co`000`000?ooooooo`2V
oooo0010oooo0P0002Hco`000`1Voc?o03?o000<<ol000<0003oooooool0Y_ooo`00@_ooo`80000T
<ol000<0I_lco`0co`0033?o00030000oooooooo0:Koool004Coool200008S?o000306Ko<ol0<ol0
00`co`020000Yoooo`00A_ooo`030000<ol0<ol001lco`000`1Voc?o03?o000<<ol000<0003ooooo
ool0Y_ooo`00Aoooo`030000<ol0<ol001hco`000`1Voc?o03?o000<<ol000<0003oooooool0Y_oo
o`00B?ooo`030000<ol0<ol001dco`000`1Voc?o03?o000<<ol000<0003oooooool0Y_ooo`00BOoo
o`030000<ol0<ol001`co`000`1Voc?o03?o000<<ol00P000:Ooool004[oool00`0003?o03?o000K
<ol000<0I_lco`0co`0033?o00030000oooooooo0:Koool004_oool00`0003?o03?o000@<ol00P00
00@co`0200000S?o000306Ko0000000000800003<ol00P0000Dco`000`000?ooooooo`2Voooo001<
oooo00<0000co`0co`003S?o00040000<ol0<ol000001c?o000306Ko0000<ol000@co`00100003?o
03?o000000@co`000`000?ooooooo`2Voooo001=oooo00<0000co`0co`003C?o00040000<ol0<ol0
00001c?o000306Ko<ol0000000Lco`000`0003?o03?o0002<ol00P000:Ooool004koool00`0003?o
03?o000<<ol000@0000co`0co`000007<ol000@0I_lco`0co`000004<ol00P0000Dco`000`000?oo
ooooo`2Voooo001?oooo00<0000co`0co`002c?o00040000<ol0<ol000001c?o000506Ko0000<ol0
<ol0000000<co`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00Coooo`030000<ol0<ol0
00`co`02000023?o000406Ko<ol00000000013?o00<00004<ol000<0003oooooool0Y_ooo`00D?oo
o`030000<ol0<ol001Dco`000`1Voc?o03?o000<<ol00P000:Ooool0057oool00`0003?o03?o000D
<ol000<0I_lco`0co`0033?o00030000oooooooo0:Koool005;oool00`0003?o03?o000C<ol000<0
I_lco`0co`0033?o00030000oooooooo0:Koool005;oool00`0003?o03?o000C<ol000<0I_lco`0c
o`0033?o00030000oooooooo0:Koool005?oool00`0003?o03?o000B<ol000<0I_lco`0co`0033?o
0080002Woooo001Coooo00<0000co`0co`004C?o0080I_l><ol000<0003oooooool0Y_ooo`00E?oo
o`030000<ol0<ol000lco`0206Ko00?o09Tco`0co`0033?o00030000oooooooo0:Koool005Coool0
0`0003?o03?o000=<ol00P1Vo`8co`000ol0VC?o03?o000<<ol000<0003oooooool0Y_ooo`00EOoo
o`030000<ol0<ol000Xco`0206Ko13?o0003o`2I<ol0<ol000`co`020000Yoooo`00EOooo`030000
<ol0<ol000Pco`0206Ko1S?o0003o`2I<ol0<ol000`co`000`000?ooooooo`2Voooo001Foooo00<0
000co`0co`001C?o0080I_l8<ol000?o09Tco`0co`0033?o00030000oooooooo0:Koool005Koool0
0`0003?o03?o0004<ol000<0I_lco`0co`0023?o0003o`2I<ol0<ol000`co`000`000?ooooooo`2V
oooo001Goooo00@0000co`0co`0co`0206Ko2c?o0003o`2I<ol0<ol000`co`020000Yoooo`00Eooo
o`040000<ol006Ko06Ko3C?o0003o`2I<ol0<ol000`co`000`000?ooooooo`2Voooo001Goooo0P1V
o`/co`0200000S?o0004o`2I<ol00000000013?o00800005<ol000<0003oooooool0Y_ooo`00EOoo
o`80I_l00oooo`0003?o0009<ol000H0000co`0co`00000co`3o09T6<ol000@0000co`0co`000004
<ol000<0003oooooool0Y_ooo`00D_ooo`<0I_l4oooo00<0000co`0co`001c?o00060000<ol0<ol0
0000<ol0o`2I2C?o00030000<ol0<ol0008co`020000Yoooo`00D?ooo`80I_l7oooo00<0000co`0c
o`001c?o00060000<ol0<ol00000<ol0o`2I1c?o00800005<ol000<0003oooooool0Y_ooo`00COoo
o`<0I_l9oooo00<0000co`0co`001c?o00060000<ol0<ol00000<ol0o`2I1c?o00030000<ol0<ol0
00@co`000`000?ooooooo`2Voooo001;oooo0P1Vo`goool00`0003?o03?o0007<ol00P00008co`00
0ol0VC?o03?o0005<ol00`0000@co`000`000?ooooooo`2Voooo0018oooo0`1Vo`ooool00`0003?o
03?o000;<ol000?o09Tco`0co`0033?o0080002Woooo0014oooo101Voa;oool00`0003?o03?o000;
<ol000?o09Tco`0co`0033?o00030000oooooooo0:Koool0043oool406Ko5oooo`030000<ol0<ol0
00Xco`000ol0VC?o03?o000<<ol000<0003oooooool0Y_ooo`00??ooo`@0I_lKoooo00<0000co`0c
o`002S?o0003o`2I<ol0<ol000`co`020000Yoooo`00>?ooo`@0I_lOoooo00<0000co`0co`002S?o
0003o`2I<ol0<ol000`co`000`000?ooooooo`2Voooo000coooo1@1VobCoool00`0003?o03?o0009
<ol000?o09Tco`0co`0033?o00030000oooooooo0:Koool002koool506Ko:Oooo`030000<ol0<ol0
00Tco`000ol0VC?o03?o000<<ol000<0003oooooool0Y_ooo`009_ooo`P0I_l^oooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol000`co`020000Yoooo`007?ooo`X0I_lgoooo00<0000co`0co`0023?o
0003o`2I<ol0<ol000`co`000`000?ooooooo`2Voooo000Foooo1P1Vod7oool00`0003?o03?o0008
<ol000?o09Tco`0co`0033?o00030000oooooooo0:Koool005goool00`0003?o03?o0008<ol000?o
09Tco`0co`0033?o00030000oooooooo0:Koool005koool00`0003?o03?o0007<ol000?o09Tco`0c
o`0033?o0080002Woooo001Noooo00<0000co`0co`001c?o0003o`2I<ol0<ol000`co`000`000?oo
ooooo`2Voooo001Noooo0P0000@co`0200000S?o0004o`2I<ol0<ol0000013?o00800005<ol000<0
003oooooool0Y_ooo`00GOooo`040000oooo000000001c?o0004o`2I<ol0<ol000000c?o00040000
<ol0<ol0000013?o00030000oooooooo0:Koool005goool010000?ooo`00000000Lco`001?l0VC?o
03?o000000Hco`000`0003?o03?o0002<ol00P000:Ooool005goool010000?ooo`00000000Lco`00
1Ol0VC?o03?o03?o00000003<ol00P0000Dco`000`000?ooooooo`2Voooo001Moooo00@0003ooooo
ool00007<ol000Go09T0000co`0co`0000000c?o00030000<ol0<ol000@co`000`000?ooooooo`2V
oooo001Noooo0`0000Lco`000ol0V@000000000200000c?o00<00004<ol000<0003oooooool0Y_oo
o`00H?ooo`030000<ol0<ol000Dco`000ol0VC?o03?o000<<ol00P000:Ooool0063oool00`0003?o
03?o0005<ol000?o09Tco`0co`0033?o00030000oooooooo0:Koool0067oool00`0003?o03?o0004
<ol000?o09Tco`0co`0033?o00030000oooooooo0:Koool0067oool00`0003?o03?o0004<ol000?o
09Tco`0co`0033?o00030000oooooooo0:Koool0067oool00`0003?o03?o0004<ol000?o09Tco`0c
o`0033?o0080002Woooo001Qoooo00<0000co`0co`0013?o0003o`2I<ol0<ol000`co`000`000?oo
ooooo`2Voooo001Roooo00<0000co`0co`000c?o0003o`2I<ol0<ol000`co`000`000?ooooooo`2V
oooo001Roooo00<0000co`0co`000c?o0003o`2I<ol0<ol000`co`000`000?ooooooo`2Voooo001R
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000`co`020000Yoooo`00H_ooo`030000<ol0<ol0
00<co`000ol0VC?o03?o000<<ol000<0003oooooool0Y_ooo`00Hoooo`030000<ol0<ol0008co`00
0ol0VC?o03?o000<<ol000<0003oooooool0Y_ooo`00Hoooo`030000<ol0<ol0008co`000ol0VC?o
03?o000<<ol000<0003oooooool0Y_ooo`00Hoooo`030000<ol0<ol0008co`000ol0VC?o03?o000<
<ol00P000:Ooool006?oool00`0003?o03?o0002<ol000?o09Tco`0co`0033?o00030000oooooooo
0:Koool006?oool00`0003?o03?o0002<ol000?o09Tco`0co`0013?o00D00003<ol000<0003ooooo
ool0Y_ooo`00I?ooo`050000<ol0<ol0<ol0o`2I00Pco`000`0003?o03?o0003<ol000<0003ooooo
ool0Y_ooo`00I?ooo`050000<ol0<ol0<ol0o`2I00Pco`000`0003?o03?o0003<ol00P000:Ooool0
06Coool=<ol000<0000co`0co`000c?o0:Woool006Coool=<ol000<0000co`0co`000c?o0:Woool0
06Coool<<ol00P0000Dco`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`02
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006GooolB<ol000?oool0003oool02Ooo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001Uoooo4S?o0003oooo0000oooo00?oool2
00001?ooo`030000oooooooo00coool500000_ooo`800004oooo0P0000Coool00`000?ooooooo`1h
oooo001Uoooo4S?o0003oooo0000oooo00;oool010000?ooooooo`0000Coool00`000?ooooooo`04
oooo100000Goool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00IOoooa8co`000`000?ooooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Woool0
0`000?ooooooo`03oooo00<0003oooooool0Moooo`00I_oooa4co`001?ooo`000?ooooooo`D0000D
oooo00<0003oooooool02_ooo`050000oooooooooooo000007[oool006KooolA<ol000?oool0003o
ool00_ooo`030000oooooooo01Goool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00I_oooa4co`02oooo00<0003oooooool05oooo`80000:oooo0P0000?oool0
0`000?ooooooo`1ioooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.35271 .30902 L
.36173 .30902 L
.36405 .30902 L
.3652 .30902 L
.36626 .30902 L
s
.36626 .30902 m
.36639 .61803 L
s
0 .4 1 r
.02381 .51511 m
.06244 .51109 L
.10458 .50526 L
.14415 .49801 L
.18221 .48895 L
.22272 .47646 L
.26171 .46099 L
.30316 .43994 L
.32392 .42727 L
.34309 .4141 L
.35271 .40689 L
.36173 .39975 L
.36405 .39784 L
.3652 .39689 L
.36626 .396 L
.36748 .30902 L
.36812 .30902 L
.36881 .30902 L
.37003 .30902 L
.37114 .30902 L
.37179 .30902 L
.37247 .30902 L
.3737 .30902 L
.37502 .30902 L
.37577 .30902 L
.37647 .30902 L
.37774 .30902 L
.3789 .30902 L
.37954 .30902 L
.38023 .30902 L
.3815 .30902 L
.38272 .30902 L
.38383 .30902 L
.38506 .30902 L
.38635 .30902 L
.3874 .30902 L
.38852 .30902 L
.38975 .30902 L
.3909 .30902 L
.39155 .30902 L
.39224 .30902 L
.393 .30902 L
.39369 .30902 L
.39495 .30902 L
.39567 .30902 L
.39633 .30902 L
.39756 .30902 L
.39872 .30902 L
.39935 .30902 L
.40005 .30902 L
Mistroke
.40127 .30902 L
.40196 .30902 L
.4027 .30902 L
.4034 .30902 L
.40404 .30902 L
.40527 .30902 L
.40655 .30902 L
.41217 .30902 L
.42228 .30902 L
.46031 .30902 L
.50078 .30902 L
.53974 .30902 L
.58116 .30902 L
.62105 .30902 L
.65943 .30902 L
.70027 .30902 L
.73959 .30902 L
.77739 .30902 L
.81765 .30902 L
.85639 .30902 L
.89758 .30902 L
.93725 .30902 L
.97541 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000O<ol000<0000co`0co`008c?o000306Ko<ol0<ol000Lco`000`000?ooooooo`0]
oooo00<0003oooooool0;Oooo`030000oooooooo02koool00`000?ooooooo`0Eoooo000Xoooo1P00
03lco`000`1Voc?o03?o0007<ol000<0003oooooool0Y_ooo`00;_ooo`D0000j<ol000<0I_lco`0c
o`001c?o0080002Woooo000coooo100003Hco`000`1Voc?o03?o0007<ol000<0003oooooool0Y_oo
o`00=oooo`80000d<ol000<0I_lco`0co`001c?o00030000oooooooo0:Koool003Woool30000<C?o
000306Ko<ol0<ol000Lco`000`000?ooooooo`2Voooo000loooo0P0002lco`000`1Voc?o03?o0007
<ol00P000:Ooool003koool20000;C?o000306Ko<ol0<ol000Lco`000`000?ooooooo`2Voooo0010
oooo0P0002/co`000`1Voc?o03?o0007<ol000<0003oooooool0Y_ooo`00@_ooo`80000Y<ol000<0
I_lco`0co`001c?o00030000oooooooo0:Koool004Coool200009c?o000306Ko<ol0<ol000Lco`02
0000Yoooo`00A_ooo`030000<ol0<ol002@co`000`1Voc?o03?o0007<ol000<0003oooooool0Y_oo
o`00Aoooo`030000<ol0<ol002<co`000`1Voc?o03?o0007<ol000<0003oooooool0Y_ooo`00B?oo
o`030000<ol0<ol0028co`000`1Voc?o03?o0007<ol000<0003oooooool0Y_ooo`00BOooo`030000
<ol0<ol0024co`000`1Voc?o03?o0007<ol00P000:Ooool004[oool00`0003?o03?o000P<ol000<0
I_lco`0co`001c?o00030000oooooooo0:Koool004_oool00`0003?o03?o000@<ol00P0000@co`02
00000c?o00@000000`1Voc?o03?o000200001C?o00030000oooooooo0:Koool004coool00`0003?o
03?o000><ol000@0000co`0co`000008<ol000L0000co`0co`0co`00I_lco`0000000S?o00030000
<ol0<ol0008co`000`000?ooooooo`2Voooo001=oooo00<0000co`0co`003C?o00040000<ol0<ol0
00002C?o00040000<ol0<ol006Ko13?o00030000<ol0<ol0008co`020000Yoooo`00C_ooo`030000
<ol0<ol000`co`00100003?o03?o000000Xco`000`0003?o001Vo`02<ol00P0000Dco`000`000?oo
ooooo`2Voooo001?oooo00<0000co`0co`002c?o00040000<ol0<ol0000023?o00050000<ol0<ol0
000006Ko008co`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00Coooo`030000<ol0<ol0
00`co`0200002S?o0080000206Ko0S?o00<00004<ol000<0003oooooool0Y_ooo`00D?ooo`030000
<ol0<ol001Pco`000`1Voc?o0?l0V@09<ol00P000:Ooool0057oool00`0003?o03?o000F<ol000@0
I_lco`0co`3o09T9<ol000<0003oooooool0Y_ooo`00D_ooo`030000<ol0<ol001<co`0206Ko0c?o
0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Voooo001Boooo00<0000co`0co`004S?o000306Ko
<ol0<ol000<co`000ol0VC?o03?o0007<ol000<0003oooooool0Y_ooo`00Doooo`030000<ol0<ol0
00lco`0206Ko1S?o0003o`2I<ol0<ol000Lco`020000Yoooo`00Doooo`030000<ol0<ol000dco`02
06Ko23?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Voooo001Doooo00<0000co`0co`002c?o
000306Ko<ol0<ol000Pco`000ol0VC?o03?o0007<ol000<0003oooooool0Y_ooo`00E?ooo`030000
<ol0<ol000Xco`000`1Voc?o03?o0009<ol000?o09Tco`0co`001c?o00030000oooooooo0:Koool0
05Goool00`0003?o03?o0007<ol00P1Vo``co`000ol0VC?o03?o0007<ol00P000:Ooool005Goool0
0`0003?o03?o0006<ol000<0I_lco`0co`0033?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2V
oooo001Foooo00<0000co`0co`0013?o000306Ko<ol0<ol000dco`000ol0VC?o03?o0007<ol000<0
003oooooool0Y_ooo`00E_ooo`030000<ol0<ol0008co`0206Ko43?o0003o`2I<ol0<ol000Lco`00
0`000?ooooooo`2Voooo001Goooo00@0000co`00I_l0I_lB<ol000?o09Tco`0co`001c?o0080002W
oooo001Goooo0P1Voa@co`000ol0VC?o03?o0007<ol000<0003oooooool0Y_ooo`00EOooo`80I_l0
0oooo`0003?o000:<ol00P0000@co`02000000@co`3o09Tco`0co`0200001C?o00030000oooooooo
0:Koool005;oool306Ko0oooo`030000<ol0<ol000Pco`00100003?o03?o000000Hco`000ol0VC?o
00000002<ol000<0000co`0co`000S?o00030000oooooooo0:Koool0053oool206Ko1oooo`030000
<ol0<ol000Lco`00100003?o03?o000000Hco`000ol0VC?o03?o0002<ol000<0000co`0co`000S?o
0080002Woooo001=oooo0`1Vo`Woool00`0003?o03?o0007<ol000@0000co`0co`000006<ol000?o
09Tco`0co`000P0000Dco`000`000?ooooooo`2Voooo001;oooo0P1Vo`coool00`0003?o03?o0007
<ol000@0000co`0co`000006<ol000Co09Tco`0co`000006<ol000<0003oooooool0Y_ooo`00B?oo
o`<0I_l?oooo00<0000co`0co`001c?o00800007<ol000?o09Tco`0co`000`0000@co`000`000?oo
ooooo`2Voooo0014oooo101Voa;oool00`0003?o03?o000@<ol000?o09Tco`0co`001c?o0080002W
oooo0010oooo101VoaKoool00`0003?o03?o000@<ol000?o09Tco`0co`001c?o00030000oooooooo
0:Koool003coool406Ko6oooo`030000<ol0<ol000lco`000ol0VC?o03?o0007<ol000<0003ooooo
ool0Y_ooo`00>?ooo`@0I_lOoooo00<0000co`0co`003c?o0003o`2I<ol0<ol000Lco`020000Yooo
o`00<oooo`D0I_lSoooo00<0000co`0co`003c?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2V
oooo000^oooo1@1VobWoool00`0003?o03?o000><ol000?o09Tco`0co`001c?o00030000oooooooo
0:Koool002Woool506Ko;_ooo`030000<ol0<ol000hco`000ol0VC?o03?o0007<ol000<0003ooooo
ool0Y_ooo`008oooo`H0I_lcoooo00<0000co`0co`003S?o0003o`2I<ol0<ol000Lco`020000Yooo
o`007?ooo`L0I_ljoooo00<0000co`0co`003C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2V
oooo000Foooo1P1Vod7oool00`0003?o03?o000=<ol000?o09Tco`0co`001c?o00030000oooooooo
0:Koool005goool00`0003?o03?o000=<ol000?o09Tco`0co`001c?o00030000oooooooo0:Koool0
05koool00`0003?o03?o000<<ol000?o09Tco`0co`001c?o0080002Woooo001Noooo00<0000co`0c
o`0033?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Voooo001Noooo0P0000@co`0200001C?o
00030000<ol0o`2I008co`0200001C?o00030000oooooooo0:Koool005goool010000?ooo`000000
00Xco`001@0003?o0?l0VC?o00000002<ol000<0000co`0co`000S?o00030000oooooooo0:Koool0
05goool010000?ooo`00000000Xco`000`0003?o0?l0V@04<ol000<0000co`0co`000S?o0080002W
oooo001Moooo00@0003oool00000000;<ol000@0003o09Tco`0co`0200001C?o00030000oooooooo
0:Koool005goool010000?ooooooo`0000Pco`001@0003?o03?o00000?l0V@02<ol000<0000co`0c
o`0013?o00030000oooooooo0:Koool005koool3000023?o00@000000ol0VC?o03?o0003000013?o
00030000oooooooo0:Koool0063oool00`0003?o03?o000:<ol000?o09Tco`0co`001c?o0080002W
oooo001Poooo00<0000co`0co`002S?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Voooo001Q
oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Voooo001Qoooo00<0
000co`0co`002C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`2Voooo001Qoooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol000Lco`020000Yoooo`00HOooo`030000<ol0<ol000Tco`000ol0VC?o
03?o0007<ol000<0003oooooool0Y_ooo`00H_ooo`030000<ol0<ol000Pco`000ol0VC?o03?o0007
<ol000<0003oooooool0Y_ooo`00H_ooo`030000<ol0<ol000Pco`000ol0VC?o03?o0007<ol000<0
003oooooool0Y_ooo`00H_ooo`030000<ol0<ol000Pco`000ol0VC?o03?o0007<ol00P000:Ooool0
06;oool00`0003?o03?o0008<ol000?o09Tco`0co`001c?o00030000oooooooo0:Koool006?oool0
0`0003?o03?o0007<ol000?o09Tco`0co`001c?o00030000oooooooo0:Koool006?oool00`0003?o
03?o0007<ol000?o09Tco`0co`001c?o00030000oooooooo0:Koool006?oool00`0003?o03?o0007
<ol000?o09Tco`0co`001c?o0080002Woooo001Soooo00<0000co`0co`001c?o0003o`2I<ol0<ol0
00Lco`000`000?ooooooo`2Voooo001Soooo00<0000co`0co`001c?o0003o`2I<ol0000000@00003
<ol000<0003oooooool0Y_ooo`00I?ooo`030000<ol0<ol000Hco`001Ol0VC?o03?o03?o00000005
<ol000<0003oooooool0Y_ooo`00I?ooo`030000<ol0<ol000Hco`001Ol0VC?o03?o03?o00000005
<ol00P000:Ooool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool=<ol000<0000co`0c
o`000c?o0:Woool006Coool<<ol00P0000Dco`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol0ZOoo
o`00IOoooa8co`02oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006GooolB<ol000?o
ool0003oool02Oooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001Uoooo4S?o0003oooo
0000oooo00?oool200001?ooo`030000oooooooo00coool500000_ooo`800003oooo100000?oool0
0`000?ooooooo`1hoooo001Uoooo4S?o0003oooo0000oooo00;oool010000?ooooooo`0000Coool0
0`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00<0003oooooool01?ooo`030000
oooooooo07Soool006GooolB<ol000<0003oooooool00_ooo`030000oooooooo01Goool00`000?oo
ooooo`08oooo00<0003oooooool01?ooo`030000oooooooo07Ooool006KooolA<ol000Coool0003o
ooooool500005?ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?oo
o`00I_oooa4co`000oooo`000?ooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001Voooo4C?o00;oool00`000?ooooooo`0G
oooo0P0000[oool200000oooo`030000oooooooo07Woool006KooolA<ol0ZOooo`00I_oooa4co`2Y
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.37685 .30902 L
.3815 .30902 L
.38384 .30902 L
.38448 .30902 L
.38517 .30902 L
s
.38517 .30902 m
.38529 .61803 L
s
0 .4 1 r
.02381 .51401 m
.06244 .50963 L
.10458 .50327 L
.14415 .49534 L
.18221 .48539 L
.22272 .47163 L
.26171 .45448 L
.30316 .43092 L
.34309 .40157 L
.36136 .38535 L
.37176 .37518 L
.37685 .36991 L
.3815 .36492 L
.38384 .36233 L
.38448 .36162 L
.38517 .36085 L
.3864 .30902 L
.38766 .30902 L
.38884 .30902 L
.38991 .30902 L
.39106 .30902 L
.3923 .30902 L
.393 .30902 L
.39366 .30902 L
.39435 .30902 L
.39499 .30902 L
.39572 .30902 L
.39641 .30902 L
.39764 .30902 L
.39877 .30902 L
.40001 .30902 L
.40134 .30902 L
.40263 .30902 L
.40382 .30902 L
.40512 .30902 L
.40578 .30902 L
.40649 .30902 L
.41133 .30902 L
.42237 .30902 L
.46293 .30902 L
.50197 .30902 L
.54347 .30902 L
.58345 .30902 L
.62192 .30902 L
.66284 .30902 L
.70224 .30902 L
.74013 .30902 L
.78047 .30902 L
.81929 .30902 L
.86057 .30902 L
Mistroke
.90033 .30902 L
.93857 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol0008co`000`1Voc?o03?o0002<ol000<0003oooooool01_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo00Goool:00007c?o00030000<ol0<ol002Pco`000`1Voc?o03?o0002
<ol000<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0^oooo00<0003ooooo
ool05Oooo`00:?ooo`H00014<ol000<0I_lco`0co`000S?o00030000oooooooo0:Koool002koool5
0000?c?o000306Ko<ol0<ol0008co`020000Yoooo`00<oooo`@0000k<ol000<0I_lco`0co`000S?o
00030000oooooooo0:Koool003Ooool20000>C?o000306Ko<ol0<ol0008co`000`000?ooooooo`2V
oooo000ioooo0`0003Hco`000`1Voc?o03?o0002<ol000<0003oooooool0Y_ooo`00??ooo`80000d
<ol000<0I_lco`0co`000S?o0080002Woooo000noooo0P00038co`000`1Voc?o03?o0002<ol000<0
003oooooool0Y_ooo`00@?ooo`80000`<ol000<0I_lco`0co`000S?o00030000oooooooo0:Koool0
04;oool20000;S?o000306Ko<ol0<ol0008co`000`000?ooooooo`2Voooo0014oooo0P0002`co`00
0`1Voc?o03?o0002<ol00P000:Ooool004Koool00`0003?o03?o000Y<ol000<0I_lco`0co`000S?o
00030000oooooooo0:Koool004Ooool00`0003?o03?o000X<ol000<0I_lco`0co`000S?o00030000
oooooooo0:Koool004Soool00`0003?o03?o000V<ol000<0I_oo09Tco`000c?o00030000oooooooo
0:Koool004Woool00`0003?o03?o000T<ol000<0I_lco`3o09T013?o0080002Woooo001:oooo00<0
000co`0co`008C?o0080I_l2<ol000?o09Tco`0co`000S?o00030000oooooooo0:Koool004_oool0
0`0003?o03?o000@<ol00P0000@co`0200000c?o00@000000`1Voc?o03?o0002000000?o09Tco`0c
o`000S?o00030000oooooooo0:Koool004coool00`0003?o03?o000><ol000@0000co`0co`000008
<ol000L0000co`0co`0co`00I_lco`0000000S?o00030000<ol0<ol0008co`000`000?ooooooo`2V
oooo001=oooo00<0000co`0co`003C?o00040000<ol0<ol000002C?o00030000<ol006Ko00Dco`00
0`0003?o03?o0002<ol00P000:Ooool004koool00`0003?o03?o000<<ol000@0000co`0co`00000:
<ol000<0000co`0co`000S?o008000000ol0VC?o03?o0002<ol000<0003oooooool0Y_ooo`00Cooo
o`030000<ol0<ol000/co`00100003?o03?o000000Pco`001000001Voc?o000000<co`000`0003?o
0?l0V@04<ol000<0003oooooool0Y_ooo`00Coooo`030000<ol0<ol000`co`02000023?o000406Ko
<ol00000000013?o00<00004<ol000<0003oooooool0Y_ooo`00D?ooo`030000<ol0<ol001@co`00
0`1Voc?o03?o0008<ol000?o09Tco`0co`000S?o0080002Woooo001Aoooo00<0000co`0co`004C?o
0080I_l;<ol000?o09Tco`0co`000S?o00030000oooooooo0:Koool005;oool00`0003?o03?o000?
<ol000<0I_lco`0co`002c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Voooo001Boooo00<0
000co`0co`003S?o000306Ko<ol0<ol000`co`000ol0VC?o03?o0002<ol000<0003oooooool0Y_oo
o`00Doooo`030000<ol0<ol000/co`0206Ko3c?o0003o`2I<ol0<ol0008co`020000Yoooo`00Dooo
o`030000<ol0<ol000Xco`000`1Voc?o03?o000?<ol000?o09Tco`0co`000S?o00030000oooooooo
0:Koool005Coool00`0003?o03?o0007<ol00P1Voa8co`000ol0VC?o03?o0002<ol000<0003ooooo
ool0Y_ooo`00E?ooo`030000<ol0<ol000Hco`000`1Voc?o03?o000B<ol000?o09Tco`0co`000S?o
00030000oooooooo0:Koool005Goool00`0003?o03?o0003<ol00P1VoaDco`000ol0VC?o03?o0002
<ol00P000:Ooool005Goool0100003?o03?o03?o0080I_lG<ol000?o09Tco`0co`000S?o00030000
oooooooo0:Koool005Koool00`0003?o001Vo`0I<ol000?o09Tco`0co`000S?o00030000oooooooo
0:Koool005Koool206Ko6S?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Voooo001Doooo0P1V
o`03oooo0000<ol001Tco`000ol0VC?o03?o0002<ol00P000:Ooool005?oool01@1Voooooooooooo
o`00000J<ol000?o09Tco`0co`000S?o00030000oooooooo0:Koool0057oool206Ko1Oooo`030000
<ol0<ol000Tco`02000013?o00800004<ol00P000003o`2I<ol0<ol0008co`000`000?ooooooo`2V
oooo001?oooo0P1Vo`Ooool00`0003?o03?o0008<ol000@0000co`0co`000008<ol000@0000co`0c
o`000004<ol000<0003oooooool0Y_ooo`00COooo`80I_l:oooo00<0000co`0co`001c?o00040000
<ol0<ol000002c?o00030000<ol0<ol0008co`020000Yoooo`00Boooo`80I_l<oooo00<0000co`0c
o`001c?o00040000<ol0<ol000002C?o008000000ol0VC?o03?o0002<ol000<0003oooooool0Y_oo
o`00B?ooo`<0I_l>oooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o00030000<ol0o`2I
00@co`000`000?ooooooo`2Voooo0014oooo101Voa;oool00`0003?o03?o0007<ol00P0000Xco`03
000013?o00030000oooooooo0:Koool0043oool406Ko5_ooo`030000<ol0<ol001Dco`000ol0VC?o
03?o0002<ol00P000:Ooool003goool306Ko6_ooo`030000<ol0<ol001Dco`000ol0VC?o03?o0002
<ol000<0003oooooool0Y_ooo`00>_ooo`<0I_lNoooo00<0000co`0co`0053?o0003o`2I<ol0<ol0
008co`000`000?ooooooo`2Voooo000goooo0`1Vob7oool00`0003?o03?o000D<ol000?o09Tco`0c
o`000S?o0080002Woooo000coooo101VobCoool00`0003?o03?o000D<ol000?o09Tco`0co`000S?o
00030000oooooooo0:Koool002koool506Ko:Oooo`030000<ol0<ol001<co`000ol0VC?o03?o0002
<ol000<0003oooooool0Y_ooo`009_ooo`P0I_l^oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0
008co`000`000?ooooooo`2Voooo000Loooo2P1VocKoool00`0003?o03?o000C<ol000?o09Tco`0c
o`000S?o0080002Woooo000Foooo1P1Vod7oool00`0003?o03?o000B<ol000?o09Tco`0co`000S?o
00030000oooooooo0:Koool005goool00`0003?o03?o000B<ol000?o09Tco`0co`000S?o00030000
oooooooo0:Koool005goool00`0003?o03?o000B<ol000?o09Tco`0co`000S?o00030000oooooooo
0:Koool005koool00`0003?o03?o000A<ol000?o09Tco`0co`000S?o0080002Woooo001Noooo00<0
000co`0co`004C?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Voooo001Noooo0P0000@co`02
00001C?o00030000<ol0<ol0008co`02000000?o09Tco`0co`000S?o00030000oooooooo0:Koool0
05goool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o
00030000oooooooo0:Koool005goool010000?ooo`00000000Xco`000`0003?o03?o0004<ol000<0
000co`0co`000S?o0080002Woooo001Moooo00@0003oool00000000;<ol000@0000co`0co`0co`02
000000?o09Tco`0co`000S?o00030000oooooooo0:Koool005goool010000?ooooooo`0000Pco`00
100003?o03?o000000<co`000`0003?o0?l0V@04<ol000<0003oooooool0Y_ooo`00G_ooo`<00008
<ol0100000<co`03000013?o00030000oooooooo0:Koool0063oool00`0003?o03?o000?<ol000?o
09Tco`0co`000S?o0080002Woooo001Poooo00<0000co`0co`003c?o0003o`2I<ol0<ol0008co`00
0`000?ooooooo`2Voooo001Qoooo00<0000co`0co`003S?o0003o`2I<ol0<ol0008co`000`000?oo
ooooo`2Voooo001Qoooo00<0000co`0co`003S?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2V
oooo001Qoooo00<0000co`0co`003S?o0003o`2I<ol0<ol0008co`020000Yoooo`00HOooo`030000
<ol0<ol000hco`000ol0VC?o03?o0002<ol000<0003oooooool0Y_ooo`00H_ooo`030000<ol0<ol0
00dco`000ol0VC?o03?o0002<ol000<0003oooooool0Y_ooo`00H_ooo`030000<ol0<ol000dco`00
0ol0VC?o03?o0002<ol000<0003oooooool0Y_ooo`00H_ooo`030000<ol0<ol000dco`000ol0VC?o
03?o0002<ol00P000:Ooool006;oool00`0003?o03?o000=<ol000?o09Tco`0co`000S?o00030000
oooooooo0:Koool006?oool00`0003?o03?o000<<ol000?o09Tco`0co`000S?o00030000oooooooo
0:Koool006?oool00`0003?o03?o000<<ol000?o09Tco`0co`000S?o00030000oooooooo0:Koool0
06?oool00`0003?o03?o000<<ol000?o09Tco`0co`000S?o0080002Woooo001Soooo00<0000co`0c
o`0033?o0003o`2I<ol0<ol0008co`000`000?ooooooo`2Voooo001Soooo00<0000co`0co`002C?o
00D00003<ol000<0003oooooool0Y_ooo`00I?ooo`030000<ol0<ol000Xco`000`000?l0VC?o0003
<ol000<0003oooooool0Y_ooo`00I?ooo`030000<ol0<ol000Xco`000`000?l0VC?o0003<ol00P00
0:Ooool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool=<ol000<0000co`0co`000c?o
0:Woool006Coool<<ol00P0000Dco`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol0ZOooo`00IOoo
oa8co`02oooo00<0003oooooool0:?ooo`030000oooooooo07Woool006GooolB<ol000?oool0003o
ool02Oooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001Uoooo4S?o0003oooo0000oooo
00?oool200001?ooo`030000oooooooo00coool500000_ooo`800003oooo1@0000;oool00`000?oo
ooooo`1hoooo001Uoooo4S?o0003oooo0000oooo00;oool010000?ooooooo`0000Coool00`000?oo
ooooo`04oooo100000Goool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo
07Soool006GooolB<ol000<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`09
oooo00<0003oooooool00oooo`030000oooooooo07Ooool006KooolA<ol000Coool0003oooooool5
00005?ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00I_oo
oa4co`000oooo`000?ooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Woool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00I_oooa4co`02oooo00<0003oooooool05oooo`80000:
oooo0P0000?oool00`000?ooooooo`1ioooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.39174 .30902 L
.39675 .30902 L
.40134 .30902 L
.40252 .30902 L
.40381 .30902 L
s
.40381 .30902 m
.40393 .61803 L
s
0 .4 1 r
.02381 .51265 m
.06244 .50781 L
.10458 .50078 L
.14415 .49199 L
.18221 .48094 L
.22272 .46558 L
.26171 .44632 L
.30316 .41962 L
.34309 .38586 L
.3815 .34277 L
.39087 .33006 L
.40095 .31509 L
.40236 .31286 L
.40311 .31167 L
.40391 .3104 L
.40467 .30916 L
.40537 .30902 L
.40606 .30902 L
.40672 .30902 L
.41201 .30902 L
.42237 .30902 L
.46172 .30902 L
.50027 .30902 L
.54127 .30902 L
.58076 .30902 L
.61873 .30902 L
.65915 .30902 L
.69806 .30902 L
.73942 .30902 L
.77927 .30902 L
.8176 .30902 L
.85838 .30902 L
.89765 .30902 L
.9354 .30902 L
.9756 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Hco`000`1Vo`000?ooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000O<ol000<0000co`0co`00;3?o000306Ko0000oooo02koool00`000?ooooooo`0]
oooo00<0003oooooool0;_ooo`030000oooooooo01Goool002Soool60000Ac?o000306Ko<ol00000
0:Soool002koool50000@C?o000306Ko<ol0<ol00080002Woooo000coooo100003dco`00101Voc?o
03?o00000:Soool003Ooool20000>S?o000506Ko<ol0<ol0<ol000000:Soool003Woool30000=S?o
000306Ko<ol0<ol0008co`000`000?ooooooo`2Voooo000loooo0P0003@co`000`1Voc?o03?o0002
<ol00P000:Ooool003koool20000<C?o000306Ko<ol0<ol000<co`000`000?ooooooo`2Voooo0010
oooo0P0002hco`000`1Voc?o03?o0004<ol000<0003oooooool0Y_ooo`00@_ooo`80000[<ol000<0
I_lco`0co`001C?o00030000oooooooo0:Koool004Coool20000:3?o000306Ko<ol0<ol000Hco`02
0000Yoooo`00A_ooo`030000<ol0<ol002@co`000`1Voc?o03?o0007<ol000<0003oooooool0Y_oo
o`00Aoooo`030000<ol0<ol0028co`000`1Voc?o03?o0008<ol000<0003oooooool0Y_ooo`00B?oo
o`030000<ol0<ol0024co`000`1Voc?o03?o0008<ol000<0003oooooool0Y_ooo`00BOooo`030000
<ol0<ol001lco`000`1Voc?o03?o0009<ol00P000:Ooool004[oool00`0003?o03?o000M<ol000<0
I_lco`0co`002S?o00030000oooooooo0:Koool004_oool00`0003?o03?o000@<ol00P0000@co`02
00000c?o00@00003<ol00P0000Dco`000`000?ooooooo`2Voooo001<oooo00<0000co`0co`003S?o
00040000<ol0<ol000001c?o000306Ko0000<ol000@co`00100003?o03?o000000@co`000`000?oo
ooooo`2Voooo001=oooo00<0000co`0co`003C?o00040000<ol0<ol000001S?o000406Ko<ol0<ol0
00001c?o00030000<ol0<ol0008co`020000Yoooo`00C_ooo`030000<ol0<ol000`co`00100003?o
03?o000000Dco`000`1Voc?o03?o0002<ol000<0000co`0co`000S?o00800005<ol000<0003ooooo
ool0Y_ooo`00Coooo`030000<ol0<ol000/co`00100003?o03?o000000<co`0206Ko0c?o00040000
<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?ooooooo`2Voooo001?oooo00<0000co`0c
o`0033?o00800003<ol000<0I_lco`0co`0013?o00800004<ol00`0000@co`000`000?ooooooo`2V
oooo001@oooo00<0000co`0co`003c?o000306Ko<ol0<ol0018co`020000Yoooo`00DOooo`030000
<ol0<ol000dco`000`1Voc?o03?o000C<ol000<0003oooooool0Y_ooo`00D_ooo`030000<ol0<ol0
00Xco`0206Ko5S?o00030000oooooooo0:Koool005;oool00`0003?o03?o0009<ol000<0I_lco`0c
o`005S?o00030000oooooooo0:Koool005?oool00`0003?o03?o0007<ol000<0I_lco`0co`005c?o
0080002Woooo001Coooo00<0000co`0co`001C?o0080I_lJ<ol000<0003oooooool0Y_ooo`00E?oo
o`030000<ol0<ol000<co`000`1Voc?o03?o000J<ol000<0003oooooool0Y_ooo`00E?ooo`030000
<ol0<ol0008co`000`1Voc?o03?o000K<ol000<0003oooooool0Y_ooo`00EOooo`040000<ol006Ko
06Ko7S?o0080002Woooo001Eoooo00<00000I_lco`007c?o00030000oooooooo0:Koool005Coool2
06Ko00<0000co`0co`007S?o00030000oooooooo0:Koool005?oool0101Vooooooooo`00020co`00
0`000?ooooooo`2Voooo001Aoooo0P1Vo`Coool00`0003?o03?o000M<ol00P000:Ooool004ooool2
06Ko1_ooo`030000<ol0<ol001dco`000`000?ooooooo`2Voooo001=oooo0P1Vo`Woool00`0003?o
03?o0009<ol00P0000@co`02000013?o00800005<ol000<0003oooooool0Y_ooo`00Boooo`80I_l;
oooo00<0000co`0co`0023?o00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000
oooooooo0:Koool004Soool306Ko3_ooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`00
0`0003?o03?o0002<ol00P000:Ooool004Goool306Ko4Oooo`030000<ol0<ol000Lco`00100003?o
03?o000000Tco`0200001C?o00030000oooooooo0:Koool004?oool206Ko5?ooo`030000<ol0<ol0
00Lco`00100003?o03?o000000Tco`000`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00@?oo
o`<0I_lGoooo00<0000co`0co`001c?o0080000:<ol00`0000@co`000`000?ooooooo`2Voooo000m
oooo0`1Voa[oool00`0003?o03?o000J<ol00P000:Ooool003[oool306Ko7Oooo`030000<ol0<ol0
01Xco`000`000?ooooooo`2Voooo000goooo0`1Vob7oool00`0003?o03?o000I<ol000<0003ooooo
ool0Y_ooo`00<oooo`@0I_lToooo00<0000co`0co`006C?o0080002Woooo000^oooo1@1VobSoool0
0`0003?o03?o000I<ol000<0003oooooool0Y_ooo`00:Oooo`D0I_l^oooo00<0000co`0co`0063?o
00030000oooooooo0:Koool002?oool606Ko<oooo`030000<ol0<ol001Pco`000`000?ooooooo`2V
oooo000Loooo1`1VocWoool00`0003?o03?o000H<ol00P000:Ooool001Koool606Ko@Oooo`030000
<ol0<ol001Lco`000`000?ooooooo`2Voooo001Moooo00<0000co`0co`005c?o00030000oooooooo
0:Koool005goool00`0003?o03?o000G<ol000<0003oooooool0Y_ooo`00G_ooo`030000<ol0<ol0
01Hco`020000Yoooo`00G_ooo`030000<ol0<ol001Hco`000`000?ooooooo`2Voooo001Noooo0P00
00@co`0200001C?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo0:Koool005goool0
10000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000
oooooooo0:Koool005goool010000?ooo`00000000Xco`000`0003?o03?o0004<ol000<0000co`0c
o`000S?o0080002Woooo001Moooo00@0003oool00000000;<ol000@0000co`0co`0co`0200001C?o
00030000oooooooo0:Koool005goool010000?ooooooo`0000Pco`00100003?o03?o000000<co`00
0`0003?o03?o0004<ol000<0003oooooool0Y_ooo`00G_ooo`<00008<ol0100000<co`03000013?o
00030000oooooooo0:Koool0063oool00`0003?o03?o000D<ol00P000:Ooool0063oool00`0003?o
03?o000D<ol000<0003oooooool0Y_ooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`2V
oooo001Qoooo00<0000co`0co`004c?o00030000oooooooo0:Koool0067oool00`0003?o03?o000C
<ol00P000:Ooool0067oool00`0003?o03?o000C<ol000<0003oooooool0Y_ooo`00H_ooo`030000
<ol0<ol0018co`000`000?ooooooo`2Voooo001Roooo00<0000co`0co`004S?o00030000oooooooo
0:Koool006;oool00`0003?o03?o000B<ol00P000:Ooool006;oool00`0003?o03?o000B<ol000<0
003oooooool0Y_ooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`2Voooo001Soooo00<0
000co`0co`004C?o00030000oooooooo0:Koool006?oool00`0003?o03?o000A<ol00P000:Ooool0
06?oool00`0003?o03?o000A<ol000<0003oooooool0Y_ooo`00Hoooo`030000<ol0<ol000Tco`05
00000c?o00030000oooooooo0:Koool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o
00030000oooooooo0:Koool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o0080002W
oooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Y
oooo001Toooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB
<ol01Oooo`030000oooooooo02;oool00`000?ooooooo`1loooo001Uoooo4S?o00Coool00`000?oo
ooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool006GooolB<ol01?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800004oooo00<0003ooooo
ool0Noooo`00IOoooa8co`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000Goool00`000?ooooooo`08oooo00<0003oooooool0Noooo`00IOoo
oa8co`03oooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`09oooo00<0
003oooooool0N_ooo`00I_oooa4co`04oooo00<0003oooooool01@0001Coool00`000?ooooooo`08
oooo00<0003oooooool0Noooo`00I_oooa4co`04oooo00D0003oooooooooool000005oooo`030000
oooooooo00Soool00`000?ooooooo`1koooo001Voooo4C?o00Goool00`000?ooooooo`0Goooo0P00
00Woool00`000?ooooooo`1loooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.41696 .30902 L
.41976 .30902 L
.42113 .30902 L
.42237 .30902 L
.42363 .30902 L
s
.42363 .30902 m
.42375 .61803 L
s
0 .4 1 r
.02381 .48216 m
.03279 .49411 L
.03793 .50133 L
.04018 .50457 L
.04136 .5063 L
.04262 .50815 L
.04325 .50845 L
.04394 .50835 L
.04517 .50818 L
.04758 .50784 L
.05288 .50706 L
.06244 .50558 L
.10458 .49773 L
.14487 .48769 L
.18364 .47496 L
.22486 .45712 L
.26457 .4345 L
.30277 .40614 L
.34341 .3663 L
.36221 .34334 L
.37209 .32977 L
.3775 .32184 L
.38254 .31409 L
.38386 .312 L
.38511 .31 L
.3858 .30902 L
.38654 .30902 L
.38786 .30902 L
.38856 .30902 L
.38933 .30902 L
.39013 .30902 L
.39089 .30902 L
.39159 .30902 L
.39224 .30902 L
.39295 .30902 L
.39369 .30902 L
.39492 .30902 L
.39623 .30902 L
.39747 .30902 L
.39859 .30902 L
.39928 .30902 L
.39991 .30902 L
.40061 .30902 L
.40135 .30902 L
.40259 .30902 L
.40329 .30902 L
.40395 .30902 L
.4052 .30902 L
.4059 .30902 L
.40656 .30902 L
Mistroke
.40903 .30902 L
.41368 .30902 L
.42412 .30902 L
.4633 .30902 L
.50494 .30902 L
.54506 .30902 L
.58366 .30902 L
.62472 .30902 L
.66426 .30902 L
.70228 .30902 L
.74276 .30902 L
.78172 .30902 L
.82313 .30902 L
.86303 .30902 L
.90141 .30902 L
.94224 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol0008co`000`1Voc?o03?o0002<ol000<0003oooooool00_oo
o`05o`2Ioooooooooooo000000Woool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo00Goool:00007c?o00030000<ol0<ol002Lco`000`1Voc?o
03?o0003<ol000<0003oooooool00_ooo`03o`2Ioooooooo02Soool00`000?ooooooo`0]oooo00<0
003oooooool0;_ooo`030000oooooooo01Goool002Soool60000@S?o000306Ko<ol0<ol000@co`00
0`000?ooooooo`02oooo00?o09Woooooool0XOooo`00;_ooo`D0000m<ol000<0I_lco`0co`0013?o
00800003oooo00?o09Woooooool0XOooo`00<oooo`@0000h<ol000<0I_lco`0co`001C?o00030000
oooooooo00;oool00ol0VOooooooo`2Qoooo000goooo0P0003Hco`000`1Voc?o03?o0005<ol000<0
003oooooool00_ooo`03o`2Ioooooooo0:7oool003Woool30000<S?o000306Ko<ol0<ol000Hco`00
0`000?ooooooo`02oooo00?o09Woooooool0XOooo`00??ooo`80000_<ol000<0I_lco`0co`001c?o
00800003oooo00?o09Woooooool0XOooo`00?_ooo`80000/<ol000<0I_lco`0co`0023?o00030000
oooooooo00;oool00ol0VOooooooo`2Qoooo0010oooo0P0002Tco`000`1Voc?o03?o0009<ol000<0
003oooooool00_ooo`03o`2Ioooooooo0:7oool004;oool200009S?o000306Ko<ol0<ol000Xco`00
0`000?ooooooo`02oooo00?o09Woooooool0XOooo`00A?ooo`80000S<ol000<0I_lco`0co`002c?o
00800003oooo00?o09Woooooool0XOooo`00A_ooo`030000<ol0<ol0020co`000`1Voc?o03?o000;
<ol000<0003oooooool00_ooo`03o`2Ioooooooo0:7oool004Ooool00`0003?o03?o000N<ol000<0
I_lco`0co`0033?o00030000oooooooo00;oool00ol0VOooooooo`2Qoooo0018oooo00<0000co`0c
o`0073?o000306Ko<ol0<ol000dco`000`000?ooooooo`02oooo00?o09Woooooool0XOooo`00BOoo
o`030000<ol0<ol001Xco`000`1Voc?o03?o000><ol00P0000?oool00ol0VOooooooo`2Qoooo001:
oooo00<0000co`0co`0063?o000306Ko<ol0<ol000lco`000`000?ooooooo`02oooo00?o09Wooooo
ool0XOooo`00Boooo`030000<ol0<ol0010co`02000013?o00800003<ol0100000<co`0200001C?o
00030000oooooooo00;oool00ol0VOooooooo`2Qoooo001<oooo00<0000co`0co`003S?o00040000
<ol0<ol000000S?o000306Ko<ol0<ol000<co`000`0003?o03?o0003<ol000@0000co`0co`000004
<ol000<0003oooooool00_ooo`03o`2Ioooooooo0:7oool004goool00`0003?o03?o000=<ol000H0
000co`0co`00000co`00I_l7<ol000<0000co`0co`001C?o00030000<ol0<ol0008co`0200000ooo
o`03o`2Ioooooooo0:7oool004koool00`0003?o03?o000<<ol000D0000co`0co`000000I_l02C?o
00030000<ol0<ol0008co`0200001C?o00030000oooooooo00;oool00ol0VOooooooo`2Qoooo001?
oooo00<0000co`0co`002c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0<ol000@co`000`000?ooooooo`02oooo00?o09Woooooool0XOooo`00Coooo`030000<ol0<ol0
00`co`0200002S?o00800004<ol00`0000@co`000`000?ooooooo`02oooo00?o09Woooooool0XOoo
o`00D?ooo`030000<ol0<ol000/co`000`1Voc?o03?o000F<ol00P0000?oool00ol0VOooooooo`2Q
oooo001Aoooo00<0000co`0co`002C?o000306Ko<ol0<ol001Lco`000`000?ooooooo`02oooo00?o
09Woooooool0XOooo`00D_ooo`030000<ol0<ol000Hco`0206Ko6S?o00030000oooooooo00;oool0
0ol0VOooooooo`2Qoooo001Boooo00<0000co`0co`001C?o000306Ko<ol0<ol001Xco`000`000?oo
ooooo`02oooo00?o09Woooooool0XOooo`00Doooo`030000<ol0<ol000<co`000`1Voc?o03?o000K
<ol00P0000?oool00ol0VOooooooo`2Qoooo001Coooo00@0000co`0co`0co`0206Ko7S?o00030000
oooooooo00;oool00ol0VOooooooo`2Qoooo001Doooo00<0000co`00I_l083?o00030000oooooooo
00;oool00ol0VOooooooo`2Qoooo001Doooo0P1Vob4co`000`000?ooooooo`02oooo00?o09Wooooo
ool0XOooo`00Doooo`0306Kooooo0000024co`0200000oooo`03o`2Ioooooooo0:7oool0057oool2
06Ko0_ooo`030000<ol0<ol001lco`000`000?ooooooo`02oooo00?o09Woooooool0XOooo`00Cooo
o`80I_l5oooo00<0000co`0co`007S?o00030000oooooooo00;oool00ol0VOooooooo`2Qoooo001>
oooo00<0I_ooooooool01Oooo`030000<ol0<ol001hco`000`000?ooooooo`02oooo00?o09Wooooo
ool0XOooo`00C?ooo`80I_l9oooo00<0000co`0co`007C?o00800003oooo00?o09Woooooool0XOoo
o`00B_ooo`80I_l;oooo00<0000co`0co`007C?o00030000oooooooo00;oool00ol0VOooooooo`2Q
oooo0018oooo0P1Vo`koool00`0003?o03?o0009<ol00P0000@co`02000013?o00800005<ol000<0
003oooooool00_ooo`03o`2Ioooooooo0:7oool004Koool206Ko4?ooo`030000<ol0<ol000Pco`00
100003?o03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`02oooo00?o09Wooooo
ool0XOooo`00@oooo`<0I_lCoooo00<0000co`0co`001c?o00040000<ol0<ol000002c?o00030000
<ol0<ol0008co`0200000oooo`03o`2Ioooooooo0:7oool0047oool206Ko5_ooo`030000<ol0<ol0
00Lco`00100003?o03?o000000Tco`0200001C?o00030000oooooooo00;oool00ol0VOooooooo`2Q
oooo000noooo0`1VoaSoool00`0003?o03?o0007<ol000@0000co`0co`000009<ol000<0000co`0c
o`0013?o00030000oooooooo00;oool00ol0VOooooooo`2Qoooo000loooo0P1Voacoool00`0003?o
03?o0007<ol00P0000Xco`03000013?o00030000oooooooo00;oool00ol0VOooooooo`2Qoooo000F
oooo00<0I_ooooooool08?ooo`<0I_lNoooo00<0000co`0co`006S?o00800003oooo00?o09Wooooo
ool0XOooo`005oooo`0306Kooooooooo01goool206Ko8Oooo`030000<ol0<ol001Xco`000`000?oo
ooooo`02oooo00?o09Woooooool0XOooo`006?ooo`0306Kooooooooo01Soool406Ko9?ooo`030000
<ol0<ol001Tco`000`000?ooooooo`02oooo00?o09Woooooool0XOooo`006Oooo`0306Kooooooooo
01;oool506Ko:?ooo`030000<ol0<ol001Tco`0200000oooo`03o`2Ioooooooo0:7oool001Woool0
0`1Vooooooooo`0=oooo1@1Vobgoool00`0003?o03?o000I<ol000<0003oooooool00_ooo`03o`2I
oooooooo0:7oool001[oool00`1Vooooooooo`06oooo1P1Voc?oool00`0003?o03?o000H<ol000<0
003oooooool00_ooo`03o`2Ioooooooo0:7oool001[oool206Ko1?ooo`<0I_lioooo00<0000co`0c
o`0063?o00030000oooooooo00;oool00ol0VOooooooo`2Qoooo000Koooo1@1Voccoool00`0003?o
03?o000H<ol00P0000?oool00ol0VOooooooo`2Qoooo001Moooo00<0000co`0co`005c?o00030000
oooooooo00;oool00ol0VOooooooo`2Qoooo001Moooo00<0000co`0co`005c?o00030000oooooooo
00;oool00ol0VOooooooo`2Qoooo001Moooo00<0000co`0co`005c?o00030000oooooooo00;oool0
0ol0VOooooooo`2Qoooo001Noooo00<0000co`0co`005S?o00800003oooo00?o09Woooooool0XOoo
o`00G_ooo`030000<ol0<ol001Hco`000`000?ooooooo`02oooo00?o09Woooooool0XOooo`00G_oo
o`800004<ol00P0000Dco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`02oooo00?o
09Woooooool0XOooo`00GOooo`040000oooo000000002S?o00050000<ol0<ol0<ol00000008co`00
0`0003?o03?o0002<ol000<0003oooooool00_ooo`03o`2Ioooooooo0:7oool005goool010000?oo
o`00000000Xco`000`0003?o03?o0004<ol000<0000co`0co`000S?o00800003oooo00?o09Wooooo
ool0XOooo`00GOooo`040000oooo000000002c?o00040000<ol0<ol0<ol00P0000Dco`000`000?oo
ooooo`02oooo00?o09Woooooool0XOooo`00GOooo`040000oooooooo000023?o00040000<ol0<ol0
00000c?o00030000<ol0<ol000@co`000`000?ooooooo`02oooo00?o09Woooooool0XOooo`00G_oo
o`<00008<ol0100000<co`03000013?o00030000oooooooo00;oool00ol0VOooooooo`2Qoooo001P
oooo00<0000co`0co`0053?o00800003oooo00?o09Woooooool0XOooo`00H?ooo`030000<ol0<ol0
01@co`000`000?ooooooo`02oooo00?o09Woooooool0XOooo`00HOooo`030000<ol0<ol001<co`00
0`000?ooooooo`02oooo00?o09Woooooool0XOooo`00HOooo`030000<ol0<ol001<co`000`000?oo
ooooo`02oooo00?o09Woooooool0XOooo`00HOooo`030000<ol0<ol001<co`0200000oooo`03o`2I
oooooooo0:7oool0067oool00`0003?o03?o000C<ol000<0003oooooool00_ooo`03o`2Ioooooooo
0:7oool006;oool00`0003?o03?o000B<ol000<0003oooooool00_ooo`03o`2Ioooooooo0:7oool0
06;oool00`0003?o03?o000B<ol000<0003oooooool00_ooo`03o`2Ioooooooo0:7oool006;oool0
0`0003?o03?o000B<ol00P0000?oool00ol0VOooooooo`2Qoooo001Roooo00<0000co`0co`004S?o
00030000oooooooo00;oool00ol0VOooooooo`2Qoooo001Soooo00<0000co`0co`004C?o00030000
oooooooo00;oool00ol0VOooooooo`2Qoooo001Soooo00<0000co`0co`004C?o00030000oooooooo
00;oool00ol0VOooooooo`2Qoooo001Soooo00<0000co`0co`004C?o00800003oooo00?o09Wooooo
ool0XOooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`02oooo00?o09Woooooool0XOoo
o`00Hoooo`030000<ol0<ol000Tco`0500000c?o00030000oooooooo00;oool00ol0VOooooooo`2Q
oooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol000<co`000`000?ooooooo`02oooo00?o
09Woooooool0XOooo`00I?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol00P0000?oool0
0ol0VOooooooo`2Qoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000
<ol0<ol000<co`2Yoooo001Toooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o
0:Woool006GooolB<ol00_ooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Uoooo4S?o
0003oooo0000oooo00Woool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00IOoooa8co`00
0oooo`000?ooo`03oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`<00004
oooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`02oooo00@0003oooooool00004
oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`030000oooooooo07Soool006GooolB<ol000<0003oooooool00_ooo`030000oooooooo01?oool0
10000?ooooooo`0000Woool300001?ooo`030000oooooooo07Ooool006KooolA<ol000Coool0003o
ooooool500004_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
07Soool006KooolA<ol000?oool0003oool00_ooo`030000oooooooo01?oool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001Voooo4C?o00;oool00`000?oo
ooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo07Woool006KooolA<ol0ZOooo`00I_oo
oa4co`2Yoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44021 .30902 L
.44151 .30902 L
.44268 .30902 L
s
.44268 .30902 m
.4428 .61803 L
s
0 .4 1 r
.02381 .45515 m
.04262 .47708 L
.0522 .48949 L
.05746 .4967 L
.06005 .50035 L
.06119 .50198 L
.06244 .50291 L
.06371 .50268 L
.06506 .50243 L
.0679 .50191 L
.07286 .50097 L
.08255 .49902 L
.10458 .49407 L
.14487 .48274 L
.18364 .46834 L
.22486 .44809 L
.26457 .42225 L
.30277 .3896 L
.34341 .34318 L
.35255 .33055 L
.36221 .31611 L
.36464 .31227 L
.36529 .31124 L
.36599 .31012 L
.36726 .30902 L
.36803 .30902 L
.36875 .30902 L
.36942 .30902 L
.37012 .30902 L
.37139 .30902 L
.37212 .30902 L
.3728 .30902 L
.37399 .30902 L
.37524 .30902 L
.37631 .30902 L
.37749 .30902 L
.37875 .30902 L
.37946 .30902 L
.3801 .30902 L
.38136 .30902 L
.38254 .30902 L
.38378 .30902 L
.38448 .30902 L
.38514 .30902 L
.38583 .30902 L
.38646 .30902 L
.38719 .30902 L
.38789 .30902 L
.38911 .30902 L
.39024 .30902 L
Mistroke
.39149 .30902 L
.39218 .30902 L
.39281 .30902 L
.39351 .30902 L
.39425 .30902 L
.39557 .30902 L
.39631 .30902 L
.39699 .30902 L
.39775 .30902 L
.39855 .30902 L
.39925 .30902 L
.4 .30902 L
.40072 .30902 L
.40138 .30902 L
.40263 .30902 L
.40326 .30902 L
.40395 .30902 L
.40523 .30902 L
.40587 .30902 L
.40657 .30902 L
.40896 .30902 L
.41436 .30902 L
.42412 .30902 L
.46474 .30902 L
.50383 .30902 L
.54538 .30902 L
.58542 .30902 L
.62394 .30902 L
.66491 .30902 L
.70436 .30902 L
.7423 .30902 L
.78269 .30902 L
.82157 .30902 L
.8629 .30902 L
.90271 .30902 L
.94101 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000O<ol000<0000co`0co`008S?o000306Ko<ol0<ol000Pco`000`000?ooooooo`06
oooo00?o09Woooooool09?ooo`030000oooooooo02goool00`000?ooooooo`0^oooo00<0003ooooo
ool05Oooo`00:?ooo`H0000m<ol000<0I_lco`0co`002C?o00030000oooooooo00Koool00ol0VOoo
ooooo`2Moooo000^oooo1@0003Pco`000`1Voc?o03?o0009<ol00P0000Ooool00ol0VOooooooo`2M
oooo000coooo100003<co`000`1Voc?o03?o000:<ol000<0003oooooool01_ooo`03o`2Ioooooooo
09goool003Ooool20000<C?o000306Ko<ol0<ol000Xco`000`000?ooooooo`06oooo00?o09Wooooo
ool0WOooo`00>Oooo`<0000]<ol000<0I_lco`0co`002c?o00030000oooooooo00Koool00ol0VOoo
ooooo`2Moooo000loooo0P0002Xco`000`1Voc?o03?o000<<ol00P0000Ooool00ol0VOooooooo`2M
oooo000noooo0P0002Lco`000`1Voc?o03?o000=<ol000<0003oooooool01_ooo`03o`2Ioooooooo
09goool0043oool2000093?o000306Ko<ol0<ol000hco`000`000?ooooooo`06oooo00?o09Wooooo
ool0WOooo`00@_ooo`80000Q<ol000<0I_lco`0co`003c?o00030000oooooooo00Koool00ol0VOoo
ooooo`2Moooo0014oooo0P0001hco`000`1Voc?o03?o000@<ol00P0000Ooool00ol0VOooooooo`2M
oooo0016oooo00<0000co`0co`006c?o000306Ko<ol0<ol0010co`000`000?ooooooo`06oooo00?o
09Woooooool0WOooo`00Aoooo`030000<ol0<ol001Tco`000`1Voc?o03?o000A<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo09goool004Soool00`0003?o03?o000G<ol000<0I_lco`0co`004S?o
00030000oooooooo00Koool00ol0VOooooooo`2Moooo0019oooo00<0000co`0co`005C?o000306Ko
<ol0<ol001<co`0200001oooo`03o`2Ioooooooo09goool004[oool00`0003?o03?o000C<ol000<0
I_lco`0co`0053?o00030000oooooooo00Koool00ol0VOooooooo`2Moooo001;oooo00<0000co`0c
o`0043?o00800004<ol00P0000<co`0400000c?o00800005<ol000<0003oooooool01_ooo`03o`2I
oooooooo09goool004coool00`0003?o03?o000><ol000@0000co`00I_l00008<ol000<0000co`0c
o`000c?o00040000<ol0<ol0000013?o00030000oooooooo00Koool00ol0VOooooooo`2Moooo001=
oooo00<0000co`0co`003C?o0004000006Ko<ol000002C?o00030000<ol0<ol000Dco`000`0003?o
03?o0002<ol00P0000Ooool00ol0VOooooooo`2Moooo001>oooo00<0000co`0co`0033?o00040000
<ol0<ol000002S?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo00Koool00ol0VOoo
ooooo`2Moooo001?oooo00<0000co`0co`002S?o000506Ko0000<ol0<ol0000000Pco`00100003?o
03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool01_ooo`03o`2Ioooooooo09goool0
04ooool00`0003?o03?o0008<ol00P1Vo`8co`0200002S?o00800004<ol00`0000@co`000`000?oo
ooooo`06oooo00?o09Woooooool0WOooo`00D?ooo`030000<ol0<ol000Hco`000`1Voc?o03?o000K
<ol00P0000Ooool00ol0VOooooooo`2Moooo001Aoooo00<0000co`0co`0013?o000306Ko<ol0<ol0
01`co`000`000?ooooooo`06oooo00?o09Woooooool0WOooo`00D_ooo`030000<ol0<ol0008co`00
0`1Voc?o03?o000M<ol000<0003oooooool01_ooo`03o`2Ioooooooo09goool005;oool00`0003?o
03?o000206Ko83?o00030000oooooooo00Koool00ol0VOooooooo`2Moooo001Coooo00<00000I_lc
o`008C?o00800007oooo00?o09Woooooool0WOooo`00Doooo`0306Ko<ol0<ol0024co`000`000?oo
ooooo`06oooo00?o09Woooooool0WOooo`00DOooo`80I_l00oooo`0003?o000Q<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo09goool0053oool01@1Vooooooooooooo`00000R<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo09goool004ooool00`1Vooooooooo`03oooo00<0000co`0co`007c?o
00800007oooo00?o09Woooooool0WOooo`00COooo`80I_l6oooo00<0000co`0co`007c?o00030000
oooooooo00Koool00ol0VOooooooo`2Moooo001<oooo00<0I_ooooooool01oooo`030000<ol0<ol0
01hco`000`000?ooooooo`06oooo00?o09Woooooool0WOooo`00B_ooo`80I_l:oooo00<0000co`0c
o`007S?o00030000oooooooo00Koool00ol0VOooooooo`2Moooo0019oooo00<0I_ooooooool02ooo
o`030000<ol0<ol001dco`0200001oooo`03o`2Ioooooooo09goool001Koool00`1Vooooooooo`0^
oooo0P1Vo`koool00`0003?o03?o000M<ol000<0003oooooool01_ooo`03o`2Ioooooooo09goool0
01Ooool00`1Vooooooooo`0[oooo0P1Voa7oool00`0003?o03?o0009<ol00P0000@co`02000013?o
00800005<ol000<0003oooooool01_ooo`03o`2Ioooooooo09goool001Soool00`1Vooooooooo`0X
oooo0P1Voa?oool00`0003?o03?o0008<ol000@0000co`0co`000008<ol000@0000co`0co`000004
<ol000<0003oooooool01_ooo`03o`2Ioooooooo09goool001Soool00`1Vooooooooo`0Voooo0P1V
oaKoool00`0003?o03?o0007<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o00800007
oooo00?o09Woooooool0WOooo`006Oooo`0306Kooooooooo02;oool306Ko6?ooo`030000<ol0<ol0
00Lco`00100003?o03?o000000Tco`0200001C?o00030000oooooooo00Koool00ol0VOooooooo`2M
oooo000Joooo00<0I_ooooooool07_ooo`<0I_lKoooo00<0000co`0co`001c?o00040000<ol0<ol0
00002C?o00030000<ol0<ol000@co`000`000?ooooooo`06oooo00?o09Woooooool0WOooo`006ooo
o`0306Kooooooooo01Woool406Ko7oooo`030000<ol0<ol000Lco`0200002S?o00<00004<ol000<0
003oooooool01_ooo`03o`2Ioooooooo09goool001coool00`1Vooooooooo`0Eoooo0`1Vob?oool0
0`0003?o03?o000J<ol00P0000Ooool00ol0VOooooooo`2Moooo000Loooo00<0I_ooooooool04_oo
o`<0I_lVoooo00<0000co`0co`006S?o00030000oooooooo00Koool00ol0VOooooooo`2Moooo000M
oooo00<0I_ooooooool03Oooo`@0I_lZoooo00<0000co`0co`006C?o00030000oooooooo00Koool0
0ol0VOooooooo`2Moooo000Noooo00<0I_ooooooool02Oooo`<0I_l^oooo00<0000co`0co`006C?o
00800007oooo00?o09Woooooool0WOooo`007oooo`0306Kooooooooo00Goool306Ko<Oooo`030000
<ol0<ol001Tco`000`000?ooooooo`06oooo00?o09Woooooool0WOooo`007oooo`P0I_leoooo00<0
000co`0co`0063?o00030000oooooooo00Koool00ol0VOooooooo`2Moooo000Poooo00<0I_oooooo
ool0>Oooo`030000<ol0<ol001Pco`000`000?ooooooo`06oooo00?o09Woooooool0WOooo`00G?oo
o`030000<ol0<ol001Pco`0200001oooo`03o`2Ioooooooo09goool005goool00`0003?o03?o000G
<ol000<0003oooooool01_ooo`03o`2Ioooooooo09goool005goool00`0003?o03?o000G<ol000<0
003oooooool01_ooo`03o`2Ioooooooo09goool005goool00`0003?o03?o000G<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo09goool005koool00`0003?o03?o000F<ol00P0000Ooool00ol0VOoo
ooooo`2Moooo001Noooo00<0000co`0co`005S?o00030000oooooooo00Koool00ol0VOooooooo`2M
oooo001Noooo0P0000@co`0200001C?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo
00Koool00ol0VOooooooo`2Moooo001Moooo00@0003oool00000000:<ol000D0000co`0co`0co`00
00000S?o00030000<ol0<ol0008co`000`000?ooooooo`06oooo00?o09Woooooool0WOooo`00GOoo
o`040000oooo000000002S?o00030000<ol0<ol000@co`000`0003?o03?o0002<ol00P0000Ooool0
0ol0VOooooooo`2Moooo001Moooo00@0003oool00000000;<ol000@0000co`0co`0co`0200001C?o
00030000oooooooo00Koool00ol0VOooooooo`2Moooo001Moooo00@0003oooooool00008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo00Koool00ol0VOooooooo`2M
oooo001Noooo0`0000Pco`0400000c?o00<00004<ol000<0003oooooool01_ooo`03o`2Ioooooooo
09goool0063oool00`0003?o03?o000D<ol00P0000Ooool00ol0VOooooooo`2Moooo001Poooo00<0
000co`0co`0053?o00030000oooooooo00Koool00ol0VOooooooo`2Moooo001Qoooo00<0000co`0c
o`004c?o00030000oooooooo00Koool00ol0VOooooooo`2Moooo001Qoooo00<0000co`0co`004c?o
00030000oooooooo00Koool00ol0VOooooooo`2Moooo001Qoooo00<0000co`0co`004c?o00800007
oooo00?o09Woooooool0WOooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`06oooo00?o
09Woooooool0WOooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`06oooo00?o09Wooooo
ool0WOooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`06oooo00?o09Woooooool0WOoo
o`00H_ooo`030000<ol0<ol0018co`0200001oooo`03o`2Ioooooooo09goool006;oool00`0003?o
03?o000B<ol000<0003oooooool01_ooo`03o`2Ioooooooo09goool006?oool00`0003?o03?o000A
<ol000<0003oooooool01_ooo`03o`2Ioooooooo09goool006?oool00`0003?o03?o000A<ol000<0
003oooooool01_ooo`03o`2Ioooooooo09goool006?oool00`0003?o03?o000A<ol00P0000Ooool0
0ol0VOooooooo`2Moooo001Soooo00<0000co`0co`004C?o00030000oooooooo00Koool00ol0VOoo
ooooo`2Moooo001Soooo00<0000co`0co`002C?o00D00003<ol000<0003oooooool01_ooo`03o`2I
oooooooo09goool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o00030000oooooooo
00Koool00ol0VOooooooo`2Moooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol000<co`02
00001oooo`03o`2Ioooooooo09goool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool=
<ol000<0000co`0co`000c?o0:Woool006Coool<<ol00P0000Dco`2Yoooo001Uoooo4S?o0:Woool0
06GooolB<ol0ZOooo`00IOoooa8co`02oooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
06GooolB<ol000?oool0003oool02Oooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001U
oooo4S?o0003oooo0000oooo00?oool200001?ooo`030000oooooooo00goool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001Uoooo4S?o0003oooo0000oooo00;oool010000?oo
ooooo`0000Coool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001Uoooo4S?o00030000oooooooo00;oool00`000?oo
ooooo`0Coooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Mooo
o`00I_oooa4co`001?ooo`000?ooooooo`D0000Boooo00@0003oooooool00009oooo0P0000Coool0
0`000?ooooooo`1hoooo001Voooo4C?o0003oooo0000oooo00;oool00`000?ooooooo`0Coooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00I_oooa4co`02
oooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo001Voooo4C?o
0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.45734 .30902 L
.45963 .30902 L
.46063 .30902 L
.46172 .30902 L
s
.46172 .30902 m
.46183 .61803 L
s
0 .4 1 r
.02381 .43106 m
.04262 .44938 L
.06244 .47168 L
.07216 .48388 L
.07472 .48724 L
.0775 .49097 L
.07878 .49271 L
.07948 .49366 L
.08013 .49456 L
.08128 .49563 L
.08255 .49533 L
.08852 .4939 L
.09396 .49254 L
.10458 .48972 L
.14335 .47742 L
.18458 .46003 L
.22428 .43773 L
.26248 .40949 L
.30312 .36954 L
.32192 .34655 L
.33181 .33303 L
.34225 .31753 L
.34482 .31351 L
.34623 .31126 L
.34693 .31014 L
.34757 .3091 L
.34832 .30902 L
.34915 .30902 L
.34985 .30902 L
.35059 .30902 L
.35128 .30902 L
.35193 .30902 L
.35264 .30902 L
.3534 .30902 L
.35465 .30902 L
.35536 .30902 L
.35601 .30902 L
.35671 .30902 L
.35734 .30902 L
.35807 .30902 L
.35876 .30902 L
.35998 .30902 L
.36111 .30902 L
.36235 .30902 L
.36366 .30902 L
.36606 .30902 L
.36737 .30902 L
.36863 .30902 L
.36979 .30902 L
.37105 .30902 L
Mistroke
.3722 .30902 L
.37327 .30902 L
.37393 .30902 L
.37465 .30902 L
.37595 .30902 L
.37722 .30902 L
.37839 .30902 L
.37965 .30902 L
.38037 .30902 L
.38104 .30902 L
.38174 .30902 L
.38239 .30902 L
.38313 .30902 L
.38383 .30902 L
.38498 .30902 L
.38621 .30902 L
.38737 .30902 L
.38844 .30902 L
.38962 .30902 L
.39091 .30902 L
.39157 .30902 L
.39226 .30902 L
.39351 .30902 L
.39421 .30902 L
.39485 .30902 L
.39555 .30902 L
.39629 .30902 L
.39753 .30902 L
.39824 .30902 L
.3989 .30902 L
.40013 .30902 L
.40126 .30902 L
.40255 .30902 L
.40378 .30902 L
.40493 .30902 L
.406 .30902 L
.40713 .30902 L
.40837 .30902 L
.41261 .30902 L
.42222 .30902 L
.46087 .30902 L
.50198 .30902 L
.54157 .30902 L
.57965 .30902 L
.62018 .30902 L
.65919 .30902 L
.70065 .30902 L
.7406 .30902 L
.77904 .30902 L
.81992 .30902 L
Mistroke
.8593 .30902 L
.89715 .30902 L
.93746 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000D0
000co`0co`0co`00I_l013?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003ooooo
ool00_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo00Goool:00007c?o00030000<ol0<ol001hco`000`1Voc?o
03?o000<<ol000<0003oooooool02oooo`03o`2Ioooooooo01ooool00`000?ooooooo`0]oooo00<0
003oooooool0;_ooo`030000oooooooo01Goool002Soool60000>C?o000306Ko<ol0<ol000dco`00
0`000?ooooooo`0;oooo00?o09Woooooool0V?ooo`00;_ooo`D0000c<ol000<0I_lco`0co`003S?o
0080000<oooo00?o09Woooooool0V?ooo`00<oooo`@0000^<ol000<0I_lco`0co`003c?o00030000
oooooooo00_oool00ol0VOooooooo`2Hoooo000goooo0P0002`co`000`1Voc?o03?o000?<ol000<0
003oooooool02oooo`03o`2Ioooooooo09Soool003Woool30000:3?o000306Ko<ol0<ol0010co`00
0`000?ooooooo`0;oooo00?o09Woooooool0V?ooo`00??ooo`80000U<ol000<0I_lco`0co`004C?o
0080000<oooo00?o09Woooooool0V?ooo`00?_ooo`80000S<ol000<0I_lco`0co`004C?o00030000
oooooooo00_oool00ol0VOooooooo`2Hoooo0010oooo0P00020co`000`1Voc?o03?o000B<ol000<0
003oooooool02oooo`03o`2Ioooooooo09Soool004;oool200007C?o000306Ko<ol0<ol001<co`00
0`000?ooooooo`0;oooo00?o09Woooooool0V?ooo`00A?ooo`80000J<ol000<0I_lco`0co`0053?o
0080000<oooo00?o09Woooooool0V?ooo`00A_ooo`030000<ol0<ol001Hco`000`1Voc?o03?o000E
<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool004Ooool00`0003?o03?o000E<ol000<0
I_lco`0co`005C?o00030000oooooooo00_oool00ol0VOooooooo`2Hoooo0018oooo00<0000co`0c
o`004c?o000306Ko<ol0<ol001Hco`000`000?ooooooo`0;oooo00?o09Woooooool0V?ooo`00BOoo
o`030000<ol0<ol0014co`000`1Voc?o03?o000G<ol00P0000coool00ol0VOooooooo`2Hoooo001:
oooo00<0000co`0co`003c?o000306Ko<ol0<ol001Pco`000`000?ooooooo`0;oooo00?o09Wooooo
ool0V?ooo`00Boooo`030000<ol0<ol000dco`000`1Voc?o03?o0002000013?o00800003<ol01000
00<co`0200001C?o00030000oooooooo00_oool00ol0VOooooooo`2Hoooo001<oooo00<0000co`0c
o`002c?o000406Ko<ol0<ol000000S?o00030000<ol0<ol000Hco`000`0003?o03?o0003<ol000@0
000co`0co`000004<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool004goool00`0003?o
03?o0009<ol000D0I_lco`0co`0co`0000000S?o00030000<ol0<ol000Lco`000`0003?o03?o0005
<ol000<0000co`0co`000S?o0080000<oooo00?o09Woooooool0V?ooo`00C_ooo`030000<ol0<ol0
00Lco`000`1Voc?o03?o0002<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800005
<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool004ooool00`0003?o03?o0005<ol000<0
I_lco`0co`000c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0<ol0
00@co`000`000?ooooooo`0;oooo00?o09Woooooool0V?ooo`00Coooo`030000<ol0<ol000@co`00
0`1Voc?o03?o0005<ol00P0000Xco`02000013?o00<00004<ol000<0003oooooool02oooo`03o`2I
oooooooo09Soool0053oool00`0003?o03?o0002<ol000<0I_lco`0co`007c?o0080000<oooo00?o
09Woooooool0V?ooo`00DOooo`040000<ol0<ol006Ko8S?o00030000oooooooo00_oool00ol0VOoo
ooooo`2Hoooo001Boooo00<00000I_lco`008S?o00030000oooooooo00_oool00ol0VOooooooo`2H
oooo001Aoooo0P1Vob@co`000`000?ooooooo`0;oooo00?o09Woooooool0V?ooo`00D?ooo`0406Ko
oooooooo00008c?o0080000<oooo00?o09Woooooool0V?ooo`00Coooo`0506Kooooooooooooo0000
02<co`000`000?ooooooo`0;oooo00?o09Woooooool0V?ooo`00COooo`80I_l5oooo00<0000co`0c
o`0083?o00030000oooooooo00_oool00ol0VOooooooo`2Hoooo000Foooo00<0I_ooooooool0<ooo
o`0306Kooooooooo00Goool00`0003?o03?o000P<ol000<0003oooooool02oooo`03o`2Ioooooooo
09Soool001Ooool00`1Vooooooooo`0`oooo0P1Vo`Woool00`0003?o03?o000O<ol00P0000coool0
0ol0VOooooooo`2Hoooo000Hoooo00<0I_ooooooool0;_ooo`0306Kooooooooo00Woool00`0003?o
03?o000O<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool001Woool00`1Vooooooooo`0[
oooo0P1Vo`goool00`0003?o03?o000N<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool0
01[oool00`1Vooooooooo`0Xoooo0P1Vo`ooool00`0003?o03?o000N<ol000<0003oooooool02ooo
o`03o`2Ioooooooo09Soool001_oool00`1Vooooooooo`0Voooo00<0I_ooooooool04?ooo`030000
<ol0<ol001dco`0200003?ooo`03o`2Ioooooooo09Soool001coool00`1Vooooooooo`0Soooo0P1V
oa?oool00`0003?o03?o000M<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool001goool0
0`1Vooooooooo`0Poooo0P1VoaKoool00`0003?o03?o0009<ol00P0000@co`02000013?o00800005
<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool001goool00`1Vooooooooo`0Noooo0P1V
oaSoool00`0003?o03?o0008<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0
003oooooool02oooo`03o`2Ioooooooo09Soool001koool00`1Vooooooooo`0Koooo0P1Voa_oool0
0`0003?o03?o0007<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o0080000<oooo00?o
09Woooooool0V?ooo`007oooo`0306Kooooooooo01Ooool306Ko7Oooo`030000<ol0<ol000Lco`00
100003?o03?o000000Tco`0200001C?o00030000oooooooo00_oool00ol0VOooooooo`2Hoooo000P
oooo00<0I_ooooooool05?ooo`80I_lPoooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o
00030000<ol0<ol000@co`000`000?ooooooo`0;oooo00?o09Woooooool0V?ooo`008Oooo`0306Ko
oooooooo013oool306Ko8oooo`030000<ol0<ol000Lco`0200002S?o00<00004<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo09Soool0027oool00`1Vooooooooo`0=oooo0`1VobKoool00`0003?o
03?o000J<ol00P0000coool00ol0VOooooooo`2Hoooo000Roooo00<0I_ooooooool02?ooo`@0I_lY
oooo00<0000co`0co`006S?o00030000oooooooo00_oool00ol0VOooooooo`2Hoooo000Soooo00<0
I_ooooooool01?ooo`<0I_l^oooo00<0000co`0co`006C?o00030000oooooooo00_oool00ol0VOoo
ooooo`2Hoooo000Toooo0P1Vo`04oooo06Ko06Ko06Ko<Oooo`030000<ol0<ol001Tco`0200003?oo
o`03o`2Ioooooooo09Soool002Goool206Ko=?ooo`030000<ol0<ol001Tco`000`000?ooooooo`0;
oooo00?o09Woooooool0V?ooo`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`0;oooo00?o
09Woooooool0V?ooo`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`0;oooo00?o09Wooooo
ool0V?ooo`00G?ooo`030000<ol0<ol001Pco`0200003?ooo`03o`2Ioooooooo09Soool005goool0
0`0003?o03?o000G<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool005goool00`0003?o
03?o000G<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool005goool00`0003?o03?o000G
<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool005koool00`0003?o03?o000F<ol00P00
00coool00ol0VOooooooo`2Hoooo001Noooo00<0000co`0co`005S?o00030000oooooooo00_oool0
0ol0VOooooooo`2Hoooo001Noooo0P0000@co`0200001C?o00030000<ol0<ol0008co`0200001C?o
00030000oooooooo00_oool00ol0VOooooooo`2Hoooo001Moooo00@0003oool00000000:<ol000D0
000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`000?ooooooo`0;oooo00?o09Wooooo
ool0V?ooo`00GOooo`040000oooo000000002S?o00030000<ol0<ol000@co`000`0003?o03?o0002
<ol00P0000coool00ol0VOooooooo`2Hoooo001Moooo00@0003oool00000000;<ol000@0000co`0c
o`0co`0200001C?o00030000oooooooo00_oool00ol0VOooooooo`2Hoooo001Moooo00@0003ooooo
ool00008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo00_oool0
0ol0VOooooooo`2Hoooo001Noooo0`0000Pco`0400000c?o00<00004<ol000<0003oooooool02ooo
o`03o`2Ioooooooo09Soool0063oool00`0003?o03?o000D<ol00P0000coool00ol0VOooooooo`2H
oooo001Poooo00<0000co`0co`0053?o00030000oooooooo00_oool00ol0VOooooooo`2Hoooo001Q
oooo00<0000co`0co`004c?o00030000oooooooo00_oool00ol0VOooooooo`2Hoooo001Qoooo00<0
000co`0co`004c?o00030000oooooooo00_oool00ol0VOooooooo`2Hoooo001Qoooo00<0000co`0c
o`004c?o0080000<oooo00?o09Woooooool0V?ooo`00HOooo`030000<ol0<ol001<co`000`000?oo
ooooo`0;oooo00?o09Woooooool0V?ooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`0;
oooo00?o09Woooooool0V?ooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`0;oooo00?o
09Woooooool0V?ooo`00H_ooo`030000<ol0<ol0018co`0200003?ooo`03o`2Ioooooooo09Soool0
06;oool00`0003?o03?o000B<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool006?oool0
0`0003?o03?o000A<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool006?oool00`0003?o
03?o000A<ol000<0003oooooool02oooo`03o`2Ioooooooo09Soool006?oool00`0003?o03?o000A
<ol00P0000coool00ol0VOooooooo`2Hoooo001Soooo00<0000co`0co`004C?o00030000oooooooo
00_oool00ol0VOooooooo`2Hoooo001Soooo00<0000co`0co`002C?o00D00003<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo09Soool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o
00030000oooooooo00_oool00ol0VOooooooo`2Hoooo001Toooo00<0000co`0co`002S?o00030000
<ol0<ol000<co`0200003?ooo`03o`2Ioooooooo09Soool006Coool=<ol000<0000co`0co`000c?o
0:Woool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool<<ol00P0000Dco`2Yoooo001U
oooo4S?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`02oooo00<0003oooooool0:?ooo`030000
oooooooo07Woool006GooolB<ol000?oool0003oool02Oooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001Uoooo4S?o0003oooo0000oooo00?oool200001?ooo`030000oooooooo00goool2
00001?ooo`800005oooo00<0003oooooool00_ooo`030000oooooooo07Soool006GooolB<ol000?o
ool0003oool00_ooo`040000oooooooo00001?ooo`030000oooooooo00Coool400000oooo`040000
oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001Uoooo4S?o00030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00ooo
o`030000oooooooo07Ooool006KooolA<ol000Coool0003oooooool500004_ooo`040000oooooooo
00002oooo`050000oooooooooooo000007[oool006KooolA<ol000?oool0003oool00_ooo`030000
oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001Voooo4C?o00;oool00`000?ooooooo`0Goooo0P0000Woool400000_ooo`030000oooooooo
07Woool006KooolA<ol0ZOooo`00I_oooa4co`2Yoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47106 .30902 L
.47567 .30902 L
.47791 .30902 L
.47889 .30902 L
.47994 .30902 L
s
.47994 .30902 m
.48007 .61803 L
s
0 .4 1 r
.02381 .40942 m
.06244 .44283 L
.08255 .46444 L
.0932 .47726 L
.09626 .48114 L
.09777 .48309 L
.09843 .48395 L
.09916 .4849 L
.10042 .48588 L
.10111 .48567 L
.10176 .48547 L
.10458 .4846 L
.12507 .47767 L
.14415 .47024 L
.18292 .45162 L
.22415 .42525 L
.26386 .39127 L
.30205 .34774 L
.31303 .3327 L
.31841 .32483 L
.32337 .31728 L
.3257 .31362 L
.32684 .3118 L
.32788 .31013 L
.32898 .30902 L
.33016 .30902 L
.33144 .30902 L
.33265 .30902 L
.33386 .30902 L
.33516 .30902 L
.33639 .30902 L
.33752 .30902 L
.33872 .30902 L
.33998 .30902 L
.34128 .30902 L
.34201 .30902 L
.34269 .30902 L
.34396 .30902 L
.34516 .30902 L
.34624 .30902 L
.3474 .30902 L
.34867 .30902 L
.34931 .30902 L
.35002 .30902 L
.35126 .30902 L
.35243 .30902 L
.3535 .30902 L
.35464 .30902 L
.35589 .30902 L
.35705 .30902 L
Mistroke
.35814 .30902 L
.35931 .30902 L
.36042 .30902 L
.36144 .30902 L
.36275 .30902 L
.36341 .30902 L
.36413 .30902 L
.3654 .30902 L
.36657 .30902 L
.36776 .30902 L
.36884 .30902 L
.37009 .30902 L
.37127 .30902 L
.37254 .30902 L
.37319 .30902 L
.3739 .30902 L
.37515 .30902 L
.37633 .30902 L
.377 .30902 L
.37771 .30902 L
.37897 .30902 L
.37968 .30902 L
.38034 .30902 L
.38106 .30902 L
.38182 .30902 L
.38306 .30902 L
.38377 .30902 L
.38442 .30902 L
.38512 .30902 L
.38575 .30902 L
.38648 .30902 L
.38717 .30902 L
.38839 .30902 L
.38953 .30902 L
.39077 .30902 L
.39209 .30902 L
.3934 .30902 L
.39414 .30902 L
.39482 .30902 L
.39606 .30902 L
.39738 .30902 L
.39807 .30902 L
.39882 .30902 L
.39952 .30902 L
.40016 .30902 L
.40091 .30902 L
.40173 .30902 L
.4025 .30902 L
.40321 .30902 L
.40437 .30902 L
Mistroke
.40562 .30902 L
.40679 .30902 L
.40787 .30902 L
.413 .30902 L
.42337 .30902 L
.4631 .30902 L
.50132 .30902 L
.54198 .30902 L
.58113 .30902 L
.62273 .30902 L
.66282 .30902 L
.70139 .30902 L
.74241 .30902 L
.78192 .30902 L
.81991 .30902 L
.86036 .30902 L
.89929 .30902 L
.94067 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0
I_l0000co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000O<ol000<0000co`0co`006C?o000306Ko<ol0<ol0014co`000`000?ooooooo`0@
oooo00?o09Woooooool06_ooo`030000oooooooo02goool00`000?ooooooo`0^oooo00<0003ooooo
ool05Oooo`00:?ooo`H0000d<ol000<0I_lco`0co`004S?o00030000oooooooo013oool00ol0VOoo
ooooo`2Coooo000^oooo1@0002hco`000`1Voc?o03?o000C<ol00P00017oool00ol0VOooooooo`2C
oooo000coooo100002Tco`000`1Voc?o03?o000D<ol000<0003oooooool04?ooo`03o`2Ioooooooo
09?oool003Ooool200009c?o000306Ko<ol0<ol001@co`000`000?ooooooo`0@oooo00?o09Wooooo
ool0Toooo`00>Oooo`<0000S<ol000<0I_lco`0co`005C?o00030000oooooooo013oool00ol0VOoo
ooooo`2Coooo000loooo0P00020co`000`1Voc?o03?o000F<ol00P00017oool00ol0VOooooooo`2C
oooo000noooo0P0001hco`000`1Voc?o03?o000F<ol000<0003oooooool04?ooo`03o`2Ioooooooo
09?oool0043oool200006c?o000306Ko<ol0<ol001Lco`000`000?ooooooo`0@oooo00?o09Wooooo
ool0Toooo`00@_ooo`80000H<ol000<0I_lco`0co`0063?o00030000oooooooo013oool00ol0VOoo
ooooo`2Coooo0014oooo0P0001Dco`000`1Voc?o03?o000I<ol00P00017oool00ol0VOooooooo`2C
oooo0016oooo00<0000co`0co`004C?o000306Ko<ol0<ol001Xco`000`000?ooooooo`0@oooo00?o
09Woooooool0Toooo`00Aoooo`030000<ol0<ol000lco`000`1Voc?o03?o000K<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo09?oool004Soool00`0003?o03?o000=<ol000<0I_lco`0co`0073?o
00030000oooooooo013oool00ol0VOooooooo`2Coooo0019oooo00<0000co`0co`0033?o000306Ko
<ol0<ol001`co`0200004Oooo`03o`2Ioooooooo09?oool004[oool00`0003?o03?o000:<ol000<0
I_lco`0co`007C?o00030000oooooooo013oool00ol0VOooooooo`2Coooo001;oooo00<0000co`0c
o`0023?o000306Ko<ol0<ol000Dco`02000013?o00800003<ol0100000<co`0200001C?o00030000
oooooooo013oool00ol0VOooooooo`2Coooo001<oooo00<0000co`0co`001S?o000306Ko<ol0<ol0
00Dco`00100003?o03?o000000Pco`000`0003?o03?o0003<ol000@0000co`0co`000004<ol000<0
003oooooool04?ooo`03o`2Ioooooooo09?oool004goool00`0003?o03?o0004<ol000<0I_lco`0c
o`001S?o00040000<ol0<ol000002C?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol00P00
017oool00ol0VOooooooo`2Coooo001>oooo00<0000co`0co`000S?o000306Ko<ol0<ol000Lco`00
100003?o03?o000000Xco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`0@oooo00?o
09Woooooool0Toooo`00Coooo`040000<ol0<ol006Ko2S?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?ooooooo`0@oooo00?o09Woooooool0Tooo
o`00Coooo`030000<ol006Ko00`co`0200002S?o00800004<ol00`0000@co`000`000?ooooooo`0@
oooo00?o09Woooooool0Toooo`00D?ooo`0306Ko<ol0<ol002@co`0200004Oooo`03o`2Ioooooooo
09?oool004ooool00`1Vooooo`00000U<ol000<0003oooooool04?ooo`03o`2Ioooooooo09?oool0
01Koool00`1Vooooooooo`0doooo0P1Vo`?oool00`0003?o03?o000R<ol000<0003oooooool04?oo
o`03o`2Ioooooooo09?oool001Ooool00`1Vooooooooo`0boooo00<0I_ooooooool00oooo`030000
<ol0<ol0028co`000`000?ooooooo`0@oooo00?o09Woooooool0Toooo`006?ooo`80I_laoooo00<0
I_ooooooool01Oooo`030000<ol0<ol0024co`0200004Oooo`03o`2Ioooooooo09?oool001[oool0
0`1Vooooooooo`0]oooo00<0I_ooooooool01_ooo`030000<ol0<ol0024co`000`000?ooooooo`0@
oooo00?o09Woooooool0Toooo`006oooo`0306Kooooooooo02_oool00`1Vooooooooo`08oooo00<0
000co`0co`0083?o00030000oooooooo013oool00ol0VOooooooo`2Coooo000Loooo00<0I_oooooo
ool0:?ooo`80I_l;oooo00<0000co`0co`0083?o00030000oooooooo013oool00ol0VOooooooo`2C
oooo000Moooo0P1VobOoool00`1Vooooooooo`0<oooo00<0000co`0co`007c?o0080000Aoooo00?o
09Woooooool0Toooo`007oooo`0306Kooooooooo02?oool00`1Vooooooooo`0=oooo00<0000co`0c
o`007c?o00030000oooooooo013oool00ol0VOooooooo`2Coooo000Poooo00<0I_ooooooool08?oo
o`80I_lAoooo00<0000co`0co`007S?o00030000oooooooo013oool00ol0VOooooooo`2Coooo000Q
oooo00<0I_ooooooool07_ooo`0306Kooooooooo017oool00`0003?o03?o000N<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo09?oool002;oool00`1Vooooooooo`0Koooo0P1VoaGoool00`0003?o
03?o000M<ol00P00017oool00ol0VOooooooo`2Coooo000Roooo00<0I_ooooooool06Oooo`80I_lG
oooo00<0000co`0co`007C?o00030000oooooooo013oool00ol0VOooooooo`2Coooo000Soooo00<0
I_ooooooool05_ooo`80I_lJoooo00<0000co`0co`002C?o00800004<ol00P0000@co`0200001C?o
00030000oooooooo013oool00ol0VOooooooo`2Coooo000Toooo00<0I_ooooooool04_ooo`<0I_lL
oooo00<0000co`0co`0023?o00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000
oooooooo013oool00ol0VOooooooo`2Coooo000Uoooo00<0I_ooooooool03oooo`80I_lPoooo00<0
000co`0co`001c?o00040000<ol0<ol000002c?o00030000<ol0<ol0008co`0200004Oooo`03o`2I
oooooooo09?oool002Koool00`1Vooooooooo`0;oooo0`1Vob;oool00`0003?o03?o0007<ol000@0
000co`0co`000009<ol00P0000Dco`000`000?ooooooo`0@oooo00?o09Woooooool0Toooo`009ooo
o`0306Kooooooooo00Soool206Ko9Oooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`00
0`0003?o03?o0004<ol000<0003oooooool04?ooo`03o`2Ioooooooo09?oool002Soool00`1Voooo
ooooo`04oooo0`1VobSoool00`0003?o03?o0007<ol00P0000Xco`03000013?o00030000oooooooo
013oool00ol0VOooooooo`2Coooo000Yoooo00@0I_ooooooooooool206Ko:oooo`030000<ol0<ol0
01Xco`0200004Oooo`03o`2Ioooooooo09?oool002Woool406Ko;Oooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0@oooo00?o09Woooooool0Toooo`00Foooo`030000<ol0<ol001Tco`000`000?oo
ooooo`0@oooo00?o09Woooooool0Toooo`00Foooo`030000<ol0<ol001Tco`0200004Oooo`03o`2I
oooooooo09?oool005_oool00`0003?o03?o000I<ol000<0003oooooool04?ooo`03o`2Ioooooooo
09?oool005coool00`0003?o03?o000H<ol000<0003oooooool04?ooo`03o`2Ioooooooo09?oool0
05coool00`0003?o03?o000H<ol000<0003oooooool04?ooo`03o`2Ioooooooo09?oool005coool0
0`0003?o03?o000H<ol00P00017oool00ol0VOooooooo`2Coooo001Moooo00<0000co`0co`005c?o
00030000oooooooo013oool00ol0VOooooooo`2Coooo001Moooo00<0000co`0co`005c?o00030000
oooooooo013oool00ol0VOooooooo`2Coooo001Moooo00<0000co`0co`005c?o00030000oooooooo
013oool00ol0VOooooooo`2Coooo001Noooo00<0000co`0co`005S?o0080000Aoooo00?o09Wooooo
ool0Toooo`00G_ooo`030000<ol0<ol001Hco`000`000?ooooooo`0@oooo00?o09Woooooool0Tooo
o`00G_ooo`800004<ol00P0000Dco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`0@
oooo00?o09Woooooool0Toooo`00GOooo`040000oooo000000002S?o00050000<ol0<ol0<ol00000
008co`000`0003?o03?o0002<ol000<0003oooooool04?ooo`03o`2Ioooooooo09?oool005goool0
10000?ooo`00000000Xco`000`0003?o03?o0004<ol000<0000co`0co`000S?o0080000Aoooo00?o
09Woooooool0Toooo`00GOooo`040000oooo000000002c?o00040000<ol0<ol0<ol00P0000Dco`00
0`000?ooooooo`0@oooo00?o09Woooooool0Toooo`00GOooo`040000oooooooo000023?o00040000
<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?ooooooo`0@oooo00?o09Woooooool0Tooo
o`00G_ooo`<00008<ol0100000<co`03000013?o00030000oooooooo013oool00ol0VOooooooo`2C
oooo001Poooo00<0000co`0co`0053?o0080000Aoooo00?o09Woooooool0Toooo`00H?ooo`030000
<ol0<ol001@co`000`000?ooooooo`0@oooo00?o09Woooooool0Toooo`00HOooo`030000<ol0<ol0
01<co`000`000?ooooooo`0@oooo00?o09Woooooool0Toooo`00HOooo`030000<ol0<ol001<co`00
0`000?ooooooo`0@oooo00?o09Woooooool0Toooo`00HOooo`030000<ol0<ol001<co`0200004Ooo
o`03o`2Ioooooooo09?oool0067oool00`0003?o03?o000C<ol000<0003oooooool04?ooo`03o`2I
oooooooo09?oool006;oool00`0003?o03?o000B<ol000<0003oooooool04?ooo`03o`2Ioooooooo
09?oool006;oool00`0003?o03?o000B<ol000<0003oooooool04?ooo`03o`2Ioooooooo09?oool0
06;oool00`0003?o03?o000B<ol00P00017oool00ol0VOooooooo`2Coooo001Roooo00<0000co`0c
o`004S?o00030000oooooooo013oool00ol0VOooooooo`2Coooo001Soooo00<0000co`0co`004C?o
00030000oooooooo013oool00ol0VOooooooo`2Coooo001Soooo00<0000co`0co`004C?o00030000
oooooooo013oool00ol0VOooooooo`2Coooo001Soooo00<0000co`0co`004C?o0080000Aoooo00?o
09Woooooool0Toooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`0@oooo00?o09Wooooo
ool0Toooo`00Hoooo`030000<ol0<ol000Tco`0500000c?o00030000oooooooo013oool00ol0VOoo
ooooo`2Coooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol000<co`000`000?ooooooo`0@
oooo00?o09Woooooool0Toooo`00I?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol00P00
017oool00ol0VOooooooo`2Coooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o
00030000<ol0<ol000<co`2Yoooo001Toooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001U
oooo4S?o0:Woool006GooolB<ol00_ooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001U
oooo4S?o0003oooo0000oooo00Woool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00IOoo
oa8co`000oooo`000?ooo`03oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000ooo
o`<00004oooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`02oooo00@0003ooooo
ool00004oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00IOoooa8co`000`000?ooooooo`02oooo00<0003ooooo
ool04oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool0
06KooolA<ol000Coool0003oooooool500004_ooo`040000oooooooo00002?ooo`<00004oooo00<0
003oooooool0N?ooo`00I_oooa4co`000oooo`000?ooo`02oooo00<0003oooooool04oooo`040000
oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001Voooo4C?o00;oool0
0`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo07Woool006KooolA<ol0ZOoo
o`00I_oooa4co`2Yoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49012 .30902 L
.49468 .30902 L
.49719 .30902 L
.49842 .30902 L
.49955 .30902 L
s
.49955 .30902 m
.49968 .61803 L
s
0 .4 1 r
.02381 .38978 m
.06244 .41667 L
.08255 .43405 L
.0932 .44436 L
.10458 .45634 L
.11009 .46253 L
.11531 .46861 L
.11758 .47134 L
.11872 .47273 L
.11999 .47275 L
.12064 .47249 L
.12135 .47221 L
.12263 .47169 L
.12507 .47068 L
.14415 .46218 L
.18538 .43927 L
.22508 .40972 L
.26328 .37196 L
.28459 .34572 L
.29466 .33175 L
.30392 .3179 L
.30636 .31409 L
.30863 .31046 L
.30977 .30902 L
.311 .30902 L
.3117 .30902 L
.31236 .30902 L
.3136 .30902 L
.31486 .30902 L
.3155 .30902 L
.31621 .30902 L
.31745 .30902 L
.31862 .30902 L
.31928 .30902 L
.31999 .30902 L
.32124 .30902 L
.32194 .30902 L
.32259 .30902 L
.32331 .30902 L
.32407 .30902 L
.32535 .30902 L
.32653 .30902 L
.32782 .30902 L
.32847 .30902 L
.32919 .30902 L
.33039 .30902 L
.33168 .30902 L
.3329 .30902 L
.33402 .30902 L
.33517 .30902 L
Mistroke
.33623 .30902 L
.3375 .30902 L
.33865 .30902 L
.33975 .30902 L
.34078 .30902 L
.34187 .30902 L
.34305 .30902 L
.3443 .30902 L
.34543 .30902 L
.34675 .30902 L
.34798 .30902 L
.34913 .30902 L
.35019 .30902 L
.35135 .30902 L
.35258 .30902 L
.35382 .30902 L
.35451 .30902 L
.35515 .30902 L
.35632 .30902 L
.35755 .30902 L
.35821 .30902 L
.35891 .30902 L
.36017 .30902 L
.36094 .30902 L
.36167 .30902 L
.36232 .30902 L
.36303 .30902 L
.36434 .30902 L
.36557 .30902 L
.36628 .30902 L
.36692 .30902 L
.36766 .30902 L
.36836 .30902 L
.36904 .30902 L
.36977 .30902 L
.37106 .30902 L
.37178 .30902 L
.37246 .30902 L
.3732 .30902 L
.374 .30902 L
.37523 .30902 L
.37592 .30902 L
.37657 .30902 L
.37788 .30902 L
.37861 .30902 L
.37927 .30902 L
.38047 .30902 L
.38176 .30902 L
.38298 .30902 L
.38411 .30902 L
Mistroke
.38536 .30902 L
.38654 .30902 L
.38761 .30902 L
.38877 .30902 L
.39003 .30902 L
.39073 .30902 L
.39137 .30902 L
.39262 .30902 L
.39379 .30902 L
.39489 .30902 L
.39605 .30902 L
.39705 .30902 L
.39814 .30902 L
.39932 .30902 L
.40058 .30902 L
.40176 .30902 L
.40285 .30902 L
.40413 .30902 L
.40477 .30902 L
.40549 .30902 L
.40793 .30902 L
.41345 .30902 L
.42348 .30902 L
.4637 .30902 L
.50241 .30902 L
.54357 .30902 L
.58321 .30902 L
.62134 .30902 L
.66192 .30902 L
.70099 .30902 L
.74251 .30902 L
.78251 .30902 L
.82099 .30902 L
.86193 .30902 L
.90136 .30902 L
.93926 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`001@0003?o03?o03?o001Vo`05
<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003ooooo
ool01oooo`030000oooooooo00;oool00ol0VOooooooo`02oooo00<0003oooooool01_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo00Goool:00007c?o00030000<ol0<ol001@co`000`1Voc?o
03?o000F<ol000<0003oooooool05Oooo`03o`2Ioooooooo01Goool00`000?ooooooo`0]oooo00<0
003oooooool0;_ooo`030000oooooooo01Goool002Soool60000;c?o000306Ko<ol0<ol001Lco`00
0`000?ooooooo`0Eoooo00?o09Woooooool0S_ooo`00;_ooo`D0000Y<ol000<0I_lco`0co`0063?o
0080000Foooo00?o09Woooooool0S_ooo`00<oooo`@0000U<ol000<0I_lco`0co`0063?o00030000
oooooooo01Goool00ol0VOooooooo`2>oooo000goooo0P00028co`000`1Voc?o03?o000I<ol000<0
003oooooool05Oooo`03o`2Ioooooooo08koool003Woool300007S?o000306Ko<ol0<ol001Xco`00
0`000?ooooooo`0Eoooo00?o09Woooooool0S_ooo`00??ooo`80000K<ol000<0I_lco`0co`006c?o
0080000Foooo00?o09Woooooool0S_ooo`00?_ooo`80000I<ol000<0I_lco`0co`006c?o00030000
oooooooo01Goool00ol0VOooooooo`2>oooo0010oooo0P0001Hco`000`1Voc?o03?o000L<ol000<0
003oooooool05Oooo`03o`2Ioooooooo08koool004;oool200004c?o000306Ko<ol0<ol001dco`00
0`000?ooooooo`0Eoooo00?o09Woooooool0S_ooo`00A?ooo`80000@<ol000<0I_lco`0co`007S?o
0080000Foooo00?o09Woooooool0S_ooo`00A_ooo`030000<ol0<ol000`co`000`1Voc?o03?o000O
<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool004Ooool00`0003?o03?o000;<ol000<0
I_lco`0co`007c?o00030000oooooooo01Goool00ol0VOooooooo`2>oooo0018oooo00<0000co`0c
o`002C?o000306Ko<ol0<ol0020co`000`000?ooooooo`0Eoooo00?o09Woooooool0S_ooo`00BOoo
o`030000<ol0<ol000Lco`000`1Voc?o03?o000Q<ol00P0001Koool00ol0VOooooooo`2>oooo001:
oooo00<0000co`0co`001C?o000306Ko<ol0<ol0028co`000`000?ooooooo`0Eoooo00?o09Wooooo
ool0S_ooo`00Boooo`030000<ol0<ol000<co`000`1Voc?o03?o000:<ol00P0000@co`0200000c?o
00@00003<ol00P0000Dco`000`000?ooooooo`0Eoooo00?o09Woooooool0S_ooo`00C?ooo`050000
<ol0<ol0<ol006Ko00`co`00100003?o03?o000000Pco`000`0003?o03?o0003<ol000@0000co`0c
o`000004<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool004goool00`0003?o001Vo`0=
<ol000@0000co`0co`000009<ol000<0000co`0co`001C?o00030000<ol0<ol0008co`0200005_oo
o`03o`2Ioooooooo08koool001Koool00`1Vooooooooo`0eoooo00<0I_lco`0co`0033?o00040000
<ol0<ol000002S?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo01Goool00ol0VOoo
ooooo`2>oooo000Goooo0P1VocCoool00`1Vooooo`00000=<ol000@0000co`0co`000008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo01Goool00ol0VOooooooo`2>
oooo000Ioooo00<0I_ooooooool0<?ooo`0406Kooooooooo00003S?o0080000:<ol00P0000@co`03
000013?o00030000oooooooo01Goool00ol0VOooooooo`2>oooo000Joooo00<0I_ooooooool0;_oo
o`0306Kooooooooo00;oool00`0003?o03?o000T<ol00P0001Koool00ol0VOooooooo`2>oooo000K
oooo0P1Vobgoool00`1Vooooooooo`04oooo00<0000co`0co`008c?o00030000oooooooo01Goool0
0ol0VOooooooo`2>oooo000Moooo00<0I_ooooooool0:Oooo`0306Kooooooooo00Koool00`0003?o
03?o000R<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool001koool206Ko9oooo`80I_l9
oooo00<0000co`0co`008S?o00030000oooooooo01Goool00ol0VOooooooo`2>oooo000Poooo00<0
I_ooooooool08oooo`0306Kooooooooo00[oool00`0003?o03?o000Q<ol00P0001Koool00ol0VOoo
ooooo`2>oooo000Qoooo00<0I_ooooooool08Oooo`0306Kooooooooo00_oool00`0003?o03?o000Q
<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool002;oool206Ko7oooo`80I_l?oooo00<0
000co`0co`0083?o00030000oooooooo01Goool00ol0VOooooooo`2>oooo000Toooo00<0I_oooooo
ool06oooo`0306Kooooooooo00ooool00`0003?o03?o000P<ol000<0003oooooool05Oooo`03o`2I
oooooooo08koool002Goool00`1Vooooooooo`0Hoooo0P1Voa?oool00`0003?o03?o000O<ol00P00
01Koool00ol0VOooooooo`2>oooo000Voooo00<0I_ooooooool05_ooo`0306Kooooooooo01?oool0
0`0003?o03?o000O<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool002Ooool00`1Voooo
ooooo`0Coooo0P1VoaOoool00`0003?o03?o000N<ol000<0003oooooool05Oooo`03o`2Ioooooooo
08koool002Soool00`1Vooooooooo`0@oooo0P1VoaWoool00`0003?o03?o000N<ol000<0003ooooo
ool05Oooo`03o`2Ioooooooo08koool002Woool00`1Vooooooooo`0>oooo00<0I_ooooooool06_oo
o`030000<ol0<ol001dco`0200005_ooo`03o`2Ioooooooo08koool002[oool00`1Vooooooooo`0;
oooo0P1Voagoool00`0003?o03?o000M<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool0
02_oool00`1Vooooooooo`08oooo0P1Vob3oool00`0003?o03?o0009<ol00P0000@co`02000013?o
00800005<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool002coool00`1Vooooooooo`05
oooo0P1Vob;oool00`0003?o03?o0008<ol000@0000co`0co`000008<ol000@0000co`0co`000004
<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool002coool00`1Vooooooooo`03oooo0P1V
obGoool00`0003?o03?o0007<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o0080000F
oooo00?o09Woooooool0S_ooo`00;Oooo`0306Kooooooooo0080I_lWoooo00<0000co`0co`001c?o
00040000<ol0<ol000002C?o00800005<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool0
02koool206Ko:Oooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`000`0003?o03?o0004
<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool005[oool00`0003?o03?o0007<ol00P00
00Xco`03000013?o00030000oooooooo01Goool00ol0VOooooooo`2>oooo001Joooo00<0000co`0c
o`006S?o0080000Foooo00?o09Woooooool0S_ooo`00F_ooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0Eoooo00?o09Woooooool0S_ooo`00Foooo`030000<ol0<ol001Tco`000`000?ooooooo`0E
oooo00?o09Woooooool0S_ooo`00Foooo`030000<ol0<ol001Tco`0200005_ooo`03o`2Ioooooooo
08koool005_oool00`0003?o03?o000I<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool0
05coool00`0003?o03?o000H<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool005coool0
0`0003?o03?o000H<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool005coool00`0003?o
03?o000H<ol00P0001Koool00ol0VOooooooo`2>oooo001Moooo00<0000co`0co`005c?o00030000
oooooooo01Goool00ol0VOooooooo`2>oooo001Moooo00<0000co`0co`005c?o00030000oooooooo
01Goool00ol0VOooooooo`2>oooo001Moooo00<0000co`0co`005c?o00030000oooooooo01Goool0
0ol0VOooooooo`2>oooo001Noooo00<0000co`0co`005S?o0080000Foooo00?o09Woooooool0S_oo
o`00G_ooo`030000<ol0<ol001Hco`000`000?ooooooo`0Eoooo00?o09Woooooool0S_ooo`00G_oo
o`800004<ol00P0000Dco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`0Eoooo00?o
09Woooooool0S_ooo`00GOooo`040000oooo000000002S?o00050000<ol0<ol0<ol00000008co`00
0`0003?o03?o0002<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool005goool010000?oo
o`00000000Xco`000`0003?o03?o0004<ol000<0000co`0co`000S?o0080000Foooo00?o09Wooooo
ool0S_ooo`00GOooo`040000oooo000000002c?o00040000<ol0<ol0<ol00P0000Dco`000`000?oo
ooooo`0Eoooo00?o09Woooooool0S_ooo`00GOooo`040000oooooooo000023?o00040000<ol0<ol0
00000c?o00030000<ol0<ol000@co`000`000?ooooooo`0Eoooo00?o09Woooooool0S_ooo`00G_oo
o`<00008<ol0100000<co`03000013?o00030000oooooooo01Goool00ol0VOooooooo`2>oooo001P
oooo00<0000co`0co`0053?o0080000Foooo00?o09Woooooool0S_ooo`00H?ooo`030000<ol0<ol0
01@co`000`000?ooooooo`0Eoooo00?o09Woooooool0S_ooo`00HOooo`030000<ol0<ol001<co`00
0`000?ooooooo`0Eoooo00?o09Woooooool0S_ooo`00HOooo`030000<ol0<ol001<co`000`000?oo
ooooo`0Eoooo00?o09Woooooool0S_ooo`00HOooo`030000<ol0<ol001<co`0200005_ooo`03o`2I
oooooooo08koool0067oool00`0003?o03?o000C<ol000<0003oooooool05Oooo`03o`2Ioooooooo
08koool006;oool00`0003?o03?o000B<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool0
06;oool00`0003?o03?o000B<ol000<0003oooooool05Oooo`03o`2Ioooooooo08koool006;oool0
0`0003?o03?o000B<ol00P0001Koool00ol0VOooooooo`2>oooo001Roooo00<0000co`0co`004S?o
00030000oooooooo01Goool00ol0VOooooooo`2>oooo001Soooo00<0000co`0co`004C?o00030000
oooooooo01Goool00ol0VOooooooo`2>oooo001Soooo00<0000co`0co`004C?o00030000oooooooo
01Goool00ol0VOooooooo`2>oooo001Soooo00<0000co`0co`004C?o0080000Foooo00?o09Wooooo
ool0S_ooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`0Eoooo00?o09Woooooool0S_oo
o`00Hoooo`030000<ol0<ol000Tco`0500000c?o00030000oooooooo01Goool00ol0VOooooooo`2>
oooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol000<co`000`000?ooooooo`0Eoooo00?o
09Woooooool0S_ooo`00I?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol00P0001Koool0
0ol0VOooooooo`2>oooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000
<ol0<ol000<co`2Yoooo001Toooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o
0:Woool006GooolB<ol00_ooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Uoooo4S?o
0003oooo0000oooo00Woool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00IOoooa8co`00
0oooo`000?ooo`03oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004
oooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`02oooo00@0003oooooool00004
oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00IOoooa8co`000`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001Voooo4C?o
0004oooo0000oooooooo1@0001;oool010000?ooooooo`0000Woool200001?ooo`030000oooooooo
07Soool006KooolA<ol000?oool0003oool00_ooo`030000oooooooo01?oool010000?ooooooo`00
00Woool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00I_oooa4co`02oooo00<0003ooooo
ool05oooo`80000:oooo0`0000;oool00`000?ooooooo`1ioooo001Voooo4C?o0:Woool006KooolA
<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.5095 .30902 L
.51441 .30902 L
.5168 .30902 L
.51784 .30902 L
.51896 .30902 L
s
.51896 .30902 m
.51909 .61803 L
s
0 .4 1 r
.02381 .37177 m
.06244 .39266 L
.10458 .42349 L
.11448 .43225 L
.12507 .44239 L
.1302 .4476 L
.13273 .45024 L
.13506 .45272 L
.13718 .45501 L
.13824 .45594 L
.13942 .45532 L
.14415 .45277 L
.18221 .42878 L
.2225 .39496 L
.26127 .3514 L
.28098 .32387 L
.28638 .31556 L
.2878 .31331 L
.28934 .31085 L
.29005 .30971 L
.2908 .30902 L
.29143 .30902 L
.29213 .30902 L
.29284 .30902 L
.29349 .30902 L
.29419 .30902 L
.29494 .30902 L
.29564 .30902 L
.29629 .30902 L
.29757 .30902 L
.2987 .30902 L
.29995 .30902 L
.30126 .30902 L
.30249 .30902 L
.30369 .30902 L
.30481 .30902 L
.30604 .30902 L
.30735 .30902 L
.30801 .30902 L
.30873 .30902 L
.31003 .30902 L
.31129 .30902 L
.31246 .30902 L
.31355 .30902 L
.31457 .30902 L
.3157 .30902 L
.3169 .30902 L
.31816 .30902 L
.31936 .30902 L
.32043 .30902 L
Mistroke
.3216 .30902 L
.32227 .30902 L
.323 .30902 L
.32432 .30902 L
.3256 .30902 L
.32678 .30902 L
.32806 .30902 L
.32878 .30902 L
.32946 .30902 L
.33018 .30902 L
.33083 .30902 L
.33158 .30902 L
.33229 .30902 L
.33349 .30902 L
.33476 .30902 L
.33584 .30902 L
.33704 .30902 L
.33951 .30902 L
.34081 .30902 L
.34154 .30902 L
.3422 .30902 L
.34352 .30902 L
.34476 .30902 L
.3459 .30902 L
.34713 .30902 L
.34845 .30902 L
.34911 .30902 L
.34983 .30902 L
.35112 .30902 L
.35232 .30902 L
.35352 .30902 L
.35466 .30902 L
.35568 .30902 L
.35679 .30902 L
.358 .30902 L
.35928 .30902 L
.3604 .30902 L
.36159 .30902 L
.36287 .30902 L
.36405 .30902 L
.36531 .30902 L
.36603 .30902 L
.3667 .30902 L
.36791 .30902 L
.36902 .30902 L
.3703 .30902 L
.3715 .30902 L
.37213 .30902 L
.37283 .30902 L
.37355 .30902 L
Mistroke
.37423 .30902 L
.37545 .30902 L
.37676 .30902 L
.37749 .30902 L
.37828 .30902 L
.37903 .30902 L
.37973 .30902 L
.38105 .30902 L
.38179 .30902 L
.38246 .30902 L
.38366 .30902 L
.38478 .30902 L
.38602 .30902 L
.38734 .30902 L
.388 .30902 L
.38872 .30902 L
.39003 .30902 L
.39131 .30902 L
.39249 .30902 L
.39359 .30902 L
.39462 .30902 L
.39575 .30902 L
.39697 .30902 L
.39817 .30902 L
.39944 .30902 L
.40053 .30902 L
.40172 .30902 L
.40239 .30902 L
.40312 .30902 L
.40382 .30902 L
.40445 .30902 L
.40566 .30902 L
.40694 .30902 L
.41251 .30902 L
.42254 .30902 L
.46045 .30902 L
.50081 .30902 L
.53965 .30902 L
.58095 .30902 L
.62073 .30902 L
.659 .30902 L
.69971 .30902 L
.73891 .30902 L
.78057 .30902 L
.82071 .30902 L
.85933 .30902 L
.90041 .30902 L
.93997 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000O<ol000<0000co`0co`003c?o000306Ko<ol0<ol001/co`000`000?ooooooo`0J
oooo00?o09Woooooool04?ooo`030000oooooooo02goool00`000?ooooooo`0^oooo00<0003ooooo
ool05Oooo`00:?ooo`H0000Z<ol000<0I_lco`0co`0073?o00030000oooooooo01[oool00ol0VOoo
ooooo`29oooo000^oooo1@0002@co`000`1Voc?o03?o000M<ol00P0001_oool00ol0VOooooooo`29
oooo000coooo100001lco`000`1Voc?o03?o000N<ol000<0003oooooool06_ooo`03o`2Ioooooooo
08Woool003Ooool200007C?o000306Ko<ol0<ol001hco`000`000?ooooooo`0Joooo00?o09Wooooo
ool0ROooo`00>Oooo`<0000I<ol000<0I_lco`0co`007c?o00030000oooooooo01[oool00ol0VOoo
ooooo`29oooo000loooo0P0001Hco`000`1Voc?o03?o000P<ol00P0001_oool00ol0VOooooooo`29
oooo000noooo0P0001<co`000`1Voc?o03?o000Q<ol000<0003oooooool06_ooo`03o`2Ioooooooo
08Woool0043oool200004C?o000306Ko<ol0<ol0024co`000`000?ooooooo`0Joooo00?o09Wooooo
ool0ROooo`00@_ooo`80000><ol000<0I_lco`0co`008S?o00030000oooooooo01[oool00ol0VOoo
ooooo`29oooo0014oooo0P0000/co`000`1Voc?o03?o000S<ol00P0001_oool00ol0VOooooooo`29
oooo0016oooo00<0000co`0co`001c?o000306Ko<ol0<ol002@co`000`000?ooooooo`0Joooo00?o
09Woooooool0ROooo`00Aoooo`030000<ol0<ol000Hco`000`1Voc?o03?o000T<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo08Woool004Soool00`0003?o03?o0004<ol000<0I_lco`0co`009C?o
00030000oooooooo01[oool00ol0VOooooooo`29oooo000Foooo00<0I_ooooooool0<?ooo`030000
<ol0<ol0008co`000`1Voc?o03?o000V<ol00P0001_oool00ol0VOooooooo`29oooo000Goooo0P1V
oc7oool0100003?o03?o001VobTco`000`000?ooooooo`0Joooo00?o09Woooooool0ROooo`006Ooo
o`80I_l`oooo00<00000I_lco`0043?o00800004<ol00P0000<co`0400000c?o00800005<ol000<0
003oooooool06_ooo`03o`2Ioooooooo08Woool001_oool00`1Vooooooooo`0]oooo00<0I_l0000c
o`003c?o00040000<ol0<ol0000023?o00030000<ol0<ol000<co`00100003?o03?o000000@co`00
0`000?ooooooo`0Joooo00?o09Woooooool0ROooo`007?ooo`80I_l]oooo00<0I_ooool000003c?o
00040000<ol0<ol000002C?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol00P0001_oool0
0ol0VOooooooo`29oooo000Noooo0P1Vob[oool01@1Vooooooooooooo`00000><ol000@0000co`0c
o`00000:<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool06_ooo`03o`2Ioooooooo
08Woool0023oool00`1Vooooooooo`0Voooo00<0I_ooooooool00oooo`030000<ol0<ol000/co`00
100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo08Woool0027oool206Ko9Oooo`0306Kooooooooo00Coool00`0003?o
03?o000<<ol00P0000Xco`02000013?o00<00004<ol000<0003oooooool06_ooo`03o`2Ioooooooo
08Woool002?oool00`1Vooooooooo`0Poooo0P1Vo`Soool00`0003?o03?o000T<ol00P0001_oool0
0ol0VOooooooo`29oooo000Toooo0P1Voaooool00`1Vooooooooo`09oooo00<0000co`0co`008c?o
00030000oooooooo01[oool00ol0VOooooooo`29oooo000Voooo0P1Voacoool00`1Vooooooooo`0;
oooo00<0000co`0co`008S?o00030000oooooooo01[oool00ol0VOooooooo`29oooo000Xoooo00<0
I_ooooooool06?ooo`0306Kooooooooo00coool00`0003?o03?o000R<ol000<0003oooooool06_oo
o`03o`2Ioooooooo08Woool002Woool206Ko5oooo`0306Kooooooooo00koool00`0003?o03?o000Q
<ol00P0001_oool00ol0VOooooooo`29oooo000[oooo00<0I_ooooooool04_ooo`80I_lAoooo00<0
000co`0co`008C?o00030000oooooooo01[oool00ol0VOooooooo`29oooo000/oooo00<0I_oooooo
ool04?ooo`0306Kooooooooo01;oool00`0003?o03?o000P<ol000<0003oooooool06_ooo`03o`2I
oooooooo08Woool002coool00`1Vooooooooo`0?oooo00<0I_ooooooool04oooo`030000<ol0<ol0
020co`000`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00;Oooo`0306Kooooooooo00coool2
06Ko5oooo`030000<ol0<ol001lco`0200006oooo`03o`2Ioooooooo08Woool002koool206Ko2ooo
o`0306Kooooooooo01Ooool00`0003?o03?o000O<ol000<0003oooooool06_ooo`03o`2Ioooooooo
08Woool0033oool00`1Vooooooooo`06oooo0P1Voa_oool00`0003?o03?o000N<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo08Woool0033oool00`1Vooooooooo`05oooo00<0I_ooooooool06ooo
o`030000<ol0<ol001hco`000`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00<Oooo`80I_l3
oooo0P1Voaooool00`0003?o03?o000M<ol00P0001_oool00ol0VOooooooo`29oooo000boooo0P1V
o`03oooo06Kooooo023oool00`0003?o03?o000M<ol000<0003oooooool06_ooo`03o`2Ioooooooo
08Woool003?oool206Ko8oooo`030000<ol0<ol000Tco`02000013?o00800004<ol00P0000Dco`00
0`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00F?ooo`030000<ol0<ol000Pco`00100003?o
03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`0Joooo00?o09Woooooool0ROoo
o`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`000`0003?o03?o0002<ol00P00
01_oool00ol0VOooooooo`29oooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o
00800005<ol000<0003oooooool06_ooo`03o`2Ioooooooo08Woool005Woool00`0003?o03?o0007
<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000oooooooo01[oool00ol0VOoo
ooooo`29oooo001Joooo00<0000co`0co`001c?o0080000:<ol00`0000@co`000`000?ooooooo`0J
oooo00?o09Woooooool0ROooo`00F_ooo`030000<ol0<ol001Xco`0200006oooo`03o`2Ioooooooo
08Woool005[oool00`0003?o03?o000J<ol000<0003oooooool06_ooo`03o`2Ioooooooo08Woool0
05_oool00`0003?o03?o000I<ol000<0003oooooool06_ooo`03o`2Ioooooooo08Woool005_oool0
0`0003?o03?o000I<ol00P0001_oool00ol0VOooooooo`29oooo001Koooo00<0000co`0co`006C?o
00030000oooooooo01[oool00ol0VOooooooo`29oooo001Loooo00<0000co`0co`0063?o00030000
oooooooo01[oool00ol0VOooooooo`29oooo001Loooo00<0000co`0co`0063?o00030000oooooooo
01[oool00ol0VOooooooo`29oooo001Loooo00<0000co`0co`0063?o0080000Koooo00?o09Wooooo
ool0ROooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`0Joooo00?o09Woooooool0ROoo
o`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00GOoo
o`030000<ol0<ol001Lco`000`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00G_ooo`030000
<ol0<ol001Hco`0200006oooo`03o`2Ioooooooo08Woool005koool00`0003?o03?o000F<ol000<0
003oooooool06_ooo`03o`2Ioooooooo08Woool005koool2000013?o00800005<ol000<0000co`0c
o`000S?o00800005<ol000<0003oooooool06_ooo`03o`2Ioooooooo08Woool005goool010000?oo
o`00000000Xco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000oooooooo
01[oool00ol0VOooooooo`29oooo001Moooo00@0003oool00000000:<ol000<0000co`0co`0013?o
00030000<ol0<ol0008co`0200006oooo`03o`2Ioooooooo08Woool005goool010000?ooo`000000
00/co`00100003?o03?o03?o00800005<ol000<0003oooooool06_ooo`03o`2Ioooooooo08Woool0
05goool010000?ooooooo`0000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0
003oooooool06_ooo`03o`2Ioooooooo08Woool005koool3000023?o00@00003<ol00`0000@co`00
0`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00H?ooo`030000<ol0<ol001@co`0200006ooo
o`03o`2Ioooooooo08Woool0063oool00`0003?o03?o000D<ol000<0003oooooool06_ooo`03o`2I
oooooooo08Woool0067oool00`0003?o03?o000C<ol000<0003oooooool06_ooo`03o`2Ioooooooo
08Woool0067oool00`0003?o03?o000C<ol000<0003oooooool06_ooo`03o`2Ioooooooo08Woool0
067oool00`0003?o03?o000C<ol00P0001_oool00ol0VOooooooo`29oooo001Qoooo00<0000co`0c
o`004c?o00030000oooooooo01[oool00ol0VOooooooo`29oooo001Roooo00<0000co`0co`004S?o
00030000oooooooo01[oool00ol0VOooooooo`29oooo001Roooo00<0000co`0co`004S?o00030000
oooooooo01[oool00ol0VOooooooo`29oooo001Roooo00<0000co`0co`004S?o0080000Koooo00?o
09Woooooool0ROooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`0Joooo00?o09Wooooo
ool0ROooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`0Joooo00?o09Woooooool0ROoo
o`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00Hooo
o`030000<ol0<ol0014co`0200006oooo`03o`2Ioooooooo08Woool006?oool00`0003?o03?o000A
<ol000<0003oooooool06_ooo`03o`2Ioooooooo08Woool006?oool00`0003?o03?o0009<ol01@00
00<co`000`000?ooooooo`0Joooo00?o09Woooooool0ROooo`00I?ooo`030000<ol0<ol000Xco`00
0`0003?o03?o0003<ol000<0003oooooool06_ooo`03o`2Ioooooooo08Woool006Coool00`0003?o
03?o000:<ol000<0000co`0co`000c?o0080000Koooo00?o09Woooooool0ROooo`00I?ooo`dco`00
0`0003?o03?o0003<ol0ZOooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo``co`02
00001C?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o00;oool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00IOoooa8co`000oooo`000?ooo`09oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool006GooolB<ol000?oool0003oool00oooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000Goool300000_ooo`030000oooooooo07Soool006GooolB
<ol000?oool0003oool00_ooo`040000oooooooo00001?ooo`030000oooooooo00Coool400000ooo
o`040000oooooooo00002oooo`050000oooooooooooo000007[oool006GooolB<ol000<0003ooooo
ool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool500000oooo`030000oooooooo
07Ooool006KooolA<ol000Coool0003oooooool500004_ooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07Soool006KooolA<ol000?oool0003oool00_ooo`030000
oooooooo01?oool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool0N?oo
o`00I_oooa4co`02oooo00<0003oooooool05oooo`80000;oooo0P0000;oool00`000?ooooooo`1i
oooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.51896 .30902 L
.52455 .30902 L
.52986 .30902 L
.53463 .30902 L
.53594 .30902 L
.53666 .30902 L
.53733 .30902 L
s
.53733 .30902 m
.53746 .61803 L
s
0 .4 1 r
.02381 .35501 m
.06244 .37032 L
.10458 .39292 L
.12507 .40677 L
.13506 .41435 L
.14415 .42176 L
.14868 .42564 L
.15107 .42775 L
.1536 .43002 L
.15581 .43204 L
.15707 .4332 L
.15825 .4325 L
.16254 .42946 L
.18221 .41423 L
.22098 .37693 L
.24069 .35343 L
.2511 .33954 L
.2622 .32346 L
.26777 .31488 L
.26909 .31277 L
.27049 .31053 L
.27169 .30902 L
.273 .30902 L
.27418 .30902 L
.27544 .30902 L
.27662 .30902 L
.27771 .30902 L
.27896 .30902 L
.27967 .30902 L
.28032 .30902 L
.28152 .30902 L
.2828 .30902 L
.28397 .30902 L
.28505 .30902 L
.28624 .30902 L
.28748 .30902 L
.28857 .30902 L
.28958 .30902 L
.2907 .30902 L
.29188 .30902 L
.29318 .30902 L
.29391 .30902 L
.29459 .30902 L
.29583 .30902 L
.29714 .30902 L
.29831 .30902 L
.29941 .30902 L
.30062 .30902 L
.30191 .30902 L
.3026 .30902 L
Mistroke
.30325 .30902 L
.30446 .30902 L
.30576 .30902 L
.3065 .30902 L
.30717 .30902 L
.3083 .30902 L
.30954 .30902 L
.31084 .30902 L
.31204 .30902 L
.31273 .30902 L
.31348 .30902 L
.31418 .30902 L
.31484 .30902 L
.31607 .30902 L
.31738 .30902 L
.31869 .30902 L
.31942 .30902 L
.32009 .30902 L
.32085 .30902 L
.32164 .30902 L
.32233 .30902 L
.32309 .30902 L
.32374 .30902 L
.32445 .30902 L
.32573 .30902 L
.32698 .30902 L
.32813 .30902 L
.32937 .30902 L
.33008 .30902 L
.33074 .30902 L
.33144 .30902 L
.33208 .30902 L
.33281 .30902 L
.33351 .30902 L
.33467 .30902 L
.33591 .30902 L
.33697 .30902 L
.33814 .30902 L
.33939 .30902 L
.3401 .30902 L
.34074 .30902 L
.34194 .30902 L
.34319 .30902 L
.34442 .30902 L
.34511 .30902 L
.34576 .30902 L
.34693 .30902 L
.34818 .30902 L
.3493 .30902 L
.35034 .30902 L
Mistroke
.35149 .30902 L
.35272 .30902 L
.35402 .30902 L
.35476 .30902 L
.35545 .30902 L
.3567 .30902 L
.3574 .30902 L
.35804 .30902 L
.35924 .30902 L
.36055 .30902 L
.36178 .30902 L
.36291 .30902 L
.36397 .30902 L
.36511 .30902 L
.36618 .30902 L
.36716 .30902 L
.36831 .30902 L
.36956 .30902 L
.37074 .30902 L
.37184 .30902 L
.37296 .30902 L
.37401 .30902 L
.37517 .30902 L
.37641 .30902 L
.37764 .30902 L
.37894 .30902 L
.38005 .30902 L
.38127 .30902 L
.38259 .30902 L
.38381 .30902 L
.38444 .30902 L
.38514 .30902 L
.38588 .30902 L
.38656 .30902 L
.3878 .30902 L
.38849 .30902 L
.38914 .30902 L
.39029 .30902 L
.39155 .30902 L
.39278 .30902 L
.3939 .30902 L
.39519 .30902 L
.3964 .30902 L
.39752 .30902 L
.39856 .30902 L
.39969 .30902 L
.40089 .30902 L
.4022 .30902 L
.40339 .30902 L
.40405 .30902 L
Mistroke
.40477 .30902 L
.40607 .30902 L
.41089 .30902 L
.42185 .30902 L
.4627 .30902 L
.50204 .30902 L
.53986 .30902 L
.58014 .30902 L
.6189 .30902 L
.66011 .30902 L
.69981 .30902 L
.73799 .30902 L
.77862 .30902 L
.81774 .30902 L
.85931 .30902 L
.89936 .30902 L
.9379 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00040000<ol0<ol0<ol00P1Vo`@co`000`0003?o03?o0007
<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool01@000?ooooooooooool0V@04oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool01Oooo`X0000O<ol000<0000co`0co`002S?o000306Ko<ol0<ol0020co`00
0`000?ooooooo`0Noooo00?o09Woooooool03?ooo`030000oooooooo02goool00`000?ooooooo`0^
oooo00<0003oooooool05Oooo`00:?ooo`H0000U<ol000<0I_lco`0co`008C?o00030000oooooooo
01koool00ol0VOooooooo`25oooo000^oooo1@00020co`000`1Voc?o03?o000Q<ol00P0001ooool0
0ol0VOooooooo`25oooo000coooo100001/co`000`1Voc?o03?o000R<ol000<0003oooooool07_oo
o`03o`2Ioooooooo08Goool003Ooool2000063?o000306Ko<ol0<ol002<co`000`000?ooooooo`0N
oooo00?o09Woooooool0QOooo`00>Oooo`<0000E<ol000<0I_lco`0co`008c?o00030000oooooooo
01koool00ol0VOooooooo`25oooo000loooo0P00018co`000`1Voc?o03?o000T<ol00P0001ooool0
0ol0VOooooooo`25oooo000noooo0P0000lco`000`1Voc?o03?o000U<ol000<0003oooooool07_oo
o`03o`2Ioooooooo08Goool0043oool2000033?o000306Ko<ol0<ol002Hco`000`000?ooooooo`0N
oooo00?o09Woooooool0QOooo`00@_ooo`80000:<ol000<0I_lco`0co`009S?o00030000oooooooo
01koool00ol0VOooooooo`25oooo000Foooo0P1Vobcoool200001c?o000306Ko<ol0<ol002Lco`02
00007oooo`03o`2Ioooooooo08Goool001Soool206Ko;?ooo`030000<ol0<ol000<co`000`1Voc?o
03?o000X<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Goool001[oool306Ko:_ooo`050000
<ol0<ol0<ol006Ko02/co`000`000?ooooooo`0Noooo00?o09Woooooool0QOooo`007Oooo`80I_lY
oooo00<0000co`00I_l0;3?o00030000oooooooo01koool00ol0VOooooooo`25oooo000Ooooo0P1V
obSoool00`00001Voc?o000[<ol00P0001ooool00ol0VOooooooo`25oooo000Qoooo0P1VobKoool0
0`1Vo`0003?o000[<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Goool002?oool206Ko8ooo
o`0406Kooooooooo00004S?o00800004<ol00P0000<co`0400000c?o00800005<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo08Goool002Goool206Ko8?ooo`0306Kooooooooo00;oool00`0003?o
03?o000><ol000@0000co`0co`000008<ol000<0000co`0co`000c?o00040000<ol0<ol0000013?o
00030000oooooooo01koool00ol0VOooooooo`25oooo000Woooo0P1Voagoool00`1Vooooooooo`04
oooo00<0000co`0co`003C?o00040000<ol0<ol000002C?o00030000<ol0<ol000Dco`000`0003?o
03?o0002<ol00P0001ooool00ol0VOooooooo`25oooo000Yoooo0P1Voa[oool00`1Vooooooooo`06
oooo00<0000co`0co`0033?o00040000<ol0<ol000002S?o00030000<ol0<ol0008co`0200001C?o
00030000oooooooo01koool00ol0VOooooooo`25oooo000[oooo00<0I_ooooooool05_ooo`0306Ko
oooooooo00Soool00`0003?o03?o000;<ol000@0000co`0co`000008<ol000@0000co`0co`000003
<ol000<0000co`0co`0013?o00030000oooooooo01koool00ol0VOooooooo`25oooo000/oooo0P1V
oaCoool206Ko2oooo`030000<ol0<ol000`co`0200002S?o00800004<ol00`0000@co`000`000?oo
ooooo`0Noooo00?o09Woooooool0QOooo`00;_ooo`80I_lAoooo00<0I_ooooooool03?ooo`030000
<ol0<ol002@co`0200007oooo`03o`2Ioooooooo08Goool0033oool00`1Vooooooooo`0=oooo00<0
I_ooooooool03_ooo`030000<ol0<ol002<co`000`000?ooooooo`0Noooo00?o09Woooooool0QOoo
o`00<Oooo`0306Kooooooooo00_oool00`1Vooooooooo`0@oooo00<0000co`0co`008S?o00030000
oooooooo01koool00ol0VOooooooo`25oooo000boooo00<0I_ooooooool02Oooo`0306Kooooooooo
017oool00`0003?o03?o000R<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Goool003?oool2
06Ko2?ooo`0306Kooooooooo01?oool00`0003?o03?o000Q<ol00P0001ooool00ol0VOooooooo`25
oooo000eoooo00<0I_ooooooool00oooo`80I_lFoooo00<0000co`0co`008C?o00030000oooooooo
01koool00ol0VOooooooo`25oooo000foooo00D0I_ooooooooooool0I_l06Oooo`030000<ol0<ol0
020co`000`000?ooooooo`0Noooo00?o09Woooooool0QOooo`00=_ooo`80I_l00oooo`1Vooooo`0I
oooo00<0000co`0co`0083?o00030000oooooooo01koool00ol0VOooooooo`25oooo000hoooo00<0
I_ooooooool06_ooo`030000<ol0<ol001lco`0200007oooo`03o`2Ioooooooo08Goool005Goool0
0`0003?o03?o000O<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Goool005Koool00`0003?o
03?o000N<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Goool005Koool00`0003?o03?o000N
<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Goool005Ooool00`0003?o03?o000M<ol00P00
01ooool00ol0VOooooooo`25oooo001Goooo00<0000co`0co`007C?o00030000oooooooo01koool0
0ol0VOooooooo`25oooo001Hoooo00<0000co`0co`002C?o00800004<ol00P0000@co`0200001C?o
00030000oooooooo01koool00ol0VOooooooo`25oooo001Hoooo00<0000co`0co`0023?o00040000
<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000oooooooo01koool00ol0VOooooooo`25
oooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002c?o00030000<ol0<ol0008co`02
00007oooo`03o`2Ioooooooo08Goool005Woool00`0003?o03?o0007<ol000@0000co`0co`000009
<ol00P0000Dco`000`000?ooooooo`0Noooo00?o09Woooooool0QOooo`00FOooo`030000<ol0<ol0
00Lco`00100003?o03?o000000Tco`000`0003?o03?o0004<ol000<0003oooooool07_ooo`03o`2I
oooooooo08Goool005[oool00`0003?o03?o0007<ol00P0000Xco`03000013?o00030000oooooooo
01koool00ol0VOooooooo`25oooo001Joooo00<0000co`0co`006S?o0080000Ooooo00?o09Wooooo
ool0QOooo`00F_ooo`030000<ol0<ol001Xco`000`000?ooooooo`0Noooo00?o09Woooooool0QOoo
o`00Foooo`030000<ol0<ol001Tco`000`000?ooooooo`0Noooo00?o09Woooooool0QOooo`00Fooo
o`030000<ol0<ol001Tco`0200007oooo`03o`2Ioooooooo08Goool005_oool00`0003?o03?o000I
<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Goool005coool00`0003?o03?o000H<ol000<0
003oooooool07_ooo`03o`2Ioooooooo08Goool005coool00`0003?o03?o000H<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo08Goool005coool00`0003?o03?o000H<ol00P0001ooool00ol0VOoo
ooooo`25oooo001Moooo00<0000co`0co`005c?o00030000oooooooo01koool00ol0VOooooooo`25
oooo001Moooo00<0000co`0co`005c?o00030000oooooooo01koool00ol0VOooooooo`25oooo001M
oooo00<0000co`0co`005c?o00030000oooooooo01koool00ol0VOooooooo`25oooo001Noooo00<0
000co`0co`005S?o0080000Ooooo00?o09Woooooool0QOooo`00G_ooo`030000<ol0<ol001Hco`00
0`000?ooooooo`0Noooo00?o09Woooooool0QOooo`00G_ooo`800004<ol00P0000Dco`000`0003?o
03?o0002<ol00P0000Dco`000`000?ooooooo`0Noooo00?o09Woooooool0QOooo`00GOooo`040000
oooo000000002S?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo08Goool005goool010000?ooo`00000000Xco`000`0003?o03?o0004
<ol000<0000co`0co`000S?o0080000Ooooo00?o09Woooooool0QOooo`00GOooo`040000oooo0000
00002c?o00040000<ol0<ol0<ol00P0000Dco`000`000?ooooooo`0Noooo00?o09Woooooool0QOoo
o`00GOooo`040000oooooooo000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`00
0`000?ooooooo`0Noooo00?o09Woooooool0QOooo`00G_ooo`<00008<ol0100000<co`03000013?o
00030000oooooooo01koool00ol0VOooooooo`25oooo001Poooo00<0000co`0co`0053?o0080000O
oooo00?o09Woooooool0QOooo`00H?ooo`030000<ol0<ol001@co`000`000?ooooooo`0Noooo00?o
09Woooooool0QOooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`0Noooo00?o09Wooooo
ool0QOooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`0Noooo00?o09Woooooool0QOoo
o`00HOooo`030000<ol0<ol001<co`0200007oooo`03o`2Ioooooooo08Goool0067oool00`0003?o
03?o000C<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Goool006;oool00`0003?o03?o000B
<ol000<0003oooooool07_ooo`03o`2Ioooooooo08Goool006;oool00`0003?o03?o000B<ol000<0
003oooooool07_ooo`03o`2Ioooooooo08Goool006;oool00`0003?o03?o000B<ol00P0001ooool0
0ol0VOooooooo`25oooo001Roooo00<0000co`0co`004S?o00030000oooooooo01koool00ol0VOoo
ooooo`25oooo001Soooo00<0000co`0co`004C?o00030000oooooooo01koool00ol0VOooooooo`25
oooo001Soooo00<0000co`0co`004C?o00030000oooooooo01koool00ol0VOooooooo`25oooo001S
oooo00<0000co`0co`004C?o0080000Ooooo00?o09Woooooool0QOooo`00Hoooo`030000<ol0<ol0
014co`000`000?ooooooo`0Noooo00?o09Woooooool0QOooo`00Hoooo`030000<ol0<ol000Tco`05
00000c?o00030000oooooooo01koool00ol0VOooooooo`25oooo001Toooo00<0000co`0co`002S?o
00030000<ol0<ol000<co`000`000?ooooooo`0Noooo00?o09Woooooool0QOooo`00I?ooo`030000
<ol0<ol000Xco`000`0003?o03?o0003<ol00P0001ooool00ol0VOooooooo`25oooo001Toooo3C?o
00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo33?o
00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol00_ooo`030000
oooooooo02Soool00`000?ooooooo`1ioooo001Uoooo4S?o0003oooo0000oooo00Woool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`03oooo0P0000Coool0
0`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?ooo`00IOoo
oa8co`000oooo`000?ooo`02oooo00@0003oooooool00004oooo00<0003oooooool01?ooo`@00003
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00IOoo
oa8co`000`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002_ooo`030000
oooooooo00?oool00`000?ooooooo`1goooo001Voooo4C?o0004oooo0000oooooooo1@0001;oool0
10000?ooooooo`0000_oool01@000?ooooooooooo`00001joooo001Voooo4C?o0003oooo0000oooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00I_oooa4co`02oooo00<0003oooooool05oooo`80000:oooo0P0000?oool0
0`000?ooooooo`1ioooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55195 .30902 L
.55338 .30902 L
.55472 .30902 L
.55598 .30902 L
.55669 .30902 L
s
.55669 .30902 m
.55675 .61803 L
s
0 .4 1 r
.02381 .33918 m
.06244 .34922 L
.10458 .36404 L
.14415 .38294 L
.1544 .38883 L
.16408 .39484 L
.1683 .3976 L
.17277 .40062 L
.1739 .4014 L
.17511 .40224 L
.1758 .40273 L
.17643 .40278 L
.17768 .40163 L
.18221 .39736 L
.20178 .37719 L
.22272 .35209 L
.23268 .33868 L
.24331 .32324 L
.24847 .31527 L
.2497 .31332 L
.251 .31124 L
.25212 .30945 L
.25333 .30902 L
.25442 .30902 L
.25559 .30902 L
.2567 .30902 L
.2577 .30902 L
.25886 .30902 L
.26013 .30902 L
.26132 .30902 L
.26243 .30902 L
.26357 .30902 L
.26461 .30902 L
.26576 .30902 L
.26697 .30902 L
.26802 .30902 L
.269 .30902 L
.27008 .30902 L
.27123 .30902 L
.27248 .30902 L
.27319 .30902 L
.27385 .30902 L
.27505 .30902 L
.27632 .30902 L
.27746 .30902 L
.27852 .30902 L
.27969 .30902 L
.28094 .30902 L
.28225 .30902 L
.28347 .30902 L
Mistroke
.28417 .30902 L
.2848 .30902 L
.28553 .30902 L
.28622 .30902 L
.28747 .30902 L
.28862 .30902 L
.28989 .30902 L
.29053 .30902 L
.29122 .30902 L
.29245 .30902 L
.29357 .30902 L
.29486 .30902 L
.29609 .30902 L
.29722 .30902 L
.29826 .30902 L
.2994 .30902 L
.30062 .30902 L
.30176 .30902 L
.30301 .30902 L
.30431 .30902 L
.30552 .30902 L
.30666 .30902 L
.3077 .30902 L
.30889 .30902 L
.31001 .30902 L
.31124 .30902 L
.31254 .30902 L
.31365 .30902 L
.31487 .30902 L
.31618 .30902 L
.31692 .30902 L
.31759 .30902 L
.31889 .30902 L
.32013 .30902 L
.32118 .30902 L
.32233 .30902 L
.32354 .30902 L
.32468 .30902 L
.32573 .30902 L
.3267 .30902 L
.32777 .30902 L
.32889 .30902 L
.33003 .30902 L
.33124 .30902 L
.33239 .30902 L
.33344 .30902 L
.33467 .30902 L
.33536 .30902 L
.336 .30902 L
.33842 .30902 L
Mistroke
.33956 .30902 L
.34081 .30902 L
.34199 .30902 L
.34308 .30902 L
.34435 .30902 L
.34506 .30902 L
.3457 .30902 L
.34694 .30902 L
.3481 .30902 L
.3492 .30902 L
.35037 .30902 L
.35136 .30902 L
.35245 .30902 L
.35361 .30902 L
.35487 .30902 L
.35606 .30902 L
.35716 .30902 L
.35847 .30902 L
.35913 .30902 L
.35986 .30902 L
.36112 .30902 L
.36231 .30902 L
.36299 .30902 L
.3637 .30902 L
.36497 .30902 L
.36568 .30902 L
.36634 .30902 L
.36706 .30902 L
.36783 .30902 L
.36912 .30902 L
.36985 .30902 L
.37052 .30902 L
.37175 .30902 L
.37305 .30902 L
.37415 .30902 L
.37532 .30902 L
.3766 .30902 L
.37779 .30902 L
.37848 .30902 L
.37912 .30902 L
.38033 .30902 L
.38148 .30902 L
.38273 .30902 L
.38387 .30902 L
.38508 .30902 L
.38611 .30902 L
.38724 .30902 L
.38792 .30902 L
.38857 .30902 L
.38977 .30902 L
Mistroke
.39108 .30902 L
.39181 .30902 L
.39249 .30902 L
.39362 .30902 L
.39486 .30902 L
.39616 .30902 L
.39738 .30902 L
.39851 .30902 L
.39974 .30902 L
.40091 .30902 L
.40199 .30902 L
.40306 .30902 L
.40403 .30902 L
.40515 .30902 L
.4062 .30902 L
.4157 .30902 L
.45424 .30902 L
.49523 .30902 L
.5347 .30902 L
.57266 .30902 L
.61308 .30902 L
.65197 .30902 L
.69332 .30902 L
.73315 .30902 L
.77147 .30902 L
.81224 .30902 L
.85149 .30902 L
.88923 .30902 L
.92942 .30902 L
.9681 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000O<ol000<0000co`0co`001C?o0080I_lV<ol000<0003oooooool08oooo`03o`2I
oooooooo00Ooool00`000?ooooooo`0]oooo00<0003oooooool0;_ooo`030000oooooooo01Goool0
02Soool6000083?o000306Ko<ol0<ol002Hco`000`000?ooooooo`0Soooo00?o09Woooooool0P?oo
o`00;_ooo`D0000K<ol000<0I_lco`0co`009S?o0080000Toooo00?o09Woooooool0P?ooo`00<ooo
o`@0000F<ol000<0I_lco`0co`009c?o00030000oooooooo02?oool00ol0VOooooooo`20oooo000g
oooo0P0001<co`000`1Voc?o03?o000X<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool0
03Woool3000043?o000306Ko<ol0<ol002Pco`000`000?ooooooo`0Soooo00?o09Woooooool0P?oo
o`005_ooo`80I_lToooo0P0000dco`000`1Voc?o03?o000Y<ol00P0002Coool00ol0VOooooooo`20
oooo000Hoooo0`1Vob?oool200002S?o000306Ko<ol0<ol002Xco`000`000?ooooooo`0Soooo00?o
09Woooooool0P?ooo`006oooo`@0I_lQoooo0P0000Pco`000`1Voc?o03?o000Z<ol000<0003ooooo
ool08oooo`03o`2Ioooooooo083oool001ooool306Ko8?ooo`800005<ol000<0I_lco`0co`00:c?o
00030000oooooooo02?oool00ol0VOooooooo`20oooo000Roooo101Voakoool200000S?o000306Ko
<ol0<ol002`co`0200009?ooo`03o`2Ioooooooo083oool002Koool406Ko7?ooo`03000006Ko<ol0
02hco`000`000?ooooooo`0Soooo00?o09Woooooool0P?ooo`00:_ooo`80I_lJoooo00<0I_l0000c
o`00;S?o00030000oooooooo02?oool00ol0VOooooooo`20oooo000/oooo0P1VoaSoool00`1Voooo
o`00000^<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool002koool206Ko5Oooo`0506Ko
oooooooooooo000002dco`0200009?ooo`03o`2Ioooooooo083oool0033oool206Ko4_ooo`0306Ko
oooooooo00?oool00`0003?o03?o000Z<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool0
03;oool206Ko3oooo`0306Kooooooooo00Goool00`0003?o03?o000@<ol00P0000@co`0200000c?o
00@00003<ol00P0000Dco`000`000?ooooooo`0Soooo00?o09Woooooool0P?ooo`00=?ooo`80I_l<
oooo00<0I_ooooooool01oooo`030000<ol0<ol000hco`00100003?o03?o000000Pco`000`0003?o
03?o0003<ol000@0000co`0co`000004<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool0
03Koool00`1Vooooooooo`08oooo00<0I_ooooooool02Oooo`030000<ol0<ol000dco`00100003?o
03?o000000Tco`000`0003?o03?o0005<ol000<0000co`0co`000S?o0080000Toooo00?o09Wooooo
ool0P?ooo`00=oooo`80I_l7oooo00<0I_ooooooool02oooo`030000<ol0<ol000`co`00100003?o
03?o000000Xco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`0Soooo00?o09Wooooo
ool0P?ooo`00>Oooo`80I_l4oooo00<0I_ooooooool03Oooo`030000<ol0<ol000/co`00100003?o
03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool08ooo
o`03o`2Ioooooooo083oool003_oool0101Vooooooooo`1Voa3oool00`0003?o03?o000<<ol00P00
00Xco`02000013?o00<00004<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool003coool2
06Ko4_ooo`030000<ol0<ol002@co`0200009?ooo`03o`2Ioooooooo083oool0057oool00`0003?o
03?o000S<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool005;oool00`0003?o03?o000R
<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool005;oool00`0003?o03?o000R<ol000<0
003oooooool08oooo`03o`2Ioooooooo083oool005?oool00`0003?o03?o000Q<ol00P0002Coool0
0ol0VOooooooo`20oooo001Coooo00<0000co`0co`008C?o00030000oooooooo02?oool00ol0VOoo
ooooo`20oooo001Doooo00<0000co`0co`0083?o00030000oooooooo02?oool00ol0VOooooooo`20
oooo001Doooo00<0000co`0co`0083?o00030000oooooooo02?oool00ol0VOooooooo`20oooo001E
oooo00<0000co`0co`007c?o0080000Toooo00?o09Woooooool0P?ooo`00EOooo`030000<ol0<ol0
01lco`000`000?ooooooo`0Soooo00?o09Woooooool0P?ooo`00E_ooo`030000<ol0<ol001hco`00
0`000?ooooooo`0Soooo00?o09Woooooool0P?ooo`00E_ooo`030000<ol0<ol001hco`000`000?oo
ooooo`0Soooo00?o09Woooooool0P?ooo`00Eoooo`030000<ol0<ol001dco`0200009?ooo`03o`2I
oooooooo083oool005Ooool00`0003?o03?o000M<ol000<0003oooooool08oooo`03o`2Ioooooooo
083oool005Soool00`0003?o03?o0009<ol00P0000@co`02000013?o00800005<ol000<0003ooooo
ool08oooo`03o`2Ioooooooo083oool005Soool00`0003?o03?o0008<ol000@0000co`0co`000008
<ol000@0000co`0co`000004<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool005Woool0
0`0003?o03?o0007<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o0080000Toooo00?o
09Woooooool0P?ooo`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`0200001C?o
00030000oooooooo02?oool00ol0VOooooooo`20oooo001Ioooo00<0000co`0co`001c?o00040000
<ol0<ol000002C?o00030000<ol0<ol000@co`000`000?ooooooo`0Soooo00?o09Woooooool0P?oo
o`00F_ooo`030000<ol0<ol000Lco`0200002S?o00<00004<ol000<0003oooooool08oooo`03o`2I
oooooooo083oool005[oool00`0003?o03?o000J<ol00P0002Coool00ol0VOooooooo`20oooo001J
oooo00<0000co`0co`006S?o00030000oooooooo02?oool00ol0VOooooooo`20oooo001Koooo00<0
000co`0co`006C?o00030000oooooooo02?oool00ol0VOooooooo`20oooo001Koooo00<0000co`0c
o`006C?o0080000Toooo00?o09Woooooool0P?ooo`00Foooo`030000<ol0<ol001Tco`000`000?oo
ooooo`0Soooo00?o09Woooooool0P?ooo`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`0S
oooo00?o09Woooooool0P?ooo`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`0Soooo00?o
09Woooooool0P?ooo`00G?ooo`030000<ol0<ol001Pco`0200009?ooo`03o`2Ioooooooo083oool0
05goool00`0003?o03?o000G<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool005goool0
0`0003?o03?o000G<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool005goool00`0003?o
03?o000G<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool005koool00`0003?o03?o000F
<ol00P0002Coool00ol0VOooooooo`20oooo001Noooo00<0000co`0co`005S?o00030000oooooooo
02?oool00ol0VOooooooo`20oooo001Noooo0P0000@co`0200001C?o00030000<ol0<ol0008co`02
00001C?o00030000oooooooo02?oool00ol0VOooooooo`20oooo001Moooo00@0003oool00000000:
<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`000?ooooooo`0Soooo00?o
09Woooooool0P?ooo`00GOooo`040000oooo000000002S?o00030000<ol0<ol000@co`000`0003?o
03?o0002<ol00P0002Coool00ol0VOooooooo`20oooo001Moooo00@0003oool00000000;<ol000@0
000co`0co`0co`0200001C?o00030000oooooooo02?oool00ol0VOooooooo`20oooo001Moooo00@0
003oooooool00008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo
02?oool00ol0VOooooooo`20oooo001Noooo0`0000Pco`0400000c?o00<00004<ol000<0003ooooo
ool08oooo`03o`2Ioooooooo083oool0063oool00`0003?o03?o000D<ol00P0002Coool00ol0VOoo
ooooo`20oooo001Poooo00<0000co`0co`0053?o00030000oooooooo02?oool00ol0VOooooooo`20
oooo001Qoooo00<0000co`0co`004c?o00030000oooooooo02?oool00ol0VOooooooo`20oooo001Q
oooo00<0000co`0co`004c?o00030000oooooooo02?oool00ol0VOooooooo`20oooo001Qoooo00<0
000co`0co`004c?o0080000Toooo00?o09Woooooool0P?ooo`00HOooo`030000<ol0<ol001<co`00
0`000?ooooooo`0Soooo00?o09Woooooool0P?ooo`00H_ooo`030000<ol0<ol0018co`000`000?oo
ooooo`0Soooo00?o09Woooooool0P?ooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`0S
oooo00?o09Woooooool0P?ooo`00H_ooo`030000<ol0<ol0018co`0200009?ooo`03o`2Ioooooooo
083oool006;oool00`0003?o03?o000B<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool0
06?oool00`0003?o03?o000A<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool006?oool0
0`0003?o03?o000A<ol000<0003oooooool08oooo`03o`2Ioooooooo083oool006?oool00`0003?o
03?o000A<ol00P0002Coool00ol0VOooooooo`20oooo001Soooo00<0000co`0co`004C?o00030000
oooooooo02?oool00ol0VOooooooo`20oooo001Soooo00<0000co`0co`002C?o00D00003<ol000<0
003oooooool08oooo`03o`2Ioooooooo083oool006Coool00`0003?o03?o000:<ol000<0000co`0c
o`000c?o00030000oooooooo02?oool00ol0VOooooooo`20oooo001Toooo00<0000co`0co`002S?o
00030000<ol0<ol000<co`0200009?ooo`03o`2Ioooooooo083oool006Coool=<ol000<0000co`0c
o`000c?o0:Woool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool<<ol00P0000Dco`2Y
oooo001Uoooo4S?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`02oooo00<0003oooooool0:?oo
o`030000oooooooo07Woool006GooolB<ol000?oool0003oool02Oooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001Uoooo4S?o0003oooo0000oooo00?oool200001?ooo`030000oooooooo
00goool200001?ooo`800003oooo100000?oool00`000?ooooooo`1hoooo001Uoooo4S?o0003oooo
0000oooo00;oool010000?ooooooo`0000Coool00`000?ooooooo`04oooo100000?oool010000?oo
ooooo`0000Soool00`000?ooooooo`04oooo00<0003oooooool0N?ooo`00IOoooa8co`000`000?oo
ooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`1goooo001Voooo4C?o0004oooo0000oooooooo1@0001;oool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00I_oooa4co`000oooo`000?ooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo07Soool006KooolA<ol00_ooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0
003oooooool0NOooo`00I_oooa4co`2Yoooo001Voooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55972 .30902 L
.56446 .30902 L
.56951 .30902 L
.57197 .30902 L
.57318 .30902 L
.57429 .30902 L
.5753 .30902 L
s
.5753 .30902 m
.5754 .61803 L
s
0 .4 1 r
.02381 .32395 m
.06244 .32892 L
.10458 .33625 L
.14415 .34561 L
.16408 .3515 L
.18221 .3577 L
.18703 .3595 L
.18957 .36047 L
.19227 .36153 L
.1934 .36198 L
.19462 .36246 L
.19532 .36261 L
.19596 .36183 L
.19721 .36029 L
.20178 .35455 L
.21264 .34009 L
.22272 .32556 L
.22745 .31835 L
.22977 .31472 L
.23191 .31132 L
.23311 .30939 L
.23437 .30902 L
.23565 .30902 L
.23637 .30902 L
.23704 .30902 L
.23822 .30902 L
.23929 .30902 L
.24053 .30902 L
.2417 .30902 L
.24289 .30902 L
.2442 .30902 L
.24486 .30902 L
.24557 .30902 L
.24686 .30902 L
.24807 .30902 L
.24935 .30902 L
.25044 .30902 L
.25163 .30902 L
.25292 .30902 L
.25358 .30902 L
.25429 .30902 L
.25507 .30902 L
.2558 .30902 L
.25646 .30902 L
.25718 .30902 L
.25785 .30902 L
.25859 .30902 L
.25928 .30902 L
.25992 .30902 L
.26113 .30902 L
Mistroke
.26243 .30902 L
.26312 .30902 L
.26376 .30902 L
.26446 .30902 L
.2652 .30902 L
.26645 .30902 L
.26716 .30902 L
.26782 .30902 L
.26905 .30902 L
.27018 .30902 L
.27147 .30902 L
.2727 .30902 L
.27383 .30902 L
.27503 .30902 L
.27605 .30902 L
.27717 .30902 L
.27838 .30902 L
.27968 .30902 L
.28091 .30902 L
.28204 .30902 L
.28326 .30902 L
.28457 .30902 L
.2858 .30902 L
.28692 .30902 L
.28823 .30902 L
.28898 .30902 L
.28966 .30902 L
.29092 .30902 L
.29155 .30902 L
.29225 .30902 L
.29297 .30902 L
.29365 .30902 L
.29493 .30902 L
.29564 .30902 L
.2963 .30902 L
.29703 .30902 L
.2978 .30902 L
.29907 .30902 L
.30026 .30902 L
.30157 .30902 L
.30231 .30902 L
.30299 .30902 L
.30426 .30902 L
.30546 .30902 L
.30654 .30902 L
.30772 .30902 L
.30899 .30902 L
.30964 .30902 L
.31035 .30902 L
.3116 .30902 L
Mistroke
.31277 .30902 L
.31395 .30902 L
.31507 .30902 L
.31607 .30902 L
.31717 .30902 L
.31835 .30902 L
.31961 .30902 L
.32081 .30902 L
.32189 .30902 L
.32318 .30902 L
.32384 .30902 L
.32455 .30902 L
.32582 .30902 L
.32701 .30902 L
.32773 .30902 L
.32841 .30902 L
.32968 .30902 L
.33039 .30902 L
.33105 .30902 L
.33178 .30902 L
.33254 .30902 L
.33373 .30902 L
.33501 .30902 L
.33621 .30902 L
.33731 .30902 L
.33854 .30902 L
.33923 .30902 L
.33988 .30902 L
.34118 .30902 L
.34191 .30902 L
.34258 .30902 L
.34377 .30902 L
.34489 .30902 L
.34612 .30902 L
.34743 .30902 L
.34809 .30902 L
.34881 .30902 L
.35012 .30902 L
.35139 .30902 L
.35257 .30902 L
.35368 .30902 L
.35487 .30902 L
.356 .30902 L
.35703 .30902 L
.35824 .30902 L
.35952 .30902 L
.3606 .30902 L
.36178 .30902 L
.36245 .30902 L
.36318 .30902 L
Mistroke
.36387 .30902 L
.3645 .30902 L
.3657 .30902 L
.36698 .30902 L
.36764 .30902 L
.36835 .30902 L
.36963 .30902 L
.37102 .30902 L
.37181 .30902 L
.37255 .30902 L
.37385 .30902 L
.37457 .30902 L
.37523 .30902 L
.37655 .30902 L
.37779 .30902 L
.37898 .30902 L
.38009 .30902 L
.3813 .30902 L
.38258 .30902 L
.3838 .30902 L
.38449 .30902 L
.38512 .30902 L
.38629 .30902 L
.38753 .30902 L
.38864 .30902 L
.38968 .30902 L
.39082 .30902 L
.39205 .30902 L
.39328 .30902 L
.39398 .30902 L
.39463 .30902 L
.39595 .30902 L
.39668 .30902 L
.39735 .30902 L
.39855 .30902 L
.39985 .30902 L
.40108 .30902 L
.40221 .30902 L
.40326 .30902 L
.40425 .30902 L
.4054 .30902 L
.40645 .30902 L
.40886 .30902 L
.41111 .30902 L
.42054 .30902 L
.45877 .30902 L
.49946 .30902 L
.53863 .30902 L
.58025 .30902 L
.62036 .30902 L
Mistroke
.65895 .30902 L
.69999 .30902 L
.73952 .30902 L
.77753 .30902 L
.81799 .30902 L
.85694 .30902 L
.89834 .30902 L
.93823 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0002[oool20000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000
oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0
003oooooool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool20000;_oo
o`030000oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool2
0000;oooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000D0000co`0co`0co`00I_l013?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool00_ooo`03o`2I
oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo00Goool:00007c?o00040000<ol0<ol006Ko;3?o00030000
oooooooo02Soool00ol0VOooooooo`02oooo00<0003oooooool0;Oooo`030000oooooooo02koool0
0`000?ooooooo`0Eoooo000Xoooo1P0001`co`000`1Voc?o03?o000Z<ol000<0003oooooool0:?oo
o`03o`2Ioooooooo07_oool001Koool506Ko4oooo`D0000F<ol000<0I_lco`0co`00:c?o0080000Y
oooo00?o09Woooooool0Noooo`006oooo`P0I_l@oooo1000018co`000`1Voc?o03?o000[<ol000<0
003oooooool0:?ooo`03o`2Ioooooooo07_oool002?oool606Ko3_ooo`80000?<ol000<0I_lco`0c
o`00;3?o00030000oooooooo02Soool00ol0VOooooooo`1koooo000Yoooo101Vo`coool300002c?o
000306Ko<ol0<ol002dco`000`000?ooooooo`0Xoooo00?o09Woooooool0Noooo`00;Oooo`<0I_l<
oooo0P0000Pco`000`1Voc?o03?o000^<ol00P0002Woool00ol0VOooooooo`1koooo000`oooo101V
o`[oool200001C?o000306Ko<ol0<ol002lco`000`000?ooooooo`0Xoooo00?o09Woooooool0Nooo
o`00=?ooo`@0I_l8oooo0P00008co`000`1Voc?o03?o000`<ol000<0003oooooool0:?ooo`03o`2I
oooooooo07_oool003Soool306Ko1oooo`8000000`1Voc?o03?o000`<ol000<0003oooooool0:?oo
o`03o`2Ioooooooo07_oool003_oool206Ko1_ooo`0306Ko00000000034co`020000:Oooo`03o`2I
oooooooo07_oool003goool406Ko00?oool0I_ooool00_ooo`030000<ol0<ol002hco`000`000?oo
ooooo`0Xoooo00?o09Woooooool0Noooo`00@Oooo`80I_l4oooo00<0000co`0co`00;C?o00030000
oooooooo02Soool00ol0VOooooooo`1koooo0018oooo00<0000co`0co`00;3?o00030000oooooooo
02Soool00ol0VOooooooo`1koooo0019oooo00<0000co`0co`00:c?o0080000Yoooo00?o09Wooooo
ool0Noooo`00B_ooo`030000<ol0<ol002Xco`000`000?ooooooo`0Xoooo00?o09Woooooool0Nooo
o`00Boooo`030000<ol0<ol0010co`02000013?o00800003<ol0100000<co`0200001C?o00030000
oooooooo02Soool00ol0VOooooooo`1koooo001<oooo00<0000co`0co`003S?o00040000<ol0<ol0
000023?o00030000<ol0<ol000<co`00100003?o03?o000000@co`000`000?ooooooo`0Xoooo00?o
09Woooooool0Noooo`00COooo`030000<ol0<ol000dco`00100003?o03?o000000Tco`000`0003?o
03?o0005<ol000<0000co`0co`000S?o0080000Yoooo00?o09Woooooool0Noooo`00C_ooo`030000
<ol0<ol000`co`00100003?o03?o000000Xco`000`0003?o03?o0002<ol00P0000Dco`000`000?oo
ooooo`0Xoooo00?o09Woooooool0Noooo`00Coooo`030000<ol0<ol000/co`00100003?o03?o0000
00Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0:?ooo`03o`2I
oooooooo07_oool004ooool00`0003?o03?o000<<ol00P0000Xco`02000013?o00<00004<ol000<0
003oooooool0:?ooo`03o`2Ioooooooo07_oool0053oool00`0003?o03?o000T<ol00P0002Woool0
0ol0VOooooooo`1koooo001Aoooo00<0000co`0co`008c?o00030000oooooooo02Soool00ol0VOoo
ooooo`1koooo001Boooo00<0000co`0co`008S?o00030000oooooooo02Soool00ol0VOooooooo`1k
oooo001Boooo00<0000co`0co`008S?o00030000oooooooo02Soool00ol0VOooooooo`1koooo001C
oooo00<0000co`0co`008C?o0080000Yoooo00?o09Woooooool0Noooo`00Doooo`030000<ol0<ol0
024co`000`000?ooooooo`0Xoooo00?o09Woooooool0Noooo`00E?ooo`030000<ol0<ol0020co`00
0`000?ooooooo`0Xoooo00?o09Woooooool0Noooo`00E?ooo`030000<ol0<ol0020co`000`000?oo
ooooo`0Xoooo00?o09Woooooool0Noooo`00EOooo`030000<ol0<ol001lco`020000:Oooo`03o`2I
oooooooo07_oool005Goool00`0003?o03?o000O<ol000<0003oooooool0:?ooo`03o`2Ioooooooo
07_oool005Koool00`0003?o03?o000N<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool0
05Koool00`0003?o03?o000N<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool005Ooool0
0`0003?o03?o000M<ol00P0002Woool00ol0VOooooooo`1koooo001Goooo00<0000co`0co`007C?o
00030000oooooooo02Soool00ol0VOooooooo`1koooo001Hoooo00<0000co`0co`002C?o00800004
<ol00P0000@co`0200001C?o00030000oooooooo02Soool00ol0VOooooooo`1koooo001Hoooo00<0
000co`0co`0023?o00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000oooooooo
02Soool00ol0VOooooooo`1koooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002c?o
00030000<ol0<ol0008co`020000:Oooo`03o`2Ioooooooo07_oool005Woool00`0003?o03?o0007
<ol000@0000co`0co`000009<ol00P0000Dco`000`000?ooooooo`0Xoooo00?o09Woooooool0Nooo
o`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`000`0003?o03?o0004<ol000<0
003oooooool0:?ooo`03o`2Ioooooooo07_oool005[oool00`0003?o03?o0007<ol00P0000Xco`03
000013?o00030000oooooooo02Soool00ol0VOooooooo`1koooo001Joooo00<0000co`0co`006S?o
0080000Yoooo00?o09Woooooool0Noooo`00F_ooo`030000<ol0<ol001Xco`000`000?ooooooo`0X
oooo00?o09Woooooool0Noooo`00Foooo`030000<ol0<ol001Tco`000`000?ooooooo`0Xoooo00?o
09Woooooool0Noooo`00Foooo`030000<ol0<ol001Tco`020000:Oooo`03o`2Ioooooooo07_oool0
05_oool00`0003?o03?o000I<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool005coool0
0`0003?o03?o000H<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool005coool00`0003?o
03?o000H<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool005coool00`0003?o03?o000H
<ol00P0002Woool00ol0VOooooooo`1koooo001Moooo00<0000co`0co`005c?o00030000oooooooo
02Soool00ol0VOooooooo`1koooo001Moooo00<0000co`0co`005c?o00030000oooooooo02Soool0
0ol0VOooooooo`1koooo001Moooo00<0000co`0co`005c?o00030000oooooooo02Soool00ol0VOoo
ooooo`1koooo001Noooo00<0000co`0co`005S?o0080000Yoooo00?o09Woooooool0Noooo`00G_oo
o`030000<ol0<ol001Hco`000`000?ooooooo`0Xoooo00?o09Woooooool0Noooo`00G_ooo`800004
<ol00P0000Dco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0Noooo`00GOooo`040000oooo000000002S?o00050000<ol0<ol0<ol00000008co`000`0003?o
03?o0002<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool005goool010000?ooo`000000
00Xco`000`0003?o03?o0004<ol000<0000co`0co`000S?o0080000Yoooo00?o09Woooooool0Nooo
o`00GOooo`040000oooo000000002c?o00040000<ol0<ol0<ol00P0000Dco`000`000?ooooooo`0X
oooo00?o09Woooooool0Noooo`00GOooo`040000oooooooo000023?o00040000<ol0<ol000000c?o
00030000<ol0<ol000@co`000`000?ooooooo`0Xoooo00?o09Woooooool0Noooo`00G_ooo`<00008
<ol0100000<co`03000013?o00030000oooooooo02Soool00ol0VOooooooo`1koooo001Poooo00<0
000co`0co`0053?o0080000Yoooo00?o09Woooooool0Noooo`00H?ooo`030000<ol0<ol001@co`00
0`000?ooooooo`0Xoooo00?o09Woooooool0Noooo`00HOooo`030000<ol0<ol001<co`000`000?oo
ooooo`0Xoooo00?o09Woooooool0Noooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`0X
oooo00?o09Woooooool0Noooo`00HOooo`030000<ol0<ol001<co`020000:Oooo`03o`2Ioooooooo
07_oool0067oool00`0003?o03?o000C<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool0
06;oool00`0003?o03?o000B<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool006;oool0
0`0003?o03?o000B<ol000<0003oooooool0:?ooo`03o`2Ioooooooo07_oool006;oool00`0003?o
03?o000B<ol00P0002Woool00ol0VOooooooo`1koooo001Roooo00<0000co`0co`004S?o00030000
oooooooo02Soool00ol0VOooooooo`1koooo001Soooo00<0000co`0co`004C?o00030000oooooooo
02Soool00ol0VOooooooo`1koooo001Soooo00<0000co`0co`004C?o00030000oooooooo02Soool0
0ol0VOooooooo`1koooo001Soooo00<0000co`0co`004C?o0080000Yoooo00?o09Woooooool0Nooo
o`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`0Xoooo00?o09Woooooool0Noooo`00Hooo
o`030000<ol0<ol000Tco`0500000c?o00030000oooooooo02Soool00ol0VOooooooo`1koooo001T
oooo00<0000co`0co`002S?o00030000<ol0<ol000<co`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0Noooo`00I?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol00P0002Woool00ol0VOoo
ooooo`1koooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol0
00<co`2Yoooo001Toooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool0
06GooolB<ol00_ooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001Uoooo4S?o0003oooo
0000oooo00Woool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00IOoooa8co`000oooo`00
0?ooo`03oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`D00002oooo00<0
003oooooool0N?ooo`00IOoooa8co`000oooo`000?ooo`02oooo00@0003oooooool00004oooo00<0
003oooooool01?ooo`@00003oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000
oooooooo07Soool006GooolB<ol000<0003oooooool00_ooo`030000oooooooo01?oool010000?oo
ooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00I_oooa4co`001?ooo`00
0?ooooooo`D0000Boooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo
07Soool006KooolA<ol000?oool0003oool00_ooo`030000oooooooo01?oool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00I_oooa4co`02oooo00<0003ooooo
ool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo001Voooo4C?o0:Woool006KooolA
<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -54.125 0 ]
[.5 .63053 54.125 13.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -115.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.625 moveto
(8) show
69.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.625 moveto
(,) show
84.563 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.44089) show
128.375 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
136.188 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
148.188 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
152.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
161.250 13.625 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.55838 .30902 L
.57861 .30902 L
.58392 .30902 L
.58957 .30902 L
.59232 .30902 L
.59367 .30902 L
.59491 .30902 L
s
.59491 .30902 m
.59502 .61803 L
s
0 .4 1 r
.02381 .30902 m
.03279 .30902 L
.04262 .30902 L
.04758 .30902 L
.0503 .30902 L
.05288 .30902 L
.05528 .30902 L
.05594 .30902 L
.05664 .30902 L
.05789 .30902 L
.05901 .30902 L
.06006 .30902 L
.06121 .30902 L
.06244 .30902 L
.06315 .30902 L
.0638 .30902 L
.06454 .30902 L
.06524 .30902 L
.06649 .30902 L
.06784 .30902 L
.06933 .30902 L
.07008 .30902 L
.0709 .30902 L
.07161 .30902 L
.07236 .30902 L
.07308 .30902 L
.07373 .30902 L
.07439 .30902 L
.0751 .30902 L
.07636 .30902 L
.07707 .30902 L
.07773 .30902 L
.07845 .30902 L
.07923 .30902 L
.08445 .30902 L
.10458 .30902 L
.10582 .30902 L
.10652 .30902 L
.10716 .30902 L
.10835 .30902 L
.1096 .30902 L
.11029 .30902 L
.11094 .30902 L
.11241 .30902 L
.11496 .30902 L
.11962 .30902 L
.12096 .30902 L
.12223 .30902 L
.12337 .30902 L
.12462 .30902 L
Mistroke
.12531 .30902 L
.12595 .30902 L
.12715 .30902 L
.12985 .30902 L
.1347 .30902 L
.13534 .30902 L
.13603 .30902 L
.13728 .30902 L
.13857 .30902 L
.13932 .30902 L
.14 .30902 L
.14073 .30902 L
.14153 .30902 L
.14298 .30902 L
.14572 .30902 L
.15026 .30902 L
.15264 .30902 L
.15394 .30902 L
.15514 .30902 L
.15579 .30902 L
.15648 .30902 L
.15725 .30902 L
.15794 .30902 L
.16051 .30902 L
.16553 .30902 L
.17648 .30902 L
.18128 .30902 L
.18259 .30902 L
.18382 .30902 L
.18451 .30902 L
.18525 .30902 L
.18655 .30902 L
.18777 .30902 L
.18906 .30902 L
.19017 .30902 L
.19138 .30902 L
.1959 .30902 L
.19841 .30902 L
.19967 .30902 L
.20038 .30902 L
.20105 .30902 L
.20225 .30902 L
.20333 .30902 L
.2046 .30902 L
.20578 .30902 L
.20705 .30902 L
.20772 .30902 L
.20843 .30902 L
.20962 .30902 L
.21094 .30902 L
Mistroke
.21166 .30902 L
.21232 .30902 L
.21309 .30902 L
.21381 .30902 L
.2151 .30902 L
.21583 .30902 L
.21651 .30902 L
.21783 .30902 L
.21907 .30902 L
.22018 .30902 L
.22139 .30902 L
.22271 .30902 L
.22337 .30902 L
.2241 .30902 L
.22539 .30902 L
.22659 .30902 L
.22785 .30902 L
.22849 .30902 L
.22919 .30902 L
.23043 .30902 L
.2316 .30902 L
.23227 .30902 L
.23297 .30902 L
.23422 .30902 L
.23559 .30902 L
.23705 .30902 L
.23833 .30902 L
.2395 .30902 L
.24067 .30902 L
.24178 .30902 L
.24307 .30902 L
.24427 .30902 L
.24557 .30902 L
.24623 .30902 L
.24696 .30902 L
.2482 .30902 L
.24937 .30902 L
.25043 .30902 L
.25158 .30902 L
.25283 .30902 L
.25351 .30902 L
.25416 .30902 L
.25541 .30902 L
.25655 .30902 L
.25764 .30902 L
.2588 .30902 L
.25978 .30902 L
.26086 .30902 L
.26202 .30902 L
.26327 .30902 L
Mistroke
.26445 .30902 L
.26552 .30902 L
.2667 .30902 L
.26781 .30902 L
.26903 .30902 L
.27035 .30902 L
.271 .30902 L
.27172 .30902 L
.27302 .30902 L
.27429 .30902 L
.27547 .30902 L
.27667 .30902 L
.2778 .30902 L
.27881 .30902 L
.27991 .30902 L
.28111 .30902 L
.28238 .30902 L
.28347 .30902 L
.28465 .30902 L
.28532 .30902 L
.28605 .30902 L
.28737 .30902 L
.28865 .30902 L
.28984 .30902 L
.29112 .30902 L
.29185 .30902 L
.29253 .30902 L
.29325 .30902 L
.29391 .30902 L
.29464 .30902 L
.2954 .30902 L
.2966 .30902 L
.29788 .30902 L
.29909 .30902 L
.30019 .30902 L
.30148 .30902 L
.30221 .30902 L
.30289 .30902 L
.30412 .30902 L
.30543 .30902 L
.30664 .30902 L
.30796 .30902 L
.31036 .30902 L
.31149 .30902 L
.3127 .30902 L
.31383 .30902 L
.31486 .30902 L
.31617 .30902 L
.31737 .30902 L
.31869 .30902 L
Mistroke
.31936 .30902 L
.32009 .30902 L
.32131 .30902 L
.32263 .30902 L
.325 .30902 L
.32614 .30902 L
.32736 .30902 L
.32799 .30902 L
.32869 .30902 L
.32992 .30902 L
.33108 .30902 L
.33233 .30902 L
.3335 .30902 L
.33458 .30902 L
.33565 .30902 L
.33679 .30902 L
.33786 .30902 L
.33884 .30902 L
.33994 .30902 L
.34097 .30902 L
.34209 .30902 L
.34331 .30902 L
.34455 .30902 L
.34567 .30902 L
.34698 .30902 L
.34821 .30902 L
.34935 .30902 L
.3504 .30902 L
.35156 .30902 L
.35279 .30902 L
.35402 .30902 L
.35471 .30902 L
.35535 .30902 L
.35651 .30902 L
.35774 .30902 L
.3584 .30902 L
.3591 .30902 L
.36035 .30902 L
.36112 .30902 L
.36185 .30902 L
.36251 .30902 L
.36321 .30902 L
.36454 .30902 L
.36528 .30902 L
.36596 .30902 L
.36728 .30902 L
.36853 .30902 L
.37121 .30902 L
.37195 .30902 L
.37264 .30902 L
Mistroke
.37344 .30902 L
.37416 .30902 L
.37537 .30902 L
.37667 .30902 L
.37788 .30902 L
.37899 .30902 L
.38022 .30902 L
.38091 .30902 L
.38156 .30902 L
.38287 .30902 L
.3836 .30902 L
.38427 .30902 L
.38545 .30902 L
.38655 .30902 L
.38777 .30902 L
.38908 .30902 L
.39038 .30902 L
.39103 .30902 L
.39174 .30902 L
.39301 .30902 L
.39418 .30902 L
.39538 .30902 L
.39651 .30902 L
.39752 .30902 L
.39862 .30902 L
.39982 .30902 L
.40109 .30902 L
.40217 .30902 L
.40336 .30902 L
.40402 .30902 L
.40475 .30902 L
.40606 .30902 L
.40734 .30902 L
.40853 .30902 L
.41409 .30902 L
.42412 .30902 L
.46331 .30902 L
.50495 .30902 L
.54508 .30902 L
.58369 .30902 L
.62475 .30902 L
.6643 .30902 L
.70233 .30902 L
.74282 .30902 L
.78178 .30902 L
.8232 .30902 L
.86311 .30902 L
.9015 .30902 L
.94234 .30902 L
.97619 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -54.125 0 ]
[.5 .63053 54.125 13.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -115.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.625 moveto
(8) show
69.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.625 moveto
(,) show
84.563 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.44089) show
128.375 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
136.188 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
148.188 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
152.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
161.250 13.625 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`<0002Voooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`<0002Voooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
0:Koool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0`000:Koool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo0P000:Ooool001Soool40000;?oo
o`D0000Zoooo00<0003oooooool0:oooo`D0000[oooo100002goool200006?ooo`006?ooo`030000
oooooooo02ooool00`000?ooooooo`0Zoooo00<0003oooooool0;Oooo`030000oooooooo02_oool0
0`000?ooooooo`0]oooo00@0003oooooool0000Goooo000Ioooo00<0003oooooool0;_ooo`030000
oooooooo02[oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02koool0
0`000?ooooooo`0Foooo000Boooo100000Coool00`000?ooooooo`0Uoooo100000Coool00`000?oo
ooooo`0Zoooo0P0002koool00`000?ooooooo`0]oooo00<0003oooooool0;_ooo`030000oooooooo
01Goool001Soool010000?ooooooo`0002koool00`000?ooooooo`0Zoooo00<0003oooooool0;Ooo
o`030000oooooooo02_oool010000?ooooooo`0002coool010000?ooooooo`0001Ooool001Woool2
0000;_ooo`80000/oooo00<0003oooooool0;?ooo`80000^oooo0P0002koool200006?ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`004Oooood0000Boooo000Goooo3@00
00Hco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0
000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Koool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo01Koool001Ooool00`000?ooooooo`0:oooo1@0001hco`00
0`0003?o03?o000]<ol000<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0]
oooo00<0003oooooool05_ooo`00:Oooo`T00015<ol000<0003oooooool0;Oooo`03o`2Ioooooooo
07Koool003;oool20000@c?o0080000^oooo00?o09Woooooool0M_ooo`00=?ooo`@0000o<ol000<0
003oooooool0;Oooo`03o`2Ioooooooo07Koool003Soool40000>c?o00030000oooooooo02goool0
0ol0VOooooooo`1foooo000loooo0P0003Tco`000`000?ooooooo`0]oooo00?o09Woooooool0M_oo
o`00?_ooo`80000g<ol00P0002koool00ol0VOooooooo`1foooo0010oooo0P0003Dco`000`000?oo
ooooo`0]oooo00?o09Woooooool0M_ooo`00@_ooo`80000c<ol000<0003oooooool0;Oooo`03o`2I
oooooooo07Koool004Coool20000<C?o00030000oooooooo02goool00ol0VOooooooo`1foooo0016
oooo00<0000co`0co`00;S?o0080000^oooo00?o09Woooooool0M_ooo`00Aoooo`80000^<ol000<0
003oooooool0;Oooo`03o`2Ioooooooo07Koool004Woool00`0003?o03?o000[<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo07Koool004[oool00`0003?o03?o000Z<ol000<0003oooooool0;Ooo
o`03o`2Ioooooooo07Koool004_oool00`0003?o03?o000Y<ol00P0002koool00ol0VOooooooo`1f
oooo001<oooo00<0000co`0co`00:3?o00030000oooooooo02goool00ol0VOooooooo`1foooo001<
oooo00<0000co`0co`003c?o00800004<ol00P0000<co`0400000c?o00800005<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo07Koool004goool00`0003?o03?o000=<ol000@0000co`0co`000008
<ol000<0000co`0co`000c?o00040000<ol0<ol0000013?o00030000oooooooo02goool00ol0VOoo
ooooo`1foooo001>oooo00<0000co`0co`0033?o00040000<ol0<ol000002C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0002<ol00`0002goool00ol0VOooooooo`1foooo001?oooo00<0000co`0c
o`002c?o00040000<ol0<ol000002S?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo
02goool00ol0VOooooooo`1foooo001?oooo00<0000co`0co`002c?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?ooooooo`0]oooo00?o09Wooooo
ool0M_ooo`00D?ooo`030000<ol0<ol000/co`0200002S?o00800004<ol00`0000@co`020000;_oo
o`03o`2Ioooooooo07Koool0057oool00`0003?o03?o000S<ol000<0003oooooool0;Oooo`03o`2I
oooooooo07Koool005;oool00`0003?o03?o000R<ol000<0003oooooool0;Oooo`03o`2Ioooooooo
07Koool005;oool00`0003?o03?o000R<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Koool0
05?oool00`0003?o03?o000Q<ol00P0002koool00ol0VOooooooo`1foooo001Doooo00<0000co`0c
o`0083?o00030000oooooooo02goool00ol0VOooooooo`1foooo001Doooo00<0000co`0co`0083?o
00030000oooooooo02goool00ol0VOooooooo`1foooo001Eoooo00<0000co`0co`007c?o00030000
oooooooo02goool00ol0VOooooooo`1foooo001Eoooo00<0000co`0co`007c?o0080000^oooo00?o
09Woooooool0M_ooo`00E_ooo`030000<ol0<ol001hco`000`000?ooooooo`0]oooo00?o09Wooooo
ool0M_ooo`00E_ooo`030000<ol0<ol001hco`000`000?ooooooo`0]oooo00?o09Woooooool0M_oo
o`00E_ooo`030000<ol0<ol001hco`000`000?ooooooo`0]oooo00?o09Woooooool0M_ooo`00Eooo
o`030000<ol0<ol001dco`020000;_ooo`03o`2Ioooooooo07Koool005Ooool00`0003?o03?o000M
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Koool005Soool00`0003?o03?o0009<ol00P00
00@co`02000013?o00800005<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Koool005Soool0
0`0003?o03?o0008<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo07Koool005Soool00`0003?o03?o0008<ol000@0000co`0co`00000;
<ol000<0000co`0co`000S?o00<0000]oooo00?o09Woooooool0M_ooo`00FOooo`030000<ol0<ol0
00Lco`00100003?o03?o000000Tco`0200001C?o00030000oooooooo02goool00ol0VOooooooo`1f
oooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o00030000<ol0<ol000@co`00
0`000?ooooooo`0]oooo00?o09Woooooool0M_ooo`00F_ooo`030000<ol0<ol000Lco`0200002S?o
00<00004<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Koool005[oool00`0003?o03?o000J
<ol00P0002koool00ol0VOooooooo`1foooo001Koooo00<0000co`0co`006C?o00030000oooooooo
02goool00ol0VOooooooo`1foooo001Koooo00<0000co`0co`006C?o00030000oooooooo02goool0
0ol0VOooooooo`1foooo001Koooo00<0000co`0co`006C?o00030000oooooooo02goool00ol0VOoo
ooooo`1foooo001Loooo00<0000co`0co`0063?o0080000^oooo00?o09Woooooool0M_ooo`00G?oo
o`030000<ol0<ol001Pco`000`000?ooooooo`0]oooo00?o09Woooooool0M_ooo`00GOooo`030000
<ol0<ol001Lco`000`000?ooooooo`0]oooo00?o09Woooooool0M_ooo`00GOooo`030000<ol0<ol0
01Lco`000`000?ooooooo`0]oooo00?o09Woooooool0M_ooo`00G_ooo`030000<ol0<ol001Hco`02
0000;_ooo`03o`2Ioooooooo07Koool005koool00`0003?o03?o000F<ol000<0003oooooool0;Ooo
o`03o`2Ioooooooo07Koool005koool00`0003?o03?o000F<ol000<0003oooooool0;Oooo`03o`2I
oooooooo07Koool005koool00`0003?o03?o000F<ol000<0003oooooool0;Oooo`03o`2Ioooooooo
07Koool005ooool00`0003?o03?o000E<ol00P0002koool00ol0VOooooooo`1foooo001Noooo0P00
00@co`0200001C?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo02goool00ol0VOoo
ooooo`1foooo001Moooo00@0003oool00000000:<ol000D0000co`0co`0co`0000000S?o00030000
<ol0<ol0008co`000`000?ooooooo`0]oooo00?o09Woooooool0M_ooo`00GOooo`040000oooo0000
00002S?o00030000<ol0<ol000@co`000`0003?o03?o0002<ol00`0002goool00ol0VOooooooo`1f
oooo001Moooo00@0003oool00000000;<ol000@0000co`0co`0co`0200001C?o00030000oooooooo
02goool00ol0VOooooooo`1foooo001Moooo00@0003oooooool00008<ol000@0000co`0co`000003
<ol000<0000co`0co`0013?o00030000oooooooo02goool00ol0VOooooooo`1foooo001Noooo0`00
00Pco`0400000c?o00<00004<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Koool0063oool0
0`0003?o03?o000D<ol00P0002koool00ol0VOooooooo`1foooo001Poooo00<0000co`0co`0053?o
00030000oooooooo02goool00ol0VOooooooo`1foooo001Poooo00<0000co`0co`0053?o00030000
oooooooo02goool00ol0VOooooooo`1foooo001Qoooo00<0000co`0co`004c?o00030000oooooooo
02goool00ol0VOooooooo`1foooo001Qoooo00<0000co`0co`004c?o0080000^oooo00?o09Wooooo
ool0M_ooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`0]oooo00?o09Woooooool0M_oo
o`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`0]oooo00?o09Woooooool0M_ooo`00H_oo
o`030000<ol0<ol0018co`000`000?ooooooo`0]oooo00?o09Woooooool0M_ooo`00H_ooo`030000
<ol0<ol0018co`020000;_ooo`03o`2Ioooooooo07Koool006;oool00`0003?o03?o000B<ol000<0
003oooooool0;Oooo`03o`2Ioooooooo07Koool006;oool00`0003?o03?o000B<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo07Koool006?oool00`0003?o03?o000A<ol000<0003oooooool0;Ooo
o`03o`2Ioooooooo07Koool006?oool00`0003?o03?o000A<ol00P0002koool00ol0VOooooooo`1f
oooo001Soooo00<0000co`0co`004C?o00030000oooooooo02goool00ol0VOooooooo`1foooo001S
oooo00<0000co`0co`002C?o00D00003<ol000<0003oooooool0;Oooo`03o`2Ioooooooo07Koool0
06Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o00030000oooooooo02goool00ol0VOoo
ooooo`1foooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol000<co`030000;Oooo`03o`2I
oooooooo07Koool006Goool<<ol000<0000co`0co`000c?o0:Woool006Goool<<ol000<0000co`0c
o`000c?o0:Woool006Goool;<ol00P0000Dco`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol0ZOoo
o`00Goooo`030000oooooooo00CooolA<ol0Aoooo`030000oooooooo05ooool005koool00`000?oo
ooooo`05oooo0c?o00030000<ol0<ol000/co`18oooo00<0003oooooool0G_ooo`00G_ooo`030000
oooooooo00;oool2000000Gooolco`0co`0co`0000002C?o00<0000013?o0?ooo`00000000Goool3
00000oooo`<00002oooo0P0000Coool200000oooo`<00005oooo00D0003oooooooooool000000ooo
o`D00002oooo0P00017oool00`000?ooooooo`1Noooo001Noooo00D0003oooooooooool000000_oo
o`030000<ol0<ol0008co`000`0003?o03?o0007<ol000<0000co`0co`002Oooo`030000oooooooo
00?oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool00`000?ooooooo`02oooo00<0
003oooooool01?ooo`030000oooo000000Koool01@000?ooooooooooo`000002oooo00<0003ooooo
ool03_ooo`030000oooooooo05koool005goool00`000?ooooooo`02oooo00@0003oooooooooool;
<ol01@000003<ol0oooooooo00Coool5000000?oool0000000000`000005oooo0000oooooooo0000
00;oool010000?ooooooo`0000?oool300001_ooo`030000oooooooo00Goool01@000?oooooooooo
o`000002oooo00<0003oooooool03oooo`030000oooooooo05goool005koool00`000?ooooooo`05
000000?ooolco`0co`0023?o00040000<ol0<ol000000S?o00Koool010000?ooooooo`0000;oool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool200000oooo`040000oooooooo00001Ooo
o`030000oooo000000Koool01@000?ooooooooooo`000002oooo00<0003oooooool03_ooo`030000
oooooooo05koool005koool01@000?ooooooooooo`000004oooo2c?o00030000<ol00000008co`07
oooo00<0003oool000000oooo`030000oooo000000;oool010000?ooooooo`0000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000Coool01@000?ooooooooooo`000005oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00Coool200000_ooo`<00003oooo00<0003oooooool0G_oo
o`00Goooo`030000oooooooo00Goool<<ol00P00008co`08oooo0P0000Coool200000oooo`800004
oooo0P0000Coool300003Oooo`800004oooo0P0000?oool300000_ooo`060000oooooooo0000oooo
00000_ooo`030000oooooooo05ooool006Ooool@<ol0?oooo`030000oooooooo0080001Uoooo001W
oooo43?o03koool200000_ooo`<0001Toooo001Woooo43?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.48579, \
-1.05774, 0.0208114, 0.012828}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.48579, -1.05774, 0.0208114, 0.012828}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.58872 .30902 L
.59975 .30902 L
.60479 .30902 L
.60756 .30902 L
.61016 .30902 L
.6126 .30902 L
.61327 .30902 L
.61397 .30902 L
s
.61397 .30902 m
.6141 .61803 L
s
0 .4 1 r
.02381 .29409 m
.06244 .28912 L
.10458 .28178 L
.14415 .27242 L
.16408 .26653 L
.18221 .26034 L
.18703 .25854 L
.18957 .25756 L
.19227 .25651 L
.1934 .25606 L
.19462 .25557 L
.19532 .25542 L
.19596 .2562 L
.19721 .25774 L
.20178 .26348 L
.21264 .27794 L
.22272 .29247 L
.22745 .29968 L
.22977 .30331 L
.23191 .30671 L
.23311 .30865 L
.23437 .30902 L
.23565 .30902 L
.23637 .30902 L
.23704 .30902 L
.23822 .30902 L
.23929 .30902 L
.24053 .30902 L
.2417 .30902 L
.24289 .30902 L
.2442 .30902 L
.24486 .30902 L
.24557 .30902 L
.24686 .30902 L
.24807 .30902 L
.24935 .30902 L
.25044 .30902 L
.25163 .30902 L
.25236 .30902 L
.25304 .30902 L
.25433 .30902 L
.25505 .30902 L
.25572 .30902 L
.25645 .30902 L
.25722 .30902 L
.2585 .30902 L
.2597 .30902 L
.26101 .30902 L
.26175 .30902 L
.26243 .30902 L
Mistroke
.26372 .30902 L
.26493 .30902 L
.26603 .30902 L
.26721 .30902 L
.2685 .30902 L
.26915 .30902 L
.26986 .30902 L
.27112 .30902 L
.2723 .30902 L
.27349 .30902 L
.27461 .30902 L
.27562 .30902 L
.27672 .30902 L
.27791 .30902 L
.27918 .30902 L
.28026 .30902 L
.28145 .30902 L
.28276 .30902 L
.28342 .30902 L
.28414 .30902 L
.28542 .30902 L
.2866 .30902 L
.28733 .30902 L
.28801 .30902 L
.28929 .30902 L
.29 .30902 L
.29066 .30902 L
.29139 .30902 L
.29215 .30902 L
.29334 .30902 L
.29462 .30902 L
.29583 .30902 L
.29693 .30902 L
.29822 .30902 L
.29895 .30902 L
.29963 .30902 L
.30087 .30902 L
.30219 .30902 L
.30332 .30902 L
.30456 .30902 L
.30586 .30902 L
.30706 .30902 L
.30817 .30902 L
.30937 .30902 L
.3105 .30902 L
.31154 .30902 L
.31278 .30902 L
.3141 .30902 L
.31521 .30902 L
.31642 .30902 L
Mistroke
.3177 .30902 L
.3189 .30902 L
.31963 .30902 L
.32033 .30902 L
.32163 .30902 L
.32278 .30902 L
.32383 .30902 L
.32495 .30902 L
.32617 .30902 L
.32729 .30902 L
.32833 .30902 L
.32932 .30902 L
.33037 .30902 L
.33151 .30902 L
.33272 .30902 L
.33387 .30902 L
.33492 .30902 L
.33614 .30902 L
.33684 .30902 L
.33748 .30902 L
.33866 .30902 L
.3399 .30902 L
.34104 .30902 L
.34229 .30902 L
.3435 .30902 L
.3448 .30902 L
.34602 .30902 L
.34712 .30902 L
.34817 .30902 L
.34928 .30902 L
.35058 .30902 L
.35178 .30902 L
.35307 .30902 L
.35381 .30902 L
.35448 .30902 L
.35571 .30902 L
.35702 .30902 L
.35824 .30902 L
.35939 .30902 L
.36055 .30902 L
.36159 .30902 L
.3628 .30902 L
.36393 .30902 L
.36499 .30902 L
.36596 .30902 L
.36702 .30902 L
.36814 .30902 L
.36937 .30902 L
.37007 .30902 L
.37071 .30902 L
Mistroke
.37188 .30902 L
.37313 .30902 L
.37425 .30902 L
.37529 .30902 L
.37644 .30902 L
.37768 .30902 L
.37889 .30902 L
.37958 .30902 L
.38022 .30902 L
.38139 .30902 L
.38264 .30902 L
.38387 .30902 L
.38503 .30902 L
.38606 .30902 L
.38719 .30902 L
.38842 .30902 L
.38911 .30902 L
.38977 .30902 L
.39108 .30902 L
.39182 .30902 L
.39249 .30902 L
.39369 .30902 L
.39499 .30902 L
.39623 .30902 L
.39737 .30902 L
.39842 .30902 L
.39955 .30902 L
.40062 .30902 L
.4016 .30902 L
.40268 .30902 L
.40387 .30902 L
.40511 .30902 L
.40626 .30902 L
.41572 .30902 L
.45475 .30902 L
.49624 .30902 L
.53621 .30902 L
.57466 .30902 L
.61557 .30902 L
.65496 .30902 L
.69283 .30902 L
.73316 .30902 L
.77197 .30902 L
.81324 .30902 L
.85299 .30902 L
.89122 .30902 L
.9319 .30902 L
.97107 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000Coool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool0043oool306Ko=?ooo`030000oooooooo0:Koool003koool306Ko00?oool0I_oo
ool0<oooo`030000oooooooo0:Koool001Ooool400008Oooo`80I_l5oooo00<0I_ooooooool00_oo
o`D0000Zoooo0P0002coool50000:oooo`@0000^oooo0P0001Ooool001Ooool00`000?ooooooo`0N
oooo101Vo`Soool00`1Vooooooooo`03oooo00<0003oooooool0:_ooo`030000oooooooo02goool0
0`000?ooooooo`0[oooo00<0003oooooool0;_ooo`040000oooooooo00005_ooo`006?ooo`030000
oooooooo01Woool406Ko3?ooo`0306Kooooooooo00?oool00`000?ooooooo`0Zoooo00<0003ooooo
ool0;Oooo`030000oooooooo02coool00`000?ooooooo`0_oooo00<0003oooooool05Oooo`004Ooo
o`@00004oooo00<0003oooooool05Oooo`<0I_l>oooo100000Coool00`000?ooooooo`0Zoooo00<0
003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0003oooooool05?oo
o`005oooo`040000oooooooo00004_ooo`@0I_lEoooo00D0I_ooooooooooool00000;?ooo`80000^
oooo00<0003oooooool0:oooo`040000oooooooo0000;Oooo`040000oooooooo00005_ooo`006?oo
o`80000<oooo1`1Voa[oool0101Vooooo`00000002coool00`000?ooooooo`0/oooo0P0002koool2
0000;oooo`80000Goooo000Noooo201Vob;oool00`1Vooooooooo`0/oooo00<0003oooooool0Y_oo
o`006Oooo`D0I_l[oooo00<0I_ooooooool0:oooo`80002Woooo000Foooo0`1Voc3oool00`1Voooo
ooooo`0[oooo00<0003oooooool0Y_ooo`00B_ooo`0306Kooooooooo02[oool00`000?ooooooo`2V
oooo001:oooo00<0I_ooooooool0:_ooo`030000oooooooo0:Koool0013ooooo00004Oooo`005_oo
o`P00002<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0003oooooool01_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?oo
ooooo`02oooo00?o09Woooooool00_ooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
01Goool001Koool00`000?ooooooo`05oooo2P0001lco`000`0003?o03?o000]<ol000<0003ooooo
ool0;Oooo`030000oooooooo00;oool00ol0VOooooooo`0Xoooo00<0003oooooool0;_ooo`030000
oooooooo01Goool002Soool60000BC?o00030000oooooooo03;oool00ol0VOooooooo`1aoooo000^
oooo1@0004@co`020000<oooo`03o`2Ioooooooo077oool003?oool40000@3?o00030000oooooooo
03;oool00ol0VOooooooo`1aoooo000goooo0P0003hco`000`000?ooooooo`0boooo00?o09Wooooo
ool0LOooo`00>Oooo`<0000k<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool003coool2
0000>C?o0080000coooo00?o09Woooooool0LOooo`00?_ooo`80000g<ol000<0003oooooool0<_oo
o`03o`2Ioooooooo077oool0043oool20000=C?o00030000oooooooo03;oool00ol0VOooooooo`1a
oooo0012oooo0P0003<co`000`000?ooooooo`0boooo00?o09Woooooool0LOooo`00A?ooo`80000a
<ol00P0003?oool00ol0VOooooooo`1aoooo0016oooo00<0000co`0co`00;S?o00030000oooooooo
03;oool00ol0VOooooooo`1aoooo0017oooo00<0000co`0co`00;C?o00030000oooooooo03;oool0
0ol0VOooooooo`1aoooo0018oooo00<0000co`0co`00;3?o00030000oooooooo03;oool00ol0VOoo
ooooo`1aoooo0019oooo00<0000co`0co`00:c?o0080000coooo00?o09Woooooool0LOooo`00B_oo
o`030000<ol0<ol002Xco`000`000?ooooooo`0boooo00?o09Woooooool0LOooo`00Boooo`030000
<ol0<ol0010co`02000013?o00800003<ol0100000<co`0200001C?o00030000oooooooo03;oool0
0ol0VOooooooo`1aoooo001<oooo00<0000co`0co`003S?o00040000<ol0<ol0000023?o00030000
<ol0<ol000<co`00100003?o03?o000000@co`000`000?ooooooo`0boooo00?o09Woooooool0LOoo
o`00COooo`030000<ol0<ol000dco`00100003?o03?o000000Tco`000`0003?o03?o0005<ol000<0
000co`0co`000S?o0080000coooo00?o09Woooooool0LOooo`00C_ooo`030000<ol0<ol000`co`00
100003?o03?o000000Xco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`0boooo00?o
09Woooooool0LOooo`00Coooo`030000<ol0<ol000/co`00100003?o03?o000000Pco`00100003?o
03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool0
04ooool00`0003?o03?o000<<ol00P0000Xco`02000013?o00<00004<ol000<0003oooooool0<_oo
o`03o`2Ioooooooo077oool0053oool00`0003?o03?o000T<ol00P0003?oool00ol0VOooooooo`1a
oooo001Aoooo00<0000co`0co`008c?o00030000oooooooo03;oool00ol0VOooooooo`1aoooo001B
oooo00<0000co`0co`008S?o00030000oooooooo03;oool00ol0VOooooooo`1aoooo001Boooo00<0
000co`0co`008S?o00030000oooooooo03;oool00ol0VOooooooo`1aoooo001Coooo00<0000co`0c
o`008C?o0080000coooo00?o09Woooooool0LOooo`00Doooo`030000<ol0<ol0024co`000`000?oo
ooooo`0boooo00?o09Woooooool0LOooo`00E?ooo`030000<ol0<ol0020co`000`000?ooooooo`0b
oooo00?o09Woooooool0LOooo`00E?ooo`030000<ol0<ol0020co`000`000?ooooooo`0boooo00?o
09Woooooool0LOooo`00EOooo`030000<ol0<ol001lco`020000<oooo`03o`2Ioooooooo077oool0
05Goool00`0003?o03?o000O<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool005Koool0
0`0003?o03?o000N<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool005Koool00`0003?o
03?o000N<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool005Ooool00`0003?o03?o000M
<ol00P0003?oool00ol0VOooooooo`1aoooo001Goooo00<0000co`0co`007C?o00030000oooooooo
03;oool00ol0VOooooooo`1aoooo001Hoooo00<0000co`0co`002C?o00800004<ol00P0000@co`02
00001C?o00030000oooooooo03;oool00ol0VOooooooo`1aoooo001Hoooo00<0000co`0co`0023?o
00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000oooooooo03;oool00ol0VOoo
ooooo`1aoooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002c?o00030000<ol0<ol0
008co`020000<oooo`03o`2Ioooooooo077oool005Woool00`0003?o03?o0007<ol000@0000co`0c
o`000009<ol00P0000Dco`000`000?ooooooo`0boooo00?o09Woooooool0LOooo`00FOooo`030000
<ol0<ol000Lco`00100003?o03?o000000Tco`000`0003?o03?o0004<ol000<0003oooooool0<_oo
o`03o`2Ioooooooo077oool005[oool00`0003?o03?o0007<ol00P0000Xco`03000013?o00030000
oooooooo03;oool00ol0VOooooooo`1aoooo001Joooo00<0000co`0co`006S?o0080000coooo00?o
09Woooooool0LOooo`00F_ooo`030000<ol0<ol001Xco`000`000?ooooooo`0boooo00?o09Wooooo
ool0LOooo`00Foooo`030000<ol0<ol001Tco`000`000?ooooooo`0boooo00?o09Woooooool0LOoo
o`00Foooo`030000<ol0<ol001Tco`020000<oooo`03o`2Ioooooooo077oool005_oool00`0003?o
03?o000I<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool005coool00`0003?o03?o000H
<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool005coool00`0003?o03?o000H<ol000<0
003oooooool0<_ooo`03o`2Ioooooooo077oool005coool00`0003?o03?o000H<ol00P0003?oool0
0ol0VOooooooo`1aoooo001Moooo00<0000co`0co`005c?o00030000oooooooo03;oool00ol0VOoo
ooooo`1aoooo001Moooo00<0000co`0co`005c?o00030000oooooooo03;oool00ol0VOooooooo`1a
oooo001Moooo00<0000co`0co`005c?o00030000oooooooo03;oool00ol0VOooooooo`1aoooo001N
oooo00<0000co`0co`005S?o0080000coooo00?o09Woooooool0LOooo`00G_ooo`030000<ol0<ol0
01Hco`000`000?ooooooo`0boooo00?o09Woooooool0LOooo`00G_ooo`800004<ol00P0000Dco`00
0`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`0boooo00?o09Woooooool0LOooo`00GOoo
o`040000oooo000000002S?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0
003oooooool0<_ooo`03o`2Ioooooooo077oool005goool010000?ooo`00000000Xco`000`0003?o
03?o0004<ol000<0000co`0co`000S?o0080000coooo00?o09Woooooool0LOooo`00GOooo`040000
oooo000000002c?o00040000<ol0<ol0<ol00P0000Dco`000`000?ooooooo`0boooo00?o09Wooooo
ool0LOooo`00GOooo`040000oooooooo000023?o00040000<ol0<ol000000c?o00030000<ol0<ol0
00@co`000`000?ooooooo`0boooo00?o09Woooooool0LOooo`00G_ooo`<00008<ol0100000<co`03
000013?o00030000oooooooo03;oool00ol0VOooooooo`1aoooo001Poooo00<0000co`0co`0053?o
0080000coooo00?o09Woooooool0LOooo`00H?ooo`030000<ol0<ol001@co`000`000?ooooooo`0b
oooo00?o09Woooooool0LOooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`0boooo00?o
09Woooooool0LOooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`0boooo00?o09Wooooo
ool0LOooo`00HOooo`030000<ol0<ol001<co`020000<oooo`03o`2Ioooooooo077oool0067oool0
0`0003?o03?o000C<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool006;oool00`0003?o
03?o000B<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool006;oool00`0003?o03?o000B
<ol000<0003oooooool0<_ooo`03o`2Ioooooooo077oool006;oool00`0003?o03?o000B<ol00P00
03?oool00ol0VOooooooo`1aoooo001Roooo00<0000co`0co`004S?o00030000oooooooo03;oool0
0ol0VOooooooo`1aoooo001Soooo00<0000co`0co`004C?o00030000oooooooo03;oool00ol0VOoo
ooooo`1aoooo001Soooo00<0000co`0co`004C?o00030000oooooooo03;oool00ol0VOooooooo`1a
oooo001Soooo00<0000co`0co`004C?o0080000coooo00?o09Woooooool0LOooo`00Hoooo`030000
<ol0<ol0014co`000`000?ooooooo`0boooo00?o09Woooooool0LOooo`00Hoooo`030000<ol0<ol0
00Tco`0500000c?o00030000oooooooo03;oool00ol0VOooooooo`1aoooo001Toooo00<0000co`0c
o`002S?o00030000<ol0<ol000<co`000`000?ooooooo`0boooo00?o09Woooooool0LOooo`00I?oo
o`030000<ol0<ol000Xco`000`0003?o03?o0003<ol00P0003?oool00ol0VOooooooo`1aoooo001T
oooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001T
oooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol01Ooo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001Uoooo4S?o00Coool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool006GooolB<ol01?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo1@0000;oool00`000?oo
ooooo`1koooo001Uoooo4S?o00Coool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003ooooo
ool0Noooo`00IOoooa8co`03oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00I_oooa4co`04oooo00<0
003oooooool01@0000coool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003ooooo
ool0Noooo`00I_oooa4co`04oooo00D0003oooooooooool000003oooo`040000oooooooo00002_oo
o`030000oooooooo00;oool00`000?ooooooo`1koooo001Voooo4C?o00Goool00`000?ooooooo`0A
oooo0P0000[oool200000oooo`030000oooooooo07coool006KooolA<ol0ZOooo`00I_oooa4co`2Y
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.60873 .30902 L
.61984 .30902 L
.6254 .30902 L
.62812 .30902 L
.63064 .30902 L
.63182 .30902 L
.63292 .30902 L
s
.63292 .30902 m
.63304 .61803 L
s
0 .4 1 r
.02381 .27885 m
.06244 .26882 L
.10458 .254 L
.14415 .23509 L
.1544 .2292 L
.16408 .2232 L
.1683 .22044 L
.17277 .21741 L
.1739 .21664 L
.17511 .21579 L
.1758 .21531 L
.17643 .21525 L
.17768 .2164 L
.18221 .22067 L
.20178 .24085 L
.22272 .26595 L
.23268 .27935 L
.24331 .2948 L
.24847 .30277 L
.2497 .30472 L
.251 .3068 L
.25212 .30859 L
.25333 .30902 L
.25442 .30902 L
.25559 .30902 L
.2567 .30902 L
.2577 .30902 L
.25886 .30902 L
.26013 .30902 L
.26132 .30902 L
.26243 .30902 L
.26357 .30902 L
.26461 .30902 L
.26576 .30902 L
.26697 .30902 L
.26802 .30902 L
.269 .30902 L
.27008 .30902 L
.27123 .30902 L
.27248 .30902 L
.27319 .30902 L
.27385 .30902 L
.27505 .30902 L
.27632 .30902 L
.27746 .30902 L
.27852 .30902 L
.27969 .30902 L
.28094 .30902 L
.28225 .30902 L
.28347 .30902 L
Mistroke
.28417 .30902 L
.2848 .30902 L
.28553 .30902 L
.28622 .30902 L
.28739 .30902 L
.28862 .30902 L
.28927 .30902 L
.28998 .30902 L
.29122 .30902 L
.29245 .30902 L
.29357 .30902 L
.29486 .30902 L
.29609 .30902 L
.29722 .30902 L
.29826 .30902 L
.2994 .30902 L
.30062 .30902 L
.30176 .30902 L
.30301 .30902 L
.30431 .30902 L
.30552 .30902 L
.30666 .30902 L
.3077 .30902 L
.30889 .30902 L
.31001 .30902 L
.31124 .30902 L
.31254 .30902 L
.31365 .30902 L
.31487 .30902 L
.31618 .30902 L
.31692 .30902 L
.31759 .30902 L
.31889 .30902 L
.32013 .30902 L
.32118 .30902 L
.32233 .30902 L
.32354 .30902 L
.32468 .30902 L
.32573 .30902 L
.3267 .30902 L
.32777 .30902 L
.32889 .30902 L
.33003 .30902 L
.33124 .30902 L
.33239 .30902 L
.33344 .30902 L
.33467 .30902 L
.33536 .30902 L
.336 .30902 L
.33842 .30902 L
Mistroke
.33956 .30902 L
.34081 .30902 L
.34199 .30902 L
.34308 .30902 L
.34435 .30902 L
.34506 .30902 L
.3457 .30902 L
.34694 .30902 L
.3481 .30902 L
.3492 .30902 L
.35037 .30902 L
.35136 .30902 L
.35245 .30902 L
.35363 .30902 L
.35489 .30902 L
.35608 .30902 L
.35716 .30902 L
.35844 .30902 L
.35909 .30902 L
.3598 .30902 L
.36106 .30902 L
.36224 .30902 L
.36291 .30902 L
.36362 .30902 L
.3649 .30902 L
.3656 .30902 L
.36626 .30902 L
.36699 .30902 L
.36776 .30902 L
.36906 .30902 L
.36974 .30902 L
.37046 .30902 L
.3711 .30902 L
.37179 .30902 L
.37302 .30902 L
.37422 .30902 L
.37549 .30902 L
.3767 .30902 L
.37779 .30902 L
.37908 .30902 L
.38029 .30902 L
.3816 .30902 L
.38234 .30902 L
.38301 .30902 L
.38426 .30902 L
.38542 .30902 L
.38664 .30902 L
.38728 .30902 L
.38796 .30902 L
.38916 .30902 L
Mistroke
.39046 .30902 L
.39169 .30902 L
.39283 .30902 L
.39385 .30902 L
.39498 .30902 L
.39615 .30902 L
.39725 .30902 L
.39854 .30902 L
.39927 .30902 L
.39995 .30902 L
.40119 .30902 L
.40251 .30902 L
.40381 .30902 L
.40503 .30902 L
.40613 .30902 L
.40732 .30902 L
.41815 .30902 L
.45914 .30902 L
.49862 .30902 L
.53658 .30902 L
.57699 .30902 L
.61589 .30902 L
.65723 .30902 L
.69707 .30902 L
.73538 .30902 L
.77615 .30902 L
.81541 .30902 L
.85315 .30902 L
.89334 .30902 L
.93201 .30902 L
.97314 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`80002Woooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool003coool206Ko>Oooo`80002Woooo000k
oooo00@0I_ooooooool0I_lhoooo00<0003oooooool0Y_ooo`00>Oooo`80I_l4oooo00<0I_oooooo
ool07?ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0Y_ooo`00=ooo
o`80I_l7oooo00<0I_ooooooool06_ooo`040000oooooooo00002?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`2Voooo000foooo00<0I_ooooooool02?ooo`0306Ko
oooooooo01Woool010000?ooooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_oo
o`80002Woooo000doooo0P1Vo`coool00`1Vooooooooo`0Boooo100000;oool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2Voooo000boooo0P1Vo`ooool0
0`1Vooooooooo`0Goooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo0:Koool002ooool306Ko4_ooo`0306Kooooooooo01Ooool200002_oo
o`800004oooo0`0000Coool00`000?ooooooo`2Voooo000]oooo0P1VoaKoool00`1Vooooooooo`0_
oooo0P000:Ooool002[oool306Ko6Oooo`0306Kooooooooo02koool00`000?ooooooo`2Voooo000W
oooo0`1Voagoool00`1Vooooooooo`0]oooo00<0003oooooool0Y_ooo`009Oooo`80I_lQoooo00<0
I_ooooooool0;?ooo`030000oooooooo0:Koool001Ooool400001oooo`<0I_lSoooo1@0002[oool2
0000;?ooo`D0000[oooo100002koool200005oooo`005oooo`030000oooooooo00Goool306Ko9ooo
o`0306Ko0000oooo02_oool00`000?ooooooo`0]oooo00<0003oooooool0:oooo`030000oooooooo
02koool010000?ooooooo`0001Koool001Soool010000?ooooooooooo`<0I_l[oooo00<0003ooooo
ool0:_ooo`030000oooooooo02goool00`000?ooooooo`0/oooo00<0003oooooool0;oooo`030000
oooooooo01Goool0017oool400000oooo`0406Ko000006Ko06Ko9_ooo`@00004oooo00<0003ooooo
ool0:_ooo`030000oooooooo02goool00`000?ooooooo`0]oooo00<0003oooooool0;oooo`030000
oooooooo01Coool001Koool01@1Vo`000?ooooooo`00000_oooo00<00000I_ooool0:_ooo`80000^
oooo00<0003oooooool0:oooo`040000oooooooo0000;Oooo`040000oooooooo00005_ooo`006?oo
o`80000_oooo0P000003oooo06Kooooo02Woool00`000?ooooooo`0/oooo0P0002koool20000;ooo
o`80000Goooo001<oooo00<0I_ooooooool0:?ooo`030000oooooooo0:Koool004goool00`1Voooo
ooooo`0Woooo0P000:Ooool004koool00`1Vooooooooo`0Voooo00<0003oooooool0Y_ooo`00C_oo
o`0306Kooooooooo02Koool00`000?ooooooo`2Voooo001?oooo0P1VobKoool00`000?ooooooo`2V
oooo000@ooooo`00017oool001Koool800000S?o00030000<ol0<ol000Lco`000`0003?o03?o0006
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000
oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`05oooo2P0001lco`000`0003?o03?o000]<ol000<0
003oooooool0;Oooo`030000oooooooo00Ooool00ol0VOooooooo`0Soooo00<0003oooooool0;_oo
o`030000oooooooo01Goool002Soool60000BC?o00030000oooooooo03Ooool00ol0VOooooooo`1/
oooo000^oooo1@0004@co`020000>?ooo`03o`2Ioooooooo06coool003?oool40000@3?o00030000
oooooooo03Ooool00ol0VOooooooo`1/oooo000goooo0P0003hco`000`000?ooooooo`0goooo00?o
09Woooooool0K?ooo`00>Oooo`<0000k<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool0
03coool20000>C?o0080000hoooo00?o09Woooooool0K?ooo`00?_ooo`80000g<ol000<0003ooooo
ool0=oooo`03o`2Ioooooooo06coool0043oool20000=C?o00030000oooooooo03Ooool00ol0VOoo
ooooo`1/oooo0012oooo0P0003<co`000`000?ooooooo`0goooo00?o09Woooooool0K?ooo`00A?oo
o`80000a<ol00P0003Soool00ol0VOooooooo`1/oooo0016oooo00<0000co`0co`00;S?o00030000
oooooooo03Ooool00ol0VOooooooo`1/oooo0017oooo00<0000co`0co`00;C?o00030000oooooooo
03Ooool00ol0VOooooooo`1/oooo0018oooo00<0000co`0co`00;3?o00030000oooooooo03Ooool0
0ol0VOooooooo`1/oooo0019oooo00<0000co`0co`00:c?o0080000hoooo00?o09Woooooool0K?oo
o`00B_ooo`030000<ol0<ol002Xco`000`000?ooooooo`0goooo00?o09Woooooool0K?ooo`00Booo
o`030000<ol0<ol0010co`02000013?o00800003<ol0100000<co`0200001C?o00030000oooooooo
03Ooool00ol0VOooooooo`1/oooo001<oooo00<0000co`0co`003S?o00040000<ol0<ol0000023?o
00030000<ol0<ol000<co`00100003?o03?o000000@co`000`000?ooooooo`0goooo00?o09Wooooo
ool0K?ooo`00COooo`030000<ol0<ol000dco`00100003?o03?o000000Tco`000`0003?o03?o0005
<ol000<0000co`0co`000S?o0080000hoooo00?o09Woooooool0K?ooo`00C_ooo`030000<ol0<ol0
00`co`00100003?o03?o000000Xco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`0g
oooo00?o09Woooooool0K?ooo`00Coooo`030000<ol0<ol000/co`00100003?o03?o000000Pco`00
100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0=oooo`03o`2Ioooooooo
06coool004ooool00`0003?o03?o000<<ol00P0000Xco`02000013?o00<00004<ol000<0003ooooo
ool0=oooo`03o`2Ioooooooo06coool0053oool00`0003?o03?o000T<ol00P0003Soool00ol0VOoo
ooooo`1/oooo001Aoooo00<0000co`0co`008c?o00030000oooooooo03Ooool00ol0VOooooooo`1/
oooo001Boooo00<0000co`0co`008S?o00030000oooooooo03Ooool00ol0VOooooooo`1/oooo001B
oooo00<0000co`0co`008S?o00030000oooooooo03Ooool00ol0VOooooooo`1/oooo001Coooo00<0
000co`0co`008C?o0080000hoooo00?o09Woooooool0K?ooo`00Doooo`030000<ol0<ol0024co`00
0`000?ooooooo`0goooo00?o09Woooooool0K?ooo`00E?ooo`030000<ol0<ol0020co`000`000?oo
ooooo`0goooo00?o09Woooooool0K?ooo`00E?ooo`030000<ol0<ol0020co`000`000?ooooooo`0g
oooo00?o09Woooooool0K?ooo`00EOooo`030000<ol0<ol001lco`020000>?ooo`03o`2Ioooooooo
06coool005Goool00`0003?o03?o000O<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool0
05Koool00`0003?o03?o000N<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool005Koool0
0`0003?o03?o000N<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool005Ooool00`0003?o
03?o000M<ol00P0003Soool00ol0VOooooooo`1/oooo001Goooo00<0000co`0co`007C?o00030000
oooooooo03Ooool00ol0VOooooooo`1/oooo001Hoooo00<0000co`0co`002C?o00800004<ol00P00
00@co`0200001C?o00030000oooooooo03Ooool00ol0VOooooooo`1/oooo001Hoooo00<0000co`0c
o`0023?o00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000oooooooo03Ooool0
0ol0VOooooooo`1/oooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002c?o00030000
<ol0<ol0008co`020000>?ooo`03o`2Ioooooooo06coool005Woool00`0003?o03?o0007<ol000@0
000co`0co`000009<ol00P0000Dco`000`000?ooooooo`0goooo00?o09Woooooool0K?ooo`00FOoo
o`030000<ol0<ol000Lco`00100003?o03?o000000Tco`000`0003?o03?o0004<ol000<0003ooooo
ool0=oooo`03o`2Ioooooooo06coool005[oool00`0003?o03?o0007<ol00P0000Xco`03000013?o
00030000oooooooo03Ooool00ol0VOooooooo`1/oooo001Joooo00<0000co`0co`006S?o0080000h
oooo00?o09Woooooool0K?ooo`00F_ooo`030000<ol0<ol001Xco`000`000?ooooooo`0goooo00?o
09Woooooool0K?ooo`00Foooo`030000<ol0<ol001Tco`000`000?ooooooo`0goooo00?o09Wooooo
ool0K?ooo`00Foooo`030000<ol0<ol001Tco`020000>?ooo`03o`2Ioooooooo06coool005_oool0
0`0003?o03?o000I<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool005coool00`0003?o
03?o000H<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool005coool00`0003?o03?o000H
<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool005coool00`0003?o03?o000H<ol00P00
03Soool00ol0VOooooooo`1/oooo001Moooo00<0000co`0co`005c?o00030000oooooooo03Ooool0
0ol0VOooooooo`1/oooo001Moooo00<0000co`0co`005c?o00030000oooooooo03Ooool00ol0VOoo
ooooo`1/oooo001Moooo00<0000co`0co`005c?o00030000oooooooo03Ooool00ol0VOooooooo`1/
oooo001Noooo00<0000co`0co`005S?o0080000hoooo00?o09Woooooool0K?ooo`00G_ooo`030000
<ol0<ol001Hco`000`000?ooooooo`0goooo00?o09Woooooool0K?ooo`00G_ooo`800004<ol00P00
00Dco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`0goooo00?o09Woooooool0K?oo
o`00GOooo`040000oooo000000002S?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002
<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool005goool010000?ooo`00000000Xco`00
0`0003?o03?o0004<ol000<0000co`0co`000S?o0080000hoooo00?o09Woooooool0K?ooo`00GOoo
o`040000oooo000000002c?o00040000<ol0<ol0<ol00P0000Dco`000`000?ooooooo`0goooo00?o
09Woooooool0K?ooo`00GOooo`040000oooooooo000023?o00040000<ol0<ol000000c?o00030000
<ol0<ol000@co`000`000?ooooooo`0goooo00?o09Woooooool0K?ooo`00G_ooo`<00008<ol01000
00<co`03000013?o00030000oooooooo03Ooool00ol0VOooooooo`1/oooo001Poooo00<0000co`0c
o`0053?o0080000hoooo00?o09Woooooool0K?ooo`00H?ooo`030000<ol0<ol001@co`000`000?oo
ooooo`0goooo00?o09Woooooool0K?ooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`0g
oooo00?o09Woooooool0K?ooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`0goooo00?o
09Woooooool0K?ooo`00HOooo`030000<ol0<ol001<co`020000>?ooo`03o`2Ioooooooo06coool0
067oool00`0003?o03?o000C<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool006;oool0
0`0003?o03?o000B<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool006;oool00`0003?o
03?o000B<ol000<0003oooooool0=oooo`03o`2Ioooooooo06coool006;oool00`0003?o03?o000B
<ol00P0003Soool00ol0VOooooooo`1/oooo001Roooo00<0000co`0co`004S?o00030000oooooooo
03Ooool00ol0VOooooooo`1/oooo001Soooo00<0000co`0co`004C?o00030000oooooooo03Ooool0
0ol0VOooooooo`1/oooo001Soooo00<0000co`0co`004C?o00030000oooooooo03Ooool00ol0VOoo
ooooo`1/oooo001Soooo00<0000co`0co`004C?o0080000hoooo00?o09Woooooool0K?ooo`00Hooo
o`030000<ol0<ol0014co`000`000?ooooooo`0goooo00?o09Woooooool0K?ooo`00Hoooo`030000
<ol0<ol000Tco`0500000c?o00030000oooooooo03Ooool00ol0VOooooooo`1/oooo001Toooo00<0
000co`0co`002S?o00030000<ol0<ol000<co`000`000?ooooooo`0goooo00?o09Woooooool0K?oo
o`00I?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol00P0003Soool00ol0VOooooooo`1/
oooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Y
oooo001Toooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB
<ol01Oooo`030000oooooooo02;oool00`000?ooooooo`1loooo001Uoooo4S?o00Coool00`000?oo
ooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool006GooolB<ol01?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo100000?oool0
0`000?ooooooo`1koooo001Uoooo4S?o00Coool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool00`000?ooooooo`04oooo00<0
003oooooool0Noooo`00IOoooa8co`03oooo00<0003oooooool00_ooo`030000oooooooo00goool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0N_ooo`00I_oooa4co`04
oooo00<0003oooooool01@0000coool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0
003oooooool0Noooo`00I_oooa4co`04oooo00D0003oooooooooool000003oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool006KooolA<ol01Oooo`030000
oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00I_oooa4co`2Yoooo001V
oooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.61984 .30902 L
.6298 .30902 L
.64043 .30902 L
.64559 .30902 L
.64812 .30902 L
.64923 .30902 L
.65045 .30902 L
.65155 .30902 L
s
.65155 .30902 m
.65165 .61803 L
s
0 .4 1 r
.02381 .26302 m
.06244 .24771 L
.10458 .22511 L
.12507 .21126 L
.13506 .20369 L
.14415 .19628 L
.14868 .19239 L
.15107 .19029 L
.1536 .18802 L
.15581 .186 L
.15707 .18483 L
.15825 .18554 L
.16254 .18858 L
.18221 .2038 L
.22098 .2411 L
.24069 .2646 L
.2511 .2785 L
.2622 .29457 L
.26777 .30316 L
.26909 .30526 L
.27049 .30751 L
.27169 .30902 L
.273 .30902 L
.27418 .30902 L
.27544 .30902 L
.27662 .30902 L
.27771 .30902 L
.27896 .30902 L
.27967 .30902 L
.28032 .30902 L
.28152 .30902 L
.2828 .30902 L
.28397 .30902 L
.28505 .30902 L
.28624 .30902 L
.28748 .30902 L
.28857 .30902 L
.28958 .30902 L
.2907 .30902 L
.29188 .30902 L
.29318 .30902 L
.29391 .30902 L
.29459 .30902 L
.29583 .30902 L
.29714 .30902 L
.29831 .30902 L
.29941 .30902 L
.30062 .30902 L
.30191 .30902 L
.3026 .30902 L
Mistroke
.30325 .30902 L
.30446 .30902 L
.30576 .30902 L
.3065 .30902 L
.30717 .30902 L
.3083 .30902 L
.30954 .30902 L
.31084 .30902 L
.31204 .30902 L
.31273 .30902 L
.31348 .30902 L
.31418 .30902 L
.31484 .30902 L
.31607 .30902 L
.31738 .30902 L
.31869 .30902 L
.31942 .30902 L
.32009 .30902 L
.32085 .30902 L
.32164 .30902 L
.32233 .30902 L
.32309 .30902 L
.32374 .30902 L
.32445 .30902 L
.32573 .30902 L
.32698 .30902 L
.32813 .30902 L
.32937 .30902 L
.33008 .30902 L
.33074 .30902 L
.33144 .30902 L
.33208 .30902 L
.33281 .30902 L
.33351 .30902 L
.33467 .30902 L
.33591 .30902 L
.33697 .30902 L
.33814 .30902 L
.33939 .30902 L
.3401 .30902 L
.34074 .30902 L
.34194 .30902 L
.34319 .30902 L
.34442 .30902 L
.34511 .30902 L
.34576 .30902 L
.34693 .30902 L
.34818 .30902 L
.3493 .30902 L
.35034 .30902 L
Mistroke
.35149 .30902 L
.35272 .30902 L
.35402 .30902 L
.35476 .30902 L
.35545 .30902 L
.35615 .30902 L
.35681 .30902 L
.35804 .30902 L
.35917 .30902 L
.3604 .30902 L
.3617 .30902 L
.36291 .30902 L
.36396 .30902 L
.36496 .30902 L
.36611 .30902 L
.36716 .30902 L
.36832 .30902 L
.36958 .30902 L
.37075 .30902 L
.37184 .30902 L
.37296 .30902 L
.37401 .30902 L
.37517 .30902 L
.37641 .30902 L
.37764 .30902 L
.37894 .30902 L
.38005 .30902 L
.38127 .30902 L
.38259 .30902 L
.38381 .30902 L
.38444 .30902 L
.38514 .30902 L
.38587 .30902 L
.38656 .30902 L
.38782 .30902 L
.38897 .30902 L
.3896 .30902 L
.39029 .30902 L
.39155 .30902 L
.39278 .30902 L
.3939 .30902 L
.39519 .30902 L
.3964 .30902 L
.39752 .30902 L
.39856 .30902 L
.39969 .30902 L
.40089 .30902 L
.4022 .30902 L
.40339 .30902 L
.40405 .30902 L
Mistroke
.40477 .30902 L
.40607 .30902 L
.41089 .30902 L
.42185 .30902 L
.4627 .30902 L
.50204 .30902 L
.53986 .30902 L
.58014 .30902 L
.6189 .30902 L
.66011 .30902 L
.69981 .30902 L
.73799 .30902 L
.77862 .30902 L
.81774 .30902 L
.85931 .30902 L
.89936 .30902 L
.9379 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Hoooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001T
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000
oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00>?oo
o`0306Kooooooooo03coool20000Yoooo`00=_ooo`80I_l00oooo`1Vooooo`0loooo00<0003ooooo
ool0Y_ooo`00=_ooo`0506Kooooooooooooo06Ko03coool00`000?ooooooo`2Voooo000eoooo00<0
I_ooooooool00oooo`80I_ljoooo00<0003oooooool0Y_ooo`00<oooo`80I_l8oooo00<0I_oooooo
ool0=oooo`80002Woooo000boooo00<0I_ooooooool02Oooo`0306Kooooooooo03Koool00`000?oo
ooooo`2Voooo000aoooo00<0I_ooooooool02oooo`0306Kooooooooo03Goool00`000?ooooooo`2V
oooo000`oooo00<0I_ooooooool03Oooo`0306Kooooooooo03Coool00`000?ooooooo`2Voooo000^
oooo0P1Voa7oool00`1Vooooooooo`0coooo0P000:Ooool002coool206Ko5?ooo`0306Kooooooooo
03;oool00`000?ooooooo`2Voooo000[oooo00<0I_ooooooool05Oooo`80I_lIoooo0P0000Coool2
00000oooo`@00003oooo0P0000Goool00`000?ooooooo`2Voooo000Yoooo0P1Voa[oool00`1Voooo
ooooo`0Eoooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool002Ooool206Ko7Oooo`0306Kooooooooo01Coool010000?ooooooo`00
00Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`80002Woooo000Uoooo0P1Vob3oool0
0`1Vooooooooo`0=oooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P00
00Goool00`000?ooooooo`2Voooo000Soooo0P1Vob?oool00`1Vooooooooo`0Boooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo0:Koool0
027oool206Ko9_ooo`0306Kooooooooo01;oool200002_ooo`800004oooo0`0000Coool00`000?oo
ooooo`2Voooo000Ooooo0P1VobWoool00`1Vooooooooo`0Zoooo0P000:Ooool001goool206Ko:ooo
o`0306Kooooooooo02[oool00`000?ooooooo`2Voooo000Joooo0`1Vobkoool00`1Vooooooooo`0Y
oooo00<0003oooooool0Y_ooo`006?ooo`80I_lboooo00<0I_ooooooool0:?ooo`030000oooooooo
0:Koool001Koool00`1Vo`00000000020000;Oooo`D000000`1Vooooooooo`0Woooo0P0002coool5
0000:oooo`@0000^oooo0P0001Ooool001Ooool00`000?ooooooo`0`oooo00D0003oooooooooool0
I_l0:?ooo`030000oooooooo02goool00`000?ooooooo`0[oooo00<0003oooooool0;_ooo`040000
oooooooo00005_ooo`006?ooo`030000oooooooo02ooool01@000?ooooooooooo`1Vo`0Xoooo00<0
003oooooool0;Oooo`030000oooooooo02coool00`000?ooooooo`0_oooo00<0003oooooool05Ooo
o`004Oooo`@00004oooo00<0003oooooool09_ooo`@00004oooo00<0003oooooool00_ooo`0306Ko
oooooooo02Goool00`000?ooooooo`0]oooo00<0003oooooool0;Oooo`030000oooooooo02ooool0
0`000?ooooooo`0Doooo000Goooo00@0003oooooool0000_oooo00<0003oooooool00oooo`0306Ko
oooooooo02Coool20000;_ooo`030000oooooooo02_oool010000?ooooooo`0002goool010000?oo
ooooo`0001Koool001Soool20000;oooo`800006oooo00<0I_ooooooool08oooo`030000oooooooo
02coool20000;_ooo`80000_oooo0P0001Ooool0057oool00`1Vooooooooo`0Soooo00<0003ooooo
ool0Y_ooo`00D_ooo`0306Kooooooooo02;oool20000Yoooo`00Doooo`0306Kooooooooo027oool0
0`000?ooooooo`2Voooo001Coooo00<0I_ooooooool08Oooo`030000oooooooo0:Koool005Coool0
0`1Vooooooooo`0Poooo00<0003oooooool0Y_ooo`004?ooool0000Aoooo000Foooo2000008co`00
0`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
1@000?ooooooooooool0V@04oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003ooooo
ool01Oooo`X0000O<ol000<0000co`0co`00;C?o00030000oooooooo02goool00`000?ooooooo`0;
oooo00?o09Woooooool07oooo`030000oooooooo02koool00`000?ooooooo`0Eoooo000Xoooo1P00
04Tco`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00;_ooo`D00014<ol00P0003coool0
0ol0VOooooooo`1Xoooo000coooo1000040co`000`000?ooooooo`0koooo00?o09Woooooool0J?oo
o`00=oooo`80000n<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool003Woool30000>c?o
00030000oooooooo03_oool00ol0VOooooooo`1Xoooo000loooo0P0003Tco`020000??ooo`03o`2I
oooooooo06Soool003koool20000=c?o00030000oooooooo03_oool00ol0VOooooooo`1Xoooo0010
oooo0P0003Dco`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00@_ooo`80000c<ol000<0
003oooooool0>oooo`03o`2Ioooooooo06Soool004Coool20000<C?o0080000loooo00?o09Wooooo
ool0J?ooo`00A_ooo`030000<ol0<ol002hco`000`000?ooooooo`0koooo00?o09Woooooool0J?oo
o`00Aoooo`030000<ol0<ol002dco`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00B?oo
o`030000<ol0<ol002`co`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00BOooo`030000
<ol0<ol002/co`020000??ooo`03o`2Ioooooooo06Soool004[oool00`0003?o03?o000Z<ol000<0
003oooooool0>oooo`03o`2Ioooooooo06Soool004_oool00`0003?o03?o000@<ol00P0000@co`02
00000c?o00@00003<ol00P0000Dco`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00C?oo
o`030000<ol0<ol000hco`00100003?o03?o000000Pco`000`0003?o03?o0003<ol000@0000co`0c
o`000004<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool004goool00`0003?o03?o000=
<ol000@0000co`0co`000009<ol000<0000co`0co`001C?o00030000<ol0<ol0008co`020000??oo
o`03o`2Ioooooooo06Soool004koool00`0003?o03?o000<<ol000@0000co`0co`00000:<ol000<0
000co`0co`000S?o00800005<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool004ooool0
0`0003?o03?o000;<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0c
o`0013?o00030000oooooooo03_oool00ol0VOooooooo`1Xoooo001?oooo00<0000co`0co`0033?o
0080000:<ol00P0000@co`03000013?o00030000oooooooo03_oool00ol0VOooooooo`1Xoooo001@
oooo00<0000co`0co`0093?o0080000loooo00?o09Woooooool0J?ooo`00DOooo`030000<ol0<ol0
02<co`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00D_ooo`030000<ol0<ol0028co`00
0`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00D_ooo`030000<ol0<ol0028co`000`000?oo
ooooo`0koooo00?o09Woooooool0J?ooo`00Doooo`030000<ol0<ol0024co`020000??ooo`03o`2I
oooooooo06Soool005?oool00`0003?o03?o000Q<ol000<0003oooooool0>oooo`03o`2Ioooooooo
06Soool005Coool00`0003?o03?o000P<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool0
05Coool00`0003?o03?o000P<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool005Goool0
0`0003?o03?o000O<ol00P0003coool00ol0VOooooooo`1Xoooo001Eoooo00<0000co`0co`007c?o
00030000oooooooo03_oool00ol0VOooooooo`1Xoooo001Foooo00<0000co`0co`007S?o00030000
oooooooo03_oool00ol0VOooooooo`1Xoooo001Foooo00<0000co`0co`007S?o00030000oooooooo
03_oool00ol0VOooooooo`1Xoooo001Goooo00<0000co`0co`007C?o0080000loooo00?o09Wooooo
ool0J?ooo`00Eoooo`030000<ol0<ol001dco`000`000?ooooooo`0koooo00?o09Woooooool0J?oo
o`00F?ooo`030000<ol0<ol000Tco`02000013?o00800004<ol00P0000Dco`000`000?ooooooo`0k
oooo00?o09Woooooool0J?ooo`00F?ooo`030000<ol0<ol000Pco`00100003?o03?o000000Pco`00
100003?o03?o000000@co`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00FOooo`030000
<ol0<ol000Lco`00100003?o03?o000000/co`000`0003?o03?o0002<ol00P0003coool00ol0VOoo
ooooo`1Xoooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o00800005<ol000<0
003oooooool0>oooo`03o`2Ioooooooo06Soool005Woool00`0003?o03?o0007<ol000@0000co`0c
o`000009<ol000<0000co`0co`0013?o00030000oooooooo03_oool00ol0VOooooooo`1Xoooo001J
oooo00<0000co`0co`001c?o0080000:<ol00`0000@co`000`000?ooooooo`0koooo00?o09Wooooo
ool0J?ooo`00F_ooo`030000<ol0<ol001Xco`020000??ooo`03o`2Ioooooooo06Soool005[oool0
0`0003?o03?o000J<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool005_oool00`0003?o
03?o000I<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool005_oool00`0003?o03?o000I
<ol00P0003coool00ol0VOooooooo`1Xoooo001Koooo00<0000co`0co`006C?o00030000oooooooo
03_oool00ol0VOooooooo`1Xoooo001Loooo00<0000co`0co`0063?o00030000oooooooo03_oool0
0ol0VOooooooo`1Xoooo001Loooo00<0000co`0co`0063?o00030000oooooooo03_oool00ol0VOoo
ooooo`1Xoooo001Loooo00<0000co`0co`0063?o0080000loooo00?o09Woooooool0J?ooo`00GOoo
o`030000<ol0<ol001Lco`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00GOooo`030000
<ol0<ol001Lco`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00GOooo`030000<ol0<ol0
01Lco`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00G_ooo`030000<ol0<ol001Hco`02
0000??ooo`03o`2Ioooooooo06Soool005koool00`0003?o03?o000F<ol000<0003oooooool0>ooo
o`03o`2Ioooooooo06Soool005koool2000013?o00800005<ol000<0000co`0co`000S?o00800005
<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool005goool010000?ooo`00000000Xco`00
1@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000oooooooo03_oool00ol0VOoo
ooooo`1Xoooo001Moooo00@0003oool00000000:<ol000<0000co`0co`0013?o00030000<ol0<ol0
008co`020000??ooo`03o`2Ioooooooo06Soool005goool010000?ooo`00000000/co`00100003?o
03?o03?o00800005<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool005goool010000?oo
ooooo`0000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0>ooo
o`03o`2Ioooooooo06Soool005koool3000023?o00@00003<ol00`0000@co`000`000?ooooooo`0k
oooo00?o09Woooooool0J?ooo`00H?ooo`030000<ol0<ol001@co`020000??ooo`03o`2Ioooooooo
06Soool0063oool00`0003?o03?o000D<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool0
067oool00`0003?o03?o000C<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool0067oool0
0`0003?o03?o000C<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool0067oool00`0003?o
03?o000C<ol00P0003coool00ol0VOooooooo`1Xoooo001Qoooo00<0000co`0co`004c?o00030000
oooooooo03_oool00ol0VOooooooo`1Xoooo001Roooo00<0000co`0co`004S?o00030000oooooooo
03_oool00ol0VOooooooo`1Xoooo001Roooo00<0000co`0co`004S?o00030000oooooooo03_oool0
0ol0VOooooooo`1Xoooo001Roooo00<0000co`0co`004S?o0080000loooo00?o09Woooooool0J?oo
o`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00Hooo
o`030000<ol0<ol0014co`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00Hoooo`030000
<ol0<ol0014co`000`000?ooooooo`0koooo00?o09Woooooool0J?ooo`00Hoooo`030000<ol0<ol0
014co`020000??ooo`03o`2Ioooooooo06Soool006?oool00`0003?o03?o000A<ol000<0003ooooo
ool0>oooo`03o`2Ioooooooo06Soool006?oool00`0003?o03?o0009<ol01@0000<co`000`000?oo
ooooo`0koooo00?o09Woooooool0J?ooo`00I?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003
<ol000<0003oooooool0>oooo`03o`2Ioooooooo06Soool006Coool00`0003?o03?o000:<ol000<0
000co`0co`000c?o0080000loooo00?o09Woooooool0J?ooo`00I?ooo`dco`000`0003?o03?o0003
<ol0ZOooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo``co`0200001C?o0:Woool0
06GooolB<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o00Goool00`000?ooooooo`0Roooo00<0
003oooooool0O?ooo`00IOoooa8co`04oooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001Uoooo4S?o00Coool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0Noooo`00IOoooa8co`04
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00IOoooa8co`03
oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000[oool00`000?oo
ooooo`03oooo00<0003oooooool0N_ooo`00I_oooa4co`04oooo00<0003oooooool01@0000coool0
10000?ooooooo`0000_oool01@000?ooooooooooo`00001moooo001Voooo4C?o00Coool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00I_oooa4co`05oooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?oo
ooooo`1loooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65045 .30902 L
.65954 .30902 L
.66412 .30902 L
.66652 .30902 L
.66906 .30902 L
.67014 .30902 L
.67129 .30902 L
s
.67129 .30902 m
.67142 .61803 L
s
0 .4 1 r
.02381 .24626 m
.06244 .22538 L
.10458 .19455 L
.11448 .18578 L
.12507 .17565 L
.1302 .17043 L
.13273 .1678 L
.13506 .16531 L
.13718 .16302 L
.13824 .1621 L
.13942 .16271 L
.14415 .16526 L
.18221 .18926 L
.2225 .22307 L
.26127 .26663 L
.28098 .29417 L
.28638 .30247 L
.2878 .30472 L
.28934 .30718 L
.29005 .30832 L
.2908 .30902 L
.29143 .30902 L
.29213 .30902 L
.29494 .30902 L
.29565 .30902 L
.29632 .30902 L
.29757 .30902 L
.2987 .30902 L
.29994 .30902 L
.30059 .30902 L
.30127 .30902 L
.30249 .30902 L
.30368 .30902 L
.30494 .30902 L
.30601 .30902 L
.30718 .30902 L
.30844 .30902 L
.30915 .30902 L
.30979 .30902 L
.31104 .30902 L
.31223 .30902 L
.31334 .30902 L
.31451 .30902 L
.31551 .30902 L
.31661 .30902 L
.3178 .30902 L
.31907 .30902 L
.32027 .30902 L
.32137 .30902 L
.32265 .30902 L
Mistroke
.32337 .30902 L
.32402 .30902 L
.32529 .30902 L
.32648 .30902 L
.32716 .30902 L
.32788 .30902 L
.32916 .30902 L
.32987 .30902 L
.33054 .30902 L
.33127 .30902 L
.33205 .30902 L
.33336 .30902 L
.3341 .30902 L
.33478 .30902 L
.33604 .30902 L
.33667 .30902 L
.33736 .30902 L
.33857 .30902 L
.33986 .30902 L
.34108 .30902 L
.3422 .30902 L
.34348 .30902 L
.34469 .30902 L
.34578 .30902 L
.34696 .30902 L
.34824 .30902 L
.34889 .30902 L
.3496 .30902 L
.35085 .30902 L
.35203 .30902 L
.35321 .30902 L
.35433 .30902 L
.35534 .30902 L
.35644 .30902 L
.35762 .30902 L
.35889 .30902 L
.35997 .30902 L
.36116 .30902 L
.36247 .30902 L
.36312 .30902 L
.36384 .30902 L
.36511 .30902 L
.3663 .30902 L
.36702 .30902 L
.3677 .30902 L
.36898 .30902 L
.36969 .30902 L
.37035 .30902 L
.37108 .30902 L
.37184 .30902 L
Mistroke
.37303 .30902 L
.37431 .30902 L
.37552 .30902 L
.37662 .30902 L
.37791 .30902 L
.37864 .30902 L
.37931 .30902 L
.38054 .30902 L
.38123 .30902 L
.38188 .30902 L
.38316 .30902 L
.38382 .30902 L
.38452 .30902 L
.3858 .30902 L
.38696 .30902 L
.38766 .30902 L
.38831 .30902 L
.38902 .30902 L
.38978 .30902 L
.39105 .30902 L
.39178 .30902 L
.39245 .30902 L
.39367 .30902 L
.39496 .30902 L
.39605 .30902 L
.39725 .30902 L
.39854 .30902 L
.39927 .30902 L
.39993 .30902 L
.40121 .30902 L
.40241 .30902 L
.40349 .30902 L
.40467 .30902 L
.40591 .30902 L
.40706 .30902 L
.41135 .30902 L
.42103 .30902 L
.45987 .30902 L
.50117 .30902 L
.54095 .30902 L
.57921 .30902 L
.61993 .30902 L
.65913 .30902 L
.70079 .30902 L
.74093 .30902 L
.77955 .30902 L
.82062 .30902 L
.86018 .30902 L
.89823 .30902 L
.93872 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0Y_ooo`00Hoooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool006?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P00
0:Ooool005goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00<oooo`80I_l^oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
0:Koool003;oool0101Vooooooooo`1Vobkoool200002_ooo`<00004oooo00<0003oooooool0Y_oo
o`00<Oooo`80I_l3oooo0P1Vocooool20000Yoooo`00<?ooo`0306Kooooooooo00Goool00`1Voooo
ooooo`0loooo00<0003oooooool0Y_ooo`00<?ooo`0306Kooooooooo00Koool206Ko??ooo`030000
oooooooo0:Koool002koool206Ko2oooo`0306Kooooooooo03Woool00`000?ooooooo`2Voooo000]
oooo00<0I_ooooooool03?ooo`80I_lioooo0P000:Ooool002coool00`1Vooooooooo`0?oooo00<0
I_ooooooool0=_ooo`030000oooooooo0:Koool002_oool00`1Vooooooooo`0Aoooo00<0I_oooooo
ool0=Oooo`030000oooooooo0:Koool002Woool206Ko5Oooo`80I_leoooo00<0003oooooool0Y_oo
o`00:?ooo`0306Kooooooooo01Ooool00`1Vooooooooo`0boooo0P000:Ooool002Ooool00`1Voooo
ooooo`0Ioooo00<0I_ooooooool0<Oooo`030000oooooooo0:Koool002Goool206Ko7Oooo`0306Ko
oooooooo033oool00`000?ooooooo`2Voooo000Toooo00<0I_ooooooool07_ooo`0306Kooooooooo
02ooool00`000?ooooooo`2Voooo000Soooo00<0I_ooooooool08?ooo`80I_l_oooo0P000:Ooool0
027oool206Ko9Oooo`0306Kooooooooo02coool00`000?ooooooo`2Voooo000Poooo00<0I_oooooo
ool09_ooo`0306Kooooooooo01;oool200001?ooo`800003oooo100000?oool200001Oooo`030000
oooooooo0:Koool001koool206Ko:_ooo`0306Kooooooooo013oool010000?ooooooo`0000Soool0
0`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0Y_ooo`007?ooo`80I_l]
oooo00<0I_ooooooool03oooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?oo
ooooo`02oooo0P000:Ooool001_oool00`1Vooooooooo`0]oooo00<0I_ooooooool02Oooo`@00002
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005oooo00<0003oooooool0Y_oo
o`006Oooo`80I_laoooo00<0I_ooooooool03_ooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo000Goooo0P1VocCoool00`1Voooo
ooooo`0>oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool0Y_ooo`005_ooo`0306Ko
oooooooo03Goool00`1Vooooooooo`0Voooo0P000:Ooool004ooool00`1Vooooooooo`0Uoooo00<0
003oooooool0Y_ooo`00D?ooo`0306Kooooooooo02Coool00`000?ooooooo`2Voooo001@oooo00<0
I_ooooooool09?ooo`030000oooooooo0:Koool001Ooool40000;Oooo`D00004oooo00<0I_oooooo
ool08oooo`80000/oooo1@0002_oool40000;_ooo`80000Goooo000Goooo00<0003oooooool0<?oo
o`030000oooooooo00Goool00`1Vooooooooo`0Roooo00<0003oooooool0;Oooo`030000oooooooo
02_oool00`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;ooo
o`030000oooooooo00Koool00`1Vooooooooo`0Qoooo00<0003oooooool0;Oooo`030000oooooooo
02coool00`000?ooooooo`0_oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003ooooo
ool09_ooo`@00004oooo00<0003oooooool01_ooo`0306Kooooooooo027oool00`000?ooooooo`0]
oooo00<0003oooooool0;Oooo`030000oooooooo02ooool00`000?ooooooo`0Doooo000Goooo00@0
003oooooool0000_oooo00<0003oooooool01oooo`0306Kooooooooo023oool20000;_ooo`030000
oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool20000;ooo
o`80000:oooo00<0I_ooooooool07oooo`030000oooooooo02coool20000;_ooo`80000_oooo0P00
01Ooool005Koool00`1Vooooooooo`0Noooo00<0003oooooool0Y_ooo`00E_ooo`0306Kooooooooo
01koool20000Yoooo`00Eoooo`0306Kooooooooo01goool00`000?ooooooo`2Voooo001Hoooo00<0
I_ooooooool07?ooo`030000oooooooo0:Koool005Woool00`1Vooooooooo`0Koooo00<0003ooooo
ool0Y_ooo`004?ooool0000Aoooo000Foooo2000008co`000`0003?o03?o0007<ol000<0000co`0c
o`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`00
0`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool01Oooo`X0000O<ol000<0000co`0co`00;C?o
00030000oooooooo02goool00`000?ooooooo`0@oooo00?o09Woooooool06_ooo`030000oooooooo
02koool00`000?ooooooo`0Eoooo000Xoooo1P0004Tco`000`000?ooooooo`10oooo00?o09Wooooo
ool0Hoooo`00;_ooo`D00014<ol00P00047oool00ol0VOooooooo`1Soooo000coooo1000040co`00
0`000?ooooooo`10oooo00?o09Woooooool0Hoooo`00=oooo`80000n<ol000<0003oooooool0@?oo
o`03o`2Ioooooooo06?oool003Woool30000>c?o00030000oooooooo043oool00ol0VOooooooo`1S
oooo000loooo0P0003Tco`020000@Oooo`03o`2Ioooooooo06?oool003koool20000=c?o00030000
oooooooo043oool00ol0VOooooooo`1Soooo0010oooo0P0003Dco`000`000?ooooooo`10oooo00?o
09Woooooool0Hoooo`00@_ooo`80000c<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06?oool0
04Coool20000<C?o00800011oooo00?o09Woooooool0Hoooo`00A_ooo`030000<ol0<ol002hco`00
0`000?ooooooo`10oooo00?o09Woooooool0Hoooo`00Aoooo`030000<ol0<ol002dco`000`000?oo
ooooo`10oooo00?o09Woooooool0Hoooo`00B?ooo`030000<ol0<ol002`co`000`000?ooooooo`10
oooo00?o09Woooooool0Hoooo`00BOooo`030000<ol0<ol002/co`020000@Oooo`03o`2Ioooooooo
06?oool004[oool00`0003?o03?o000Z<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06?oool0
04_oool00`0003?o03?o000@<ol00P0000@co`0200000c?o00@00003<ol00P0000Dco`000`000?oo
ooooo`10oooo00?o09Woooooool0Hoooo`00C?ooo`030000<ol0<ol000hco`00100003?o03?o0000
00Pco`000`0003?o03?o0003<ol000@0000co`0co`000004<ol000<0003oooooool0@?ooo`03o`2I
oooooooo06?oool004goool00`0003?o03?o000=<ol000@0000co`0co`000009<ol000<0000co`0c
o`001C?o00030000<ol0<ol0008co`020000@Oooo`03o`2Ioooooooo06?oool004koool00`0003?o
03?o000<<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800005<ol000<0003ooooo
ool0@?ooo`03o`2Ioooooooo06?oool004ooool00`0003?o03?o000;<ol000@0000co`0co`000008
<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo043oool00ol0VOoo
ooooo`1Soooo001?oooo00<0000co`0co`0033?o0080000:<ol00P0000@co`03000013?o00030000
oooooooo043oool00ol0VOooooooo`1Soooo001@oooo00<0000co`0co`0093?o00800011oooo00?o
09Woooooool0Hoooo`00DOooo`030000<ol0<ol002<co`000`000?ooooooo`10oooo00?o09Wooooo
ool0Hoooo`00D_ooo`030000<ol0<ol0028co`000`000?ooooooo`10oooo00?o09Woooooool0Hooo
o`00D_ooo`030000<ol0<ol0028co`000`000?ooooooo`10oooo00?o09Woooooool0Hoooo`00Dooo
o`030000<ol0<ol0024co`020000@Oooo`03o`2Ioooooooo06?oool005?oool00`0003?o03?o000Q
<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06?oool005Coool00`0003?o03?o000P<ol000<0
003oooooool0@?ooo`03o`2Ioooooooo06?oool005Coool00`0003?o03?o000P<ol000<0003ooooo
ool0@?ooo`03o`2Ioooooooo06?oool005Goool00`0003?o03?o000O<ol00P00047oool00ol0VOoo
ooooo`1Soooo001Eoooo00<0000co`0co`007c?o00030000oooooooo043oool00ol0VOooooooo`1S
oooo001Foooo00<0000co`0co`007S?o00030000oooooooo043oool00ol0VOooooooo`1Soooo001F
oooo00<0000co`0co`007S?o00030000oooooooo043oool00ol0VOooooooo`1Soooo001Goooo00<0
000co`0co`007C?o00800011oooo00?o09Woooooool0Hoooo`00Eoooo`030000<ol0<ol001dco`00
0`000?ooooooo`10oooo00?o09Woooooool0Hoooo`00F?ooo`030000<ol0<ol000Tco`02000013?o
00800004<ol00P0000Dco`000`000?ooooooo`10oooo00?o09Woooooool0Hoooo`00F?ooo`030000
<ol0<ol000Pco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`10
oooo00?o09Woooooool0Hoooo`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`00
0`0003?o03?o0002<ol00P00047oool00ol0VOooooooo`1Soooo001Ioooo00<0000co`0co`001c?o
00040000<ol0<ol000002C?o00800005<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06?oool0
05Woool00`0003?o03?o0007<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000
oooooooo043oool00ol0VOooooooo`1Soooo001Joooo00<0000co`0co`001c?o0080000:<ol00`00
00@co`000`000?ooooooo`10oooo00?o09Woooooool0Hoooo`00F_ooo`030000<ol0<ol001Xco`02
0000@Oooo`03o`2Ioooooooo06?oool005[oool00`0003?o03?o000J<ol000<0003oooooool0@?oo
o`03o`2Ioooooooo06?oool005_oool00`0003?o03?o000I<ol000<0003oooooool0@?ooo`03o`2I
oooooooo06?oool005_oool00`0003?o03?o000I<ol00P00047oool00ol0VOooooooo`1Soooo001K
oooo00<0000co`0co`006C?o00030000oooooooo043oool00ol0VOooooooo`1Soooo001Loooo00<0
000co`0co`0063?o00030000oooooooo043oool00ol0VOooooooo`1Soooo001Loooo00<0000co`0c
o`0063?o00030000oooooooo043oool00ol0VOooooooo`1Soooo001Loooo00<0000co`0co`0063?o
00800011oooo00?o09Woooooool0Hoooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`10
oooo00?o09Woooooool0Hoooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`10oooo00?o
09Woooooool0Hoooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`10oooo00?o09Wooooo
ool0Hoooo`00G_ooo`030000<ol0<ol001Hco`020000@Oooo`03o`2Ioooooooo06?oool005koool0
0`0003?o03?o000F<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06?oool005koool2000013?o
00800005<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0@?ooo`03o`2Ioooooooo
06?oool005goool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0000co`0c
o`000S?o00030000oooooooo043oool00ol0VOooooooo`1Soooo001Moooo00@0003oool00000000:
<ol000<0000co`0co`0013?o00030000<ol0<ol0008co`020000@Oooo`03o`2Ioooooooo06?oool0
05goool010000?ooo`00000000/co`00100003?o03?o03?o00800005<ol000<0003oooooool0@?oo
o`03o`2Ioooooooo06?oool005goool010000?ooooooo`0000Pco`00100003?o03?o000000<co`00
0`0003?o03?o0004<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06?oool005koool3000023?o
00@00003<ol00`0000@co`000`000?ooooooo`10oooo00?o09Woooooool0Hoooo`00H?ooo`030000
<ol0<ol001@co`020000@Oooo`03o`2Ioooooooo06?oool0063oool00`0003?o03?o000D<ol000<0
003oooooool0@?ooo`03o`2Ioooooooo06?oool0067oool00`0003?o03?o000C<ol000<0003ooooo
ool0@?ooo`03o`2Ioooooooo06?oool0067oool00`0003?o03?o000C<ol000<0003oooooool0@?oo
o`03o`2Ioooooooo06?oool0067oool00`0003?o03?o000C<ol00P00047oool00ol0VOooooooo`1S
oooo001Qoooo00<0000co`0co`004c?o00030000oooooooo043oool00ol0VOooooooo`1Soooo001R
oooo00<0000co`0co`004S?o00030000oooooooo043oool00ol0VOooooooo`1Soooo001Roooo00<0
000co`0co`004S?o00030000oooooooo043oool00ol0VOooooooo`1Soooo001Roooo00<0000co`0c
o`004S?o00800011oooo00?o09Woooooool0Hoooo`00H_ooo`030000<ol0<ol0018co`000`000?oo
ooooo`10oooo00?o09Woooooool0Hoooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`10
oooo00?o09Woooooool0Hoooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`10oooo00?o
09Woooooool0Hoooo`00Hoooo`030000<ol0<ol0014co`020000@Oooo`03o`2Ioooooooo06?oool0
06?oool00`0003?o03?o000A<ol000<0003oooooool0@?ooo`03o`2Ioooooooo06?oool006?oool0
0`0003?o03?o0009<ol01@0000<co`000`000?ooooooo`10oooo00?o09Woooooool0Hoooo`00I?oo
o`030000<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003oooooool0@?ooo`03o`2Ioooooooo
06?oool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o00800011oooo00?o09Wooooo
ool0Hoooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo`dco`000`0003?o03?o0003
<ol0ZOooo`00I?ooo``co`0200001C?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`2Yoooo001U
oooo4S?o00Goool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00IOoooa8co`04oooo00<0
003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001Uoooo4S?o00Coool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`<00002
oooo00<0003oooooool0Noooo`00IOoooa8co`04oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000;oooo00D0003oooooooooool0
0000OOooo`00IOoooa8co`03oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000Soool500000oooo`030000oooooooo07[oool006KooolA<ol01?ooo`030000oooooooo
00D0000<oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Nooo
o`00I_oooa4co`04oooo00D0003oooooooooool000003oooo`040000oooooooo00002Oooo`030000
oooo000000?oool00`000?ooooooo`1koooo001Voooo4C?o00Goool00`000?ooooooo`0Aoooo0P00
00_oool200000_ooo`030000oooooooo07coool006KooolA<ol0ZOooo`00I_oooa4co`2Yoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65954 .30902 L
.67803 .30902 L
.68335 .30902 L
.68596 .30902 L
.68711 .30902 L
.68837 .30902 L
.6895 .30902 L
s
.6895 .30902 m
.6896 .61803 L
s
0 .4 1 r
.02381 .22825 m
.06244 .20137 L
.08255 .18399 L
.0932 .17367 L
.10458 .16169 L
.11009 .15551 L
.11531 .14942 L
.11758 .14669 L
.11872 .1453 L
.11999 .14528 L
.12064 .14554 L
.12135 .14583 L
.12263 .14635 L
.12507 .14735 L
.14415 .15586 L
.18538 .17876 L
.22508 .20831 L
.26328 .24607 L
.28459 .27232 L
.29466 .28628 L
.30392 .30013 L
.30636 .30394 L
.30863 .30757 L
.30977 .30902 L
.311 .30902 L
.31166 .30902 L
.31235 .30902 L
.3136 .30902 L
.31424 .30902 L
.31495 .30902 L
.3157 .30902 L
.31641 .30902 L
.3177 .30902 L
.31842 .30902 L
.31908 .30902 L
.32024 .30902 L
.32151 .30902 L
.32215 .30902 L
.32284 .30902 L
.32407 .30902 L
.32535 .30902 L
.32653 .30902 L
.32782 .30902 L
.32847 .30902 L
.32919 .30902 L
.33039 .30902 L
.33168 .30902 L
.3329 .30902 L
.33402 .30902 L
.33517 .30902 L
Mistroke
.33623 .30902 L
.33741 .30902 L
.33865 .30902 L
.33984 .30902 L
.34096 .30902 L
.34197 .30902 L
.34305 .30902 L
.3443 .30902 L
.34543 .30902 L
.34675 .30902 L
.34798 .30902 L
.34913 .30902 L
.35019 .30902 L
.35135 .30902 L
.35258 .30902 L
.35382 .30902 L
.35451 .30902 L
.35515 .30902 L
.35632 .30902 L
.35755 .30902 L
.35821 .30902 L
.35891 .30902 L
.36017 .30902 L
.36094 .30902 L
.36167 .30902 L
.36232 .30902 L
.36303 .30902 L
.36434 .30902 L
.36557 .30902 L
.36628 .30902 L
.36692 .30902 L
.36766 .30902 L
.36836 .30902 L
.36904 .30902 L
.36977 .30902 L
.37106 .30902 L
.37178 .30902 L
.37246 .30902 L
.3732 .30902 L
.374 .30902 L
.37465 .30902 L
.37533 .30902 L
.37657 .30902 L
.37786 .30902 L
.3786 .30902 L
.37927 .30902 L
.38047 .30902 L
.38176 .30902 L
.38298 .30902 L
.38411 .30902 L
Mistroke
.38536 .30902 L
.38654 .30902 L
.38761 .30902 L
.38877 .30902 L
.39003 .30902 L
.39073 .30902 L
.39137 .30902 L
.39262 .30902 L
.39379 .30902 L
.39489 .30902 L
.39605 .30902 L
.39705 .30902 L
.39814 .30902 L
.39932 .30902 L
.40058 .30902 L
.40176 .30902 L
.40285 .30902 L
.40413 .30902 L
.40477 .30902 L
.40549 .30902 L
.40793 .30902 L
.41345 .30902 L
.42348 .30902 L
.4637 .30902 L
.50241 .30902 L
.54357 .30902 L
.58321 .30902 L
.62134 .30902 L
.66192 .30902 L
.70099 .30902 L
.74251 .30902 L
.78251 .30902 L
.82099 .30902 L
.86193 .30902 L
.90136 .30902 L
.93926 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?ooooooo`2Voooo001g
oooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo000^oooo0`1Voc?oool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`2Voooo000]oooo00@0I_ooooooooooool206Ko<?ooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo0:Koool002coool00`1Voooo
ooooo`04oooo0P1Vobkoool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0P000:Ooool0
02_oool00`1Vooooooooo`07oooo00<0I_ooooooool09Oooo`@00002oooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`2Voooo000[oooo00<0I_ooooooool02?ooo`80I_l[oooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo0:Koool002[oool00`1Voooo
ooooo`0;oooo0P1Vob[oool200002_ooo`<00004oooo00<0003oooooool0Y_ooo`00:Oooo`0306Ko
oooooooo00koool206Ko>oooo`80002Woooo000Xoooo00<0I_ooooooool04Oooo`80I_lioooo00<0
003oooooool0Y_ooo`009oooo`0306Kooooooooo01Coool206Ko=oooo`030000oooooooo0:Koool0
02Koool00`1Vooooooooo`0Goooo00<0I_ooooooool0=?ooo`030000oooooooo0:Koool002Goool0
0`1Vooooooooo`0Ioooo0P1VocCoool20000Yoooo`009?ooo`0306Kooooooooo01coool00`1Voooo
ooooo`0aoooo00<0003oooooool0Y_ooo`008_ooo`80I_lPoooo00<0I_ooooooool0<?ooo`030000
oooooooo0:Koool0027oool00`1Vooooooooo`0Qoooo00<0I_ooooooool0;oooo`030000oooooooo
0:Koool0023oool00`1Vooooooooo`0Soooo0P1Vobooool20000Yoooo`007_ooo`80I_lXoooo00<0
I_ooooooool0;?ooo`030000oooooooo0:Koool001goool00`1Vooooooooo`0Yoooo00<0I_oooooo
ool0:oooo`030000oooooooo0:Koool001coool00`1Vooooooooo`0[oooo00<0I_ooooooool0:_oo
o`030000oooooooo0:Koool001[oool206Ko;oooo`0306Kooooooooo02Woool20000Yoooo`006Ooo
o`0306Kooooooooo033oool00`1Vooooooooo`0Xoooo00<0003oooooool0Y_ooo`005oooo`80I_ld
oooo00<0I_ooooooool03_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003ooooo
ool0Y_ooo`005_ooo`0306Kooooooooo03Goool206Ko3Oooo`040000oooooooo00002?ooo`030000
oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`2Voooo001@oooo00<0I_oooooo
ool02_ooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0P00
0:Ooool0057oool00`1Vooooooooo`03oooo100000;oool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo0P0000Goool00`000?ooooooo`2Voooo001Boooo00<0I_ooooooool02?ooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2V
oooo001Coooo00<0I_ooooooool02?ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo
0:Koool005Coool00`1Vooooooooo`0Poooo0P000:Ooool005Coool00`1Vooooooooo`0Poooo00<0
003oooooool0Y_ooo`00EOooo`0306Kooooooooo01ooool00`000?ooooooo`2Voooo001Foooo00<0
I_ooooooool07_ooo`030000oooooooo0:Koool001Ooool40000;Oooo`D0000:oooo00<0I_oooooo
ool07Oooo`80000/oooo1@0002_oool40000;_ooo`80000Goooo000Goooo00<0003oooooool0<?oo
o`030000oooooooo00[oool00`1Vooooooooo`0Moooo00<0003oooooool0;Oooo`030000oooooooo
02_oool00`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;ooo
o`030000oooooooo00_oool00`1Vooooooooo`0Loooo00<0003oooooool0;Oooo`030000oooooooo
02coool00`000?ooooooo`0_oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003ooooo
ool09_ooo`@00004oooo00<0003oooooool03?ooo`0306Kooooooooo01_oool00`000?ooooooo`0]
oooo00<0003oooooool0;Oooo`030000oooooooo02ooool00`000?ooooooo`0Doooo000Goooo00@0
003oooooool0000_oooo00<0003oooooool03?ooo`0306Kooooooooo01_oool20000;_ooo`030000
oooooooo02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool20000;ooo
o`80000?oooo00<0I_ooooooool06_ooo`030000oooooooo02coool20000;_ooo`80000_oooo0P00
01Ooool005_oool00`1Vooooooooo`0Ioooo00<0003oooooool0Y_ooo`00G?ooo`0306Kooooooooo
01Soool20000Yoooo`00G?ooo`0306Kooooooooo01Soool00`000?ooooooo`2Voooo001Moooo00<0
I_ooooooool05oooo`030000oooooooo0:Koool005koool00`1Vooooooooo`0Foooo00<0003ooooo
ool0Y_ooo`004?ooool0000Aoooo000Foooo2000008co`000`0003?o03?o0007<ol000<0000co`0c
o`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`00
0`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003ooooo
ool00_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo00Goool:00007c?o
00030000<ol0<ol002dco`000`000?ooooooo`0]oooo00<0003oooooool05Oooo`03o`2Ioooooooo
01Goool00`000?ooooooo`0^oooo00<0003oooooool05Oooo`00:?ooo`H00019<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo05koool002koool50000A3?o00800016oooo00?o09Woooooool0G_oo
o`00<oooo`@00010<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool003Ooool20000?S?o
00030000oooooooo04Goool00ol0VOooooooo`1Noooo000ioooo0`0003/co`000`000?ooooooo`15
oooo00?o09Woooooool0G_ooo`00??ooo`80000i<ol00P0004Koool00ol0VOooooooo`1Noooo000n
oooo0P0003Lco`000`000?ooooooo`15oooo00?o09Woooooool0G_ooo`00@?ooo`80000e<ol000<0
003oooooool0AOooo`03o`2Ioooooooo05koool004;oool20000<c?o00030000oooooooo04Goool0
0ol0VOooooooo`1Noooo0014oooo0P00034co`020000A_ooo`03o`2Ioooooooo05koool004Koool0
0`0003?o03?o000^<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool004Ooool00`0003?o
03?o000]<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool004Soool00`0003?o03?o000/
<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool004Woool00`0003?o03?o000[<ol00P00
04Koool00ol0VOooooooo`1Noooo001:oooo00<0000co`0co`00:S?o00030000oooooooo04Goool0
0ol0VOooooooo`1Noooo001;oooo00<0000co`0co`0043?o00800004<ol00P0000<co`0400000c?o
00800005<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool004coool00`0003?o03?o000>
<ol000@0000co`0co`000008<ol000<0000co`0co`000c?o00040000<ol0<ol0000013?o00030000
oooooooo04Goool00ol0VOooooooo`1Noooo001=oooo00<0000co`0co`003C?o00040000<ol0<ol0
00002C?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol00P0004Koool00ol0VOooooooo`1N
oooo001>oooo00<0000co`0co`0033?o00040000<ol0<ol000002S?o00030000<ol0<ol0008co`02
00001C?o00030000oooooooo04Goool00ol0VOooooooo`1Noooo001?oooo00<0000co`0co`002c?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?oo
ooooo`15oooo00?o09Woooooool0G_ooo`00Coooo`030000<ol0<ol000`co`0200002S?o00800004
<ol00`0000@co`000`000?ooooooo`15oooo00?o09Woooooool0G_ooo`00D?ooo`030000<ol0<ol0
02@co`020000A_ooo`03o`2Ioooooooo05koool0057oool00`0003?o03?o000S<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo05koool005;oool00`0003?o03?o000R<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo05koool005;oool00`0003?o03?o000R<ol000<0003oooooool0AOooo`03o`2I
oooooooo05koool005?oool00`0003?o03?o000Q<ol00P0004Koool00ol0VOooooooo`1Noooo001C
oooo00<0000co`0co`008C?o00030000oooooooo04Goool00ol0VOooooooo`1Noooo001Doooo00<0
000co`0co`0083?o00030000oooooooo04Goool00ol0VOooooooo`1Noooo001Doooo00<0000co`0c
o`0083?o00030000oooooooo04Goool00ol0VOooooooo`1Noooo001Eoooo00<0000co`0co`007c?o
00800016oooo00?o09Woooooool0G_ooo`00EOooo`030000<ol0<ol001lco`000`000?ooooooo`15
oooo00?o09Woooooool0G_ooo`00E_ooo`030000<ol0<ol001hco`000`000?ooooooo`15oooo00?o
09Woooooool0G_ooo`00E_ooo`030000<ol0<ol001hco`000`000?ooooooo`15oooo00?o09Wooooo
ool0G_ooo`00Eoooo`030000<ol0<ol001dco`020000A_ooo`03o`2Ioooooooo05koool005Ooool0
0`0003?o03?o000M<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool005Soool00`0003?o
03?o0009<ol00P0000@co`02000013?o00800005<ol000<0003oooooool0AOooo`03o`2Ioooooooo
05koool005Soool00`0003?o03?o0008<ol000@0000co`0co`000008<ol000@0000co`0co`000004
<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool005Woool00`0003?o03?o0007<ol000@0
000co`0co`00000;<ol000<0000co`0co`000S?o00800016oooo00?o09Woooooool0G_ooo`00FOoo
o`030000<ol0<ol000Lco`00100003?o03?o000000Tco`0200001C?o00030000oooooooo04Goool0
0ol0VOooooooo`1Noooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o00030000
<ol0<ol000@co`000`000?ooooooo`15oooo00?o09Woooooool0G_ooo`00F_ooo`030000<ol0<ol0
00Lco`0200002S?o00<00004<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool005[oool0
0`0003?o03?o000J<ol00P0004Koool00ol0VOooooooo`1Noooo001Joooo00<0000co`0co`006S?o
00030000oooooooo04Goool00ol0VOooooooo`1Noooo001Koooo00<0000co`0co`006C?o00030000
oooooooo04Goool00ol0VOooooooo`1Noooo001Koooo00<0000co`0co`006C?o00800016oooo00?o
09Woooooool0G_ooo`00Foooo`030000<ol0<ol001Tco`000`000?ooooooo`15oooo00?o09Wooooo
ool0G_ooo`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`15oooo00?o09Woooooool0G_oo
o`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`15oooo00?o09Woooooool0G_ooo`00G?oo
o`030000<ol0<ol001Pco`020000A_ooo`03o`2Ioooooooo05koool005goool00`0003?o03?o000G
<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool005goool00`0003?o03?o000G<ol000<0
003oooooool0AOooo`03o`2Ioooooooo05koool005goool00`0003?o03?o000G<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo05koool005koool00`0003?o03?o000F<ol00P0004Koool00ol0VOoo
ooooo`1Noooo001Noooo00<0000co`0co`005S?o00030000oooooooo04Goool00ol0VOooooooo`1N
oooo001Noooo0P0000@co`0200001C?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo
04Goool00ol0VOooooooo`1Noooo001Moooo00@0003oool00000000:<ol000D0000co`0co`0co`00
00000S?o00030000<ol0<ol0008co`000`000?ooooooo`15oooo00?o09Woooooool0G_ooo`00GOoo
o`040000oooo000000002S?o00030000<ol0<ol000@co`000`0003?o03?o0002<ol00P0004Koool0
0ol0VOooooooo`1Noooo001Moooo00@0003oool00000000;<ol000@0000co`0co`0co`0200001C?o
00030000oooooooo04Goool00ol0VOooooooo`1Noooo001Moooo00@0003oooooool00008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo04Goool00ol0VOooooooo`1N
oooo001Noooo0`0000Pco`0400000c?o00<00004<ol000<0003oooooool0AOooo`03o`2Ioooooooo
05koool0063oool00`0003?o03?o000D<ol00P0004Koool00ol0VOooooooo`1Noooo001Poooo00<0
000co`0co`0053?o00030000oooooooo04Goool00ol0VOooooooo`1Noooo001Qoooo00<0000co`0c
o`004c?o00030000oooooooo04Goool00ol0VOooooooo`1Noooo001Qoooo00<0000co`0co`004c?o
00030000oooooooo04Goool00ol0VOooooooo`1Noooo001Qoooo00<0000co`0co`004c?o00800016
oooo00?o09Woooooool0G_ooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`15oooo00?o
09Woooooool0G_ooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`15oooo00?o09Wooooo
ool0G_ooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`15oooo00?o09Woooooool0G_oo
o`00H_ooo`030000<ol0<ol0018co`020000A_ooo`03o`2Ioooooooo05koool006;oool00`0003?o
03?o000B<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool006?oool00`0003?o03?o000A
<ol000<0003oooooool0AOooo`03o`2Ioooooooo05koool006?oool00`0003?o03?o000A<ol000<0
003oooooool0AOooo`03o`2Ioooooooo05koool006?oool00`0003?o03?o000A<ol00P0004Koool0
0ol0VOooooooo`1Noooo001Soooo00<0000co`0co`004C?o00030000oooooooo04Goool00ol0VOoo
ooooo`1Noooo001Soooo00<0000co`0co`002C?o00D00003<ol000<0003oooooool0AOooo`03o`2I
oooooooo05koool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o00030000oooooooo
04Goool00ol0VOooooooo`1Noooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol000<co`02
0000A_ooo`03o`2Ioooooooo05koool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool=
<ol000<0000co`0co`000c?o0:Woool006Coool<<ol00P0000Dco`2Yoooo001Uoooo4S?o0:Woool0
06GooolB<ol0ZOooo`00IOoooa8co`05oooo00<0003oooooool08_ooo`030000oooooooo07coool0
06GooolB<ol01?ooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Nooo
o`00IOoooa8co`04oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004
oooo0P0000Coool200001?ooo`030000oooooooo07_oool006GooolB<ol01?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo07_oool006GooolB<ol00oooo`030000oooooooo
00;oool00`000?ooooooo`0=oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`030000
oooooooo07[oool006KooolA<ol01?ooo`030000oooooooo00D0000<oooo00@0003oooooool00009
oooo0P0000Coool00`000?ooooooo`1koooo001Voooo4C?o00Coool01@000?ooooooooooo`00000?
oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo07_oool006KooolA
<ol01Oooo`030000oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00I_oo
oa4co`2Yoooo001Voooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.67958 .30902 L
.69774 .30902 L
.7026 .30902 L
.70516 .30902 L
.70656 .30902 L
.70787 .30902 L
.70901 .30902 L
s
.70901 .30902 m
.70913 .61803 L
s
0 .4 1 r
.02381 .20862 m
.06244 .1752 L
.08255 .15359 L
.0932 .14077 L
.09626 .13689 L
.09777 .13495 L
.09843 .13409 L
.09916 .13313 L
.10042 .13215 L
.10111 .13236 L
.10176 .13256 L
.10458 .13344 L
.12507 .14036 L
.14415 .14779 L
.18292 .16641 L
.22415 .19279 L
.26386 .22677 L
.30205 .27029 L
.31303 .28533 L
.31841 .2932 L
.32337 .30075 L
.3257 .30442 L
.32684 .30623 L
.32788 .3079 L
.32898 .30902 L
.33016 .30902 L
.33144 .30902 L
.33265 .30902 L
.33386 .30902 L
.33515 .30902 L
.33625 .30902 L
.33746 .30902 L
.33876 .30902 L
.33949 .30902 L
.34016 .30902 L
.3414 .30902 L
.34269 .30902 L
.34396 .30902 L
.34515 .30902 L
.34622 .30902 L
.34738 .30902 L
.34864 .30902 L
.34928 .30902 L
.34998 .30902 L
.35122 .30902 L
.35238 .30902 L
.35354 .30902 L
.35464 .30902 L
.35564 .30902 L
.35672 .30902 L
Mistroke
.35789 .30902 L
.35914 .30902 L
.36032 .30902 L
.36138 .30902 L
.36267 .30902 L
.36331 .30902 L
.36402 .30902 L
.36528 .30902 L
.36645 .30902 L
.3671 .30902 L
.3678 .30902 L
.36909 .30902 L
.36986 .30902 L
.37057 .30902 L
.37122 .30902 L
.37192 .30902 L
.37309 .30902 L
.37435 .30902 L
.37554 .30902 L
.37663 .30902 L
.37784 .30902 L
.37916 .30902 L
.37983 .30902 L
.38054 .30902 L
.38182 .30902 L
.38306 .30902 L
.38377 .30902 L
.38442 .30902 L
.38512 .30902 L
.38575 .30902 L
.38648 .30902 L
.38717 .30902 L
.38839 .30902 L
.38953 .30902 L
.39077 .30902 L
.39209 .30902 L
.3934 .30902 L
.39414 .30902 L
.39482 .30902 L
.39606 .30902 L
.39738 .30902 L
.39807 .30902 L
.39882 .30902 L
.39952 .30902 L
.40016 .30902 L
.40091 .30902 L
.40173 .30902 L
.4025 .30902 L
.40321 .30902 L
.40437 .30902 L
Mistroke
.40562 .30902 L
.40679 .30902 L
.40787 .30902 L
.413 .30902 L
.42337 .30902 L
.4631 .30902 L
.50132 .30902 L
.54198 .30902 L
.58113 .30902 L
.62273 .30902 L
.66282 .30902 L
.70139 .30902 L
.74241 .30902 L
.78192 .30902 L
.81991 .30902 L
.86036 .30902 L
.89929 .30902 L
.94067 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0
003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool002Woool406KoB_ooo`030000oooooooo
0:Koool002Woool0101Vooooooooooooo`80I_m8oooo0P000:Ooool002Soool00`1Vooooooooo`04
oooo0`1VodGoool00`000?ooooooo`2Voooo000Woooo00<0I_ooooooool02?ooo`80I_l`oooo0P00
00Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`009_ooo`0306Kooooooooo00_oool3
06Ko;?ooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo0:Koool0
02Goool00`1Vooooooooo`0?oooo0P1Vob[oool010000?ooooooo`0000_oool00`000?ooooooo`02
oooo0P000:Ooool002Coool00`1Vooooooooo`0Boooo0`1Vob7oool400000_ooo`040000oooooooo
00002Oooo`800005oooo00<0003oooooool0Y_ooo`008oooo`0306Kooooooooo01Koool206Ko9Ooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo000Roooo00<0
I_ooooooool06Oooo`80I_lToooo0P0000[oool300001?ooo`030000oooooooo0:Koool0027oool0
0`1Vooooooooo`0Loooo0P1VocGoool20000Yoooo`008?ooo`0306Kooooooooo01ooool00`1Voooo
ooooo`0boooo00<0003oooooool0Y_ooo`007oooo`0306Kooooooooo027oool00`1Vooooooooo`0a
oooo00<0003oooooool0Y_ooo`007_ooo`0306Kooooooooo02?oool206Ko<Oooo`030000oooooooo
0:Koool001goool00`1Vooooooooo`0Voooo00<0I_ooooooool0;_ooo`80002Woooo000Loooo00<0
I_ooooooool0:?ooo`80I_l^oooo00<0003oooooool0Y_ooo`006_ooo`80I_l]oooo00<0I_oooooo
ool0:oooo`030000oooooooo0:Koool001Woool00`1Vooooooooo`0^oooo00<0I_ooooooool0:_oo
o`030000oooooooo0:Koool001Soool00`1Vooooooooo`0`oooo00<0I_ooooooool0:Oooo`80002W
oooo000Goooo00<0I_ooooooool0<_ooo`0306Kooooooooo02Soool00`000?ooooooo`2Voooo000F
oooo00<0I_ooooooool0=?ooo`0306Kooooooooo02Ooool00`000?ooooooo`2Voooo001>oooo0P1V
obOoool00`000?ooooooo`2Voooo001@oooo00<0I_ooooooool09?ooo`80002Woooo001Aoooo00<0
I_ooooooool08oooo`030000oooooooo0:Koool005;oool00`1Vooooooooo`09oooo0P0000Coool2
00000oooo`@00003oooo0P0000Goool00`000?ooooooo`2Voooo001Coooo00<0I_ooooooool01ooo
o`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?oo
ooooo`2Voooo001Doooo00<0I_ooooooool01_ooo`040000oooooooo00002Oooo`030000oooooooo
00Goool00`000?ooooooo`02oooo0P000:Ooool005Goool00`1Vooooo`00000300000_ooo`040000
oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005Koool0
0`1Vooooooooo`04oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool01?ooo`030000oooooooo0:Koool005Ooool00`1Vooooooooo`04oooo0P0000[oool200001?oo
o`<00004oooo00<0003oooooool0Y_ooo`00F?ooo`0306Kooooooooo01coool20000Yoooo`00F?oo
o`0306Kooooooooo01coool00`000?ooooooo`2Voooo001Ioooo00<0I_ooooooool06oooo`030000
oooooooo0:Koool005[oool00`1Vooooooooo`0Joooo00<0003oooooool0Y_ooo`005oooo`@0000]
oooo1@0000koool00`1Vooooooooo`0Ioooo0P0002coool50000:oooo`@0000^oooo0P0001Ooool0
01Ooool00`000?ooooooo`0`oooo00<0003oooooool03oooo`0306Kooooooooo01Soool00`000?oo
ooooo`0]oooo00<0003oooooool0:oooo`030000oooooooo02koool010000?ooooooo`0001Koool0
01Soool00`000?ooooooo`0_oooo00<0003oooooool04?ooo`0306Kooooooooo01Ooool00`000?oo
ooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool00`000?ooooooo`0Eoooo000A
oooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?ooooooo`0Aoooo00<0I_oooooo
ool05_ooo`030000oooooooo02goool00`000?ooooooo`0]oooo00<0003oooooool0;oooo`030000
oooooooo01Coool001Ooool010000?ooooooo`0002ooool00`000?ooooooo`0Boooo00<0I_oooooo
ool05Oooo`80000^oooo00<0003oooooool0:oooo`040000oooooooo0000;Oooo`040000oooooooo
00005_ooo`006?ooo`80000_oooo0P0001Goool00`1Vooooooooo`0Doooo00<0003oooooool0;?oo
o`80000^oooo0P0002ooool200005oooo`00H?ooo`0306Kooooooooo01Coool00`000?ooooooo`2V
oooo001Qoooo00<0I_ooooooool04oooo`80002Woooo001Qoooo00<0I_ooooooool04oooo`030000
oooooooo0:Koool006;oool00`1Vooooooooo`0Boooo00<0003oooooool0Y_ooo`00Hoooo`0306Ko
oooooooo017oool00`000?ooooooo`2Voooo000@ooooo`00017oool001Koool800000S?o00030000
<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006
<ol000<0000co`0co`001c?o00030000oooooooo00Koool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo01Goool001Koool00`000?ooooooo`05oooo2P00
01lco`000`0003?o03?o000]<ol000<0003oooooool0;Oooo`030000oooooooo01[oool00ol0VOoo
ooooo`0@oooo00<0003oooooool0;_ooo`030000oooooooo01Goool002Soool60000BC?o00030000
oooooooo04[oool00ol0VOooooooo`1Ioooo000^oooo1@0004@co`020000Boooo`03o`2Ioooooooo
05Woool003?oool40000@3?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo000goooo0P00
03hco`000`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00>Oooo`<0000k<ol000<0003ooooo
ool0B_ooo`03o`2Ioooooooo05Woool003coool20000>C?o0080001;oooo00?o09Woooooool0FOoo
o`00?_ooo`80000g<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05Woool0043oool20000=C?o
00030000oooooooo04[oool00ol0VOooooooo`1Ioooo0012oooo0P0003<co`000`000?ooooooo`1:
oooo00?o09Woooooool0FOooo`00A?ooo`80000a<ol00P0004_oool00ol0VOooooooo`1Ioooo0016
oooo00<0000co`0co`00;S?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo0017oooo00<0
000co`0co`00;C?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo0018oooo00<0000co`0c
o`00;3?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo0019oooo00<0000co`0co`00:c?o
0080001;oooo00?o09Woooooool0FOooo`00B_ooo`030000<ol0<ol002Xco`000`000?ooooooo`1:
oooo00?o09Woooooool0FOooo`00Boooo`030000<ol0<ol0010co`02000013?o00800003<ol01000
00<co`0200001C?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001<oooo00<0000co`0c
o`003S?o00040000<ol0<ol0000023?o00030000<ol0<ol000<co`00100003?o03?o000000@co`00
0`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00COooo`030000<ol0<ol000dco`00100003?o
03?o000000Tco`000`0003?o03?o0005<ol000<0000co`0co`000S?o0080001;oooo00?o09Wooooo
ool0FOooo`00C_ooo`030000<ol0<ol000`co`00100003?o03?o000000Xco`000`0003?o03?o0002
<ol00P0000Dco`000`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00Coooo`030000<ol0<ol0
00/co`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol000<0
003oooooool0B_ooo`03o`2Ioooooooo05Woool004ooool00`0003?o03?o000<<ol00P0000Xco`02
000013?o00<00004<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05Woool0053oool00`0003?o
03?o000T<ol00P0004_oool00ol0VOooooooo`1Ioooo001Aoooo00<0000co`0co`008c?o00030000
oooooooo04[oool00ol0VOooooooo`1Ioooo001Boooo00<0000co`0co`008S?o00030000oooooooo
04[oool00ol0VOooooooo`1Ioooo001Boooo00<0000co`0co`008S?o00030000oooooooo04[oool0
0ol0VOooooooo`1Ioooo001Coooo00<0000co`0co`008C?o0080001;oooo00?o09Woooooool0FOoo
o`00Doooo`030000<ol0<ol0024co`000`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00E?oo
o`030000<ol0<ol0020co`000`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00E?ooo`030000
<ol0<ol0020co`000`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00EOooo`030000<ol0<ol0
01lco`020000Boooo`03o`2Ioooooooo05Woool005Goool00`0003?o03?o000O<ol000<0003ooooo
ool0B_ooo`03o`2Ioooooooo05Woool005Koool00`0003?o03?o000N<ol000<0003oooooool0B_oo
o`03o`2Ioooooooo05Woool005Koool00`0003?o03?o000N<ol000<0003oooooool0B_ooo`03o`2I
oooooooo05Woool005Ooool00`0003?o03?o000M<ol00P0004_oool00ol0VOooooooo`1Ioooo001G
oooo00<0000co`0co`007C?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001Hoooo00<0
000co`0co`002C?o00800004<ol00P0000@co`0200001C?o00030000oooooooo04[oool00ol0VOoo
ooooo`1Ioooo001Hoooo00<0000co`0co`0023?o00040000<ol0<ol0000023?o00040000<ol0<ol0
000013?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001Ioooo00<0000co`0co`001c?o
00040000<ol0<ol000002c?o00030000<ol0<ol0008co`020000Boooo`03o`2Ioooooooo05Woool0
05Woool00`0003?o03?o0007<ol000@0000co`0co`000009<ol00P0000Dco`000`000?ooooooo`1:
oooo00?o09Woooooool0FOooo`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`00
0`0003?o03?o0004<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05Woool005[oool00`0003?o
03?o0007<ol00P0000Xco`03000013?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001J
oooo00<0000co`0co`006S?o0080001;oooo00?o09Woooooool0FOooo`00F_ooo`030000<ol0<ol0
01Xco`000`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00Foooo`030000<ol0<ol001Tco`00
0`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00Foooo`030000<ol0<ol001Tco`020000Booo
o`03o`2Ioooooooo05Woool005_oool00`0003?o03?o000I<ol000<0003oooooool0B_ooo`03o`2I
oooooooo05Woool005coool00`0003?o03?o000H<ol000<0003oooooool0B_ooo`03o`2Ioooooooo
05Woool005coool00`0003?o03?o000H<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05Woool0
05coool00`0003?o03?o000H<ol00P0004_oool00ol0VOooooooo`1Ioooo001Moooo00<0000co`0c
o`005c?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001Moooo00<0000co`0co`005c?o
00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001Moooo00<0000co`0co`005c?o00030000
oooooooo04[oool00ol0VOooooooo`1Ioooo001Noooo00<0000co`0co`005S?o0080001;oooo00?o
09Woooooool0FOooo`00G_ooo`030000<ol0<ol001Hco`000`000?ooooooo`1:oooo00?o09Wooooo
ool0FOooo`00G_ooo`800004<ol00P0000Dco`000`0003?o03?o0002<ol00P0000Dco`000`000?oo
ooooo`1:oooo00?o09Woooooool0FOooo`00GOooo`040000oooo000000002S?o00050000<ol0<ol0
<ol00000008co`000`0003?o03?o0002<ol000<0003oooooool0B_ooo`03o`2Ioooooooo05Woool0
05goool010000?ooo`00000000Xco`000`0003?o03?o0004<ol000<0000co`0co`000S?o0080001;
oooo00?o09Woooooool0FOooo`00GOooo`040000oooo000000002c?o00040000<ol0<ol0<ol00P00
00Dco`000`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00GOooo`040000oooooooo000023?o
00040000<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?ooooooo`1:oooo00?o09Wooooo
ool0FOooo`00G_ooo`<00008<ol0100000<co`03000013?o00030000oooooooo04[oool00ol0VOoo
ooooo`1Ioooo001Poooo00<0000co`0co`0053?o0080001;oooo00?o09Woooooool0FOooo`00H?oo
o`030000<ol0<ol001@co`000`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00HOooo`030000
<ol0<ol001<co`000`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00HOooo`030000<ol0<ol0
01<co`000`000?ooooooo`1:oooo00?o09Woooooool0FOooo`00HOooo`030000<ol0<ol001<co`02
0000Boooo`03o`2Ioooooooo05Woool0067oool00`0003?o03?o000C<ol000<0003oooooool0B_oo
o`03o`2Ioooooooo05Woool006;oool00`0003?o03?o000B<ol000<0003oooooool0B_ooo`03o`2I
oooooooo05Woool006;oool00`0003?o03?o000B<ol000<0003oooooool0B_ooo`03o`2Ioooooooo
05Woool006;oool00`0003?o03?o000B<ol00P0004_oool00ol0VOooooooo`1Ioooo001Roooo00<0
000co`0co`004S?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001Soooo00<0000co`0c
o`004C?o00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001Soooo00<0000co`0co`004C?o
00030000oooooooo04[oool00ol0VOooooooo`1Ioooo001Soooo00<0000co`0co`004C?o0080001;
oooo00?o09Woooooool0FOooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`1:oooo00?o
09Woooooool0FOooo`00Hoooo`030000<ol0<ol000Tco`0500000c?o00030000oooooooo04[oool0
0ol0VOooooooo`1Ioooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol000<co`000`000?oo
ooooo`1:oooo00?o09Woooooool0FOooo`00I?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003
<ol00P0004_oool00ol0VOooooooo`1Ioooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001T
oooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo33?o00800005<ol0ZOooo`00IOoooa8co`2Y
oooo001Uoooo4S?o0:Woool006GooolB<ol01Oooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001Uoooo4S?o00Coool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo
07_oool006GooolB<ol01?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2
00001?ooo`800003oooo0`0000Coool00`000?ooooooo`1koooo001Uoooo4S?o00Coool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001Uoooo4S?o00?oool00`000?oo
ooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo07[oool006KooolA<ol01?ooo`030000oooooooo00D0000<oooo00@0003ooooo
ool00008oooo0`0000Coool00`000?ooooooo`1koooo001Voooo4C?o00Coool01@000?oooooooooo
o`00000?oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo07_oool0
06KooolA<ol01Oooo`030000oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?oo
o`00I_oooa4co`2Yoooo001Voooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71741 .30902 L
.72307 .30902 L
.72585 .30902 L
.72707 .30902 L
.72772 .30902 L
.72841 .30902 L
s
.72841 .30902 m
.72853 .61803 L
s
0 .4 1 r
.02381 .18697 m
.04262 .16866 L
.06244 .14635 L
.07216 .13416 L
.07472 .13079 L
.0775 .12706 L
.07878 .12533 L
.07948 .12437 L
.08013 .12347 L
.08128 .12241 L
.08255 .1227 L
.08852 .12414 L
.09396 .1255 L
.10458 .12831 L
.14335 .14061 L
.18458 .158 L
.22428 .1803 L
.26248 .20855 L
.30312 .24849 L
.32192 .27148 L
.33181 .285 L
.34225 .30051 L
.34482 .30453 L
.34623 .30678 L
.34693 .3079 L
.34757 .30894 L
.34832 .30902 L
.34915 .30902 L
.34985 .30902 L
.35059 .30902 L
.35128 .30902 L
.35193 .30902 L
.35264 .30902 L
.3534 .30902 L
.35465 .30902 L
.35536 .30902 L
.35601 .30902 L
.35671 .30902 L
.35734 .30902 L
.35807 .30902 L
.35876 .30902 L
.35998 .30902 L
.36111 .30902 L
.36235 .30902 L
.36366 .30902 L
.36491 .30902 L
.36606 .30902 L
.36737 .30902 L
.36863 .30902 L
.36978 .30902 L
Mistroke
.37085 .30902 L
.37202 .30902 L
.37327 .30902 L
.37398 .30902 L
.37464 .30902 L
.37536 .30902 L
.37613 .30902 L
.37741 .30902 L
.37814 .30902 L
.37881 .30902 L
.38007 .30902 L
.38076 .30902 L
.38141 .30902 L
.38257 .30902 L
.38383 .30902 L
.38506 .30902 L
.38618 .30902 L
.38741 .30902 L
.3887 .30902 L
.38975 .30902 L
.39088 .30902 L
.39211 .30902 L
.39326 .30902 L
.39396 .30902 L
.39461 .30902 L
.39531 .30902 L
.39606 .30902 L
.39732 .30902 L
.39804 .30902 L
.39871 .30902 L
.39995 .30902 L
.40109 .30902 L
.4024 .30902 L
.40365 .30902 L
.40485 .30902 L
.40554 .30902 L
.40618 .30902 L
.40887 .30902 L
.41371 .30902 L
.42467 .30902 L
.46332 .30902 L
.50443 .30902 L
.54402 .30902 L
.5821 .30902 L
.62263 .30902 L
.66164 .30902 L
.70311 .30902 L
.74306 .30902 L
.78149 .30902 L
.82238 .30902 L
Mistroke
.86175 .30902 L
.8996 .30902 L
.93991 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool007Ooool0
0`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`009Oooo`0306Kooooooooo04ooool2
0000Yoooo`009?ooo`0306Kooooo06Ko00<0I_m=oooo00<0003oooooool0Y_ooo`008oooo`0306Ko
oooooooo00Coool306KoB_ooo`030000oooooooo0:Koool002;oool00`1Vooooooooo`08oooo0`1V
odOoool00`000?ooooooo`2Voooo000Qoooo00<0I_ooooooool03?ooo`@0I_m3oooo0P000:Ooool0
027oool00`1Vooooooooo`0@oooo0`1Vod3oool00`000?ooooooo`2Voooo000Poooo00<0I_oooooo
ool05?ooo`80I_l[oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`007ooo
o`0306Kooooooooo01Ooool306Ko9oooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool001koool00`1Vooooooooo`0Koooo0P1VobGoool010000?ooooooo`00
00_oool00`000?ooooooo`02oooo0P000:Ooool001goool00`1Vooooooooo`0Noooo0P1Voagoool4
00000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_ooo`007Oooo`0306Ko
oooooooo023oool206Ko8Oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`2Voooo000Loooo00<0I_ooooooool08oooo`80I_lPoooo0P0000[oool300001?ooo`030000
oooooooo0:Koool001_oool00`1Vooooooooo`0Voooo00<0I_ooooooool0<?ooo`80002Woooo000J
oooo00<0I_ooooooool0:?ooo`80I_l`oooo00<0003oooooool0Y_ooo`006?ooo`80I_l]oooo0P1V
obkoool00`000?ooooooo`2Voooo000Goooo00<0I_ooooooool0;oooo`0306Kooooooooo02_oool0
0`000?ooooooo`2Voooo000Foooo00<0I_ooooooool0<Oooo`80I_l[oooo0P000:Ooool004coool0
0`1Vooooooooo`0Xoooo00<0003oooooool0Y_ooo`00COooo`0306Kooooooooo02Ooool00`000?oo
ooooo`2Voooo001>oooo0P1VobOoool00`000?ooooooo`2Voooo001@oooo00<0I_ooooooool09?oo
o`80002Woooo001Aoooo0P1VobCoool00`000?ooooooo`2Voooo001Coooo00<0I_ooooooool08Ooo
o`030000oooooooo0:Koool005Coool00`1Vooooooooo`0Poooo00<0003oooooool0Y_ooo`00EOoo
o`0306Kooooooooo01ooool20000Yoooo`00E_ooo`0306Kooooooooo01koool00`000?ooooooo`2V
oooo001Goooo00<0I_ooooooool01?ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool0Y_ooo`00F?ooo`0306Kooooooooo00;oool010000?ooooooo`0000Soool00`000?oo
ooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0Y_ooo`00FOooo`0506Kooooooooo
oooo000000;oool00`000?ooooooo`07oooo00<0003oooooool01Oooo`030000oooooooo00;oool2
0000Yoooo`00Eoooo`@00002oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800005
oooo00<0003oooooool0Y_ooo`00Foooo`0306Kooooo000000;oool00`000?ooooooo`06oooo00@0
003oooooool00003oooo00<0003oooooool01?ooo`030000oooooooo0:Koool005coool0101Voooo
o`00000000[oool200001?ooo`<00004oooo00<0003oooooool0Y_ooo`00GOooo`0306Kooooooooo
01Ooool20000Yoooo`00G_ooo`0306Kooooooooo01Koool00`000?ooooooo`2Voooo001Ooooo00<0
I_ooooooool05Oooo`030000oooooooo0:Koool005ooool00`1Vooooooooo`0Eoooo00<0003ooooo
ool0Y_ooo`005oooo`@0000]oooo1@0001?oool00`1Vooooooooo`0Doooo0P0002coool50000:ooo
o`@0000^oooo0P0001Ooool001Ooool00`000?ooooooo`0`oooo00<0003oooooool05?ooo`0306Ko
oooooooo01?oool00`000?ooooooo`0]oooo00<0003oooooool0:oooo`030000oooooooo02koool0
10000?ooooooo`0001Koool001Soool00`000?ooooooo`0_oooo00<0003oooooool05Oooo`0306Ko
oooooooo01;oool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?oo
ooooo`0Foooo00<0I_ooooooool04Oooo`030000oooooooo02goool00`000?ooooooo`0]oooo00<0
003oooooool0;oooo`030000oooooooo01Coool001Ooool010000?ooooooo`0002ooool00`000?oo
ooooo`0Foooo00<0I_ooooooool04Oooo`80000^oooo00<0003oooooool0:oooo`040000oooooooo
0000;Oooo`040000oooooooo00005_ooo`006?ooo`80000_oooo0P0001Woool00`1Vooooooooo`0@
oooo00<0003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00IOooo`0306Kooooooooo
00ooool00`000?ooooooo`2Voooo001Uoooo00<0I_ooooooool03oooo`80002Woooo001Voooo00<0
I_ooooooool03_ooo`030000oooooooo0:Koool006Ooool00`1Vooooooooo`0=oooo00<0003ooooo
ool0Y_ooo`00J?ooo`0306Kooooooooo00coool00`000?ooooooo`2Voooo000@ooooo`00017oool0
01Koool800000S?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000oooooooo00Koool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool00_oo
o`03o`2Ioooooooo00;oool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool01Oooo`X0000O<ol000<0000co`0co`00;C?o00030000
oooooooo02goool00`000?ooooooo`0Ooooo00?o09Woooooool02oooo`030000oooooooo02koool0
0`000?ooooooo`0Eoooo000Xoooo1P0004Tco`000`000?ooooooo`1?oooo00?o09Woooooool0E?oo
o`00;_ooo`D00014<ol00P00053oool00ol0VOooooooo`1Doooo000coooo1000040co`000`000?oo
ooooo`1?oooo00?o09Woooooool0E?ooo`00=oooo`80000n<ol000<0003oooooool0Coooo`03o`2I
oooooooo05Coool003Woool30000>c?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo000l
oooo0P0003Tco`020000D?ooo`03o`2Ioooooooo05Coool003koool20000=c?o00030000oooooooo
04ooool00ol0VOooooooo`1Doooo0010oooo0P0003Dco`000`000?ooooooo`1?oooo00?o09Wooooo
ool0E?ooo`00@_ooo`80000c<ol000<0003oooooool0Coooo`03o`2Ioooooooo05Coool004Coool2
0000<C?o0080001@oooo00?o09Woooooool0E?ooo`00A_ooo`030000<ol0<ol002hco`000`000?oo
ooooo`1?oooo00?o09Woooooool0E?ooo`00Aoooo`030000<ol0<ol002dco`000`000?ooooooo`1?
oooo00?o09Woooooool0E?ooo`00B?ooo`030000<ol0<ol002`co`000`000?ooooooo`1?oooo00?o
09Woooooool0E?ooo`00BOooo`030000<ol0<ol002/co`020000D?ooo`03o`2Ioooooooo05Coool0
04[oool00`0003?o03?o000Z<ol000<0003oooooool0Coooo`03o`2Ioooooooo05Coool004_oool0
0`0003?o03?o000@<ol00P0000@co`0200000c?o00@00003<ol00P0000Dco`000`000?ooooooo`1?
oooo00?o09Woooooool0E?ooo`00C?ooo`030000<ol0<ol000hco`00100003?o03?o000000Pco`00
0`0003?o03?o0003<ol000@0000co`0co`000004<ol000<0003oooooool0Coooo`03o`2Ioooooooo
05Coool004goool00`0003?o03?o000=<ol000@0000co`0co`000009<ol000<0000co`0co`001C?o
00030000<ol0<ol0008co`020000D?ooo`03o`2Ioooooooo05Coool004koool00`0003?o03?o000<
<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Cooo
o`03o`2Ioooooooo05Coool004ooool00`0003?o03?o000;<ol000@0000co`0co`000008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo04ooool00ol0VOooooooo`1D
oooo001?oooo00<0000co`0co`0033?o0080000:<ol00P0000@co`03000013?o00030000oooooooo
04ooool00ol0VOooooooo`1Doooo001@oooo00<0000co`0co`0093?o0080001@oooo00?o09Wooooo
ool0E?ooo`00DOooo`030000<ol0<ol002<co`000`000?ooooooo`1?oooo00?o09Woooooool0E?oo
o`00D_ooo`030000<ol0<ol0028co`000`000?ooooooo`1?oooo00?o09Woooooool0E?ooo`00D_oo
o`030000<ol0<ol0028co`000`000?ooooooo`1?oooo00?o09Woooooool0E?ooo`00Doooo`030000
<ol0<ol0024co`020000D?ooo`03o`2Ioooooooo05Coool005?oool00`0003?o03?o000Q<ol000<0
003oooooool0Coooo`03o`2Ioooooooo05Coool005Coool00`0003?o03?o000P<ol000<0003ooooo
ool0Coooo`03o`2Ioooooooo05Coool005Coool00`0003?o03?o000P<ol000<0003oooooool0Cooo
o`03o`2Ioooooooo05Coool005Goool00`0003?o03?o000O<ol00P00053oool00ol0VOooooooo`1D
oooo001Eoooo00<0000co`0co`007c?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001F
oooo00<0000co`0co`007S?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Foooo00<0
000co`0co`007S?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Goooo00<0000co`0c
o`007C?o0080001@oooo00?o09Woooooool0E?ooo`00Eoooo`030000<ol0<ol001dco`000`000?oo
ooooo`1?oooo00?o09Woooooool0E?ooo`00F?ooo`030000<ol0<ol000Tco`02000013?o00800004
<ol00P0000Dco`000`000?ooooooo`1?oooo00?o09Woooooool0E?ooo`00F?ooo`030000<ol0<ol0
00Pco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`1?oooo00?o
09Woooooool0E?ooo`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`000`0003?o
03?o0002<ol00P00053oool00ol0VOooooooo`1Doooo001Ioooo00<0000co`0co`001c?o00040000
<ol0<ol000002C?o00800005<ol000<0003oooooool0Coooo`03o`2Ioooooooo05Coool005Woool0
0`0003?o03?o0007<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000oooooooo
04ooool00ol0VOooooooo`1Doooo001Joooo00<0000co`0co`001c?o0080000:<ol00`0000@co`00
0`000?ooooooo`1?oooo00?o09Woooooool0E?ooo`00F_ooo`030000<ol0<ol001Xco`020000D?oo
o`03o`2Ioooooooo05Coool005[oool00`0003?o03?o000J<ol000<0003oooooool0Coooo`03o`2I
oooooooo05Coool005_oool00`0003?o03?o000I<ol000<0003oooooool0Coooo`03o`2Ioooooooo
05Coool005_oool00`0003?o03?o000I<ol00P00053oool00ol0VOooooooo`1Doooo001Koooo00<0
000co`0co`006C?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Loooo00<0000co`0c
o`0063?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Loooo00<0000co`0co`0063?o
00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Loooo00<0000co`0co`0063?o0080001@
oooo00?o09Woooooool0E?ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1?oooo00?o
09Woooooool0E?ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1?oooo00?o09Wooooo
ool0E?ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1?oooo00?o09Woooooool0E?oo
o`00G_ooo`030000<ol0<ol001Hco`020000D?ooo`03o`2Ioooooooo05Coool005koool00`0003?o
03?o000F<ol000<0003oooooool0Coooo`03o`2Ioooooooo05Coool005koool2000013?o00800005
<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Coooo`03o`2Ioooooooo05Coool0
05goool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o
00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Moooo00@0003oool00000000:<ol000<0
000co`0co`0013?o00030000<ol0<ol0008co`020000D?ooo`03o`2Ioooooooo05Coool005goool0
10000?ooo`00000000/co`00100003?o03?o03?o00800005<ol000<0003oooooool0Coooo`03o`2I
oooooooo05Coool005goool010000?ooooooo`0000Pco`00100003?o03?o000000<co`000`0003?o
03?o0004<ol000<0003oooooool0Coooo`03o`2Ioooooooo05Coool005koool3000023?o00@00003
<ol00`0000@co`000`000?ooooooo`1?oooo00?o09Woooooool0E?ooo`00H?ooo`030000<ol0<ol0
01@co`020000D?ooo`03o`2Ioooooooo05Coool0063oool00`0003?o03?o000D<ol000<0003ooooo
ool0Coooo`03o`2Ioooooooo05Coool0067oool00`0003?o03?o000C<ol000<0003oooooool0Cooo
o`03o`2Ioooooooo05Coool0067oool00`0003?o03?o000C<ol000<0003oooooool0Coooo`03o`2I
oooooooo05Coool0067oool00`0003?o03?o000C<ol00P00053oool00ol0VOooooooo`1Doooo001Q
oooo00<0000co`0co`004c?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Roooo00<0
000co`0co`004S?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Roooo00<0000co`0c
o`004S?o00030000oooooooo04ooool00ol0VOooooooo`1Doooo001Roooo00<0000co`0co`004S?o
0080001@oooo00?o09Woooooool0E?ooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`1?
oooo00?o09Woooooool0E?ooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`1?oooo00?o
09Woooooool0E?ooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`1?oooo00?o09Wooooo
ool0E?ooo`00Hoooo`030000<ol0<ol0014co`020000D?ooo`03o`2Ioooooooo05Coool006?oool0
0`0003?o03?o000A<ol000<0003oooooool0Coooo`03o`2Ioooooooo05Coool006?oool00`0003?o
03?o0009<ol01@0000<co`000`000?ooooooo`1?oooo00?o09Woooooool0E?ooo`00I?ooo`030000
<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003oooooool0Coooo`03o`2Ioooooooo05Coool0
06Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o0080001@oooo00?o09Woooooool0E?oo
o`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOoo
o`00I?ooo``co`0200001C?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o
00Goool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00IOoooa8co`04oooo00<0003ooooo
ool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001Uoooo4S?o00Coool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`030000oooooooo
00;oool00`000?ooooooo`1koooo001Uoooo4S?o00Coool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo00<0003oooooool0Noooo`00IOoooa8co`03oooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00I_oo
oa4co`04oooo00<0003oooooool01@0000coool010000?ooooooo`0000_oool01@000?oooooooooo
o`00001moooo001Voooo4C?o00Coool01@000?ooooooooooo`00000?oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00I_oooa4co`05oooo00<0003ooooo
ool04Oooo`800009oooo100000;oool00`000?ooooooo`1loooo001Voooo4C?o0:Woool006KooolA
<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.72912 .30902 L
.73838 .30902 L
.74309 .30902 L
.74546 .30902 L
.74611 .30902 L
.7468 .30902 L
s
.7468 .30902 m
.74693 .61803 L
s
0 .4 1 r
.02381 .16289 m
.04262 .14095 L
.0522 .12854 L
.05746 .12133 L
.06005 .11768 L
.06119 .11605 L
.06244 .11513 L
.06371 .11535 L
.06506 .1156 L
.0679 .11612 L
.07286 .11707 L
.08255 .11901 L
.10458 .12396 L
.14487 .13529 L
.18364 .14969 L
.22486 .16994 L
.26457 .19578 L
.30277 .22844 L
.34341 .27485 L
.35255 .28748 L
.36221 .30192 L
.36464 .30576 L
.36529 .30679 L
.36599 .30791 L
.36726 .30902 L
.36803 .30902 L
.36875 .30902 L
.36942 .30902 L
.37012 .30902 L
.37139 .30902 L
.37212 .30902 L
.3728 .30902 L
.37399 .30902 L
.37524 .30902 L
.37631 .30902 L
.37749 .30902 L
.37875 .30902 L
.37946 .30902 L
.3801 .30902 L
.38136 .30902 L
.38254 .30902 L
.38378 .30902 L
.38448 .30902 L
.38514 .30902 L
.38583 .30902 L
.38646 .30902 L
.38719 .30902 L
.38789 .30902 L
.38911 .30902 L
.39024 .30902 L
Mistroke
.39149 .30902 L
.39218 .30902 L
.39281 .30902 L
.39351 .30902 L
.39425 .30902 L
.39557 .30902 L
.39631 .30902 L
.39699 .30902 L
.39775 .30902 L
.39855 .30902 L
.39925 .30902 L
.4 .30902 L
.40072 .30902 L
.40138 .30902 L
.40263 .30902 L
.40326 .30902 L
.40395 .30902 L
.40523 .30902 L
.40587 .30902 L
.40657 .30902 L
.40896 .30902 L
.41436 .30902 L
.42412 .30902 L
.46474 .30902 L
.50383 .30902 L
.54538 .30902 L
.58542 .30902 L
.62394 .30902 L
.66491 .30902 L
.70436 .30902 L
.7423 .30902 L
.78269 .30902 L
.82157 .30902 L
.8629 .30902 L
.90271 .30902 L
.94101 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo0:Koool0023oool2
06KoEOooo`030000oooooooo0:Koool001ooool00`1Vooooo`1Vo`0606KoCoooo`030000oooooooo
0:Koool001ooool00`1Vooooooooo`06oooo1@1Vod[oool20000Yoooo`007_ooo`0306Kooooooooo
00coool306KoAoooo`030000oooooooo0:Koool001goool00`1Vooooooooo`0@oooo101Vod?oool0
0`000?ooooooo`2Voooo000Loooo00<0I_ooooooool05Oooo`<0I_m0oooo00<0003oooooool0Y_oo
o`007?ooo`0306Kooooooooo01Soool206Ko?_ooo`80002Woooo000Koooo00<0I_ooooooool06ooo
o`<0I_lkoooo00<0003oooooool0Y_ooo`006_ooo`0306Kooooooooo01ooool206Ko9_ooo`800004
oooo0P0000Coool200001Oooo`030000oooooooo0:Koool001Woool00`1Vooooooooo`0Roooo0P1V
ob?oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`2Voooo000H
oooo00<0I_ooooooool09Oooo`80I_lQoooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`80002Woooo000Goooo00<0I_ooooooool0:?ooo`80I_lIoooo100000;oool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo0:Koool001Koool00`1Vooooooooo`0[oooo0P1Voagoool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00A_ooo`80I_lL
oooo0P0000[oool300001?ooo`030000oooooooo0:Koool004Soool206Ko;Oooo`80002Woooo001:
oooo0P1Vob_oool00`000?ooooooo`2Voooo001<oooo00<0I_ooooooool0:?ooo`030000oooooooo
0:Koool004goool00`1Vooooooooo`0Woooo00<0003oooooool0Y_ooo`00C_ooo`80I_lWoooo0P00
0:Ooool0053oool00`1Vooooooooo`0Toooo00<0003oooooool0Y_ooo`00DOooo`80I_lToooo00<0
003oooooool0Y_ooo`00Doooo`0306Kooooooooo027oool00`000?ooooooo`2Voooo001Doooo00<0
I_ooooooool08?ooo`80002Woooo001Eoooo0P1Vob3oool00`000?ooooooo`2Voooo001Goooo00<0
I_ooooooool07Oooo`030000oooooooo0:Koool005Soool00`1Vooooooooo`0Loooo00<0003ooooo
ool0Y_ooo`00FOooo`0306Kooooooooo01_oool20000Yoooo`00F_ooo`80I_lKoooo00<0003ooooo
ool0Y_ooo`00G?ooo`0406Kooooo000000001?ooo`800003oooo100000?oool200001Oooo`030000
oooooooo0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003ooooo
ool00004oooo00<0003oooooool0Y_ooo`00GOooo`04000006Kooooo00002Oooo`030000oooooooo
00Goool00`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooo06Ko00002_oo
o`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?ooo`1Vo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Y_ooo`00G_oo
o`8000000`1Vooooooooo`07oooo0P0000Coool300001?ooo`030000oooooooo0:Koool0067oool0
0`1Vooooooooo`0Coooo0P000:Ooool006;oool00`1Vooooooooo`0Boooo00<0003oooooool0Y_oo
o`00Hoooo`0306Kooooooooo017oool00`000?ooooooo`2Voooo001Toooo00<0I_ooooooool04?oo
o`030000oooooooo0:Koool001Ooool40000;Oooo`D0000Goooo00<0I_ooooooool04?ooo`80000/
oooo1@0002_oool40000;_ooo`80000Goooo000Goooo00<0003oooooool0<?ooo`030000oooooooo
01Soool00`1Vooooooooo`0?oooo00<0003oooooool0;Oooo`030000oooooooo02_oool00`000?oo
ooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000oooooooo
01Woool00`1Vooooooooo`0>oooo00<0003oooooool0;Oooo`030000oooooooo02coool00`000?oo
ooooo`0_oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool09_ooo`@00004
oooo00<0003oooooool06_ooo`0306Kooooooooo00goool00`000?ooooooo`0]oooo00<0003ooooo
ool0;Oooo`030000oooooooo02ooool00`000?ooooooo`0Doooo000Goooo00@0003oooooool0000_
oooo00<0003oooooool06oooo`0306Kooooooooo00coool20000;_ooo`030000oooooooo02_oool0
10000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool20000;oooo`80000Noooo00<0
I_ooooooool02oooo`030000oooooooo02coool20000;_ooo`80000_oooo0P0001Ooool006[oool0
0`1Vooooooooo`0:oooo00<0003oooooool0Y_ooo`00J_ooo`0306Kooooooooo00[oool20000Yooo
o`00Joooo`0306Kooooooooo00Woool00`000?ooooooo`2Voooo001[oooo00<0I_ooooooool02Ooo
o`030000oooooooo0:Koool006coool00`1Vooooooooo`08oooo00<0003oooooool0Y_ooo`004?oo
ool0000Aoooo000Foooo2000008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`000?ooooooo`06
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool01Oooo`X0000O<ol000<0000co`0co`00;C?o00030000oooooooo
02goool00`000?ooooooo`0Toooo00?o09Woooooool01_ooo`030000oooooooo02koool00`000?oo
ooooo`0Eoooo000Xoooo1P0004Tco`000`000?ooooooo`1Doooo00?o09Woooooool0Coooo`00;_oo
o`D00014<ol00P0005Goool00ol0VOooooooo`1?oooo000coooo1000040co`000`000?ooooooo`1D
oooo00?o09Woooooool0Coooo`00=oooo`80000n<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
04ooool003Woool30000>c?o00030000oooooooo05Coool00ol0VOooooooo`1?oooo000loooo0P00
03Tco`020000EOooo`03o`2Ioooooooo04ooool003koool20000=c?o00030000oooooooo05Coool0
0ol0VOooooooo`1?oooo0010oooo0P0003Dco`000`000?ooooooo`1Doooo00?o09Woooooool0Cooo
o`00@_ooo`80000c<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04ooool004Coool20000<C?o
0080001Eoooo00?o09Woooooool0Coooo`00A_ooo`030000<ol0<ol002hco`000`000?ooooooo`1D
oooo00?o09Woooooool0Coooo`00Aoooo`030000<ol0<ol002dco`000`000?ooooooo`1Doooo00?o
09Woooooool0Coooo`00B?ooo`030000<ol0<ol002`co`000`000?ooooooo`1Doooo00?o09Wooooo
ool0Coooo`00BOooo`030000<ol0<ol002/co`020000EOooo`03o`2Ioooooooo04ooool004[oool0
0`0003?o03?o000Z<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04ooool004_oool00`0003?o
03?o000@<ol00P0000@co`0200000c?o00@00003<ol00P0000Dco`000`000?ooooooo`1Doooo00?o
09Woooooool0Coooo`00C?ooo`030000<ol0<ol000hco`00100003?o03?o000000Pco`000`0003?o
03?o0003<ol000@0000co`0co`000004<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04ooool0
04goool00`0003?o03?o000=<ol000@0000co`0co`000009<ol000<0000co`0co`001C?o00030000
<ol0<ol0008co`020000EOooo`03o`2Ioooooooo04ooool004koool00`0003?o03?o000<<ol000@0
000co`0co`00000:<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0E?ooo`03o`2I
oooooooo04ooool004ooool00`0003?o03?o000;<ol000@0000co`0co`000008<ol000@0000co`0c
o`000003<ol000<0000co`0co`0013?o00030000oooooooo05Coool00ol0VOooooooo`1?oooo001?
oooo00<0000co`0co`0033?o0080000:<ol00P0000@co`03000013?o00030000oooooooo05Coool0
0ol0VOooooooo`1?oooo001@oooo00<0000co`0co`0093?o0080001Eoooo00?o09Woooooool0Cooo
o`00DOooo`030000<ol0<ol002<co`000`000?ooooooo`1Doooo00?o09Woooooool0Coooo`00D_oo
o`030000<ol0<ol0028co`000`000?ooooooo`1Doooo00?o09Woooooool0Coooo`00D_ooo`030000
<ol0<ol0028co`000`000?ooooooo`1Doooo00?o09Woooooool0Coooo`00Doooo`030000<ol0<ol0
024co`020000EOooo`03o`2Ioooooooo04ooool005?oool00`0003?o03?o000Q<ol000<0003ooooo
ool0E?ooo`03o`2Ioooooooo04ooool005Coool00`0003?o03?o000P<ol000<0003oooooool0E?oo
o`03o`2Ioooooooo04ooool005Coool00`0003?o03?o000P<ol000<0003oooooool0E?ooo`03o`2I
oooooooo04ooool005Goool00`0003?o03?o000O<ol00P0005Goool00ol0VOooooooo`1?oooo001E
oooo00<0000co`0co`007c?o00030000oooooooo05Coool00ol0VOooooooo`1?oooo001Foooo00<0
000co`0co`007S?o00030000oooooooo05Coool00ol0VOooooooo`1?oooo001Foooo00<0000co`0c
o`007S?o00030000oooooooo05Coool00ol0VOooooooo`1?oooo001Goooo00<0000co`0co`007C?o
0080001Eoooo00?o09Woooooool0Coooo`00Eoooo`030000<ol0<ol001dco`000`000?ooooooo`1D
oooo00?o09Woooooool0Coooo`00F?ooo`030000<ol0<ol000Tco`02000013?o00800004<ol00P00
00Dco`000`000?ooooooo`1Doooo00?o09Woooooool0Coooo`00F?ooo`030000<ol0<ol000Pco`00
100003?o03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`1Doooo00?o09Wooooo
ool0Coooo`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`000`0003?o03?o0002
<ol00P0005Goool00ol0VOooooooo`1?oooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol0
00002C?o00800005<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04ooool005Woool00`0003?o
03?o0007<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000oooooooo05Coool0
0ol0VOooooooo`1?oooo001Joooo00<0000co`0co`001c?o0080000:<ol00`0000@co`000`000?oo
ooooo`1Doooo00?o09Woooooool0Coooo`00F_ooo`030000<ol0<ol001Xco`020000EOooo`03o`2I
oooooooo04ooool005[oool00`0003?o03?o000J<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
04ooool005_oool00`0003?o03?o000I<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04ooool0
05_oool00`0003?o03?o000I<ol00P0005Goool00ol0VOooooooo`1?oooo001Koooo00<0000co`0c
o`006C?o00030000oooooooo05Coool00ol0VOooooooo`1?oooo001Loooo00<0000co`0co`0063?o
00030000oooooooo05Coool00ol0VOooooooo`1?oooo001Loooo00<0000co`0co`0063?o00030000
oooooooo05Coool00ol0VOooooooo`1?oooo001Loooo00<0000co`0co`0063?o0080001Eoooo00?o
09Woooooool0Coooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1Doooo00?o09Wooooo
ool0Coooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1Doooo00?o09Woooooool0Cooo
o`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1Doooo00?o09Woooooool0Coooo`00G_oo
o`030000<ol0<ol001Hco`020000EOooo`03o`2Ioooooooo04ooool005koool00`0003?o03?o000F
<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04ooool005koool2000013?o00800005<ol000<0
000co`0co`000S?o00800005<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04ooool005goool0
10000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000
oooooooo05Coool00ol0VOooooooo`1?oooo001Moooo00@0003oool00000000:<ol000<0000co`0c
o`0013?o00030000<ol0<ol0008co`020000EOooo`03o`2Ioooooooo04ooool005goool010000?oo
o`00000000/co`00100003?o03?o03?o00800005<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
04ooool005goool010000?ooooooo`0000Pco`00100003?o03?o000000<co`000`0003?o03?o0004
<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04ooool005koool3000023?o00@00003<ol00`00
00@co`000`000?ooooooo`1Doooo00?o09Woooooool0Coooo`00H?ooo`030000<ol0<ol001@co`02
0000EOooo`03o`2Ioooooooo04ooool0063oool00`0003?o03?o000D<ol000<0003oooooool0E?oo
o`03o`2Ioooooooo04ooool0067oool00`0003?o03?o000C<ol000<0003oooooool0E?ooo`03o`2I
oooooooo04ooool0067oool00`0003?o03?o000C<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
04ooool0067oool00`0003?o03?o000C<ol00P0005Goool00ol0VOooooooo`1?oooo001Qoooo00<0
000co`0co`004c?o00030000oooooooo05Coool00ol0VOooooooo`1?oooo001Roooo00<0000co`0c
o`004S?o00030000oooooooo05Coool00ol0VOooooooo`1?oooo001Roooo00<0000co`0co`004S?o
00030000oooooooo05Coool00ol0VOooooooo`1?oooo001Roooo00<0000co`0co`004S?o0080001E
oooo00?o09Woooooool0Coooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`1Doooo00?o
09Woooooool0Coooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`1Doooo00?o09Wooooo
ool0Coooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`1Doooo00?o09Woooooool0Cooo
o`00Hoooo`030000<ol0<ol0014co`020000EOooo`03o`2Ioooooooo04ooool006?oool00`0003?o
03?o000A<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04ooool006?oool00`0003?o03?o0009
<ol01@0000<co`000`000?ooooooo`1Doooo00?o09Woooooool0Coooo`00I?ooo`030000<ol0<ol0
00Xco`000`0003?o03?o0003<ol000<0003oooooool0E?ooo`03o`2Ioooooooo04ooool006Coool0
0`0003?o03?o000:<ol000<0000co`0co`000c?o0080001Eoooo00?o09Woooooool0Coooo`00I?oo
o`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?oo
o``co`0200001C?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o00Goool0
0`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00IOoooa8co`04oooo00<0003oooooool02?oo
o`030000oooooooo01Woool00`000?ooooooo`1koooo001Uoooo4S?o00Coool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo00<0003ooooo
ool0Noooo`00IOoooa8co`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00IOoooa8co`03oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1joooo001Voooo4C?o00Coool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002Oooo`800004oooo00<0003oooooool0Nooo
o`00I_oooa4co`04oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool006KooolA<ol01Oooo`030000oooooooo017oool2
00002_ooo`800003oooo00<0003oooooool0O?ooo`00I_oooa4co`2Yoooo001Voooo4C?o0:Woool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75315 .30902 L
.75853 .30902 L
.76324 .30902 L
.76453 .30902 L
.76525 .30902 L
.76592 .30902 L
s
.76592 .30902 m
.76605 .61803 L
s
0 .4 1 r
.02381 .13587 m
.03279 .12392 L
.03793 .1167 L
.04018 .11346 L
.04136 .11173 L
.04262 .10988 L
.04325 .10958 L
.04394 .10968 L
.04517 .10985 L
.04758 .1102 L
.05288 .11097 L
.06244 .11245 L
.10458 .1203 L
.14487 .13035 L
.18364 .14308 L
.22486 .16091 L
.26457 .18353 L
.30277 .21189 L
.34341 .25173 L
.36221 .27469 L
.37209 .28827 L
.3775 .29619 L
.38254 .30394 L
.38386 .30603 L
.38511 .30803 L
.3858 .30902 L
.38654 .30902 L
.38786 .30902 L
.38856 .30902 L
.38933 .30902 L
.39013 .30902 L
.39089 .30902 L
.39159 .30902 L
.39224 .30902 L
.39295 .30902 L
.39369 .30902 L
.39492 .30902 L
.39623 .30902 L
.39747 .30902 L
.39859 .30902 L
.39928 .30902 L
.39991 .30902 L
.40061 .30902 L
.40135 .30902 L
.40259 .30902 L
.40329 .30902 L
.40395 .30902 L
.4052 .30902 L
.4059 .30902 L
.40656 .30902 L
Mistroke
.40903 .30902 L
.41368 .30902 L
.42412 .30902 L
.4633 .30902 L
.50494 .30902 L
.54506 .30902 L
.58366 .30902 L
.62472 .30902 L
.66426 .30902 L
.70228 .30902 L
.74276 .30902 L
.78172 .30902 L
.82313 .30902 L
.86303 .30902 L
.90141 .30902 L
.94224 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool007Ooool20000Yoooo`006oooo`@0I_mHoooo00<0003oooooool0Y_oo
o`006_ooo`0306Kooooooooo00;oool406KoE?ooo`030000oooooooo0:Koool001[oool00`1Voooo
ooooo`06oooo1P1Vodkoool00`000?ooooooo`2Voooo000Ioooo00<0I_ooooooool03Oooo`D0I_m9
oooo0P000:Ooool001Soool00`1Vooooooooo`0Coooo1@1VodCoool00`000?ooooooo`2Voooo000G
oooo00<0I_ooooooool06Oooo`@0I_m0oooo00<0003oooooool0Y_ooo`005oooo`0306Kooooooooo
01goool306Ko?Oooo`030000oooooooo0:Koool001Koool00`1Vooooooooo`0Qoooo101VocWoool2
0000Yoooo`00?_ooo`80I_lgoooo00<0003oooooool0Y_ooo`00@?ooo`80I_lRoooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool0Y_ooo`00@_ooo`80I_lOoooo00@0003oooooool00008
oooo00@0003oooooool00004oooo00<0003oooooool0Y_ooo`00A?ooo`80I_lMoooo00@0003ooooo
ool0000;oooo00<0003oooooool00_ooo`80002Woooo0016oooo0P1VoaGoool400000_ooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool0Y_ooo`00B?ooo`80I_lIoooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo0:Koool004[oool206Ko6?ooo`80000:
oooo0`0000Coool00`000?ooooooo`2Voooo001<oooo0P1VobWoool20000Yoooo`00C_ooo`0306Ko
oooooooo02Koool00`000?ooooooo`2Voooo001?oooo0P1VobKoool00`000?ooooooo`2Voooo001A
oooo0P1VobCoool00`000?ooooooo`2Voooo001Coooo00<0I_ooooooool08Oooo`80002Woooo001D
oooo0P1Vob7oool00`000?ooooooo`2Voooo001Foooo00<0I_ooooooool07_ooo`030000oooooooo
0:Koool005Ooool00`1Vooooooooo`0Moooo00<0003oooooool0Y_ooo`00F?ooo`80I_lMoooo0P00
0:Ooool005[oool00`1Vooooooooo`0Joooo00<0003oooooool0Y_ooo`00Foooo`80I_lJoooo00<0
003oooooool0Y_ooo`00GOooo`0306Kooooooooo01Ooool00`000?ooooooo`2Voooo001Noooo00<0
I_ooooooool05_ooo`80002Woooo001Ooooo00<0I_ooooooool05Oooo`030000oooooooo0:Koool0
05koool2000000@0I_ooooooooooool200000oooo`@00003oooo0P0000Goool00`000?ooooooo`2V
oooo001Moooo00D0003oooooool00000I_l01oooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`2Voooo001Moooo00H0003oooooool0003oool0I_l7oooo00<0003ooooo
ool01Oooo`030000oooooooo00;oool20000Yoooo`00Eoooo`@00002oooo00@0003oooooool00002
oooo00<0I_ooooooool01Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool0
05goool010000?ooooooo`0000?oool00`1Vooooooooo`02oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo0:Koool005koool200001Oooo`0306Kooooooooo00;oool2
00001?ooo`<00004oooo00<0003oooooool0Y_ooo`00I_ooo`0306Kooooooooo00koool20000Yooo
o`00Ioooo`0306Kooooooooo00goool00`000?ooooooo`2Voooo001Xoooo00<0I_ooooooool03?oo
o`030000oooooooo0:Koool006Woool00`1Vooooooooo`0;oooo00<0003oooooool0Y_ooo`005ooo
o`@0000]oooo1@0001coool00`1Vooooooooo`0;oooo0P0002coool50000:oooo`@0000^oooo0P00
01Ooool001Ooool00`000?ooooooo`0`oooo00<0003oooooool07Oooo`0306Kooooooooo00[oool0
0`000?ooooooo`0]oooo00<0003oooooool0:oooo`030000oooooooo02koool010000?ooooooo`00
01Koool001Soool00`000?ooooooo`0_oooo00<0003oooooool07_ooo`0306Kooooooooo00Woool0
0`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool00`000?ooooooo`0E
oooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?ooooooo`0Ooooo00<0
I_ooooooool02?ooo`030000oooooooo02goool00`000?ooooooo`0]oooo00<0003oooooool0;ooo
o`030000oooooooo01Coool001Ooool010000?ooooooo`0002ooool00`000?ooooooo`0Poooo00<0
I_ooooooool01oooo`80000^oooo00<0003oooooool0:oooo`040000oooooooo0000;Oooo`040000
oooooooo00005_ooo`006?ooo`80000_oooo0P0002?oool00`1Vooooooooo`06oooo00<0003ooooo
ool0;?ooo`80000^oooo0P0002ooool200005oooo`00Koooo`0306Kooooooooo00Goool00`000?oo
ooooo`2Voooo001_oooo00<0I_ooooooool01Oooo`80002Woooo001`oooo00<0I_ooooooool01?oo
o`030000oooooooo0:Koool0073oool00`1Vooooooooo`04oooo00<0003oooooool0Y_ooo`00LOoo
o`0306Kooooooooo00?oool00`000?ooooooo`2Voooo000@ooooo`00017oool001Koool800000S?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0006<ol000<0000co`0co`001c?o00030000oooooooo00Koool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`050000oooooooo
ooooo`2I00Coool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`05oooo2P0001lco`000`0003?o03?o000]<ol000<0003oooooool0;Oooo`030000oooooooo
02Soool00ol0VOooooooo`02oooo00<0003oooooool0;_ooo`030000oooooooo01Goool002Soool6
0000BC?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo000^oooo1@0004@co`020000FOoo
o`03o`2Ioooooooo04_oool003?oool40000@3?o00030000oooooooo05Soool00ol0VOooooooo`1;
oooo000goooo0P0003hco`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00>Oooo`<0000k
<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04_oool003coool20000>C?o0080001Ioooo00?o
09Woooooool0Boooo`00?_ooo`80000g<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04_oool0
043oool20000=C?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo0012oooo0P0003<co`00
0`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00A?ooo`80000a<ol00P0005Woool00ol0VOoo
ooooo`1;oooo0016oooo00<0000co`0co`00;S?o00030000oooooooo05Soool00ol0VOooooooo`1;
oooo0017oooo00<0000co`0co`00;C?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo0018
oooo00<0000co`0co`00;3?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo0019oooo00<0
000co`0co`00:c?o0080001Ioooo00?o09Woooooool0Boooo`00B_ooo`030000<ol0<ol002Xco`00
0`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00Boooo`030000<ol0<ol0010co`02000013?o
00800003<ol0100000<co`0200001C?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo001<
oooo00<0000co`0co`003S?o00040000<ol0<ol0000023?o00030000<ol0<ol000<co`00100003?o
03?o000000@co`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00COooo`030000<ol0<ol0
00dco`00100003?o03?o000000Tco`000`0003?o03?o0005<ol000<0000co`0co`000S?o0080001I
oooo00?o09Woooooool0Boooo`00C_ooo`030000<ol0<ol000`co`00100003?o03?o000000Xco`00
0`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00Cooo
o`030000<ol0<ol000/co`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o
03?o0004<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04_oool004ooool00`0003?o03?o000<
<ol00P0000Xco`02000013?o00<00004<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04_oool0
053oool00`0003?o03?o000T<ol00P0005Woool00ol0VOooooooo`1;oooo001Aoooo00<0000co`0c
o`008c?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo001Boooo00<0000co`0co`008S?o
00030000oooooooo05Soool00ol0VOooooooo`1;oooo001Boooo00<0000co`0co`008S?o00030000
oooooooo05Soool00ol0VOooooooo`1;oooo001Coooo00<0000co`0co`008C?o0080001Ioooo00?o
09Woooooool0Boooo`00Doooo`030000<ol0<ol0024co`000`000?ooooooo`1Hoooo00?o09Wooooo
ool0Boooo`00E?ooo`030000<ol0<ol0020co`000`000?ooooooo`1Hoooo00?o09Woooooool0Booo
o`00E?ooo`030000<ol0<ol0020co`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00EOoo
o`030000<ol0<ol001lco`020000FOooo`03o`2Ioooooooo04_oool005Goool00`0003?o03?o000O
<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04_oool005Koool00`0003?o03?o000N<ol000<0
003oooooool0F?ooo`03o`2Ioooooooo04_oool005Koool00`0003?o03?o000N<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo04_oool005Ooool00`0003?o03?o000M<ol00P0005Woool00ol0VOoo
ooooo`1;oooo001Goooo00<0000co`0co`007C?o00030000oooooooo05Soool00ol0VOooooooo`1;
oooo001Hoooo00<0000co`0co`002C?o00800004<ol00P0000@co`0200001C?o00030000oooooooo
05Soool00ol0VOooooooo`1;oooo001Hoooo00<0000co`0co`0023?o00040000<ol0<ol0000023?o
00040000<ol0<ol0000013?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo001Ioooo00<0
000co`0co`001c?o00040000<ol0<ol000002c?o00030000<ol0<ol0008co`020000FOooo`03o`2I
oooooooo04_oool005Woool00`0003?o03?o0007<ol000@0000co`0co`000009<ol00P0000Dco`00
0`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00FOooo`030000<ol0<ol000Lco`00100003?o
03?o000000Tco`000`0003?o03?o0004<ol000<0003oooooool0F?ooo`03o`2Ioooooooo04_oool0
05[oool00`0003?o03?o0007<ol00P0000Xco`03000013?o00030000oooooooo05Soool00ol0VOoo
ooooo`1;oooo001Joooo00<0000co`0co`006S?o0080001Ioooo00?o09Woooooool0Boooo`00F_oo
o`030000<ol0<ol001Xco`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00Foooo`030000
<ol0<ol001Tco`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00Foooo`030000<ol0<ol0
01Tco`020000FOooo`03o`2Ioooooooo04_oool005_oool00`0003?o03?o000I<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo04_oool005coool00`0003?o03?o000H<ol000<0003oooooool0F?oo
o`03o`2Ioooooooo04_oool005coool00`0003?o03?o000H<ol000<0003oooooool0F?ooo`03o`2I
oooooooo04_oool005coool00`0003?o03?o000H<ol00P0005Woool00ol0VOooooooo`1;oooo001M
oooo00<0000co`0co`005c?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo001Moooo00<0
000co`0co`005c?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo001Moooo00<0000co`0c
o`005c?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo001Noooo00<0000co`0co`005S?o
0080001Ioooo00?o09Woooooool0Boooo`00G_ooo`030000<ol0<ol001Hco`000`000?ooooooo`1H
oooo00?o09Woooooool0Boooo`00G_ooo`800004<ol00P0000Dco`000`0003?o03?o0002<ol00P00
00Dco`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00GOooo`040000oooo000000002S?o
00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0003oooooool0F?ooo`03o`2I
oooooooo04_oool005goool010000?ooo`00000000Xco`000`0003?o03?o0004<ol000<0000co`0c
o`000S?o0080001Ioooo00?o09Woooooool0Boooo`00GOooo`040000oooo000000002c?o00040000
<ol0<ol0<ol00P0000Dco`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00GOooo`040000
oooooooo000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?ooooooo`1H
oooo00?o09Woooooool0Boooo`00G_ooo`<00008<ol0100000<co`03000013?o00030000oooooooo
05Soool00ol0VOooooooo`1;oooo001Poooo00<0000co`0co`0053?o0080001Ioooo00?o09Wooooo
ool0Boooo`00H?ooo`030000<ol0<ol001@co`000`000?ooooooo`1Hoooo00?o09Woooooool0Booo
o`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00HOoo
o`030000<ol0<ol001<co`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00HOooo`030000
<ol0<ol001<co`020000FOooo`03o`2Ioooooooo04_oool0067oool00`0003?o03?o000C<ol000<0
003oooooool0F?ooo`03o`2Ioooooooo04_oool006;oool00`0003?o03?o000B<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo04_oool006;oool00`0003?o03?o000B<ol000<0003oooooool0F?oo
o`03o`2Ioooooooo04_oool006;oool00`0003?o03?o000B<ol00P0005Woool00ol0VOooooooo`1;
oooo001Roooo00<0000co`0co`004S?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo001S
oooo00<0000co`0co`004C?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo001Soooo00<0
000co`0co`004C?o00030000oooooooo05Soool00ol0VOooooooo`1;oooo001Soooo00<0000co`0c
o`004C?o0080001Ioooo00?o09Woooooool0Boooo`00Hoooo`030000<ol0<ol0014co`000`000?oo
ooooo`1Hoooo00?o09Woooooool0Boooo`00Hoooo`030000<ol0<ol000Tco`0500000c?o00030000
oooooooo05Soool00ol0VOooooooo`1;oooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol0
00<co`000`000?ooooooo`1Hoooo00?o09Woooooool0Boooo`00I?ooo`030000<ol0<ol000Xco`00
0`0003?o03?o0003<ol00P0005Woool00ol0VOooooooo`1;oooo001Toooo3C?o00030000<ol0<ol0
00<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo33?o00800005<ol0ZOoo
o`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol01Oooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001Uoooo4S?o00Coool00`000?ooooooo`08oooo00<0003oooooool06Ooo
o`030000oooooooo07_oool006GooolB<ol01?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800003oooo0`0000Coool00`000?ooooooo`1koooo001Uoooo4S?o
00Coool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00IOoooa8co`03
oooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Woool300001?oo
o`030000oooooooo07[oool006KooolA<ol01?ooo`030000oooooooo00D0000<oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00I_oooa4co`04oooo00D0
003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo07_oool006KooolA<ol01Oooo`030000oooooooo017oool200002_ooo`<00002oooo00<0
003oooooool0O?ooo`00I_oooa4co`2Yoooo001Voooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.75718 .30902 L
.76707 .30902 L
.77751 .30902 L
.78008 .30902 L
.78283 .30902 L
.78364 .30902 L
.78441 .30902 L
.7851 .30902 L
s
.7851 .30902 m
.78517 .61803 L
s
0 .4 1 r
.02381 .10539 m
.06244 .11022 L
.10458 .11725 L
.14415 .12605 L
.18221 .1371 L
.22272 .15246 L
.26171 .17172 L
.30316 .19841 L
.34309 .23217 L
.3815 .27526 L
.39087 .28798 L
.40095 .30295 L
.40236 .30517 L
.40311 .30636 L
.40391 .30764 L
.40467 .30887 L
.40537 .30902 L
.40606 .30902 L
.40672 .30902 L
.41201 .30902 L
.42237 .30902 L
.46172 .30902 L
.50027 .30902 L
.54127 .30902 L
.58076 .30902 L
.61873 .30902 L
.65915 .30902 L
.69806 .30902 L
.73942 .30902 L
.77927 .30902 L
.8176 .30902 L
.85838 .30902 L
.89765 .30902 L
.9354 .30902 L
.9756 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`00Mooo
o`030000oooooooo0:Koool001Koool506KoG?ooo`80002Woooo000Koooo201VoeCoool00`000?oo
ooooo`2Voooo000Soooo1P1Vodkoool00`000?ooooooo`2Voooo000Yoooo1@1VodWoool00`000?oo
ooooo`2Voooo000^oooo1@1VodCoool20000Yoooo`00<oooo`@0I_m0oooo00<0003oooooool0Y_oo
o`00=oooo`<0I_lmoooo00<0003oooooool0Y_ooo`00>_ooo`<0I_ljoooo00<0003oooooool0Y_oo
o`00?Oooo`<0I_lgoooo0P000:Ooool0043oool306Ko=?ooo`030000oooooooo0:Koool004?oool2
06Ko7oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo0:Koool004Goool306Ko6ooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo0:Koool004Soool2
06Ko6Oooo`040000oooooooo00002oooo`030000oooooooo00;oool20000Yoooo`00B_ooo`80I_lA
oooo100000;oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo0:Koool004coool2
06Ko5Oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001>
oooo0P1VoaCoool200002_ooo`<00004oooo00<0003oooooool0Y_ooo`00D?ooo`80I_lUoooo0P00
0:Ooool005;oool206Ko8oooo`030000oooooooo0:Koool005Coool206Ko8Oooo`030000oooooooo
0:Koool005Koool206Ko7oooo`030000oooooooo0:Koool005Soool00`1Vooooooooo`0Loooo0P00
0:Ooool005Woool206Ko7?ooo`030000oooooooo0:Koool005_oool206Ko6_ooo`030000oooooooo
0:Koool005goool00`1Vooooooooo`0Goooo00<0003oooooool0Y_ooo`00G_ooo`0306Kooooooooo
01Koool20000Yoooo`00Goooo`0306Kooooooooo01Goool00`000?ooooooo`2Voooo001Poooo00<0
I_ooooooool05?ooo`030000oooooooo0:Koool0067oool00`1Vooooooooo`0Coooo00<0003ooooo
ool0Y_ooo`00H_ooo`80I_lCoooo0P000:Ooool006Coool00`1Vooooooooo`0@oooo00<0003ooooo
ool0Y_ooo`00G_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0003oooooool0Y_oo
o`00GOooo`040000oooooooo00001Oooo`0406Kooooooooo00001Oooo`040000oooooooo00001?oo
o`030000oooooooo0:Koool005goool010000?ooooooo`0000Koool0101Vooooooooo`0000Ooool0
0`000?ooooooo`02oooo0P000:Ooool005Ooool400000_ooo`040000oooooooo00001oooo`0406Ko
oooooooo00001?ooo`800005oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P00
00[oool200001?ooo`<00004oooo00<0003oooooool0Y_ooo`00Joooo`0306Kooooooooo00Woool2
0000Yoooo`00K?ooo`0306Kooooooooo00Soool00`000?ooooooo`2Voooo001/oooo00<0I_oooooo
ool02?ooo`030000oooooooo0:Koool006goool00`1Vooooooooo`07oooo00<0003oooooool0Y_oo
o`005oooo`@0000]oooo1@00027oool00`1Vooooooooo`06oooo0P0002coool50000:oooo`@0000^
oooo0P0001Ooool001Ooool00`000?ooooooo`0`oooo00<0003oooooool08_ooo`0306Kooooooooo
00Goool00`000?ooooooo`0]oooo00<0003oooooool0:oooo`030000oooooooo02koool010000?oo
ooooo`0001Koool001Soool00`000?ooooooo`0_oooo00<0003oooooool08oooo`0306Kooooooooo
00Coool00`000?ooooooo`0]oooo00<0003oooooool0;?ooo`030000oooooooo02ooool00`000?oo
ooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo100000Coool00`000?ooooooo`0T
oooo00<0I_ooooooool00oooo`030000oooooooo02goool00`000?ooooooo`0]oooo00<0003ooooo
ool0;oooo`030000oooooooo01Coool001Ooool010000?ooooooo`0002ooool00`000?ooooooo`0U
oooo00<0I_ooooooool00_ooo`80000^oooo00<0003oooooool0:oooo`040000oooooooo0000;Ooo
o`040000oooooooo00005_ooo`006?ooo`80000_oooo0P0002Ooool00`1Vooooooooo`02oooo00<0
003oooooool0;?ooo`80000^oooo0P0002ooool200005oooo`00Loooo`0506Kooooooooooooo0000
0:Soool007Coool00`1Vooooooooo`020000Yoooo`00M?ooo`0406Kooooooooo0000Z?ooo`00MOoo
o`0306Kooooo00000:Soool007Koool00`1Vo`000?ooo`2Woooo000@ooooo`00017oool001Koool8
00000S?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0006<ol000<0000co`0co`001c?o00030000oooooooo00Koool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`05oooo2P0001lco`000`0003?o03?o000]<ol000<0003oooooool0;Oooo`030000oooooooo
02goool00`000?ooooooo`0^oooo00<0003oooooool05Oooo`00:?ooo`H00019<ol000<0003ooooo
ool0GOooo`03o`2Ioooooooo04Koool002koool50000A3?o0080001Noooo00?o09Woooooool0A_oo
o`00<oooo`@00010<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool003Ooool20000?S?o
00030000oooooooo05goool00ol0VOooooooo`16oooo000ioooo0`0003/co`000`000?ooooooo`1M
oooo00?o09Woooooool0A_ooo`00??ooo`80000i<ol00P0005koool00ol0VOooooooo`16oooo000n
oooo0P0003Lco`000`000?ooooooo`1Moooo00?o09Woooooool0A_ooo`00@?ooo`80000e<ol000<0
003oooooool0GOooo`03o`2Ioooooooo04Koool004;oool20000<c?o00030000oooooooo05goool0
0ol0VOooooooo`16oooo0014oooo0P00034co`020000G_ooo`03o`2Ioooooooo04Koool004Koool0
0`0003?o03?o000^<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool004Ooool00`0003?o
03?o000]<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool004Soool00`0003?o03?o000/
<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool004Woool00`0003?o03?o000[<ol00P00
05koool00ol0VOooooooo`16oooo001:oooo00<0000co`0co`00:S?o00030000oooooooo05goool0
0ol0VOooooooo`16oooo001;oooo00<0000co`0co`0043?o00800004<ol00P0000<co`0400000c?o
00800005<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool004coool00`0003?o03?o000>
<ol000@0000co`0co`000008<ol000<0000co`0co`000c?o00040000<ol0<ol0000013?o00030000
oooooooo05goool00ol0VOooooooo`16oooo001=oooo00<0000co`0co`003C?o00040000<ol0<ol0
00002C?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol00P0005koool00ol0VOooooooo`16
oooo001>oooo00<0000co`0co`0033?o00040000<ol0<ol000002S?o00030000<ol0<ol0008co`02
00001C?o00030000oooooooo05goool00ol0VOooooooo`16oooo001?oooo00<0000co`0co`002c?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?oo
ooooo`1Moooo00?o09Woooooool0A_ooo`00Coooo`030000<ol0<ol000`co`0200002S?o00800004
<ol00`0000@co`000`000?ooooooo`1Moooo00?o09Woooooool0A_ooo`00D?ooo`030000<ol0<ol0
02@co`020000G_ooo`03o`2Ioooooooo04Koool0057oool00`0003?o03?o000S<ol000<0003ooooo
ool0GOooo`03o`2Ioooooooo04Koool005;oool00`0003?o03?o000R<ol000<0003oooooool0GOoo
o`03o`2Ioooooooo04Koool005;oool00`0003?o03?o000R<ol000<0003oooooool0GOooo`03o`2I
oooooooo04Koool005?oool00`0003?o03?o000Q<ol00P0005koool00ol0VOooooooo`16oooo001C
oooo00<0000co`0co`008C?o00030000oooooooo05goool00ol0VOooooooo`16oooo001Doooo00<0
000co`0co`0083?o00030000oooooooo05goool00ol0VOooooooo`16oooo001Doooo00<0000co`0c
o`0083?o00030000oooooooo05goool00ol0VOooooooo`16oooo001Eoooo00<0000co`0co`007c?o
0080001Noooo00?o09Woooooool0A_ooo`00EOooo`030000<ol0<ol001lco`000`000?ooooooo`1M
oooo00?o09Woooooool0A_ooo`00E_ooo`030000<ol0<ol001hco`000`000?ooooooo`1Moooo00?o
09Woooooool0A_ooo`00E_ooo`030000<ol0<ol001hco`000`000?ooooooo`1Moooo00?o09Wooooo
ool0A_ooo`00Eoooo`030000<ol0<ol001dco`020000G_ooo`03o`2Ioooooooo04Koool005Ooool0
0`0003?o03?o000M<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool005Soool00`0003?o
03?o0009<ol00P0000@co`02000013?o00800005<ol000<0003oooooool0GOooo`03o`2Ioooooooo
04Koool005Soool00`0003?o03?o0008<ol000@0000co`0co`000008<ol000@0000co`0co`000004
<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool005Woool00`0003?o03?o0007<ol000@0
000co`0co`00000;<ol000<0000co`0co`000S?o0080001Noooo00?o09Woooooool0A_ooo`00FOoo
o`030000<ol0<ol000Lco`00100003?o03?o000000Tco`0200001C?o00030000oooooooo05goool0
0ol0VOooooooo`16oooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o00030000
<ol0<ol000@co`000`000?ooooooo`1Moooo00?o09Woooooool0A_ooo`00F_ooo`030000<ol0<ol0
00Lco`0200002S?o00<00004<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool005[oool0
0`0003?o03?o000J<ol00P0005koool00ol0VOooooooo`16oooo001Joooo00<0000co`0co`006S?o
00030000oooooooo05goool00ol0VOooooooo`16oooo001Koooo00<0000co`0co`006C?o00030000
oooooooo05goool00ol0VOooooooo`16oooo001Koooo00<0000co`0co`006C?o0080001Noooo00?o
09Woooooool0A_ooo`00Foooo`030000<ol0<ol001Tco`000`000?ooooooo`1Moooo00?o09Wooooo
ool0A_ooo`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1Moooo00?o09Woooooool0A_oo
o`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1Moooo00?o09Woooooool0A_ooo`00G?oo
o`030000<ol0<ol001Pco`020000G_ooo`03o`2Ioooooooo04Koool005goool00`0003?o03?o000G
<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool005goool00`0003?o03?o000G<ol000<0
003oooooool0GOooo`03o`2Ioooooooo04Koool005goool00`0003?o03?o000G<ol000<0003ooooo
ool0GOooo`03o`2Ioooooooo04Koool005koool00`0003?o03?o000F<ol00P0005koool00ol0VOoo
ooooo`16oooo001Noooo00<0000co`0co`005S?o00030000oooooooo05goool00ol0VOooooooo`16
oooo001Noooo0P0000@co`0200001C?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo
05goool00ol0VOooooooo`16oooo001Moooo00@0003oool00000000:<ol000D0000co`0co`0co`00
00000S?o00030000<ol0<ol0008co`000`000?ooooooo`1Moooo00?o09Woooooool0A_ooo`00GOoo
o`040000oooo000000002S?o00030000<ol0<ol000@co`000`0003?o03?o0002<ol00P0005koool0
0ol0VOooooooo`16oooo001Moooo00@0003oool00000000;<ol000@0000co`0co`0co`0200001C?o
00030000oooooooo05goool00ol0VOooooooo`16oooo001Moooo00@0003oooooool00008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo05goool00ol0VOooooooo`16
oooo001Noooo0`0000Pco`0400000c?o00<00004<ol000<0003oooooool0GOooo`03o`2Ioooooooo
04Koool0063oool00`0003?o03?o000D<ol00P0005koool00ol0VOooooooo`16oooo001Poooo00<0
000co`0co`0053?o00030000oooooooo05goool00ol0VOooooooo`16oooo001Qoooo00<0000co`0c
o`004c?o00030000oooooooo05goool00ol0VOooooooo`16oooo001Qoooo00<0000co`0co`004c?o
00030000oooooooo05goool00ol0VOooooooo`16oooo001Qoooo00<0000co`0co`004c?o0080001N
oooo00?o09Woooooool0A_ooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`1Moooo00?o
09Woooooool0A_ooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`1Moooo00?o09Wooooo
ool0A_ooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`1Moooo00?o09Woooooool0A_oo
o`00H_ooo`030000<ol0<ol0018co`020000G_ooo`03o`2Ioooooooo04Koool006;oool00`0003?o
03?o000B<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool006?oool00`0003?o03?o000A
<ol000<0003oooooool0GOooo`03o`2Ioooooooo04Koool006?oool00`0003?o03?o000A<ol000<0
003oooooool0GOooo`03o`2Ioooooooo04Koool006?oool00`0003?o03?o000A<ol00P0005koool0
0ol0VOooooooo`16oooo001Soooo00<0000co`0co`004C?o00030000oooooooo05goool00ol0VOoo
ooooo`16oooo001Soooo00<0000co`0co`002C?o00D00003<ol000<0003oooooool0GOooo`03o`2I
oooooooo04Koool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o00030000oooooooo
05goool00ol0VOooooooo`16oooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol000<co`02
0000G_ooo`03o`2Ioooooooo04Koool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool=
<ol000<0000co`0co`000c?o0:Woool006Coool<<ol00P0000Dco`2Yoooo001Uoooo4S?o0:Woool0
06GooolB<ol0ZOooo`00IOoooa8co`08oooo00<0003oooooool07?ooo`030000oooooooo07ooool0
06GooolB<ol01oooo`030000oooooooo00Soool00`000?ooooooo`0Coooo00<0003oooooool0O_oo
o`00IOoooa8co`07oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
oooo0P0000Coool00`000?ooooooo`1noooo001Uoooo4S?o00Ooool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool0O_ooo`00IOoooa8co`06oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`09oooo00<0003oooooool0OOooo`00I_oooa4co`07oooo00<0003oooooool01@0000koool0
0`000?ooooooo`08oooo00<0003oooooool0O_ooo`00I_oooa4co`07oooo00D0003oooooooooool0
00004Oooo`030000oooooooo00Soool00`000?ooooooo`1noooo001Voooo4C?o00Soool00`000?oo
ooooo`0Aoooo0P0000Woool00`000?ooooooo`1ooooo001Voooo4C?o0:Woool006KooolA<ol0ZOoo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.7878 .30902 L
.79321 .30902 L
.79892 .30902 L
.80134 .30902 L
.80267 .30902 L
.80393 .30902 L
.80464 .30902 L
s
.80464 .30902 m
.80472 .61803 L
s
0 .4 1 r
.02381 .10402 m
.06244 .1084 L
.10458 .11476 L
.14415 .1227 L
.18221 .13264 L
.22272 .1464 L
.26171 .16356 L
.30316 .18711 L
.34309 .21647 L
.3815 .25312 L
.40095 .2761 L
.41127 .28996 L
.41696 .29829 L
.41976 .30259 L
.42113 .30473 L
.42237 .30669 L
.42363 .30873 L
.42482 .30902 L
.42608 .30902 L
.42744 .30902 L
.43298 .30902 L
.44268 .30902 L
.46172 .30902 L
.50272 .30902 L
.54221 .30902 L
.58018 .30902 L
.6206 .30902 L
.65951 .30902 L
.70087 .30902 L
.74072 .30902 L
.77905 .30902 L
.81983 .30902 L
.8591 .30902 L
.89685 .30902 L
.93705 .30902 L
.97574 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`005_oo
o`<0I_mNoooo00<0003oooooool0Y_ooo`006Oooo`D0I_mIoooo0P000:Ooool001koool806KoDOoo
o`030000oooooooo0:Koool002Koool806KoBOooo`030000oooooooo0:Koool002koool506KoA?oo
o`030000oooooooo0:Koool003?oool406Ko@?ooo`80002Woooo000goooo0`1Vocgoool00`000?oo
ooooo`2Voooo000joooo0`1Voc[oool00`000?ooooooo`2Voooo000moooo0`1VocOoool00`000?oo
ooooo`2Voooo0010oooo101Voc?oool20000Yoooo`00A?ooo`@0I_l_oooo00<0003oooooool0Y_oo
o`00B?ooo`80I_lJoooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`00B_oo
o`80I_lGoooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Y_oo
o`00C?ooo`80I_lEoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`80002Woooo001>
oooo0P1Vo`goool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00D?ooo`80I_lAoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
0:Koool005;oool206Ko4?ooo`80000:oooo0`0000Coool00`000?ooooooo`2Voooo001Doooo0P1V
ob7oool20000Yoooo`00E_ooo`80I_lOoooo00<0003oooooool0Y_ooo`00F?ooo`0306Kooooooooo
01coool00`000?ooooooo`2Voooo001Ioooo0P1Voacoool00`000?ooooooo`2Voooo001Koooo0P1V
oa[oool20000Yoooo`00GOooo`0306Kooooooooo01Ooool00`000?ooooooo`2Voooo001Noooo0P1V
oaOoool00`000?ooooooo`2Voooo001Poooo00<0I_ooooooool05?ooo`030000oooooooo0:Koool0
067oool00`1Vooooooooo`0Coooo0P000:Ooool006;oool206Ko4oooo`030000oooooooo0:Koool0
06Coool00`1Vooooooooo`0@oooo00<0003oooooool0Y_ooo`00IOooo`80I_l@oooo00<0003ooooo
ool0Y_ooo`00Ioooo`0306Kooooooooo00goool20000Yoooo`00J?ooo`0306Kooooooooo00coool0
0`000?ooooooo`2Voooo001Noooo0P0000Coool200000oooo`@00003oooo0P0000Goool00`000?oo
ooooo`2Voooo001Moooo00@0003oooooool00008oooo00<00000I_ooool00oooo`040000oooooooo
00001?ooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Woool00`00001Vooooo`05
oooo00<0003oooooool00_ooo`80002Woooo001Goooo100000;oool010000?ooooooo`0000[oool0
0`00001Vo`1Vo`02oooo0P0000Goool00`000?ooooooo`2Voooo001Moooo00@0003oooooool00008
oooo00P0003oooooool0003oool0I_ooool00006oooo00<0003oooooool0Y_ooo`00G_ooo`80000:
oooo0P0000?oool0101Vo`000000000000Coool00`000?ooooooo`2Voooo001`oooo00<0I_oooooo
ool01?ooo`80002Woooo001aoooo00<0I_ooooooool00oooo`030000oooooooo0:Koool007;oool0
0`1Vooooooooo`02oooo00<0003oooooool0Y_ooo`00Loooo`0506Kooooooooooooo00000:Soool0
01Ooool40000;Oooo`D0000Voooo00@0I_ooooooooooool20000;?ooo`D0000[oooo100002koool2
00005oooo`005oooo`030000oooooooo033oool00`000?ooooooo`0Woooo00@0I_ooooooool0000_
oooo00<0003oooooool0:oooo`030000oooooooo02koool010000?ooooooo`0001Koool001Soool0
0`000?ooooooo`0_oooo00<0003oooooool0:?ooo`0306Kooooo000002ooool00`000?ooooooo`0/
oooo00<0003oooooool0;oooo`030000oooooooo01Goool0017oool400001?ooo`030000oooooooo
02Koool400001?ooo`030000oooooooo02Woool00`1Vo`000?ooo`0^oooo00<0003oooooool0;Ooo
o`030000oooooooo02ooool00`000?ooooooo`0Doooo000Goooo00@0003oooooool0000_oooo00<0
003oooooool0:Oooo`0306Ko0000000002koool00`000?ooooooo`0[oooo00@0003oooooool0000]
oooo00@0003oooooool0000Foooo000Hoooo0P0002ooool20000;?ooo`030000oooooooo02coool2
0000;_ooo`80000_oooo0P0001Ooool007Ooool00`000?ooooooo`2Voooo001goooo0P000:Ooool0
07Ooool00`000?ooo`1Vo`2Voooo001goooo00@0003oooooool0I_nUoooo001goooo00D0003ooooo
ooooool0I_l0Y?ooo`004?ooool0000Aoooo000Foooo2000008co`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol0
00Lco`000`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool00_oo
o`03o`2Ioooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo00Goool:
00007c?o00030000<ol0<ol002dco`000`000?ooooooo`0]oooo00<0003oooooool0;Oooo`030000
oooooooo00;oool00ol0VOooooooo`0Yoooo00<0003oooooool05Oooo`00:?ooo`H00019<ol000<0
003oooooool0H_ooo`03o`2Ioooooooo047oool002koool50000A3?o0080001Soooo00?o09Wooooo
ool0@Oooo`00<oooo`@00010<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool003Ooool2
0000?S?o00030000oooooooo06;oool00ol0VOooooooo`11oooo000ioooo0`0003/co`000`000?oo
ooooo`1Roooo00?o09Woooooool0@Oooo`00??ooo`80000i<ol00P0006?oool00ol0VOooooooo`11
oooo000noooo0P0003Lco`000`000?ooooooo`1Roooo00?o09Woooooool0@Oooo`00@?ooo`80000e
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool004;oool20000<c?o00030000oooooooo
06;oool00ol0VOooooooo`11oooo0014oooo0P00034co`020000Hoooo`03o`2Ioooooooo047oool0
04Koool00`0003?o03?o000^<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool004Ooool0
0`0003?o03?o000]<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool004Soool00`0003?o
03?o000/<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool004Woool00`0003?o03?o000[
<ol00P0006?oool00ol0VOooooooo`11oooo001:oooo00<0000co`0co`00:S?o00030000oooooooo
06;oool00ol0VOooooooo`11oooo001;oooo00<0000co`0co`0043?o00800004<ol00P0000<co`04
00000c?o00800005<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool004coool00`0003?o
03?o000><ol000@0000co`0co`000008<ol000<0000co`0co`000c?o00040000<ol0<ol0000013?o
00030000oooooooo06;oool00ol0VOooooooo`11oooo001=oooo00<0000co`0co`003C?o00040000
<ol0<ol000002C?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol00P0006?oool00ol0VOoo
ooooo`11oooo001>oooo00<0000co`0co`0033?o00040000<ol0<ol000002S?o00030000<ol0<ol0
008co`0200001C?o00030000oooooooo06;oool00ol0VOooooooo`11oooo001?oooo00<0000co`0c
o`002c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`00
0`000?ooooooo`1Roooo00?o09Woooooool0@Oooo`00Coooo`030000<ol0<ol000`co`0200002S?o
00800004<ol00`0000@co`000`000?ooooooo`1Roooo00?o09Woooooool0@Oooo`00D?ooo`030000
<ol0<ol002@co`020000Hoooo`03o`2Ioooooooo047oool0057oool00`0003?o03?o000S<ol000<0
003oooooool0H_ooo`03o`2Ioooooooo047oool005;oool00`0003?o03?o000R<ol000<0003ooooo
ool0H_ooo`03o`2Ioooooooo047oool005;oool00`0003?o03?o000R<ol000<0003oooooool0H_oo
o`03o`2Ioooooooo047oool005?oool00`0003?o03?o000Q<ol00P0006?oool00ol0VOooooooo`11
oooo001Coooo00<0000co`0co`008C?o00030000oooooooo06;oool00ol0VOooooooo`11oooo001D
oooo00<0000co`0co`0083?o00030000oooooooo06;oool00ol0VOooooooo`11oooo001Doooo00<0
000co`0co`0083?o00030000oooooooo06;oool00ol0VOooooooo`11oooo001Eoooo00<0000co`0c
o`007c?o0080001Soooo00?o09Woooooool0@Oooo`00EOooo`030000<ol0<ol001lco`000`000?oo
ooooo`1Roooo00?o09Woooooool0@Oooo`00E_ooo`030000<ol0<ol001hco`000`000?ooooooo`1R
oooo00?o09Woooooool0@Oooo`00E_ooo`030000<ol0<ol001hco`000`000?ooooooo`1Roooo00?o
09Woooooool0@Oooo`00Eoooo`030000<ol0<ol001dco`020000Hoooo`03o`2Ioooooooo047oool0
05Ooool00`0003?o03?o000M<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool005Soool0
0`0003?o03?o0009<ol00P0000@co`02000013?o00800005<ol000<0003oooooool0H_ooo`03o`2I
oooooooo047oool005Soool00`0003?o03?o0008<ol000@0000co`0co`000008<ol000@0000co`0c
o`000004<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool005Woool00`0003?o03?o0007
<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o0080001Soooo00?o09Woooooool0@Ooo
o`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`0200001C?o00030000oooooooo
06;oool00ol0VOooooooo`11oooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o
00030000<ol0<ol000@co`000`000?ooooooo`1Roooo00?o09Woooooool0@Oooo`00F_ooo`030000
<ol0<ol000Lco`0200002S?o00<00004<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool0
05[oool00`0003?o03?o000J<ol00P0006?oool00ol0VOooooooo`11oooo001Joooo00<0000co`0c
o`006S?o00030000oooooooo06;oool00ol0VOooooooo`11oooo001Koooo00<0000co`0co`006C?o
00030000oooooooo06;oool00ol0VOooooooo`11oooo001Koooo00<0000co`0co`006C?o0080001S
oooo00?o09Woooooool0@Oooo`00Foooo`030000<ol0<ol001Tco`000`000?ooooooo`1Roooo00?o
09Woooooool0@Oooo`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1Roooo00?o09Wooooo
ool0@Oooo`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1Roooo00?o09Woooooool0@Ooo
o`00G?ooo`030000<ol0<ol001Pco`020000Hoooo`03o`2Ioooooooo047oool005goool00`0003?o
03?o000G<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool005goool00`0003?o03?o000G
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool005goool00`0003?o03?o000G<ol000<0
003oooooool0H_ooo`03o`2Ioooooooo047oool005koool00`0003?o03?o000F<ol00P0006?oool0
0ol0VOooooooo`11oooo001Noooo00<0000co`0co`005S?o00030000oooooooo06;oool00ol0VOoo
ooooo`11oooo001Noooo0P0000@co`0200001C?o00030000<ol0<ol0008co`0200001C?o00030000
oooooooo06;oool00ol0VOooooooo`11oooo001Moooo00@0003oool00000000:<ol000D0000co`0c
o`0co`0000000S?o00030000<ol0<ol0008co`000`000?ooooooo`1Roooo00?o09Woooooool0@Ooo
o`00GOooo`040000oooo000000002S?o00030000<ol0<ol000@co`000`0003?o03?o0002<ol00P00
06?oool00ol0VOooooooo`11oooo001Moooo00@0003oool00000000;<ol000@0000co`0co`0co`02
00001C?o00030000oooooooo06;oool00ol0VOooooooo`11oooo001Moooo00@0003oooooool00008
<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo06;oool00ol0VOoo
ooooo`11oooo001Noooo0`0000Pco`0400000c?o00<00004<ol000<0003oooooool0H_ooo`03o`2I
oooooooo047oool0063oool00`0003?o03?o000D<ol00P0006?oool00ol0VOooooooo`11oooo001P
oooo00<0000co`0co`0053?o00030000oooooooo06;oool00ol0VOooooooo`11oooo001Qoooo00<0
000co`0co`004c?o00030000oooooooo06;oool00ol0VOooooooo`11oooo001Qoooo00<0000co`0c
o`004c?o00030000oooooooo06;oool00ol0VOooooooo`11oooo001Qoooo00<0000co`0co`004c?o
0080001Soooo00?o09Woooooool0@Oooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`1R
oooo00?o09Woooooool0@Oooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`1Roooo00?o
09Woooooool0@Oooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`1Roooo00?o09Wooooo
ool0@Oooo`00H_ooo`030000<ol0<ol0018co`020000Hoooo`03o`2Ioooooooo047oool006;oool0
0`0003?o03?o000B<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool006?oool00`0003?o
03?o000A<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool006?oool00`0003?o03?o000A
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo047oool006?oool00`0003?o03?o000A<ol00P00
06?oool00ol0VOooooooo`11oooo001Soooo00<0000co`0co`004C?o00030000oooooooo06;oool0
0ol0VOooooooo`11oooo001Soooo00<0000co`0co`002C?o00D00003<ol000<0003oooooool0H_oo
o`03o`2Ioooooooo047oool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o00030000
oooooooo06;oool00ol0VOooooooo`11oooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol0
00<co`020000Hoooo`03o`2Ioooooooo047oool006Coool=<ol000<0000co`0co`000c?o0:Woool0
06Coool=<ol000<0000co`0co`000c?o0:Woool006Coool<<ol00P0000Dco`2Yoooo001Uoooo4S?o
0:Woool006GooolB<ol0ZOooo`00IOoooa8co`05oooo00<0003oooooool08_ooo`030000oooooooo
07coool006GooolB<ol01?ooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003ooooo
ool0Noooo`00IOoooa8co`04oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`D00002oooo0P0000?oool500000_ooo`030000oooooooo07_oool006GooolB<ol01?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo
00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00IOoooa8co`03oooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000
oooooooo07[oool006KooolA<ol01?ooo`030000oooooooo00D0000>oooo00<0003oooooool02Ooo
o`030000oooooooo00;oool00`000?ooooooo`1koooo001Voooo4C?o00Coool01@000?oooooooooo
o`00000Aoooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001V
oooo4C?o00Goool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo07coool0
06KooolA<ol0ZOooo`00I_oooa4co`2Yoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.80799 .30902 L
.81373 .30902 L
.81654 .30902 L
.81909 .30902 L
.82028 .30902 L
.82156 .30902 L
.82277 .30902 L
s
.82277 .30902 m
.82289 .61803 L
s
0 .4 1 r
.02381 .10293 m
.06244 .10695 L
.10458 .11277 L
.14415 .12002 L
.18221 .12908 L
.22272 .14157 L
.26171 .15704 L
.30316 .17809 L
.34309 .20393 L
.3815 .23542 L
.42237 .27916 L
.43215 .2926 L
.43755 .30065 L
.44021 .30479 L
.44151 .30684 L
.44268 .30873 L
.44387 .30902 L
.44498 .30902 L
.44744 .30902 L
.45262 .30902 L
.46172 .30902 L
.49955 .30902 L
.5381 .30902 L
.57911 .30902 L
.61859 .30902 L
.65656 .30902 L
.69699 .30902 L
.7359 .30902 L
.77726 .30902 L
.8171 .30902 L
.85543 .30902 L
.89622 .30902 L
.93548 .30902 L
.97323 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`005_oo
o`D0I_mLoooo00<0003oooooool0Y_ooo`006oooo`P0I_mDoooo0P000:Ooool002?oool606KoC_oo
o`030000oooooooo0:Koool002Woool706KoAoooo`030000oooooooo0:Koool0033oool706Ko@?oo
o`030000oooooooo0:Koool003Ooool306Ko?Oooo`80002Woooo000joooo0`1Voc[oool00`000?oo
ooooo`2Voooo000moooo0`1VocOoool00`000?ooooooo`2Voooo0010oooo101Voc?oool00`000?oo
ooooo`2Voooo0014oooo101Vobooool20000Yoooo`00B?ooo`<0I_l/oooo00<0003oooooool0Y_oo
o`00Boooo`80I_lGoooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`00COoo
o`<0I_lCoooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Y_oo
o`00D?ooo`80I_lAoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`80002Woooo001B
oooo0P1Vo`Woool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00E?ooo`80I_l=oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
0:Koool005Koool206Ko3?ooo`80000:oooo0`0000Coool00`000?ooooooo`2Voooo001Hoooo0P1V
oagoool20000Yoooo`00F_ooo`80I_lKoooo00<0003oooooool0Y_ooo`00G?ooo`80I_lIoooo00<0
003oooooool0Y_ooo`00G_ooo`80I_lGoooo00<0003oooooool0Y_ooo`00H?ooo`0306Kooooooooo
01Coool20000Yoooo`00HOooo`0306Kooooooooo01?oool00`000?ooooooo`2Voooo001Roooo0P1V
oa?oool00`000?ooooooo`2Voooo001Toooo00<0I_ooooooool04?ooo`030000oooooooo0:Koool0
06Goool206Ko4?ooo`80002Woooo001Woooo00<0I_ooooooool03Oooo`030000oooooooo0:Koool0
06Soool00`1Vooooooooo`0<oooo00<0003oooooool0Y_ooo`00JOooo`80I_l<oooo00<0003ooooo
ool0Y_ooo`00Joooo`0306Kooooooooo00Woool20000Yoooo`00K?ooo`0306Kooooooooo00Soool0
0`000?ooooooo`2Voooo001Noooo0P0000Coool200000oooo`@000000`1Vooooooooo`0200001Ooo
o`030000oooooooo0:Koool005goool010000?ooooooo`0000Soool00`000?ooooooo`02oooo00D0
I_l0003oooooool000001?ooo`030000oooooooo0:Koool005goool010000?ooooooo`0000Woool0
0`000?ooooooo`03oooo00<0I_ooool000001?ooo`80002Woooo001Goooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool00`000?ooooooo`2Voooo001Moooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oool0I_l01?ooo`030000oooooooo
0:Koool005koool200002_ooo`800004oooo0`00000506Kooooooooooooo00000:Soool007Coool0
0`1Vooooooooo`020000Yoooo`00MOooo`0306Kooooo00000:Soool007Koool00`1Vo`000?ooo`2W
oooo001foooo00<0I_l0003oool0Yoooo`005oooo`@0000]oooo1@0002[oool20000;?ooo`D0000[
oooo100002koool200005oooo`005oooo`030000oooooooo033oool00`000?ooooooo`0Zoooo00<0
0000I_ooool0;Oooo`030000oooooooo02_oool00`000?ooooooo`0^oooo00@0003oooooool0000F
oooo000Hoooo00<0003oooooool0;oooo`030000oooooooo02[oool00`000?ooo`1Vo`0]oooo00<0
003oooooool0;?ooo`030000oooooooo02ooool00`000?ooooooo`0Eoooo000Aoooo100000Coool0
0`000?ooooooo`0Voooo100000Coool00`000?ooooooo`0Zoooo00@0003oooooool0I_l/oooo00<0
003oooooool0;Oooo`030000oooooooo02ooool00`000?ooooooo`0Doooo000Goooo00@0003ooooo
ool0000_oooo00<0003oooooool0:_ooo`800002oooo00<0I_ooooooool0:Oooo`030000oooooooo
02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool20000;oooo`80000/
oooo00<0003oooooool00_ooo`0306Kooooooooo02Ooool20000;_ooo`80000_oooo0P0001Ooool0
07Ooool00`000?ooooooo`03oooo00<0I_ooooooool0X?ooo`00Moooo`800005oooo00<0I_oooooo
ool0Woooo`00Moooo`030000oooooooo00Coool00`1Vooooooooo`2Ooooo001goooo00<0003ooooo
ool01Oooo`0306Kooooooooo09koool007Ooool00`000?ooooooo`06oooo00<0I_ooooooool0WOoo
o`004?ooool0000Aoooo000Foooo2000008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool01Oooo`X0000O<ol000<0000co`0co`00;C?o00030000
oooooooo02goool00`000?ooooooo`0]oooo00<0003oooooool01oooo`03o`2Ioooooooo02Coool0
0`000?ooooooo`0Eoooo000Xoooo1P0004Tco`000`000?ooooooo`1Woooo00?o09Woooooool0??oo
o`00;_ooo`D00014<ol00P0006Soool00ol0VOooooooo`0loooo000coooo1000040co`000`000?oo
ooooo`1Woooo00?o09Woooooool0??ooo`00=oooo`80000n<ol000<0003oooooool0Ioooo`03o`2I
oooooooo03coool003Woool30000>c?o00030000oooooooo06Ooool00ol0VOooooooo`0loooo000l
oooo0P0003Tco`020000J?ooo`03o`2Ioooooooo03coool003koool20000=c?o00030000oooooooo
06Ooool00ol0VOooooooo`0loooo0010oooo0P0003Dco`000`000?ooooooo`1Woooo00?o09Wooooo
ool0??ooo`00@_ooo`80000c<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03coool004Coool2
0000<C?o0080001Xoooo00?o09Woooooool0??ooo`00A_ooo`030000<ol0<ol002hco`000`000?oo
ooooo`1Woooo00?o09Woooooool0??ooo`00Aoooo`030000<ol0<ol002dco`000`000?ooooooo`1W
oooo00?o09Woooooool0??ooo`00B?ooo`030000<ol0<ol002`co`000`000?ooooooo`1Woooo00?o
09Woooooool0??ooo`00BOooo`030000<ol0<ol002/co`020000J?ooo`03o`2Ioooooooo03coool0
04[oool00`0003?o03?o000Z<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03coool004_oool0
0`0003?o03?o000@<ol00P0000@co`0200000c?o00@00003<ol00P0000Dco`000`000?ooooooo`1W
oooo00?o09Woooooool0??ooo`00C?ooo`030000<ol0<ol000hco`00100003?o03?o000000Pco`00
0`0003?o03?o0003<ol000@0000co`0co`000004<ol000<0003oooooool0Ioooo`03o`2Ioooooooo
03coool004goool00`0003?o03?o000=<ol000@0000co`0co`000009<ol000<0000co`0co`001C?o
00030000<ol0<ol0008co`020000J?ooo`03o`2Ioooooooo03coool004koool00`0003?o03?o000<
<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Iooo
o`03o`2Ioooooooo03coool004ooool00`0003?o03?o000;<ol000@0000co`0co`000008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo06Ooool00ol0VOooooooo`0l
oooo001?oooo00<0000co`0co`0033?o0080000:<ol00P0000@co`03000013?o00030000oooooooo
06Ooool00ol0VOooooooo`0loooo001@oooo00<0000co`0co`0093?o0080001Xoooo00?o09Wooooo
ool0??ooo`00DOooo`030000<ol0<ol002<co`000`000?ooooooo`1Woooo00?o09Woooooool0??oo
o`00D_ooo`030000<ol0<ol0028co`000`000?ooooooo`1Woooo00?o09Woooooool0??ooo`00D_oo
o`030000<ol0<ol0028co`000`000?ooooooo`1Woooo00?o09Woooooool0??ooo`00Doooo`030000
<ol0<ol0024co`020000J?ooo`03o`2Ioooooooo03coool005?oool00`0003?o03?o000Q<ol000<0
003oooooool0Ioooo`03o`2Ioooooooo03coool005Coool00`0003?o03?o000P<ol000<0003ooooo
ool0Ioooo`03o`2Ioooooooo03coool005Coool00`0003?o03?o000P<ol000<0003oooooool0Iooo
o`03o`2Ioooooooo03coool005Goool00`0003?o03?o000O<ol00P0006Soool00ol0VOooooooo`0l
oooo001Eoooo00<0000co`0co`007c?o00030000oooooooo06Ooool00ol0VOooooooo`0loooo001F
oooo00<0000co`0co`007S?o00030000oooooooo06Ooool00ol0VOooooooo`0loooo001Foooo00<0
000co`0co`007S?o00030000oooooooo06Ooool00ol0VOooooooo`0loooo001Goooo00<0000co`0c
o`007C?o0080001Xoooo00?o09Woooooool0??ooo`00Eoooo`030000<ol0<ol001dco`000`000?oo
ooooo`1Woooo00?o09Woooooool0??ooo`00F?ooo`030000<ol0<ol000Tco`02000013?o00800004
<ol00P0000Dco`000`000?ooooooo`1Woooo00?o09Woooooool0??ooo`00F?ooo`030000<ol0<ol0
00Pco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`1Woooo00?o
09Woooooool0??ooo`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`000`0003?o
03?o0002<ol00P0006Soool00ol0VOooooooo`0loooo001Ioooo00<0000co`0co`001c?o00040000
<ol0<ol000002C?o00800005<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03coool005Woool0
0`0003?o03?o0007<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000oooooooo
06Ooool00ol0VOooooooo`0loooo001Joooo00<0000co`0co`001c?o0080000:<ol00`0000@co`00
0`000?ooooooo`1Woooo00?o09Woooooool0??ooo`00F_ooo`030000<ol0<ol001Xco`020000J?oo
o`03o`2Ioooooooo03coool005[oool00`0003?o03?o000J<ol000<0003oooooool0Ioooo`03o`2I
oooooooo03coool005_oool00`0003?o03?o000I<ol000<0003oooooool0Ioooo`03o`2Ioooooooo
03coool005_oool00`0003?o03?o000I<ol00P0006Soool00ol0VOooooooo`0loooo001Koooo00<0
000co`0co`006C?o00030000oooooooo06Ooool00ol0VOooooooo`0loooo001Loooo00<0000co`0c
o`0063?o00030000oooooooo06Ooool00ol0VOooooooo`0loooo001Loooo00<0000co`0co`0063?o
00030000oooooooo06Ooool00ol0VOooooooo`0loooo001Loooo00<0000co`0co`0063?o0080001X
oooo00?o09Woooooool0??ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1Woooo00?o
09Woooooool0??ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1Woooo00?o09Wooooo
ool0??ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1Woooo00?o09Woooooool0??oo
o`00G_ooo`030000<ol0<ol001Hco`020000J?ooo`03o`2Ioooooooo03coool005koool00`0003?o
03?o000F<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03coool005koool2000013?o00800005
<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03coool0
05goool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o
00030000oooooooo06Ooool00ol0VOooooooo`0loooo001Moooo00@0003oool00000000:<ol000<0
000co`0co`0013?o00030000<ol0<ol0008co`020000J?ooo`03o`2Ioooooooo03coool005goool0
10000?ooo`00000000/co`00100003?o03?o03?o00800005<ol000<0003oooooool0Ioooo`03o`2I
oooooooo03coool005goool010000?ooooooo`0000Pco`00100003?o03?o000000<co`000`0003?o
03?o0004<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03coool005koool3000023?o00@00003
<ol00`0000@co`000`000?ooooooo`1Woooo00?o09Woooooool0??ooo`00H?ooo`030000<ol0<ol0
01@co`020000J?ooo`03o`2Ioooooooo03coool0063oool00`0003?o03?o000D<ol000<0003ooooo
ool0Ioooo`03o`2Ioooooooo03coool0067oool00`0003?o03?o000C<ol000<0003oooooool0Iooo
o`03o`2Ioooooooo03coool0067oool00`0003?o03?o000C<ol000<0003oooooool0Ioooo`03o`2I
oooooooo03coool0067oool00`0003?o03?o000C<ol00P0006Soool00ol0VOooooooo`0loooo001Q
oooo00<0000co`0co`004c?o00030000oooooooo06Ooool00ol0VOooooooo`0loooo001Roooo00<0
000co`0co`004S?o00030000oooooooo06Ooool00ol0VOooooooo`0loooo001Roooo00<0000co`0c
o`004S?o00030000oooooooo06Ooool00ol0VOooooooo`0loooo001Roooo00<0000co`0co`004S?o
0080001Xoooo00?o09Woooooool0??ooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`1W
oooo00?o09Woooooool0??ooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`1Woooo00?o
09Woooooool0??ooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`1Woooo00?o09Wooooo
ool0??ooo`00Hoooo`030000<ol0<ol0014co`020000J?ooo`03o`2Ioooooooo03coool006?oool0
0`0003?o03?o000A<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03coool006?oool00`0003?o
03?o0009<ol01@0000<co`000`000?ooooooo`1Woooo00?o09Woooooool0??ooo`00I?ooo`030000
<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003oooooool0Ioooo`03o`2Ioooooooo03coool0
06Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o0080001Xoooo00?o09Woooooool0??oo
o`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOoo
o`00I?ooo``co`0200001C?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o
00Goool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00IOoooa8co`04oooo00<0003ooooo
ool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001Uoooo4S?o00Coool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200000oooo`@00003oooo00<0
003oooooool0Noooo`00IOoooa8co`04oooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Coool00`000?oo
ooooo`1koooo001Uoooo4S?o00?oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000
oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0N_ooo`00I_oooa4co`04oooo00<0
003oooooool01@0000koool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo
07_oool006KooolA<ol01?ooo`050000oooooooooooo0000017oool00`000?ooooooo`07oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00I_oooa4co`05oooo00<0003oooooool04Ooo
o`80000:oooo0P0000?oool00`000?ooooooo`1loooo001Voooo4C?o0:Woool006KooolA<ol0ZOoo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.81909 .30902 L
.82924 .30902 L
.83479 .30902 L
.83749 .30902 L
.83996 .30902 L
.84105 .30902 L
.84223 .30902 L
s
.84223 .30902 m
.84234 .61803 L
s
0 .4 1 r
.02381 .10209 m
.06244 .10583 L
.10458 .11124 L
.14415 .11797 L
.18221 .12635 L
.22272 .13786 L
.26171 .15204 L
.30316 .17117 L
.34309 .19432 L
.3815 .22159 L
.40095 .23715 L
.42237 .2569 L
.44268 .28083 L
.45178 .29345 L
.45659 .30063 L
.45923 .30474 L
.46053 .30679 L
.46172 .30871 L
.46238 .30902 L
.46307 .30902 L
.46454 .30902 L
.4671 .30902 L
.4721 .30902 L
.48196 .30902 L
.50049 .30902 L
.53846 .30902 L
.57888 .30902 L
.61779 .30902 L
.65915 .30902 L
.699 .30902 L
.73733 .30902 L
.77811 .30902 L
.81738 .30902 L
.85513 .30902 L
.89533 .30902 L
.93402 .30902 L
.97516 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`005_oo
o`D0I_mLoooo00<0003oooooool0Y_ooo`006oooo`/0I_mAoooo0P000:Ooool002Koool806KoBOoo
o`030000oooooooo0:Koool002koool506KoA?ooo`030000oooooooo0:Koool003?oool506Ko?ooo
o`030000oooooooo0:Koool003Soool406Ko>oooo`80002Woooo000loooo101VocOoool00`000?oo
ooooo`2Voooo0010oooo101Voc?oool00`000?ooooooo`2Voooo0014oooo101Vobooool00`000?oo
ooooo`2Voooo0018oooo0`1Vobcoool20000Yoooo`00Boooo`80I_lZoooo00<0003oooooool0Y_oo
o`00COooo`<0I_lDoooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`00D?oo
o`80I_lAoooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Y_oo
o`00D_ooo`<0I_l>oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`80002Woooo001E
oooo0P1Vo`Koool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00Eoooo`<0I_l9oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
0:Koool005[oool206Ko2?ooo`80000:oooo0`0000Coool00`000?ooooooo`2Voooo001Loooo0P1V
oaWoool20000Yoooo`00G_ooo`80I_lGoooo00<0003oooooool0Y_ooo`00H?ooo`80I_lEoooo00<0
003oooooool0Y_ooo`00H_ooo`0306Kooooooooo01;oool00`000?ooooooo`2Voooo001Soooo0P1V
oa;oool20000Yoooo`00IOooo`80I_l@oooo00<0003oooooool0Y_ooo`00Ioooo`0306Kooooooooo
00goool00`000?ooooooo`2Voooo001Xoooo0P1Vo`goool00`000?ooooooo`2Voooo001Zoooo00<0
I_ooooooool02_ooo`80002Woooo001[oooo00<0I_ooooooool02Oooo`030000oooooooo0:Koool0
06coool206Ko2Oooo`030000oooooooo0:Koool006koool00`1Vooooooooo`06oooo00<0003ooooo
ool0Y_ooo`00Koooo`80I_l6oooo0P000:Ooool0077oool00`1Vooooooooo`03oooo00<0003ooooo
ool0Y_ooo`00G_ooo`800004oooo0P0000?oool400000oooo`8000000`1Vooooooooo`02oooo00<0
003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?oo
ooooo`000080I_l2oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002Oooo`030000
oooooooo00Goool01@000?ooooooo`1Vooooo`020000Yoooo`00Eoooo`@00002oooo00@0003ooooo
ool0000:oooo00<0003oooooool00_ooo`800004oooo00<0I_l0003oool0Yoooo`00GOooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`2V
oooo001Noooo0P0000[oool200001?ooo`<00004oooo00<00000I_ooool0Y_ooo`00Moooo`800000
0`1Vooooooooo`2Toooo001goooo00@0003oooooool0I_nUoooo001goooo00D0003oooooooooool0
I_l0Y?ooo`00Moooo`030000oooooooo00;oool00`1Vooooooooo`2Qoooo000Goooo100002goool5
0000:_ooo`800004oooo00<0I_ooooooool09Oooo`D0000[oooo100002koool200005oooo`005ooo
o`030000oooooooo033oool00`000?ooooooo`0Zoooo00<0003oooooool00oooo`0306Kooooooooo
02Ooool00`000?ooooooo`0[oooo00<0003oooooool0;_ooo`040000oooooooo00005_ooo`006?oo
o`030000oooooooo02ooool00`000?ooooooo`0Zoooo00<0003oooooool01?ooo`0306Kooooooooo
02Koool00`000?ooooooo`0/oooo00<0003oooooool0;oooo`030000oooooooo01Goool0017oool4
00001?ooo`030000oooooooo02Koool400001?ooo`030000oooooooo02[oool00`000?ooooooo`05
oooo00<0I_ooooooool09Oooo`030000oooooooo02goool00`000?ooooooo`0_oooo00<0003ooooo
ool05?ooo`005oooo`040000oooooooo0000;oooo`030000oooooooo02[oool200001oooo`0306Ko
oooooooo02Coool00`000?ooooooo`0[oooo00@0003oooooool0000]oooo00@0003oooooool0000F
oooo000Hoooo0P0002ooool20000;?ooo`030000oooooooo00Ooool00`1Vooooooooo`0Roooo0P00
02koool20000;oooo`80000Goooo001goooo00<0003oooooool02?ooo`0306Kooooooooo09_oool0
07Ooool200002_ooo`0306Kooooooooo09[oool007Ooool00`000?ooooooo`09oooo00<0I_oooooo
ool0V_ooo`00Moooo`030000oooooooo00[oool00`1Vooooooooo`2Ioooo001goooo00<0003ooooo
ool02oooo`0306Kooooooooo09Soool0013ooooo00004Oooo`005_ooo`P00002<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`00
0`0003?o03?o0007<ol000<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000
oooooooo00Ooool00`000?ooooooo`02oooo00?o09Woooooool00_ooo`030000oooooooo00Koool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`05oooo2P0001lco`000`0003?o03?o000]<ol000<0003oooooool0;Oooo`030000oooooooo
02goool00`000?ooooooo`0<oooo00?o09Woooooool07oooo`030000oooooooo01Goool002Soool6
0000BC?o00030000oooooooo06coool00ol0VOooooooo`0goooo000^oooo1@0004@co`020000KOoo
o`03o`2Ioooooooo03Ooool003?oool40000@3?o00030000oooooooo06coool00ol0VOooooooo`0g
oooo000goooo0P0003hco`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00>Oooo`<0000k
<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03Ooool003coool20000>C?o0080001]oooo00?o
09Woooooool0=oooo`00?_ooo`80000g<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03Ooool0
043oool20000=C?o00030000oooooooo06coool00ol0VOooooooo`0goooo0012oooo0P0003<co`00
0`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00A?ooo`80000a<ol00P0006goool00ol0VOoo
ooooo`0goooo0016oooo00<0000co`0co`00;S?o00030000oooooooo06coool00ol0VOooooooo`0g
oooo0017oooo00<0000co`0co`00;C?o00030000oooooooo06coool00ol0VOooooooo`0goooo0018
oooo00<0000co`0co`00;3?o00030000oooooooo06coool00ol0VOooooooo`0goooo0019oooo00<0
000co`0co`00:c?o0080001]oooo00?o09Woooooool0=oooo`00B_ooo`030000<ol0<ol002Xco`00
0`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00Boooo`030000<ol0<ol0010co`02000013?o
00800003<ol0100000<co`0200001C?o00030000oooooooo06coool00ol0VOooooooo`0goooo001<
oooo00<0000co`0co`003S?o00040000<ol0<ol0000023?o00030000<ol0<ol000<co`00100003?o
03?o000000@co`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00COooo`030000<ol0<ol0
00dco`00100003?o03?o000000Tco`000`0003?o03?o0005<ol000<0000co`0co`000S?o0080001]
oooo00?o09Woooooool0=oooo`00C_ooo`030000<ol0<ol000`co`00100003?o03?o000000Xco`00
0`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00Cooo
o`030000<ol0<ol000/co`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o
03?o0004<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03Ooool004ooool00`0003?o03?o000<
<ol00P0000Xco`02000013?o00<00004<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03Ooool0
053oool00`0003?o03?o000T<ol00P0006goool00ol0VOooooooo`0goooo001Aoooo00<0000co`0c
o`008c?o00030000oooooooo06coool00ol0VOooooooo`0goooo001Boooo00<0000co`0co`008S?o
00030000oooooooo06coool00ol0VOooooooo`0goooo001Boooo00<0000co`0co`008S?o00030000
oooooooo06coool00ol0VOooooooo`0goooo001Coooo00<0000co`0co`008C?o0080001]oooo00?o
09Woooooool0=oooo`00Doooo`030000<ol0<ol0024co`000`000?ooooooo`1/oooo00?o09Wooooo
ool0=oooo`00E?ooo`030000<ol0<ol0020co`000`000?ooooooo`1/oooo00?o09Woooooool0=ooo
o`00E?ooo`030000<ol0<ol0020co`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00EOoo
o`030000<ol0<ol001lco`020000KOooo`03o`2Ioooooooo03Ooool005Goool00`0003?o03?o000O
<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03Ooool005Koool00`0003?o03?o000N<ol000<0
003oooooool0K?ooo`03o`2Ioooooooo03Ooool005Koool00`0003?o03?o000N<ol000<0003ooooo
ool0K?ooo`03o`2Ioooooooo03Ooool005Ooool00`0003?o03?o000M<ol00P0006goool00ol0VOoo
ooooo`0goooo001Goooo00<0000co`0co`007C?o00030000oooooooo06coool00ol0VOooooooo`0g
oooo001Hoooo00<0000co`0co`002C?o00800004<ol00P0000@co`0200001C?o00030000oooooooo
06coool00ol0VOooooooo`0goooo001Hoooo00<0000co`0co`0023?o00040000<ol0<ol0000023?o
00040000<ol0<ol0000013?o00030000oooooooo06coool00ol0VOooooooo`0goooo001Ioooo00<0
000co`0co`001c?o00040000<ol0<ol000002c?o00030000<ol0<ol0008co`020000KOooo`03o`2I
oooooooo03Ooool005Woool00`0003?o03?o0007<ol000@0000co`0co`000009<ol00P0000Dco`00
0`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00FOooo`030000<ol0<ol000Lco`00100003?o
03?o000000Tco`000`0003?o03?o0004<ol000<0003oooooool0K?ooo`03o`2Ioooooooo03Ooool0
05[oool00`0003?o03?o0007<ol00P0000Xco`03000013?o00030000oooooooo06coool00ol0VOoo
ooooo`0goooo001Joooo00<0000co`0co`006S?o0080001]oooo00?o09Woooooool0=oooo`00F_oo
o`030000<ol0<ol001Xco`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00Foooo`030000
<ol0<ol001Tco`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00Foooo`030000<ol0<ol0
01Tco`020000KOooo`03o`2Ioooooooo03Ooool005_oool00`0003?o03?o000I<ol000<0003ooooo
ool0K?ooo`03o`2Ioooooooo03Ooool005coool00`0003?o03?o000H<ol000<0003oooooool0K?oo
o`03o`2Ioooooooo03Ooool005coool00`0003?o03?o000H<ol000<0003oooooool0K?ooo`03o`2I
oooooooo03Ooool005coool00`0003?o03?o000H<ol00P0006goool00ol0VOooooooo`0goooo001M
oooo00<0000co`0co`005c?o00030000oooooooo06coool00ol0VOooooooo`0goooo001Moooo00<0
000co`0co`005c?o00030000oooooooo06coool00ol0VOooooooo`0goooo001Moooo00<0000co`0c
o`005c?o00030000oooooooo06coool00ol0VOooooooo`0goooo001Noooo00<0000co`0co`005S?o
0080001]oooo00?o09Woooooool0=oooo`00G_ooo`030000<ol0<ol001Hco`000`000?ooooooo`1/
oooo00?o09Woooooool0=oooo`00G_ooo`800004<ol00P0000Dco`000`0003?o03?o0002<ol00P00
00Dco`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00GOooo`040000oooo000000002S?o
00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0003oooooool0K?ooo`03o`2I
oooooooo03Ooool005goool010000?ooo`00000000Xco`000`0003?o03?o0004<ol000<0000co`0c
o`000S?o0080001]oooo00?o09Woooooool0=oooo`00GOooo`040000oooo000000002c?o00040000
<ol0<ol0<ol00P0000Dco`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00GOooo`040000
oooooooo000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?ooooooo`1/
oooo00?o09Woooooool0=oooo`00G_ooo`<00008<ol0100000<co`03000013?o00030000oooooooo
06coool00ol0VOooooooo`0goooo001Poooo00<0000co`0co`0053?o0080001]oooo00?o09Wooooo
ool0=oooo`00H?ooo`030000<ol0<ol001@co`000`000?ooooooo`1/oooo00?o09Woooooool0=ooo
o`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00HOoo
o`030000<ol0<ol001<co`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00HOooo`030000
<ol0<ol001<co`020000KOooo`03o`2Ioooooooo03Ooool0067oool00`0003?o03?o000C<ol000<0
003oooooool0K?ooo`03o`2Ioooooooo03Ooool006;oool00`0003?o03?o000B<ol000<0003ooooo
ool0K?ooo`03o`2Ioooooooo03Ooool006;oool00`0003?o03?o000B<ol000<0003oooooool0K?oo
o`03o`2Ioooooooo03Ooool006;oool00`0003?o03?o000B<ol00P0006goool00ol0VOooooooo`0g
oooo001Roooo00<0000co`0co`004S?o00030000oooooooo06coool00ol0VOooooooo`0goooo001S
oooo00<0000co`0co`004C?o00030000oooooooo06coool00ol0VOooooooo`0goooo001Soooo00<0
000co`0co`004C?o00030000oooooooo06coool00ol0VOooooooo`0goooo001Soooo00<0000co`0c
o`004C?o0080001]oooo00?o09Woooooool0=oooo`00Hoooo`030000<ol0<ol0014co`000`000?oo
ooooo`1/oooo00?o09Woooooool0=oooo`00Hoooo`030000<ol0<ol000Tco`0500000c?o00030000
oooooooo06coool00ol0VOooooooo`0goooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol0
00<co`000`000?ooooooo`1/oooo00?o09Woooooool0=oooo`00I?ooo`030000<ol0<ol000Xco`00
0`0003?o03?o0003<ol00P0006goool00ol0VOooooooo`0goooo001Toooo3C?o00030000<ol0<ol0
00<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo33?o00800005<ol0ZOoo
o`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol01Oooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001Uoooo4S?o00Coool00`000?ooooooo`08oooo00<0003oooooool06Ooo
o`030000oooooooo07_oool006GooolB<ol01?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Koool500000_ooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001Uoooo4S?o
00Coool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00IOoooa8co`03
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003ooooo
ool00oooo`030000oooooooo07[oool006KooolA<ol01?ooo`030000oooooooo00D0000>oooo00<0
003oooooool02_ooo`050000oooooooooooo000007goool006KooolA<ol01?ooo`050000oooooooo
oooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Nooo
o`00I_oooa4co`05oooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1l
oooo001Voooo4C?o0:Woool006KooolA<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.84911 .30902 L
.85396 .30902 L
.85663 .30902 L
.85916 .30902 L
.86034 .30902 L
.86159 .30902 L
s
.86159 .30902 m
.86165 .61803 L
s
0 .4 1 r
.02381 .10149 m
.06244 .10503 L
.10458 .11015 L
.14415 .1165 L
.18221 .12439 L
.22272 .13521 L
.26171 .14846 L
.30316 .16621 L
.34309 .1874 L
.3815 .21107 L
.40095 .22367 L
.42237 .23914 L
.44268 .25823 L
.46172 .28081 L
.4721 .2953 L
.47721 .30307 L
.4785 .30508 L
.4797 .30701 L
.48079 .30875 L
.48196 .30902 L
.48305 .30902 L
.4842 .30902 L
.48625 .30902 L
.49082 .30902 L
.50049 .30902 L
.53846 .30902 L
.57888 .30902 L
.61779 .30902 L
.65915 .30902 L
.699 .30902 L
.73733 .30902 L
.77811 .30902 L
.81738 .30902 L
.85513 .30902 L
.89533 .30902 L
.93402 .30902 L
.97516 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`005_oo
o`D0I_mLoooo00<0003oooooool0Y_ooo`006oooo`/0I_mAoooo0P000:Ooool002Koool806KoBOoo
o`030000oooooooo0:Koool002koool506KoA?ooo`030000oooooooo0:Koool003?oool506Ko?ooo
o`030000oooooooo0:Koool003Soool406Ko>oooo`80002Woooo000loooo1@1VocKoool00`000?oo
ooooo`2Voooo0011oooo1P1Voc3oool00`000?ooooooo`2Voooo0017oooo101Vobcoool00`000?oo
ooooo`2Voooo001;oooo0P1Vob[oool20000Yoooo`00COooo`<0I_lWoooo00<0003oooooool0Y_oo
o`00D?ooo`80I_lBoooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`00D_oo
o`<0I_l>oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Y_oo
o`00EOooo`80I_l<oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`80002Woooo001G
oooo0`1Vo`?oool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00F_ooo`80I_l7oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
0:Koool005coool206Ko1_ooo`80000:oooo0`0000Coool00`000?ooooooo`2Voooo001Noooo0P1V
oaOoool20000Yoooo`00H?ooo`80I_lEoooo00<0003oooooool0Y_ooo`00H_ooo`0306Kooooooooo
01;oool00`000?ooooooo`2Voooo001Soooo0P1Voa;oool00`000?ooooooo`2Voooo001Uoooo0P1V
oa3oool20000Yoooo`00Ioooo`0306Kooooooooo00goool00`000?ooooooo`2Voooo001Xoooo0P1V
o`goool00`000?ooooooo`2Voooo001Zoooo0P1Vo`_oool00`000?ooooooo`2Voooo001/oooo00<0
I_ooooooool02?ooo`80002Woooo001]oooo0P1Vo`Soool00`000?ooooooo`2Voooo001_oooo0P1V
o`Koool00`000?ooooooo`2Voooo001aoooo00<0I_ooooooool00oooo`030000oooooooo0:Koool0
07;oool206Ko0oooo`80002Woooo001doooo0P1Vo`03oooo0000oooo0:Ooool005koool200001?oo
o`800003oooo100000?oool200001?ooo`0306Ko0000oooo0:Ooool005goool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool0Y_ooo`00GOoo
o`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0P00000306Ko
oooooooo0:Coool005Ooool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool2
00001Oooo`040000oooooooo06KoYOooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool01@000?ooooooooooo`1Vo`2Toooo001Noooo0P0000[oool2
00001?ooo`<00004oooo00<0003oooooool00_ooo`0306Kooooooooo0:7oool007Ooool200001?oo
o`0306Kooooooooo0:3oool007Ooool00`000?ooooooo`04oooo00<0I_ooooooool0Woooo`00Mooo
o`030000oooooooo00Goool00`1Vooooooooo`2Noooo001goooo00<0003oooooool01_ooo`0306Ko
oooooooo09goool001Ooool40000;Oooo`D0000Zoooo0P0000Soool00`1Vooooooooo`0Qoooo1@00
02_oool40000;_ooo`80000Goooo000Goooo00<0003oooooool0<?ooo`030000oooooooo02[oool0
0`000?ooooooo`08oooo00<0I_ooooooool08_ooo`030000oooooooo02_oool00`000?ooooooo`0^
oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000oooooooo02[oool0
0`000?ooooooo`09oooo00<0I_ooooooool08Oooo`030000oooooooo02coool00`000?ooooooo`0_
oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool09_ooo`@00004oooo00<0
003oooooool0:_ooo`030000oooooooo00[oool00`1Vooooooooo`0Poooo00<0003oooooool0;Ooo
o`030000oooooooo02ooool00`000?ooooooo`0Doooo000Goooo00@0003oooooool0000_oooo00<0
003oooooool0:_ooo`80000<oooo00<0I_ooooooool07oooo`030000oooooooo02_oool010000?oo
ooooo`0002goool010000?ooooooo`0001Koool001Soool20000;oooo`80000/oooo00<0003ooooo
ool03?ooo`0306Kooooooooo01goool20000;_ooo`80000_oooo0P0001Ooool007Ooool00`000?oo
ooooo`0<oooo00<0I_ooooooool0Uoooo`00Moooo`80000>oooo00<0I_ooooooool0U_ooo`00Mooo
o`030000oooooooo00koool00`1Vooooooooo`2Eoooo001goooo00<0003oooooool03_ooo`0306Ko
oooooooo09Goool007Ooool00`000?ooooooo`0?oooo0P1VoiGoool0013ooooo00004Oooo`005_oo
o`P00002<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0003oooooool01_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool05Oooo`005_ooo`030000
oooooooo00Goool:00007c?o00030000<ol0<ol002dco`000`000?ooooooo`0]oooo00<0003ooooo
ool0;Oooo`030000oooooooo017oool00ol0VOooooooo`0Joooo00<0003oooooool05Oooo`00:?oo
o`H00019<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool002koool50000A3?o0080001b
oooo00?o09Woooooool0<_ooo`00<oooo`@00010<ol000<0003oooooool0LOooo`03o`2Ioooooooo
03;oool003Ooool20000?S?o00030000oooooooo077oool00ol0VOooooooo`0boooo000ioooo0`00
03/co`000`000?ooooooo`1aoooo00?o09Woooooool0<_ooo`00??ooo`80000i<ol00P0007;oool0
0ol0VOooooooo`0boooo000noooo0P0003Lco`000`000?ooooooo`1aoooo00?o09Woooooool0<_oo
o`00@?ooo`80000e<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool004;oool20000<c?o
00030000oooooooo077oool00ol0VOooooooo`0boooo0014oooo0P00034co`020000L_ooo`03o`2I
oooooooo03;oool004Koool00`0003?o03?o000^<ol000<0003oooooool0LOooo`03o`2Ioooooooo
03;oool004Ooool00`0003?o03?o000]<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool0
04Soool00`0003?o03?o000/<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool004Woool0
0`0003?o03?o000[<ol00P0007;oool00ol0VOooooooo`0boooo001:oooo00<0000co`0co`00:S?o
00030000oooooooo077oool00ol0VOooooooo`0boooo001;oooo00<0000co`0co`0043?o00800004
<ol00P0000<co`0400000c?o00800005<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool0
04coool00`0003?o03?o000><ol000@0000co`0co`000008<ol000<0000co`0co`000c?o00040000
<ol0<ol0000013?o00030000oooooooo077oool00ol0VOooooooo`0boooo001=oooo00<0000co`0c
o`003C?o00040000<ol0<ol000002C?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol00P00
07;oool00ol0VOooooooo`0boooo001>oooo00<0000co`0co`0033?o00040000<ol0<ol000002S?o
00030000<ol0<ol0008co`0200001C?o00030000oooooooo077oool00ol0VOooooooo`0boooo001?
oooo00<0000co`0co`002c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0<ol000@co`000`000?ooooooo`1aoooo00?o09Woooooool0<_ooo`00Coooo`030000<ol0<ol0
00`co`0200002S?o00800004<ol00`0000@co`000`000?ooooooo`1aoooo00?o09Woooooool0<_oo
o`00D?ooo`030000<ol0<ol002@co`020000L_ooo`03o`2Ioooooooo03;oool0057oool00`0003?o
03?o000S<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool005;oool00`0003?o03?o000R
<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool005;oool00`0003?o03?o000R<ol000<0
003oooooool0LOooo`03o`2Ioooooooo03;oool005?oool00`0003?o03?o000Q<ol00P0007;oool0
0ol0VOooooooo`0boooo001Coooo00<0000co`0co`008C?o00030000oooooooo077oool00ol0VOoo
ooooo`0boooo001Doooo00<0000co`0co`0083?o00030000oooooooo077oool00ol0VOooooooo`0b
oooo001Doooo00<0000co`0co`0083?o00030000oooooooo077oool00ol0VOooooooo`0boooo001E
oooo00<0000co`0co`007c?o0080001boooo00?o09Woooooool0<_ooo`00EOooo`030000<ol0<ol0
01lco`000`000?ooooooo`1aoooo00?o09Woooooool0<_ooo`00E_ooo`030000<ol0<ol001hco`00
0`000?ooooooo`1aoooo00?o09Woooooool0<_ooo`00E_ooo`030000<ol0<ol001hco`000`000?oo
ooooo`1aoooo00?o09Woooooool0<_ooo`00Eoooo`030000<ol0<ol001dco`020000L_ooo`03o`2I
oooooooo03;oool005Ooool00`0003?o03?o000M<ol000<0003oooooool0LOooo`03o`2Ioooooooo
03;oool005Soool00`0003?o03?o0009<ol00P0000@co`02000013?o00800005<ol000<0003ooooo
ool0LOooo`03o`2Ioooooooo03;oool005Soool00`0003?o03?o0008<ol000@0000co`0co`000008
<ol000@0000co`0co`000004<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool005Woool0
0`0003?o03?o0007<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o0080001boooo00?o
09Woooooool0<_ooo`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000Tco`0200001C?o
00030000oooooooo077oool00ol0VOooooooo`0boooo001Ioooo00<0000co`0co`001c?o00040000
<ol0<ol000002C?o00030000<ol0<ol000@co`000`000?ooooooo`1aoooo00?o09Woooooool0<_oo
o`00F_ooo`030000<ol0<ol000Lco`0200002S?o00<00004<ol000<0003oooooool0LOooo`03o`2I
oooooooo03;oool005[oool00`0003?o03?o000J<ol00P0007;oool00ol0VOooooooo`0boooo001J
oooo00<0000co`0co`006S?o00030000oooooooo077oool00ol0VOooooooo`0boooo001Koooo00<0
000co`0co`006C?o00030000oooooooo077oool00ol0VOooooooo`0boooo001Koooo00<0000co`0c
o`006C?o0080001boooo00?o09Woooooool0<_ooo`00Foooo`030000<ol0<ol001Tco`000`000?oo
ooooo`1aoooo00?o09Woooooool0<_ooo`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1a
oooo00?o09Woooooool0<_ooo`00G?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1aoooo00?o
09Woooooool0<_ooo`00G?ooo`030000<ol0<ol001Pco`020000L_ooo`03o`2Ioooooooo03;oool0
05goool00`0003?o03?o000G<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool005goool0
0`0003?o03?o000G<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool005goool00`0003?o
03?o000G<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool005koool00`0003?o03?o000F
<ol00P0007;oool00ol0VOooooooo`0boooo001Noooo00<0000co`0co`005S?o00030000oooooooo
077oool00ol0VOooooooo`0boooo001Noooo0P0000@co`0200001C?o00030000<ol0<ol0008co`02
00001C?o00030000oooooooo077oool00ol0VOooooooo`0boooo001Moooo00@0003oool00000000:
<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`000?ooooooo`1aoooo00?o
09Woooooool0<_ooo`00GOooo`040000oooo000000002S?o00030000<ol0<ol000@co`000`0003?o
03?o0002<ol00P0007;oool00ol0VOooooooo`0boooo001Moooo00@0003oool00000000;<ol000@0
000co`0co`0co`0200001C?o00030000oooooooo077oool00ol0VOooooooo`0boooo001Moooo00@0
003oooooool00008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo
077oool00ol0VOooooooo`0boooo001Noooo0`0000Pco`0400000c?o00<00004<ol000<0003ooooo
ool0LOooo`03o`2Ioooooooo03;oool0063oool00`0003?o03?o000D<ol00P0007;oool00ol0VOoo
ooooo`0boooo001Poooo00<0000co`0co`0053?o00030000oooooooo077oool00ol0VOooooooo`0b
oooo001Qoooo00<0000co`0co`004c?o00030000oooooooo077oool00ol0VOooooooo`0boooo001Q
oooo00<0000co`0co`004c?o00030000oooooooo077oool00ol0VOooooooo`0boooo001Qoooo00<0
000co`0co`004c?o0080001boooo00?o09Woooooool0<_ooo`00HOooo`030000<ol0<ol001<co`00
0`000?ooooooo`1aoooo00?o09Woooooool0<_ooo`00H_ooo`030000<ol0<ol0018co`000`000?oo
ooooo`1aoooo00?o09Woooooool0<_ooo`00H_ooo`030000<ol0<ol0018co`000`000?ooooooo`1a
oooo00?o09Woooooool0<_ooo`00H_ooo`030000<ol0<ol0018co`020000L_ooo`03o`2Ioooooooo
03;oool006;oool00`0003?o03?o000B<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool0
06?oool00`0003?o03?o000A<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool006?oool0
0`0003?o03?o000A<ol000<0003oooooool0LOooo`03o`2Ioooooooo03;oool006?oool00`0003?o
03?o000A<ol00P0007;oool00ol0VOooooooo`0boooo001Soooo00<0000co`0co`004C?o00030000
oooooooo077oool00ol0VOooooooo`0boooo001Soooo00<0000co`0co`002C?o00D00003<ol000<0
003oooooool0LOooo`03o`2Ioooooooo03;oool006Coool00`0003?o03?o000:<ol000<0000co`0c
o`000c?o00030000oooooooo077oool00ol0VOooooooo`0boooo001Toooo00<0000co`0co`002S?o
00030000<ol0<ol000<co`020000L_ooo`03o`2Ioooooooo03;oool006Coool=<ol000<0000co`0c
o`000c?o0:Woool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool<<ol00P0000Dco`2Y
oooo001Uoooo4S?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`05oooo00<0003oooooool08_oo
o`030000oooooooo07coool006GooolB<ol01?ooo`030000oooooooo00Soool00`000?ooooooo`0I
oooo00<0003oooooool0Noooo`00IOoooa8co`04oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002oooo0P0000Goool300000_ooo`030000oooooooo07_oool006GooolB
<ol01?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01ooo
o`030000oooooooo00[oool01@000?ooooooooooo`00001moooo001Uoooo4S?o00?oool00`000?oo
ooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Ooool500000oooo`030000oooooooo
07[oool006KooolA<ol01?ooo`030000oooooooo00D0000>oooo00<0003oooooool01oooo`040000
oooooooo00000oooo`030000oooooooo07_oool006KooolA<ol01?ooo`050000oooooooooooo0000
017oool00`000?ooooooo`08oooo00<0003oool000000oooo`030000oooooooo07_oool006KooolA
<ol01Oooo`030000oooooooo017oool200002oooo`800002oooo00<0003oooooool0O?ooo`00I_oo
oa4co`2Yoooo001Voooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.83996 .30902 L
.85916 .30902 L
.86886 .30902 L
.87359 .30902 L
.87791 .30902 L
.87903 .30902 L
.88025 .30902 L
s
.88025 .30902 m
.88036 .61803 L
s
0 .4 1 r
.02381 .10112 m
.06244 .10453 L
.10458 .10946 L
.14415 .11558 L
.18221 .12317 L
.22272 .13355 L
.26171 .14622 L
.30316 .16311 L
.34309 .18284 L
.3815 .20333 L
.40095 .21341 L
.42237 .22523 L
.44268 .24019 L
.46172 .25822 L
.48025 .28014 L
.49005 .29369 L
.49542 .30177 L
.49806 .3059 L
.49922 .30775 L
.50049 .30902 L
.50118 .30902 L
.50183 .30902 L
.50325 .30902 L
.50624 .30902 L
.51145 .30902 L
.52162 .30902 L
.54171 .30902 L
.58062 .30902 L
.62198 .30902 L
.66183 .30902 L
.70016 .30902 L
.74094 .30902 L
.78021 .30902 L
.81796 .30902 L
.85816 .30902 L
.89685 .30902 L
.93799 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`005_oo
o`D0I_mLoooo00<0003oooooool0Y_ooo`006oooo`/0I_mAoooo0P000:Ooool002Koool:06KoAooo
o`030000oooooooo0:Koool0033oool806Ko?oooo`030000oooooooo0:Koool003Soool406Ko>ooo
o`030000oooooooo0:Koool003coool406Ko=oooo`80002Woooo0010oooo101Voc?oool00`000?oo
ooooo`2Voooo0014oooo101Vobooool00`000?ooooooo`2Voooo0018oooo0`1Vobcoool00`000?oo
ooooo`2Voooo001;oooo0`1VobWoool20000Yoooo`00C_ooo`@0I_lUoooo00<0003oooooool0Y_oo
o`00D_ooo`<0I_l?oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`00EOoo
o`80I_l<oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Y_oo
o`00Eoooo`<0I_l9oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`80002Woooo001J
oooo0P1Vo`03oooo0000000000800002oooo00@0003oooooool00009oooo0P0000Goool00`000?oo
ooooo`2Voooo001Loooo0P1Vo`Goool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0Y_ooo`00G_ooo`80I_l4oooo0P0000[oool300001?ooo`030000oooooooo0:Koool0
063oool206Ko5Oooo`80002Woooo001Roooo0P1Voa?oool00`000?ooooooo`2Voooo001Toooo0P1V
oa7oool00`000?ooooooo`2Voooo001Voooo0P1Vo`ooool00`000?ooooooo`2Voooo001Xoooo0P1V
o`goool20000Yoooo`00J_ooo`80I_l;oooo00<0003oooooool0Y_ooo`00K?ooo`0306Kooooooooo
00Soool00`000?ooooooo`2Voooo001]oooo0P1Vo`Soool00`000?ooooooo`2Voooo001_oooo0P1V
o`Koool20000Yoooo`00LOooo`80I_l4oooo00<0003oooooool0Y_ooo`00Loooo`80I_l2oooo00<0
003oooooool0Y_ooo`00MOooo`80I_l00`000?ooooooo`2Voooo001goooo0P000:Ooool007Ooool0
10000?ooo`1Vo`1VojGoool005koool200001?ooo`800003oooo100000?oool200001Oooo`050000
oooooooooooo06Ko0:Coool005goool010000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0
003oooooool00004oooo00<0003oooooool00_ooo`0306Kooooooooo0:7oool005goool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool00_ooo`800004oooo0P1Voj7oool0
05Ooool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001Oooo`030000
oooooooo00Goool00`1Vooooooooo`2Noooo001Moooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo00Koool00`1Vooooooooo`2Moooo001N
oooo0P0000[oool200001?ooo`<00004oooo00<0003oooooool01oooo`0306Kooooooooo09coool0
07Ooool200002Oooo`0306Kooooooooo09_oool007Ooool00`000?ooooooo`09oooo00<0I_oooooo
ool0V_ooo`00Moooo`030000oooooooo00[oool00`1Vooooooooo`2Ioooo001goooo00<0003ooooo
ool02oooo`0306Kooooooooo09Soool001Ooool40000;Oooo`D0000Zoooo0P0000goool00`1Voooo
ooooo`0Loooo1@0002_oool40000;_ooo`80000Goooo000Goooo00<0003oooooool0<?ooo`030000
oooooooo02[oool00`000?ooooooo`0=oooo00<0I_ooooooool07Oooo`030000oooooooo02_oool0
0`000?ooooooo`0^oooo00@0003oooooool0000Foooo000Hoooo00<0003oooooool0;oooo`030000
oooooooo02[oool00`000?ooooooo`0>oooo00<0I_ooooooool07?ooo`030000oooooooo02coool0
0`000?ooooooo`0_oooo00<0003oooooool05Oooo`004Oooo`@00004oooo00<0003oooooool09_oo
o`@00004oooo00<0003oooooool0:_ooo`030000oooooooo00ooool00`1Vooooooooo`0Koooo00<0
003oooooool0;Oooo`030000oooooooo02ooool00`000?ooooooo`0Doooo000Goooo00@0003ooooo
ool0000_oooo00<0003oooooool0:_ooo`80000Aoooo00<0I_ooooooool06_ooo`030000oooooooo
02_oool010000?ooooooo`0002goool010000?ooooooo`0001Koool001Soool20000;oooo`80000/
oooo00<0003oooooool04?ooo`0306Kooooooooo01Woool20000;_ooo`80000_oooo0P0001Ooool0
07Ooool00`000?ooooooo`0Aoooo00<0I_ooooooool0T_ooo`00Moooo`80000Boooo00<0I_oooooo
ool0T_ooo`00Moooo`030000oooooooo01;oool00`1Vooooooooo`2Aoooo001goooo00<0003ooooo
ool04oooo`0306Kooooooooo093oool007Ooool00`000?ooooooo`0Doooo00<0I_ooooooool0Sooo
o`004?ooool0000Aoooo000Foooo2000008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`000?oo
ooooo`06oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`06oooo00<0003oooooool01oooo`030000oooooooo
00Ooool01@000?ooooooooooool0V@04oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool01Oooo`X0000O<ol000<0000co`0co`00;C?o
00030000oooooooo02goool00`000?ooooooo`0]oooo00<0003oooooool05Oooo`03o`2Ioooooooo
01Koool00`000?ooooooo`0Eoooo000Xoooo1P0004Tco`000`000?ooooooo`1eoooo00?o09Wooooo
ool0;_ooo`00;_ooo`D00014<ol00P0007Koool00ol0VOooooooo`0^oooo000coooo1000040co`00
0`000?ooooooo`1eoooo00?o09Woooooool0;_ooo`00=oooo`80000n<ol000<0003oooooool0MOoo
o`03o`2Ioooooooo02koool003Woool30000>c?o00030000oooooooo07Goool00ol0VOooooooo`0^
oooo000loooo0P0003Tco`020000M_ooo`03o`2Ioooooooo02koool003koool20000=c?o00030000
oooooooo07Goool00ol0VOooooooo`0^oooo0010oooo0P0003Dco`000`000?ooooooo`1eoooo00?o
09Woooooool0;_ooo`00@_ooo`80000c<ol000<0003oooooool0MOooo`03o`2Ioooooooo02koool0
04Coool20000<C?o0080001foooo00?o09Woooooool0;_ooo`00A_ooo`030000<ol0<ol002hco`00
0`000?ooooooo`1eoooo00?o09Woooooool0;_ooo`00Aoooo`030000<ol0<ol002dco`000`000?oo
ooooo`1eoooo00?o09Woooooool0;_ooo`00B?ooo`030000<ol0<ol002`co`000`000?ooooooo`1e
oooo00?o09Woooooool0;_ooo`00BOooo`030000<ol0<ol002/co`020000M_ooo`03o`2Ioooooooo
02koool004[oool00`0003?o03?o000Z<ol000<0003oooooool0MOooo`03o`2Ioooooooo02koool0
04_oool00`0003?o03?o000@<ol00P0000@co`0200000c?o00@00003<ol00P0000Dco`000`000?oo
ooooo`1eoooo00?o09Woooooool0;_ooo`00C?ooo`030000<ol0<ol000hco`00100003?o03?o0000
00Pco`000`0003?o03?o0003<ol000@0000co`0co`000004<ol000<0003oooooool0MOooo`03o`2I
oooooooo02koool004goool00`0003?o03?o000=<ol000@0000co`0co`000009<ol000<0000co`0c
o`001C?o00030000<ol0<ol0008co`020000M_ooo`03o`2Ioooooooo02koool004koool00`0003?o
03?o000<<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800005<ol000<0003ooooo
ool0MOooo`03o`2Ioooooooo02koool004ooool00`0003?o03?o000;<ol000@0000co`0co`000008
<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo07Goool00ol0VOoo
ooooo`0^oooo001?oooo00<0000co`0co`0033?o0080000:<ol00P0000@co`03000013?o00030000
oooooooo07Goool00ol0VOooooooo`0^oooo001@oooo00<0000co`0co`0093?o0080001foooo00?o
09Woooooool0;_ooo`00DOooo`030000<ol0<ol002<co`000`000?ooooooo`1eoooo00?o09Wooooo
ool0;_ooo`00D_ooo`030000<ol0<ol0028co`000`000?ooooooo`1eoooo00?o09Woooooool0;_oo
o`00D_ooo`030000<ol0<ol0028co`000`000?ooooooo`1eoooo00?o09Woooooool0;_ooo`00Dooo
o`030000<ol0<ol0024co`020000M_ooo`03o`2Ioooooooo02koool005?oool00`0003?o03?o000Q
<ol000<0003oooooool0MOooo`03o`2Ioooooooo02koool005Coool00`0003?o03?o000P<ol000<0
003oooooool0MOooo`03o`2Ioooooooo02koool005Coool00`0003?o03?o000P<ol000<0003ooooo
ool0MOooo`03o`2Ioooooooo02koool005Goool00`0003?o03?o000O<ol00P0007Koool00ol0VOoo
ooooo`0^oooo001Eoooo00<0000co`0co`007c?o00030000oooooooo07Goool00ol0VOooooooo`0^
oooo001Foooo00<0000co`0co`007S?o00030000oooooooo07Goool00ol0VOooooooo`0^oooo001F
oooo00<0000co`0co`007S?o00030000oooooooo07Goool00ol0VOooooooo`0^oooo001Goooo00<0
000co`0co`007C?o0080001foooo00?o09Woooooool0;_ooo`00Eoooo`030000<ol0<ol001dco`00
0`000?ooooooo`1eoooo00?o09Woooooool0;_ooo`00F?ooo`030000<ol0<ol000Tco`02000013?o
00800004<ol00P0000Dco`000`000?ooooooo`1eoooo00?o09Woooooool0;_ooo`00F?ooo`030000
<ol0<ol000Pco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`000?ooooooo`1e
oooo00?o09Woooooool0;_ooo`00FOooo`030000<ol0<ol000Lco`00100003?o03?o000000/co`00
0`0003?o03?o0002<ol00P0007Koool00ol0VOooooooo`0^oooo001Ioooo00<0000co`0co`001c?o
00040000<ol0<ol000002C?o00800005<ol000<0003oooooool0MOooo`03o`2Ioooooooo02koool0
05Woool00`0003?o03?o0007<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000
oooooooo07Goool00ol0VOooooooo`0^oooo001Joooo00<0000co`0co`001c?o0080000:<ol00`00
00@co`000`000?ooooooo`1eoooo00?o09Woooooool0;_ooo`00F_ooo`030000<ol0<ol001Xco`02
0000M_ooo`03o`2Ioooooooo02koool005[oool00`0003?o03?o000J<ol000<0003oooooool0MOoo
o`03o`2Ioooooooo02koool005_oool00`0003?o03?o000I<ol000<0003oooooool0MOooo`03o`2I
oooooooo02koool005_oool00`0003?o03?o000I<ol00P0007Koool00ol0VOooooooo`0^oooo001K
oooo00<0000co`0co`006C?o00030000oooooooo07Goool00ol0VOooooooo`0^oooo001Loooo00<0
000co`0co`0063?o00030000oooooooo07Goool00ol0VOooooooo`0^oooo001Loooo00<0000co`0c
o`0063?o00030000oooooooo07Goool00ol0VOooooooo`0^oooo001Loooo00<0000co`0co`0063?o
0080001foooo00?o09Woooooool0;_ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1e
oooo00?o09Woooooool0;_ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1eoooo00?o
09Woooooool0;_ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1eoooo00?o09Wooooo
ool0;_ooo`00G_ooo`030000<ol0<ol001Hco`020000M_ooo`03o`2Ioooooooo02koool005koool0
0`0003?o03?o000F<ol000<0003oooooool0MOooo`03o`2Ioooooooo02koool005koool2000013?o
00800005<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0MOooo`03o`2Ioooooooo
02koool005goool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0000co`0c
o`000S?o00030000oooooooo07Goool00ol0VOooooooo`0^oooo001Moooo00@0003oool00000000:
<ol000<0000co`0co`0013?o00030000<ol0<ol0008co`020000M_ooo`03o`2Ioooooooo02koool0
05goool010000?ooo`00000000/co`00100003?o03?o03?o00800005<ol000<0003oooooool0MOoo
o`03o`2Ioooooooo02koool005goool010000?ooooooo`0000Pco`00100003?o03?o000000<co`00
0`0003?o03?o0004<ol000<0003oooooool0MOooo`03o`2Ioooooooo02koool005koool3000023?o
00@00003<ol00`0000@co`000`000?ooooooo`1eoooo00?o09Woooooool0;_ooo`00H?ooo`030000
<ol0<ol001@co`020000M_ooo`03o`2Ioooooooo02koool0063oool00`0003?o03?o000D<ol000<0
003oooooool0MOooo`03o`2Ioooooooo02koool0067oool00`0003?o03?o000C<ol000<0003ooooo
ool0MOooo`03o`2Ioooooooo02koool0067oool00`0003?o03?o000C<ol000<0003oooooool0MOoo
o`03o`2Ioooooooo02koool0067oool00`0003?o03?o000C<ol00P0007Koool00ol0VOooooooo`0^
oooo001Qoooo00<0000co`0co`004c?o00030000oooooooo07Goool00ol0VOooooooo`0^oooo001R
oooo00<0000co`0co`004S?o00030000oooooooo07Goool00ol0VOooooooo`0^oooo001Roooo00<0
000co`0co`004S?o00030000oooooooo07Goool00ol0VOooooooo`0^oooo001Roooo00<0000co`0c
o`004S?o0080001foooo00?o09Woooooool0;_ooo`00H_ooo`030000<ol0<ol0018co`000`000?oo
ooooo`1eoooo00?o09Woooooool0;_ooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`1e
oooo00?o09Woooooool0;_ooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`1eoooo00?o
09Woooooool0;_ooo`00Hoooo`030000<ol0<ol0014co`020000M_ooo`03o`2Ioooooooo02koool0
06?oool00`0003?o03?o000A<ol000<0003oooooool0MOooo`03o`2Ioooooooo02koool006?oool0
0`0003?o03?o0009<ol01@0000<co`000`000?ooooooo`1eoooo00?o09Woooooool0;_ooo`00I?oo
o`030000<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003oooooool0MOooo`03o`2Ioooooooo
02koool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o0080001foooo00?o09Wooooo
ool0;_ooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo`dco`000`0003?o03?o0003
<ol0ZOooo`00I?ooo``co`0200001C?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`2Yoooo001U
oooo4S?o00Goool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00IOoooa8co`04oooo00<0
003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001Uoooo4S?o00Coool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001?ooo`800004
oooo00<0003oooooool0Noooo`00IOoooa8co`04oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00000ooo
o`030000oooooooo07_oool006GooolB<ol00oooo`030000oooooooo00;oool00`000?ooooooo`0?
oooo00<0003oooooool02_ooo`030000oooooooo00;oool00`000?ooooooo`1joooo001Voooo4C?o
00Coool00`000?ooooooo`0500003_ooo`030000oooooooo00Soool200001?ooo`030000oooooooo
07_oool006KooolA<ol01?ooo`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0
003oooooool00oooo`030000oooooooo07_oool006KooolA<ol01Oooo`030000oooooooo017oool2
00002_ooo`<00002oooo00<0003oooooool0O?ooo`00I_oooa4co`2Yoooo001Voooo4C?o0:Woool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.87754 .30902 L
.88797 .30902 L
.89307 .30902 L
.89548 .30902 L
.89771 .30902 L
.89886 .30902 L
s
.89886 .30902 m
.89898 .61803 L
s
0 .4 1 r
.02381 .10096 m
.06244 .10432 L
.10458 .10918 L
.14415 .11519 L
.18221 .12266 L
.22272 .13285 L
.26171 .14529 L
.30316 .16179 L
.34309 .18025 L
.3815 .19796 L
.40095 .20587 L
.42237 .2146 L
.44268 .22605 L
.46172 .24018 L
.48196 .2595 L
.50049 .2817 L
.50968 .29455 L
.51472 .30216 L
.5172 .30604 L
.51828 .30778 L
.51947 .30902 L
.52079 .30902 L
.52218 .30902 L
.52511 .30902 L
.53022 .30902 L
.5402 .30902 L
.58062 .30902 L
.61953 .30902 L
.66089 .30902 L
.70074 .30902 L
.73907 .30902 L
.77985 .30902 L
.81911 .30902 L
.85686 .30902 L
.89707 .30902 L
.93576 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`005_oo
o`D0I_mLoooo00<0003oooooool0Y_ooo`006oooo`/0I_mAoooo0P000:Ooool002Koool:06KoAooo
o`030000oooooooo0:Koool0033oool806Ko?oooo`030000oooooooo0:Koool003Soool406Ko>ooo
o`030000oooooooo0:Koool003coool406Ko=oooo`80002Woooo0010oooo101Voc?oool00`000?oo
ooooo`2Voooo0014oooo101Vobooool00`000?ooooooo`2Voooo0018oooo0`1Vobcoool00`000?oo
ooooo`2Voooo001;oooo0`1VobWoool20000Yoooo`00C_ooo`@0I_lUoooo00<0003oooooool0Y_oo
o`00D_ooo`<0I_l?oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`00EOoo
o`80I_l<oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Y_oo
o`00Eoooo`<0I_l9oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`80002Woooo001J
oooo0P1Vo`03oooo0000000000800002oooo00@0003oooooool00009oooo0P0000Goool00`000?oo
ooooo`2Voooo001Loooo0P1Vo`Goool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0Y_ooo`00G_ooo`80I_l4oooo0P0000[oool300001?ooo`030000oooooooo0:Koool0
063oool206Ko5Oooo`80002Woooo001Roooo0P1Voa?oool00`000?ooooooo`2Voooo001Toooo0P1V
oa7oool00`000?ooooooo`2Voooo001Voooo0`1Vo`koool00`000?ooooooo`2Voooo001Yoooo0P1V
o`coool20000Yoooo`00Joooo`<0I_l9oooo00<0003oooooool0Y_ooo`00K_ooo`80I_l7oooo00<0
003oooooool0Y_ooo`00L?ooo`<0I_l4oooo00<0003oooooool0Y_ooo`00Loooo`80I_l2oooo0P00
0:Ooool007Goool206Ko00<0003oooooool0Y_ooo`00Moooo`03000006Ko06Ko0:Koool007Ooool0
0`000?ooooooo`0206KoY?ooo`00Moooo`800003oooo0P1Voj;oool007Ooool00`000?ooooooo`04
oooo0P1Voj3oool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
00Koool00`1Vooooooooo`2Moooo001Moooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo00Ooool00`1Vooooooooo`2Loooo001Moooo00@0
003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00;oool200002Oooo`80I_nL
oooo001Goooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`0:oooo00<0I_ooooooool0VOooo`00GOooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`0;oooo00<0I_ooooooool0V?oo
o`00G_ooo`80000:oooo0P0000Coool300001?ooo`030000oooooooo00coool00`1Vooooooooo`2G
oooo001goooo0P0000koool00`1Vooooooooo`2Foooo001goooo00<0003oooooool03_ooo`0306Ko
oooooooo09Goool007Ooool00`000?ooooooo`0?oooo00<0I_ooooooool0U?ooo`00Moooo`030000
oooooooo013oool00`1Vooooooooo`2Coooo000Goooo100002goool50000:_ooo`80000Boooo00<0
I_ooooooool05oooo`D0000[oooo100002koool200005oooo`005oooo`030000oooooooo033oool0
0`000?ooooooo`0Zoooo00<0003oooooool04_ooo`0306Kooooooooo01Soool00`000?ooooooo`0[
oooo00<0003oooooool0;_ooo`040000oooooooo00005_ooo`006?ooo`030000oooooooo02ooool0
0`000?ooooooo`0Zoooo00<0003oooooool04oooo`0306Kooooooooo01Ooool00`000?ooooooo`0/
oooo00<0003oooooool0;oooo`030000oooooooo01Goool0017oool400001?ooo`030000oooooooo
02Koool400001?ooo`030000oooooooo02[oool00`000?ooooooo`0Doooo00<0I_ooooooool05_oo
o`030000oooooooo02goool00`000?ooooooo`0_oooo00<0003oooooool05?ooo`005oooo`040000
oooooooo0000;oooo`030000oooooooo02[oool200005_ooo`0306Kooooooooo01Goool00`000?oo
ooooo`0[oooo00@0003oooooool0000]oooo00@0003oooooool0000Foooo000Hoooo0P0002ooool2
0000;?ooo`030000oooooooo01Goool00`1Vooooooooo`0Doooo0P0002koool20000;oooo`80000G
oooo001goooo00<0003oooooool05_ooo`0306Kooooooooo08goool007Ooool200005oooo`0306Ko
oooooooo08goool007Ooool00`000?ooooooo`0Goooo00<0I_ooooooool0S?ooo`00Moooo`030000
oooooooo01Soool00`1Vooooooooo`2;oooo001goooo00<0003oooooool06Oooo`0306Kooooooooo
08[oool0013ooooo00004Oooo`005_ooo`P00002<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Hco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0
003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool05Oooo`005_ooo`030000oooooooo00Goool:00007c?o00030000<ol0<ol002dco`00
0`000?ooooooo`0]oooo00<0003oooooool0;Oooo`030000oooooooo01[oool00ol0VOooooooo`0A
oooo00<0003oooooool05Oooo`00:?ooo`H00019<ol000<0003oooooool0N_ooo`03o`2Ioooooooo
02Woool002koool50000A3?o0080001koooo00?o09Woooooool0:Oooo`00<oooo`@00010<ol000<0
003oooooool0N_ooo`03o`2Ioooooooo02Woool003Ooool20000?S?o00030000oooooooo07[oool0
0ol0VOooooooo`0Yoooo000ioooo0`0003/co`000`000?ooooooo`1joooo00?o09Woooooool0:Ooo
o`00??ooo`80000i<ol00P0007_oool00ol0VOooooooo`0Yoooo000noooo0P0003Lco`000`000?oo
ooooo`1joooo00?o09Woooooool0:Oooo`00@?ooo`80000e<ol000<0003oooooool0N_ooo`03o`2I
oooooooo02Woool004;oool20000<c?o00030000oooooooo07[oool00ol0VOooooooo`0Yoooo0014
oooo0P00034co`020000Noooo`03o`2Ioooooooo02Woool004Koool00`0003?o03?o000^<ol000<0
003oooooool0N_ooo`03o`2Ioooooooo02Woool004Ooool00`0003?o03?o000]<ol000<0003ooooo
ool0N_ooo`03o`2Ioooooooo02Woool004Soool00`0003?o03?o000/<ol000<0003oooooool0N_oo
o`03o`2Ioooooooo02Woool004Woool00`0003?o03?o000[<ol00P0007_oool00ol0VOooooooo`0Y
oooo001:oooo00<0000co`0co`00:S?o00030000oooooooo07[oool00ol0VOooooooo`0Yoooo001;
oooo00<0000co`0co`0043?o00800004<ol00P0000<co`0400000c?o00800005<ol000<0003ooooo
ool0N_ooo`03o`2Ioooooooo02Woool004coool00`0003?o03?o000><ol000@0000co`0co`000008
<ol000<0000co`0co`000c?o00040000<ol0<ol0000013?o00030000oooooooo07[oool00ol0VOoo
ooooo`0Yoooo001=oooo00<0000co`0co`003C?o00040000<ol0<ol000002C?o00030000<ol0<ol0
00Dco`000`0003?o03?o0002<ol00P0007_oool00ol0VOooooooo`0Yoooo001>oooo00<0000co`0c
o`0033?o00040000<ol0<ol000002S?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo
07[oool00ol0VOooooooo`0Yoooo001?oooo00<0000co`0co`002c?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000c?o00030000<ol0<ol000@co`000`000?ooooooo`1joooo00?o09Wooooo
ool0:Oooo`00Coooo`030000<ol0<ol000`co`0200002S?o00800004<ol00`0000@co`000`000?oo
ooooo`1joooo00?o09Woooooool0:Oooo`00D?ooo`030000<ol0<ol002@co`020000Noooo`03o`2I
oooooooo02Woool0057oool00`0003?o03?o000S<ol000<0003oooooool0N_ooo`03o`2Ioooooooo
02Woool005;oool00`0003?o03?o000R<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02Woool0
05;oool00`0003?o03?o000R<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02Woool005?oool0
0`0003?o03?o000Q<ol00P0007_oool00ol0VOooooooo`0Yoooo001Coooo00<0000co`0co`008C?o
00030000oooooooo07[oool00ol0VOooooooo`0Yoooo001Doooo00<0000co`0co`0083?o00030000
oooooooo07[oool00ol0VOooooooo`0Yoooo001Doooo00<0000co`0co`0083?o00030000oooooooo
07[oool00ol0VOooooooo`0Yoooo001Eoooo00<0000co`0co`007c?o0080001koooo00?o09Wooooo
ool0:Oooo`00EOooo`030000<ol0<ol001lco`000`000?ooooooo`1joooo00?o09Woooooool0:Ooo
o`00E_ooo`030000<ol0<ol001hco`000`000?ooooooo`1joooo00?o09Woooooool0:Oooo`00E_oo
o`030000<ol0<ol001hco`000`000?ooooooo`1joooo00?o09Woooooool0:Oooo`00Eoooo`030000
<ol0<ol001dco`020000Noooo`03o`2Ioooooooo02Woool005Ooool00`0003?o03?o000M<ol000<0
003oooooool0N_ooo`03o`2Ioooooooo02Woool005Soool00`0003?o03?o0009<ol00P0000@co`02
000013?o00800005<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02Woool005Soool00`0003?o
03?o0008<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0003oooooool0N_oo
o`03o`2Ioooooooo02Woool005Woool00`0003?o03?o0007<ol000@0000co`0co`00000;<ol000<0
000co`0co`000S?o0080001koooo00?o09Woooooool0:Oooo`00FOooo`030000<ol0<ol000Lco`00
100003?o03?o000000Tco`0200001C?o00030000oooooooo07[oool00ol0VOooooooo`0Yoooo001I
oooo00<0000co`0co`001c?o00040000<ol0<ol000002C?o00030000<ol0<ol000@co`000`000?oo
ooooo`1joooo00?o09Woooooool0:Oooo`00F_ooo`030000<ol0<ol000Lco`0200002S?o00<00004
<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02Woool005[oool00`0003?o03?o000J<ol00P00
07_oool00ol0VOooooooo`0Yoooo001Joooo00<0000co`0co`006S?o00030000oooooooo07[oool0
0ol0VOooooooo`0Yoooo001Koooo00<0000co`0co`006C?o00030000oooooooo07[oool00ol0VOoo
ooooo`0Yoooo001Koooo00<0000co`0co`006C?o0080001koooo00?o09Woooooool0:Oooo`00Fooo
o`030000<ol0<ol001Tco`000`000?ooooooo`1joooo00?o09Woooooool0:Oooo`00G?ooo`030000
<ol0<ol001Pco`000`000?ooooooo`1joooo00?o09Woooooool0:Oooo`00G?ooo`030000<ol0<ol0
01Pco`000`000?ooooooo`1joooo00?o09Woooooool0:Oooo`00G?ooo`030000<ol0<ol001Pco`02
0000Noooo`03o`2Ioooooooo02Woool005goool00`0003?o03?o000G<ol000<0003oooooool0N_oo
o`03o`2Ioooooooo02Woool005goool00`0003?o03?o000G<ol000<0003oooooool0N_ooo`03o`2I
oooooooo02Woool005goool00`0003?o03?o000G<ol000<0003oooooool0N_ooo`03o`2Ioooooooo
02Woool005koool00`0003?o03?o000F<ol00P0007_oool00ol0VOooooooo`0Yoooo001Noooo00<0
000co`0co`005S?o00030000oooooooo07[oool00ol0VOooooooo`0Yoooo001Noooo0P0000@co`02
00001C?o00030000<ol0<ol0008co`0200001C?o00030000oooooooo07[oool00ol0VOooooooo`0Y
oooo001Moooo00@0003oool00000000:<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0
008co`000`000?ooooooo`1joooo00?o09Woooooool0:Oooo`00GOooo`040000oooo000000002S?o
00030000<ol0<ol000@co`000`0003?o03?o0002<ol00P0007_oool00ol0VOooooooo`0Yoooo001M
oooo00@0003oool00000000;<ol000@0000co`0co`0co`0200001C?o00030000oooooooo07[oool0
0ol0VOooooooo`0Yoooo001Moooo00@0003oooooool00008<ol000@0000co`0co`000003<ol000<0
000co`0co`0013?o00030000oooooooo07[oool00ol0VOooooooo`0Yoooo001Noooo0`0000Pco`04
00000c?o00<00004<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02Woool0063oool00`0003?o
03?o000D<ol00P0007_oool00ol0VOooooooo`0Yoooo001Poooo00<0000co`0co`0053?o00030000
oooooooo07[oool00ol0VOooooooo`0Yoooo001Qoooo00<0000co`0co`004c?o00030000oooooooo
07[oool00ol0VOooooooo`0Yoooo001Qoooo00<0000co`0co`004c?o00030000oooooooo07[oool0
0ol0VOooooooo`0Yoooo001Qoooo00<0000co`0co`004c?o0080001koooo00?o09Woooooool0:Ooo
o`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`1joooo00?o09Woooooool0:Oooo`00H_oo
o`030000<ol0<ol0018co`000`000?ooooooo`1joooo00?o09Woooooool0:Oooo`00H_ooo`030000
<ol0<ol0018co`000`000?ooooooo`1joooo00?o09Woooooool0:Oooo`00H_ooo`030000<ol0<ol0
018co`020000Noooo`03o`2Ioooooooo02Woool006;oool00`0003?o03?o000B<ol000<0003ooooo
ool0N_ooo`03o`2Ioooooooo02Woool006?oool00`0003?o03?o000A<ol000<0003oooooool0N_oo
o`03o`2Ioooooooo02Woool006?oool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`03o`2I
oooooooo02Woool006?oool00`0003?o03?o000A<ol00P0007_oool00ol0VOooooooo`0Yoooo001S
oooo00<0000co`0co`004C?o00030000oooooooo07[oool00ol0VOooooooo`0Yoooo001Soooo00<0
000co`0co`002C?o00D00003<ol000<0003oooooool0N_ooo`03o`2Ioooooooo02Woool006Coool0
0`0003?o03?o000:<ol000<0000co`0co`000c?o00030000oooooooo07[oool00ol0VOooooooo`0Y
oooo001Toooo00<0000co`0co`002S?o00030000<ol0<ol000<co`020000Noooo`03o`2Ioooooooo
02Woool006Coool=<ol000<0000co`0co`000c?o0:Woool006Coool=<ol000<0000co`0co`000c?o
0:Woool006Coool<<ol00P0000Dco`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol0ZOooo`00IOoo
oa8co`05oooo00<0003oooooool08_ooo`030000oooooooo07coool006GooolB<ol01?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00IOoooa8co`04oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000?oool300001?oo
o`030000oooooooo07_oool006GooolB<ol01?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool0
0`000?ooooooo`1koooo001Uoooo4S?o00?oool00`000?ooooooo`02oooo00<0003oooooool03ooo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1joooo001Voooo4C?o
00Coool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool300001?ooo`030000oooooooo
07_oool006KooolA<ol01?ooo`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0
003oooooool00oooo`030000oooooooo07_oool006KooolA<ol01Oooo`030000oooooooo017oool2
00002_ooo`<00002oooo00<0003oooooool0O?ooo`00I_oooa4co`2Yoooo001Voooo4C?o0:Woool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.90802 .30902 L
.91306 .30902 L
.91526 .30902 L
.91765 .30902 L
.91894 .30902 L
s
.91894 .30902 m
.91906 .61803 L
s
0 .4 1 r
.02381 .10102 m
.06244 .1044 L
.10458 .10928 L
.14415 .11533 L
.18221 .12285 L
.22272 .1331 L
.26171 .14563 L
.30316 .16205 L
.34309 .17929 L
.3815 .19457 L
.40095 .20063 L
.41127 .20329 L
.42237 .20675 L
.44268 .21522 L
.46172 .22604 L
.48285 .24196 L
.50294 .2616 L
.52297 .28635 L
.5317 .29898 L
.53629 .30611 L
.5374 .30789 L
.5386 .30902 L
.53991 .30902 L
.54113 .30902 L
.54641 .30902 L
.55126 .30902 L
.56081 .30902 L
.58178 .30902 L
.62314 .30902 L
.66299 .30902 L
.70132 .30902 L
.7421 .30902 L
.78136 .30902 L
.81911 .30902 L
.85932 .30902 L
.898 .30902 L
.93914 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`005_oo
o`D0I_mLoooo00<0003oooooool0Y_ooo`006oooo`/0I_mAoooo0P000:Ooool002Koool:06KoAooo
o`030000oooooooo0:Koool0033oool806Ko?oooo`030000oooooooo0:Koool003Soool406Ko>ooo
o`030000oooooooo0:Koool003coool406Ko=oooo`80002Woooo0010oooo101Voc?oool00`000?oo
ooooo`2Voooo0014oooo101Vobooool00`000?ooooooo`2Voooo0018oooo0`1Vobcoool00`000?oo
ooooo`2Voooo001;oooo0`1VobWoool20000Yoooo`00C_ooo`@0I_lUoooo00<0003oooooool0Y_oo
o`00D_ooo`<0I_l?oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`00EOoo
o`80I_l<oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Y_oo
o`00Eoooo`<0I_l9oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`80002Woooo001J
oooo0P1Vo`03oooo0000000000800002oooo00@0003oooooool00009oooo0P0000Goool00`000?oo
ooooo`2Voooo001Loooo0P1Vo`Goool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0Y_ooo`00G_ooo`80I_l4oooo0P0000[oool300001?ooo`030000oooooooo0:Koool0
063oool206Ko5Oooo`80002Woooo001Roooo0P1Voa?oool00`000?ooooooo`2Voooo001Toooo0P1V
oa7oool00`000?ooooooo`2Voooo001Voooo0`1Vo`koool00`000?ooooooo`2Voooo001Yoooo0`1V
o`_oool20000Yoooo`00K?ooo`@0I_l7oooo00<0003oooooool0Y_ooo`00L?ooo`<0I_l4oooo00<0
003oooooool0Y_ooo`00Loooo`80I_l2oooo00<0003oooooool0Y_ooo`00MOooo`80I_l20000Yooo
o`00Moooo`03000006Ko06Ko0080I_nToooo001goooo00<0003oooooool00_ooo`80I_nRoooo001g
oooo00<0003oooooool01?ooo`80I_nPoooo001goooo0P0000Ooool206KoW_ooo`00Moooo`030000
oooooooo00Soool206KoW?ooo`00G_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool02_ooo`80I_nJoooo001Moooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo00coool206KoV?ooo`00GOooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0P0000ooool00`1Vooooooooo`2E
oooo001Goooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`0?oooo0P1VoiGoool005goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool04Oooo`0306Kooooooooo09;oool005koool2
00002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Boooo00<0I_ooooooool0TOooo`00Mooo
o`80000Doooo00<0I_ooooooool0T?ooo`00Moooo`030000oooooooo01Coool00`1Vooooooooo`2?
oooo001goooo00<0003oooooool05Oooo`0306Kooooooooo08koool007Ooool00`000?ooooooo`0F
oooo00<0I_ooooooool0SOooo`005oooo`@0000]oooo1@0002[oool200006?ooo`0306Kooooooooo
017oool50000:oooo`@0000^oooo0P0001Ooool001Ooool00`000?ooooooo`0`oooo00<0003ooooo
ool0:_ooo`030000oooooooo01Ooool00`1Vooooooooo`0Coooo00<0003oooooool0:oooo`030000
oooooooo02koool010000?ooooooo`0001Koool001Soool00`000?ooooooo`0_oooo00<0003ooooo
ool0:_ooo`030000oooooooo01Soool00`1Vooooooooo`0Boooo00<0003oooooool0;?ooo`030000
oooooooo02ooool00`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo1000
00Coool00`000?ooooooo`0Zoooo00<0003oooooool06Oooo`0306Kooooooooo017oool00`000?oo
ooooo`0]oooo00<0003oooooool0;oooo`030000oooooooo01Coool001Ooool010000?ooooooo`00
02ooool00`000?ooooooo`0Zoooo0P0001_oool00`1Vooooooooo`0@oooo00<0003oooooool0:ooo
o`040000oooooooo0000;Oooo`040000oooooooo00005_ooo`006?ooo`80000_oooo0P0002coool0
0`000?ooooooo`0Joooo00<0I_ooooooool03oooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo01_oool00`1Vooooooooo`28oooo001goooo0P0001goool00`1Vooooooooo`27
oooo001goooo00<0003oooooool07?ooo`0306Kooooooooo08Ooool007Ooool00`000?ooooooo`0M
oooo00<0I_ooooooool0Q_ooo`00Moooo`030000oooooooo01goool00`1Vooooooooo`26oooo000@
ooooo`00017oool001Koool800000S?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000oooooooo
00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Koool00`000?ooooooo`02oooo00?o09Woooooool00_ooo`030000oooooooo
00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool01Oooo`X0000O<ol000<0000co`0c
o`00;C?o00030000oooooooo02goool00`000?ooooooo`0]oooo00<0003oooooool07oooo`03o`2I
oooooooo00coool00`000?ooooooo`0Eoooo000Xoooo1P0004Tco`000`000?ooooooo`1ooooo00?o
09Woooooool09?ooo`00;_ooo`D00014<ol00P00083oool00ol0VOooooooo`0Toooo000coooo1000
040co`000`000?ooooooo`1ooooo00?o09Woooooool09?ooo`00=oooo`80000n<ol000<0003ooooo
ool0Ooooo`03o`2Ioooooooo02Coool003Woool30000>c?o00030000oooooooo07ooool00ol0VOoo
ooooo`0Toooo000loooo0P0003Tco`020000P?ooo`03o`2Ioooooooo02Coool003koool20000=c?o
00030000oooooooo07ooool00ol0VOooooooo`0Toooo0010oooo0P0003Dco`000`000?ooooooo`1o
oooo00?o09Woooooool09?ooo`00@_ooo`80000c<ol000<0003oooooool0Ooooo`03o`2Ioooooooo
02Coool004Coool20000<C?o00800020oooo00?o09Woooooool09?ooo`00A_ooo`030000<ol0<ol0
02hco`000`000?ooooooo`1ooooo00?o09Woooooool09?ooo`00Aoooo`030000<ol0<ol002dco`00
0`000?ooooooo`1ooooo00?o09Woooooool09?ooo`00B?ooo`030000<ol0<ol002`co`000`000?oo
ooooo`1ooooo00?o09Woooooool09?ooo`00BOooo`030000<ol0<ol002/co`020000P?ooo`03o`2I
oooooooo02Coool004[oool00`0003?o03?o000Z<ol000<0003oooooool0Ooooo`03o`2Ioooooooo
02Coool004_oool00`0003?o03?o000@<ol00P0000@co`0200000c?o00@00003<ol00P0000Dco`00
0`000?ooooooo`1ooooo00?o09Woooooool09?ooo`00C?ooo`030000<ol0<ol000hco`00100003?o
03?o000000Pco`000`0003?o03?o0003<ol000@0000co`0co`000004<ol000<0003oooooool0Oooo
o`03o`2Ioooooooo02Coool004goool00`0003?o03?o000=<ol000@0000co`0co`000009<ol000<0
000co`0co`001C?o00030000<ol0<ol0008co`020000P?ooo`03o`2Ioooooooo02Coool004koool0
0`0003?o03?o000<<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800005<ol000<0
003oooooool0Ooooo`03o`2Ioooooooo02Coool004ooool00`0003?o03?o000;<ol000@0000co`0c
o`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo07ooool0
0ol0VOooooooo`0Toooo001?oooo00<0000co`0co`0033?o0080000:<ol00P0000@co`03000013?o
00030000oooooooo07ooool00ol0VOooooooo`0Toooo001@oooo00<0000co`0co`0093?o00800020
oooo00?o09Woooooool09?ooo`00DOooo`030000<ol0<ol002<co`000`000?ooooooo`1ooooo00?o
09Woooooool09?ooo`00D_ooo`030000<ol0<ol0028co`000`000?ooooooo`1ooooo00?o09Wooooo
ool09?ooo`00D_ooo`030000<ol0<ol0028co`000`000?ooooooo`1ooooo00?o09Woooooool09?oo
o`00Doooo`030000<ol0<ol0024co`020000P?ooo`03o`2Ioooooooo02Coool005?oool00`0003?o
03?o000Q<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Coool005Coool00`0003?o03?o000P
<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Coool005Coool00`0003?o03?o000P<ol000<0
003oooooool0Ooooo`03o`2Ioooooooo02Coool005Goool00`0003?o03?o000O<ol00P00083oool0
0ol0VOooooooo`0Toooo001Eoooo00<0000co`0co`007c?o00030000oooooooo07ooool00ol0VOoo
ooooo`0Toooo001Foooo00<0000co`0co`007S?o00030000oooooooo07ooool00ol0VOooooooo`0T
oooo001Foooo00<0000co`0co`007S?o00030000oooooooo07ooool00ol0VOooooooo`0Toooo001G
oooo00<0000co`0co`007C?o00800020oooo00?o09Woooooool09?ooo`00Eoooo`030000<ol0<ol0
01dco`000`000?ooooooo`1ooooo00?o09Woooooool09?ooo`00F?ooo`030000<ol0<ol000Tco`02
000013?o00800004<ol00P0000Dco`000`000?ooooooo`1ooooo00?o09Woooooool09?ooo`00F?oo
o`030000<ol0<ol000Pco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`000?oo
ooooo`1ooooo00?o09Woooooool09?ooo`00FOooo`030000<ol0<ol000Lco`00100003?o03?o0000
00/co`000`0003?o03?o0002<ol00P00083oool00ol0VOooooooo`0Toooo001Ioooo00<0000co`0c
o`001c?o00040000<ol0<ol000002C?o00800005<ol000<0003oooooool0Ooooo`03o`2Ioooooooo
02Coool005Woool00`0003?o03?o0007<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o
00030000oooooooo07ooool00ol0VOooooooo`0Toooo001Joooo00<0000co`0co`001c?o0080000:
<ol00`0000@co`000`000?ooooooo`1ooooo00?o09Woooooool09?ooo`00F_ooo`030000<ol0<ol0
01Xco`020000P?ooo`03o`2Ioooooooo02Coool005[oool00`0003?o03?o000J<ol000<0003ooooo
ool0Ooooo`03o`2Ioooooooo02Coool005_oool00`0003?o03?o000I<ol000<0003oooooool0Oooo
o`03o`2Ioooooooo02Coool005_oool00`0003?o03?o000I<ol00P00083oool00ol0VOooooooo`0T
oooo001Koooo00<0000co`0co`006C?o00030000oooooooo07ooool00ol0VOooooooo`0Toooo001L
oooo00<0000co`0co`0063?o00030000oooooooo07ooool00ol0VOooooooo`0Toooo001Loooo00<0
000co`0co`0063?o00030000oooooooo07ooool00ol0VOooooooo`0Toooo001Loooo00<0000co`0c
o`0063?o00800020oooo00?o09Woooooool09?ooo`00GOooo`030000<ol0<ol001Lco`000`000?oo
ooooo`1ooooo00?o09Woooooool09?ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1o
oooo00?o09Woooooool09?ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`1ooooo00?o
09Woooooool09?ooo`00G_ooo`030000<ol0<ol001Hco`020000P?ooo`03o`2Ioooooooo02Coool0
05koool00`0003?o03?o000F<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Coool005koool2
000013?o00800005<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0Ooooo`03o`2I
oooooooo02Coool005goool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0
000co`0co`000S?o00030000oooooooo07ooool00ol0VOooooooo`0Toooo001Moooo00@0003oool0
0000000:<ol000<0000co`0co`0013?o00030000<ol0<ol0008co`020000P?ooo`03o`2Ioooooooo
02Coool005goool010000?ooo`00000000/co`00100003?o03?o03?o00800005<ol000<0003ooooo
ool0Ooooo`03o`2Ioooooooo02Coool005goool010000?ooooooo`0000Pco`00100003?o03?o0000
00<co`000`0003?o03?o0004<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Coool005koool3
000023?o00@00003<ol00`0000@co`000`000?ooooooo`1ooooo00?o09Woooooool09?ooo`00H?oo
o`030000<ol0<ol001@co`020000P?ooo`03o`2Ioooooooo02Coool0063oool00`0003?o03?o000D
<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Coool0067oool00`0003?o03?o000C<ol000<0
003oooooool0Ooooo`03o`2Ioooooooo02Coool0067oool00`0003?o03?o000C<ol000<0003ooooo
ool0Ooooo`03o`2Ioooooooo02Coool0067oool00`0003?o03?o000C<ol00P00083oool00ol0VOoo
ooooo`0Toooo001Qoooo00<0000co`0co`004c?o00030000oooooooo07ooool00ol0VOooooooo`0T
oooo001Roooo00<0000co`0co`004S?o00030000oooooooo07ooool00ol0VOooooooo`0Toooo001R
oooo00<0000co`0co`004S?o00030000oooooooo07ooool00ol0VOooooooo`0Toooo001Roooo00<0
000co`0co`004S?o00800020oooo00?o09Woooooool09?ooo`00H_ooo`030000<ol0<ol0018co`00
0`000?ooooooo`1ooooo00?o09Woooooool09?ooo`00Hoooo`030000<ol0<ol0014co`000`000?oo
ooooo`1ooooo00?o09Woooooool09?ooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`1o
oooo00?o09Woooooool09?ooo`00Hoooo`030000<ol0<ol0014co`020000P?ooo`03o`2Ioooooooo
02Coool006?oool00`0003?o03?o000A<ol000<0003oooooool0Ooooo`03o`2Ioooooooo02Coool0
06?oool00`0003?o03?o0009<ol01@0000<co`000`000?ooooooo`1ooooo00?o09Woooooool09?oo
o`00I?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003oooooool0Ooooo`03o`2I
oooooooo02Coool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o00800020oooo00?o
09Woooooool09?ooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo`dco`000`0003?o
03?o0003<ol0ZOooo`00I?ooo``co`0200001C?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`2Y
oooo001Uoooo4S?o00Goool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00IOoooa8co`04
oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001Uoooo4S?o
00Coool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001Ooo
o`030000oooooooo00;oool00`000?ooooooo`1koooo001Uoooo4S?o00Coool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`09oooo00<0
003oooooool00_ooo`030000oooooooo07_oool006GooolB<ol00oooo`030000oooooooo00;oool0
0`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`1j
oooo001Voooo4C?o00Coool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool01@000?oo
ooooooooo`00001moooo001Voooo4C?o00Coool01@000?ooooooooooo`00000Aoooo00<0003ooooo
ool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool006KooolA<ol01Oooo`030000
oooooooo017oool200002Oooo`@00002oooo00<0003oooooool0O?ooo`00I_oooa4co`2Yoooo001V
oooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91765 .30902 L
.92769 .30902 L
.93044 .30902 L
.93339 .30902 L
.93482 .30902 L
.93618 .30902 L
.93739 .30902 L
s
.93739 .30902 m
.93752 .61803 L
s
0 .4 1 r
.02381 .10129 m
.06244 .10476 L
.10458 .10978 L
.14415 .116 L
.18221 .12374 L
.22272 .13431 L
.26171 .14725 L
.30316 .16359 L
.34309 .17968 L
.36136 .18643 L
.3815 .19283 L
.40134 .19739 L
.41232 .19917 L
.42237 .20126 L
.44177 .20688 L
.45248 .211 L
.46265 .21567 L
.48246 .22715 L
.50085 .24106 L
.52137 .26092 L
.53998 .28357 L
.54933 .29686 L
.5518 .30059 L
.55445 .30471 L
.55573 .30674 L
.55695 .3087 L
.55804 .30902 L
.55922 .30902 L
.56439 .30902 L
.57007 .30902 L
.58004 .30902 L
.62082 .30902 L
.66009 .30902 L
.69784 .30902 L
.73804 .30902 L
.77673 .30902 L
.81787 .30902 L
.8575 .30902 L
.8956 .30902 L
.93617 .30902 L
.97521 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`005_oo
o`D0I_mLoooo00<0003oooooool0Y_ooo`006oooo`/0I_mAoooo0P000:Ooool002Koool:06KoAooo
o`030000oooooooo0:Koool0033oool806Ko?oooo`030000oooooooo0:Koool003Soool406Ko>ooo
o`030000oooooooo0:Koool003coool406Ko=oooo`80002Woooo0010oooo101Voc?oool00`000?oo
ooooo`2Voooo0014oooo101Vobooool00`000?ooooooo`2Voooo0018oooo0`1Vobcoool00`000?oo
ooooo`2Voooo001;oooo0`1VobWoool20000Yoooo`00C_ooo`@0I_lUoooo00<0003oooooool0Y_oo
o`00D_ooo`80I_l@oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`00E?oo
o`80I_l=oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Y_oo
o`00E_ooo`80I_l;oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`80002Woooo001H
oooo0P1Vo`?oool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00F_ooo`80I_l7oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
0:Koool005coool306Ko1Oooo`80000:oooo0`0000Coool00`000?ooooooo`2Voooo001Ooooo0P1V
oaKoool20000Yoooo`00HOooo`<0I_lCoooo00<0003oooooool0Y_ooo`00I?ooo`80I_lAoooo00<0
003oooooool0Y_ooo`00I_ooo`@0I_l=oooo00<0003oooooool0Y_ooo`00J_ooo`@0I_l9oooo0P00
0:Ooool006koool206Ko1oooo`030000oooooooo0:Koool0073oool406Ko0oooo`030000oooooooo
0:Koool007Coool306Ko00<0003oooooool0Y_ooo`00Moooo`80000406KoXoooo`00Moooo`030000
oooooooo00?oool206KoXOooo`00Moooo`030000oooooooo00Goool306KoW_ooo`00Moooo`030000
oooooooo00Soool306KoVoooo`00Moooo`80000<oooo0P1VoiWoool007Ooool00`000?ooooooo`0=
oooo0P1VoiOoool005koool200001?ooo`800003oooo100000?oool200001Oooo`030000oooooooo
00ooool206KoUOooo`00GOooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?oo
ooooo`0000Coool00`000?ooooooo`0Aoooo00<0I_ooooooool0T_ooo`00GOooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0P0001?oool00`1Vooooooooo`2A
oooo001Goooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`0Coooo0P1Voi7oool005goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool05Oooo`0306Kooooooooo08koool005koool2
00002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Foooo00<0I_ooooooool0SOooo`00Mooo
o`80000Hoooo00<0I_ooooooool0S?ooo`00Moooo`030000oooooooo01Soool00`1Vooooooooo`2;
oooo001goooo00<0003oooooool06Oooo`0306Kooooooooo08[oool007Ooool00`000?ooooooo`0J
oooo00<0I_ooooooool0ROooo`005oooo`@0000]oooo1@0002[oool200007?ooo`0306Kooooooooo
00goool50000:oooo`@0000^oooo0P0001Ooool001Ooool00`000?ooooooo`0`oooo00<0003ooooo
ool0:_ooo`030000oooooooo01coool00`1Vooooooooo`0>oooo00<0003oooooool0:oooo`030000
oooooooo02koool010000?ooooooo`0001Koool001Soool00`000?ooooooo`0_oooo00<0003ooooo
ool0:_ooo`030000oooooooo01coool00`1Vooooooooo`0>oooo00<0003oooooool0;?ooo`030000
oooooooo02ooool00`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo1000
00Coool00`000?ooooooo`0Zoooo00<0003oooooool07Oooo`0306Kooooooooo00goool00`000?oo
ooooo`0]oooo00<0003oooooool0;oooo`030000oooooooo01Coool001Ooool010000?ooooooo`00
02ooool00`000?ooooooo`0Zoooo0P0001ooool00`1Vooooooooo`0<oooo00<0003oooooool0:ooo
o`040000oooooooo0000;Oooo`040000oooooooo00005_ooo`006?ooo`80000_oooo0P0002coool0
0`000?ooooooo`0Ooooo00<0I_ooooooool02_ooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo023oool00`1Vooooooooo`23oooo001goooo0P00027oool00`1Vooooooooo`23
oooo001goooo00<0003oooooool08Oooo`0306Kooooooooo08;oool007Ooool00`000?ooooooo`0R
oooo00<0I_ooooooool0POooo`00Moooo`030000oooooooo02?oool00`1Vooooooooo`20oooo000@
ooooo`00017oool001Koool800000S?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000oooooooo
00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
01Goool001Koool00`000?ooooooo`05oooo2P0001lco`000`0003?o03?o000]<ol000<0003ooooo
ool0;Oooo`030000oooooooo02goool00`000?ooooooo`0Toooo00?o09Woooooool01oooo`030000
oooooooo01Goool002Soool60000BC?o00030000oooooooo08Coool00ol0VOooooooo`0Ooooo000^
oooo1@0004@co`020000QOooo`03o`2Ioooooooo01ooool003?oool40000@3?o00030000oooooooo
08Coool00ol0VOooooooo`0Ooooo000goooo0P0003hco`000`000?ooooooo`24oooo00?o09Wooooo
ool07oooo`00>Oooo`<0000k<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01ooool003coool2
0000>C?o00800025oooo00?o09Woooooool07oooo`00?_ooo`80000g<ol000<0003oooooool0Q?oo
o`03o`2Ioooooooo01ooool0043oool20000=C?o00030000oooooooo08Coool00ol0VOooooooo`0O
oooo0012oooo0P0003<co`000`000?ooooooo`24oooo00?o09Woooooool07oooo`00A?ooo`80000a
<ol00P0008Goool00ol0VOooooooo`0Ooooo0016oooo00<0000co`0co`00;S?o00030000oooooooo
08Coool00ol0VOooooooo`0Ooooo0017oooo00<0000co`0co`00;C?o00030000oooooooo08Coool0
0ol0VOooooooo`0Ooooo0018oooo00<0000co`0co`00;3?o00030000oooooooo08Coool00ol0VOoo
ooooo`0Ooooo0019oooo00<0000co`0co`00:c?o00800025oooo00?o09Woooooool07oooo`00B_oo
o`030000<ol0<ol002Xco`000`000?ooooooo`24oooo00?o09Woooooool07oooo`00Boooo`030000
<ol0<ol0010co`02000013?o00800003<ol0100000<co`0200001C?o00030000oooooooo08Coool0
0ol0VOooooooo`0Ooooo001<oooo00<0000co`0co`003S?o00040000<ol0<ol0000023?o00030000
<ol0<ol000<co`00100003?o03?o000000@co`000`000?ooooooo`24oooo00?o09Woooooool07ooo
o`00COooo`030000<ol0<ol000dco`00100003?o03?o000000Tco`000`0003?o03?o0005<ol000<0
000co`0co`000S?o00800025oooo00?o09Woooooool07oooo`00C_ooo`030000<ol0<ol000`co`00
100003?o03?o000000Xco`000`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`24oooo00?o
09Woooooool07oooo`00Coooo`030000<ol0<ol000/co`00100003?o03?o000000Pco`00100003?o
03?o000000<co`000`0003?o03?o0004<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01ooool0
04ooool00`0003?o03?o000<<ol00P0000Xco`02000013?o00<00004<ol000<0003oooooool0Q?oo
o`03o`2Ioooooooo01ooool0053oool00`0003?o03?o000T<ol00P0008Goool00ol0VOooooooo`0O
oooo001Aoooo00<0000co`0co`008c?o00030000oooooooo08Coool00ol0VOooooooo`0Ooooo001B
oooo00<0000co`0co`008S?o00030000oooooooo08Coool00ol0VOooooooo`0Ooooo001Boooo00<0
000co`0co`008S?o00030000oooooooo08Coool00ol0VOooooooo`0Ooooo001Coooo00<0000co`0c
o`008C?o00800025oooo00?o09Woooooool07oooo`00Doooo`030000<ol0<ol0024co`000`000?oo
ooooo`24oooo00?o09Woooooool07oooo`00E?ooo`030000<ol0<ol0020co`000`000?ooooooo`24
oooo00?o09Woooooool07oooo`00E?ooo`030000<ol0<ol0020co`000`000?ooooooo`24oooo00?o
09Woooooool07oooo`00EOooo`030000<ol0<ol001lco`020000QOooo`03o`2Ioooooooo01ooool0
05Goool00`0003?o03?o000O<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01ooool005Koool0
0`0003?o03?o000N<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01ooool005Koool00`0003?o
03?o000N<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01ooool005Ooool00`0003?o03?o000M
<ol00P0008Goool00ol0VOooooooo`0Ooooo001Goooo00<0000co`0co`007C?o00030000oooooooo
08Coool00ol0VOooooooo`0Ooooo001Hoooo00<0000co`0co`002C?o00800004<ol00P0000@co`02
00001C?o00030000oooooooo08Coool00ol0VOooooooo`0Ooooo001Hoooo00<0000co`0co`0023?o
00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000oooooooo08Coool00ol0VOoo
ooooo`0Ooooo001Ioooo00<0000co`0co`001c?o00040000<ol0<ol000002c?o00030000<ol0<ol0
008co`020000QOooo`03o`2Ioooooooo01ooool005Woool00`0003?o03?o0007<ol000@0000co`0c
o`000009<ol00P0000Dco`000`000?ooooooo`24oooo00?o09Woooooool07oooo`00FOooo`030000
<ol0<ol000Lco`00100003?o03?o000000Tco`000`0003?o03?o0004<ol000<0003oooooool0Q?oo
o`03o`2Ioooooooo01ooool005[oool00`0003?o03?o0007<ol00P0000Xco`03000013?o00030000
oooooooo08Coool00ol0VOooooooo`0Ooooo001Joooo00<0000co`0co`006S?o00800025oooo00?o
09Woooooool07oooo`00F_ooo`030000<ol0<ol001Xco`000`000?ooooooo`24oooo00?o09Wooooo
ool07oooo`00Foooo`030000<ol0<ol001Tco`000`000?ooooooo`24oooo00?o09Woooooool07ooo
o`00Foooo`030000<ol0<ol001Tco`020000QOooo`03o`2Ioooooooo01ooool005_oool00`0003?o
03?o000I<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01ooool005coool00`0003?o03?o000H
<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01ooool005coool00`0003?o03?o000H<ol000<0
003oooooool0Q?ooo`03o`2Ioooooooo01ooool005coool00`0003?o03?o000H<ol00P0008Goool0
0ol0VOooooooo`0Ooooo001Moooo00<0000co`0co`005c?o00030000oooooooo08Coool00ol0VOoo
ooooo`0Ooooo001Moooo00<0000co`0co`005c?o00030000oooooooo08Coool00ol0VOooooooo`0O
oooo001Moooo00<0000co`0co`005c?o00030000oooooooo08Coool00ol0VOooooooo`0Ooooo001N
oooo00<0000co`0co`005S?o00800025oooo00?o09Woooooool07oooo`00G_ooo`030000<ol0<ol0
01Hco`000`000?ooooooo`24oooo00?o09Woooooool07oooo`00G_ooo`800004<ol00P0000Dco`00
0`0003?o03?o0002<ol00P0000Dco`000`000?ooooooo`24oooo00?o09Woooooool07oooo`00GOoo
o`040000oooo000000002S?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0
003oooooool0Q?ooo`03o`2Ioooooooo01ooool005goool010000?ooo`00000000Xco`000`0003?o
03?o0004<ol000<0000co`0co`000S?o00800025oooo00?o09Woooooool07oooo`00GOooo`040000
oooo000000002c?o00040000<ol0<ol0<ol00P0000Dco`000`000?ooooooo`24oooo00?o09Wooooo
ool07oooo`00GOooo`040000oooooooo000023?o00040000<ol0<ol000000c?o00030000<ol0<ol0
00@co`000`000?ooooooo`24oooo00?o09Woooooool07oooo`00G_ooo`<00008<ol0100000<co`03
000013?o00030000oooooooo08Coool00ol0VOooooooo`0Ooooo001Poooo00<0000co`0co`0053?o
00800025oooo00?o09Woooooool07oooo`00H?ooo`030000<ol0<ol001@co`000`000?ooooooo`24
oooo00?o09Woooooool07oooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`24oooo00?o
09Woooooool07oooo`00HOooo`030000<ol0<ol001<co`000`000?ooooooo`24oooo00?o09Wooooo
ool07oooo`00HOooo`030000<ol0<ol001<co`020000QOooo`03o`2Ioooooooo01ooool0067oool0
0`0003?o03?o000C<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01ooool006;oool00`0003?o
03?o000B<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01ooool006;oool00`0003?o03?o000B
<ol000<0003oooooool0Q?ooo`03o`2Ioooooooo01ooool006;oool00`0003?o03?o000B<ol00P00
08Goool00ol0VOooooooo`0Ooooo001Roooo00<0000co`0co`004S?o00030000oooooooo08Coool0
0ol0VOooooooo`0Ooooo001Soooo00<0000co`0co`004C?o00030000oooooooo08Coool00ol0VOoo
ooooo`0Ooooo001Soooo00<0000co`0co`004C?o00030000oooooooo08Coool00ol0VOooooooo`0O
oooo001Soooo00<0000co`0co`004C?o00800025oooo00?o09Woooooool07oooo`00Hoooo`030000
<ol0<ol0014co`000`000?ooooooo`24oooo00?o09Woooooool07oooo`00Hoooo`030000<ol0<ol0
00Tco`0500000c?o00030000oooooooo08Coool00ol0VOooooooo`0Ooooo001Toooo00<0000co`0c
o`002S?o00030000<ol0<ol000<co`000`000?ooooooo`24oooo00?o09Woooooool07oooo`00I?oo
o`030000<ol0<ol000Xco`000`0003?o03?o0003<ol00P0008Goool00ol0VOooooooo`0Ooooo001T
oooo3C?o00030000<ol0<ol000<co`2Yoooo001Toooo3C?o00030000<ol0<ol000<co`2Yoooo001T
oooo33?o00800005<ol0ZOooo`00IOoooa8co`2Yoooo001Uoooo4S?o0:Woool006GooolB<ol01Ooo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001Uoooo4S?o00Coool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool006GooolB<ol01?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004oooo0P0000Coool00`000?oo
ooooo`1koooo001Uoooo4S?o00Coool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00IOoooa8co`03oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0N_ooo`00I_oooa4co`04oooo00<0
003oooooool01@0000koool00`000?ooooooo`08oooo0P0000Coool00`000?ooooooo`1koooo001V
oooo4C?o00Coool01@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07_oool006KooolA<ol01Oooo`030000oooooooo017oool200002_oo
o`800003oooo00<0003oooooool0O?ooo`00I_oooa4co`2Yoooo001Voooo4C?o0:Woool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
.33626 .65768 L
.34581 .71904 L
.36548 .88801 L
.37628 1.01446 L
.38646 1.16447 L
.39622 1.34603 L
.40114 1.45529 L
.40248 1.48768 L
.40323 1.506 L
.40393 1.52368 L
.40458 1.54041 L
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .31198 m
.04262 .31294 L
.06244 .31429 L
.08255 .31613 L
.10458 .31889 L
.12415 .32224 L
.14509 .32709 L
.16639 .33389 L
.18653 .34267 L
.20651 .35451 L
.22495 .36918 L
.24367 .38908 L
.2643 .41902 L
.28371 .45793 L
.30459 .51644 L
.31469 .5532 L
.32572 .60155 L
s
.32572 .60155 m
.32882 .61803 L
s
.40511 .61803 m
.40529 .30902 L
.40653 .30902 L
.42501 .30902 L
.46579 .30902 L
.50506 .30902 L
.54281 .30902 L
.58301 .30902 L
.6217 .30902 L
.66284 .30902 L
.70246 .30902 L
.74057 .30902 L
.78113 .30902 L
.82018 .30902 L
.86167 .30902 L
.90166 .30902 L
.94012 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.91726 .30902 L
.92761 .30902 L
.93871 .30902 L
.94392 .30902 L
.94885 .30902 L
.95328 .30902 L
.95449 .30902 L
.95578 .30902 L
.95688 .30902 L
s
.95688 .30902 m
.957 .61803 L
s
0 .4 1 r
.02381 .10178 m
.06244 .10542 L
.10458 .11068 L
.14415 .11721 L
.18221 .12535 L
.22272 .1365 L
.26171 .15004 L
.30316 .16617 L
.34309 .18118 L
.36136 .18714 L
.37176 .19009 L
.3815 .19245 L
.39106 .19431 L
.39642 .19511 L
.40134 .19567 L
.40661 .19607 L
.41224 .19655 L
.42237 .19773 L
.43232 .19935 L
.44135 .20124 L
.45214 .20409 L
.46207 .20732 L
.48132 .21548 L
.50214 .22758 L
.52097 .24197 L
.54163 .26225 L
.56277 .28873 L
.56763 .29574 L
.57279 .30359 L
.57491 .30695 L
.5761 .30887 L
.57719 .30902 L
.57841 .30902 L
.5797 .30902 L
.58205 .30902 L
.59162 .30902 L
.60203 .30902 L
.62096 .30902 L
.65907 .30902 L
.69963 .30902 L
.73868 .30902 L
.78017 .30902 L
.82016 .30902 L
.85862 .30902 L
.89954 .30902 L
.93894 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.309017 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 0 -12 -4.5 ]
[.39226 0 0 4.5 ]
[.39226 .07725 -30 -4.5 ]
[.39226 .07725 0 4.5 ]
[.39226 .15451 -24 -4.5 ]
[.39226 .15451 0 4.5 ]
[.39226 .23176 -30 -4.5 ]
[.39226 .23176 0 4.5 ]
[.39226 .38627 -24 -4.5 ]
[.39226 .38627 0 4.5 ]
[.39226 .46353 -18 -4.5 ]
[.39226 .46353 0 4.5 ]
[.39226 .54078 -24 -4.5 ]
[.39226 .54078 0 4.5 ]
[.39226 .61803 -6 -4.5 ]
[.39226 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 0 m
.41101 0 L
s
[(-1)] .39226 0 1 0 Mshowa
.40476 .07725 m
.41101 .07725 L
s
[(-0.75)] .39226 .07725 1 0 Mshowa
.40476 .15451 m
.41101 .15451 L
s
[(-0.5)] .39226 .15451 1 0 Mshowa
.40476 .23176 m
.41101 .23176 L
s
[(-0.25)] .39226 .23176 1 0 Mshowa
.40476 .38627 m
.41101 .38627 L
s
[(0.25)] .39226 .38627 1 0 Mshowa
.40476 .46353 m
.41101 .46353 L
s
[(0.5)] .39226 .46353 1 0 Mshowa
.40476 .54078 m
.41101 .54078 L
s
[(0.75)] .39226 .54078 1 0 Mshowa
.40476 .61803 m
.41101 .61803 L
s
[(1)] .39226 .61803 1 0 Mshowa
.125 Mabswid
.40476 .01545 m
.40851 .01545 L
s
.40476 .0309 m
.40851 .0309 L
s
.40476 .04635 m
.40851 .04635 L
s
.40476 .0618 m
.40851 .0618 L
s
.40476 .09271 m
.40851 .09271 L
s
.40476 .10816 m
.40851 .10816 L
s
.40476 .12361 m
.40851 .12361 L
s
.40476 .13906 m
.40851 .13906 L
s
.40476 .16996 m
.40851 .16996 L
s
.40476 .18541 m
.40851 .18541 L
s
.40476 .20086 m
.40851 .20086 L
s
.40476 .21631 m
.40851 .21631 L
s
.40476 .24721 m
.40851 .24721 L
s
.40476 .26266 m
.40851 .26266 L
s
.40476 .27812 m
.40851 .27812 L
s
.40476 .29357 m
.40851 .29357 L
s
.40476 .32447 m
.40851 .32447 L
s
.40476 .33992 m
.40851 .33992 L
s
.40476 .35537 m
.40851 .35537 L
s
.40476 .37082 m
.40851 .37082 L
s
.40476 .40172 m
.40851 .40172 L
s
.40476 .41717 m
.40851 .41717 L
s
.40476 .43262 m
.40851 .43262 L
s
.40476 .44807 m
.40851 .44807 L
s
.40476 .47898 m
.40851 .47898 L
s
.40476 .49443 m
.40851 .49443 L
s
.40476 .50988 m
.40851 .50988 L
s
.40476 .52533 m
.40851 .52533 L
s
.40476 .55623 m
.40851 .55623 L
s
.40476 .57168 m
.40851 .57168 L
s
.40476 .58713 m
.40851 .58713 L
s
.40476 .60258 m
.40851 .60258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001_oooo1@000:coool0077oool00`000?ooooooo`2/oooo001aoooo00<0003ooooo
ool00oooo`80002Woooo001Yoooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0Y_oo
o`00LOooo`030000oooooooo00?oool00`000?ooooooo`2Voooo001`oooo0P0000Goool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001goooo00<0003ooooo
ool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool20000Yoooo`00Moooo`030000oooooooo
0:Koool007Ooool00`000?ooooooo`2Voooo001goooo00<0003oooooool0Y_ooo`00Moooo`80002W
oooo001goooo00<0003oooooool0Y_ooo`00Moooo`030000oooooooo0:Koool007Ooool00`000?oo
ooooo`2Voooo001goooo0P000:Ooool007Ooool00`000?ooooooo`2Voooo001Noooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001Oooo`030000oooooooo0:Koool005goool010000?oo
ooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
0:Koool005goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`80002Woooo001Goooo100000;oool010000?ooooooo`0000_oool010000?ooooooooooo`800005
oooo00<0003oooooool0Y_ooo`00GOooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool00`000?ooooooo`2Voooo001Noooo0P0000Woool400000oooo`<00004
oooo00<0003oooooool0Y_ooo`00Moooo`80002Woooo001goooo00<0003oooooool0Y_ooo`005_oo
o`D0I_mLoooo00<0003oooooool0Y_ooo`006oooo`/0I_mAoooo0P000:Ooool002Koool806KoBOoo
o`030000oooooooo0:Koool002koool506KoA?ooo`030000oooooooo0:Koool003?oool506Ko?ooo
o`030000oooooooo0:Koool003Soool406Ko>oooo`80002Woooo000loooo101VocOoool00`000?oo
ooooo`2Voooo0010oooo101Voc?oool00`000?ooooooo`2Voooo0014oooo101Vobooool00`000?oo
ooooo`2Voooo0018oooo0`1Vobcoool20000Yoooo`00Boooo`<0I_lYoooo00<0003oooooool0Y_oo
o`00C_ooo`@0I_lBoooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0Y_ooo`00D_oo
o`<0I_l>oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Y_oo
o`00EOooo`80I_l<oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`80002Woooo001G
oooo0`1Vo`?oool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Y_oo
o`00F_ooo`80I_l7oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
0:Koool005coool306Ko1Oooo`80000:oooo0`0000Coool00`000?ooooooo`2Voooo001Ooooo0P1V
oaKoool20000Yoooo`00HOooo`<0I_lCoooo00<0003oooooool0Y_ooo`00I?ooo`80I_lAoooo00<0
003oooooool0Y_ooo`00I_ooo`<0I_l>oooo00<0003oooooool0Y_ooo`00JOooo`80I_l<oooo0P00
0:Ooool006_oool506Ko1oooo`030000oooooooo0:Koool0073oool406Ko0oooo`030000oooooooo
0:Koool007Coool306Ko00<00000I_l0I_l00`1Voj?oool007Ooool200001?ooo`D0I_nNoooo001g
oooo00<0003oooooool02?ooo`80I_nLoooo001goooo00<0003oooooool02_ooo`<0I_nIoooo001g
oooo00<0003oooooool03Oooo`80I_nGoooo001goooo0P00013oool206KoUOooo`00Moooo`030000
oooooooo017oool206KoToooo`00G_ooo`800004oooo0P0000?oool400000oooo`800005oooo00<0
003oooooool04oooo`80I_nAoooo001Moooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`040000oooooooo00001?ooo`030000oooooooo01Goool206KoSoooo`00GOooo`040000oooooooo
00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo0P0001Soool00`1Vooooooooo`2<
oooo001Goooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Goool0
0`000?ooooooo`0Hoooo0P1Vohcoool005goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`04oooo00<0003oooooool06_ooo`0306Kooooooooo08Woool005koool2
00002_ooo`800004oooo0`0000Coool00`000?ooooooo`0Koooo00<0I_ooooooool0R?ooo`00Mooo
o`80000Moooo00<0I_ooooooool0Qoooo`00Moooo`030000oooooooo01goool00`1Vooooooooo`26
oooo001goooo00<0003oooooool07_ooo`0306Kooooooooo08Goool007Ooool00`000?ooooooo`0O
oooo00<0I_ooooooool0Q?ooo`005oooo`@0000]oooo1@0002[oool200008Oooo`0306Kooooooooo
00Soool50000:oooo`@0000^oooo0P0001Ooool001Ooool00`000?ooooooo`0`oooo00<0003ooooo
ool0:_ooo`030000oooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0:oooo`030000
oooooooo02koool010000?ooooooo`0001Koool001Soool00`000?ooooooo`0_oooo00<0003ooooo
ool0:_ooo`030000oooooooo02;oool00`1Vooooooooo`08oooo00<0003oooooool0;?ooo`030000
oooooooo02ooool00`000?ooooooo`0Eoooo000Aoooo100000Coool00`000?ooooooo`0Voooo1000
00Coool00`000?ooooooo`0Zoooo00<0003oooooool08_ooo`0306Kooooooooo00Soool00`000?oo
ooooo`0]oooo00<0003oooooool0;oooo`030000oooooooo01Coool001Ooool010000?ooooooo`00
02ooool00`000?ooooooo`0Zoooo0P0002Coool00`1Vooooooooo`07oooo00<0003oooooool0:ooo
o`040000oooooooo0000;Oooo`040000oooooooo00005_ooo`006?ooo`80000_oooo0P0002coool0
0`000?ooooooo`0Toooo00<0I_ooooooool01Oooo`80000^oooo0P0002ooool200005oooo`00Mooo
o`030000oooooooo02Goool00`1Vooooooooo`1noooo001goooo0P0002Koool00`1Vooooooooo`1n
oooo001goooo00<0003oooooool09_ooo`0306Kooooooooo07goool007Ooool00`000?ooooooo`0V
oooo00<0I_ooooooool0OOooo`00Moooo`030000oooooooo02Ooool00`1Vooooooooo`1loooo000@
ooooo`00017oool001Koool800000S?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000oooooooo
00Koool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Koool00`000?ooooooo`07oooo00<0003oooooool00_ooo`03o`2Ioooooooo
00;oool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool01Oooo`X0000O<ol000<0000co`0c
o`00;C?o00030000oooooooo02goool00`000?ooooooo`0]oooo00<0003oooooool0:Oooo`03o`2I
oooooooo00;oool00`000?ooooooo`0Eoooo000Xoooo1P0004Tco`000`000?ooooooo`29oooo00?o
09Woooooool06_ooo`00;_ooo`D00014<ol00P0008[oool00ol0VOooooooo`0Joooo000coooo1000
040co`000`000?ooooooo`29oooo00?o09Woooooool06_ooo`00=oooo`80000n<ol000<0003ooooo
ool0ROooo`03o`2Ioooooooo01[oool003Woool30000>c?o00030000oooooooo08Woool00ol0VOoo
ooooo`0Joooo000loooo0P0003Tco`020000R_ooo`03o`2Ioooooooo01[oool003koool20000=c?o
00030000oooooooo08Woool00ol0VOooooooo`0Joooo0010oooo0P0003Dco`000`000?ooooooo`29
oooo00?o09Woooooool06_ooo`00@_ooo`80000c<ol000<0003oooooool0ROooo`03o`2Ioooooooo
01[oool004Coool20000<C?o0080002:oooo00?o09Woooooool06_ooo`00A_ooo`030000<ol0<ol0
02hco`000`000?ooooooo`29oooo00?o09Woooooool06_ooo`00Aoooo`030000<ol0<ol002dco`00
0`000?ooooooo`29oooo00?o09Woooooool06_ooo`00B?ooo`030000<ol0<ol002`co`000`000?oo
ooooo`29oooo00?o09Woooooool06_ooo`00BOooo`030000<ol0<ol002/co`020000R_ooo`03o`2I
oooooooo01[oool004[oool00`0003?o03?o000Z<ol000<0003oooooool0ROooo`03o`2Ioooooooo
01[oool004_oool00`0003?o03?o000@<ol00P0000@co`0200000c?o00@00003<ol00P0000Dco`00
0`000?ooooooo`29oooo00?o09Woooooool06_ooo`00C?ooo`030000<ol0<ol000hco`00100003?o
03?o000000Pco`000`0003?o03?o0003<ol000@0000co`0co`000004<ol000<0003oooooool0ROoo
o`03o`2Ioooooooo01[oool004goool00`0003?o03?o000=<ol000@0000co`0co`000009<ol000<0
000co`0co`001C?o00030000<ol0<ol0008co`020000R_ooo`03o`2Ioooooooo01[oool004koool0
0`0003?o03?o000<<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800005<ol000<0
003oooooool0ROooo`03o`2Ioooooooo01[oool004ooool00`0003?o03?o000;<ol000@0000co`0c
o`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000oooooooo08Woool0
0ol0VOooooooo`0Joooo001?oooo00<0000co`0co`0033?o0080000:<ol00P0000@co`03000013?o
00030000oooooooo08Woool00ol0VOooooooo`0Joooo001@oooo00<0000co`0co`0093?o0080002:
oooo00?o09Woooooool06_ooo`00DOooo`030000<ol0<ol002<co`000`000?ooooooo`29oooo00?o
09Woooooool06_ooo`00D_ooo`030000<ol0<ol0028co`000`000?ooooooo`29oooo00?o09Wooooo
ool06_ooo`00D_ooo`030000<ol0<ol0028co`000`000?ooooooo`29oooo00?o09Woooooool06_oo
o`00Doooo`030000<ol0<ol0024co`020000R_ooo`03o`2Ioooooooo01[oool005?oool00`0003?o
03?o000Q<ol000<0003oooooool0ROooo`03o`2Ioooooooo01[oool005Coool00`0003?o03?o000P
<ol000<0003oooooool0ROooo`03o`2Ioooooooo01[oool005Coool00`0003?o03?o000P<ol000<0
003oooooool0ROooo`03o`2Ioooooooo01[oool005Goool00`0003?o03?o000O<ol00P0008[oool0
0ol0VOooooooo`0Joooo001Eoooo00<0000co`0co`007c?o00030000oooooooo08Woool00ol0VOoo
ooooo`0Joooo001Foooo00<0000co`0co`007S?o00030000oooooooo08Woool00ol0VOooooooo`0J
oooo001Foooo00<0000co`0co`007S?o00030000oooooooo08Woool00ol0VOooooooo`0Joooo001G
oooo00<0000co`0co`007C?o0080002:oooo00?o09Woooooool06_ooo`00Eoooo`030000<ol0<ol0
01dco`000`000?ooooooo`29oooo00?o09Woooooool06_ooo`00F?ooo`030000<ol0<ol000Tco`02
000013?o00800004<ol00P0000Dco`000`000?ooooooo`29oooo00?o09Woooooool06_ooo`00F?oo
o`030000<ol0<ol000Pco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`000?oo
ooooo`29oooo00?o09Woooooool06_ooo`00FOooo`030000<ol0<ol000Lco`00100003?o03?o0000
00/co`000`0003?o03?o0002<ol00P0008[oool00ol0VOooooooo`0Joooo001Ioooo00<0000co`0c
o`001c?o00040000<ol0<ol000002C?o00800005<ol000<0003oooooool0ROooo`03o`2Ioooooooo
01[oool005Woool00`0003?o03?o0007<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o
00030000oooooooo08Woool00ol0VOooooooo`0Joooo001Joooo00<0000co`0co`001c?o0080000:
<ol00`0000@co`000`000?ooooooo`29oooo00?o09Woooooool06_ooo`00F_ooo`030000<ol0<ol0
01Xco`020000R_ooo`03o`2Ioooooooo01[oool005[oool00`0003?o03?o000J<ol000<0003ooooo
ool0ROooo`03o`2Ioooooooo01[oool005_oool00`0003?o03?o000I<ol000<0003oooooool0ROoo
o`03o`2Ioooooooo01[oool005_oool00`0003?o03?o000I<ol00P0008[oool00ol0VOooooooo`0J
oooo001Koooo00<0000co`0co`006C?o00030000oooooooo08Woool00ol0VOooooooo`0Joooo001L
oooo00<0000co`0co`0063?o00030000oooooooo08Woool00ol0VOooooooo`0Joooo001Loooo00<0
000co`0co`0063?o00030000oooooooo08Woool00ol0VOooooooo`0Joooo001Loooo00<0000co`0c
o`0063?o0080002:oooo00?o09Woooooool06_ooo`00GOooo`030000<ol0<ol001Lco`000`000?oo
ooooo`29oooo00?o09Woooooool06_ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`29
oooo00?o09Woooooool06_ooo`00GOooo`030000<ol0<ol001Lco`000`000?ooooooo`29oooo00?o
09Woooooool06_ooo`00G_ooo`030000<ol0<ol001Hco`020000R_ooo`03o`2Ioooooooo01[oool0
05koool00`0003?o03?o000F<ol000<0003oooooool0ROooo`03o`2Ioooooooo01[oool005koool2
000013?o00800005<ol000<0000co`0co`000S?o00800005<ol000<0003oooooool0ROooo`03o`2I
oooooooo01[oool005goool010000?ooo`00000000Xco`001@0003?o03?o03?o00000002<ol000<0
000co`0co`000S?o00030000oooooooo08Woool00ol0VOooooooo`0Joooo001Moooo00@0003oool0
0000000:<ol000<0000co`0co`0013?o00030000<ol0<ol0008co`020000R_ooo`03o`2Ioooooooo
01[oool005goool010000?ooo`00000000/co`00100003?o03?o03?o00800005<ol000<0003ooooo
ool0ROooo`03o`2Ioooooooo01[oool005goool010000?ooooooo`0000Pco`00100003?o03?o0000
00<co`000`0003?o03?o0004<ol000<0003oooooool0ROooo`03o`2Ioooooooo01[oool005koool3
000023?o00@00003<ol00`0000@co`000`000?ooooooo`29oooo00?o09Woooooool06_ooo`00H?oo
o`030000<ol0<ol001@co`020000R_ooo`03o`2Ioooooooo01[oool0063oool00`0003?o03?o000D
<ol000<0003oooooool0ROooo`03o`2Ioooooooo01[oool0067oool00`0003?o03?o000C<ol000<0
003oooooool0ROooo`03o`2Ioooooooo01[oool0067oool00`0003?o03?o000C<ol000<0003ooooo
ool0ROooo`03o`2Ioooooooo01[oool0067oool00`0003?o03?o000C<ol00P0008[oool00ol0VOoo
ooooo`0Joooo001Qoooo00<0000co`0co`004c?o00030000oooooooo08Woool00ol0VOooooooo`0J
oooo001Roooo00<0000co`0co`004S?o00030000oooooooo08Woool00ol0VOooooooo`0Joooo001R
oooo00<0000co`0co`004S?o00030000oooooooo08Woool00ol0VOooooooo`0Joooo001Roooo00<0
000co`0co`004S?o0080002:oooo00?o09Woooooool06_ooo`00H_ooo`030000<ol0<ol0018co`00
0`000?ooooooo`29oooo00?o09Woooooool06_ooo`00Hoooo`030000<ol0<ol0014co`000`000?oo
ooooo`29oooo00?o09Woooooool06_ooo`00Hoooo`030000<ol0<ol0014co`000`000?ooooooo`29
oooo00?o09Woooooool06_ooo`00Hoooo`030000<ol0<ol0014co`020000R_ooo`03o`2Ioooooooo
01[oool006?oool00`0003?o03?o000A<ol000<0003oooooool0ROooo`03o`2Ioooooooo01[oool0
06?oool00`0003?o03?o0009<ol01@0000<co`000`000?ooooooo`29oooo00?o09Woooooool06_oo
o`00I?ooo`030000<ol0<ol000Xco`000`0003?o03?o0003<ol000<0003oooooool0ROooo`03o`2I
oooooooo01[oool006Coool00`0003?o03?o000:<ol000<0000co`0co`000c?o0080002:oooo00?o
09Woooooool06_ooo`00I?ooo`dco`000`0003?o03?o0003<ol0ZOooo`00I?ooo`dco`000`0003?o
03?o0003<ol0ZOooo`00I?ooo``co`0200001C?o0:Woool006GooolB<ol0ZOooo`00IOoooa8co`2Y
oooo001Uoooo4S?o00Goool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00IOoooa8co`04
oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001Uoooo4S?o
00Coool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200000ooo
o`<00004oooo00<0003oooooool0Noooo`00IOoooa8co`04oooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02Oooo`030000oooooooo
00;oool00`000?ooooooo`1koooo001Uoooo4S?o00?oool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Soool300001?ooo`030000oooooooo07[oool006KooolA<ol01?oo
o`030000oooooooo00D0000>oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07_oool006KooolA<ol01?ooo`050000oooooooooooo0000017oool00`000?ooooooo`07
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00I_oooa4co`05oooo00<0003ooooo
ool04Oooo`80000:oooo0`0000;oool00`000?ooooooo`1loooo001Voooo4C?o0:Woool006KooolA
<ol0ZOooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.47062, \
-1.05744, 0.0207057, 0.0127628}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.47062, -1.05744, 0.0207057, 0.0127628}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
ScreenStyleEnvironment->"Working",
WindowSize->{757, 792},
WindowMargins->{{Automatic, 84}, {Automatic, -14}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 239, 9, 96, "Title"],
Cell[1969, 63, 1138, 31, 277, "Text"],
Cell[3110, 96, 120, 4, 49, "Text"],
Cell[3233, 102, 578, 13, 19, "Input",
  CellOpen->False],
Cell[3814, 117, 121, 4, 49, "Text"],
Cell[3938, 123, 54, 1, 30, "Input"],
Cell[3995, 126, 108, 1, 49, "Text"],
Cell[4106, 129, 2514, 56, 19, "Input",
  CellOpen->False],
Cell[6623, 187, 74, 2, 19, "Input",
  CellOpen->False],
Cell[6700, 191, 75, 2, 19, "Input",
  CellOpen->False],
Cell[6778, 195, 373, 12, 49, "Text"],

Cell[CellGroupData[{
Cell[7176, 211, 635, 10, 110, "Input"],

Cell[CellGroupData[{
Cell[7836, 225, 31590, 1414, 186, 20201, 1269, "GraphicsData", "PostScript", \
"Graphics"],
Cell[39429, 1641, 31708, 1416, 186, 20220, 1270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[71140, 3059, 31237, 1383, 186, 19688, 1236, "GraphicsData", \
"PostScript", "Graphics"],
Cell[102380, 4444, 31440, 1395, 186, 19875, 1248, "GraphicsData", \
"PostScript", "Graphics"],
Cell[133823, 5841, 31331, 1388, 186, 19766, 1241, "GraphicsData", \
"PostScript", "Graphics"],
Cell[165157, 7231, 31227, 1384, 186, 19702, 1237, "GraphicsData", \
"PostScript", "Graphics"],
Cell[196387, 8617, 31066, 1374, 186, 19545, 1227, "GraphicsData", \
"PostScript", "Graphics"],
Cell[227456, 9993, 31156, 1376, 186, 19575, 1229, "GraphicsData", \
"PostScript", "Graphics"],
Cell[258615, 11371, 30782, 1352, 186, 19193, 1205, "GraphicsData", \
"PostScript", "Graphics"],
Cell[289400, 12725, 30890, 1360, 186, 19325, 1213, "GraphicsData", \
"PostScript", "Graphics"],
Cell[320293, 14087, 30706, 1354, 186, 19250, 1208, "GraphicsData", \
"PostScript", "Graphics"],
Cell[351002, 15443, 30458, 1332, 186, 18885, 1185, "GraphicsData", \
"PostScript", "Graphics"],
Cell[381463, 16777, 30331, 1323, 186, 18750, 1176, "GraphicsData", \
"PostScript", "Graphics"],
Cell[411797, 18102, 30363, 1326, 186, 18786, 1179, "GraphicsData", \
"PostScript", "Graphics"],
Cell[442163, 19430, 30210, 1315, 186, 18621, 1168, "GraphicsData", \
"PostScript", "Graphics"],
Cell[472376, 20747, 30213, 1316, 186, 18640, 1169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[502592, 22065, 30054, 1308, 186, 18497, 1161, "GraphicsData", \
"PostScript", "Graphics"],
Cell[532649, 23375, 29894, 1296, 186, 18321, 1149, "GraphicsData", \
"PostScript", "Graphics"],
Cell[562546, 24673, 29789, 1288, 186, 18200, 1141, "GraphicsData", \
"PostScript", "Graphics"],
Cell[592338, 25963, 29566, 1276, 186, 17997, 1129, "GraphicsData", \
"PostScript", "Graphics"],
Cell[621907, 27241, 29423, 1273, 186, 17971, 1127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[651333, 28516, 29497, 1271, 186, 17924, 1124, "GraphicsData", \
"PostScript", "Graphics"],
Cell[680833, 29789, 29270, 1256, 186, 17689, 1109, "GraphicsData", \
"PostScript", "Graphics"],
Cell[710106, 31047, 29394, 1264, 186, 17817, 1117, "GraphicsData", \
"PostScript", "Graphics"],
Cell[739503, 32313, 29033, 1243, 186, 17480, 1096, "GraphicsData", \
"PostScript", "Graphics"],
Cell[768539, 33558, 28995, 1241, 186, 17454, 1094, "GraphicsData", \
"PostScript", "Graphics"],
Cell[797537, 34801, 28949, 1238, 186, 17404, 1091, "GraphicsData", \
"PostScript", "Graphics"],
Cell[826489, 36041, 28821, 1228, 186, 17248, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[855313, 37271, 28572, 1214, 186, 17027, 1067, "GraphicsData", \
"PostScript", "Graphics"],
Cell[883888, 38487, 28500, 1211, 186, 16996, 1065, "GraphicsData", \
"PostScript", "Graphics"],
Cell[912391, 39700, 28248, 1202, 186, 16869, 1057, "GraphicsData", \
"PostScript", "Graphics"],
Cell[940642, 40904, 28179, 1194, 186, 16752, 1049, "GraphicsData", \
"PostScript", "Graphics"],
Cell[968824, 42100, 28071, 1190, 186, 16676, 1045, "GraphicsData", \
"PostScript", "Graphics"],
Cell[996898, 43292, 27750, 1175, 186, 16452, 1031, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1024651, 44469, 27508, 1168, 186, 16380, 1026, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1052162, 45639, 27185, 1157, 186, 16235, 1017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1079350, 46798, 26717, 1148, 186, 16193, 1014, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1106070, 47948, 26494, 1141, 186, 16099, 1008, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1132567, 49091, 25806, 1127, 186, 15978, 1001, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1158376, 50220, 24957, 1108, 186, 15826, 991, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1183336, 51330, 24575, 1095, 186, 15667, 981, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1207914, 52427, 25596, 1117, 186, 15841, 992, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1233513, 53546, 26853, 1137, 186, 15936, 998, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1260369, 54685, 27804, 1154, 186, 16036, 1004, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1288176, 55841, 27947, 1166, 186, 16232, 1017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1316126, 57009, 28068, 1175, 186, 16377, 1026, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1344197, 58186, 28111, 1182, 186, 16522, 1035, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1372311, 59370, 28107, 1184, 186, 16550, 1037, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1400421, 60556, 28230, 1196, 186, 16758, 1050, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1428654, 61754, 28120, 1197, 186, 16806, 1053, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1456777, 62953, 25893, 1077, 186, 14785, 935, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1482673, 64032, 27740, 1181, 186, 16394, 1037, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1510416, 65215, 27891, 1183, 186, 16403, 1037, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1538310, 66400, 27743, 1171, 186, 16194, 1024, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1566056, 67573, 27754, 1170, 186, 16156, 1022, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1593813, 68745, 27657, 1160, 186, 15999, 1012, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1621473, 69907, 27609, 1154, 186, 15890, 1005, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1649085, 71063, 27508, 1143, 186, 15704, 993, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1676596, 72208, 27431, 1137, 186, 15607, 987, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1704030, 73347, 27277, 1131, 186, 15509, 981, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1731310, 74480, 26966, 1119, 186, 15352, 971, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1758279, 75601, 27072, 1120, 186, 15357, 971, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1785354, 76723, 27126, 1123, 186, 15399, 974, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1812483, 77848, 27146, 1124, 186, 15411, 975, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1839632, 78974, 27125, 1123, 186, 15402, 974, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1866760, 80099, 27166, 1123, 186, 15386, 973, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1893929, 81224, 27205, 1124, 186, 15401, 974, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1921137, 82350, 27172, 1121, 186, 15360, 971, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1948312, 83473, 27317, 1129, 186, 15472, 978, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1975632, 84604, 27372, 1133, 186, 15527, 982, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2003007, 85739, 27486, 1146, 186, 15763, 997, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2030496, 86887, 27699, 1156, 186, 15907, 1006, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2058198, 88045, 27756, 1160, 186, 15956, 1010, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2085957, 89207, 27814, 1163, 186, 16006, 1013, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2113774, 90372, 27942, 1169, 186, 16110, 1019, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2141719, 91543, 27974, 1171, 186, 16125, 1020, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2169696, 92716, 27956, 1169, 186, 16091, 1018, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2197655, 93887, 28026, 1171, 186, 16113, 1020, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2225684, 95060, 28062, 1173, 186, 16140, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2253749, 96235, 28068, 1174, 186, 16171, 1023, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2281820, 97411, 28012, 1176, 186, 16216, 1026, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2309835, 98589, 28072, 1175, 186, 16191, 1024, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2337910, 99766, 28054, 1174, 186, 16173, 1023, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2365967, 100942, 28089, 1173, 186, 16139, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2394059, 102117, 28072, 1174, 186, 16150, 1022, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2422134, 103293, 28104, 1173, 186, 16138, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2450241, 104468, 28117, 1173, 186, 16135, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2478361, 105643, 28220, 1179, 186, 16234, 1027, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2506584, 106824, 28171, 1175, 186, 16177, 1023, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2534804, 108005, 652, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[2535481, 108020, 31671, 1393, 186, 19446, 1238, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2567155, 109415, 31439, 1380, 186, 19232, 1225, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2598597, 110797, 30999, 1351, 186, 18768, 1196, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2629599, 112150, 30658, 1330, 186, 18443, 1175, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2660260, 113482, 30358, 1309, 186, 18119, 1154, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2690621, 114793, 30441, 1316, 186, 18230, 1161, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2721065, 116111, 29579, 1259, 186, 17315, 1103, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2750647, 117372, 29670, 1266, 186, 17435, 1111, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2780320, 118640, 31623, 1350, 186, 18300, 1181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2811946, 119992, 28914, 1226, 186, 16837, 1073, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2840863, 121220, 28505, 1199, 186, 16395, 1045, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2869371, 122421, 28283, 1186, 186, 16218, 1033, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2897657, 123609, 28107, 1178, 186, 16086, 1025, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2925767, 124789, 27630, 1157, 186, 15779, 1006, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2953400, 125948, 27036, 1130, 186, 15404, 982, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2980439, 127080, 26954, 1114, 186, 15103, 963, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3007396, 128196, 26996, 1101, 186, 14854, 947, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3034395, 129299, 26834, 1086, 186, 14582, 930, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3061232, 130387, 26509, 1065, 186, 14270, 910, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3087744, 131454, 25061, 1032, 186, 13964, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3112808, 132488, 27572, 1091, 186, 14502, 925, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3140383, 133581, 27985, 1112, 186, 14822, 945, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3168371, 134695, 28451, 1132, 186, 15106, 963, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3196825, 135829, 28676, 1148, 186, 15355, 979, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3225504, 136979, 28955, 1166, 186, 15646, 997, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3254462, 138147, 29004, 1176, 186, 15825, 1009, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3283469, 139325, 29207, 1196, 186, 16174, 1031, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3312679, 140523, 29183, 1207, 186, 16393, 1045, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3341865, 141732, 29466, 1236, 186, 16886, 1076, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3371334, 142970, 33557, 1416, 186, 20526, 1251, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3404894, 144388, 28915, 1211, 186, 16339, 1051, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3433812, 145601, 28807, 1196, 186, 16057, 1034, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3462622, 146799, 28961, 1187, 186, 15855, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3491586, 147988, 28894, 1173, 186, 15597, 1004, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3520483, 149163, 28775, 1159, 186, 15361, 989, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3549261, 150324, 28498, 1141, 186, 15076, 971, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3577762, 151467, 28226, 1126, 186, 14836, 956, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3605991, 152595, 27792, 1107, 186, 14572, 939, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3633786, 153704, 27484, 1088, 186, 14289, 921, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3661273, 154794, 26508, 1051, 186, 13774, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3687784, 155847, 26563, 1052, 186, 13793, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3714350, 156901, 26595, 1052, 186, 13780, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3740948, 157955, 26763, 1056, 186, 13827, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3767714, 159013, 26751, 1056, 186, 13823, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3794468, 160071, 26808, 1057, 186, 13831, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3821279, 161130, 26788, 1056, 186, 13811, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3848070, 162188, 26816, 1057, 186, 13823, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3874889, 163247, 26888, 1062, 186, 13920, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3901780, 164311, 27020, 1070, 186, 14035, 905, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

